(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7917752,     120737]*)
(*NotebookOutlinePosition[   7918509,     120763]*)
(*  CellTagsIndexPosition[   7918465,     120759]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Tiling with Circles", "Title",
  FontColor->RGBColor[0.501961, 0, 0],
  Background->RGBColor[1, 1, 0.501961]],

Cell["by Jaime Rangel-Mondrag\[OAcute]n", "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Autonomous University of Queretaro. Faculty of Informatics
Queretaro\.b4s Institute of Technology. Mechatronics Department

jrangel@sunserver.uaq.mx\
\>", "Address"],

Cell["\<\


Copyright \[Copyright] April 2003
Permission is hereby granted to reproduce part or all of this file for any \
purpose other than direct profit providing that the source is acknowledged.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Abstract", "SectionFirst"],

Cell["\<\
Our purpose in this work is to fill the interior of an arbitrary polygon with \
circles in a systematic way. This process  necessarily involves an infinite \
number of circles so a convergent process is provided. Included are a gallery \
and animations using the Real3D feature.\
\>", "Text"],

Cell["\<\
\"Fill what's empty, empty what's full, and scratch where it itches.\"
- the Duchess of Windsor,when asked what is the secret of a long and happy \
life

\"When I am working on a problem I never think about beauty. I only think \
about how to solve the problem. 
But when I have finished, if the solution is not beautiful, I know it is \
wrong.\"
- Buckminster Fuller\
\>", "Abstract",
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`Colors`\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Motivation", "Section"],

Cell["\<\
The motivation of this work arose from generating the following figure:\
\>", "Text"],

Cell[BoxData[{
    \(shG[
        g_] := \((\(Show[Graphics[g], AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All];\))\)\), "\[IndentingNewLine]", 
    \(\(\(size[p_] := \@\(p . p\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(tower[c_, r_, 1] := Circle[c, r]\), "\n", 
    \(tower[c_, r_, n_] := 
      Join[{Circle[c, r]}, {tower[c + \(\(4  r\)\/3\) {0, 1}, r\/3, n - 1], 
          tower[c + \(\(2  r\)\/3\) {\@3, \(-1\)}, r\/3, n - 1], 
          tower[c + \(\(2  r\)\/3\) {\(-\@3\), \(-1\)}, r\/3, 
            n - 1]}]\)}], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(shG[tower[{0, 0}, 1, 4]]\)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86894 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.279301 0.29999 0.279301 [
[ 0 0 0 0 ]
[ 1 .86894 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .29999 .2793 0 365.73 arc
s
newpath
.5 .67239 .0931 0 365.73 arc
s
newpath
.5 .79652 .03103 0 365.73 arc
s
newpath
.5 .8379 .01034 0 365.73 arc
s
newpath
.53583 .77584 .01034 0 365.73 arc
s
newpath
.46417 .77584 .01034 0 365.73 arc
s
newpath
.6075 .61032 .03103 0 365.73 arc
s
newpath
.6075 .6517 .01034 0 365.73 arc
s
newpath
.64334 .58963 .01034 0 365.73 arc
s
newpath
.57167 .58963 .01034 0 365.73 arc
s
newpath
.3925 .61032 .03103 0 365.73 arc
s
newpath
.3925 .6517 .01034 0 365.73 arc
s
newpath
.42833 .58963 .01034 0 365.73 arc
s
newpath
.35666 .58963 .01034 0 365.73 arc
s
newpath
.82251 .11379 .0931 0 365.73 arc
s
newpath
.82251 .23792 .03103 0 365.73 arc
s
newpath
.82251 .2793 .01034 0 365.73 arc
s
newpath
.85834 .21723 .01034 0 365.73 arc
s
newpath
.78667 .21723 .01034 0 365.73 arc
s
newpath
.93001 .05172 .03103 0 365.73 arc
s
newpath
.93001 .0931 .01034 0 365.73 arc
s
newpath
.96585 .03103 .01034 0 365.73 arc
s
newpath
.89418 .03103 .01034 0 365.73 arc
s
newpath
.71501 .05172 .03103 0 365.73 arc
s
newpath
.71501 .0931 .01034 0 365.73 arc
s
newpath
.75084 .03103 .01034 0 365.73 arc
s
newpath
.67917 .03103 .01034 0 365.73 arc
s
newpath
.17749 .11379 .0931 0 365.73 arc
s
newpath
.17749 .23792 .03103 0 365.73 arc
s
newpath
.17749 .2793 .01034 0 365.73 arc
s
newpath
.21333 .21723 .01034 0 365.73 arc
s
newpath
.14166 .21723 .01034 0 365.73 arc
s
newpath
.28499 .05172 .03103 0 365.73 arc
s
newpath
.28499 .0931 .01034 0 365.73 arc
s
newpath
.32083 .03103 .01034 0 365.73 arc
s
newpath
.24916 .03103 .01034 0 365.73 arc
s
newpath
.06999 .05172 .03103 0 365.73 arc
s
newpath
.06999 .0931 .01034 0 365.73 arc
s
newpath
.10582 .03103 .01034 0 365.73 arc
s
newpath
.03415 .03103 .01034 0 365.73 arc
s
0 0 m
1 0 L
1 .86894 L
0 .86894 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{288, 250.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`002@3oool2000000P0oooo0P0000090?ooo`030000003oool0oooo00h0oooo1`00000A0?oo
o`030000003oool0oooo00H0oooo0`0000090?ooo`030000003oool0oooo02X0oooo3@00000/0?oo
o`800000203oool2000000T0oooo00<000000?ooo`3oool03P3oool700000140oooo00<000000?oo
o`3oool01P3oool3000000T0oooo00<000000?ooo`3oool0203oool000L0oooo0P0000020?ooo`80
00000`3oool300000080oooo100000030?ooo`80000000<0oooo0000000000002`3oool3000000L0
oooo1@00000:0?ooo`80000000<0oooo0000000000000`3oool3000000<0oooo0`0000040?ooo`80
000000<0oooo0000000000008P3oool8000000d0oooo2000000R0?ooo`8000000P3oool2000000<0
oooo0`0000020?ooo`@000000`3oool2000000030?ooo`000000000000/0oooo0`0000070?ooo`D0
00002P3oool2000000030?ooo`000000000000@0oooo0P0000030?ooo`<00000103oool200000003
0?ooo`000000000000P0oooo00060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000
00002@3oool00`000000oooo000000040?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`<0
00001P3oool00`000000oooo0?ooo`020?ooo`040000003oool00000000000T0oooo0P0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo01`0oooo1000000M0?ooo`@000007@3oool00`00
0000oooo0?ooo`030?ooo`040000003oool00000000000T0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`070?ooo`8000003`3oool3000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo00000002000000P0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo00H0oooo00060?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`<00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`8000001@3oool00`000000oooo0?ooo`0G0?ooo`@000009@3oool40000
01T0oooo00<000000?ooo`3oool00`3oool2000000`0oooo0P0000050?ooo`030000003oool0oooo
00<0oooo0`00000D0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00/0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool2000000@0oooo00<000000?ooo`3oool00P3oool2000001T0
oooo0P0000020?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`800000103oool00`000000
oooo0?ooo`0E0?ooo`<00000;@3oool4000001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000<0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`8000006@3oool200000080
oooo00<000000?ooo`3oool00P3oool2000000d0oooo0P0000040?ooo`030000003oool0oooo00H0
oooo00070?ooo`040000003oool0oooo0?ooo`8000003P3oool2000000<0oooo00<000000?ooo`3o
ool00P00000M0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03@3oool20000
00<0oooo00<000000?ooo`3oool04`3oool2000003@0oooo00<000000?ooo`3oool04`3oool01000
0000oooo0?ooo`3oool2000000h0oooo0P0000030?ooo`030000003oool0oooo008000007@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`030000003o
ool0oooo00H0oooo00080?ooo`@00000403oool400000080oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0400000100oooo1000000B0?ooo`@00000=`3oool400000180oooo1000000@
0?ooo`@000000P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@00000403oool4
000000T0oooo000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0A0?ooo`800000?`3oool2000001<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool00000903oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo00l0oooo0P0000130?ooo`8000004@3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000002@0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0:0?ooo`002`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0000002H0oooo00<000000?ooo`0000004@3o
ool00`000000oooo0?ooo`0=0?ooo`800000A`3oool2000000l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0000000V0?ooo`030000003oool000000140oooo00<000000?ooo`3oool02P3o
ool000/0oooo00<000000?ooo`3oool03P3oool3000002P0oooo00<000000?ooo`000000403oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0>0?ooo`<00000:03oool00`000000oooo0000000@0?ooo`030000003oool0
oooo00X0oooo000;0?ooo`030000003oool0oooo00h0oooo0P00000Z0?ooo`800000403oool00`00
0000oooo0?ooo`0:0?ooo`800000C@3oool2000000`0oooo00<000000?ooo`3oool03P3oool20000
02X0oooo0P00000@0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo0P00001A0?ooo`8000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02X0oooo0P00000?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0:P3oool2000000l0oooo00<000000?ooo`3oool02P3oool000`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01P3oool2000005L0oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo000=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool2000000`0oooo00<00000
0?ooo`3oool01@3oool2000005/0oooo0P0000070?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0;@3oool2000000`0oooo00<000000?ooo`3oool0303oool000h0oooo0P0000080?oo
o`<00000<03oool3000000P0oooo0P0000070?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool01@3oool2000000P0oooo0`00000`0?ooo`<00000203oool2000000l0oooo000@0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000<@3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000000<@3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo00l0oooo000A0?ooo`H000000P3oool00`000000oooo0?ooo`0_0?oo
o`040000003oool0oooo0?ooo`H00000203oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo00H0oooo1P0000020?ooo`030000003oool0oooo02l0oooo00@000000?ooo`3oool0oooo1P00
000B0?ooo`004P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0200000080oooo0P0000070?ooo`030000003oool0oooo06<0oooo0P000007
0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo008000000P3oool200000180oooo000A0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000<P3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo0P00001X
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000b0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0403oool00140oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000c0?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000003<0oooo0P0000050?ooo`030000003oool0oooo0100oooo000A0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000=03oool2000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1[0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0000000d0?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`004@3oool20000
00<0oooo00<000000?ooo`000000=03oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`000000K`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000=03o
ool00`000000oooo000000030?ooo`030000003oool0oooo0140oooo000C0?ooo`<000000P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00<000000`3oool00`000000oooo0?ooo`1_
0?ooo`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00<00000503oool001P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`00603oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00800000N`3oool200000080oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0000007h0oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0G
0?ooo`00603oool00`000000oooo0?ooo`0b0?ooo`030000003oool0000007l0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`0a0?ooo`80
0000P03oool010000000oooo0?ooo`00000c0?ooo`030000003oool0oooo01L0oooo000I0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`000000P@3oool00`000000oooo0000000b0?ooo`03
0000003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo0300oooo0P0000230?ooo`800000
<P3oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`0_0?ooo`800000Q03o
ool200000340oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0;`3oool2
000008D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo08@0oooo0P00000`0?ooo`030000003oool0oooo
01T0oooo000K0?ooo`030000003oool0oooo02`0oooo0P0000270?ooo`800000;P3oool00`000000
oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`00703oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo08P0oooo0P00000/0?ooo`030000003oool0oooo01/0oooo000L
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0RP3oool2000002X0oooo00<000000?ooo`3oool0703oool001h0oooo00<000000?ooo`3o
ool09P3oool2000008d0oooo0P00000X0?ooo`030000003oool0oooo01d0oooo000O0?ooo`030000
003oool0oooo02@0oooo0P00002>0?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0
7P3oool00200oooo00<000000?ooo`3oool08P3oool00`000000oooo0000002?0?ooo`030000003o
ool0000002@0oooo00<000000?ooo`3oool07`3oool00240oooo00<000000?ooo`3oool0803oool0
0`000000oooo0000002A0?ooo`030000003oool000000280oooo00<000000?ooo`3oool0803oool0
0280oooo00<000000?ooo`3oool07P3oool00`000000oooo0000002B0?ooo`040000003oool0oooo
00000200oooo00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool06`3oool20000
0080oooo00<000000?ooo`3oool0T@3oool010000000oooo0?ooo`00000M0?ooo`800000903oool0
02@0oooo0`00000I0?ooo`050000003oool0oooo0?ooo`000000U03oool010000000oooo0?ooo`3o
ool3000001T0oooo00<000000?ooo`3oool0903oool002L0oooo0P00000E0?ooo`800000103oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00<0oooo0P00000E0?ooo`8000009`3oool0
02T0oooo0`00000@0?ooo`8000001P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
00D0oooo0`00000@0?ooo`800000:@3oool002`0oooo1@0000050?ooo`H00000203oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo00P0oooo1@0000060?ooo`D00000:`3oool002H0oooo
0`0000070?ooo`H000001@3oool3000000D0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`020?ooo`@000001P3oool7000000@0oooo0`00000Y0?ooo`009@3oool010000000oooo0?oo
o`3oool2000000<0oooo0P0000060?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000<0
oooo00<000000?ooo`3oool0U@3oool010000000oooo0?ooo`0000040?ooo`8000000P3oool20000
00H0oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000009`3oool002D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0000000@0oooo00@00000
0?ooo`3oool00000V03oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000X0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?oo
o`030?ooo`800000303oool2000000D0oooo00<000000?ooo`000000V@3oool00`000000oooo0000
00050?ooo`800000303oool2000000D0oooo00<000000?ooo`3oool0903oool002H0oooo00@00000
0?ooo`3oool0oooo0P00000>0?ooo`8000000`3oool010000000oooo0?ooo`00002I0?ooo`040000
003oool0oooo000000<0oooo0P00000>0?ooo`8000000`3oool00`000000oooo0?ooo`0U0?ooo`00
9P3oool01@000000oooo0?ooo`3oool0000000l0oooo0P0000030?ooo`040000003oool0oooo0000
09T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool0
0`000000oooo0?ooo`0U0?ooo`009`3oool400000100oooo100000020?ooo`030000003oool0oooo
09P0oooo00@000000?ooo`3oool0oooo1000000@0?ooo`@00000:03oool002X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02T0oooo000Z0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Y0?ooo`00
:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
:@3oool002X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo02T0oooo000Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0:@3oool002/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool002d0oooo0P000008
0?ooo`8000001`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00D0oooo0P000008
0?ooo`800000;P3oool002l0oooo200000080?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool01`3oool800000300oooo000a0?ooo`80000000<0oooo0000000000002@3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000000000a0?ooo`00
<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
;`3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0_0?ooo`00<03oool010000000oooo0?ooo`3oool2000000T0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`800000<@3o
ool00340oooo0`00000;0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0203oool3
000003<0oooo000o0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0?P3oool003l0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo03h0oooo000o0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0?P3oool003l0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0n
0?ooo`00?`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo03h0oooo000o0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0?P3oool003l0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo03h0oooo000o0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0?P3oool0
03l0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0n0?ooo`00?`3oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0o0?ooo`00@03oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo03l0oooo00100?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo03l0oooo00100?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0?`3o
ool00400oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo0400oooo00110?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0@03oool00440oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0440oooo0012
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0@@3oool00480oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`110?ooo`00@P3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo0440oooo00120?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
@P3oool004<0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`120?ooo`00@`3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo04<0oooo00140?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0@`3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`130?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo04<0oooo
00150?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0A03oool004D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`150?ooo`00AP3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo04D0oooo00160?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0AP3oool004L0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`160?ooo`00A`3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo04L0oooo00180?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0A`3oool004P0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04P0
oooo001:0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0B@3oool004X0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`1:0?ooo`00B`3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0B`3oool004`0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1;0?ooo`00
C@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo04`0oooo001=0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0C@3oool004h0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1=0?ooo`00CP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
04h0oooo001?0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0CP3oool00500oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo0500oooo001B0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0D@3oool005<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?oo
o`00D`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0580oooo001D0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0D`3oool005D0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`1D0?ooo`00EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo05D0oooo001G0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0EP3oool005P0
oooo0P00001[0?ooo`800000F@3oool005X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`1I0?ooo`00FP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo05X0oooo001K
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0F`3oool005`0oooo0P00001S0?oo
o`030000003oool0oooo05`0oooo001N0?ooo`800000G`3oool2000005l0oooo001P0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0G`3oool00640oooo0P00001I0?ooo`800000HP3o
ool006<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0I03oool006H0oooo0P00001?0?ooo`800000I`3oool006P0oooo0P00
001;0?ooo`800000J@3oool006X0oooo0`0000150?ooo`<00000J`3oool006d0oooo0P0000110?oo
o`800000KP3oool006l0oooo0P00000m0?ooo`800000L03oool00740oooo0P00000i0?ooo`800000
LP3oool007<0oooo0`00000c0?ooo`<00000M03oool007H0oooo1000000[0?ooo`@00000M`3oool0
07X0oooo1000000S0?ooo`@00000N`3oool007h0oooo1000000K0?ooo`@00000O`3oool006H0oooo
00<000000?ooo`3oool01P3oool3000000P0oooo0P0000060?oooa/000001`3oool00`000000oooo
0?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`1U0?ooo`00I03oool2000000030?ooo`00
0000000000@0oooo0P0000030?ooo`<000000`3oool200000080oooo0P00000;0?ooo`D000001@3o
ool5000000X0oooo0P0000000`3oool00000000000040?ooo`8000000`3oool3000000<0oooo0P00
00000`3oool000000000001U0?ooo`00H`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00800000203oool00`000000oooo000000050?ooo`030000003oool0oooo00H0oooo0`00000?
0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000203oool0
0`000000oooo000000040?ooo`030000003oool0oooo06<0oooo001S0?ooo`030000003oool0oooo
00<0oooo0P00000;0?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`800000503oool20000
00D0oooo00<000000?ooo`3oool00`3oool2000000/0oooo0P0000050?ooo`030000003oool0oooo
0680oooo001S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<00000603oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0680oooo001T0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool00000000001`0oooo0P0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000006D0oooo001U
0?ooo`@000003`3oool700000200oooo0P0000000`3oool0000000000003000000l0oooo1@00001U
0?ooo`00J03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000008`3oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0I`3oool006L0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000U0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0IP3oool006L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000
000V0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0IP3oool006L0oooo00<0
00000?ooo`3oool03`3oool2000002P0oooo00<000000?ooo`0000004@3oool00`000000oooo0?oo
o`1V0?ooo`00I`3oool00`000000oooo0?ooo`0?0?ooo`800000:@3oool200000140oooo00<00000
0?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3oool03@3oool2000002/0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1W0?ooo`00J@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02X0oooo0P00000?0?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000
003oool0oooo00/0oooo0P00000]0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
J03oool006X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0J03oool006/0oooo0P0000090?ooo`800000;`3oool3
000000X0oooo00<000000?ooo`3oool0J@3oool006d0oooo00<000000?ooo`3oool0103oool30000
0340oooo00<000000?ooo`0000001`3oool2000006`0oooo001^0?ooo`H000000P3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00L00000KP3oool006h0oooo0P0000000`3oool00000
000000030?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P0000000`3oool00000
0000001_0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003<0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`1]0?ooo`00K@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000003<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`1/0?ooo`00K@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003<0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`1]0?ooo`00KP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo06d0oooo001_0?ooo`<000000`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00<00000L03oool007@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1c
0?ooo`00M03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07<0oooo001d0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0L`3oool007@0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`1c0?ooo`00M03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo07<0oooo001e0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0L`3oool0
07D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1d0?ooo`00M@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo07@0oooo001e0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0M03oool007D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`1d0?ooo`00M@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo07@0oooo001f0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0M@3oool007H0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`1e0?ooo`00M`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo07H0oooo001g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0MP3o
ool007L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1g0?ooo`00N03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo07P0oooo001i0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0N03oool007X0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1i0?ooo`00NP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07X0oooo001k
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0N`3oool007`0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1k0?ooo`00O@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo07`0oooo001n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
O@3oool007l0oooo0P00000M0?ooo`800000P03oool00840oooo0P00000J0?ooo`030000003oool0
oooo0800oooo00230?ooo`8000005P3oool2000008<0oooo00250?ooo`<00000403oool3000008D0
oooo00280?ooo`<00000203oool5000008P0oooo00250?ooo`030000003oool0oooo00<0oooo2000
00060?ooo`800000Q@3oool008<0oooo0P0000000`3oool00000000000020?ooo`8000001P3oool2
000000<0oooo0P0000020?ooo`800000P`3oool00880oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000:0?ooo`<000001@3oool00`000000oooo0?ooo`210?ooo`00PP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`210?ooo`00PP3oool00`000000oooo0?ooo`020?ooo`8000003@3oool2000000<0oooo
00<000000?ooo`3oool0PP3oool008<0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`050000
003oool0oooo0?ooo`000000Q03oool008@0oooo0`00000A0?ooo`<00000Q@3oool008H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`250?ooo`00QP3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo08D0oooo00260?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0Q@3oool008H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`250?ooo`00
QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08H0oooo00270?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0QP3oool008L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`270?ooo`00R03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
08L0oooo00280?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0R03oool008T0oooo
0P0000080?ooo`800000R`3oool008/0oooo0`0000030?ooo`800000S@3oool008d0oooo1000002?
0?ooo`00S03oool010000000oooo0?ooo`3oool2000008h0oooo002<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0S03oool008`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`2;0?ooo`00S@3oool01@000000oooo0?ooo`3oool0000008h0oooo002=0?ooo`050000
003oool0oooo0?ooo`000000SP3oool008h0oooo0`00002?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {249.25, 0}} -> {-1.79116, -1.07407, \
0.0124819, 0.0124819}}]
}, Open  ]],

Cell["We wanted to obtain something like this instead!:", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86894 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0162368 0.483763 0.0206889 0.483763 [
[ 0 0 0 0 ]
[ 1 .86894 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .29999 .2793 0 365.73 arc
s
newpath
.17749 .11379 .0931 0 365.73 arc
s
newpath
.06999 .05172 .03103 0 365.73 arc
s
newpath
.03415 .03103 .01034 0 365.73 arc
s
newpath
.10934 .03316 .01247 0 365.73 arc
s
newpath
.07359 .09508 .01247 0 365.73 arc
s
newpath
.29554 .05811 .03742 0 365.73 arc
s
newpath
.35032 .04074 .02005 0 365.73 arc
s
newpath
.24974 .0347 .01402 0 365.73 arc
s
newpath
.28248 .10596 .01218 0 365.73 arc
s
newpath
.18829 .24386 .03742 0 365.73 arc
s
newpath
.20065 .29999 .02005 0 365.73 arc
s
newpath
.14512 .2159 .01402 0 365.73 arc
s
newpath
.22321 .20863 .01218 0 365.73 arc
s
newpath
.82251 .11379 .0931 0 365.73 arc
s
newpath
.93001 .05172 .03103 0 365.73 arc
s
newpath
.96585 .03103 .01034 0 365.73 arc
s
newpath
.89066 .03316 .01247 0 365.73 arc
s
newpath
.92641 .09508 .01247 0 365.73 arc
s
newpath
.70446 .05811 .03742 0 365.73 arc
s
newpath
.64968 .04074 .02005 0 365.73 arc
s
newpath
.75026 .0347 .01402 0 365.73 arc
s
newpath
.71752 .10596 .01218 0 365.73 arc
s
newpath
.81171 .24386 .03742 0 365.73 arc
s
newpath
.79935 .29999 .02005 0 365.73 arc
s
newpath
.85488 .2159 .01402 0 365.73 arc
s
newpath
.77679 .20863 .01218 0 365.73 arc
s
newpath
.5 .67239 .0931 0 365.73 arc
s
newpath
.5 .79652 .03103 0 365.73 arc
s
newpath
.5 .8379 .01034 0 365.73 arc
s
newpath
.46425 .77173 .01247 0 365.73 arc
s
newpath
.53575 .77173 .01247 0 365.73 arc
s
newpath
.39276 .598 .03742 0 365.73 arc
s
newpath
.35032 .55924 .02005 0 365.73 arc
s
newpath
.39539 .64937 .01402 0 365.73 arc
s
newpath
.44072 .58538 .01218 0 365.73 arc
s
newpath
.60724 .598 .03742 0 365.73 arc
s
newpath
.64968 .55924 .02005 0 365.73 arc
s
newpath
.60461 .64937 .01402 0 365.73 arc
s
newpath
.55928 .58538 .01218 0 365.73 arc
s
0 0 m
1 0 L
1 .86894 L
0 .86894 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 250.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`002@3oool2000400P0oooo0P00100:0?ooo`8000@03P3oool700040140oooo0P00100:0?oo
o`<000@0303oool4000402<0oooo3@00100R0?ooo`@000@0303oool4000400X0oooo0P00100@0?oo
o`L000@0403oool2000400P0oooo0`0010090?ooo`030004003oool0oooo00P0oooo00070?ooo`80
00@00P3oool2000400<0oooo0`0010020?ooo`@000@0103oool200040080oooo0P0010090?ooo`<0
00@01`3oool5000400X0oooo0P0010020?ooo`030004003oool0oooo00D0oooo0P0010030?ooo`@0
00@01`3oool00`001000oooo0?ooo`020?ooo`8000@06@3oool8000400d0oooo2000100I0?ooo`03
0004003oool0oooo0080oooo0P0010080?ooo`8000@0103oool4000400@0oooo0P0010020?ooo`80
00@02`3oool3000400L0oooo1@0010090?ooo`8000@00P3oool2000400@0oooo0P0010030?ooo`<0
00@0103oool2000400030?ooo`00100000@000P0oooo00060?ooo`030004003oool0oooo00<0oooo
00@000@00?ooo`00100000@02@3oool010001000oooo0?ooo`0010050?ooo`030004003oool0oooo
00D0oooo0P00100?0?ooo`<000@01P3oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo
0080oooo0P0010090?ooo`030004003oool0oooo00<0oooo00<000@00?ooo`3oool01@3oool00`00
1000oooo0?ooo`0B0?ooo`@000@07@3oool4000401@0oooo00<000@00?ooo`3oool01@3oool00`00
1000oooo0?ooo`030?ooo`8000@02P3oool01@001000oooo0?ooo`3oool000@000D0oooo00<000@0
0?ooo`3oool01P3oool2000400l0oooo0`0010050?ooo`030004003oool0oooo00<0oooo00<000@0
0?ooo`0010000P0010080?ooo`8000@000<0oooo0004003oool0103oool00`001000oooo0?ooo`05
0?ooo`001P3oool00`001000oooo0?ooo`030?ooo`8000@0303oool00`001000oooo000400060?oo
o`040004003oool0oooo0?ooo`<000@0503oool2000400@0oooo00<000@00?ooo`3oool00`3oool0
0`001000oooo0?ooo`02000400`0oooo00D000@00?ooo`3oool0oooo000400090?ooo`030004003o
ool0oooo00d0oooo1000100U0?ooo`@000@03`3oool00`001000oooo0?ooo`070?ooo`050004003o
ool0oooo0?ooo`001000303oool010001000oooo0?ooo`0010060?ooo`030004003oool0oooo00<0
oooo0`00100D0?ooo`8000@00`3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo00/0
oooo0P0010050?ooo`030004003oool0oooo00D0oooo00070?ooo`070004003oool0oooo0?ooo`00
1000oooo0004000=0?ooo`030004003oool0oooo00D0oooo00@000@00?ooo`00100000@06@3oool2
000400030?ooo`001000oooo00H0oooo0P00100?0?ooo`8000@000<0oooo0004003oool02@3oool0
0`001000oooo0?ooo`090?ooo`<000@0;@3oool4000400/0oooo00<000@00?ooo`3oool01`3oool0
10001000oooo00040000100>0?ooo`<000@01`3oool00`001000oooo0?ooo`02000401T0oooo0`00
10070?ooo`030004003oool0oooo00`0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?oo
o`060?ooo`001`3oool010001000oooo0?ooo`3oool2000400h0oooo0P0010050?ooo`<000@07@3o
ool2000400L0oooo00<000@00?ooo`3oool0403oool00`001000oooo0?ooo`090?ooo`030004003o
ool0oooo00L0oooo0P00100d0?ooo`030004003oool0oooo00L0oooo00<000@00?ooo`3oool0203o
ool200040180oooo00<000@00?ooo`3oool01@3oool3000401d0oooo0P0010050?ooo`030004003o
ool0oooo00d0oooo0P0010030?ooo`030004003oool0oooo00H0oooo00080?ooo`@000@0403oool2
000400<0oooo0P00100P0?ooo`8000@01@3oool200040180oooo00<000@00?ooo`3oool02@3oool0
0`001000oooo0?ooo`030?ooo`@000@0=`3oool4000400D0oooo00<000@00?ooo`3oool02@3oool0
0`001000oooo0?ooo`0@0?ooo`8000@01@3oool200040200oooo0P0010030?ooo`8000@0403oool4
000400T0oooo000;0?ooo`030004003oool0oooo00l0oooo1@00100R0?ooo`8000@00`3oool20004
01@0oooo00<000@00?ooo`3oool01`3oool2000400<0oooo0P00100o0?ooo`8000@0103oool00`00
1000oooo0?ooo`070?ooo`8000@04`3oool2000400<0oooo0P00100R0?ooo`@000@000<0oooo0004
003oool03`3oool00`001000oooo0?ooo`0:0?ooo`002`3oool00`001000oooo0?ooo`0?0?ooo`04
0004003oool0oooo000402@0oooo100010000`3oool000@00?ooo`0C0?ooo`030004003oool0oooo
00L0oooo00<000@00?ooo`3oool00P0010130?ooo`8000@00P3oool00`001000oooo0?ooo`070?oo
o`030004003oool0oooo0180oooo00<000@00?ooo`0010000`00100T0?ooo`040004003oool0oooo
00040140oooo00<000@00?ooo`3oool02P3oool000/0oooo00<000@00?ooo`3oool03`3oool00`00
1000oooo0004000V0?ooo`050004003oool0oooo0?ooo`001000503oool2000400L0oooo00@000@0
0?ooo`00100000@0A`3oool2000400030?ooo`001000oooo00H0oooo0P00100D0?ooo`050004003o
ool0oooo0?ooo`0010009P3oool00`001000oooo0004000A0?ooo`030004003oool0oooo00X0oooo
000;0?ooo`030004003oool0oooo00h0oooo0`00100X0?ooo`040004003oool0oooo000401@0oooo
0P0010070?ooo`8000@0B`3oool2000400L0oooo0P00100D0?ooo`040004003oool0oooo000402P0
oooo00<000@00?ooo`001000403oool00`001000oooo0?ooo`0:0?ooo`002`3oool00`001000oooo
0?ooo`0>0?ooo`8000@0:P3oool00`001000oooo0004000D0?ooo`040004003oool000@0000400<0
oooo0`00101=0?ooo`<000@00`3oool2000400030?ooo`001000oooo01<0oooo00<000@00?ooo`00
1000:P3oool200040100oooo00<000@00?ooo`3oool02P3oool000/0oooo00<000@00?ooo`3oool0
3P3oool00`001000oooo0?ooo`0Z0?ooo`8000@0503oool010001000oooo0?ooo`3oool400040540
oooo100010030?ooo`030004003oool0oooo0180oooo0P00100/0?ooo`030004003oool0oooo00h0
oooo00<000@00?ooo`3oool02P3oool000`0oooo00<000@00?ooo`3oool03@3oool00`001000oooo
0?ooo`0[0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool00P3oool00`001000oooo
0?ooo`1C0?ooo`030004003oool0oooo0080oooo00<000@00?ooo`3oool04P3oool2000402d0oooo
00<000@00?ooo`3oool03@3oool00`001000oooo0?ooo`0:0?ooo`00303oool00`001000oooo0?oo
o`0<0?ooo`030004003oool0oooo02`0oooo00<000@00?ooo`3oool04@3oool010001000oooo0?oo
o`3oool2000405L0oooo0P0010030?ooo`030004003oool0oooo0140oooo00<000@00?ooo`3oool0
;03oool00`001000oooo0?ooo`0<0?ooo`030004003oool0oooo00/0oooo000=0?ooo`030004003o
ool0oooo00X0oooo00<000@00?ooo`3oool0;@3oool00`001000oooo0?ooo`0A0?ooo`040004003o
ool000@0000405/0oooo0P0010000`3oool000@00?ooo`0A0?ooo`8000@0;P3oool2000400`0oooo
00<000@00?ooo`3oool0303oool000h0oooo0P0010080?ooo`<000@0<03oool00`001000oooo0?oo
o`0?0?ooo`030004003oool000@005l0oooo0P00100B0?ooo`030004003oool0oooo02h0oooo0`00
10080?ooo`8000@03`3oool00100oooo00<000@00?ooo`3oool0103oool00`001000oooo0004000a
0?ooo`030004003oool0oooo00l0oooo0P00101Q0?ooo`030004003oool0oooo00l0oooo0P00100`
0?ooo`040004003oool0oooo000400H0oooo00<000@00?ooo`3oool03`3oool00140oooo1P001002
0?ooo`030004003oool0oooo0300oooo00<000@00?ooo`3oool03@3oool2000406<0oooo0P00100?
0?ooo`030004003oool0oooo0300oooo00<000@00?ooo`3oool01P00100B0?ooo`004P3oool20004
0080oooo0P0010000`3oool000@00?ooo`0a0?ooo`8000@03P3oool00`001000oooo0?ooo`1S0?oo
o`8000@03@3oool200040380oooo00@000@00?ooo`00100000@00P3oool2000401<0oooo000A0?oo
o`030004003oool0oooo00<0oooo00<000@00?ooo`001000<P3oool00`001000oooo0004000;0?oo
o`8000@0I`3oool2000400X0oooo0P0010000`3oool000@00?ooo`0a0?ooo`8000@01@3oool00`00
1000oooo0?ooo`0A0?ooo`004@3oool00`001000oooo0?ooo`040?ooo`8000@0<`3oool00`001000
oooo00040003000400<0oooo1000101Z0?ooo`@000@00`3oool4000400<0oooo00<000@00?ooo`3o
ool0<@3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo0100oooo000A0?ooo`030004
003oool0oooo00@0oooo00<000@00?ooo`3oool0<P3oool300040080oooo100010020?ooo`030004
003oool0oooo06/0oooo00<000@00?ooo`001000100010020?ooo`<000@0=03oool00`001000oooo
0?ooo`040?ooo`030004003oool0oooo0100oooo000B0?ooo`030004003oool0oooo0080oooo0P00
100d0?ooo`030004003oool0oooo00<0oooo00D000@00?ooo`3oool0oooo0004001_0?ooo`040004
003oool0oooo000400D0oooo0P00100d0?ooo`8000@0103oool00`001000oooo0?ooo`0A0?ooo`00
4P3oool2000400<0oooo0P00100d0?ooo`030004003oool0oooo00@0oooo00<000@00?ooo`001000
L@3oool00`001000oooo000400060?ooo`030004003oool0oooo0380oooo0P0010030?ooo`8000@0
4`3oool001@0oooo0`0010000`3oool000@00?ooo`0c0?ooo`030004003oool0oooo00@0oooo0P00
101c0?ooo`8000@01P3oool00`001000oooo0?ooo`0b0?ooo`030004003oool000@0008000@05@3o
ool001P0oooo00<000@00?ooo`3oool0<P3oool2000400@0oooo0P00101e0?ooo`8000@0103oool2
000403@0oooo00<000@00?ooo`3oool05`3oool001P0oooo00<000@00?ooo`3oool0<P3oool30004
00<0oooo00<000@00?ooo`3oool0M@3oool010001000oooo0?ooo`3oool3000403@0oooo00<000@0
0?ooo`3oool05`3oool001P0oooo00<000@00?ooo`3oool0<P3oool00`001000oooo0?ooo`040004
07L0oooo100010020?ooo`030004003oool0oooo0380oooo00<000@00?ooo`3oool05`3oool001P0
oooo00<000@00?ooo`3oool0<P3oool00`001000oooo0?ooo`020?ooo`030004003oool0oooo07L0
oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`0b0?ooo`030004003oool0oooo01L0
oooo000H0?ooo`030004003oool0oooo0380oooo00<000@00?ooo`3oool00P00101k0?ooo`8000@0
0P3oool00`001000oooo0?ooo`0b0?ooo`030004003oool0oooo01L0oooo000H0?ooo`030004003o
ool0oooo0380oooo00<000@00?ooo`001000O`3oool00`001000oooo0004000d0?ooo`030004003o
ool0oooo01L0oooo000I0?ooo`030004003oool0oooo0340oooo00<000@00?ooo`001000O`3oool0
10001000oooo0?ooo`00100c0?ooo`030004003oool0oooo01L0oooo000I0?ooo`030004003oool0
oooo0340oooo0P0010210?ooo`030004003oool000@003<0oooo00<000@00?ooo`3oool05`3oool0
01T0oooo00<000@00?ooo`3oool0<03oool00`001000oooo000400210?ooo`030004003oool000@0
0380oooo00<000@00?ooo`3oool0603oool001T0oooo00<000@00?ooo`3oool0<03oool2000408<0
oooo0P00100b0?ooo`030004003oool0oooo01P0oooo000I0?ooo`030004003oool0oooo02l0oooo
0P0010250?ooo`030004003oool0oooo02l0oooo00<000@00?ooo`3oool06@3oool001X0oooo00<0
00@00?ooo`3oool0;P3oool2000408D0oooo0P00100`0?ooo`030004003oool0oooo01T0oooo000J
0?ooo`030004003oool0oooo02h0oooo00<000@00?ooo`3oool0Q@3oool00`001000oooo0?ooo`0^
0?ooo`030004003oool0oooo01T0oooo000K0?ooo`030004003oool0oooo02`0oooo0P0010270?oo
o`8000@0;P3oool00`001000oooo0?ooo`0J0?ooo`006`3oool00`001000oooo0?ooo`0/0?ooo`03
0004003oool0oooo08L0oooo00<000@00?ooo`3oool0;03oool00`001000oooo0?ooo`0J0?ooo`00
703oool00`001000oooo0?ooo`0Z0?ooo`030004003oool0oooo08T0oooo00<000@00?ooo`3oool0
:P3oool00`001000oooo0?ooo`0K0?ooo`007@3oool00`001000oooo0?ooo`0Y0?ooo`030004003o
ool0oooo08T0oooo0P00100[0?ooo`030004003oool0oooo01/0oooo000M0?ooo`030004003oool0
oooo02P0oooo00<000@00?ooo`3oool0R`3oool00`001000oooo0?ooo`0X0?ooo`030004003oool0
oooo01`0oooo000N0?ooo`030004003oool0oooo02H0oooo0P00102=0?ooo`8000@0:03oool00`00
1000oooo0?ooo`0M0?ooo`007`3oool00`001000oooo0?ooo`0T0?ooo`8000@0S`3oool2000402H0
oooo00<000@00?ooo`3oool07P3oool00200oooo00<000@00?ooo`3oool08P3oool00`001000oooo
0004002?0?ooo`030004003oool000@002@0oooo00<000@00?ooo`3oool07`3oool00240oooo00<0
00@00?ooo`3oool0803oool00`001000oooo0004002A0?ooo`030004003oool000@00280oooo00<0
00@00?ooo`3oool0803oool00280oooo00<000@00?ooo`3oool07P3oool00`001000oooo0004002C
0?ooo`030004003oool000@00200oooo00<000@00?ooo`3oool08@3oool002<0oooo00<000@00?oo
o`3oool06`3oool200040080oooo00<000@00?ooo`3oool0T@3oool010001000oooo0?ooo`00100M
0?ooo`8000@0903oool002@0oooo0`00100I0?ooo`050004003oool0oooo0?ooo`001000U@3oool0
0`001000oooo0?ooo`03000401T0oooo00<000@00?ooo`3oool0903oool002L0oooo0P00100D0?oo
o`@000@00`3oool00`001000oooo0?ooo`2C0?ooo`030004003oool000@000D000@05@3oool20004
02L0oooo000Y0?ooo`<000@0403oool2000400<0oooo0P0010000`3oool000@00?ooo`2D0?ooo`03
0004003oool000@000<0oooo1@00100?0?ooo`<000@0:@3oool002L0oooo0P0010020?ooo`H000@0
1@3oool7000400H0oooo0P00102E0?ooo`8000@01P3oool00`001000oooo0?ooo`05000400H0oooo
1@0010000`3oool000@00004000X0?ooo`009P3oool00`001000oooo0?ooo`030?ooo`030004003o
ool0oooo0080oooo1@0010000`3oool000@0000400030?ooo`030004003oool0oooo00@0oooo00<0
00@00?ooo`3oool0U@3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo00@000@000<0
oooo000400001000100010020?ooo`030004003oool0oooo00<0oooo00<000@00?ooo`3oool09@3o
ool002H0oooo00<000@00?ooo`3oool00`3oool010001000oooo0?ooo`3oool2000400L0oooo0P00
10020?ooo`030004003oool0oooo00<0oooo00<000@00?ooo`3oool0U@3oool2000400D0oooo0`00
10070?ooo`8000@00`3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo02D0oooo000U
0?ooo`030004003oool0oooo00D0oooo0`00100;0?ooo`<000@0103oool00`001000oooo0?ooo`2G
0?ooo`030004003oool0oooo0080oooo0P00100;0?ooo`8000@000<0oooo0004003oool01P3oool0
0`001000oooo0?ooo`0T0?ooo`009@3oool00`001000oooo0?ooo`050?ooo`030004003oool0oooo
00d0oooo0`0010020?ooo`030004003oool0oooo09L0oooo0P0010020?ooo`8000@03P3oool20004
00L0oooo00<000@00?ooo`3oool0903oool002H0oooo00<000@00?ooo`3oool00`3oool200040140
oooo1000102I0?ooo`030004003oool000@0008000@04@3oool00`001000oooo0?ooo`030?ooo`03
0004003oool0oooo02D0oooo000V0?ooo`8000@00`3oool200040180oooo00@000@00?ooo`3oool0
00@0V@3oool010001000oooo0?ooo`00100B0?ooo`8000@00`3oool2000402L0oooo000X0?ooo`<0
00@000<0oooo0004003oool04P3oool2000409/0oooo00<000@00?ooo`0010004`3oool4000402T0
oooo000[0?ooo`030004003oool0oooo0180oooo0P00102K0?ooo`8000@0503oool00`001000oooo
0?ooo`0Z0?ooo`00:`3oool00`001000oooo0?ooo`0B0?ooo`8000@0V`3oool2000401@0oooo00<0
00@00?ooo`3oool0:P3oool002/0oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`2K
0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool0:P3oool002/0oooo00<000@00?oo
o`3oool04P3oool00`001000oooo0?ooo`2K0?ooo`030004003oool0oooo0180oooo00<000@00?oo
o`3oool0:P3oool002/0oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`2K0?ooo`03
0004003oool0oooo0180oooo00<000@00?ooo`3oool0:P3oool002/0oooo00<000@00?ooo`3oool0
4P3oool00`001000oooo0?ooo`2K0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool0
:P3oool002`0oooo00<000@00?ooo`3oool0403oool2000409d0oooo00<000@00?ooo`3oool04@3o
ool00`001000oooo0?ooo`0[0?ooo`00;03oool00`001000oooo0?ooo`0@0?ooo`8000@0W@3oool0
0`001000oooo0?ooo`0A0?ooo`030004003oool0oooo02/0oooo000/0?ooo`030004003oool0oooo
00l0oooo00<000@00?ooo`001000W@3oool200040140oooo00<000@00?ooo`3oool0;03oool002`0
oooo00<000@00?ooo`3oool03`3oool00`001000oooo0004002M0?ooo`8000@04@3oool00`001000
oooo0?ooo`0/0?ooo`00;@3oool2000400h0oooo00<000@00?ooo`001000W`3oool3000400h0oooo
00<000@00?ooo`3oool0;@3oool002l0oooo00<000@00?ooo`3oool02`3oool00`001000oooo0004
002O0?ooo`040004003oool0oooo000400d0oooo00<000@00?ooo`3oool0;@3oool002l0oooo00<0
00@00?ooo`3oool02@3oool200040080oooo00<000@00?ooo`3oool0W@3oool010001000oooo0?oo
o`00100;0?ooo`8000@0<03oool00300oooo0P0010070?ooo`8000@0103oool00`001000oooo0?oo
o`2M0?ooo`040004003oool0oooo0?ooo`8000@01`3oool200040380oooo000b0?ooo`/000@00P3o
ool00`001000oooo0?ooo`2M0?ooo`040004003oool0oooo0?ooo`T000@0=03oool003D0oooo0P00
10060?ooo`030004003oool000@009l0oooo00@000@00?ooo`00100000@01@3oool00`001000oooo
0?ooo`0e0?ooo`00=03oool00`001000oooo0?ooo`070?ooo`8000@0W`3oool2000400P0oooo00<0
00@00?ooo`3oool0=03oool003@0oooo00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`2M
0?ooo`8000@02@3oool00`001000oooo0?ooo`0c0?ooo`00<`3oool00`001000oooo0?ooo`090?oo
o`030004003oool0oooo09d0oooo00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`0c0?oo
o`00<`3oool00`001000oooo0?ooo`090?ooo`030004003oool0oooo09d0oooo00<000@00?ooo`3o
ool02@3oool00`001000oooo0?ooo`0b0?ooo`00=03oool00`001000oooo0?ooo`080?ooo`030004
003oool0oooo09d0oooo00<000@00?ooo`3oool02@3oool00`001000oooo0?ooo`0b0?ooo`00=03o
ool00`001000oooo0?ooo`070?ooo`8000@0W`3oool00`001000oooo0?ooo`080?ooo`030004003o
ool0oooo03<0oooo000e0?ooo`030004003oool0oooo00H0oooo0P00102O0?ooo`8000@02@3oool0
0`001000oooo0?ooo`0c0?ooo`00=@3oool00`001000oooo0?ooo`050?ooo`030004003oool000@0
09l0oooo00<000@00?ooo`0010001`3oool00`001000oooo0?ooo`0d0?ooo`00=P3oool00`001000
oooo0?ooo`030?ooo`040004003oool0oooo000409l0oooo00@000@00?ooo`3oool000@01@3oool0
0`001000oooo0?ooo`0e0?ooo`00=`3oool5000400<0oooo00<000@00?ooo`3oool0W@3oool01000
1000oooo0?ooo`3oool5000403P0oooo000o0?ooo`030004003oool0oooo09d0oooo00<000@00?oo
o`3oool0?P3oool003l0oooo00<000@00?ooo`3oool0W@3oool00`001000oooo0?ooo`0n0?ooo`00
@03oool00`001000oooo0?ooo`2K0?ooo`030004003oool0oooo03l0oooo00100?ooo`030004003o
ool0oooo09/0oooo00<000@00?ooo`3oool0?`3oool00400oooo00<000@00?ooo`3oool0V`3oool0
0`001000oooo0?ooo`0o0?ooo`00@03oool00`001000oooo0?ooo`2K0?ooo`030004003oool0oooo
03l0oooo00100?ooo`030004003oool0oooo09/0oooo00<000@00?ooo`3oool0?`3oool00400oooo
00<000@00?ooo`3oool0V`3oool00`001000oooo0?ooo`0o0?ooo`00@03oool00`001000oooo0?oo
o`2K0?ooo`030004003oool0oooo03l0oooo00100?ooo`030004003oool0oooo09/0oooo00<000@0
0?ooo`3oool0?`3oool00440oooo00<000@00?ooo`3oool0V@3oool00`001000oooo0?ooo`100?oo
o`00@@3oool00`001000oooo0?ooo`2I0?ooo`030004003oool0oooo0400oooo00110?ooo`030004
003oool0oooo09T0oooo00<000@00?ooo`3oool0@03oool00440oooo00<000@00?ooo`3oool0V@3o
ool00`001000oooo0?ooo`100?ooo`00@P3oool00`001000oooo0?ooo`2G0?ooo`030004003oool0
oooo0440oooo00120?ooo`030004003oool0oooo09L0oooo00<000@00?ooo`3oool0@@3oool00480
oooo00<000@00?ooo`3oool0U`3oool00`001000oooo0?ooo`110?ooo`00@P3oool00`001000oooo
0?ooo`2G0?ooo`030004003oool0oooo0440oooo00130?ooo`030004003oool0oooo09D0oooo00<0
00@00?ooo`3oool0@P3oool004<0oooo00<000@00?ooo`3oool0U@3oool00`001000oooo0?ooo`12
0?ooo`00A03oool00`001000oooo0?ooo`2C0?ooo`030004003oool0oooo04<0oooo00140?ooo`03
0004003oool0oooo09<0oooo00<000@00?ooo`3oool0@`3oool004@0oooo00<000@00?ooo`3oool0
T`3oool00`001000oooo0?ooo`130?ooo`00A03oool00`001000oooo0?ooo`2C0?ooo`030004003o
ool0oooo04<0oooo00150?ooo`030004003oool0oooo0940oooo00<000@00?ooo`3oool0A03oool0
04H0oooo00<000@00?ooo`3oool0S`3oool00`001000oooo0?ooo`150?ooo`00AP3oool00`001000
oooo0?ooo`2?0?ooo`030004003oool0oooo04D0oooo00170?ooo`030004003oool0oooo08d0oooo
00<000@00?ooo`3oool0AP3oool004L0oooo00<000@00?ooo`3oool0S@3oool00`001000oooo0?oo
o`160?ooo`00B03oool00`001000oooo0?ooo`2;0?ooo`030004003oool0oooo04L0oooo00180?oo
o`030004003oool0oooo08/0oooo00<000@00?ooo`3oool0A`3oool004T0oooo00<000@00?ooo`3o
ool0R@3oool00`001000oooo0?ooo`180?ooo`00B@3oool00`001000oooo0?ooo`290?ooo`030004
003oool0oooo04P0oooo001:0?ooo`030004003oool0oooo08L0oooo00<000@00?ooo`3oool0B@3o
ool004/0oooo00<000@00?ooo`3oool0Q@3oool00`001000oooo0?ooo`1:0?ooo`00B`3oool00`00
1000oooo0?ooo`250?ooo`030004003oool0oooo04X0oooo001<0?ooo`030004003oool0oooo08<0
oooo00<000@00?ooo`3oool0B`3oool004`0oooo00<000@00?ooo`3oool0P`3oool00`001000oooo
0?ooo`1;0?ooo`00C@3oool00`001000oooo0?ooo`210?ooo`030004003oool0oooo04`0oooo001>
0?ooo`030004003oool0oooo07l0oooo00<000@00?ooo`3oool0C@3oool004h0oooo00<000@00?oo
o`3oool0O`3oool00`001000oooo0?ooo`1=0?ooo`00C`3oool00`001000oooo0?ooo`1m0?ooo`03
0004003oool0oooo04h0oooo001?0?ooo`030004003oool0oooo07d0oooo00<000@00?ooo`3oool0
CP3oool00500oooo00<000@00?ooo`3oool0N`3oool00`001000oooo0?ooo`1?0?ooo`00D@3oool0
0`001000oooo0?ooo`1i0?ooo`030004003oool0oooo0500oooo001B0?ooo`030004003oool0oooo
07L0oooo00<000@00?ooo`3oool0D@3oool005<0oooo00<000@00?ooo`3oool0M@3oool00`001000
oooo0?ooo`1B0?ooo`00D`3oool00`001000oooo0?ooo`1e0?ooo`030004003oool0oooo0580oooo
001D0?ooo`030004003oool0oooo07<0oooo00<000@00?ooo`3oool0D`3oool005D0oooo00<000@0
0?ooo`3oool0L@3oool00`001000oooo0?ooo`1D0?ooo`00EP3oool00`001000oooo0?ooo`1_0?oo
o`030004003oool0oooo05D0oooo001G0?ooo`030004003oool0oooo06d0oooo00<000@00?ooo`3o
ool0EP3oool005P0oooo0P00101[0?ooo`8000@0F@3oool005X0oooo00<000@00?ooo`3oool0I`3o
ool00`001000oooo0?ooo`1I0?ooo`00F`3oool00`001000oooo0?ooo`1U0?ooo`030004003oool0
oooo05X0oooo001K0?ooo`030004003oool0oooo06@0oooo00<000@00?ooo`3oool0F`3oool005`0
oooo0P00101S0?ooo`030004003oool0oooo05`0oooo001N0?ooo`8000@0G`3oool2000405l0oooo
001P0?ooo`030004003oool0oooo05/0oooo00<000@00?ooo`3oool0G`3oool00640oooo0P00101I
0?ooo`8000@0HP3oool006<0oooo00<000@00?ooo`3oool0E@3oool00`001000oooo0?ooo`1R0?oo
o`00I03oool00`001000oooo0?ooo`1C0?ooo`030004003oool0oooo06<0oooo001R0?ooo`@000@0
DP3oool4000406@0oooo001P0?ooo`8000@0103oool2000404h0oooo0`0010030?ooo`8000@0HP3o
ool005l0oooo00<000@00?ooo`3oool01P3oool2000404/0oooo0P0010070?ooo`030004003oool0
oooo05l0oooo001O0?ooo`030004003oool0oooo00L0oooo100010150?ooo`@000@02@3oool00`00
1000oooo0?ooo`1N0?ooo`00GP3oool00`001000oooo0?ooo`090?ooo`030004003oool0oooo0080
00@0@@3oool200040080oooo00<000@00?ooo`3oool0203oool00`001000oooo0?ooo`1N0?ooo`00
GP3oool00`001000oooo0?ooo`090?ooo`030004003oool0oooo0080oooo0P00100m0?ooo`8000@0
103oool00`001000oooo0?ooo`090?ooo`030004003oool0oooo05d0oooo001N0?ooo`030004003o
ool0oooo00T0oooo00<000@00?ooo`3oool00P3oool5000403P0oooo1P0010020?ooo`030004003o
ool0oooo00T0oooo00<000@00?ooo`3oool0G@3oool005l0oooo00<000@00?ooo`3oool01`3oool0
0`001000oooo00040003000400@0oooo0`00100b0?ooo`@000@01P3oool2000400030?ooo`001000
oooo00P0oooo00<000@00?ooo`3oool0GP3oool005l0oooo00<000@00?ooo`3oool01`3oool20004
00/0oooo1000100[0?ooo`@000@02`3oool2000400T0oooo00<000@00?ooo`3oool0GP3oool00600
oooo00<000@00?ooo`3oool01@3oool2000400h0oooo00<000@00?ooo`0010000`00100S0?ooo`@0
00@00P3oool00`001000oooo0?ooo`0;0?ooo`8000@01`3oool00`001000oooo0?ooo`1O0?ooo`00
H03oool00`001000oooo0?ooo`050?ooo`030004003oool0oooo00d0oooo00<000@00?ooo`3oool0
0`3oool4000401/0oooo1@0010030?ooo`8000@03`3oool00`001000oooo0?ooo`050?ooo`030004
003oool0oooo05l0oooo001Q0?ooo`L000@04@3oool00`001000oooo0?ooo`0200040080oooo7@00
10000`3oool000@0000400020?ooo`<000@04P3oool700040680oooo001W0?ooo`030004003oool0
oooo0100oooo0P0010050?ooo`030004003oool0oooo00D0oooo1@0010050?ooo`D000@01@3oool0
0`001000oooo0?ooo`030?ooo`8000@04P3oool00`001000oooo0?ooo`1V0?ooo`00IP3oool00`00
1000oooo0?ooo`0A0?ooo`8000@01@3oool00`001000oooo0?ooo`020?ooo`<000@03`3oool20004
00<0oooo00<000@00?ooo`3oool00`3oool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo
06D0oooo001V0?ooo`030004003oool0oooo0140oooo0P0010050?ooo`030004003oool0oooo0080
00@0503oool2000400030?ooo`001000oooo00@0oooo00<000@00?ooo`3oool04P3oool00`001000
oooo0?ooo`1U0?ooo`00IP3oool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo0080oooo
1000100H0?ooo`8000@0103oool2000401@0oooo00<000@00?ooo`3oool0I@3oool006H0oooo00<0
00@00?ooo`3oool04P3oool200040080oooo0P00100L0?ooo`8000@00`3oool2000401@0oooo00<0
00@00?ooo`3oool0I@3oool006H0oooo00<000@00?ooo`3oool04P3oool00`001000oooo00040002
000401l0oooo0`0010000`3oool000@00?ooo`0C0?ooo`030004003oool0oooo06D0oooo001V0?oo
o`030004003oool0oooo0180oooo00<000@00?ooo`0010008`3oool00`001000oooo0004000D0?oo
o`030004003oool0oooo06D0oooo001V0?ooo`030004003oool0oooo0180oooo0P00100U0?ooo`03
0004003oool000@001<0oooo00<000@00?ooo`3oool0I@3oool006H0oooo00<000@00?ooo`3oool0
4@3oool2000402L0oooo0P00100C0?ooo`030004003oool0oooo06D0oooo001W0?ooo`030004003o
ool0oooo0100oooo00<000@00?ooo`3oool09P3oool00`001000oooo0004000B0?ooo`030004003o
ool0oooo06D0oooo001W0?ooo`030004003oool0oooo00l0oooo0P00100Y0?ooo`8000@04@3oool0
0`001000oooo0?ooo`1V0?ooo`00J03oool00`001000oooo0?ooo`0>0?ooo`030004003oool0oooo
02T0oooo0P00100@0?ooo`030004003oool0oooo06H0oooo001X0?ooo`030004003oool0oooo00d0
oooo00<000@00?ooo`3oool0:`3oool00`001000oooo0?ooo`0<0?ooo`8000@0J@3oool006T0oooo
0P00100<0?ooo`8000@0;@3oool2000400`0oooo00<000@00?ooo`3oool0J@3oool006/0oooo00<0
00@00?ooo`3oool0203oool2000402l0oooo0P00100;0?ooo`030004003oool0oooo06T0oooo001/
0?ooo`<000@00`3oool4000400030?ooo`001000oooo02h0oooo00<000@00?ooo`0010000P001003
0?ooo`D000@0K03oool006l0oooo100010030?ooo`030004003oool0oooo02l0oooo00@000@00?oo
o`3oool0oooo0`00101a0?ooo`00KP3oool2000400<0oooo0P0010000`3oool000@00?ooo`0a0?oo
o`<000@00`3oool2000406l0oooo001]0?ooo`030004003oool0oooo00@0oooo00<000@00?ooo`00
1000<P3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo06d0oooo001]0?ooo`030004
003oool0oooo00D0oooo00<000@00?ooo`3oool0<@3oool00`001000oooo0?ooo`050?ooo`030004
003oool0oooo06`0oooo001]0?ooo`030004003oool0oooo00D0oooo00<000@00?ooo`3oool0<@3o
ool00`001000oooo0?ooo`050?ooo`030004003oool0oooo06`0oooo001^0?ooo`030004003oool0
oooo00<0oooo0P00100c0?ooo`8000@01@3oool00`001000oooo0?ooo`1]0?ooo`00KP3oool00`00
1000oooo0?ooo`030?ooo`8000@0=03oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo
06d0oooo001_0?ooo`8000@000D0oooo000400001000oooo0004000d0?ooo`<000@000<0oooo0004
00001000L03oool00740oooo00@000@00?ooo`3oool000@0=@3oool010001000oooo0?ooo`00101b
0?ooo`00M03oool00`001000oooo0?ooo`0c0?ooo`030004003oool0oooo07<0oooo001d0?ooo`03
0004003oool0oooo03<0oooo00<000@00?ooo`3oool0L`3oool007@0oooo00<000@00?ooo`3oool0
<`3oool00`001000oooo0?ooo`1c0?ooo`00M03oool00`001000oooo0?ooo`0c0?ooo`030004003o
ool0oooo07<0oooo001e0?ooo`030004003oool0oooo0380oooo00<000@00?ooo`3oool0L`3oool0
07D0oooo00<000@00?ooo`3oool0<@3oool00`001000oooo0?ooo`1d0?ooo`00M@3oool00`001000
oooo0?ooo`0a0?ooo`030004003oool0oooo07@0oooo001e0?ooo`030004003oool0oooo0340oooo
00<000@00?ooo`3oool0M03oool007D0oooo00<000@00?ooo`3oool0<@3oool00`001000oooo0?oo
o`1d0?ooo`00MP3oool00`001000oooo0?ooo`0`0?ooo`030004003oool0oooo07@0oooo001f0?oo
o`030004003oool0oooo02l0oooo00<000@00?ooo`3oool0M@3oool007H0oooo00<000@00?ooo`3o
ool0;`3oool00`001000oooo0?ooo`1e0?ooo`00M`3oool00`001000oooo0?ooo`0]0?ooo`030004
003oool0oooo07H0oooo001g0?ooo`030004003oool0oooo02d0oooo00<000@00?ooo`3oool0MP3o
ool007P0oooo00<000@00?ooo`3oool0:`3oool00`001000oooo0?ooo`1g0?ooo`00N03oool00`00
1000oooo0?ooo`0Z0?ooo`030004003oool0oooo07P0oooo001i0?ooo`030004003oool0oooo02T0
oooo00<000@00?ooo`3oool0N03oool007X0oooo00<000@00?ooo`3oool09`3oool00`001000oooo
0?ooo`1i0?ooo`00N`3oool00`001000oooo0?ooo`0U0?ooo`030004003oool0oooo07X0oooo001k
0?ooo`030004003oool0oooo02@0oooo00<000@00?ooo`3oool0N`3oool007`0oooo00<000@00?oo
o`3oool08`3oool00`001000oooo0?ooo`1k0?ooo`00O@3oool00`001000oooo0?ooo`0Q0?ooo`03
0004003oool0oooo07`0oooo001n0?ooo`030004003oool0oooo01l0oooo00<000@00?ooo`3oool0
O@3oool007l0oooo0P00100M0?ooo`8000@0P03oool00840oooo0P00100J0?ooo`030004003oool0
oooo0800oooo00230?ooo`8000@05P3oool2000408<0oooo00240?ooo`@000@0403oool3000408D0
oooo00220?ooo`8000@00P3oool5000400P0oooo1P0010020?ooo`8000@0P`3oool00840oooo00<0
00@00?ooo`3oool00`3oool010001000oooo0?ooo`3oool8000400<0oooo00<000@00?ooo`3oool0
0`3oool00`001000oooo0?ooo`210?ooo`00P@3oool00`001000oooo0?ooo`040?ooo`040004003o
ool000@0000400H0oooo0P0010020?ooo`030004003oool0oooo00@0oooo00<000@00?ooo`3oool0
P03oool00840oooo00<000@00?ooo`3oool0103oool2000400X0oooo0`0010060?ooo`030004003o
ool0oooo0800oooo00220?ooo`030004003oool0oooo0080oooo0P00100=0?ooo`8000@0103oool0
0`001000oooo0?ooo`210?ooo`00PP3oool2000400<0oooo0P00100>0?ooo`040004003oool0oooo
0?ooo`8000@0P`3oool008@0oooo1000100@0?ooo`<000@0Q@3oool008H0oooo00<000@00?ooo`3o
ool03`3oool00`001000oooo0?ooo`250?ooo`00QP3oool00`001000oooo0?ooo`0?0?ooo`030004
003oool0oooo08D0oooo00260?ooo`030004003oool0oooo00l0oooo00<000@00?ooo`3oool0Q@3o
ool008H0oooo00<000@00?ooo`3oool03`3oool00`001000oooo0?ooo`250?ooo`00QP3oool00`00
1000oooo0?ooo`0?0?ooo`030004003oool0oooo08D0oooo00270?ooo`030004003oool0oooo00d0
oooo00<000@00?ooo`3oool0QP3oool008L0oooo00<000@00?ooo`3oool03@3oool00`001000oooo
0?ooo`260?ooo`00Q`3oool00`001000oooo0?ooo`0<0?ooo`030004003oool0oooo08L0oooo0028
0?ooo`030004003oool0oooo00/0oooo00<000@00?ooo`3oool0Q`3oool008P0oooo00<000@00?oo
o`3oool02P3oool00`001000oooo0?ooo`280?ooo`00R@3oool2000400P0oooo0P00102;0?ooo`00
R`3oool3000400<0oooo0P00102=0?ooo`00S@3oool4000408l0oooo002<0?ooo`040004003oool0
oooo0?ooo`8000@0SP3oool008`0oooo00<000@00?ooo`3oool00`3oool00`001000oooo0?ooo`2;
0?ooo`00S03oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo08/0oooo002=0?ooo`05
0004003oool0oooo0?ooo`001000SP3oool008d0oooo00D000@00?ooo`3oool0oooo0004002>0?oo
o`00SP3oool3000408l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{109, 396}, {264.25, 15}} -> {-0.819631, 0.0653303, \
0.00720646, 0.00720646}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtaining the Incircle", "Section"],

Cell["\<\
First we obtain the circle of maximum area inscribed in the triangle \
(incircle). This triangle results tangent to the three sides and hence \
divides it into equal sections limited by two segments and an arc, all \
pairwise touching at one point. These types of figures we will refer to as \
being of type 1. A figure limited by one segment and two arcs tangent to it \
pairwise touching in one point will be regarded as being of type 2. Finally, \
a figure limited by three arcs will be type 3. Just for completeness, any \
triangle will be considered of type 0. 

Let us consider first the simplest of triangles, an equilateral one\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(triangle = {{0, 0}, {2, 0}, {1, \@3}, {0, 
            0}};\)\), "\[IndentingNewLine]", 
    \(shG[Line[triangle]]\)}], "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86603 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0206197 0.47619 [
[ 0 0 0 0 ]
[ 1 .86603 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02062 m
.97619 .02062 L
.5 .84541 L
.02381 .02062 L
s
0 0 m
1 0 L
1 .86603 L
0 .86603 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{288, 249.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`001P3ooooo000001@000001`3oool000L0oooo00<000000?ooo`3oool0o`3oool>0?ooo`03
0000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo
0?ooo`060?ooo`00203oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool01`3o
ool000P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo00090?oo
o`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000
oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0
o`3oool80?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo0?l0oooo1P3o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<00000
0?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo
00/0oooo000<0?ooo`030000003oool0oooo0?l0oooo103oool00`000000oooo0?ooo`0;0?ooo`00
3@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0303oool000h0oooo00<0
00000?ooo`3oool0o`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`3o
0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo0?d0oooo00<000000?oo
o`3oool03P3oool000l0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0>0?ooo`00
403oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003o
ool0oooo0?/0oooo00<000000?ooo`3oool03`3oool00140oooo00<000000?ooo`3oool0n@3oool0
0`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo
0140oooo000B0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool04@3oool001<0oooo
00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?oo
o`3e0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000003oool0oooo0?<0oooo00<00000
0?ooo`3oool04`3oool001@0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0C0?oo
o`005@3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo01@0oooo000F0?ooo`030000
003oool0oooo0>l0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0k`3o
ool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0
oooo01H0oooo000G0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool05P3oool001P0
oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo
0?ooo`3[0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo0>T0oooo00<0
00000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`0I
0?ooo`006P3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo01T0oooo000K0?ooo`03
0000003oool0oooo0>D0oooo00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool0
i@3oool00`000000oooo0?ooo`0J0?ooo`00703oool00`000000oooo0?ooo`3S0?ooo`030000003o
ool0oooo01/0oooo000M0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0703oool0
01d0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0L0?ooo`007P3oool00`000000
oooo0?ooo`3O0?ooo`030000003oool0oooo01d0oooo000N0?ooo`030000003oool0oooo0=l0oooo
00<000000?ooo`3oool07@3oool001l0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?oo
o`0N0?ooo`007`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo01h0oooo000P0?oo
o`030000003oool0oooo0=/0oooo00<000000?ooo`3oool07`3oool00240oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool0oooo0200oooo000R0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool08@3o
ool00280oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0280oooo000S0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool08P3oool002@0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`0S0?ooo`009@3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0903oool002H0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo02D0oooo000W0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0
9P3oool002P0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0W0?ooo`00:03oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0X0?ooo`00:P3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo02T0oooo
000Z0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0:@3oool002/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0:`3oool002d0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0/0?ooo`00;@3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo02`0oooo000^0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`0]0?ooo`00;`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo02h0
oooo000`0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0_0?ooo`00<@3oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo0300oooo000a0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool0<03oool00380oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0a0?ooo`00
<`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool0<P3oool003@0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0c0?ooo`00=03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
03<0oooo000e0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0=03oool003D0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?oo
o`2_0?ooo`030000003oool0oooo03D0oooo000g0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0=P3oool003L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0f0?oo
o`00>03oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool0Z@3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo03P0oooo000j0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0>@3oool003/0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0j0?ooo`00>`3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0>`3oool003`0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0k
0?ooo`00?@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo03`0oooo000m0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0?03oool003h0oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo03h0oooo000o0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0?P3oool0
0400oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0o0?ooo`00@03oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo03l0oooo00110?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0@03oool00480oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`110?ooo`00@P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0440oooo00130?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0@P3oool004<0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo04<0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0@`3o
ool004D0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo04D0oooo00160?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0A@3oool004L0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`160?ooo`00A`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04H0oooo0018
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0A`3oool004P0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`170?ooo`00B@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
B@3oool004X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`190?ooo`00B`3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0BP3oool004`0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`1;0?ooo`00C@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo04`0oooo
001=0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0C03oool004h0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`1=0?ooo`00CP3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo04d0oooo001?0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0CP3oool004l0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1>0?ooo`00D03o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001A0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0D03oool00540oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`1@0?ooo`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0540
oooo001B0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0D@3oool005<0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`00D`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo0580oooo001D0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0D`3oool005D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1D0?ooo`00
E@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05@0oooo001F0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0E@3oool005H0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
05H0oooo001H0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0E`3oool005P0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`00F@3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo05P0oooo001I0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0F03oool005X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1I0?oo
o`00FP3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo05T0oooo001K0?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0FP3oool005`0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`1K0?ooo`00G03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo05/0oooo001M0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0G03oool005d0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1L0?ooo`00GP3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05d0oooo001N0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0G@3oool005l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1N
0?ooo`00H03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05l0oooo001P0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0G`3oool00640oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1P0?ooo`00H@3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo0600oooo001R0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0H@3oool0
0680oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1Q0?ooo`00H`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0680oooo001T0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0H`3oool006@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`1S0?ooo`00I@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo06@0oooo001U0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0I03oool006H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1U0?ooo`00I`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo06H0oooo001W0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0IP3o
ool006P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1W0?ooo`00J03oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0J03oool006T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`1X0?ooo`00JP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo06T0oooo001[
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0JP3oool006/0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo06/0oooo001/0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
J`3oool006d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1/0?ooo`00K@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo06`0oooo001^0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0K@3oool006l0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`1^0?ooo`00K`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo06h0oooo
001`0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0K`3oool00700oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`1_0?ooo`00L@3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0700oooo001b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0L@3oool00780oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1a0?ooo`00L`3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0780oooo001c0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0LP3oool007@0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`1c0?ooo`00M03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07<0
oooo001e0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0M03oool007H0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`1e0?ooo`00MP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo07D0oooo001g0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0MP3oool007L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1f0?ooo`00
N03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07L0oooo001h0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0M`3oool007T0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1h0?ooo`00NP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
07T0oooo001j0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0N@3oool007/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1j0?ooo`00N`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo07X0oooo001l0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0N`3oool007d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1l0?oo
o`00O@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07`0oooo001n0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0O@3oool007h0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1m0?ooo`00O`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo07h0oooo001o0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0OP3oool00800
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1o0?ooo`00P@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0800oooo00210?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0P03oool00880oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`21
0?ooo`00PP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0840oooo00230?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0PP3oool008<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`220?ooo`00Q03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo08<0oooo00250?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0Q03oool0
08D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`240?ooo`00QP3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo08D0oooo00260?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0Q@3oool008L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`260?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08H0oooo00280?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0Q`3oool008T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`280?ooo`00R@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo08P0oooo002:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R@3o
ool008X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`290?ooo`00R`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08X0oooo002<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0R`3oool008`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2;0?ooo`00S@3oool01@000000oooo0?ooo`3oool0000008h0oooo002=0?ooo`050000003o
ool0oooo0?ooo`000000SP3oool008h0oooo00<000000?ooo`000000S`3oool008h0oooo00<00000
0?ooo`000000S`3oool008l0oooo00<000000?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {248.375, 0}} -> {-0.0507529, -0.0433105, \
0.00732233, 0.00732233}}]
}, Open  ]],

Cell["\<\
The function computing the distance from a point p to line ab will be useful.\
\
\>", "Text"],

Cell[BoxData[
    \(disP2Seg[p_, a_, b_] := 
      size[p - a - \(\((p - a)\) . \((b - a)\)\/size[b - a]\^2\) \((b - 
                a)\)]\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell["\<\
For instance, the distance from point (1, 1) to the left side of the above \
triangle is computed as:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      disP2Seg[{1, 1}, 
        triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), 
        triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)]]\
\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(1\/2\ \((\(-1\) + \@3)\)\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
Let us consider point p the centre of the circle we want. By means of its \
property we can compute it.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      disP2Seg[p, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)] == 
        disP2Seg[p, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)] == 
        disP2Seg[p, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)]]\)], \
"Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
The reason for this result is, of course, that we have to explicitly ask for \
its coordinates\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      disP2Seg[{x, y}, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)] == 
        disP2Seg[{x, y}, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)] == 
        disP2Seg[{x, y}, 
          triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\)\
, triangle\_\(\(\[LeftDoubleBracket]\)\(4\)\(\[RightDoubleBracket]\)\)]]\)], \
"Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[27]:="],

Cell[BoxData[
    \({{y \[Rule] 1\/\@3, x \[Rule] 1}, {y \[Rule] \(-\@3\), 
        x \[Rule] 1}, {y \[Rule] \@3, x \[Rule] \(-1\)}, {y \[Rule] \@3, 
        x \[Rule] 3}}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["We can avoid this diagnostic by squaring", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]\^2 == 
        disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]\^2 == 
        disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]\^2]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{x \[Rule] \(-1\), y \[Rule] \@3}, {x \[Rule] 3, 
        y \[Rule] \@3}, {y \[Rule] 1\/\@3, x \[Rule] 1}, {y \[Rule] \(-\@3\), 
        x \[Rule] 1}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
Note that this distance is not directed, which is useful when we are \
interested in generating pictures like the following:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(centres = {x, y} /. %;\)\), "\[IndentingNewLine]", 
    \(shG[{Line[
          triangle], \(Circle[#, 
              disP2Seg[#, 
                triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
                triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]] &\) /@ centres}]\)}], "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9282 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.372405 0.127595 0.464102 0.127595 [
[ 0 0 0 0 ]
[ 1 .9282 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.37241 .4641 m
.62759 .4641 L
.5 .6851 L
.37241 .4641 L
s
newpath
.24481 .6851 .221 0 365.73 arc
s
newpath
.75519 .6851 .221 0 365.73 arc
s
newpath
.5 .53777 .07367 0 365.73 arc
s
newpath
.5 .2431 .221 0 365.73 arc
s
0 0 m
1 0 L
1 .9282 L
0 .9282 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 267.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00012b000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00Q03ooolG000008D0oooo001o0?ooo`D000005`3oool500000800oooo
001l0?ooo`<000008@3oool3000007d0oooo001j0?ooo`8000009`3oool2000007/0oooo001g0?oo
o`<00000:`3oool3000007P0oooo001e0?ooo`800000<@3oool2000007H0oooo001c0?ooo`800000
=@3oool2000007@0oooo001a0?ooo`800000>@3oool200000780oooo001_0?ooo`800000?@3oool2
00000700oooo001^0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0K@3oool006`0
oooo0P0000130?ooo`800000K@3oool006X0oooo0P0000170?ooo`800000J`3oool006P0oooo0P00
001;0?ooo`800000J@3oool006L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1V
0?ooo`00IP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06D0oooo001U0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0I03oool006@0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`1S0?ooo`00I03oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo06<0oooo001S0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0HP3oool0
0680oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1Q0?ooo`00H@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0600oooo001O0?ooo`800000G@3oool200000600oooo
001N0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G@3oool005d0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`1L0?ooo`00G@3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo05`0oooo001L0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0F`3oool005/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1K0?ooo`00F`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo05X0oooo001J0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0F@3oool005X0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1I0?ooo`00F@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05P0
oooo001H0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0E`3oool005P0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`00E`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo05H0oooo001F0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0EP3oool005H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1E0?ooo`00
EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0oooo001E0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0E03oool005D0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
05<0oooo001D0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0D`3oool005<0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`00D`3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1A0?oo
o`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0540oooo001A0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0D03oool00540
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0D03oool00500oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1@
0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool0
0500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3o
ool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0D03oool00540oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
D03oool00540oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1A0?ooo`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0540oooo
001B0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0580oooo001C0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0DP3oool005@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1C0?ooo`00E03o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0E03oool005D0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`1E0?ooo`00EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0
oooo001F0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0E@3oool005L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`1F0?ooo`00E`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo05H0oooo001H0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0E`3oool005P0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`00
F@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05P0oooo001J0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0F@3oool005X0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1I0?ooo`00F`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
05X0oooo001K0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0F`3oool005`0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1K0?ooo`00G@3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo05`0oooo001M0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0G03oool005h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1M0?oo
o`00G`3oool2000005d0oooo0P00001P0?ooo`00H@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0600oooo001R0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0H@3o
ool006<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0I03oool006H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1U0?ooo`00IP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06D0oooo001W
0?ooo`800000C@3oool2000006P0oooo001Y0?ooo`800000B@3oool2000006X0oooo001[0?ooo`80
0000A@3oool2000006`0oooo001]0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
K03oool006h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1]0?ooo`00K`3oool2
000003d0oooo0P00001`0?ooo`00L@3oool2000003T0oooo0P00001b0?ooo`00L`3oool2000003D0
oooo0P00001d0?ooo`00M@3oool200000340oooo0P00001f0?ooo`00M`3oool3000002/0oooo0`00
001h0?ooo`00NP3oool3000002D0oooo0`00001k0?ooo`00O@3oool3000001l0oooo0`00001n0?oo
o`00P03oool5000001D0oooo1@0000210?ooo`00@`3oool700000200ooooB`00000P0?ooo`L00000
A03oool003/0oooo200000070?ooo`P000006@3oool00`000000oooo0?ooo`0J0?ooo`H00000103o
ool4000001d0oooo00<000000?ooo`3oool05`3oool8000000L0oooo2000000l0?ooo`00=P3oool5
000001L0oooo1000000E0?ooo`030000003oool0oooo01P0oooo0P00000>0?ooo`8000006`3oool0
0`000000oooo0?ooo`0C0?ooo`@000005`3oool5000003L0oooo000c0?ooo`<00000803oool30000
01<0oooo00<000000?ooo`3oool05@3oool200000180oooo0P00000H0?ooo`030000003oool0oooo
0140oooo0`00000P0?ooo`<00000=03oool00340oooo0P00000V0?ooo`<00000403oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0>0?ooo`<000009P3oool200000380oooo000^0?ooo`<00000:`3oool3000000h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`800000503oool00`000000oooo
0?ooo`0<0?ooo`<00000:`3oool3000002l0oooo000[0?ooo`<00000<@3oool3000000/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02@3oool300000340oooo0`00000/0?ooo`00:@3oool2000003L0oooo0P00000:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00P0oooo0P00000g0?ooo`800000:P3oool002L0oooo0P00000k0?oo
o`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03T0oooo0P00000X0?oo
o`009@3oool2000003l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`80
0000?P3oool2000002H0oooo000S0?ooo`800000@P3oool2000000L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool200000480oooo0P00000T0?ooo`008P3oool00`000000oooo0?ooo`140?ooo`8000001@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo0P00000;0?ooo`030000003o
ool0oooo00<0oooo0P0000160?ooo`030000003oool0oooo0240oooo000Q0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0803oool001l0oooo0P00001;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`190?ooo`800000803oool001h0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0M0?ooo`007@3oool00`000000oooo
0?ooo`1>0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool200000500oooo00<000000?ooo`3o
ool0703oool001`0oooo00<000000?ooo`3oool0D@3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00001C0?oo
o`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo05<0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000E@3oool2000001/0oooo000J0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`000000F03oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0
F03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02L0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool05`3oool001L0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo000000030?ooo`030000003oool0oooo02L0
oooo00L000000?ooo`3oool0oooo0000003oool0000005`0oooo00<000000?ooo`3oool05P3oool0
01H0oooo00<000000?ooo`3oool0G03oool00`000000oooo000000020?ooo`030000003oool0oooo
02L0oooo00H000000?ooo`3oool000000?ooo`00001N0?ooo`030000003oool0oooo01D0oooo000E
0?ooo`030000003oool0oooo05h0oooo0P0000020?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool00P00001P0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo
0600oooo0P0000000`3oool000000?ooo`0X0?ooo`040000003oool0000000000680oooo00<00000
0?ooo`3oool04`3oool001<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0000000Y0?oo
o`030000003oool0000006@0oooo00<000000?ooo`3oool04P3oool00180oooo00<000000?ooo`3o
ool0I03oool2000002T0oooo0P00001V0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo06@0oooo0`00000W0?ooo`<00000IP3oool00`000000oooo0?ooo`0A0?ooo`004@3o
ool00`000000oooo0?ooo`1V0?ooo`8000009`3oool2000006P0oooo00<000000?ooo`3oool0403o
ool00140oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0T0?ooo`800000J@3oool0
0`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
02@0oooo0P00001Z0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00l0
oooo000?0?ooo`030000003oool0oooo06X0oooo0P00000S0?ooo`800000K03oool00`000000oooo
0?ooo`0>0?ooo`003P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0200oooo0P00
001^0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool07P3oool2000006l0oooo00<000000?ooo`3oool03@3oool000d0oooo00<000000?oo
o`3oool0KP3oool2000001l0oooo0P00001`0?ooo`030000003oool0oooo00`0oooo000=0?ooo`03
0000003oool0oooo06l0oooo0P00000M0?ooo`800000L@3oool00`000000oooo0?ooo`0<0?ooo`00
303oool00`000000oooo0?ooo`1`0?ooo`030000003oool0000001`0oooo0P00001b0?ooo`030000
003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo0740oooo00<000000?ooo`0000006@3o
ool3000007<0oooo00<000000?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool0LP3oool2
000000030?ooo`000000oooo01D0oooo0P0000000`3oool000000000001d0?ooo`030000003oool0
oooo00X0oooo000;0?ooo`030000003oool0oooo0780oooo0P0000020?ooo`030000003oool0oooo
0180oooo00@000000?ooo`3oool0oooo0P00001d0?ooo`030000003oool0oooo00X0oooo000:0?oo
o`030000003oool0oooo07@0oooo0P0000020?ooo`800000403oool2000000<0oooo0P00001f0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo07@0oooo0P0000040?ooo`H0
00001P3oool4000000D0oooo0P00001f0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`0000002@3oool6000000P0oooo00<000000?ooo`000000
MP3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`1f0?ooo`8000005`3o
ool2000007P0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0000000E0?ooo`030000003oool0000007P0oooo00<000000?ooo`3oool0203oool0
00T0oooo00<000000?ooo`3oool0MP3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0
000007T0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0000000C0?ooo`030000003oool0000007X0oooo00<000000?ooo`3oool01`3oool000P0
oooo00<000000?ooo`3oool0N03oool010000000oooo0?ooo`00000A0?ooo`040000003oool0oooo
000007X0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0N03oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0000007/0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0N@3oool010000000oooo0?ooo`00000?0?ooo`040000003oool0
oooo000007/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0N@3oool0
10000000oooo0?ooo`00000?0?ooo`040000003oool0oooo000007/0oooo00<000000?ooo`3oool0
1`3oool000L0oooo00<000000?ooo`3oool0NP3oool01@000000oooo0?ooo`3oool0000000d0oooo
00D000000?ooo`3oool0oooo0000001k0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`060?ooo`001`3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool01P3o
ool000L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo00H0oooo00070?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000080?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`060?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00H0
oooo00070?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00H0oooo0007
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00H0oooo00070?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00P0oooo
00090?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00P0oooo00090?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0
oooo0780oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00X0oooo000;0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00/0
oooo000<0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00`0oooo000=
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00d0oooo000>0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo00h0oooo000@0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
0100oooo000A0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0140oooo
000B0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0180oooo000D0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo01@0oooo000F0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo01H0oooo000H0?ooo`800000F@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
05L0oooo0P00000I0?ooo`006P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0J0?ooo`00703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`1>
0?ooo`800000?`3oool200000500oooo00<000000?ooo`3oool0703oool001h0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool07@3oool001l0oooo0P00001;0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0B@3oool200000200oooo000Q0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003o
ool0oooo04@0oooo0P0000190?ooo`800000AP3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0R0?ooo`00903oool200000400oooo0P00001?0?ooo`800000@03oool20000
02D0oooo000V0?ooo`800000?@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03/0
oooo0P00000W0?ooo`00:03oool2000003T0oooo0P00001E0?ooo`800000>@3oool2000002T0oooo
000Z0?ooo`800000=@3oool2000005T0oooo0P00000e0?ooo`800000:`3oool002`0oooo0P00000a
0?ooo`800000G@3oool200000340oooo0P00000]0?ooo`00;P3oool3000002/0oooo0`00001Q0?oo
o`<00000:`3oool3000002l0oooo000a0?ooo`<000009@3oool3000006L0oooo0`00000U0?ooo`<0
0000<P3oool003@0oooo0`00000N0?ooo`@00000K@3oool4000001h0oooo0`00000e0?ooo`00=`3o
ool600000180oooo1P00001e0?ooo`H000004P3oool6000003P0oooo000m0?oooa800000P@3ooolB
000003h0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {266.313, 0}} -> {-2.91988, -3.63734, \
0.0273162, 0.0273162}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Triangles", "Subsection"],

Cell["Let us now test the above procedure with random triangles", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]centres = {x, y} /. 
              Solve[disP2Seg[{x, y}, a, b]\^2 == disP2Seg[{x, y}, b, c]\^2 == 
                  disP2Seg[{x, y}, c, a]\^2]; \
\[IndentingNewLine]Graphics[{{LightSteelBlue, Polygon[{a, b, c, a}]}, 
              Line[{a, b, c, a}], \(Circle[#, disP2Seg[#, a, b]] &\) /@ 
                centres}, AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {8}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 4]]];\)\)}], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .51358 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0122282 0.238095 [
[ 0 0 0 0 ]
[ 1 .51358 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .51358 L
0 .51358 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0122282 0.245293 0.245146 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.350246 0.654959 0.234343 0.654959 [
[ 0 0 0 0 ]
[ 1 .99301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.59384 .79741 m
.50039 .84651 L
.35984 .63569 L
.59384 .79741 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.59384 .79741 m
.50039 .84651 L
.35984 .63569 L
.59384 .79741 L
s
newpath
.2185 .77467 .19469 0 365.73 arc
s
newpath
.51413 .79258 .04135 0 365.73 arc
s
newpath
.58949 .86921 .06154 0 365.73 arc
s
newpath
.61908 .38075 .35711 0 365.73 arc
s
0 0 m
1 0 L
1 .99301 L
0 .99301 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0122282 0.488926 0.245146 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0339461 0.507543 0.177167 0.507543 [
[ 0 0 0 0 ]
[ 1 1.10103 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.51394 .67499 m
.26264 .66085 L
.29453 .47594 L
.51394 .67499 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.51394 .67499 m
.26264 .66085 L
.29453 .47594 L
.51394 .67499 L
s
newpath
.15404 .52431 .13023 0 365.73 arc
s
newpath
.33765 .60119 .06379 0 365.73 arc
s
newpath
.43116 .87273 .20208 0 365.73 arc
s
newpath
.64828 .35412 .32791 0 365.73 arc
s
0 0 m
1 0 L
1 1.10103 L
0 1.10103 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0122282 0.732558 0.245146 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.412872 0.38642 0.400953 0.38642 [
[ 0 0 0 0 ]
[ 1 1.00259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.75787 .58751 m
.50214 .46486 L
.58128 .73831 L
.75787 .58751 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.75787 .58751 m
.50214 .46486 L
.58128 .73831 L
.75787 .58751 L
s
newpath
.28432 .64932 .26051 0 365.73 arc
s
newpath
.62112 .60536 .07523 0 365.73 arc
s
newpath
.71801 .28205 .25818 0 365.73 arc
s
newpath
.78554 .79952 .1792 0 365.73 arc
s
0 0 m
1 0 L
1 1.00259 L
0 1.00259 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0122282 0.97619 0.245146 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0997263 0.477741 0.286808 0.477741 [
[ 0 0 0 0 ]
[ 1 .71307 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.46537 .32175 m
.32813 .5241 L
.43707 .57335 L
.46537 .32175 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.46537 .32175 m
.32813 .5241 L
.43707 .57335 L
.46537 .32175 L
s
newpath
.24839 .24156 .22458 0 365.73 arc
s
newpath
.35518 .61992 .07617 0 365.73 arc
s
newpath
.39787 .50441 .04666 0 365.73 arc
s
newpath
.71638 .41452 .25981 0 365.73 arc
s
0 0 m
1 0 L
1 .71307 L
0 .71307 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.268438 0.245293 0.501356 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0647538 0.338129 0.78325 0.338129 [
[ 0 0 0 0 ]
[ 1 1.05162 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.26283 .95794 m
.3454 .9654 L
.18556 .86674 L
.26283 .95794 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.26283 .95794 m
.3454 .9654 L
.18556 .86674 L
.26283 .95794 L
s
newpath
.15519 .90204 .04599 0 365.73 arc
s
newpath
.2717 .94085 .01782 0 365.73 arc
s
newpath
.33534 .9956 .03098 0 365.73 arc
s
newpath
.5 .50123 .47619 0 365.73 arc
s
0 0 m
1 0 L
1 1.05162 L
0 1.05162 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.268438 0.488926 0.501356 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.647363 0.425425 0.202791 0.425425 [
[ 0 0 0 0 ]
[ 1 .82213 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.76797 .60856 m
.88733 .48348 L
.83128 .36964 L
.76797 .60856 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.76797 .60856 m
.88733 .48348 L
.83128 .36964 L
.76797 .60856 L
s
newpath
.4153 .41107 .39149 0 365.73 arc
s
newpath
.84192 .47651 .03766 0 365.73 arc
s
newpath
.86022 .66022 .1024 0 365.73 arc
s
newpath
.90593 .36221 .07026 0 365.73 arc
s
0 0 m
1 0 L
1 .82213 L
0 .82213 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.268438 0.732558 0.501356 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0824222 1.2246 0.199551 1.2246 [
[ 0 0 0 0 ]
[ 1 1.26831 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.76546 .77537 m
.42826 .71789 L
.64207 .94626 L
.76546 .77537 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.76546 .77537 m
.42826 .71789 L
.64207 .94626 L
.76546 .77537 L
s
newpath
.29346 .96846 .26965 0 365.73 arc
s
newpath
.60645 .38666 .35646 0 365.73 arc
s
newpath
.6346 .8289 .07476 0 365.73 arc
s
newpath
.83047 .93427 .14572 0 365.73 arc
s
0 0 m
1 0 L
1 1.26831 L
0 1.26831 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.268438 0.97619 0.501356 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.269836 0.348351 0.139008 0.348351 [
[ 0 0 0 0 ]
[ 1 1.26658 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.69 .769 .871 r
.43204 .17114 m
.60346 .27011 L
.29047 .3039 L
.43204 .17114 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.43204 .17114 m
.60346 .27011 L
.29047 .3039 L
.43204 .17114 L
s
newpath
.23971 .19333 .11539 0 365.73 arc
s
newpath
.43947 .23549 .05202 0 365.73 arc
s
newpath
.5 .76024 .47619 0 365.73 arc
s
newpath
.62915 .1484 .11824 0 365.73 arc
s
0 0 m
1 0 L
1 1.26658 L
0 1.26658 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{637.063, 327.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009m0001Ab000`400?l00000o`00003oo`3ooooo
0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo
003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0
ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool0
0?l0ooooo`3ooomo0?ooo`00o03ooolA00000?l0ooooL@3oool00?P0oooo1000000A0?ooo`@00000
o`3ooom]0?ooo`00mP3oool2000001T0oooo0P00003o0?ooof/0oooo003d0?ooo`8000007@3oool2
00000900oooo2P00003>0?ooo`00G@3ooolC00000800oooo1000000Q0?ooo`800000R@3oool50000
00X0oooo1@0000390?ooo`00F03oool5000001<0oooo1@00001j0?ooo`030000003oool0oooo02D0
oooo0P0000230?ooo`@00000503oool400000<D0oooo001F0?ooo`8000007@3oool3000007H0oooo
00<000000?ooo`3oool0:03oool200000800oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`320?ooo`00E03oool200000280oooo0P00001b0?ooo`800000;@3oool2000007`0oooo0P00
000N0?ooo`800000`P3oool00540oooo0`00000V0?ooo`800000KP3oool200000340oooo0P00001h
0?ooo`8000008P3oool200000<00oooo001?0?ooo`800000:`3oool2000006/0oooo00<000000?oo
o`3oool0<`3oool2000007@0oooo0P00000V0?ooo`030000003oool0oooo0;d0oooo001=0?ooo`80
0000;`3oool2000006P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo02L0oooo0P00002m0?ooo`00C03oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0^P3oool004/0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1Q0?ooo`800000>`3oool2000006h0oooo00<000000?ooo`3oool0;03o
ool200000;X0oooo00190?ooo`800000=`3oool200000600oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0]`3oool0
04P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0;H0oooo00170?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0FP3oool200000440
oooo0P00001X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0]P3oool004D0oooo
0P00000o0?ooo`800000F@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2e0?ooo`00A03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0]03oool004<0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0;<0oooo00120?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2b0?oo
o`00@@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0/@3oool00400oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0;40oooo00100?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0d0?ooo`H00000M`3oool003h0oooo0P00001>0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0;P3oool6000000H0oooo1000001c0?ooo`00?@3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0:P3oool30000
0100oooo0`00001`0?ooo`00?@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool09`3oool2000001H0oooo0`00001]0?ooo`00?03oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool09@3oool2000001/0oooo
0P00001[0?ooo`00?03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`800000J@3oool003/0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0240oooo0P00000R
0?ooo`800000I`3oool003X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo01l0oooo0P00000V0?ooo`030000003oool0oooo06@0oooo000j0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0H`3oool003T0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1R0?ooo`00>@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0640oooo000h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0H@3oool0
03P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1P0?ooo`00>03oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo05l0oooo000g0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0GP3oool003L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`1M0?ooo`00=P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05d0oooo000f0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0G03oool003D0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`1L0?ooo`00=@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo05/0oooo000e0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0703o
ool=00000380oooo000e0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0603oool4
000000d0oooo1000000^0?ooo`00=@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
01@0oooo0`00000E0?ooo`<00000:`3oool003@0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0B0?ooo`8000006`3oool2000002T0oooo000d0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0403oool2000001l0oooo0P00000W0?ooo`00=03oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0T0?ooo`00=03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo0P00000U
0?ooo`800000903oool003@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0T0?oo
o`L000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`8000008P3oool003@0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0Q0?ooo`<000001`3oool3000000l0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo0P00000/0?ooo`03
0000003oool0oooo01l0oooo000d0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
7P3oool3000000d0oooo0P00000=0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo0P00000O0?ooo`00=03o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01`0oooo0P00000B0?ooo`800000303o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01@3o
ool200000380oooo00<000000?ooo`3oool0703oool003@0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01/0oooo000d0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0h0?ooo`H00000603oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool06`3oool003@0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0380
oooo1P0000060?ooo`H000004`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool06P3oool003@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0300oooo0`00000B0?ooo`<00000403oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3oool003@0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02h0oooo0P00
000H0?ooo`8000003`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000003X0oooo00<000000?ooo`3oool0
6@3oool003@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo02`0oooo0`00000L0?ooo`<000003@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0603oool003@0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02X0oooo0P00000R0?ooo`800000303oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool0
1@000000oooo0?ooo`3oool0000003d0oooo00<000000?ooo`3oool05`3oool003@0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0k0?ooo`040000003oool0oooo000003h0oooo
00<000000?ooo`3oool05`3oool003@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P0000040?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool09`3oool2000002P0oooo0P00000:0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0k0?ooo`040000003o
ool0oooo000003l0oooo00<000000?ooo`3oool05P3oool003@0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00H000000?ooo`3oool00000
0;34gP0000030?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool09P3oool2000002`0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0>@3oool010000000oooo0?ooo`0000110?ooo`030000003oool0oooo
01D0oooo000e0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0P0?ooo`8000000`2`a=h01@000000oooo0?ooo`3oool0000004l0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`000000@P3oool00`000000oooo0?ooo`0E0?ooo`00=@3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool2000000@0/<CN00@000000?ooo`3o
ool00000CP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0>03oool00`000000oooo000000130?ooo`030000003oool0oooo01@0oooo000e0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`80
00001@2`a=h010000000oooo0?ooo`00001=0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`020?ooo`8000000`3oool200000340oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0g0?ooo`040000003oool00000000004<0oooo00<00000
0?ooo`3oool0503oool003D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0200oooo0P0000060;34gP030000003oool0000004`0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0b0?ooo`8000000P3oool010000000/<CN000000000003
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0g
0?ooo`@00000@`3oool00`000000oooo0?ooo`0D0?ooo`00=@3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool2000000L0/<CN0`00001;0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`000002
0;34gP8000000P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0=P3oool3000004D0oooo00<000000?ooo`3oool04`3oool003H0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo00<000000;34
gP2`a=h00`2`a=h300000080/<CN0P0000190?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo000000040;34gP<00000;03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03D0oooo0P0000000`2`a=h000000?ooo`140?ooo`030000003oool0oooo
01<0oooo000f0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0P0?ooo`040000002`a=h0/<CN0;34gP8000000`2`a=h5000004L0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0h0?ooo`030000003oool0000000H0/<CN0P00000Y0?oo
o`8000009P3oool00`000000oooo0?ooo`0e0?ooo`040000002`a=h0/<CN000004D0oooo00<00000
0?ooo`3oool04`3oool003H0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0200oooo00@000000;34gP0000000000202`a=h3000004D0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0j0?ooo`800000202`a=h2000002H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0c0?ooo`80000000<0/<CN0000003oool0A@3oool0
0`000000oooo0?ooo`0C0?ooo`00=`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool07P3oool3000000`0/<CN00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`0000002@2`a=h20000
02<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0b0?ooo`040000002`a=h0/<CN
000004L0oooo00<000000?ooo`3oool04P3oool003L0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo0`00000=0;34gP030000003oool0oooo
0440oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0l0?ooo`8000002P2`a=h40000
01`0oooo1000000/0?ooo`030000003oool0oooo0340oooo00D000000;34gP2`a=h0/<CN00000017
0?ooo`030000003oool0oooo0180oooo000h0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`8000003P2`a=h200000440oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0n0?ooo`030000002`a=h0/<CN00/0/<CN0P00000J0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000/<CN0;34gP020;34
gP030000003oool0oooo04D0oooo00<000000?ooo`3oool04P3oool003P0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo0P00000@0;34gP80
0000?`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03h0oooo0P00000<0;34gPH0
00004P3oool4000003<0oooo00<000000?ooo`3oool0;@3oool2000000@0/<CN00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0B0?ooo`00>@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0703oool200000100/<CN00<000000;34gP000000
?@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03l0oooo00<000000;34gP2`a=h0
202`a=h2000000<0/<CN2P0000040?ooo`L00000>03oool00`000000oooo0?ooo`0[0?ooo`800000
1@2`a=h00`000000oooo0?ooo`150?ooo`030000003oool0oooo0180oooo000i0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool000000100/<CN00@000000;34gP2`a=h00000>`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0400oooo00<000000;34gP2`a=h01P2`a=h2000000T0/<CN0P0000040?ooo`@00000
@03oool00`000000oooo0?ooo`0Z0?ooo`030000002`a=h0/<CN00@0/<CN00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0A0?ooo`00>@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00000@0;34gP050000
002`a=h0/<CN0;34gP000000>@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0400
oooo00<000000;34gP2`a=h0102`a=h2000000`0/<CN0`0000160?ooo`030000003oool0oooo02T0
oooo0P0000050;34gP800000B03oool00`000000oooo0?ooo`0A0?ooo`00>P3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05`3oool010000000oooo
00000000000@0;34gP030000002`a=h0/<CN0080/<CN0P00000f0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0@P3oool010000000/<CN0;34gP2`a=h2000000l0/<CN00@000000;34
gP0000000000A@3oool00`000000oooo0?ooo`0W0?ooo`8000001P2`a=h2000004P0oooo00<00000
0?ooo`3oool04@3oool003X0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00000@0;34gP030000002`a=h0/<CN
00<0/<CN0P00000c0?ooo`800000:P3oool00`000000oooo0?ooo`120?ooo`040000002`a=h0/<CN
00000140/<CN00@000000;34gP2`a=h0/<CN0P0000140?ooo`8000009@3oool3000000L0/<CN00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0A0?ooo`00>`3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool2000000<0oooo0P00000?
0;34gP030000002`a=h0/<CN00D0/<CN0P00000a0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0@P3oool2000000030;34gP000000/<CN0140/<CN00<000000;34gP2`a=h00P2`a=h2
000004@0oooo00<000000?ooo`3oool0803oool200000080oooo00<000000;34gP2`a=h01@2`a=h2
000004P0oooo00<000000?ooo`3oool04@3oool003`0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`00
0000/<CN0000000=0;34gP030000002`a=h0/<CN00P0/<CN00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo04@0oooo00<000000;34gP0000004P2`a=h00`00
0000/<CN0;34gP040;34gP800000@`3oool2000001l0oooo00D000000?ooo`3oool0oooo00000008
0;34gP800000A`3oool00`000000oooo0?ooo`0B0?ooo`00:P3oool:000000T0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0U0?ooo`800000403oool00`000000oooo0?ooo`040?oo
o`030000002`a=h0000000d0/<CN00<000000;34gP2`a=h02@2`a=h2000002/0oooo0P00000]0?oo
o`030000003oool0oooo04@0oooo00<000000;34gP0000004`2`a=h00`000000/<CN0;34gP050;34
gP800000@`3oool2000001/0oooo0P0000030?ooo`030000002`a=h0/<CN00L0/<CN0P0000170?oo
o`030000003oool0oooo0180oooo000U0?ooo`D000002P3oool3000000H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0X0?ooo`<000002@3oool4000000H0oooo00D000000;34gP2`
a=h0/<CN0000000;0;34gP030000002`a=h0/<CN00/0/<CN0`00000W0?ooo`800000;`3oool00`00
0000oooo0?ooo`140?ooo`800000502`a=h00`000000/<CN0;34gP050;34gP030000003oool0oooo
04@0oooo0P00000F0?ooo`<000001@3oool00`000000/<CN0;34gP070;34gP800000A`3oool00`00
0000oooo0?ooo`0B0?ooo`008`3oool200000180oooo0P0000050?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0;03oool9000000X0oooo00<000000;34gP2`a=h00P2`a=h2000000L0
/<CN0P00000?0;34gP040000003oool00000000002<0oooo0P00000a0?ooo`030000003oool0oooo
04@0oooo0P00000D0;34gP030000002`a=h0/<CN00@0/<CN00<000000?ooo`3oool0A`3oool30000
0140oooo0P0000070?ooo`030000002`a=h0/<CN008000001P2`a=h2000004L0oooo00<000000?oo
o`3oool04P3oool00240oooo0P00000F0?ooo`<000000`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0400oooo3P00000B0;34gP030000003oool0oooo00@000006`3oool400000380
oooo00<000000?ooo`3oool0AP3oool00`000000/<CN0;34gP0B0;34gP030000002`a=h0/<CN0080
/<CN0P00001=0?ooo`L00000103oool6000000P0oooo00@000000;34gP00000000000P2`a=h20000
00@0/<CN0P0000170?ooo`030000003oool0oooo0180oooo000P0?ooo`030000003oool0oooo01T0
oooo0P0000020?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B@3ooolB000000H0
/<CN00<000000?ooo`3oool00`3oool2000001L0oooo0P00000f0?ooo`030000003oool0oooo04H0
oooo00<000000;34gP2`a=h04P2`a=h01@000000/<CN0;34gP2`a=h0000005H0oooo1000000>0?oo
o`8000001P2`a=h010000000/<CN0;34gP2`a=h2000004H0oooo00<000000?ooo`3oool04`3oool0
01h0oooo0P00000N0?ooo`030000003oool0000004/0oooo00<000000?ooo`3oool0D@3oool30000
00L0oooo2@0000060?ooo`L000002@3oool7000003P0oooo00<000000?ooo`3oool0AP3oool00`00
0000/<CN0;34gP0B0;34gP040000002`a=h0/<CN000000<0oooo3000001I0?ooo`030000002`a=h0
/<CN00L0/<CN00H000000;34gP2`a=h000000?ooo`0000150?ooo`030000003oool0oooo01<0oooo
000M0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`000000B@3oool00`000000oooo0?oo
o`1@0?ooo`800000403oool2000000h0oooo2@00000o0?ooo`030000003oool0oooo04H0oooo0P00
000C0;34gP030000002`a=h000000080oooo0P00000<0?ooo`800000EP3oool00`000000/<CN0;34
gP090;34gP8000000P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01<0oooo000L
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1>
0?ooo`<00000503oool2000005@0oooo00<000000?ooo`3oool0AP3oool2000001<0/<CN1@00000@
0?ooo`<00000DP3oool2000000`0/<CN00@000000?ooo`3oool00000A@3oool00`000000oooo0?oo
o`0C0?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`<00000A@3oool00`000000oooo0?ooo`1=
0?ooo`8000006@3oool200000580oooo00<000000?ooo`3oool0AP3oool300000140/<CN0`00000F
0?ooo`800000D03oool2000000`0/<CN00@000000?ooo`3oool00000A03oool00`000000oooo0?oo
o`0D0?ooo`006P3oool00`000000oooo0?ooo`0U0?ooo`@00000@@3oool2000004h0oooo0P00000M
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0000000@
0;34gP8000006P3oool2000004d0oooo00<000000;34gP000000302`a=h01@000000oooo0?ooo`3o
ool0000004<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool09`3oool0
10000000/<CN00000000000o0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool07P3o
ool2000004l0oooo00<000000?ooo`3oool0AP3oool010000000oooo00000000000>0;34gP800000
7@3oool2000004X0oooo00@000000;34gP2`a=h000002`2`a=h2000000<0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0D0?ooo`00603oool00`000000oooo0?ooo`0X0?ooo`800000
00<0/<CN000000000000?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`160?ooo`040000003oool000000;34gP80
00002`2`a=h200000200oooo00<000000?ooo`3oool0A`3oool010000000/<CN0;34gP00000;0;34
gP8000000`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01D0oooo000G0?ooo`03
0000003oool0oooo02X0oooo0P0000020;34gP030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo000000030;34gP800000202`a=h200000280oooo00<000000?ooo`3o
ool0A@3oool200000080/<CN00<000000;34gP2`a=h02@2`a=h2000000@0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`0/0?ooo`040000
002`a=h0/<CN0;34gP800000>03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`160?ooo`040000003oool0oooo0000
00@0/<CN2@00000S0?ooo`030000003oool0oooo04L0oooo0P0000000`2`a=h000000;34gP080;34
gP030000002`a=h0000000@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0F0?oo
o`005@3oool00`000000oooo0?ooo`0^0?ooo`040000002`a=h0/<CN0;34gP800000=@3oool20000
04l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
04H0oooo00@000000?ooo`3oool000002@2`a=h00`000000oooo0000000U0?ooo`030000003oool0
oooo04P0oooo100000070;34gP030000002`a=h0000000D0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0^0?ooo`800000102`a=h20000
0340oooo0P00001@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`150?ooo`050000003oool0oooo0?ooo`000000202`a=h00`000000oooo0000000W
0?ooo`030000003oool0oooo04@0oooo100000000`3oool0000000000007000000030;34gP000000
oooo00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0G0?ooo`005@3oool00`00
0000oooo0?ooo`0_0?ooo`030000002`a=h0/<CN00@0/<CN00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo0080oooo00<000000;34gP2`a=h0102`a=h00`00
0000oooo0000000Y0?ooo`030000003oool0oooo0440oooo0P0000070?ooo`<000001@2`a=h00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0603oool001@0
oooo00<000000?ooo`3oool0<03oool2000000H0/<CN0P00000/0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool00P3oool00`000000/<CN0;34gP030;34gP040000003oool0oooo0000
02T0oooo00<000000?ooo`3oool0?`3oool2000000/0oooo0`0000030;34gP030000003oool0oooo
00H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0H0?ooo`00503oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0000000H0/<CN0`00000X0?ooo`800000DP3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`020?ooo`040000002`a=h0/<CN0;34gP8000000P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool3000000030;34gP000000oooo
00P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0I0?ooo`004`3oool00`000000
oooo0?ooo`0b0?ooo`800000202`a=h6000001h0oooo1@00001D0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0080
oooo00@000000;34gP2`a=h000000`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03P3oool010000000oooo00000000000:0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool06@3oool001<0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo000000090;34gP040000003oool0oooo0?ooo`8000006@3oool3000005P0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo01X0oooo000C0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`0000002@2`a=h2000000<0oooo1@00000?0?ooo`D00000FP3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo01/0oooo000C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`00
00002`2`a=h00`000000oooo0?ooo`050?ooo`l00000G`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`00
4`3oool00`000000oooo0?ooo`0c0?ooo`040000003oool0oooo000000/0/<CN0P00001c0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01d0oooo000C0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool0
00002@2`a=h3000000030;34gP000000oooo0740oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool07P3oool00180oooo
00<000000?ooo`3oool0=03oool01@000000oooo0?ooo`3oool0000000H0/<CN0P0000030;34gP@0
0000L03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo0P00000/0?ooo`03
0000003oool0oooo01l0oooo000B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
0P3oool00`000000/<CN0;34gP020;34gP030000002`a=h0/<CN00D0/<CN0`00001^0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`800000
8P3oool00180oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`050000002`
a=h0/<CN0;34gP0000002@2`a=h010000000/<CN00000000001/0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0280
oooo000B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool00`3oool010000000/<CN
0;34gP00000:0;34gP040000002`a=h0/<CN000006/0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0C0?ooo`8000008`3oool2000002D0oooo000B0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0103oool00`000000/<CN0000000:0;34gP040000002`a=h0/<CN0;34
gP800000J@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0U0?ooo`004P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00@0oooo00<000000;34gP0000002P2`a=h00`000000/<CN0;34gP030;34gP03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`@0
00006@3oool4000002P0oooo000C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
1@3oool2000000X0/<CN00@000000;34gP2`a=h0/<CN0P00001Y0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06`3oool3000001<0oooo0`00000/0?ooo`004`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00H0oooo00<000000;34gP2`a=h0202`a=h00`000000/<CN
00000005000006L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0O0?ooo`@00000
2`3oool4000002l0oooo000C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01P3o
ool00`000000/<CN0;34gP070;34gP<000001P3oool2000006D0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0S0?ooo`/00000<`3oool001<0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`080?ooo`030000002`a=h0/<CN00D0/<CN0P00000:0?ooo`800000H`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`090?ooo`800000I03oool001<0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`090?ooo`8000000`2`a=h3000000d0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0?@3oool20000
00L0oooo0P00001V0?ooo`00503oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0
oooo00<000000;34gP0000000P0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0@03oool7000006P0oooo000D0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
2`3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2_0?ooo`00503o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`2_0?ooo`005@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0W0?ooo`800000603oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;00oooo000E0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1D0?ooo`8000009P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0/03oool001H0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0/@3oool001H0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo05P0oooo0`00000N0?ooo`<000007P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0;40oooo000G0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`1L0?ooo`8000006P3oool200000280oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`2b0?ooo`00603oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0GP3oool400000180oooo1000000T
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0/P3oool001T0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo06<0oooo1`0000040?oo
o`L00000:@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;<0oooo000J0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1Z0?ooo`@0
0000<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0;@0oooo000K0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0]@3oool001`0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0P00001Y0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0;D0oooo000M0?ooo`800000803oool00`000000oooo0?ooo`0M0?ooo`L00000K03oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`2f0?ooo`007`3oool00`000000oooo0?ooo`0K0?ooo`800000U03oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo0:D0oooo0P00000N0?ooo`030000003oool0oooo
0;L0oooo000P0?ooo`8000006@3oool2000009L0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo01T0oooo0P00002j0?ooo`008P3oool2000001H0oooo
00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0:X0oooo
0P00000F0?ooo`<00000_03oool002@0oooo0`00000@0?ooo`<00000W03oool200000200oooo00<0
00000?ooo`3oool0[@3oool200000180oooo0P00002o0?ooo`009`3oool5000000H0oooo1@00002Q
0?ooo`030000003oool0oooo01/0oooo0P00002b0?ooo`8000003@3oool300000<40oooo000/0?oo
o`H00000Y`3oool2000001T0oooo0P00002f0?ooo`d00000a03oool00=/0oooo0P00000F0?ooo`03
0000003oool0oooo0?l0ooooR03oool00=d0oooo0`00000@0?ooo`<00000o`3ooon;0?ooo`00h03o
ool5000000<0oooo2000003o0?ooohh0oooo003U0?ooo`<00000o`3ooonF0?ooo`00o`3ooooo0?oo
ogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o
0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0oooo
O`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0
ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo
0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3o
oooo0?ooogl0oooo003o0?ooool0ooooO`3oool00580oooo2000003o0?oooc/0oooo1`00002G0?oo
o`D00000AP3oool004X0oooo200000080?ooo`P00000o`3oool]0?ooo`H000001`3oool7000008h0
oooo0P0000050?ooo`<00000@`3oool004D0oooo1@00000H0?ooo`D00000o`3ooolT0?ooo`@00000
503oool2000008X0oooo0P00000:0?ooo`800000@@3oool00480oooo0`00000R0?ooo`<00000o`3o
oolO0?ooo`8000006P3oool3000008H0oooo00<000000?ooo`3oool0303oool2000003l0oooo000o
0?ooo`<00000:03oool300000?l0oooo6P3oool2000001l0oooo0P0000230?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0?03oool003d0oooo0P00000^0?ooo`800000o`3ooolF0?oo
o`8000008`3oool200000800oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0k0?oo
o`00>P3oool300000380oooo0`00003o0?oooa80oooo00<000000?ooo`3oool09@3oool2000005P0
oooo1`00000N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>P3oool003P0oooo
0P00000h0?ooo`800000o`3oool>0?ooo`800000:P3oool2000005<0oooo0`0000070?ooo`800000
6`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03X0oooo000f0?ooo`800000?03o
ool200000?l0oooo2P3oool2000002h0oooo0P00001?0?ooo`800000303oool2000001P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0i0?ooo`00=03oool200000400oooo0P00003o
0?ooo`H0oooo0P00000b0?ooo`030000003oool0oooo04X0oooo0P00000@0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0i0?ooo`00<P3oool20000
04@0oooo0P00003o0?ooo`<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo03P0oooo000a0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0o`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0>03oool002l0oooo0P00001:0?ooo`800000oP3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0>03oool002h0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0h0?ooo`00;@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0?P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo03P0oooo000/0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0m@3oool20000
03h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0h0?ooo`00:P3oool2000005@0
oooo0P00001K0?oooa000000R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0>03oool002T0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`1B0?ooo`H00000403oool5000008@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>03oool002P0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1?0?ooo`8000006`3oool300000800oooo00<0
00000?ooo`3oool0@@3oool2000003l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`040000002`a=h00000000000L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0h0?ooo`009`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04/0oooo0`00
000P0?ooo`800000O@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`<0000000@0/<CN0000000000000000
1@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03T0oooo000V0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool0B03oool2000002D0oooo0`00001j0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00<0oooo0P0000050;34gP<000000`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo03T0oooo000U0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0A03oool3
000002X0oooo0P00001g0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0G0?ooo`8000000`3oool2000000P0/<CN00@000000;34gP00000000000P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03X0oooo000T0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0@@3oool2000002l0oooo0`00001d0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0
oooo0?ooo`8000002P2`a=h010000000/<CN0;34gP0000020?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0>P3oool002<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0n0?ooo`800000=03oool200000740oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P00000;0;34gP040000002`
a=h0/<CN0;34gP<00000503oool00`000000oooo0?ooo`0k0?ooo`008P3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo03/0oooo0P00000h0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01H0oooo00D0
00000?ooo`000000/<CN0000000;0;34gP800000102`a=h200000180oooo00<000000?ooo`3oool0
?03oool00240oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool05P3oool200000080/<CN00<000000;34gP2`a=h02P2`
a=h00`000000/<CN0;34gP040;34gP8000003`3oool00`000000oooo0?ooo`0m0?ooo`008@3oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo03L0oooo0P00000m0?ooo`800000K03oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0503oool2
000000@0/<CN00<000000;34gP2`a=h0202`a=h00`000000/<CN0;34gP070;34gP800000303oool0
0`000000oooo0?ooo`0n0?ooo`00803oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0?`3oool2000006T0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01<0oooo0P0000050;34gP030000002`a=h0/<CN
00P0/<CN00<000000;34gP2`a=h0202`a=h3000000L0oooo0`0000110?ooo`007`3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0A0?ooo`8000001`2`a=h00`000000/<CN0;34gP060;34gP030000002`a=h0/<CN00P0
/<CN2`0000140?ooo`007`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0340oooo
0P0000160?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0100oooo0P0000090;34gP030000002`a=h0/<CN00D0/<CN
00<000000;34gP0000002000001?0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0?03oool2000000l0oooo0P00000:0;34gQ<00000C`3o
ool001d0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo04T0oooo0P00001S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0?P3oool2
000000`0oooo0P0000020;34gP`00000403oool6000004T0oooo000L0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00L0oooo1P0000040?ooo`<000006`3oool2000004L0oooo000L0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`100?ooo`T000001`3oool300000200
oooo0`0000140?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0CP3oool2000002H0oooo0P0000120?ooo`006`3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0B`3oool3000002X0oooo0`00
000o0?ooo`006P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0B@3oool200000300oooo0P00000m0?ooo`006P3oool00`000000oooo0?ooo`1d0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0A`3oool2000003@0oooo0P00000k0?oo
o`006@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0A03oool2000003P0oooo0P00000i0?ooo`00603oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03H0oooo000H0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`110?ooo`800000?P3oool2000003H0oooo000H0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0<`3oool001L0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0b0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0340
oooo000F0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0<03oool001H0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0_0?ooo`005P3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo02h0oooo000E0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0;@3oool001D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0/0?ooo`00
5@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02/0oooo000D0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0:P3oool001@0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0Y0?ooo`00503oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
02P0oooo000D0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09`3oool001@0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0303oool5000004<0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool09P3oool001<0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0203oool4000000D0oooo0P0000110?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02H0oooo000C
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo02D0oooo000C0?ooo`030000003oool0oooo0880oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02D0oooo000C0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo00@0oooo0P00000>0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool09@3oool001<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0903oool001<0oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool08`3o
ool001<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool08P3oool001<0oooo00<000000?ooo`3oool0PP3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo06X0oooo00D000000?ooo`3oool0oooo0000000C
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool08P3oool001<0oooo00<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06X0oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool08@3oool0
01<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
06/0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool08@3oool00180oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo06/0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool08@3oool00180oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo00D000000?ooo`3oool0oooo0000000C
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0803oool00180oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo00H000000?oo
o`3oool000000;34gP00000A0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0803o
ool00180oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo06/0oooo00H000000?ooo`3oool000000;34gP00000A0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0803oool00180oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo06/0oooo00@000000?ooo`3oool000000P2`a=h00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool07`3oool00180oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo00@0
00000?ooo`3oool000000P2`a=h00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04D0oooo
0P00000l0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo000000040;34gP030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0O0?ooo`004`3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0J`3oool00`000000oooo00000004
0;34gP8000002`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01l0oooo000C0?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0000000D0/<CN0`0000070?ooo`800000C@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0O0?oo
o`004`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo000000050;34gP030000003oool0oooo00L00000D03oool00`000000
oooo0?ooo`0a0?ooo`800000?03oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01h0
oooo000C0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1[0?ooo`8000000P2`a=h6000005T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool001<0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06/0oooo1000
00040;34gP800000FP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0J`3oool2000000L0/<CN0P00001J
0?ooo`800000;03oool2000003l0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0M
0?ooo`004`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0JP3oool2000000P0/<CN00<000000?ooo`3oool0B03oool6000000`0oooo0P00000X0?oo
o`800000@@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01d0oooo000C0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Z0?ooo`03
0000002`a=h0/<CN00L0/<CN0P0000130?ooo`H000001P3oool7000000L0oooo00<000000?ooo`3o
ool08`3oool200000480oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`00
4`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
JP3oool00`000000/<CN0;34gP070;34gP800000@@3oool2000001<0oooo0P0000060?ooo`800000
8@3oool2000004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`00503o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0J@3o
ool2000000T0/<CN00<000000;34gP000000?P3oool2000001L0oooo0P0000020?ooo`P000006P3o
ool3000004H0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`00503oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0J@3oool2
000000T0/<CN0P00000m0?ooo`8000006`3oool2000000040?ooo`000000/<CN0;34gPP000004P3o
ool4000004T0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`00503oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0J@3oool2
000000P0/<CN0P00000l0?ooo`8000007`3oool3000000L0/<CN5000001=0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool07@3oool001@0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo06P0oooo00<000000;34gP0000001`2`a=h00`00
0000oooo0?ooo`0i0?ooo`8000008`3oool2000000d0/<CN1P00001D0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool07@3oool001D0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo06P0oooo00<000000;34gP2`a=h01`00000k0?ooo`03
0000003oool0oooo02@0oooo0P00000@0;34gPT00000C@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01d0oooo000E0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1V0?ooo`030000002`a=h0/<CN00H0/<CN00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0V0?ooo`8000003@2`a=h2000000H0/<CN0P0000000`2`a=h00000
00000004000004L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`005@3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0IP3o
ool00`000000/<CN0;34gP050;34gP030000003oool0oooo03T0oooo00<000000?ooo`3oool0:@3o
ool00`000000/<CN0;34gP090;34gP030000002`a=h0/<CN00P0/<CN00<000000;34gP2`a=h0102`
a=h4000004<0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`005@3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0IP3oool0
0`000000/<CN0;34gP040;34gP030000003oool0oooo03T0oooo00<000000?ooo`3oool0:P3oool2
000000T0/<CN00<000000;34gP2`a=h02P2`a=h00`000000/<CN0;34gP050;34gP030000003oool0
oooo0480oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`005P3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0I@3oool20000
00D0/<CN00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0/0?ooo`030000002`a=h0/<CN
00L0/<CN00<000000;34gP2`a=h02`2`a=h00`000000/<CN0;34gP030;34gP030000003oool0oooo
00<0oooo2@00000g0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool07@3oool001H0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06D0
oooo00<000000;34gP2`a=h00`2`a=h00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02d0
oooo00<000000;34gP2`a=h01@2`a=h00`000000/<CN0;34gP0<0;34gP030000002`a=h0/<CN00<0
/<CN00<000000?ooo`0000000`0000090?ooo`800000=@3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01d0oooo000F0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`1T0?ooo`8000001@2`a=h00`000000oooo0?ooo`020?ooo`<00000
=03oool00`000000oooo0?ooo`0_0?ooo`030000002`a=h0/<CN00<0/<CN00<000000;34gP2`a=h0
3P2`a=h01`000000/<CN0;34gP2`a=h000000?ooo`0000003`3oool2000003<0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`0M0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0H`3oool2000000@0/<CN1P0000030?ooo`80
0000<@3oool00`000000oooo0?ooo`0a0?ooo`030000002`a=h0/<CN0080/<CN00<000000;34gP2`
a=h03P2`a=h00`000000/<CN0;34gP0300000180oooo0P00000a0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool07@3oool001P0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0680oooo0P0000030;34gP8000002P3oool2000002h0oooo
00<000000?ooo`3oool0<P3oool2000000<0/<CN00<000000;34gP2`a=h03P2`a=h010000000/<CN
00000000000F0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`0M0?ooo`00603oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0H@3oool200000080/<CN0P00000>0?ooo`800000:`3oool00`000000oooo
0?ooo`0d0?ooo`8000000P2`a=h00`000000/<CN0;34gP0>0;34gP030000002`a=h0000001L0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01d0oooo
000I0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1P0?ooo`80000000<0/<CN0000000000004@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo03@0oooo00D000000?ooo`000000/<CN0000000@0;34gP<00000603oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool07@3oool001T0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`0000000P00000C0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0=P3o
ool010000000oooo00000000000@0;34gP8000006P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool001X0oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05h0oooo00@000000?ooo`0000000000
5@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
0P00000>0;34gP8000006`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool07P3oool001X0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo05d0oooo00@000000?ooo`00000000005P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo03P0oooo00@000000?ooo`3oool000003P2`a=h00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0J@3oool00`000000
oooo0?ooo`0O0?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0F`3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000000`0/<CN0P00000N0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0O0?oo
o`006`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0FP3oool010000000oooo0?ooo`00000I0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0>@3oool010000000oooo0?ooo`3oool2000000T0/<CN0P00000O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0O0?ooo`00703oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0F@3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>P3oool0
1`000000oooo0?ooo`3oool000000;34gP0000001`2`a=h300000200oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01l0oooo000L0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1H0?ooo`040000003o
ool0oooo000001/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0080oooo00<000000;34gP0000001`0000000`3oool000000?ooo`0O0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0O0?ooo`007@3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0E`3o
ool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00<0oooo00<000000;34gP2`a=h0102`a=h010000000oooo
0?ooo`00000P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`0O0?ooo`007@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0E@3oool01@000000oooo0?ooo`3oool0000001`0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<000000;34gP2`
a=h00P2`a=h010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`007P3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00@0oooo00@000000;34gP2`a=h000000`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?oo
o`007`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo00<000000;34gP00
00000`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`0Q0?ooo`007`3oool00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0Q0?ooo`00803o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool08@3o
ool00240oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0280oooo000R0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool08`3oool002<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo02@0oooo000T0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0T0?ooo`009@3oool2000005h0oooo0P00000k
0?ooo`030000003oool0oooo0440oooo0P00000?0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool09@3oool002L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?oo
o`800000?`3oool200000140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0U0?oo
o`00:03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool09P3oool002D0oooo0P0000000`3oool000000?ooo`1I0?ooo`030000003oool0oooo0400oooo
0P00000j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0V0?ooo`008`3oool200000080oooo0`00001H0?ooo`030000003oool0oooo04<0oooo0P00
000f0?ooo`800000603oool2000000h0oooo0P00000X0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0W0?ooo`008@3oool2000000H0oooo0`00001D
0?ooo`800000B03oool00`000000oooo0?ooo`0a0?ooo`800000703oool3000000P0oooo0`00000Z
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0X
0?ooo`00803oool00`000000oooo0?ooo`070?ooo`<00000DP3oool00`000000oooo0?ooo`190?oo
o`800000<03oool00`000000oooo0?ooo`0O0?ooo`P00000;P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo01<0oooo0P00000B0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0Y0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`@0
0000D03oool00`000000oooo0?ooo`1<0?ooo`800000:`3oool3000005P0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0F0?ooo`8000003P3oool200000400oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0Z0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`800000
00<0/<CN0000003oool0C@3oool00`000000oooo0?ooo`1?0?ooo`<000009P3oool2000005/0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0H0?ooo`@000001`3oool3000004<0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0[0?ooo`007P3oool00`000000oooo0?oo
o`0:0?ooo`8000000P2`a=h2000004X0oooo0P00001E0?ooo`8000008@3oool3000005h0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0M0?ooo`L00000A`3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo02`0oooo000N0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`0000000`2`a=h2000004H0oooo0P00001I0?ooo`H000005P3oool500000680oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0;@3oool001l0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000004
0;34gP800000@P3oool200000640oooo1@00000;0?ooo`H00000I`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0^
0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000102`a=h3
000003h0oooo0P00001X0?ooo`/00000KP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0_0?ooo`007`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00@000000;34gP2`a=h0/<CN1@00000k
0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0<03oool00200oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000002`a=h000000080/<CN1@00000f0?oo
o`<00000i@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0a0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000;34gP000000102`a=h4000003<0oooo0P00003Y0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0380oooo000R0?ooo`H000002P3oool2000000<0/<CN00@000000;34gP2`a=h0
/<CN1000000]0?ooo`<00000k03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0c0?ooo`00<`3oool01@000000/<CN
0;34gP2`a=h0000000@0/<CN0P0000000`3oool0000000000002000002H0oooo0`00003`0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo03@0oooo000d0?ooo`H00000102`a=h2000000<0oooo0`00000P0?ooo`<00000
m03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07X0oooo0P00000l0?ooo`800000
=`3oool003X0oooo1`0000050?ooo`D000005P3oool500000?P0oooo00<000000?ooo`3oool09P3o
ool2000007l0oooo0P00000h0?ooo`800000>@3oool003/0oooo0P0000040?ooo`800000203ooolF
00000?h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0>@3oool003X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`230?oo
o`<00000<03oool3000003`0oooo000j0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooolM0?ooo`8000008@3oool00`000000oooo0?ooo`270?ooo`800000;03oool2000003l0
oooo000j0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`800000
7@3oool2000008`0oooo0`00000V0?ooo`<00000@@3oool003X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooob40oooo0P00000I0?ooo`800000T@3oool300000240oooo0P00
00140?ooo`00>P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8`3oool2
000001@0oooo0`00002F0?ooo`800000703oool3000004H0oooo000k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`@000003@3oool3000009/0oooo1P00000A0?oo
o`D00000B@3oool003`0oooo1@00003o0?ooobd0oooo3@00002T0?oooa400000CP3oool00?l0oooo
o`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?oo
o`00o`3ooooo0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo
0?ooogl0oooo003o0?ooool0ooooO`3oool00?l0ooooo`3ooomo0?ooo`00o`3ooooo0?ooogl0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 636.063}, {326.188, 0}} -> {-0.103121, -0.0513693, \
0.00661294, 0.00661294}, {{15.5625, 156.25}, {318.375, 170.438}} -> \
{-0.703662, -0.487269, 0.0108526, 0.0108526}, {{170.313, 310.938}, {318.375, \
170.438}} -> {-2.61027, -0.463641, 0.014664, 0.014664}, {{325.063, 465.688}, \
{318.375, 170.438}} -> {-7.0505, -1.24533, 0.0184027, 0.0184027}, {{479.75, \
620.438}, {318.375, 170.438}} -> {-7.34667, -1.07082, 0.0148784, 0.0148784}, \
{{15.5625, 156.25}, {155.688, 7.75}} -> {-0.51882, -5.90093, 0.0210234, \
0.0210234}, {{170.313, 310.938}, {155.688, 7.75}} -> {-4.36855, -3.59685, \
0.0167155, 0.0167155}, {{325.063, 465.688}, {155.688, 7.75}} -> {-2.42701, \
-1.35662, 0.00700095, 0.00700095}, {{479.75, 620.438}, {155.688, 7.75}} -> \
{-12.8593, -4.58957, 0.0245777, 0.0245777}}]
}, Open  ]],

Cell[TextData[{
  "In order to compute only the incircle, we resort to another technique. \
Predicate ",
  StyleBox["insideQ", "Input",
    FontSlant->"Italic"],
  " tests whether point p is inside the triangle abc"
}], "Text"],

Cell[BoxData[{
    \(\(\(insideQ[a_, b_, c_, 
        p_] := \((Sign[Det[{b - a, p - a}]] \[Equal] 
          Sign[Det[{c - b, p - b}]] \[Equal] 
          Sign[Det[{a - c, p - c}]])\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(incircle[a_, b_, c_] := 
      Module[{centres, x, 
          y}, \[IndentingNewLine]centres = \(({x, y} /. 
              Solve[disP2Seg[{x, y}, a, b]\^2 == disP2Seg[{x, y}, b, c]\^2 == 
                  disP2Seg[{x, y}, c, a]\^2])\); \[IndentingNewLine]{p} = 
          Select[centres, \ insideQ[a, b, c, #] &]; \[IndentingNewLine]{p, 
          disP2Seg[p, a, b]}]\)}], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]ic = 
            incircle[a, b, 
              c]; \[IndentingNewLine]Graphics[{{LightSlateGray, 
                Polygon[{a, b, c, a}], Chartreuse, 
                Disk[First[ic], Last[ic]]}, Line[{a, b, c, a}], 
              Circle[First[ic], Last[ic]]}, AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {12}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 6]]];\)\)}], "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .30555 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.00727497 0.15873 [
[ 0 0 0 0 ]
[ 1 .30555 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .30555 L
0 .30555 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00727497 0.17033 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0131737 1.119 -0.284887 1.119 [
[ 0 0 0 0 ]
[ 1 .39793 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .00947 m
.64948 .38845 L
.02381 .26674 L
.97619 .00947 L
F
.498 1 0 r
.60014 .24607 m
.60014 .24607 .13034 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .00947 m
.64948 .38845 L
.02381 .26674 L
.97619 .00947 L
s
newpath
.60014 .24607 .13034 0 365.73 arc
s
0 0 m
1 0 L
1 .39793 L
0 .39793 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.00727497 0.331502 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.578905 1.83926 -0.151714 1.83926 [
[ 0 0 0 0 ]
[ 1 .78437 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.3181 .76569 m
.97619 .01868 L
.02381 .65384 L
.3181 .76569 L
F
.498 1 0 r
.28315 .62454 m
.28315 .62454 .11952 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.3181 .76569 m
.97619 .01868 L
.02381 .65384 L
.3181 .76569 L
s
newpath
.28315 .62454 .11952 0 365.73 arc
s
0 0 m
1 0 L
1 .78437 L
0 .78437 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.00727497 0.492674 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.182713 1.56004 -0.930853 1.56004 [
[ 0 0 0 0 ]
[ 1 .42453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .35187 m
.10338 .41442 L
.97619 .01011 L
.02381 .35187 L
F
.498 1 0 r
.10907 .3657 m
.10907 .3657 .04182 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .35187 m
.10338 .41442 L
.97619 .01011 L
.02381 .35187 L
s
newpath
.10907 .3657 .04182 0 365.73 arc
s
0 0 m
1 0 L
1 .42453 L
0 .42453 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.00727497 0.653846 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.077796 1.36701 -0.0983162 1.36701 [
[ 0 0 0 0 ]
[ 1 1.06515 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .0407 m
.02381 .02536 L
.05003 1.03979 L
.97619 .0407 L
F
.498 1 0 r
.32157 .32023 m
.32157 .32023 .29004 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .0407 m
.02381 .02536 L
.05003 1.03979 L
.97619 .0407 L
s
newpath
.32157 .32023 .29004 0 365.73 arc
s
0 0 m
1 0 L
1 1.06515 L
0 1.06515 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.00727497 0.815018 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.410955 2.76699 -0.597404 2.76699 [
[ 0 0 0 0 ]
[ 1 1.73331 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.11526 1.69204 m
.97619 .04127 L
.02381 .32802 L
.11526 1.69204 L
F
.498 1 0 r
.35362 .55643 m
.35362 .55643 .31379 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.11526 1.69204 m
.97619 .04127 L
.02381 .32802 L
.11526 1.69204 L
s
newpath
.35362 .55643 .31379 0 365.73 arc
s
0 0 m
1 0 L
1 1.73331 L
0 1.73331 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.00727497 0.97619 0.145846 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00451291 1.41659 -0.325188 1.41659 [
[ 0 0 0 0 ]
[ 1 .72916 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .7118 m
.44596 .01736 L
.97619 .09137 L
.02381 .7118 L
F
.498 1 0 r
.52842 .19119 m
.52842 .19119 .16077 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .7118 m
.44596 .01736 L
.97619 .09137 L
.02381 .7118 L
s
newpath
.52842 .19119 .16077 0 365.73 arc
s
0 0 m
1 0 L
1 .72916 L
0 .72916 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.159703 0.17033 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00878104 2.0761 -0.0840473 2.0761 [
[ 0 0 0 0 ]
[ 1 .94575 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .18568 m
.02381 .92323 L
.66305 .02252 L
.97619 .18568 L
F
.498 1 0 r
.70818 .20968 m
.70818 .20968 .14513 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .18568 m
.02381 .92323 L
.66305 .02252 L
.97619 .18568 L
s
newpath
.70818 .20968 .14513 0 365.73 arc
s
0 0 m
1 0 L
1 .94575 L
0 .94575 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.159703 0.331502 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-49.4234 68.5842 -33.1551 68.5842 [
[ 0 0 0 0 ]
[ 1 23.2951 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.77592 22.7405 m
.02381 15.2914 L
.97619 .55465 L
.77592 22.7405 L
F
.498 1 0 r
.43418 15.284 m
.43418 15.284 .40904 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.77592 22.7405 m
.02381 15.2914 L
.97619 .55465 L
.77592 22.7405 L
s
newpath
.43418 15.284 .40904 0 365.73 arc
s
0 0 m
1 0 L
1 23.2951 L
0 23.2951 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.159703 0.492674 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.082308 1.24368 -0.294286 1.24368 [
[ 0 0 0 0 ]
[ 1 .67965 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.89323 .01618 m
.02381 .53575 L
.97619 .66347 L
.89323 .01618 L
F
.498 1 0 r
.70919 .39491 m
.70919 .39491 .23069 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.89323 .01618 m
.02381 .53575 L
.97619 .66347 L
.89323 .01618 L
s
newpath
.70919 .39491 .23069 0 365.73 arc
s
0 0 m
1 0 L
1 .67965 L
0 .67965 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.159703 0.653846 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.17425 11.4659 -0.599975 11.4659 [
[ 0 0 0 0 ]
[ 1 4.08741 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .58039 m
.97619 3.99009 L
.66034 .09732 L
.02381 .58039 L
F
.498 1 0 r
.38943 .70343 m
.38943 .70343 .31904 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .58039 m
.97619 3.99009 L
.66034 .09732 L
.02381 .58039 L
s
newpath
.38943 .70343 .31904 0 365.73 arc
s
0 0 m
1 0 L
1 4.08741 L
0 4.08741 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.159703 0.815018 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.217808 1.67434 -0.351875 1.67434 [
[ 0 0 0 0 ]
[ 1 .62686 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .10087 m
.02381 .61194 L
.43437 .01493 L
.97619 .10087 L
F
.498 1 0 r
.50546 .18051 m
.50546 .18051 .1524 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .10087 m
.02381 .61194 L
.43437 .01493 L
.97619 .10087 L
s
newpath
.50546 .18051 .1524 0 365.73 arc
s
0 0 m
1 0 L
1 .62686 L
0 .62686 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.159703 0.97619 0.298274 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.4574 3.59195 -0.922594 3.59195 [
[ 0 0 0 0 ]
[ 1 1.85375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 1.80961 m
.94397 .91898 L
.97619 .04414 L
.02381 1.80961 L
F
.498 1 0 r
.76034 .83714 m
.76034 .83714 .18652 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 1.80961 m
.94397 .91898 L
.97619 .04414 L
.02381 1.80961 L
s
newpath
.76034 .83714 .18652 0 365.73 arc
s
0 0 m
1 0 L
1 1.85375 L
0 1.85375 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{564.125, 172.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008d0000[2000`400?l00000o`00003oo`3ooooo
0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo
003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooolT0?ooob<00000K`3oool20000
07d0oooo003o0?ooob@0oooo00<0000007N8V@1gR9T03P1gR9T50000000307oo00000000000000@0
00001P1gR9TT000004P0oooo1000001n0?ooo`00o`3ooolT0?ooo`030000001gR9T0MhRI00/0MhRI
0`00000<07oo008000009P1gR9T00`000000oooo0?ooo`130?ooo`@000000`1gR9T00`000000oooo
0?ooo`1l0?ooo`00o`3ooolT0?ooo`030000001gR9T0MhRI00T0MhRI0P00000A07oo008000008`1g
R9T00`000000oooo0?ooo`110?ooo`<000001P1gR9T00`000000oooo0?ooo`1m0?ooo`00o`3ooolT
0?ooo`030000001gR9T0MhRI00L0MhRI0P00000E07oo00800000801gR9T00`000000oooo0?ooo`0o
0?ooo`<000002@1gR9T00`000000oooo0?ooo`1m0?ooo`00o`3ooolT0?ooo`030000001gR9T0MhRI
00H0MhRI00<0000007oo001oo`005`1oo`000`000000MhRI07N8V@0L07N8V@030000003oool0oooo
03`0oooo1000000;07N8V@030000003oool0oooo07h0oooo002i0?ooo`030000003oool0oooo06L0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000Ool007oo000I07oo00030000001gR9T0MhRI01X0
MhRI00<000000?ooo`3oool0>P3oool3000000l0MhRI00<000000?ooo`3oool0OP3oool00;L0oooo
0P00001Z0?ooo`030000001gR9T0MhRI00@0MhRI00<0000007oo001oo`006`1oo`000`000000MhRI
07N8V@0H07N8V@030000003oool0oooo03P0oooo0`00000A07N8V@030000003oool0oooo07l0oooo
002f0?ooo`800000J`3oool00`000000MhRI07N8V@0307N8V@030000001oo`00Ool001d0Ool000<0
000007N8V@1gR9T05P1gR9T00`000000oooo0?ooo`0e0?ooo`@00000501gR9T00`000000oooo0?oo
o`1o0?ooo`00]03oool3000006`0oooo00<0000007N8V@1gR9T00P1gR9T00`000000Ool007oo000O
07oo00030000001gR9T0MhRI01D0MhRI00<000000?ooo`3oool0<P3oool6000001@0MhRI00<00000
0?ooo`3oool0@`3oool4000003T0oooo002c0?ooo`040000001gR9T0MhRI000006`0oooo00D00000
07N8V@1gR9T0MhRI0000000S07oo00030000001gR9T0MhRI01<0MhRI00<000000?ooo`3oool0<03o
ool4000000D0Ool00P00000B07N8V@030000003oool0oooo0480oooo00<0000007N8V@1gR9T02@00
000b0?ooo`00/@3oool200000080MhRI00<000000?ooo`3oool0J`3oool01@000000MhRI07N8V@1g
R9T0000002@0Ool000<0000007N8V@1gR9T04@1gR9T00`000000oooo0?ooo`0]0?ooo`D000002P1o
o`03000000h0MhRI00<000000?ooo`3oool0@`3oool3000000T0Ool01`00000[0?ooo`00/03oool0
1@000000MhRI07N8V@1gR9T0000006h0oooo00@0000007N8V@1gR9T000009@1oo`000`000000MhRI
07N8V@0@07N8V@030000003oool0oooo02/0oooo0`00000207N8V@030000001oo`00Ool000d0Ool0
0P00000<07N8V@030000003oool0oooo0480oooo0P00000=07oo008000000`1gR9T8000002<0oooo
002^0?ooo`8000000`1gR9T00`000000oooo0?ooo`1]0?ooo`030000001gR9T0000002L0Ool000<0
000007N8V@1gR9T03P1gR9T00`000000oooo0?ooo`0Z0?ooo`800000101gR9T00`000000Ool007oo
000@07oo00030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0@`3oool00`000000Ool007oo
000>07oo00030000001gR9T0MhRI00P0MhRI1`00000L0?ooo`00[@3oool00`000000MhRI07N8V@02
07N8V@030000003oool0oooo06h0oooo00<0000007N8V@0000009`1oo`000`000000MhRI07N8V@0=
07N8V@030000003oool0oooo02/0oooo00<0000007N8V@1gR9T00P1gR9T00`000000Ool007oo000B
07oo00030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0@P3oool00`000000Ool007oo000@
07oo00030000001gR9T0MhRI00h0MhRI1`00000E0?ooo`00Z`3oool2000000@0MhRI00<000000?oo
o`3oool0K`3oool00`000000MhRI0000000W07oo00030000001gR9T0MhRI00`0MhRI00<000000?oo
o`3oool0;03oool01@000000MhRI07N8V@1gR9T0000001D0Ool000<0000007N8V@1gR9T01P1gR9T0
0`000000oooo0?ooo`120?ooo`030000001oo`00Ool00180Ool000<0000007N8V@1gR9T0501gR9T4
00000140oooo002Z0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0L03oool00`00
0000MhRI0000000W07oo00030000001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0;@3oool01000
0000MhRI07N8V@00000G07oo00030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0@@3oool2
000001@0Ool000<0000007N8V@1gR9T05@1gR9T200000180oooo002X0?ooo`8000001@1gR9T00`00
0000oooo0?ooo`1a0?ooo`800000:@1oo`000`000000MhRI07N8V@0907N8V@030000003oool0oooo
02h0oooo00<0000007N8V@0000006@1oo`000`000000MhRI07N8V@0307N8V@030000003oool0oooo
0440oooo0P00000F07oo00030000001gR9T0MhRI01<0MhRI00<000000?ooo`3oool04P3oool00:L0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`1a0?ooo`800000:@1oo`000`000000
MhRI07N8V@0807N8V@030000003oool0oooo02l0oooo00<0000007N8V@0000006@1oo`000`000000
MhRI07N8V@0307N8V@030000003oool0oooo0440oooo00<0000007oo001oo`005@1oo`000`000000
MhRI07N8V@0A07N8V@8000005@3oool00:D0oooo0P00000707N8V@030000003oool0oooo07<0oooo
00<0000007oo001oo`009`1oo`000`000000MhRI07N8V@0707N8V@030000003oool0oooo0300oooo
0P00000K07oo00050000001gR9T0MhRI07N8V@000000A03oool00`000000Ool007oo000F07oo0003
0000001gR9T0MhRI00l0MhRI00<000000?ooo`3oool05@3oool00:@0oooo00<0000007N8V@1gR9T0
1P1gR9T00`000000oooo0?ooo`1R0?ooo`800000403oool00`000000Ool007oo000W07oo00030000
001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0<@3oool2000001/0Ool000@0000007N8V@1gR9T0
0000A03oool2000001P0Ool000<0000007N8V@1gR9T03@1gR9T2000001P0oooo002R0?ooo`800000
201gR9T00`000000oooo0?ooo`1P0?ooo`<000004P3oool00`000000Ool007oo000W07oo00030000
001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0<`3oool00`000000Ool007oo000I07oo00040000
001gR9T0MhRI000004@0oooo00<0000007oo001oo`00601oo`000`000000MhRI07N8V@0;07N8V@03
0000003oool0oooo01P0oooo001M0?ooo`800000@P3oool00`000000MhRI07N8V@0707N8V@030000
003oool0oooo05l0oooo0`00000D0?ooo`030000001oo`00Ool002L0Ool000<0000007N8V@1gR9T0
101gR9T00`000000oooo0?ooo`0d0?ooo`030000001oo`00Ool001T0Ool000<0000007N8V@000000
A03oool2000001X0Ool000<0000007N8V@1gR9T02@1gR9T2000001/0oooo001I0?ooo`D00000@@3o
ool2000000T0MhRI00<000000?ooo`3oool0G@3oool4000001H0oooo00<0000007oo001oo`009`1o
o`000`000000MhRI07N8V@0407N8V@030000003oool0oooo03@0oooo00<0000007oo001oo`006@1o
o`000`000000MhRI000000130?ooo`030000001gR9T0000001X0Ool000<0000007N8V@1gR9T0201g
R9T00`000000oooo0?ooo`0K0?ooo`00E@3oool4000000<0MhRI00<000000?ooo`3oool0?`3oool0
0`000000MhRI07N8V@0807N8V@030000003oool0oooo05/0oooo1@00000H0?ooo`030000001oo`00
Ool002L0Ool000<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0e0?ooo`030000001oo`00
Ool001T0Ool00P0000140?ooo`030000001gR9T0000001T0Ool00P00000807N8V@8000007P3oool0
0580oooo0`00000607N8V@030000003oool0oooo03h0oooo0P00000:07N8V@030000003oool0oooo
05X0oooo0P0000000`1gR9T000000000000J0?ooo`030000001oo`00Ool002L0Ool000<0000007N8
V@1gR9T00P1gR9T00`000000oooo0?ooo`0f0?ooo`030000001oo`00Ool001T0Ool00P0000130?oo
o`040000001gR9T0MhRI000001T0Ool000<0000007N8V@1gR9T01@1gR9T200000200oooo001>0?oo
o`@000002@1gR9T00`000000oooo0?ooo`0m0?ooo`030000001gR9T0MhRI00X0MhRI00<000000?oo
o`3oool0E`3oool30000000307N8V@000000000001`0oooo00<0000007oo001oo`009`1oo`001@00
0000MhRI07N8V@1gR9T0000003T0oooo00<0000007oo001oo`006@1oo`000`000000oooo0?ooo`12
0?ooo`040000001gR9T0MhRI000001T0Ool000<0000007N8V@1gR9T0101gR9T00`000000oooo0?oo
o`0P0?ooo`00BP3oool4000000`0MhRI00<000000?ooo`3oool0?03oool2000000`0MhRI00<00000
0?ooo`3oool0E@3oool300000080MhRI0P00000N0?ooo`8000009`1oo`001@000000MhRI07N8V@1g
R9T0000003X0oooo0P00000J07oo00030000003oool0oooo0440oooo00<0000007N8V@1gR9T00P1g
R9T00`000000Ool007oo000F07oo00030000001gR9T0MhRI0080MhRI0P00000S0?ooo`00AP3oool4
000000l0MhRI00<000000?ooo`3oool0?03oool00`000000MhRI07N8V@0;07N8V@030000003oool0
oooo05@0oooo0P00000307N8V@800000803oool2000002L0Ool000@0000007N8V@1gR9T00000>`3o
ool2000001T0Ool000<000000?ooo`3oool0@@3oool00`000000MhRI07N8V@0307N8V@030000001o
o`00Ool001H0Ool000D0000007N8V@1gR9T0MhRI0000000U0?ooo`00@`3oool300000180MhRI00<0
00000?ooo`3oool0>`3oool2000000d0MhRI00<000000?ooo`3oool0DP3oool300000080MhRI0`00
000R0?ooo`8000009`1oo`000`000000MhRI0000000l0?ooo`8000006@1oo`000`000000oooo0?oo
o`110?ooo`030000001gR9T0MhRI00@0MhRI00<0000007oo001oo`00501oo`000`000000MhRI07N8
V@02000002H0oooo000n0?ooo`D00000501gR9T00`000000oooo0?ooo`0k0?ooo`030000001gR9T0
MhRI00`0MhRI00<000000?ooo`3oool0D03oool3000000<0MhRI0P00000U0?ooo`8000009`1oo`02
000003d0oooo00<0000007N8V@0000005`1oo`000`000000oooo0?ooo`110?ooo`030000001gR9T0
MhRI00D0MhRI00<0000007oo001oo`004`1oo`0010000000MhRI07N8V@00000X0?ooo`00>`3oool4
00000080Ool01000000A07N8V@030000003oool0oooo03X0oooo0P00000>07N8V@030000003oool0
oooo04l0oooo0P00000407N8V@8000009`3oool00`000000MhRI0000000U07oo00800000?P3oool0
0`000000MhRI0000000G07oo00030000003oool0oooo0400oooo00<0000007N8V@1gR9T01`1gR9T0
0`000000Ool007oo000A07oo00040000001gR9T00000000002T0oooo000h0?ooo`@000002@1oo`00
0`000000MhRI07N8V@0=07N8V@030000003oool0oooo03X0oooo00<0000007N8V@1gR9T03@1gR9T0
0`000000oooo0?ooo`1=0?ooo`<00000101gR9T2000002T0oooo00<0000007N8V@0000009@1oo`00
0`000000oooo0?ooo`0m0?ooo`040000001gR9T0MhRI000001D0Ool000<000000?ooo`3oool0@@3o
ool00`000000MhRI07N8V@0807N8V@030000001oo`00Ool00100Ool00P00000[0?ooo`00=03oool6
000000`0Ool000<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`0j0?ooo`030000001gR9T0
MhRI00d0MhRI00<000000?ooo`3oool0B`3oool3000000D0MhRI0P00000[0?ooo`040000001gR9T0
MhRI000002<0Ool000<000000?ooo`3oool0?P3oool01@000000MhRI07N8V@1gR9T0000001<0Ool0
0P0000120?ooo`030000001gR9T0MhRI00X0MhRI00<0000007oo001oo`003P1oo`02000002`0oooo
000`0?ooo`@000000`1gR9T00`000000Ool007oo000=07oo00030000001gR9T0MhRI00X0MhRI00<0
00000?ooo`3oool0>03oool200000100MhRI00<000000?ooo`3oool0B@3oool2000000H0MhRI0P00
000]0?ooo`050000001gR9T0MhRI07N8V@0000008@1oo`0200000400oooo00<0000007N8V@1gR9T0
0P1gR9T00`000000Ool007oo000?07oo00800000@`3oool00`000000MhRI07N8V@0;07N8V@030000
001oo`00Ool000/0Ool00P00000^0?ooo`00;03oool4000000H0MhRI00<0000007oo001oo`003`1o
o`000`000000MhRI07N8V@0807N8V@030000003oool0oooo03P0oooo00<0000007N8V@1gR9T03`1g
R9T00`000000oooo0?ooo`170?ooo`<000001P1gR9T2000002l0oooo00<0000007N8V@1gR9T00P1g
R9T00`000000Ool007oo000M07oo00800000@@3oool00`000000MhRI07N8V@0307N8V@030000001o
o`00Ool000`0Ool00P0000000`1gR9T000000?ooo`110?ooo`030000001gR9T0MhRI00d0MhRI0P00
000907oo00<00000;`3oool002T0oooo0`00000:07N8V@030000001oo`00Ool00100Ool000<00000
07N8V@1gR9T01P1gR9T00`000000oooo0?ooo`0g0?ooo`8000004@1gR9T00`000000oooo0?ooo`15
0?ooo`<000001`1gR9T200000340oooo00<0000007N8V@1gR9T00`1gR9T00`000000Ool007oo000K
07oo00030000003oool0oooo0480oooo00<0000007N8V@1gR9T00`1gR9T3000000T0Ool00P000002
07N8V@030000003oool0oooo0400oooo00<0000007N8V@1gR9T0401gR9T:00000340oooo000U0?oo
o`@00000301gR9T00`000000Ool007oo000A07oo00030000001gR9T0MhRI00D0MhRI00<000000?oo
o`3oool0=`3oool00`000000MhRI07N8V@0@07N8V@030000003oool0oooo04<0oooo0`00000707N8
V@<00000<`3oool00`000000MhRI07N8V@0407N8V@030000001oo`00Ool001T0Ool00P0000140?oo
o`030000001gR9T0MhRI00H0MhRI2@00000307N8V@030000003oool0oooo0440oooo00<0000007N8
V@1gR9T05`1gR9T200000380oooo000Q0?ooo`@00000401gR9T00`000000Ool007oo000B07oo0003
0000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0=P3oool200000180MhRI00<000000?ooo`3o
ool0@P3oool2000000P0MhRI0P00000f0?ooo`030000001gR9T0MhRI00D0MhRI00<0000007oo001o
o`005`1oo`02000004D0oooo00<0000007N8V@1gR9T04P1gR9T00`000000oooo0?ooo`100?ooo`03
0000001gR9T0MhRI01L0MhRI00<000000?ooo`3oool0<P3oool001h0oooo0`00000D07N8V@030000
001oo`00Ool00180Ool000<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0f0?ooo`030000
001gR9T0MhRI0140MhRI00<000000?ooo`3oool0@03oool3000000P0MhRI0P00000h0?ooo`030000
001gR9T0MhRI00H0MhRI00<0000007oo001oo`005@1oo`02000004H0oooo00<0000007N8V@1gR9T0
4@1gR9T00`000000oooo0?ooo`110?ooo`030000001gR9T0MhRI01D0MhRI0P00000e0?ooo`006P3o
ool4000001L0MhRI00<0000007oo001oo`004P1oo`001@000000MhRI07N8V@1gR9T0000003L0oooo
0P00000C07N8V@030000003oool0oooo03h0oooo0`00000907N8V@800000>P3oool00`000000MhRI
07N8V@0707N8V@8000004`1oo`03000004L0oooo00<0000007N8V@1gR9T04@1gR9T00`000000oooo
0?ooo`100?ooo`030000001gR9T0MhRI01D0MhRI00<000000?ooo`3oool0=@3oool001H0oooo1000
000K07N8V@030000001oo`00Ool00180Ool000@0000007N8V@1gR9T00000=`3oool00`000000MhRI
07N8V@0C07N8V@030000003oool0oooo03`0oooo0P00000:07N8V@800000?03oool00`000000MhRI
07N8V@0907N8V@8000003`1oo`020000000307N8V@000000oooo04L0oooo00<0000007N8V@1gR9T0
401gR9T00`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI01@0MhRI0P00000h0?ooo`004P3o
ool4000001l0MhRI00<0000007oo001oo`004P1oo`0010000000MhRI07N8V@00000e0?ooo`800000
5@1gR9T00`000000oooo0?ooo`0j0?ooo`<000002P1gR9T2000003h0oooo00<0000007N8V@1gR9T0
2`1gR9T4000000L0Ool01000000207N8V@030000003oool0oooo04L0oooo00<0000007N8V@1gR9T0
401gR9T00`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI0180MhRI0P00000j0?ooo`00403o
ool300000280MhRI00<0000007oo001oo`004P1oo`000`000000MhRI0000000e0?ooo`030000001g
R9T0MhRI01@0MhRI00<000000?ooo`3oool0>03oool3000000/0MhRI0P0000100?ooo`030000001g
R9T0MhRI00l0MhRI1`00000507N8V@030000003oool0oooo04P0oooo00<0000007N8V@1gR9T03`1g
R9T00`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI0180MhRI00<000000?ooo`3oool0>P3o
ool001<0oooo1@00000M07N8V@030000001oo`00Ool00140Ool000<0000007N8V@000000=03oool2
000001H0MhRI00<000000?ooo`3oool0=`3oool2000000`0MhRI0P0000120?ooo`030000001gR9T0
MhRI01X0MhRI00<000000?ooo`3oool0B@3oool00`000000MhRI07N8V@0?07N8V@030000003oool0
oooo0400oooo00<0000007N8V@1gR9T0401gR9T2000003d0oooo000H0?ooo`D00000601gR9T00`00
0000Ool007oo000A07oo00800000=03oool00`000000MhRI07N8V@0E07N8V@030000003oool0oooo
03D0oooo0`00000<07N8V@800000A03oool00`000000MhRI07N8V@0I07N8V@030000003oool0oooo
04X0oooo00<0000007N8V@1gR9T03P1gR9T00`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI
0100MhRI00<000000?ooo`3oool0?@3oool001d0oooo1@00000C07N8V@030000001oo`00Ool00100
Ool00P00000c0?ooo`@000005@1gR9T00`000000oooo0?ooo`0b0?ooo`@00000301gR9T3000004H0
oooo00<0000007N8V@1gR9T0601gR9T00`000000oooo0?ooo`1;0?ooo`030000001gR9T0MhRI00h0
MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0?07N8V@800000@03oool00280oooo
1@00000?07N8V@030000001oo`00Ool000l0Ool000<000000?ooo`3oool0<@3oool2000000<0Ool0
1000000@07N8V@030000003oool0oooo0340oooo0`0000000`1oo`0000000000000:07N8V@800000
B@3oool00`000000MhRI07N8V@0G07N8V@030000003oool0oooo04`0oooo00<0000007N8V@1gR9T0
3@1gR9T00`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI00h0MhRI00<000000?ooo`3oool0
@03oool002L0oooo1P00000:07N8V@030000001oo`00Ool000d0Ool000<000000?ooo`3oool0<03o
ool3000000P0Ool000<0000007N8V@1gR9T0301gR9T00`000000oooo0?ooo`0`0?ooo`<00000101o
o`000`000000MhRI07N8V@0607N8V@800000B`3oool00`000000MhRI07N8V@0F07N8V@030000003o
ool0oooo04d0oooo00<0000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`0o0?ooo`030000001g
R9T0MhRI00d0MhRI0P0000130?ooo`00;@3oool5000000H0MhRI00<0000007oo001oo`002`1oo`02
00000340oooo0P00000;07oo00030000001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0;P3oool2
0000000307N8V@000000Ool000D0Ool000<0000007N8V@1gR9T00`1gR9T2000004d0oooo00<00000
07N8V@1gR9T05@1gR9T00`000000oooo0?ooo`1>0?ooo`030000001gR9T0MhRI00`0MhRI00<00000
0?ooo`3oool0?`3oool00`000000MhRI07N8V@0=07N8V@030000003oool0oooo04<0oooo000b0?oo
o`D000000P1gR9T00`000000Ool007oo000907oo00800000<03oool2000000h0Ool000<0000007N8
V@1gR9T02@1gR9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0000000H0Ool000@0000007N8
V@1gR9T0MhRI0P00001?0?ooo`030000001gR9T0MhRI01@0MhRI00<000000?ooo`3oool0C`3oool0
0`000000MhRI07N8V@0<07N8V@030000003oool0oooo03l0oooo00<0000007N8V@1gR9T02`1gR9T2
000004H0oooo000g0?ooo`L000001@1oo`0300000300oooo0P00000@07oo00030000001gR9T0MhRI
00L0MhRI00<000000?ooo`3oool0<P3oool2000000D0Ool000<0000007N8V@1gR9T00P00001A0?oo
o`030000001gR9T0MhRI01<0MhRI00<000000?ooo`3oool0D03oool00`000000MhRI07N8V@0;07N8
V@030000003oool0oooo03l0oooo00<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`160?oo
o`00?03oool70000000307N8V@000000oooo02h0oooo0P0000000`1gR9T0000007oo000?07oo0003
0000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0=03oool3000000<0Ool00`00001C0?ooo`03
0000001gR9T0MhRI0180MhRI00<000000?ooo`3oool0DP3oool00`000000MhRI07N8V@0:07N8V@03
0000003oool0oooo03l0oooo00<0000007N8V@1gR9T02@1gR9T2000004T0oooo00110?ooo`<00000
;`3oool010000000MhRI07N8V@00000B07oo00030000001gR9T0MhRI00@0MhRI00<000000?ooo`3o
ool0=`3oool5000005D0oooo00<0000007N8V@1gR9T04P1gR9T00`000000oooo0?ooo`1B0?ooo`03
0000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0907N8V@03
0000003oool0oooo04T0oooo001a0?ooo`8000000`1gR9T00`000000Ool007oo000@07oo00030000
001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0>@3oool2000005L0oooo00<0000007N8V@1gR9T0
4@1gR9T00`000000oooo0?ooo`1C0?ooo`030000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0
?P3oool00`000000MhRI07N8V@0807N8V@800000C03oool00700oooo00<0000007N8V@1gR9T00`1g
R9T00`000000Ool007oo000@07oo00030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0T`3o
ool00`000000MhRI07N8V@0@07N8V@030000003oool0oooo05@0oooo00<0000007N8V@1gR9T0201g
R9T00`000000oooo0?ooo`0o0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0C03o
ool006h0oooo0P00000607N8V@030000001oo`00Ool00100Ool000D0000007N8V@1gR9T0MhRI0000
002G0?ooo`030000001gR9T0MhRI00h0MhRI00<000000?ooo`3oool0E@3oool00`000000MhRI07N8
V@0707N8V@030000003oool0oooo03l0oooo00<0000007N8V@1gR9T01P1gR9T2000004l0oooo001]
0?ooo`030000001gR9T0MhRI00H0MhRI00<0000007oo001oo`00401oo`001@000000MhRI07N8V@1g
R9T0000009L0oooo00<0000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`1F0?ooo`030000001g
R9T0MhRI00L0MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0507N8V@030000003o
ool0oooo04l0oooo001[0?ooo`8000002@1gR9T00`000000Ool007oo000@07oo00040000001gR9T0
MhRI000009P0oooo00<0000007N8V@1gR9T0301gR9T00`000000oooo0?ooo`1G0?ooo`030000001g
R9T0MhRI00H0MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0407N8V@800000DP3o
ool006X0oooo0P00000:07N8V@030000001oo`00Ool00100Ool000<0000007N8V@000000V@3oool0
0`000000MhRI07N8V@0;07N8V@030000003oool0oooo05P0oooo00<0000007N8V@1gR9T01P1gR9T0
0`000000oooo0?ooo`0n0?ooo`030000001gR9T0MhRI00<0MhRI0P00001D0?ooo`00K03oool30000
00L0MhRI00<0000007oo001oo`00401oo`02000009X0oooo00<0000007N8V@1gR9T02P1gR9T00`00
0000oooo0?ooo`1I0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0?`3oool00`00
0000MhRI07N8V@0207N8V@030000003oool0oooo05@0oooo001_0?ooo`8000001P1gR9T00`000000
Ool007oo000>07oo00800000V`3oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo05X0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0n0?ooo`040000001gR9T0MhRI07N8
V@800000E`3oool00740oooo0`00000307N8V@030000001oo`00Ool000h0Ool000<000000?ooo`3o
ool0VP3oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo05/0oooo00<0000007N8V@1g
R9T0101gR9T00`000000oooo0?ooo`0n0?ooo`050000001gR9T0MhRI07N8V@000000F@3oool007@0
oooo0`0000000`1gR9T0000007oo000<07oo00800000W@3oool00`000000MhRI07N8V@0707N8V@03
0000003oool0oooo05`0oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0n0?ooo`04
0000001gR9T00000000005X0oooo001g0?ooo`@000002P1oo`02000009h0oooo00<0000007N8V@1g
R9T01P1gR9T00`000000oooo0?ooo`1M0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3o
ool0?P3oool00`000000MhRI0000001L0?ooo`00NP3oool3000000H0Ool00P0000000`1gR9T00000
0?ooo`2M0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0GP3oool00`000000MhRI
07N8V@0307N8V@030000003oool0oooo03h0oooo0P00001M0?ooo`00O@3oool600000080MhRI00<0
00000?ooo`3oool0W@3oool00`000000MhRI07N8V@0407N8V@030000003oool0oooo05l0oooo00<0
000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05d0oooo001o
0?ooo`<000000P1gR9T00`000000oooo0?ooo`2N0?ooo`030000001gR9T0MhRI00@0MhRI00<00000
0?ooo`3oool0H03oool01@000000MhRI07N8V@1gR9T000000:00oooo00220?ooo`800000X@3oool0
0`000000MhRI07N8V@0307N8V@030000003oool0oooo0640oooo00@0000007N8V@1gR9T00000X@3o
ool00?l0oooo9P3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo0680oooo00@00000
07N8V@1gR9T00000X@3oool00?l0oooo9P3oool01@000000MhRI07N8V@1gR9T0000006D0oooo00<0
000007N8V@000000XP3oool00?l0oooo9P3oool010000000MhRI07N8V@00001V0?ooo`030000001g
R9T000000:80oooo003o0?ooobH0oooo00<0000007N8V@000000I`3oool200000:<0oooo003o0?oo
obH0oooo0P00001X0?ooo`800000X`3oool00?l0oooo9P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0:80oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo
0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo
003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0
oooo=P3oool00?l0ooooo`3ooolf0?ooo`00A03oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0R0?ooo`00@`3oool0
10000000MhRI00000000001<0?ooo`030000003oool0oooo0;80oooo0P0000340?ooo`800000903o
ool004<0oooo00@0000007N8V@1gR9T0MhRI0P00001:0?ooo`030000003oool0oooo0;00oooo0P00
00000`1gR9T000000?ooo`330?ooo`800000903oool00480oooo00@0000007N8V@1gR9T0MhRI1`00
00160?ooo`030000003oool0oooo0:l0oooo00D0000007N8V@1gR9T0MhRI000000330?ooo`030000
001gR9T0000002@0oooo00110?ooo`030000001gR9T0MhRI008000001@1oo`04000004@0oooo00<0
00000?ooo`3oool0[P3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo0<40oooo00<0
000007N8V@000000903oool00400oooo00@0000007N8V@00000000002@1oo`03000004<0oooo00<0
00000?ooo`3oool0[03oool4000000<0MhRI00<000000?ooo`3oool0`03oool010000000MhRI07N8
V@00000T0?ooo`00@03oool2000000d0Ool00P0000120?ooo`030000003oool0oooo0:/0oooo00<0
000007oo001oo`000P1oo`020000000307N8V@000000oooo0<40oooo00@0000007N8V@1gR9T00000
903oool003l0oooo00<0000007oo001oo`003`1oo`0200000400oooo00<000000?ooo`3oool0ZP3o
ool00`000000Ool007oo000507oo00<00000`03oool01@000000MhRI07N8V@1gR9T0000002@0oooo
000n0?ooo`8000004P1oo`03000003h0oooo00<000000?ooo`3oool0Z03oool2000000T0Ool00P00
00300?ooo`050000001gR9T0MhRI07N8V@000000903oool003h0oooo00<0000007oo001oo`004P1o
o`0010000000MhRI00000000000k0?ooo`800000Z@3oool00`000000MhRI0000000:07oo00030000
003oool0oooo0;d0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0R0?ooo`00?@3o
ool00`000000Ool007oo000C07oo00040000001gR9T0MhRI07N8V@800000>@3oool2000007P0oooo
00<000000?ooo`3oool0;P3oool2000000/0Ool000<000000?ooo`3oool0_@3oool00`000000MhRI
07N8V@0207N8V@030000003oool0oooo0280oooo000l0?ooo`8000005P1oo`000`000000MhRI07N8
V@0207N8V@800000=`3oool2000007H0oooo0`00000a0?ooo`030000001oo`00Ool000T0Ool000<0
00000?ooo`3oool0_03oool00`000000MhRI07N8V@0307N8V@030000003oool0oooo0280oooo000l
0?ooo`8000005P1oo`000`000000MhRI07N8V@0407N8V@800000=@3oool2000007@0oooo0P000002
07N8V@030000003oool0oooo02l0oooo00<0000007oo001oo`002@1oo`000`000000oooo0?ooo`1>
0?ooo`@00000JP3oool00`000000MhRI07N8V@0307N8V@030000003oool0oooo0280oooo000k0?oo
o`8000005`1oo`000`000000MhRI07N8V@0607N8V@800000<`3oool2000007<0oooo00<0000007N8
V@1gR9T00P1gR9T00`000000oooo0?ooo`0_0?ooo`030000001oo`00Ool000T0Ool000<000000?oo
o`3oool0C@3oool00`000000MhRI07N8V@0207N8V@H00000H`3oool00`000000MhRI07N8V@0407N8
V@030000003oool0oooo0280oooo000j0?ooo`030000001gR9T0000001L0Ool000<0000007N8V@1g
R9T01P1gR9T00`000000oooo0?ooo`0b0?ooo`800000L@3oool2000000H0MhRI00<000000?ooo`3o
ool0;P3oool2000000T0Ool00P00001?0?ooo`030000001gR9T0MhRI00800000101oo`09000005/0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0R0?ooo`00>@3oool010000000MhRI
07N8V@00000G07oo00030000001gR9T0MhRI00@0MhRI0P00000e0?ooo`800000K`3oool2000000P0
MhRI00<000000?ooo`3oool0;`3oool2000000L0Ool000<0000007N8V@000000CP3oool010000000
MhRI00000000000907oo00800000101gR9T6000005D0oooo00<0000007N8V@1gR9T01@1gR9T00`00
0000oooo0?ooo`0R0?ooo`00>@3oool010000000MhRI07N8V@00000G07oo00030000001gR9T0MhRI
00<0MhRI00<000000?ooo`3oool0=@3oool2000006h0oooo00<0000007N8V@1gR9T0201gR9T00`00
0000oooo0?ooo`0_0?ooo`030000001gR9T0000000D0Ool000@0000007N8V@1gR9T00000C@3oool3
000000d0Ool00P00000807N8V@H00000CP3oool00`000000MhRI07N8V@0607N8V@030000003oool0
oooo0280oooo000h0?ooo`050000001gR9T0MhRI07N8V@0000005`1oo`000`000000MhRI07N8V@02
07N8V@030000003oool0oooo03H0oooo0P00001/0?ooo`8000002`1gR9T00`000000oooo0?ooo`0_
0?ooo`030000001gR9T0MhRI00D000000`1gR9T00`000000oooo0?ooo`1;0?ooo`030000001oo`00
Ool000l0Ool000<0000007N8V@1gR9T02`1gR9T7000004L0oooo00<0000007N8V@1gR9T01P1gR9T0
0`000000oooo0?ooo`0R0?ooo`00=`3oool00`000000MhRI07N8V@0207N8V@030000001oo`00Ool0
01D0Ool000<0000007N8V@1gR9T00P00000i0?ooo`800000JP3oool2000000d0MhRI00<000000?oo
o`3oool0;`3oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo04X0oooo00<0000007oo
001oo`004@1oo`000`000000MhRI07N8V@0A07N8V@H00000@03oool00`000000MhRI07N8V@0607N8
V@030000003oool0oooo02<0oooo000g0?ooo`030000001gR9T0MhRI00<0MhRI00<0000007oo001o
o`004`1oo`0010000000MhRI07N8V@00000k0?ooo`800000J@3oool00`000000MhRI07N8V@0=07N8
V@030000003oool0oooo0300oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`180?oo
o`030000001oo`00Ool00180Ool000<0000007N8V@1gR9T05`1gR9T4000003`0oooo00<0000007N8
V@1gR9T01P1gR9T00`000000oooo0?ooo`0S0?ooo`00=P3oool00`000000MhRI07N8V@0407N8V@03
0000001oo`00Ool001<0Ool000<0000007N8V@000000?03oool2000006L0oooo0P00000@07N8V@03
0000003oool0oooo0300oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`180?ooo`03
0000001oo`00Ool001<0Ool000<0000007N8V@1gR9T05`1gR9T2000003`0oooo00<0000007N8V@1g
R9T01`1gR9T00`000000oooo0?ooo`0S0?ooo`00=@3oool00`000000MhRI07N8V@0607N8V@030000
001oo`00Ool00140Ool000<0000007N8V@000000?@3oool2000006H0oooo00<0000007N8V@1gR9T0
401gR9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0
A`3oool2000001D0Ool000<0000007N8V@1gR9T05@1gR9T2000003h0oooo00<0000007N8V@1gR9T0
1`1gR9T00`000000oooo0?ooo`0S0?ooo`00=@3oool00`000000MhRI07N8V@0607N8V@030000001o
o`00Ool00140Ool00P00000n0?ooo`800000I03oool20000000307N8V@000000000000@000003@1g
R9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0AP3o
ool2000001L0Ool000<0000007N8V@1gR9T04P1gR9T2000003l0oooo00<0000007N8V@1gR9T0201g
R9T00`000000oooo0?ooo`0S0?ooo`00=03oool00`000000MhRI07N8V@0807N8V@030000001oo`00
Ool000l0Ool000<000000?ooo`3oool0?P3oool200000680oooo1@00000607oo00@000002@1gR9T0
0`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0AP3oool2
000001L0Ool000<0000007N8V@1gR9T0401gR9T200000440oooo00<0000007N8V@1gR9T0201gR9T0
0`000000oooo0?ooo`0S0?ooo`00<`3oool00`000000MhRI07N8V@0:07N8V@030000001oo`00Ool0
00d0Ool000<000000?ooo`3oool0?`3oool200000640oooo0P00000>07oo008000001`1gR9T00`00
0000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0A@3oool00`00
0000MhRI0000000H07oo00030000001gR9T0MhRI00d0MhRI0P0000120?ooo`030000001gR9T0MhRI
00T0MhRI00<000000?ooo`3oool08`3oool00380oooo00<0000007N8V@1gR9T0301gR9T00`000000
Ool007oo000:07oo00800000@@3oool00`000000MhRI0000001O0?ooo`8000004P1oo`000`000000
MhRI07N8V@0407N8V@030000003oool0oooo0300oooo00<0000007N8V@1gR9T01`1gR9T00`000000
oooo0?ooo`140?ooo`040000001gR9T0MhRI000001P0Ool000<0000007N8V@1gR9T02`1gR9T20000
04<0oooo00<0000007N8V@0000001@00000507N8V@030000003oool0oooo02<0oooo000b0?ooo`03
0000001gR9T0MhRI00d0MhRI0P00000807oo00<00000@P3oool00`000000MhRI0000001M0?ooo`<0
0000501oo`02000000@0MhRI00<000000?ooo`3oool0<@3oool00`000000MhRI07N8V@0607N8V@03
0000003oool0oooo04@0oooo00@0000007N8V@1gR9T00000601oo`000`000000MhRI07N8V@0:07N8
V@030000003oool0oooo04<0oooo0P00000607oo008000000`1gR9T00`000000oooo0?ooo`0S0?oo
o`00<@3oool00`000000MhRI07N8V@0@07N8V@T00000A03oool00`000000MhRI0000001L0?ooo`80
0000601oo`001@000000MhRI07N8V@1gR9T0000003<0oooo00<0000007N8V@1gR9T01P1gR9T00`00
0000oooo0?ooo`130?ooo`050000001gR9T0MhRI07N8V@0000005`1oo`02000000X0MhRI0P000015
0?ooo`8000002@1oo`0010000000MhRI07N8V@00000U0?ooo`00<03oool00`000000MhRI07N8V@0H
07N8V@030000003oool0oooo04<0oooo00<0000007N8V@000000FP3oool2000001/0Ool000@00000
07N8V@1gR9T00000<`3oool00`000000MhRI07N8V@0607N8V@030000003oool0oooo0480oooo00<0
000007N8V@1gR9T00P1gR9T00`000000Ool007oo000E07oo00030000001gR9T0MhRI00L0MhRI0P00
00170?ooo`030000001oo`00Ool000T0Ool000<0000007N8V@0000009@3oool00300oooo00<00000
07N8V@1gR9T05P1gR9T2000004H0oooo00<0000007N8V@000000F03oool20000000307N8V@000000
Ool001/0Ool000@0000007N8V@1gR9T00000<`3oool00`000000MhRI07N8V@0507N8V@030000003o
ool0oooo0480oooo00<0000007N8V@1gR9T00P1gR9T00`000000Ool007oo000E07oo00030000001g
R9T0MhRI00D0MhRI0P0000180?ooo`030000001oo`00Ool000X0Ool000<0000007N8V@0000009@3o
ool002l0oooo00<0000007N8V@1gR9T05P1gR9T00`000000oooo0?ooo`160?ooo`030000001gR9T0
000005L0oooo00@0000007N8V@1gR9T000007P1oo`000`000000MhRI0000000c0?ooo`030000001g
R9T0MhRI00D0MhRI00<000000?ooo`3oool0@@3oool00`000000MhRI07N8V@0307N8V@030000001o
o`00Ool001D0Ool000<0000007N8V@1gR9T00`1gR9T2000004X0oooo00<0000007oo001oo`002`1o
o`02000002D0oooo000^0?ooo`030000001gR9T0MhRI01H0MhRI00<000000?ooo`3oool0A`3oool0
0`000000MhRI0000001E0?ooo`8000000P1gR9T00`000000Ool007oo000M07oo00030000001gR9T0
000003<0oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`0o0?ooo`030000001gR9T0
MhRI00@0MhRI00<0000007oo001oo`005@1oo`0010000000MhRI07N8V@1gR9T2000004/0oooo00<0
000007oo001oo`00301oo`02000002D0oooo000^0?ooo`030000001gR9T0MhRI01D0MhRI00<00000
0?ooo`3oool0B03oool00`000000MhRI0000001C0?ooo`8000000`1gR9T00`000000Ool007oo000O
07oo00800000<`3oool00`000000MhRI07N8V@0607N8V@030000003oool0oooo03l0oooo00<00000
07N8V@1gR9T01@1gR9T00`000000Ool007oo000C07oo00030000001gR9T0MhRI00800000C@3oool0
0`000000Ool007oo000=07oo00030000003oool0oooo02<0oooo000]0?ooo`030000001gR9T0MhRI
01@0MhRI0P00001;0?ooo`030000001gR9T000000580oooo00<0000007N8V@1gR9T00`1gR9T00`00
0000Ool007oo000O07oo00800000=03oool00`000000MhRI07N8V@0507N8V@030000003oool0oooo
03h0oooo00<0000007N8V@1gR9T01`1gR9T00`000000Ool007oo000A07oo00040000001gR9T0MhRI
000004h0oooo0P00000?07oo00030000003oool0oooo02<0oooo000/0?ooo`030000001gR9T0MhRI
01@0MhRI00<000000?ooo`3oool0B`3oool00`000000MhRI0000001@0?ooo`8000001@1gR9T00`00
0000Ool007oo000Q07oo00030000003oool0oooo0380oooo00<0000007N8V@1gR9T01@1gR9T00`00
0000oooo0?ooo`0m0?ooo`030000001gR9T0MhRI00T0MhRI00<0000007oo001oo`003`1oo`001000
0000MhRI00000000001?0?ooo`8000003`1oo`000`000000oooo0?ooo`0S0?ooo`00:`3oool00`00
0000MhRI07N8V@0D07N8V@030000003oool0oooo04`0oooo00<0000007N8V@000000CP3oool20000
00L0MhRI00<0000007oo001oo`008@1oo`000`000000oooo0?ooo`0b0?ooo`030000001gR9T0MhRI
00D0MhRI00<000000?ooo`3oool0?@3oool00`000000MhRI07N8V@0:07N8V@030000001oo`00Ool0
00h0Ool00P00001@0?ooo`030000001gR9T0000000h0Ool00P00000U0?ooo`00:`3oool00`000000
MhRI07N8V@0B07N8V@800000C`3oool00`000000MhRI0000001=0?ooo`030000001gR9T0MhRI00L0
MhRI00<0000007oo001oo`008@1oo`000`000000oooo0?ooo`0b0?ooo`030000001gR9T0MhRI00D0
MhRI00<000000?ooo`3oool0?03oool00`000000MhRI07N8V@0<07N8V@030000001oo`00Ool000/0
Ool00P00001B0?ooo`040000001gR9T0MhRI000000d0Ool00P00000U0?ooo`00:P3oool00`000000
MhRI07N8V@0B07N8V@030000003oool0oooo04l0oooo0P00001<0?ooo`8000002@1gR9T00`000000
Ool007oo000S07oo00030000003oool0oooo0380oooo00<0000007N8V@1gR9T0101gR9T00`000000
oooo0?ooo`0k0?ooo`030000001gR9T0MhRI00h0MhRI0P00000807oo00<00000D`3oool01@000000
MhRI07N8V@1gR9T0000000`0Ool00P00000V0?ooo`00:@3oool00`000000MhRI07N8V@0B07N8V@03
0000003oool0oooo0500oooo0P00001:0?ooo`8000002`1gR9T00`000000Ool007oo000S07oo0003
0000003oool0oooo0380oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0j0?ooo`03
0000001gR9T0MhRI0140MhRI2@00001D0?ooo`030000001gR9T0MhRI00<0MhRI00<0000007oo001o
o`00201oo`02000002L0oooo000Y0?ooo`030000001gR9T0MhRI0140MhRI00<000000?ooo`3oool0
D@3oool2000004T0oooo00<0000007N8V@1gR9T02`1gR9T00`000000Ool007oo000S07oo00030000
003oool0oooo0380oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0j0?ooo`030000
001gR9T0MhRI01H0MhRI0P00001F0?ooo`030000001gR9T0MhRI00@0MhRI0P00000707oo00800000
:03oool002P0oooo00<0000007N8V@1gR9T0401gR9T2000005@0oooo0P0000170?ooo`8000003P1g
R9T00`000000Ool007oo000S07oo00030000003oool0oooo03<0oooo00<0000007N8V@1gR9T00`1g
R9T00`000000oooo0?ooo`0i0?ooo`030000001gR9T0MhRI01H0MhRI00<000000?ooo`3oool0E@3o
ool00`000000MhRI07N8V@0707N8V@8000000`1oo`03000002T0oooo000W0?ooo`030000001gR9T0
MhRI0100MhRI00<000000?ooo`3oool0D`3oool00`000000MhRI000000150?ooo`800000401gR9T0
0`000000Ool007oo000S07oo00030000003oool0oooo03<0oooo00<0000007N8V@1gR9T00`1gR9T0
0`000000oooo0?ooo`0h0?ooo`030000001gR9T0MhRI01D0MhRI0P00001H0?ooo`030000001gR9T0
MhRI00T0MhRI0`0000000`1gR9T000000?ooo`0Y0?ooo`009P3oool00`000000MhRI07N8V@0@07N8
V@030000003oool0oooo05@0oooo00<0000007N8V@000000A03oool00`000000MhRI07N8V@0@07N8
V@030000001oo`00Ool002<0Ool000<000000?ooo`3oool0<`3oool00`000000MhRI07N8V@0307N8
V@030000003oool0oooo03P0oooo00<0000007N8V@1gR9T04`1gR9T2000005T0oooo00<0000007N8
V@1gR9T03@1gR9T00`000000oooo0?ooo`0Y0?ooo`009P3oool00`000000MhRI07N8V@0?07N8V@03
0000003oool0oooo05D0oooo00<0000007N8V@000000@P3oool2000001<0MhRI00<0000007oo001o
o`008`1oo`000`000000oooo0?ooo`0c0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3o
ool0=`3oool00`000000MhRI07N8V@0B07N8V@800000F`3oool00`000000MhRI07N8V@0<07N8V@03
0000003oool0oooo02X0oooo000U0?ooo`030000001gR9T0MhRI00h0MhRI0P00001H0?ooo`030000
001gR9T000000440oooo00<0000007N8V@1gR9T04`1gR9T00`000000Ool007oo000S07oo00030000
003oool0oooo03@0oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0e0?ooo`030000
001gR9T0MhRI0140MhRI0P00001L0?ooo`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0
:`3oool002@0oooo00<0000007N8V@1gR9T03P1gR9T00`000000oooo0?ooo`1H0?ooo`030000001g
R9T0000003l0oooo0P00000F07N8V@030000001oo`00Ool002<0Ool00P00000e0?ooo`030000001g
R9T0MhRI00<0MhRI00<000000?ooo`3oool0=@3oool00`000000MhRI07N8V@0?07N8V@800000GP3o
ool00`000000MhRI07N8V@0;07N8V@030000003oool0oooo02`0oooo000T0?ooo`030000001gR9T0
MhRI00d0MhRI00<000000?ooo`3oool0F@3oool00`000000MhRI0000000m0?ooo`8000006@1gR9T0
0`000000Ool007oo000Q07oo00030000001gR9T0000003D0oooo00<0000007N8V@1gR9T00`1gR9T0
0`000000oooo0?ooo`0d0?ooo`030000001gR9T0MhRI00h0MhRI0P00001O0?ooo`030000001gR9T0
MhRI00/0MhRI00<000000?ooo`3oool0;@3oool002<0oooo00<0000007N8V@1gR9T0301gR9T20000
05`0oooo0`00000l0?ooo`030000001gR9T0MhRI01T0MhRI00<0000007oo001oo`008@1oo`000`00
0000MhRI0000000f0?ooo`030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0<`3oool00`00
0000MhRI07N8V@0>07N8V@030000003oool0oooo05l0oooo00<0000007N8V@1gR9T02P1gR9T00`00
0000oooo0?ooo`0^0?ooo`008P3oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo05`0
oooo00<0000007oo00000000>P3oool2000001`0MhRI00<0000007oo001oo`008@1oo`000`000000
MhRI0000000f0?ooo`030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0<`3oool00`000000
MhRI07N8V@0<07N8V@800000H@3oool00`000000MhRI07N8V@0:07N8V@030000003oool0oooo02l0
oooo000R0?ooo`030000001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0G@3oool010000000Ool0
00000000000g0?ooo`8000007`1gR9T00`000000Ool007oo000O07oo00040000001gR9T0MhRI0000
03H0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0b0?ooo`030000001gR9T0MhRI
00/0MhRI0P00001S0?ooo`030000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0<03oool00240
oooo00<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`1N0?ooo`<00000=`3oool00`000000
MhRI07N8V@0O07N8V@030000001oo`00Ool001l0Ool000@0000007N8V@1gR9T00000=P3oool00`00
0000MhRI07N8V@0207N8V@030000003oool0oooo0340oooo00<0000007N8V@1gR9T02P1gR9T20000
06@0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0a0?ooo`00803oool00`000000
MhRI07N8V@0:07N8V@800000H@3oool00`000000MhRI0000000e0?ooo`8000008`1gR9T00`000000
Ool007oo000M07oo00050000001gR9T0MhRI07N8V@000000=`3oool01@000000MhRI07N8V@1gR9T0
000003<0oooo00<0000007N8V@1gR9T0201gR9T2000006D0oooo00<0000007N8V@1gR9T02@1gR9T0
0`000000oooo0?ooo`0b0?ooo`007`3oool00`000000MhRI07N8V@0:07N8V@030000003oool0oooo
0640oooo00<0000007N8V@000000<`3oool2000002H0MhRI00<0000007oo001oo`00701oo`000`00
0000MhRI07N8V@0207N8V@030000003oool0oooo03@0oooo00D0000007N8V@1gR9T0MhRI0000000b
0?ooo`030000001gR9T0MhRI00L0MhRI0P00001W0?ooo`030000001gR9T0MhRI00P0MhRI00<00000
0?ooo`3oool0<`3oool001l0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`1R0?oo
o`030000001gR9T000000380oooo1000000U07N8V@030000001oo`00Ool001/0Ool000<0000007N8
V@1gR9T00`1gR9T00`000000oooo0?ooo`0d0?ooo`050000001gR9T0MhRI07N8V@000000<@3oool0
0`000000MhRI07N8V@0607N8V@800000J03oool00`000000MhRI07N8V@0807N8V@030000003oool0
oooo03@0oooo000N0?ooo`030000001gR9T0MhRI00P0MhRI0P00001U0?ooo`030000001gR9T00000
03H0oooo2000000N07N8V@030000001oo`00Ool001T0Ool000<0000007N8V@1gR9T0101gR9T00`00
0000oooo0?ooo`0d0?ooo`050000001gR9T0MhRI07N8V@000000<@3oool00`000000MhRI07N8V@05
07N8V@030000003oool0oooo06P0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0e
0?ooo`007@3oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo06D0oooo00<0000007N8
V@000000?P3oool8000001L0MhRI00<0000007oo001oo`005`1oo`000`000000MhRI07N8V@0507N8
V@030000003oool0oooo03D0oooo00@0000007N8V@1gR9T00000<03oool00`000000MhRI07N8V@04
07N8V@800000JP3oool00`000000MhRI07N8V@0607N8V@800000>03oool001d0oooo00<0000007N8
V@1gR9T01`1gR9T00`000000oooo0?ooo`1W0?ooo`800000AP3oool800000100MhRI00<0000007oo
001oo`00501oo`02000000P0MhRI00<000000?ooo`3oool0=@3oool01@000000MhRI07N8V@1gR9T0
000002h0oooo00<0000007N8V@1gR9T00`1gR9T2000006`0oooo00<0000007N8V@1gR9T01@1gR9T0
0`000000oooo0?ooo`0h0?ooo`00703oool00`000000MhRI07N8V@0707N8V@030000003oool0oooo
06P0oooo0P00001>0?ooo`P000002@1gR9T00`000000Ool007oo000B07oo00030000001gR9T0MhRI
00P0MhRI00<000000?ooo`3oool0=@3oool01@000000MhRI07N8V@1gR9T0000002h0oooo00@00000
07N8V@1gR9T0MhRI0P00001]0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0>@3o
ool001/0oooo00<0000007N8V@1gR9T01P1gR9T2000006/0oooo0P00001F0?ooo`L000000`1gR9T3
00000100Ool000<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0f0?ooo`040000001gR9T0
MhRI000002d0oooo00<0000007N8V@1gR9T00P00001_0?ooo`030000001gR9T0MhRI00@0MhRI00<0
00000?ooo`3oool0>P3oool001/0oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`1[
0?ooo`800000G@3oool8000000X0Ool01000000<07N8V@030000003oool0oooo03H0oooo00@00000
07N8V@1gR9T00000;03oool010000000MhRI00000000001`0?ooo`030000001gR9T0MhRI00@0MhRI
00<000000?ooo`3oool0>`3oool001X0oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?oo
o`1/0?ooo`800000I@3oool:00000140MhRI00<000000?ooo`3oool0=@3oool010000000MhRI07N8
V@00000/0?ooo`800000LP3oool00`000000MhRI07N8V@0307N8V@030000003oool0oooo03`0oooo
000I0?ooo`030000001gR9T0MhRI00@0MhRI0P00001_0?ooo`800000K@3oool8000000/0MhRI00<0
00000?ooo`3oool0=@3oool010000000MhRI07N8V@00000[0?ooo`030000003oool0oooo0740oooo
00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0m0?ooo`00603oool00`000000MhRI07N8
V@0407N8V@030000003oool0oooo06l0oooo0P00001e0?ooo`P000000`1gR9T00`000000oooo0?oo
o`0f0?ooo`030000001gR9T0000009h0oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?oo
o`0n0?ooo`00603oool00`000000MhRI07N8V@0307N8V@030000003oool0oooo0700oooo0P00001m
0?ooo`@00000>03oool00`000000MhRI0000002N0?ooo`030000001gR9T0MhRI0080MhRI00<00000
0?ooo`3oool0?`3oool001L0oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`1a0?oo
o`800000^@3oool00`000000MhRI0000002M0?ooo`030000001gR9T0MhRI0080MhRI00<000000?oo
o`3oool0@03oool001H0oooo00<0000007N8V@1gR9T00P1gR9T2000007@0oooo0P00002j0?ooo`80
0000W@3oool01@000000MhRI07N8V@1gR9T0000004<0oooo000F0?ooo`050000001gR9T0MhRI07N8
V@000000MP3oool200000;X0oooo0P00002L0?ooo`050000001gR9T0MhRI07N8V@000000A03oool0
01D0oooo00D0000007N8V@1gR9T0MhRI0000001g0?ooo`800000^P3oool2000009`0oooo00@00000
07N8V@1gR9T00000A@3oool001@0oooo00D0000007N8V@1gR9T0MhRI0000001i0?ooo`030000003o
ool0oooo0;P0oooo00<0000007N8V@000000VP3oool010000000MhRI07N8V@0000160?ooo`00503o
ool010000000MhRI00000000001j0?ooo`030000003oool0oooo0;T0oooo0P00002J0?ooo`030000
001gR9T0000004L0oooo000C0?ooo`030000001gR9T0000007`0oooo00<000000?ooo`3oool0^@3o
ool2000009T0oooo00<0000007N8V@000000B03oool00180oooo00<0000007N8V@000000O@3oool0
0`000000oooo0?ooo`2i0?ooo`800000V@3oool2000004T0oooo000A0?ooo`<00000OP3oool00`00
0000oooo0?ooo`2i0?ooo`800000V03oool2000004X0oooo000A0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo04T0
oooo000@0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo04X0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf
0?ooo`00o`3ooooo0?ooocH0oooo003o0?ooool0oooo=P3oool00?l0ooooo`3ooolf0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 563.125}, {171.375, 0}} -> {-0.162675, -0.045842, \
0.0112326, 0.0112326}, {{14.4375, 96.625}, {167.25, 89.5625}} -> {-0.145218, \
-0.034823, 0.0108735, 0.0108735}, {{104.875, 187}, {167.25, 89.5625}} -> \
{-0.379571, 0.0112448, 0.00662042, 0.00662042}, {{195.25, 277.438}, {167.25, \
89.5625}} -> {-1.40572, 0.397617, 0.00779943, 0.00779943}, {{285.625, \
367.813}, {167.25, 89.5625}} -> {-2.85425, 0.0305438, 0.0100298, 0.0100298}, \
{{376.063, 458.188}, {167.25, 89.5625}} -> {-3.03425, 0.182639, 0.00806347, \
0.00806347}, {{466.438, 548.625}, {167.25, 89.5625}} -> {-4.00953, 0.117853, \
0.00858923, 0.00858923}, {{14.4375, 96.625}, {81.75, 4.0625}} -> {-0.08056, \
-0.485065, 0.00586383, 0.00586383}, {{104.875, 187}, {81.75, 4.0625}} -> \
{0.0898554, 0.0915674, 0.00437214, 0.00437214}, {{195.25, 277.438}, {81.75, \
4.0625}} -> {-1.84403, -0.746995, 0.0097834, 0.0097834}, {{285.625, 367.813}, \
{81.75, 4.0625}} -> {-1.35321, -0.358941, 0.00458874, 0.00458874}, {{376.063, \
458.188}, {81.75, 4.0625}} -> {-2.60484, -0.536939, 0.00727253, 0.00727253}, \
{{466.438, 548.625}, {81.75, 4.0625}} -> {-2.82667, -0.338544, 0.00664315, \
0.00664315}}]
}, Open  ]],

Cell["\<\
A better technique obtains the centre of the incircle as intersection of  \
straight lines:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Clear[incircle]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(incircle[a_, b_, c_] := 
      Module[{h, k, \[Alpha], \[Beta], 
          p}, \[IndentingNewLine]h = \(b - a\)\/size[b - a] + \(c - \
a\)\/size[c - a]; \[IndentingNewLine]k = \(c - b\)\/size[c - b] + \(a - \
b\)\/size[a - b]; \[IndentingNewLine]{p} = \((a + \[Alpha]\ h /. 
              Solve[a + \[Alpha]\ h \[Equal] 
                  b + \[Beta]\ k])\); \[IndentingNewLine]{p, 
          disP2Seg[p, a, b]}]\)}], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]ic = 
            incircle[a, b, 
              c]; \[IndentingNewLine]Graphics[{{LightSlateGray, 
                Polygon[{a, b, c, a}], Chartreuse, 
                Disk[First[ic], Last[ic]]}, Line[{a, b, c, a}], 
              Circle[First[ic], Last[ic]]}, AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {12}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 6]]];\)\)}], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39656 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.00944196 0.15873 [
[ 0 0 0 0 ]
[ 1 .39656 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .39656 L
0 .39656 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00944196 0.17033 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.23437 7.60599 -3.42968 7.60599 [
[ 0 0 0 0 ]
[ 1 3.48149 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .08289 m
.02381 2.00631 L
.86404 3.3986 L
.97619 .08289 L
F
.498 1 0 r
.4966 1.98663 m
.4966 1.98663 .41496 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .08289 m
.02381 2.00631 L
.86404 3.3986 L
.97619 .08289 L
s
newpath
.4966 1.98663 .41496 0 365.73 arc
s
0 0 m
1 0 L
1 3.48149 L
0 3.48149 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.00944196 0.331502 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.49277 1.69206 -0.272574 1.69206 [
[ 0 0 0 0 ]
[ 1 1.34925 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .03213 m
.92132 .7012 L
.97619 1.31713 L
.02381 .03213 L
F
.498 1 0 r
.77342 .78383 m
.77342 .78383 .15464 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .03213 m
.92132 .7012 L
.97619 1.31713 L
.02381 .03213 L
s
newpath
.77342 .78383 .15464 0 365.73 arc
s
0 0 m
1 0 L
1 1.34925 L
0 1.34925 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.00944196 0.492674 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.277459 1.34289 -0.157258 1.34289 [
[ 0 0 0 0 ]
[ 1 .76446 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.14132 .74626 m
.97619 .0182 L
.02381 .63041 L
.14132 .74626 L
F
.498 1 0 r
.14448 .64294 m
.14448 .64294 .07579 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.14132 .74626 m
.97619 .0182 L
.02381 .63041 L
.14132 .74626 L
s
newpath
.14448 .64294 .07579 0 365.73 arc
s
0 0 m
1 0 L
1 .76446 L
0 .76446 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.00944196 0.653846 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.254952 1.68543 -0.36254 1.68543 [
[ 0 0 0 0 ]
[ 1 .78623 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .73608 m
.58589 .01872 L
.02381 .76751 L
.97619 .73608 L
F
.498 1 0 r
.5513 .49294 m
.5513 .49294 .25702 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .73608 m
.58589 .01872 L
.02381 .76751 L
.97619 .73608 L
s
newpath
.5513 .49294 .25702 0 365.73 arc
s
0 0 m
1 0 L
1 .78623 L
0 .78623 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.00944196 0.815018 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.694596 1.76746 -1.34258 1.76746 [
[ 0 0 0 0 ]
[ 1 .35519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .00846 m
.60807 .34673 L
.02381 .18918 L
.97619 .00846 L
F
.498 1 0 r
.57464 .21008 m
.57464 .21008 .12323 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .00846 m
.60807 .34673 L
.02381 .18918 L
.97619 .00846 L
s
newpath
.57464 .21008 .12323 0 365.73 arc
s
0 0 m
1 0 L
1 .35519 L
0 .35519 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.00944196 0.97619 0.189289 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.93398 6.85106 -1.9013 6.85106 [
[ 0 0 0 0 ]
[ 1 3.9209 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 3.41311 m
.97619 .09335 L
.92712 3.82754 L
.02381 3.41311 L
F
.498 1 0 r
.52078 3.1848 m
.52078 3.1848 .41475 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 3.41311 m
.97619 .09335 L
.92712 3.82754 L
.02381 3.41311 L
s
newpath
.52078 3.1848 .41475 0 365.73 arc
s
0 0 m
1 0 L
1 3.9209 L
0 3.9209 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.207274 0.17033 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.504211 2.94583 -1.20677 2.94583 [
[ 0 0 0 0 ]
[ 1 1.22746 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .02923 m
.97619 .065 L
.78127 1.19823 L
.02381 .02923 L
F
.498 1 0 r
.60979 .36217 m
.60979 .36217 .31072 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .02923 m
.97619 .065 L
.78127 1.19823 L
.02381 .02923 L
s
newpath
.60979 .36217 .31072 0 365.73 arc
s
0 0 m
1 0 L
1 1.22746 L
0 1.22746 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.207274 0.331502 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.909421 2.57765 -0.82518 2.57765 [
[ 0 0 0 0 ]
[ 1 1.07154 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .02551 m
.02381 1.04603 L
.73516 .45713 L
.97619 .02551 L
F
.498 1 0 r
.68929 .41894 m
.68929 .41894 .05867 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .02551 m
.02381 1.04603 L
.73516 .45713 L
.97619 .02551 L
s
newpath
.68929 .41894 .05867 0 365.73 arc
s
0 0 m
1 0 L
1 1.07154 L
0 1.07154 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.207274 0.492674 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0655642 6.06127 -1.52051 6.06127 [
[ 0 0 0 0 ]
[ 1 4.02141 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 3.92566 m
.76299 .09575 L
.02381 1.89845 L
.97619 3.92566 L
F
.498 1 0 r
.4614 1.8875 m
.4614 1.8875 .40072 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.97619 3.92566 m
.76299 .09575 L
.02381 1.89845 L
.97619 3.92566 L
s
newpath
.4614 1.8875 .40072 0 365.73 arc
s
0 0 m
1 0 L
1 4.02141 L
0 4.02141 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.207274 0.653846 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.178267 1.64191 -0.38292 1.64191 [
[ 0 0 0 0 ]
[ 1 .50695 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .49488 m
.97619 .14619 L
.53949 .01207 L
.02381 .49488 L
F
.498 1 0 r
.57297 .15688 m
.57297 .15688 .12859 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .49488 m
.97619 .14619 L
.53949 .01207 L
.02381 .49488 L
s
newpath
.57297 .15688 .12859 0 365.73 arc
s
0 0 m
1 0 L
1 .50695 L
0 .50695 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.207274 0.815018 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0745677 1.12428 -0.0740465 1.12428 [
[ 0 0 0 0 ]
[ 1 .96376 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.51442 .94082 m
.97619 .83533 L
.02381 .02295 L
.51442 .94082 L
F
.498 1 0 r
.60414 .74396 m
.60414 .74396 .17193 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.51442 .94082 m
.97619 .83533 L
.02381 .02295 L
.51442 .94082 L
s
newpath
.60414 .74396 .17193 0 365.73 arc
s
0 0 m
1 0 L
1 .96376 L
0 .96376 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.207274 0.97619 0.387121 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.346448 1.82318 -0.628653 1.82318 [
[ 0 0 0 0 ]
[ 1 1.18884 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .24433 m
.97619 .02831 L
.68377 1.16053 L
.02381 .24433 L
F
.498 1 0 r
.54895 .44305 m
.54895 .44305 .30996 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .24433 m
.97619 .02831 L
.68377 1.16053 L
.02381 .24433 L
s
newpath
.54895 .44305 .30996 0 365.73 arc
s
0 0 m
1 0 L
1 1.18884 L
0 1.18884 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{559.813, 222},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008_0000gR000`400?l00000o`00003oo`3ooooo
0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo
003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0
oooo<@3oool004@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?oooiD0oooo
00<000000?ooo`3oool0:03oool004@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3o0?oooi@0oooo00<000000?ooo`3oool0:03oool004<0oooo0P00000Y0?ooo`<00000o`3ooonC
0?ooo`800000:P3oool004<0oooo0P00000Z0?ooo`030000001gR9T000000?l0ooooTP3oool20000
02X0oooo00120?ooo`030000001gR9T0000002/0oooo00<0000007N8V@000000o`3ooonA0?ooo`80
0000:P3oool00480oooo00<0000007N8V@000000;03oool010000000MhRI00000000003o0?ooohl0
oooo0P00000Z0?ooo`00@@3oool010000000MhRI07N8V@00000/0?ooo`050000001gR9T0MhRI07N8
V@000000o`3ooon=0?ooo`030000001gR9T0000002X0oooo00110?ooo`040000001gR9T0MhRI0000
02d0oooo00D0000007N8V@1gR9T0MhRI0000003o0?oooh`0oooo00<0000007N8V@000000:P3oool0
0400oooo00D0000007N8V@1gR9T0MhRI0000000^0?ooo`040000001gR9T0MhRI07N8V@800000o`3o
oon:0?ooo`030000001gR9T0000002X0oooo00100?ooo`050000001gR9T0MhRI07N8V@000000;`3o
ool00`000000MhRI07N8V@0207N8V@030000003oool0oooo0?l0ooooQP3oool010000000MhRI07N8
V@00000Z0?ooo`00?`3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo02d0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`3o0?ooohD0oooo00@0000007N8V@1gR9T00000
:P3oool003l0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0^0?ooo`030000001g
R9T0MhRI00<0MhRI0P00003o0?ooohD0oooo00@0000007N8V@1gR9T00000:P3oool003h0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0_0?ooo`030000001gR9T0MhRI00@0MhRI00<0
00000?ooo`3oool0o`3ooon10?ooo`050000001gR9T0MhRI07N8V@000000:P3oool003h0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00@0MhRI00<0
00000?ooo`3oool0o`3ooon00?ooo`050000001gR9T0MhRI07N8V@000000:P3oool003d0oooo00<0
000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00D0MhRI0P00
003o0?oooh00oooo00D0000007N8V@1gR9T0MhRI0000000Z0?ooo`00?@3oool00`000000MhRI07N8
V@0407N8V@030000003oool0oooo0340oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?oo
o`3o0?ooogd0oooo00D0000007N8V@1gR9T0MhRI0000000Z0?ooo`00?03oool00`000000MhRI07N8
V@0407N8V@030000003oool0oooo03<0oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?oo
o`3o0?ooog/0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0X0?ooo`00?03oool0
0`000000MhRI07N8V@0407N8V@030000003oool0oooo03@0oooo00<0000007N8V@1gR9T01P1gR9T2
00000<H0oooo00<000000?ooo`3oool0/@3oool00`000000MhRI07N8V@0207N8V@030000003oool0
oooo02P0oooo000k0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0=03oool00`00
0000MhRI07N8V@0807N8V@030000003oool0oooo08T0oooo00<000000?ooo`3oool0=P3oool00`00
0000MhRI0000002b0?ooo`030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0:03oool003/0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0e0?ooo`030000001gR9T0MhRI00P0
MhRI00<000000?ooo`3oool0QP3oool2000003P0oooo00@0000007N8V@1gR9T00000/@3oool00`00
0000MhRI07N8V@0307N8V@030000003oool0oooo02P0oooo000j0?ooo`030000001gR9T0MhRI00H0
MhRI00<000000?ooo`3oool0=P3oool00`000000MhRI07N8V@0807N8V@800000Q@3oool2000003T0
oooo00D0000007N8V@1gR9T0MhRI0000002`0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?oo
o`3oool0:03oool003X0oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`0g0?ooo`03
0000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0P03oool3000003T0oooo00<0000007N8V@1g
R9T00P1gR9T00`000000oooo0?ooo`2^0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3o
ool0:03oool003T0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0g0?ooo`030000
001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0O@3oool4000003T0oooo00<0000007N8V@1gR9T0
101gR9T00`000000oooo0?ooo`2]0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0
:03oool003T0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0h0?ooo`030000001g
R9T0MhRI00X0MhRI0P00001l0?ooo`030000001gR9T0000003X0oooo00<0000007N8V@1gR9T01@1g
R9T00`000000oooo0?ooo`2/0?ooo`030000001gR9T0MhRI00@0MhRI00<000000?ooo`3oool0:03o
ool003P0oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`0i0?ooo`030000001gR9T0
MhRI00/0MhRI00<000000?ooo`3oool0M`3oool20000000307N8V@000000oooo03X0oooo00<00000
07N8V@1gR9T01P1gR9T00`000000oooo0?ooo`2[0?ooo`030000001gR9T0MhRI00<0MhRI00<00000
0?ooo`3oool0:@3oool003P0oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`0i0?oo
o`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0M@3oool010000000MhRI07N8V@00000k
0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0Z`3oool00`000000MhRI07N8V@03
07N8V@030000003oool0oooo02T0oooo000g0?ooo`030000001gR9T0MhRI00T0MhRI00<000000?oo
o`3oool0>P3oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo0780oooo0P00000207N8
V@030000003oool0oooo03T0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`2Y0?oo
o`030000001gR9T0MhRI00@0MhRI00<000000?ooo`3oool0:@3oool003L0oooo00<0000007N8V@1g
R9T02@1gR9T00`000000oooo0?ooo`0k0?ooo`030000001gR9T0MhRI00`0MhRI0P00001a0?ooo`05
0000001gR9T0MhRI07N8V@000000>`3oool00`000000MhRI07N8V@0:07N8V@030000003oool0oooo
0:T0oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0Y0?ooo`00=P3oool00`000000
MhRI07N8V@0:07N8V@030000003oool0oooo03`0oooo00<0000007N8V@1gR9T03@1gR9T00`000000
oooo0?ooo`1/0?ooo`8000000`1gR9T00`000000oooo0?ooo`0j0?ooo`030000001gR9T0MhRI00/0
MhRI00<000000?ooo`3oool0Z03oool00`000000MhRI07N8V@0407N8V@030000003oool0oooo02T0
oooo000f0?ooo`030000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0?03oool00`000000MhRI
07N8V@0>07N8V@030000003oool0oooo06X0oooo00@0000007N8V@1gR9T0MhRI0P00000l0?ooo`03
0000001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0YP3oool00`000000MhRI07N8V@0507N8V@03
0000003oool0oooo02T0oooo000f0?ooo`030000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0
?@3oool00`000000MhRI07N8V@0>07N8V@800000J03oool2000000<0MhRI00<000000?ooo`3oool0
>`3oool00`000000MhRI07N8V@0>07N8V@030000003oool0oooo0:H0oooo00<0000007N8V@1gR9T0
1@1gR9T00`000000oooo0?ooo`0Y0?ooo`00=@3oool00`000000MhRI07N8V@0;07N8V@030000003o
ool0oooo03h0oooo00<0000007N8V@1gR9T03`1gR9T00`000000oooo0?ooo`1S0?ooo`800000101g
R9T00`000000oooo0?ooo`0k0?ooo`030000001gR9T0MhRI0100MhRI00<000000?ooo`3oool0Y@3o
ool00`000000MhRI07N8V@0507N8V@030000003oool0oooo02T0oooo000e0?ooo`030000001gR9T0
MhRI00/0MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0?07N8V@030000003oool0
oooo0640oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0l0?ooo`030000001gR9T0
MhRI0100MhRI00<000000?ooo`3oool0Y@3oool00`000000MhRI07N8V@0507N8V@030000003oool0
oooo02T0oooo000d0?ooo`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0?`3oool00`00
0000MhRI07N8V@0@07N8V@800000G`3oool2000000D0MhRI00<000000?ooo`3oool0?03oool00`00
0000MhRI07N8V@0B07N8V@030000003oool0oooo0:<0oooo00<0000007N8V@1gR9T01P1gR9T00`00
0000oooo0?ooo`0Y0?ooo`00=03oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo0400
oooo00<0000007N8V@1gR9T04@1gR9T00`000000oooo0?ooo`1K0?ooo`030000001gR9T0MhRI00@0
MhRI00<000000?ooo`3oool0?03oool00`000000MhRI07N8V@0C07N8V@030000003oool0oooo06/0
oooo0`00000e0?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0:@3oool003<0oooo
00<0000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`110?ooo`030000001gR9T0MhRI0140MhRI
00<000000?ooo`3oool0F03oool2000000H0MhRI00<000000?ooo`3oool0?03oool00`000000MhRI
07N8V@0507N8V@P00000201gR9T00`000000oooo0?ooo`1U0?ooo`D0000000<0MhRI0000003oool0
=@3oool00`000000MhRI07N8V@0607N8V@030000003oool0oooo02T0oooo000c0?ooo`030000001g
R9T0MhRI00d0MhRI00<000000?ooo`3oool0@P3oool00`000000MhRI07N8V@0A07N8V@800000E`3o
ool00`000000MhRI07N8V@0507N8V@030000003oool0oooo03d0oooo00@0000007N8V@1gR9T0MhRI
1000000807oo008000001P1gR9T00`000000oooo0?ooo`1P0?ooo`D000001@1gR9T00`000000oooo
0?ooo`0d0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0:@3oool00380oooo00<0
000007N8V@1gR9T03P1gR9T00`000000oooo0?ooo`120?ooo`030000001gR9T0MhRI01<0MhRI00<0
00000?ooo`3oool0DP3oool2000000H0MhRI0P00000o0?ooo`030000001gR9T0MhRI008000003P1o
o`04000000<0MhRI00<000000?ooo`3oool0FP3oool5000000T0MhRI00<000000?ooo`3oool0=@3o
ool00`000000MhRI07N8V@0707N8V@030000003oool0oooo02T0oooo000b0?ooo`030000001gR9T0
MhRI00h0MhRI00<000000?ooo`3oool0@`3oool00`000000MhRI07N8V@0C07N8V@030000003oool0
oooo0500oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0n0?ooo`040000001gR9T0
0000000001@0Ool000@0000007N8V@1gR9T00000EP3oool6000000d0MhRI00<000000?ooo`3oool0
=P3oool00`000000MhRI07N8V@0707N8V@030000003oool0oooo02T0oooo000a0?ooo`030000001g
R9T0MhRI00l0MhRI00<000000?ooo`3oool0A03oool00`000000MhRI07N8V@0C07N8V@800000CP3o
ool2000000L0MhRI00<000000?ooo`3oool0?P3oool00`000000MhRI0000000G07oo00040000001g
R9T0MhRI00000500oooo1@00000B07N8V@030000003oool0oooo03L0oooo00<0000007N8V@1gR9T0
1`1gR9T00`000000oooo0?ooo`0Y0?ooo`00<@3oool00`000000MhRI07N8V@0?07N8V@030000003o
ool0oooo04D0oooo00<0000007N8V@1gR9T0501gR9T00`000000oooo0?ooo`190?ooo`800000201g
R9T00`000000oooo0?ooo`0o0?ooo`8000006@1oo`000`000000MhRI0000001;0?ooo`D000005P1g
R9T00`000000oooo0?ooo`0g0?ooo`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0:@3o
ool00300oooo00<0000007N8V@1gR9T0401gR9T00`000000oooo0?ooo`150?ooo`030000001gR9T0
MhRI01D0MhRI00<000000?ooo`3oool0A`3oool00`000000MhRI07N8V@0707N8V@030000003oool0
oooo03l0oooo00<0000007oo001oo`006P1oo`000`000000MhRI000000150?ooo`T000005@1gR9T2
000003X0oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`0Y0?ooo`00<03oool00`00
0000MhRI07N8V@0@07N8V@030000003oool0oooo04H0oooo00<0000007N8V@1gR9T05@1gR9T20000
04D0oooo0P00000907N8V@030000003oool0oooo03l0oooo0P00000M07oo00030000001gR9T00000
03l0oooo1@0000000`1gR9T0000007oo000607oo008000004P1gR9T00`000000oooo0?ooo`0j0?oo
o`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0:@3oool002l0oooo00<0000007N8V@1g
R9T00P1gR9T7000000P0MhRI00<000000?ooo`3oool0A`3oool00`000000MhRI07N8V@0F07N8V@03
0000003oool0oooo0440oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`0o0?ooo`80
00007`1oo`02000003X0oooo1@00000407N8V@8000002P1oo`02000000l0MhRI00<000000?ooo`3o
ool0>P3oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo02T0oooo000_0?ooo`030000
001gR9T0MhRI008000001`1oo`02000000H0MhRI00<000000?ooo`3oool0B03oool00`000000MhRI
07N8V@0F07N8V@030000003oool0oooo03h0oooo0P00000907N8V@800000@@3oool200000240Ool0
0P00000d0?ooo`D00000201gR9T00`000000Ool007oo000<07oo00030000001gR9T0MhRI00/0MhRI
00<000000?ooo`3oool0>`3oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo02T0oooo
000^0?ooo`040000001gR9T00000000000/0Ool000<0000007N8V@1gR9T00`1gR9T00`000000oooo
0?ooo`180?ooo`030000001gR9T0MhRI0100MhRI2@00000m0?ooo`030000001gR9T0MhRI00P0MhRI
00<000000?ooo`3oool0@@3oool00`000000Ool007oo000P07oo00800000;P3oool6000000`0MhRI
00<0000007oo001oo`003P1oo`000`000000MhRI07N8V@0907N8V@030000003oool0oooo03`0oooo
00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0Y0?ooo`00;P3oool2000000h0Ool000<0
000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`190?ooo`030000001gR9T0MhRI00d0MhRI0P00
000807oo00800000>P3oool2000000X0MhRI00<000000?ooo`3oool0@@3oool00`000000Ool007oo
000R07oo00800000:03oool500000180MhRI00<0000007oo001oo`003`1oo`000`000000MhRI07N8
V@0707N8V@030000003oool0oooo03`0oooo00<0000007N8V@1gR9T02P1gR9T00`000000oooo0?oo
o`0Y0?ooo`00;@3oool00`000000Ool007oo000?07oo00050000001gR9T0MhRI07N8V@000000C03o
ool00`000000MhRI07N8V@0:07N8V@800000301oo`02000003H0oooo0P00000;07N8V@030000003o
ool0oooo0440oooo0P00000T07oo008000008`3oool5000001H0MhRI00<0000007oo001oo`00401o
o`000`000000MhRI07N8V@0607N8V@030000003oool0oooo03d0oooo00<0000007N8V@1gR9T02P1g
R9T00`000000oooo0?ooo`0Y0?ooo`00;@3oool00`000000Ool007oo000@07oo00030000001gR9T0
000004d0oooo00<0000007N8V@1gR9T02@1gR9T00`000000Ool007oo000=07oo00800000=03oool0
0`000000MhRI07N8V@0:07N8V@030000003oool0oooo0480oooo00<0000007oo001oo`00901oo`02
000001d0oooo1@00000K07N8V@030000001oo`00Ool00100Ool000<0000007N8V@1gR9T01@1gR9T0
0`000000oooo0?ooo`0n0?ooo`030000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0:@3oool0
02`0oooo00<0000007oo001oo`004P1oo`02000004h0oooo00<0000007N8V@1gR9T01`1gR9T00`00
0000Ool007oo000?07oo00800000<@3oool2000000`0MhRI00<000000?ooo`3oool0@P3oool20000
02H0Ool00P00000J0?ooo`<00000801gR9T00`000000Ool007oo000@07oo00030000001gR9T0MhRI
00@0MhRI00<000000?ooo`3oool0?`3oool00`000000MhRI07N8V@0:07N8V@030000003oool0oooo
02T0oooo000[0?ooo`800000501oo`02000004l0oooo00<0000007N8V@1gR9T01@1gR9T00`000000
Ool007oo000A07oo00800000;`3oool00`000000MhRI07N8V@0;07N8V@030000003oool0oooo0480
oooo00<0000007N8V@0000009`1oo`02000001/0oooo1000000M07N8V@030000001oo`00Ool00140
Ool000<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0o0?ooo`030000001gR9T0MhRI00/0
MhRI00<000000?ooo`3oool0:@3oool002/0oooo00<0000007oo001oo`00501oo`000`000000oooo
0?ooo`1>0?ooo`030000001gR9T0MhRI00@0MhRI00<0000007oo001oo`004P1oo`000`000000oooo
0?ooo`0[0?ooo`8000003@1gR9T00`000000oooo0?ooo`120?ooo`040000001gR9T0MhRI000002L0
Ool00P00000O0?ooo`@000006@1gR9T00`000000Ool007oo000A07oo00050000001gR9T0MhRI07N8
V@000000@P3oool00`000000MhRI07N8V@0;07N8V@030000003oool0oooo02T0oooo000[0?ooo`03
0000001oo`00Ool001@0Ool000<000000?ooo`3oool0CP3oool00`000000MhRI07N8V@0307N8V@03
0000001oo`00Ool001<0Ool000<000000?ooo`3oool0:P3oool00`000000MhRI07N8V@0;07N8V@80
0000A@3oool00`000000MhRI0000000Y07oo008000008P3oool3000001H0MhRI00<0000007oo001o
o`004@1oo`0010000000MhRI07N8V@0000130?ooo`030000001gR9T0MhRI00/0MhRI00<000000?oo
o`3oool0:@3oool002X0oooo00<0000007oo001oo`005@1oo`000`000000oooo0?ooo`1?0?ooo`03
0000001gR9T0MhRI0080MhRI00<0000007oo001oo`004`1oo`000`000000oooo0?ooo`0X0?ooo`80
00003@1gR9T00`000000oooo0?ooo`140?ooo`040000001gR9T0MhRI000002T0Ool000<0000007N8
V@000000903oool400000180MhRI00<0000007oo001oo`004@1oo`000`000000MhRI000000130?oo
o`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0:@3oool002X0oooo00<0000007oo001o
o`005@1oo`000`000000oooo0?ooo`1@0?ooo`050000001gR9T0MhRI07N8V@0000005@1oo`000`00
0000oooo0?ooo`0W0?ooo`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0A03oool01@00
0000MhRI07N8V@1gR9T0000002T0Ool000<0000007N8V@000000:03oool3000000l0MhRI00<00000
07oo001oo`00401oo`000`000000MhRI000000140?ooo`030000001gR9T0MhRI00`0MhRI00<00000
0?ooo`3oool0:@3oool002T0oooo0P00000G07oo00030000003oool0oooo0540oooo00@0000007N8
V@1gR9T000005P1oo`000`000000oooo0?ooo`0T0?ooo`8000003P1gR9T00`000000oooo0?ooo`14
0?ooo`030000001gR9T0MhRI0080MhRI00<0000007oo001oo`009`1oo`0010000000MhRI07N8V@00
000Z0?ooo`@000002`1gR9T00`000000Ool007oo000?07oo00<00000A@3oool00`000000MhRI07N8
V@0<07N8V@030000003oool0oooo02T0oooo000Y0?ooo`8000005`1oo`000`000000oooo0?ooo`1A
0?ooo`040000001gR9T0MhRI000001H0Ool000<000000?ooo`3oool08P3oool2000000l0MhRI00<0
00000?ooo`3oool0A@3oool00`000000MhRI07N8V@0207N8V@030000001oo`00Ool002L0Ool000@0
000007N8V@1gR9T00000;P3oool4000000P0MhRI00<0000007oo001oo`003P1oo`000`000000oooo
0?ooo`150?ooo`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0:@3oool002X0oooo00<0
000007oo001oo`005@1oo`000`000000oooo0?ooo`1B0?ooo`030000001gR9T0000001H0Ool000<0
00000?ooo`3oool08@3oool00`000000MhRI07N8V@0>07N8V@030000003oool0oooo04D0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000Ool007oo000W07oo00050000001gR9T0MhRI07N8V@000000
<@3oool3000000H0MhRI00<0000007oo001oo`00301oo`000`000000oooo0?ooo`150?ooo`030000
001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0:@3oool002X0oooo00<0000007oo001oo`005@1o
o`000`000000oooo0?ooo`1C0?ooo`8000005P1oo`000`000000oooo0?ooo`0O0?ooo`800000401g
R9T00`000000oooo0?ooo`150?ooo`030000001gR9T0MhRI00@0MhRI00<0000007oo001oo`009`1o
o`001@000000MhRI07N8V@1gR9T0000003@0oooo1000000307N8V@030000001oo`00Ool000X0Ool0
0P0000170?ooo`030000001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0:@3oool002/0oooo00<0
000007oo001oo`004`1oo`02000005H0oooo00<0000007oo001oo`004`1oo`0200000200oooo00<0
000007N8V@1gR9T03P1gR9T2000004L0oooo00<0000007N8V@1gR9T01@1gR9T00`000000Ool007oo
000W07oo00030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0=@3oool30000000307N8V@00
0000Ool000T0Ool00P0000180?ooo`030000001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0:@3o
ool002/0oooo00<0000007oo001oo`004`1oo`02000005H0oooo0P00000D07oo008000007P3oool2
00000100MhRI00<000000?ooo`3oool0A`3oool00`000000MhRI07N8V@0507N8V@030000001oo`00
Ool002L0Ool000<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0h0?ooo`D000000`1oo`04
000004T0oooo00<0000007N8V@1gR9T03P1gR9T00`000000oooo0?ooo`0Y0?ooo`00;03oool00`00
0000Ool007oo000A07oo00030000001gR9T0000005L0oooo00<0000007oo001oo`004@1oo`000`00
0000MhRI0000000M0?ooo`030000001gR9T0MhRI00l0MhRI00<000000?ooo`3oool0A`3oool00`00
0000MhRI07N8V@0707N8V@030000001oo`00Ool002D0Ool000<0000007N8V@1gR9T0101gR9T00`00
0000oooo0?ooo`0k0?ooo`@000000P1gR9T00`000000oooo0?ooo`180?ooo`030000001gR9T0MhRI
00h0MhRI00<000000?ooo`3oool0:@3oool002`0oooo0P00000B07oo00030000001gR9T0000005P0
oooo00<0000007oo001oo`00401oo`000`000000MhRI0000000K0?ooo`8000004@1gR9T00`000000
oooo0?ooo`170?ooo`030000001gR9T0MhRI00P0MhRI00<0000007oo001oo`009@1oo`000`000000
MhRI07N8V@0407N8V@030000003oool0oooo03l0oooo0P00001;0?ooo`030000001gR9T0MhRI00h0
MhRI00<000000?ooo`3oool0:@3oool002d0oooo00<0000007oo001oo`003`1oo`0010000000MhRI
07N8V@00001H0?ooo`800000401oo`0010000000MhRI07N8V@00000J0?ooo`@000003`1gR9T00`00
0000oooo0?ooo`170?ooo`030000001gR9T0MhRI00T0MhRI00<0000007oo001oo`00901oo`000`00
0000MhRI07N8V@0607N8V@030000003oool0oooo08X0oooo00<0000007N8V@1gR9T03`1gR9T00`00
0000oooo0?ooo`0Y0?ooo`00;P3oool00`000000Ool007oo000>07oo00040000001gR9T0MhRI0000
05T0oooo00<0000007oo001oo`003@1oo`000`000000MhRI07N8V@0207N8V@030000003oool0oooo
01D0oooo0P00000407oo00800000301gR9T00`000000oooo0?ooo`180?ooo`030000001gR9T0MhRI
00T0MhRI00<0000007oo001oo`00901oo`000`000000MhRI07N8V@0607N8V@030000003oool0oooo
08X0oooo00<0000007N8V@1gR9T03`1gR9T00`000000oooo0?ooo`0Y0?ooo`00;P3oool2000000d0
Ool00P00000307N8V@030000003oool0oooo05P0oooo0P00000<07oo00030000001gR9T0MhRI00<0
MhRI00<000000?ooo`3oool04`3oool3000000L0Ool00P00000907N8V@030000003oool0oooo04P0
oooo00<0000007N8V@1gR9T02`1gR9T00`000000Ool007oo000R07oo00030000001gR9T0MhRI00P0
MhRI00<000000?ooo`3oool0R@3oool00`000000MhRI07N8V@0?07N8V@030000003oool0oooo02T0
oooo000_0?ooo`@000001`1oo`03000000D0MhRI00<000000?ooo`3oool0F@3oool3000000X0Ool0
00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0B0?ooo`030000001gR9T0000000T0Ool0
00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`180?ooo`030000001gR9T0MhRI00`0MhRI
00<0000007oo001oo`008P1oo`000`000000MhRI07N8V@0907N8V@030000003oool0oooo08P0oooo
00<0000007N8V@1gR9T03`1gR9T00`000000oooo0?ooo`0Y0?ooo`00<03oool00`000000MhRI07N8
V@07000000P0MhRI00<000000?ooo`3oool0FP3oool00`000000MhRI00000009000000H0MhRI00<0
00000?ooo`3oool0403oool20000000307N8V@000000Ool000X0Ool000<0000007N8V@1gR9T00`1g
R9T2000004X0oooo00<0000007N8V@1gR9T03P1gR9T00`000000Ool007oo000P07oo00030000001g
R9T0MhRI00X0MhRI00<000000?ooo`3oool0Q`3oool00`000000MhRI07N8V@0@07N8V@030000003o
ool0oooo02T0oooo000`0?ooo`030000001gR9T0MhRI00l0MhRI00<000000?ooo`3oool0FP3oool0
0`000000MhRI07N8V@0?07N8V@030000003oool0oooo00l0oooo00D0000007N8V@1gR9T0MhRI0000
000;07oo00030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0BP3oool00`000000MhRI07N8
V@0>07N8V@030000001oo`00Ool00200Ool000<0000007N8V@1gR9T02`1gR9T00`000000oooo0?oo
o`260?ooo`030000001gR9T0MhRI0100MhRI00<000000?ooo`3oool0:@3oool00340oooo00<00000
07N8V@1gR9T03P1gR9T00`000000oooo0?ooo`1K0?ooo`030000001gR9T0MhRI00h0MhRI00<00000
0?ooo`3oool0403oool010000000MhRI07N8V@00000;07oo00050000001gR9T0MhRI07N8V@000000
C03oool00`000000MhRI07N8V@0@07N8V@030000001oo`00Ool001h0Ool000<0000007N8V@1gR9T0
301gR9T00`000000oooo0?ooo`260?ooo`030000001gR9T0MhRI0080MhRI1`00000707N8V@030000
003oool0oooo02T0oooo000a0?ooo`030000001gR9T0MhRI00h0MhRI00<000000?ooo`3oool0G03o
ool00`000000MhRI07N8V@0=07N8V@030000003oool0oooo0140oooo00<0000007N8V@0000002`1o
o`0010000000MhRI07N8V@00001<0?ooo`030000001gR9T0MhRI0180MhRI0P00000N07oo00030000
001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0Q03oool010000000MhRI07N8V@1gR9T2000000L0
Ool00P00000507N8V@030000003oool0oooo02T0oooo000b0?ooo`030000001gR9T0MhRI00d0MhRI
00<000000?ooo`3oool0G@3oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo0180oooo
0P00000;07oo00030000001gR9T0000004`0oooo00<0000007N8V@1gR9T0501gR9T00`000000Ool0
07oo000K07oo00030000001gR9T0MhRI00h0MhRI00<000000?ooo`3oool0Q03oool010000000MhRI
00000000000;07oo008000000`1gR9T00`000000oooo0?ooo`0Y0?ooo`00<`3oool00`000000MhRI
07N8V@0<07N8V@030000003oool0oooo05d0oooo00<0000007N8V@1gR9T0301gR9T00`000000oooo
0?ooo`0C0?ooo`030000001oo`00Ool000T0Ool00P00001=0?ooo`030000001gR9T0MhRI01D0MhRI
00<0000007oo001oo`00601oo`0200000180MhRI00<000000?ooo`3oool0P`3oool2000000l0Ool0
00<0000007N8V@000000;03oool003<0oooo00<0000007N8V@1gR9T0301gR9T00`000000oooo0?oo
o`1N0?ooo`030000001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0503oool00`000000Ool007oo
000707oo00800000C@3oool00`000000MhRI07N8V@0G07N8V@8000005`1oo`000`000000MhRI07N8
V@0B07N8V@030000003oool0oooo08<0oooo0P00000?07oo00030000001gR9T0000002`0oooo000d
0?ooo`030000001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0G`3oool00`000000MhRI07N8V@0;
07N8V@030000003oool0oooo01@0oooo00<0000007oo001oo`001@1oo`02000004d0oooo00<00000
07N8V@1gR9T06P1gR9T00`000000Ool007oo000C07oo00030000001gR9T0MhRI01@0MhRI00<00000
0?ooo`3oool0P@3oool200000140Ool00P00000/0?ooo`00=03oool00`000000MhRI07N8V@0;07N8
V@030000003oool0oooo05l0oooo00<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`0E0?oo
o`L00000CP3oool00`000000MhRI07N8V@0L07N8V@8000004P1oo`000`000000MhRI07N8V@0E07N8
V@030000003oool0oooo0840oooo00<0000007oo001oo`00401oo`02000002`0oooo000e0?ooo`03
0000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0H03oool00`000000MhRI07N8V@0:07N8V@03
0000003oool0oooo01H0oooo00D0000007N8V@1gR9T0MhRI0000001?0?ooo`030000001gR9T0MhRI
01h0MhRI0P00000<07oo00@000001P1gR9TD00000880oooo00<0000007oo001oo`004@1oo`000`00
0000oooo0?ooo`0Z0?ooo`00=P3oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo0640
oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0G0?ooo`030000001gR9T0000004l0
oooo00<0000007N8V@1gR9T0401gR9TW000009D0oooo0P00000C07oo00030000003oool0oooo02X0
oooo000f0?ooo`030000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0HP3oool00`000000MhRI
07N8V@0807N8V@030000003oool0oooo01P0oooo00<000000?ooo`3oool0C@3ooolD00000;`0oooo
00<0000007oo001oo`004P1oo`02000002/0oooo000g0?ooo`030000001gR9T0MhRI00P0MhRI00<0
00000?ooo`3oool0HP3oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo0?l0oooo>@3o
ool00`000000Ool007oo000B07oo00800000:`3oool003L0oooo00<0000007N8V@1gR9T01`1gR9T0
0`000000oooo0?ooo`1T0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0o`3ooolh
0?ooo`800000501oo`02000002/0oooo000h0?ooo`030000001gR9T0MhRI00H0MhRI00<000000?oo
o`3oool0I@3oool00`000000MhRI07N8V@0607N8V@030000003oool0oooo0?l0oooo>03oool20000
01@0Ool000<000000?ooo`3oool0:P3oool003T0oooo00<0000007N8V@1gR9T01@1gR9T00`000000
oooo0?ooo`1V0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0o`3ooolh0?ooo`80
0000501oo`000`000000oooo0?ooo`0Z0?ooo`00>@3oool00`000000MhRI07N8V@0507N8V@030000
003oool0oooo06H0oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`3o0?ooocL0oooo
00<0000007N8V@0000004`1oo`000`000000oooo0?ooo`0Z0?ooo`00>P3oool00`000000MhRI07N8
V@0407N8V@030000003oool0oooo06L0oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?oo
o`3o0?ooocH0oooo00@0000007N8V@1gR9T000004P1oo`02000002`0oooo000j0?ooo`030000001g
R9T0MhRI00@0MhRI00<000000?ooo`3oool0J03oool00`000000MhRI07N8V@0407N8V@030000003o
ool0oooo0?l0oooo=P3oool200000080MhRI00<0000007oo001oo`003`1oo`02000002`0oooo000k
0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0J@3oool00`000000MhRI07N8V@03
07N8V@030000003oool0oooo0?l0oooo>03oool20000000307N8V@000000Ool000h0Ool000<00000
07N8V@000000;03oool003`0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`1Y0?oo
o`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0o`3ooolj0?ooo`<000003@1oo`001000
0000MhRI07N8V@00000/0?ooo`00?03oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo
06X0oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`3o0?oooc`0oooo0P00000;07oo
00050000001gR9T0MhRI07N8V@000000;03oool003d0oooo00D0000007N8V@1gR9T0MhRI0000001]
0?ooo`050000001gR9T0MhRI07N8V@000000o`3ooom00?ooo`8000001`1oo`02000000@0MhRI00<0
00000?ooo`3oool0:P3oool003d0oooo00D0000007N8V@1gR9T0MhRI0000001^0?ooo`040000001g
R9T0MhRI00000?l0oooo@P3oool7000000H0MhRI00<000000?ooo`3oool0:P3oool003h0oooo00@0
000007N8V@1gR9T00000KP3oool010000000MhRI07N8V@00003o0?oood@0oooo0P00000907N8V@03
0000003oool0oooo02X0oooo000o0?ooo`030000001gR9T0000006l0oooo00@0000007N8V@1gR9T0
0000o`3ooom50?ooo`8000001`1gR9T00`000000oooo0?ooo`0Z0?ooo`00?`3oool00`000000MhRI
0000001`0?ooo`030000001gR9T000000?l0ooooA`3oool2000000D0MhRI00<000000?ooo`3oool0
:P3oool00400oooo0P00001a0?ooo`800000o`3ooom90?ooo`8000000`1gR9T00`000000oooo0?oo
o`0Z0?ooo`00@03oool200000740oooo0P00003o0?oood/0oooo0P0000000`1gR9T000000?ooo`0[
0?ooo`00@@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0?l0ooooB`3oool20000
02`0oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o
0?ooool0oooo<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo
<@3oool00?l0ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0
ooooo`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool000l0oooo3@00003E
0?ooo`030000003oool0oooo0?l0oooo?03oool00100oooo00<0000007N8V@1gR9T02@1gR9TJ0000
0;/0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00403oool00`000000MhRI07N8V@0S07N8VAX0
0000X03oool200000?l0oooo:`3oool300000100oooo000A0?ooo`030000001gR9T0MhRI02D0MhRI
0`00000707oo00D00000201gR9T>00000980oooo0P00003o0?ooobL0oooo1000000207N8V@030000
003oool0oooo00h0oooo000B0?ooo`030000001gR9T0MhRI0280MhRI0P00000?07oo008000004`1g
R9T00`000000oooo0?ooo`2?0?ooo`030000001gR9T000000?l0oooo8`3oool4000000D0MhRI00<0
00000?ooo`3oool03`3oool00180oooo00<0000007N8V@1gR9T0801gR9T2000001<0Ool00P00000A
07N8V@030000003oool0oooo08l0oooo00<0000007N8V@000000o`3ooolO0?ooo`@000002@1gR9T0
0`000000oooo0?ooo`0?0?ooo`004`3oool00`000000MhRI07N8V@0L07N8V@<000005`1oo`020000
00h0MhRI00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0d0?ooo`040000001gR9T0MhRI
00000?l0oooo6P3oool5000000d0MhRI00<000000?ooo`3oool03`3oool001@0oooo00<0000007N8
V@1gR9T06@1gR9T2000001`0Ool000<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo03D0oooo00@0000007N8V@1gR9T00000o`3ooolF0?ooo`@000004P1gR9T0
0`000000oooo0?ooo`0?0?ooo`00503oool00`000000MhRI07N8V@0H07N8V@030000001oo`00Ool0
01d0Ool000<0000007N8V@1gR9T02P1gR9T00`000000oooo0?ooo`1F0?ooo`800000=`3oool01000
0000MhRI07N8V@00003o0?oooa80oooo1000000E07N8V@030000003oool0oooo0100oooo000E0?oo
o`030000001gR9T0MhRI01H0MhRI00<0000007oo001oo`007`1oo`02000000X0MhRI00<000000?oo
o`3oool0E@3oool2000003L0oooo00D0000007N8V@1gR9T0MhRI0000003o0?ooo`d0oooo1@00000I
07N8V@030000003oool0oooo0100oooo000E0?ooo`030000001gR9T0MhRI01D0MhRI00<0000007oo
001oo`008P1oo`000`000000MhRI07N8V@0707N8V@030000003oool0oooo05@0oooo00<0000007N8
V@000000=`3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo0?l0oooo1P3oool40000
01h0MhRI00<000000?ooo`3oool0403oool001H0oooo00<0000007N8V@1gR9T04`1gR9T00`000000
Ool007oo000T07oo00030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0D`3oool00`000000
MhRI0000000g0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`1k0?ooo`l00000601gR9T00`000000oooo0?ooo`0@0?ooo`005`3oool00`000000MhRI
07N8V@0A07N8V@030000001oo`00Ool002D0Ool000<0000007N8V@1gR9T01@1gR9T00`000000oooo
0?ooo`1C0?ooo`040000001gR9T0MhRI000003L0oooo00<0000007N8V@1gR9T00`1gR9T00`000000
oooo0?ooo`230?ooo`030000003oool0oooo07L0oooo1000000>07oo008000005@1gR9T00`000000
oooo0?ooo`0A0?ooo`005`3oool00`000000MhRI07N8V@0@07N8V@030000001oo`00Ool002L0Ool0
00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`1B0?ooo`040000001gR9T0MhRI000003P0
oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`230?ooo`800000L`3oool6000001<0
Ool00P00000C07N8V@030000003oool0oooo0140oooo000H0?ooo`030000001gR9T0MhRI00l0MhRI
00<0000007oo001oo`00:01oo`000`000000MhRI07N8V@0307N8V@030000003oool0oooo0580oooo
00@0000007N8V@1gR9T00000=`3oool00`000000MhRI07N8V@0407N8V@030000003oool0oooo08@0
oooo0`00001]0?ooo`@000000P1gR9T2000001L0Ool000<0000007N8V@1gR9T0401gR9T00`000000
oooo0?ooo`0A0?ooo`006@3oool00`000000MhRI07N8V@0=07N8V@030000001oo`00Ool002X0Ool0
00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`1A0?ooo`040000001gR9T0MhRI000003P0
oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`240?ooo`040000001gR9T0MhRI0000
06P0oooo1000000407N8V@8000006P1oo`000`000000MhRI07N8V@0?07N8V@030000003oool0oooo
0140oooo000I0?ooo`030000001gR9T0MhRI00d0MhRI00<0000007oo001oo`00:P1oo`000`000000
MhRI07N8V@0207N8V@030000003oool0oooo0500oooo00@0000007N8V@1gR9T00000>03oool00`00
0000MhRI07N8V@0507N8V@030000003oool0oooo08D0oooo00@0000007N8V@1gR9T00000HP3oool5
000000L0MhRI00<0000007oo001oo`006`1oo`02000000h0MhRI00<000000?ooo`3oool04P3oool0
01X0oooo00<0000007N8V@1gR9T02`1gR9T00`000000Ool007oo000/07oo00050000001gR9T0MhRI
07N8V@000000D@3oool01@000000MhRI07N8V@1gR9T0000003P0oooo00<0000007N8V@1gR9T01@1g
R9T00`000000oooo0?ooo`250?ooo`050000001gR9T0MhRI07N8V@000000G@3oool4000000/0MhRI
00<0000007oo001oo`007P1oo`000`000000MhRI07N8V@0;07N8V@030000003oool0oooo0180oooo
000K0?ooo`030000001gR9T0MhRI00T0MhRI00<0000007oo001oo`00;@1oo`0010000000MhRI07N8
V@00001A0?ooo`050000001gR9T0MhRI07N8V@000000>03oool00`000000MhRI07N8V@0607N8V@03
0000003oool0oooo08H0oooo00D0000007N8V@1gR9T0MhRI0000001H0?ooo`@000003P1gR9T00`00
0000Ool007oo000P07oo00030000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool04P3oool001/0
oooo00<0000007N8V@1gR9T02@1gR9T00`000000Ool007oo000]07oo00040000001gR9T0MhRI0000
0500oooo00<0000007N8V@1gR9T00P1gR9T00`000000oooo0?ooo`0f0?ooo`030000001gR9T0MhRI
00H0MhRI00<000000?ooo`3oool0QP3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo
0540oooo1000000A07N8V@030000001oo`00Ool00280Ool000<0000007N8V@1gR9T02@1gR9T00`00
0000oooo0?ooo`0B0?ooo`00703oool00`000000MhRI07N8V@0807N8V@030000001oo`00Ool002h0
Ool000<0000007N8V@000000C`3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo03L0
oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`270?ooo`030000001gR9T0MhRI0080
MhRI0P00001>0?ooo`<00000501gR9T00`000000Ool007oo000T07oo00030000001gR9T0MhRI00L0
MhRI00<000000?ooo`3oool04`3oool001d0oooo00<0000007N8V@1gR9T01`1gR9T00`000000Ool0
07oo000^07oo00030000001gR9T0000004h0oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo
0?ooo`0f0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0Q`3oool00`000000MhRI
07N8V@0407N8V@030000003oool0oooo04`0oooo00<0000007N8V@1gR9T04P1gR9T00`000000Ool0
07oo000U07oo00030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool04`3oool001d0oooo00<0
000007N8V@1gR9T01`1gR9T00`000000Ool007oo000^07oo00030000001gR9T0000004d0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0g0?ooo`030000001gR9T0MhRI00L0MhRI00<0
00000?ooo`3oool0R03oool00`000000MhRI07N8V@0407N8V@030000003oool0oooo04/0oooo00<0
000007N8V@1gR9T04@1gR9T00`000000Ool007oo000W07oo00030000001gR9T0MhRI00H0MhRI00<0
00000?ooo`3oool04`3oool001h0oooo00<0000007N8V@1gR9T01@1gR9T00`000000Ool007oo000_
07oo00030000001gR9T0000004`0oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0f
0?ooo`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0R03oool00`000000MhRI07N8V@05
07N8V@030000003oool0oooo04/0oooo00<0000007N8V@1gR9T0401gR9T00`000000Ool007oo000X
07oo00030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool04`3oool001h0oooo00<0000007N8
V@1gR9T01@1gR9T00`000000Ool007oo000_07oo00800000C03oool00`000000MhRI07N8V@0407N8
V@030000003oool0oooo03L0oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`290?oo
o`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0B`3oool00`000000MhRI07N8V@0>07N8
V@030000001oo`00Ool002X0Ool000<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0D0?oo
o`007`3oool00`000000MhRI07N8V@0407N8V@030000001oo`00Ool00300Ool000<000000?ooo`3o
ool0B@3oool00`000000MhRI07N8V@0407N8V@030000003oool0oooo03L0oooo00<0000007N8V@1g
R9T02@1gR9T00`000000oooo0?ooo`290?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3o
ool0B`3oool00`000000MhRI07N8V@0=07N8V@030000001oo`00Ool002X0Ool000<0000007N8V@1g
R9T00`1gR9T00`000000oooo0?ooo`0D0?ooo`00803oool00`000000MhRI07N8V@0307N8V@030000
001oo`00Ool00300Ool000<000000?ooo`3oool0B03oool00`000000MhRI07N8V@0507N8V@030000
003oool0oooo03L0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`2:0?ooo`030000
001gR9T0MhRI00H0MhRI0P00001;0?ooo`030000001gR9T0MhRI00`0MhRI00<0000007oo001oo`00
;01oo`000`000000MhRI07N8V@0207N8V@030000003oool0oooo01@0oooo000P0?ooo`030000001g
R9T0MhRI00<0MhRI00<0000007oo001oo`00<01oo`000`000000oooo0?ooo`170?ooo`030000001g
R9T0MhRI00D0MhRI00<000000?ooo`3oool0>03oool00`000000MhRI07N8V@0907N8V@030000003o
ool0oooo08/0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`190?ooo`030000001g
R9T0MhRI00/0MhRI00<0000007oo001oo`00;01oo`001@000000MhRI07N8V@1gR9T0000001L0oooo
000Q0?ooo`030000001gR9T0MhRI0080MhRI00<0000007oo001oo`00<01oo`000`000000oooo0?oo
o`170?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0=`3oool00`000000MhRI07N8
V@0:07N8V@030000003oool0oooo0580oooo0P00000g0?ooo`030000001gR9T0MhRI00P0MhRI00<0
00000?ooo`3oool0B@3oool00`000000MhRI07N8V@0:07N8V@030000001oo`00Ool002d0Ool000@0
000007N8V@1gR9T000005`3oool00280oooo00D0000007N8V@1gR9T0MhRI0000000b07oo00030000
003oool0oooo04H0oooo00<0000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0h0?ooo`030000
001gR9T0MhRI00/0MhRI00<000000?ooo`3oool0D03oool00`000000MhRI07N8V@03000003D0oooo
00<0000007N8V@1gR9T0201gR9T00`000000oooo0?ooo`180?ooo`030000001gR9T0MhRI00T0MhRI
00<0000007oo001oo`00;P1oo`0010000000MhRI07N8V@00000G0?ooo`008P3oool01@000000MhRI
07N8V@1gR9T000000340Ool00P0000170?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3o
ool0=`3oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo04l0oooo2`00000a0?ooo`03
0000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0B03oool00`000000MhRI07N8V@0807N8V@03
0000001oo`00Ool002h0Ool000@0000007N8V@1gR9T000005`3oool002<0oooo00@0000007N8V@1g
R9T00000<@1oo`02000004H0oooo00<0000007N8V@1gR9T01P1gR9T00`000000oooo0?ooo`0h0?oo
o`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0CP3oool2000000P0Ool01@00000_0?oo
o`030000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool0B03oool00`000000MhRI07N8V@0607N8
V@030000001oo`00Ool002l0Ool000<0000007N8V@000000603oool002@0oooo00<0000007N8V@00
0000<@1oo`000`000000oooo0?ooo`140?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3o
ool0=`3oool00`000000MhRI07N8V@0=07N8V@030000003oool0oooo04d0oooo00<0000007oo001o
o`002P1oo`000`000000MhRI07N8V@03000002`0oooo00<0000007N8V@1gR9T02P1gR9T2000004T0
oooo00<0000007N8V@1gR9T01@1gR9T00`000000Ool007oo000_07oo00030000001gR9T0000001P0
oooo000T0?ooo`040000001gR9T0MhRI00000300Ool000<000000?ooo`3oool0@`3oool00`000000
MhRI07N8V@0707N8V@030000003oool0oooo03P0oooo00<0000007N8V@1gR9T03@1gR9T00`000000
oooo0?ooo`1<0?ooo`030000001oo`00Ool000`0Ool000<0000007N8V@1gR9T00P1gR9T3000002X0
oooo00<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`160?ooo`030000001gR9T0MhRI00D0
MhRI00<0000007oo001oo`00<01oo`02000001P0oooo000U0?ooo`030000001gR9T000000300Ool0
00<000000?ooo`3oool0@P3oool6000000@0MhRI00<000000?ooo`3oool0>@3oool00`000000MhRI
07N8V@0=07N8V@030000003oool0oooo04/0oooo00<0000007oo001oo`003P1oo`000`000000MhRI
07N8V@0407N8V@@000009P3oool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo04H0oooo
00<0000007N8V@1gR9T0101gR9T00`000000Ool007oo000`07oo00800000603oool002H0oooo0P00
000_07oo00800000@`3oool2000000@0Ool000<0000007N8V@1gR9T00P1gR9T00`000000oooo0?oo
o`0h0?ooo`030000001gR9T0MhRI00<0MhRI1@00000607N8V@030000003oool0oooo04X0oooo00<0
000007oo001oo`00401oo`000`000000MhRI07N8V@0707N8V@<00000903oool00`000000MhRI07N8
V@0<07N8V@030000003oool0oooo04H0oooo00<0000007N8V@1gR9T00`1gR9T00`000000Ool007oo
000`07oo00030000003oool0oooo01L0oooo000V0?ooo`800000;`1oo`000`000000oooo0?ooo`11
0?ooo`030000001oo`00Ool000D0Ool000@0000007N8V@1gR9T00000>`3oool00`000000MhRI0000
0003000000D0Ool00P00000407N8V@030000003oool0oooo04T0oooo0P00000B07oo00030000001g
R9T0MhRI00X0MhRI0`00000Q0?ooo`030000001gR9T0MhRI00d0MhRI00<000000?ooo`3oool0A@3o
ool00`000000MhRI07N8V@0307N8V@030000001oo`00Ool00300Ool000<000000?ooo`3oool05`3o
ool002L0oooo00<0000007oo001oo`00;@1oo`000`000000oooo0?ooo`100?ooo`800000201oo`00
0`000000MhRI0000000j0?ooo`030000001gR9T0000000/0Ool000D0000007N8V@1gR9T0MhRI0000
001:0?ooo`030000001gR9T0000001<0Ool000<0000007N8V@1gR9T0301gR9T4000001h0oooo00<0
000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`150?ooo`030000001gR9T0MhRI0080MhRI00<0
000007oo001oo`00<01oo`000`000000oooo0?ooo`0G0?ooo`00:03oool00`000000Ool007oo000/
07oo00030000003oool0oooo03l0oooo00<0000007N8V@000000201oo`02000003/0oooo0P00000=
07oo00040000001gR9T0MhRI000004P0oooo0P00000207N8V@030000001oo`00Ool00140Ool000<0
000007N8V@1gR9T0401gR9T3000001/0oooo00<0000007N8V@1gR9T03P1gR9T2000004H0oooo00D0
000007N8V@1gR9T0MhRI0000000b07oo00030000003oool0oooo01L0oooo000X0?ooo`030000001o
o`00Ool002/0Ool00P0000100?ooo`040000001gR9T0MhRI000000P0Ool00P00000k0?ooo`030000
001oo`00Ool000d0Ool000<0000007N8V@000000A`3oool01@000000MhRI07N8V@1gR9T0000001@0
Ool000<0000007N8V@1gR9T04`1gR9T2000001X0oooo00<0000007N8V@1gR9T03`1gR9T00`000000
oooo0?ooo`140?ooo`040000001gR9T0MhRI00000340Ool00P00000I0?ooo`00:@3oool00`000000
Ool007oo000Z07oo00800000?`3oool01@000000MhRI07N8V@1gR9T0000000P0Ool000<000000?oo
o`3oool0>@3oool00`000000Ool007oo000?07oo00800000AP3oool00`000000MhRI07N8V@0207N8
V@030000001oo`00Ool00180Ool000<0000007N8V@1gR9T0401gR9T3000001`0oooo00<0000007N8
V@1gR9T0401gR9T00`000000oooo0?ooo`130?ooo`040000001gR9T0MhRI00000340Ool000<00000
0?ooo`3oool0603oool002T0oooo0P00000Z07oo00800000?`3oool00`000000MhRI07N8V@0207N8
V@030000001oo`00Ool000D0Ool00P00000k0?ooo`030000001oo`00Ool000l0Ool00P0000150?oo
o`030000001gR9T0MhRI00<0MhRI00<0000007oo001oo`004P1oo`000`000000MhRI07N8V@0>07N8
V@800000803oool00`000000MhRI07N8V@0@07N8V@030000003oool0oooo04<0oooo00<0000007N8
V@000000<@1oo`000`000000oooo0?ooo`0H0?ooo`00:P3oool00`000000Ool007oo000W07oo0003
0000001gR9T0000003l0oooo00<0000007N8V@1gR9T00`1gR9T00`000000Ool007oo000407oo0003
0000003oool0oooo03T0oooo00<0000007oo001oo`004@1oo`000`000000oooo0?ooo`120?ooo`03
0000001gR9T0MhRI00@0MhRI00<0000007oo001oo`004P1oo`000`000000MhRI07N8V@0;07N8V@<0
00008`3oool00`000000MhRI07N8V@0@07N8V@030000003oool0oooo04<0oooo00<0000007N8V@00
0000<01oo`000`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000Ool007oo000U07oo00040000
001gR9T0MhRI000003h0oooo00<0000007N8V@1gR9T01@1gR9T6000003`0oooo00<0000007oo001o
o`004@1oo`000`000000oooo0?ooo`110?ooo`030000001gR9T0MhRI00D0MhRI00<0000007oo001o
o`004@1oo`000`000000MhRI07N8V@0907N8V@<000009P3oool00`000000MhRI07N8V@0A07N8V@03
0000003oool0oooo0480oooo00<0000007N8V@000000;`1oo`02000001X0oooo000[0?ooo`800000
9P1oo`0010000000MhRI07N8V@00000m0?ooo`030000001gR9T0MhRI00T0MhRI0P00000l0?ooo`80
00004`1oo`000`000000oooo0?ooo`100?ooo`030000001gR9T0MhRI00L0MhRI00<0000007oo001o
o`00401oo`000`000000MhRI07N8V@0707N8V@800000:P3oool00`000000MhRI07N8V@0A07N8V@80
0000@`3oool00`000000MhRI0000000^07oo008000006P3oool002`0oooo0P00000T07oo00050000
001gR9T0MhRI07N8V@000000?03oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo03`0
oooo0P00000C07oo00030000003oool0oooo03l0oooo00<0000007N8V@1gR9T0201gR9T00`000000
Ool007oo000?07oo00030000001gR9T0MhRI00D0MhRI0`00000/0?ooo`030000001gR9T0MhRI01<0
MhRI00<000000?ooo`3oool0@@3oool2000002h0Ool000<000000?ooo`3oool06@3oool002d0oooo
00<0000007oo001oo`008@1oo`000`000000MhRI07N8V@0207N8V@030000003oool0oooo03T0oooo
00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0m0?ooo`8000004`1oo`000`000000oooo
0?ooo`0n0?ooo`030000001gR9T0MhRI00X0MhRI00<0000007oo001oo`003P1oo`000`000000MhRI
07N8V@0207N8V@<00000<03oool00`000000MhRI07N8V@0C07N8V@030000003oool0oooo0440oooo
0P00000]07oo00030000003oool0oooo01T0oooo000]0?ooo`800000801oo`02000000@0MhRI00<0
00000?ooo`3oool0>@3oool00`000000MhRI07N8V@0907N8V@030000003oool0oooo03l0oooo00<0
000007oo001oo`004@1oo`000`000000oooo0?ooo`0m0?ooo`030000001gR9T0MhRI00`0MhRI00<0
000007oo001oo`00301oo`0010000000MhRI07N8V@1gR9T2000003<0oooo00<0000007N8V@1gR9T0
501gR9T00`000000oooo0?ooo`100?ooo`800000;01oo`000`000000oooo0?ooo`0J0?ooo`00;P3o
ool3000001d0Ool000<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0h0?ooo`030000001g
R9T0MhRI00T0MhRI00<000000?ooo`3oool0@03oool200000140Ool00P00000n0?ooo`030000001g
R9T0MhRI00h0MhRI00<0000007oo001oo`002`1oo`04000003H0oooo00<0000007N8V@1gR9T0501g
R9T00`000000oooo0?ooo`100?ooo`030000001oo`00Ool002X0Ool000<000000?ooo`3oool06P3o
ool002l0oooo00@0000007N8V@00000000006P1oo`000`000000MhRI07N8V@0507N8V@030000003o
ool0oooo03L0oooo00<0000007N8V@1gR9T0201gR9T2000004@0oooo00<0000007oo001oo`003`1o
o`000`000000MhRI0000000l0?ooo`030000001gR9T0MhRI0100MhRI00<0000007oo001oo`00201o
o`03000003T0oooo00<0000007N8V@1gR9T05@1gR9T00`000000oooo0?ooo`100?ooo`030000001o
o`00Ool002P0Ool00P00000L0?ooo`00;`3oool01@000000MhRI07N8V@1gR9T0000001L0Ool00P00
000807N8V@030000003oool0oooo03H0oooo00<0000007N8V@1gR9T0201gR9T00`000000oooo0?oo
o`140?ooo`030000001oo`00Ool000h0Ool000@0000007N8V@1gR9T00000>`3oool00`000000MhRI
07N8V@0B07N8V@030000001oo`00Ool000D0Ool00P00000m0?ooo`030000001gR9T0MhRI01D0MhRI
0P0000100?ooo`030000001oo`00Ool002L0Ool00P00000M0?ooo`00<03oool010000000MhRI07N8
V@1gR9T200000180Ool00`00000:07N8V@030000003oool0oooo03D0oooo00<0000007N8V@1gR9T0
201gR9T00`000000oooo0?ooo`160?ooo`030000001oo`00Ool000d0Ool000@0000007N8V@1gR9T0
0000>P3oool00`000000MhRI07N8V@0D07N8V@P00000?P3oool00`000000MhRI07N8V@0G07N8V@03
0000003oool0oooo03h0oooo00<0000007oo001oo`009@1oo`000`000000MhRI0000000M0?ooo`00
<@3oool00`000000MhRI07N8V@0207N8V@D000002`1oo`02000000d0MhRI00<000000?ooo`3oool0
=03oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo04L0oooo0P00000=07oo00050000
001gR9T0MhRI07N8V@000000>@3oool00`000000MhRI07N8V@0F07N8V@<00000@`3oool00`000000
MhRI07N8V@0G07N8V@030000003oool0oooo03h0oooo00<0000007oo001oo`00901oo`000`000000
MhRI0000000M0?ooo`00<@3oool00`000000MhRI07N8V@0707N8V@/000003P1gR9T00`000000oooo
0?ooo`0d0?ooo`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool0B@3oool2000000X0Ool0
0P00000407N8V@030000003oool0oooo03H0oooo00<0000007N8V@1gR9T05@1gR9T2000004H0oooo
00<0000007N8V@1gR9T0601gR9T00`000000oooo0?ooo`0n0?ooo`030000001oo`00Ool00280Ool0
00@0000007N8V@1gR9T000007@3oool00380oooo00<0000007N8V@1gR9T07`1gR9T00`000000oooo
0?ooo`0c0?ooo`030000001gR9T0MhRI00L0MhRI0P00001<0?ooo`040000001gR9T00000000000L0
Ool000<0000007N8V@1gR9T0101gR9T00`000000oooo0?ooo`0e0?ooo`030000001gR9T0MhRI01<0
MhRI0`0000190?ooo`030000001gR9T0MhRI01P0MhRI00<000000?ooo`3oool0?@3oool200000280
Ool000@0000007N8V@1gR9T000007P3oool003<0oooo00<0000007N8V@1gR9T07P1gR9T00`000000
oooo0?ooo`0b0?ooo`030000001gR9T0MhRI00L0MhRI00<000000?ooo`3oool0C@3oool00`000000
MhRI07N8V@07000000L0MhRI00<000000?ooo`3oool0=03oool00`000000MhRI07N8V@0A07N8V@<0
0000C03oool00`000000MhRI07N8V@0I07N8V@030000003oool0oooo03d0oooo0P00000P07oo0005
0000001gR9T0MhRI07N8V@0000007P3oool003<0oooo00<0000007N8V@1gR9T07P1gR9T00`000000
oooo0?ooo`0b0?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0CP3oool00`000000
MhRI07N8V@0>07N8V@030000003oool0oooo03<0oooo00<0000007N8V@1gR9T03`1gR9T300000500
oooo00<0000007N8V@1gR9T03`1gR9T<000003h0oooo0`00000M07oo00030000001gR9T0MhRI0080
MhRI00<000000?ooo`3oool0703oool003@0oooo00<0000007N8V@1gR9T07@1gR9T00`000000oooo
0?ooo`0a0?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0D03oool00`000000MhRI
07N8V@0=07N8V@030000003oool0oooo0380oooo00<0000007N8V@1gR9T03P1gR9T2000005@0oooo
00<0000007N8V@1gR9T0301gR9T2000000/0Ool00P00000m0?ooo`040000001gR9T0MhRI000001X0
Ool00P00000507N8V@030000003oool0oooo01`0oooo000d0?ooo`030000001gR9T0MhRI01d0MhRI
00<000000?ooo`3oool0<03oool00`000000MhRI07N8V@0607N8V@030000003oool0oooo0540oooo
00<0000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`0`0?ooo`8000003P1gR9T3000005H0oooo
00<0000007N8V@1gR9T02`1gR9T00`000000Ool007oo000=07oo00030000003oool0oooo03/0oooo
00@0000007N8V@1gR9T000005`1oo`02000000H0MhRI00<000000?ooo`3oool07@3oool003D0oooo
00<0000007N8V@1gR9T06`1gR9T00`000000oooo0?ooo`0`0?ooo`030000001gR9T0MhRI00D0MhRI
0P00001E0?ooo`030000001gR9T0MhRI00`0MhRI00<000000?ooo`3oool0;`3oool00`000000MhRI
07N8V@0;07N8V@<00000FP3oool00`000000MhRI07N8V@0907N8V@030000001oo`00Ool000l0Ool0
00<000000?ooo`3oool0>`3oool00`000000MhRI07N8V@0200000180Ool00`00000807N8V@030000
003oool0oooo01d0oooo000f0?ooo`030000001gR9T0MhRI01X0MhRI00<000000?ooo`3oool0;`3o
ool00`000000MhRI07N8V@0507N8V@030000003oool0oooo05D0oooo00<0000007N8V@1gR9T0301g
R9T00`000000oooo0?ooo`0^0?ooo`030000001gR9T0MhRI00X0MhRI0P00001M0?ooo`030000001g
R9T0MhRI00P0MhRI00<0000007oo001oo`004@1oo`000`000000oooo0?ooo`0k0?ooo`040000001g
R9T0MhRI07N8V@D000002`1oo`02000000/0MhRI00<000000?ooo`3oool07@3oool003H0oooo00<0
000007N8V@1gR9T06P1gR9T00`000000oooo0?ooo`0^0?ooo`030000001gR9T0MhRI00D0MhRI00<0
00000?ooo`3oool0E`3oool00`000000MhRI07N8V@0;07N8V@030000003oool0oooo02d0oooo00<0
000007N8V@1gR9T0201gR9T300000600oooo00<0000007N8V@1gR9T01P1gR9T00`000000Ool007oo
000C07oo00030000003oool0oooo03X0oooo00<0000007N8V@1gR9T01P1gR9T;000000d0MhRI00<0
00000?ooo`3oool07@3oool003L0oooo00<0000007N8V@1gR9T06@1gR9T00`000000oooo0?ooo`0]
0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0F03oool00`000000MhRI07N8V@0;
07N8V@030000003oool0oooo02`0oooo00<0000007N8V@1gR9T01P1gR9T3000006<0oooo00<00000
07N8V@1gR9T01@1gR9T00`000000Ool007oo000D07oo00<00000>`3oool00`000000MhRI07N8V@0L
07N8V@030000003oool0oooo01h0oooo000h0?ooo`030000001gR9T0MhRI01P0MhRI00<000000?oo
o`3oool0;03oool00`000000MhRI07N8V@0507N8V@030000003oool0oooo05T0oooo00<0000007N8
V@1gR9T02`1gR9T00`000000oooo0?ooo`0[0?ooo`030000001gR9T0MhRI00D0MhRI0P00001W0?oo
o`030000001gR9T0MhRI00<0MhRI00<0000007oo001oo`005P1oo`000`000000MhRI0000000k0?oo
o`030000001gR9T0MhRI01/0MhRI00<000000?ooo`3oool07P3oool003P0oooo00<0000007N8V@1g
R9T0601gR9T00`000000oooo0?ooo`0[0?ooo`030000001gR9T0MhRI00@0MhRI0P00001M0?ooo`03
0000001gR9T0MhRI00X0MhRI00<000000?ooo`3oool0:P3oool00`000000MhRI07N8V@0307N8V@<0
0000J@3oool00`000000MhRI07N8V@0307N8V@030000001oo`00Ool001L0Ool000<0000007N8V@00
0000>`3oool00`000000MhRI07N8V@0J07N8V@030000003oool0oooo01h0oooo000i0?ooo`030000
001gR9T0MhRI01H0MhRI00<000000?ooo`3oool0:`3oool00`000000MhRI07N8V@0407N8V@030000
003oool0oooo05d0oooo00<0000007N8V@1gR9T02P1gR9T00`000000oooo0?ooo`0Y0?ooo`040000
001gR9T0MhRI07N8V@<00000K@3oool01@000000MhRI07N8V@1gR9T0000001/0Ool000<0000007N8
V@000000>P3oool00`000000MhRI07N8V@0J07N8V@030000003oool0oooo01h0oooo000j0?ooo`03
0000001gR9T0MhRI01D0MhRI00<000000?ooo`3oool0:P3oool00`000000MhRI07N8V@0407N8V@03
0000003oool0oooo05l0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0X0?ooo`03
0000001gR9T0MhRI00800000L03oool01@000000MhRI07N8V@1gR9T0000001/0Ool000@0000007N8
V@1gR9T00000>P3oool00`000000MhRI07N8V@0H07N8V@030000003oool0oooo01l0oooo000j0?oo
o`030000001gR9T0MhRI01D0MhRI00<000000?ooo`3oool0:@3oool00`000000MhRI07N8V@0407N8
V@030000003oool0oooo0600oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0W0?oo
o`@00000L`3oool010000000MhRI07N8V@00000K07oo00050000001gR9T0MhRI07N8V@000000>P3o
ool00`000000MhRI07N8V@0G07N8V@030000003oool0oooo01l0oooo000k0?ooo`030000001gR9T0
MhRI01@0MhRI00<000000?ooo`3oool0:03oool00`000000MhRI07N8V@0307N8V@800000I03oool0
0`000000MhRI07N8V@0907N8V@030000003oool0oooo02D0oooo0P00001f0?ooo`040000001gR9T0
MhRI000001/0Ool000<0000007N8V@1gR9T00P1gR9T2000003P0oooo00<0000007N8V@1gR9T05`1g
R9T00`000000oooo0?ooo`0O0?ooo`00?03oool00`000000MhRI07N8V@0C07N8V@030000003oool0
oooo02L0oooo00<0000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`1T0?ooo`030000001gR9T0
MhRI00T0MhRI00<000000?ooo`3oool0WP3oool00`000000MhRI0000000K07oo00030000001gR9T0
MhRI00@0MhRI00<000000?ooo`3oool0=P3oool00`000000MhRI07N8V@0F07N8V@030000003oool0
oooo01l0oooo000l0?ooo`030000001gR9T0MhRI0180MhRI00<000000?ooo`3oool0:03oool00`00
0000MhRI07N8V@0207N8V@030000003oool0oooo06H0oooo00<0000007N8V@1gR9T0201gR9T00`00
0000oooo0?ooo`2N0?ooo`030000001gR9T0000001/0Ool000<0000007N8V@1gR9T01@1gR9T00`00
0000oooo0?ooo`0f0?ooo`030000001gR9T0MhRI01@0MhRI00<000000?ooo`3oool0803oool003d0
oooo00<0000007N8V@1gR9T04@1gR9T00`000000oooo0?ooo`0W0?ooo`030000001gR9T0MhRI0080
MhRI00<000000?ooo`3oool0I`3oool00`000000MhRI07N8V@0807N8V@030000003oool0oooo09l0
oooo0P00000K07oo00030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0=P3oool00`000000
MhRI07N8V@0C07N8V@030000003oool0oooo0200oooo000m0?ooo`030000001gR9T0MhRI0140MhRI
00<000000?ooo`3oool09P3oool00`000000MhRI07N8V@0207N8V@030000003oool0oooo06T0oooo
00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`2P0?ooo`030000001oo`00Ool001T0Ool0
00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0e0?ooo`030000001gR9T0MhRI01<0MhRI
00<000000?ooo`3oool0803oool003h0oooo00<0000007N8V@1gR9T0401gR9T00`000000oooo0?oo
o`0U0?ooo`040000001gR9T0MhRI07N8V@800000K03oool00`000000MhRI07N8V@0707N8V@030000
003oool0oooo0:00oooo00<0000007oo001oo`006@1oo`000`000000MhRI07N8V@0807N8V@030000
003oool0oooo03D0oooo00<0000007N8V@1gR9T04@1gR9T00`000000oooo0?ooo`0Q0?ooo`00?`3o
ool00`000000MhRI07N8V@0?07N8V@030000003oool0oooo02@0oooo00D0000007N8V@1gR9T0MhRI
0000001_0?ooo`030000001gR9T0MhRI00H0MhRI00<000000?ooo`3oool0X@3oool00`000000Ool0
07oo000G07oo00030000001gR9T0MhRI00X0MhRI0P00000f0?ooo`030000001gR9T0MhRI0100MhRI
00<000000?ooo`3oool08@3oool003l0oooo00<0000007N8V@1gR9T03`1gR9T00`000000oooo0?oo
o`0S0?ooo`050000001gR9T0MhRI07N8V@000000L03oool00`000000MhRI07N8V@0607N8V@030000
003oool0oooo0:40oooo00<0000007oo001oo`005`1oo`000`000000MhRI07N8V@0<07N8V@030000
003oool0oooo03<0oooo00<0000007N8V@1gR9T0401gR9T00`000000oooo0?ooo`0Q0?ooo`00@03o
ool00`000000MhRI07N8V@0=07N8V@030000003oool0oooo02<0oooo00D0000007N8V@1gR9T0MhRI
0000001b0?ooo`030000001gR9T0MhRI00D0MhRI00<000000?ooo`3oool0XP3oool00`000000Ool0
07oo000E07oo00030000001gR9T0MhRI00h0MhRI00<000000?ooo`3oool0<`3oool00`000000MhRI
07N8V@0?07N8V@030000003oool0oooo0240oooo00110?ooo`030000001gR9T0MhRI00`0MhRI00<0
00000?ooo`3oool08P3oool01@000000MhRI07N8V@1gR9T0000007<0oooo00<0000007N8V@1gR9T0
1@1gR9T00`000000oooo0?ooo`2R0?ooo`030000001oo`00Ool001D0Ool000<0000007N8V@1gR9T0
3@1gR9T3000003D0oooo00<0000007N8V@1gR9T03@1gR9T00`000000oooo0?ooo`0R0?ooo`00@@3o
ool00`000000MhRI07N8V@0<07N8V@030000003oool0oooo0240oooo00<0000007N8V@1gR9T00P00
001e0?ooo`030000001gR9T0MhRI00@0MhRI00<000000?ooo`3oool0X`3oool00`000000Ool007oo
000C07oo00030000001gR9T0MhRI00X0MhRI1000000i0?ooo`030000001gR9T0MhRI00`0MhRI00<0
00000?ooo`3oool08P3oool00480oooo00<0000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`0P
0?ooo`040000001gR9T0MhRI000007L0oooo00<0000007N8V@1gR9T0101gR9T00`000000oooo0?oo
o`2S0?ooo`800000501oo`000`000000MhRI07N8V@0607N8V@@00000?@3oool00`000000MhRI07N8
V@0<07N8V@030000003oool0oooo0280oooo00130?ooo`030000001gR9T0MhRI00X0MhRI00<00000
0?ooo`3oool07`3oool010000000MhRI07N8V@00001h0?ooo`030000001gR9T0MhRI00@0MhRI00<0
00000?ooo`3oool0Y03oool200000180Ool000<0000007N8V@1gR9T00`1gR9T400000480oooo00<0
000007N8V@1gR9T02`1gR9T00`000000oooo0?ooo`0R0?ooo`00@`3oool00`000000MhRI07N8V@0:
07N8V@030000003oool0oooo01h0oooo00@0000007N8V@1gR9T00000NP3oool00`000000MhRI07N8
V@0307N8V@030000003oool0oooo0:@0oooo00<0000007N8V@0000003`1oo`0200000080MhRI1000
00170?ooo`030000001gR9T0MhRI00T0MhRI00<000000?ooo`3oool08`3oool004@0oooo00<00000
07N8V@1gR9T0201gR9T00`000000oooo0?ooo`0N0?ooo`040000001gR9T0MhRI000007/0oooo00<0
000007N8V@1gR9T00`1gR9T00`000000oooo0?ooo`2U0?ooo`030000001gR9T00000008000002P1o
o`06000004/0oooo00<0000007N8V@1gR9T02@1gR9T00`000000oooo0?ooo`0S0?ooo`00A@3oool0
0`000000MhRI07N8V@0707N8V@030000003oool0oooo01d0oooo00@0000007N8V@0000000000O@3o
ool00`000000MhRI07N8V@0207N8V@030000003oool0oooo0:D0oooo00<0000007N8V@1gR9T00P1g
R9T3000000<0Ool01P00001@0?ooo`030000001gR9T0MhRI00P0MhRI00<000000?ooo`3oool08`3o
ool004D0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0M0?ooo`800000O`3oool0
0`000000MhRI07N8V@0207N8V@030000003oool0oooo0:H0oooo00<0000007N8V@1gR9T0101gR9T5
000005D0oooo00<0000007N8V@1gR9T01`1gR9T00`000000oooo0?ooo`0S0?ooo`00AP3oool00`00
0000MhRI07N8V@0607N8V@030000003oool0oooo01`0oooo0P0000210?ooo`050000001gR9T0MhRI
07N8V@000000Z03oool010000000MhRI07N8V@1gR9T4000005X0oooo00<0000007N8V@1gR9T01@1g
R9T00`000000oooo0?ooo`0T0?ooo`00A`3oool00`000000MhRI07N8V@0507N8V@030000003oool0
oooo01/0oooo0P0000220?ooo`050000001gR9T0MhRI07N8V@000000Z@3oool3000005h0oooo00<0
000007N8V@1gR9T01@1gR9T00`000000oooo0?ooo`0T0?ooo`00A`3oool00`000000MhRI07N8V@05
07N8V@030000003oool0oooo01X0oooo0P0000240?ooo`050000001gR9T0MhRI07N8V@000000o`3o
ool;0?ooo`030000001gR9T0MhRI00@0MhRI00<000000?ooo`3oool0903oool004P0oooo00<00000
07N8V@1gR9T00`1gR9T00`000000oooo0?ooo`0J0?ooo`800000Q@3oool01@000000MhRI07N8V@1g
R9T000000?l0oooo303oool00`000000MhRI07N8V@0307N8V@030000003oool0oooo02@0oooo0018
0?ooo`030000001gR9T0MhRI00<0MhRI00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`26
0?ooo`040000001gR9T0MhRI00000?l0oooo303oool00`000000MhRI07N8V@0207N8V@030000003o
ool0oooo02D0oooo00190?ooo`030000001gR9T0MhRI0080MhRI00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`270?ooo`040000001gR9T0MhRI00000?l0oooo3@3oool01@000000MhRI07N8
V@1gR9T0000002L0oooo001:0?ooo`050000001gR9T0MhRI07N8V@000000Y@3oool00`000000MhRI
0000003o0?ooo`h0oooo00@0000007N8V@1gR9T000009`3oool004X0oooo00D0000007N8V@1gR9T0
MhRI0000002U0?ooo`030000001gR9T000000?l0oooo3`3oool00`000000MhRI0000000W0?ooo`00
B`3oool010000000MhRI07N8V@00002V0?ooo`800000o`3oool?0?ooo`800000:03oool004`0oooo
0P00002W0?ooo`800000o`3oool@0?ooo`030000003oool0oooo02H0oooo001<0?ooo`800000Z03o
ool00`000000oooo0?ooo`3o0?ooocL0oooo001=0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0oooo
o`3ooola0?ooo`00o`3ooooo0?oooc40oooo003o0?ooool0oooo<@3oool00?l0ooooo`3ooola0?oo
o`00o`3ooooo0?oooc40oooo0000\
\>"],
  ImageRangeCache->{{{0, 558.813}, {221, 0}} -> {-0.158622, -0.0594969, \
0.0113048, 0.0113048}, {{14, 95.625}, {215.688, 115.5}} -> {0.240551, \
0.426644, 0.00456878, 0.00456878}, {{103.813, 185.5}, {215.688, 115.5}} -> \
{-0.56462, 0.118803, 0.00795916, 0.00795916}, {{193.625, 275.313}, {215.688, \
115.5}} -> {-1.55849, -0.103351, 0.00911608, 0.00911608}, {{283.438, \
365.125}, {215.688, 115.5}} -> {-1.90745, 0.0459096, 0.00726337, 0.00726337}, \
{{373.25, 454.938}, {215.688, 115.5}} -> {-2.19224, 0.476332, 0.00692627, \
0.00692627}, {{463.125, 544.75}, {215.688, 115.5}} -> {-2.37746, 0.247169, \
0.0057124, 0.0057124}, {{14, 95.625}, {105.438, 5.25}} -> {0.112926, \
-0.0709746, 0.00415901, 0.00415901}, {{103.813, 185.5}, {105.438, 5.25}} -> \
{-0.140223, -0.258762, 0.00474925, 0.00474925}, {{193.625, 275.313}, \
{105.438, 5.25}} -> {-1.4594, -0.51443, 0.00662225, 0.00662225}, {{283.438, \
365.125}, {105.438, 5.25}} -> {-2.00471, -0.84752, 0.00745589, 0.00745589}, \
{{373.25, 454.938}, {105.438, 5.25}} -> {-3.99787, -1.3093, 0.0108887, \
0.0108887}, {{463.125, 544.75}, {105.438, 5.25}} -> {-2.92205, -0.442319, \
0.00671973, 0.00671973}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Types", "Subsection"],

Cell["\<\
Figures of types 2 and 3 arise from computing further tangent circles. For \
instance, three type 2 figures appear when computing the greatest circle \
inscribed in a type 1 figure:\
\>", "Text"],

Cell[BoxData[
    \(disP2Cir[p_, c_, r_] := Abs[size[p - c] - r]\)], "Input",
  CellLabel->"In[49]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]\^2 == 
        disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]\^2 \[Equal] 
        disP2Cir[{x, y}, {1, 1\/\@3}, 1\/\@3]\^2]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[50]:="],

Cell[BoxData[
    \({{x \[Rule] \(-1\), y \[Rule] \@3}, {x \[Rule] 1, 
        y \[Rule] 1\/\@3}, {x \[Rule] 1, y \[Rule] \(-\@3\)}, {x \[Rule] 3, 
        y \[Rule] \@3}, {x \[Rule] \(11\/\(9\ \@3\) - \@3\)\/\(2\/\(3\ \@3\) \
- 2\ \@3\), y \[Rule] 1\/\(3\ \@3\)}}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(centres = {x, y} /. %;\)\), "\[IndentingNewLine]", 
    \(shG[{Line[triangle], {Burlywood, 
          Disk[{1, 1\/\@3}, 
            1\/\@3]}, \(Circle[#, 
              disP2Seg[#, 
                triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
                triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]] &\) /@ centres}]\)}], "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9282 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.372405 0.127595 0.464102 0.127595 [
[ 0 0 0 0 ]
[ 1 .9282 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.37241 .4641 m
.62759 .4641 L
.5 .6851 L
.37241 .4641 L
s
.871 .722 .529 r
.5 .53777 m
.5 .53777 .07367 0 365.73 arc
F
0 g
newpath
.24481 .6851 .221 0 365.73 arc
s
newpath
.5 .53777 .07367 0 365.73 arc
s
newpath
.5 .2431 .221 0 365.73 arc
s
newpath
.75519 .6851 .221 0 365.73 arc
s
newpath
.41494 .48866 .02456 0 365.73 arc
s
0 0 m
1 0 L
1 .9282 L
0 .9282 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{288, 267.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00012b000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00Q03ooolG000008D0oooo001o0?ooo`D000005`3oool500000800oooo
001l0?ooo`<000008@3oool3000007d0oooo001j0?ooo`8000009`3oool2000007/0oooo001g0?oo
o`<00000:`3oool3000007P0oooo001e0?ooo`800000<@3oool2000007H0oooo001c0?ooo`800000
=@3oool2000007@0oooo001a0?ooo`800000>@3oool200000780oooo001_0?ooo`800000?@3oool2
00000700oooo001^0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0K@3oool006`0
oooo0P0000130?ooo`800000K@3oool006X0oooo0P0000170?ooo`800000J`3oool006P0oooo0P00
001;0?ooo`800000J@3oool006L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1V
0?ooo`00IP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06D0oooo001U0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0I03oool006@0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`1S0?ooo`00I03oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo06<0oooo001S0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0HP3oool0
0680oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1Q0?ooo`00H@3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0600oooo001O0?ooo`800000G@3oool200000600oooo
001N0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G@3oool005d0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`1L0?ooo`00G@3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo05`0oooo001L0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0F`3oool005/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1K0?ooo`00F`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo05X0oooo001J0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0F@3oool005X0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1I0?ooo`00F@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05P0
oooo001H0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0E`3oool005P0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`00E`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo05H0oooo001F0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0EP3oool005H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1E0?ooo`00
EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0oooo001E0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0E03oool005D0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
05<0oooo001D0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0D`3oool005<0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1B0?ooo`00D`3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1A0?oo
o`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0540oooo001A0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0D03oool00540
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0D03oool00500oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1@
0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool0
0500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0C`3o
ool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1?0?ooo`00D03oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo04l0oooo001@
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0D03oool00540oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo0500oooo001A0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
D03oool00540oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1@0?ooo`00D@3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0540oooo001B0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1A0?ooo`00DP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0540oooo
001B0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0D@3oool00580oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo0580oooo001C0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool0DP3oool005@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1C0?ooo`00E03o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0E03oool005D0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`1E0?ooo`00EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0
oooo001F0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0E@3oool005L0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`1F0?ooo`00E`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo05H0oooo001H0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0E`3oool005P0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1G0?ooo`00
F@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05P0oooo001J0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0F@3oool005X0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1I0?ooo`00F`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
05X0oooo001K0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0F`3oool005`0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1K0?ooo`00G@3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo05`0oooo001M0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0G03oool005h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1M0?oo
o`00G`3oool2000005d0oooo0P00001P0?ooo`00H@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0600oooo001R0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0H@3o
ool006<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0I03oool006H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1U0?ooo`00IP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06D0oooo001W
0?ooo`800000C@3oool2000006P0oooo001Y0?ooo`800000B@3oool2000006X0oooo001[0?ooo`80
0000A@3oool2000006`0oooo001]0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
K03oool006h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1]0?ooo`00K`3oool2
000003d0oooo0P00001`0?ooo`00L@3oool2000003T0oooo0P00001b0?ooo`00L`3oool2000003D0
oooo0P00001d0?ooo`00M@3oool200000340oooo0P00001f0?ooo`00M`3oool3000002/0oooo0`00
001h0?ooo`00NP3oool3000002D0oooo0`00001k0?ooo`00O@3oool3000001l0oooo0`00001n0?oo
o`00P03oool5000001D0oooo1@0000210?ooo`00@`3oool700000200ooooB`00000P0?ooo`L00000
A03oool003/0oooo200000070?ooo`P000006@3oool00`000000oooo0?ooo`060?ooo`8000000`3o
ool2000000d0oooo1P0000040=jhQ`@000007@3oool00`000000oooo0?ooo`0G0?ooo`P000001`3o
ool8000003`0oooo000f0?ooo`D000005`3oool4000001D0oooo00<000000?ooo`3oool0103oool2
000000L0oooo00<000000?ooo`3oool0203oool2000000h0g[R70P00000K0?ooo`030000003oool0
oooo01<0oooo1000000G0?ooo`D00000=`3oool003<0oooo0`00000P0?ooo`<000004`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool20000
0180g[R70P00000H0?ooo`030000003oool0oooo0140oooo0`00000P0?ooo`<00000=03oool00340
oooo0P00000V0?ooo`<00000403oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?oo
o`3oool0103oool00`000000g[R70=jhQ`0D0=jhQ`030000003oool0oooo01D0oooo00<000000?oo
o`3oool03P3oool3000002H0oooo0P00000b0?ooo`00;P3oool3000002/0oooo0`00000>0?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool00P3oool00`000000g[R70=jhQ`0F0=jh
Q`800000503oool00`000000oooo0?ooo`0<0?ooo`<00000:`3oool3000002l0oooo000[0?ooo`<0
0000<@3oool3000000/0oooo00@000000?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0
000001/0g[R700<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`<00000<@3oool3
000002`0oooo000Y0?ooo`800000=`3oool2000000X0oooo00<000000?ooo`0000003@3oool00`00
0000oooo0000000M0=jhQ`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool20000
03L0oooo0P00000Z0?ooo`009`3oool2000003/0oooo0P0000090?ooo`8000003@3oool2000001l0
g[R700<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03T0
oooo0P00000X0?ooo`009@3oool2000003l0oooo00<000000?ooo`3oool01P3oool2000000`0oooo
0P00000P0=jhQ`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool2000003h0oooo
0P00000V0?ooo`008`3oool200000480oooo0P0000070?ooo`030000003oool0oooo00X0oooo00<0
00000=jhQ`3N^8L0803N^8L00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo0P00
00120?ooo`800000903oool00280oooo00<000000?ooo`3oool0A03oool2000000D0oooo00<00000
0?ooo`3oool02@3oool00`000000g[R70=jhQ`0R0=jhQ`8000002`3oool00`000000oooo0?ooo`03
0?ooo`800000AP3oool00`000000oooo0?ooo`0Q0?ooo`008@3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000g[R70=jhQ`0S0=jh
Q`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo0200oooo000O0?ooo`800000B`3oool00`000000oooo0?ooo`030?ooo`80
00001P3oool2000002H0g[R700<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04T0oooo0P00000P0?ooo`007P3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@0000000`3oool000000=jhQ`0U0=jhQ`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo01d0oooo000M0?ooo`030000003oool0oooo04h0oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo00<000000=jhQ`3N^8L09@3N^8L00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo0?ooo`800000D03oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000oooo0?oo
o`1A0?ooo`040000003oool0oooo000000L0oooo00<000000=jhQ`3N^8L09@3N^8L00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000005<0oooo00<000000?ooo`3oool06`3oool001/0oooo
00<000000?ooo`3oool0D`3oool010000000oooo0?ooo`0000050?ooo`030000003N^8L0g[R702L0
g[R700<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001E0?ooo`8000006`3oool001X0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo000000050?ooo`030000003N^8L0g[R702L0
g[R700<000000?ooo`3oool00`3oool00`000000oooo0000001H0?ooo`030000003oool0oooo01P0
oooo000I0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`000000103oool00`000000g[R7
0=jhQ`0W0=jhQ`030000003oool0oooo0080oooo00<000000?ooo`000000FP3oool00`000000oooo
0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`1H0?ooo`040000003oool0oooo000000<0oooo
00<000000=jhQ`3N^8L09`3N^8L01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0000000<0oooo00<000000=jhQ`3N^8L09`3N^8L01`000000oooo0?ooo`3oool000000?oo
o`000000G03oool00`000000oooo0?ooo`0F0?ooo`005P3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool000000080oooo00<000000=jhQ`3N^8L09`3N^8L01P000000oooo0?ooo`000000oooo
000005h0oooo00<000000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0GP3oool20000
0080oooo00<000000=jhQ`3N^8L09`3N^8L00`000000oooo0?ooo`0200000600oooo00<000000?oo
o`3oool0503oool001@0oooo00<000000?ooo`3oool0H03oool2000000030?ooo`000000g[R702P0
g[R700@000000?ooo`0000000000HP3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0000002T0g[R700<000000?ooo`000000I03oool00`000000
oooo0?ooo`0B0?ooo`004P3oool00`000000oooo0?ooo`1T0?ooo`800000:@3N^8L2000006H0oooo
00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0I03oool3000002L0g[R70`00
001V0?ooo`030000003oool0oooo0140oooo000A0?ooo`030000003oool0oooo06H0oooo0P00000W
0=jhQ`800000J03oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`1W0?oo
o`030000003N^8L0g[R702@0g[R70P00001Y0?ooo`030000003oool0oooo0100oooo000@0?ooo`03
0000003oool0oooo06P0oooo00<000000=jhQ`3N^8L0903N^8L2000006X0oooo00<000000?ooo`3o
ool03`3oool00100oooo00<000000?ooo`3oool0J@3oool00`000000g[R70=jhQ`0S0=jhQ`030000
003oool0oooo06T0oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool0JP3o
ool2000002<0g[R70P00001/0?ooo`030000003oool0oooo00h0oooo000>0?ooo`030000003oool0
oooo06`0oooo00<000000=jhQ`3N^8L0803N^8L2000006h0oooo00<000000?ooo`3oool03@3oool0
00h0oooo00<000000?ooo`3oool0K@3oool00`000000g[R70=jhQ`0N0=jhQ`800000K`3oool00`00
0000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?ooo`1^0?ooo`8000007`3N^8L200000700
oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0K`3oool2000001d0g[R7
0P00001a0?ooo`030000003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`000000703N^8L200000780oooo00<000000?ooo`3oool02`3oool000`0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0000000I0=jhQ`<00000L`3oool00`000000oooo0?ooo`0;
0?ooo`002`3oool00`000000oooo0?ooo`1b0?ooo`80000000<0oooo0000003N^8L05@3N^8L20000
00030?ooo`000000000007@0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3o
ool0LP3oool200000080oooo00<000000=jhQ`3N^8L04P3N^8L010000000oooo0?ooo`3oool20000
07@0oooo00<000000?ooo`3oool02P3oool000X0oooo00<000000?ooo`3oool0M03oool200000080
oooo0P00000@0=jhQ`8000000`3oool2000007H0oooo00<000000?ooo`3oool02@3oool000X0oooo
00<000000?ooo`3oool0M03oool2000000@0oooo1P0000060=jhQ`@000001@3oool2000007H0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0M03oool00`000000oooo0000
00090?ooo`H00000203oool00`000000oooo0000001f0?ooo`030000003oool0oooo00T0oooo0009
0?ooo`030000003oool0oooo07H0oooo0P00000G0?ooo`800000N03oool00`000000oooo0?ooo`08
0?ooo`002@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0000001D0oooo00<000000?oo
o`000000N03oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`1f0?ooo`04
0000003oool0oooo000001<0oooo00<000000?ooo`000000N@3oool00`000000oooo0?ooo`080?oo
o`002@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0000001<0oooo00<000000?ooo`00
0000NP3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`1h0?ooo`040000
003oool0oooo00000140oooo00@000000?ooo`3oool00000NP3oool00`000000oooo0?ooo`070?oo
o`00203oool00`000000oooo0?ooo`1h0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`000000N`3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`1i0?ooo`04
0000003oool0oooo000000l0oooo00@000000?ooo`3oool00000N`3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo000000l0oooo00@00000
0?ooo`3oool00000N`3oool00`000000oooo0?ooo`070?ooo`001`3oool00`000000oooo0?ooo`1j
0?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool0000007/0oooo
00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`060?ooo`001`3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01P3o
ool000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1k0?ooo`030000003oool0
oooo00H0oooo00060?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`06
0?ooo`001P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`060?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3o
ool01P3oool000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo07/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01P3o
ool000L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo07/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01P3oool000L0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool01P3oool000L0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0203oool0
00T0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0203oool000X0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool02`3o
ool000d0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0K03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool03@3oool000l0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool03`3oool00100oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
403oool00180oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool04@3oool0
01<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool04`3oool001@0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool04`3oool001D0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0503oool001H0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool05P3oool001P0oooo0P00001I0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0E`3oool2000001T0oooo000J0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo01T0oooo000K0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo000L0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo01/0oooo000M0?ooo`030000003oool0oooo04h0oooo0P00000o0?ooo`800000D03oool00`00
0000oooo0?ooo`0L0?ooo`007P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0M0?ooo`007`3oool2000004/0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`190?ooo`800000803oool00240oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0803oool00280oooo00<000000?ooo`3oool0A03oool2000004T0oooo0P000016
0?ooo`030000003oool0oooo0240oooo000S0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0280oooo000T0?ooo`80
0000@03oool2000004l0oooo0P0000100?ooo`8000009@3oool002H0oooo0P00000m0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0>`3oool2000002L0oooo000X0?ooo`800000>@3o
ool2000005D0oooo0P00000i0?ooo`800000:@3oool002X0oooo0P00000e0?ooo`800000F@3oool2
000003D0oooo0P00000[0?ooo`00;03oool200000340oooo0P00001M0?ooo`800000<@3oool20000
02d0oooo000^0?ooo`<00000:`3oool300000640oooo0`00000[0?ooo`<00000;`3oool00340oooo
0`00000U0?ooo`<00000I`3oool3000002D0oooo0`00000b0?ooo`00=03oool3000001h0oooo1000
001]0?ooo`@000007P3oool3000003D0oooo000g0?ooo`H000004P3oool6000007D0oooo1P00000B
0?ooo`H00000>03oool003d0oooo4P0000210?oooa800000?P3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {266.313, 0}} -> {-2.91988, -3.63734, \
0.0273162, 0.0273162}}]
}, Open  ]],

Cell["\<\
Note that four circles have the stated property, i. e.,  they are at the same \
distance from lines ab and ac and the coloured circle above. We need to \
select the inner one.  Let us first solve two interesting related problems.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Problem: Draw n circles consecutively tangent so that all are tangent to the \
x axis and a line passing through the origin, given the first of those \
circles\
\>", "Subsubsection"],

Cell["\<\
Consider the first two circles and let the first one (given) have radius R \
and centre at (X, R) and the second one radius r and centre  at (x, r)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Solve[{\((r + R)\)\^2 \[Equal] \((R - r)\)\^2 + \((X - x)\)\^2, 
          R\/X == r\/x}, {x, r}]]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({{r \[Rule] \(R\ \((X\^2 + 2\ R\ \((R - \@\(R\^2 + \
X\^2\))\))\)\)\/X\^2, 
        x \[Rule] \(X\^2 + 2\ R\ \((R - \@\(R\^2 + X\^2\))\)\)\/X}, {r \
\[Rule] \(R\ \((X\^2 + 2\ R\ \((R + \@\(R\^2 + X\^2\))\))\)\)\/X\^2, 
        x \[Rule] \(X\^2 + 2\ R\ \((R + \@\(R\^2 + X\^2\))\)\)\/X}}\)], \
"Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["\<\
The first set of data corresponds to the antecedent of the circle of radius R \
and the other to its consequent\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c = 
      FullSimplify[
        NestList[{u = \(First[#]\^2 + 2\ Last[#]\ \((Last[#] - \@\(Last[#]\^2 \
+ First[#]\^2\))\)\)\/First[#], \(Last[#]\/First[#]\) u} &, {15, 3}, 
          4]]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({{15, 3}, {1\/5\ \((81 - 6\ \@26)\), 
        1\/25\ \((81 - 6\ \@26)\)}, {3\/125\ \((27 - 2\ \@26)\)\^2, 
        3\/625\ \((27 - 2\ \@26)\)\^2}, {\(-\(\(3\ \((\(-27\) + 2\ \@26)\)\^3\
\)\/3125\)\), \(-\(\(3\ \((\(-27\) + 2\ \@26)\)\^3\)\/15625\)\)}, {\(-\(\(3\ \
\((\(-997153\) + 179928\ \@26)\)\)\/78125\)\), \(-\(\(3\ \((\(-997153\) + 
                    179928\ \@26)\)\)\/390625\)\)}}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(shG[\(Circle[#, Last[#]] &\) /@ c]\)], "Input",
  CellLabel->"In[55]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.126122 0.0612396 0.00918594 0.0612396 [
[ 0 0 0 0 ]
[ 1 .38581 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.79247 .1929 .18372 0 365.73 arc
s
newpath
.49124 .13266 .12347 0 365.73 arc
s
newpath
.2888 .09217 .08298 0 365.73 arc
s
newpath
.15274 .06496 .05577 0 365.73 arc
s
newpath
.06129 .04667 .03748 0 365.73 arc
s
0 0 m
1 0 L
1 .38581 L
0 .38581 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{288, 111.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Kb000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00403oool600000180oooo2000000O0?ooo`T00000
<03oool:000004T0oooo4000000e0?ooo`003@3oool3000000H0oooo0P00000>0?ooo`800000203o
ool2000001T0oooo100000090?ooo`800000:@3oool5000000X0oooo1@00000o0?ooo`D00000403o
ool500000300oooo000<0?ooo`030000003oool0oooo00T0oooo0P00000:0?ooo`800000303oool2
000001D0oooo0P00000?0?ooo`<000008`3oool3000001@0oooo0`00000j0?ooo`8000006P3oool2
000002h0oooo000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool20000
0100oooo0P00000A0?ooo`800000503oool2000001l0oooo0P00000J0?ooo`800000=@3oool30000
01h0oooo0`00000[0?ooo`002@3oool2000000l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool2000001/0
oooo0P00000N0?ooo`800000<@3oool2000002@0oooo0P00000Y0?ooo`00203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01T0oooo0P00000H0?ooo`030000003oool0oooo0200oooo
0P00000]0?ooo`800000:03oool2000002L0oooo00080?ooo`030000003oool0oooo0100oooo00D0
00000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo00P0oooo0P00000M0?ooo`030000
003oool0oooo01@0oooo0P00000U0?ooo`030000003oool0oooo02L0oooo0`00000/0?ooo`<00000
903oool000L0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000001T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`800000<P3oool200000280oooo
00070?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000006`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3oool2000002X0oooo00<0
00000?ooo`3oool08@3oool2000003H0oooo0P00000P0?ooo`001`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:`3oool200000200oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`001`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0000001`0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0703oool000L0oooo00<000000?ooo`3oool04P3oool20000
01d0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0I0?ooo`800000?P3oool2000001`0oooo00070?oo
o`030000003oool0oooo0180oooo0P00000M0?ooo`040000003oool0oooo000002T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`001`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01d0oooo0P00000Z0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0603oool000P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`80
0000:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo0P00000E0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool05`3oool000P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0M0?ooo`800000:`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01H0oooo00090?ooo`030000003oool0oooo00l0oooo0P00000O0?ooo`800000:`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo00090?ooo`030000003oool0
oooo00l0oooo0P00000O0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0D0?ooo`002P3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000
003oool07P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool04`3oool000/0oooo0P00000;0?ooo`050000003oool0oooo0?ooo`0000007P3oool20000
02d0oooo00@000000?ooo`3oool00000?@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool04P3oool000d0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo0P00000]0?ooo`040000003oool0oooo
000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0180oooo000>0?ooo`X000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`000000?`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool000000400oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0100oooo000N0?ooo`030000003oool0oooo01T0oooo
0P00000^0?ooo`800000@P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool03`3oool001h0oooo00<000000?ooo`3oool06@3oool2000002h0oooo0P00
00120?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0?0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0000002h0oooo0P000012
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000002h0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0
000002h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool03@3oool00240oooo0P00000C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0<0?ooo`008`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`120?ooo`050000003oool0oooo0?ooo`000000G@3oool00`000000oooo0?ooo`0<0?oo
o`00903oool3000000`0oooo0P0000070?ooo`030000003oool0oooo02X0oooo0P0000140?ooo`05
0000003oool0oooo0?ooo`000000GP3oool00`000000oooo0?ooo`0;0?ooo`009`3oool2000000P0
oooo0P0000090?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0@`3oool010000000
oooo0?ooo`00001O0?ooo`030000003oool0oooo00/0oooo000Y0?ooo`P00000303oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000H03oool00`000000
oooo0?ooo`0:0?ooo`00?@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`000000H03oool00`000000oooo0?ooo`0:0?ooo`00?@3oool00`000000oooo0?oo
o`0X0?ooo`800000AP3oool200000680oooo00<000000?ooo`3oool02@3oool003h0oooo00<00000
0?ooo`3oool09`3oool2000004H0oooo0P00001R0?ooo`030000003oool0oooo00T0oooo000o0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`000000AP3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo00T0oooo000o0?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3o
ool00000AP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00P0oooo00100?ooo`03
0000003oool0oooo0280oooo00D000000?ooo`3oool0oooo000000160?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0203oool00400oooo00<000000?ooo`3oool08P3oool01@000000
oooo0?ooo`3oool0000004H0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`080?oo
o`00@@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@`3oool2000006@0oooo00<000000?ooo`3oool0203oool00480oooo0P00000O0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo00P0oooo00140?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01`3o
ool004D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`070?ooo`00AP3oool20000
01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool01`3oool004P0oooo0P00000C0?ooo`<000002P3oool00`000000
oooo0?ooo`110?ooo`800000IP3oool00`000000oooo0?ooo`070?ooo`00BP3oool2000000l0oooo
0P00000>0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`070?ooo`00C03oool?00000100oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo00H0oooo001[0?ooo`030000003oool0oooo03l0oooo0P00001X
0?ooo`030000003oool0oooo00H0oooo001/0?ooo`030000003oool0oooo03h0oooo0P00001X0?oo
o`030000003oool0oooo00H0oooo001/0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`00
0000J03oool00`000000oooo0?ooo`060?ooo`00K@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0000006P0oooo00<000000?ooo`3oool01P3oool006h0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`00001X0?ooo`030000003oool0oooo00H0oooo001^0?ooo`030000003o
ool0oooo03X0oooo00@000000?ooo`3oool00000J03oool00`000000oooo0?ooo`060?ooo`00KP3o
ool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo0?ooo`000000J03oool00`000000oooo
0?ooo`060?ooo`00K`3oool00`000000oooo0?ooo`0h0?ooo`050000003oool0oooo0?ooo`000000
J03oool00`000000oooo0?ooo`060?ooo`00K`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`060?ooo`00L03oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`060?ooo`00L@3oool2000003@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo00H0oooo001c0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0
oooo001d0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00L0oooo001d0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00L0oooo001e
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00L0oooo001f0?ooo`800000:P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool01`3oool007P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0203oool007T0oooo0P00000U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`080?ooo`00N`3oool00`000000oooo0?ooo`0P0?ooo`800000403o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00P0oooo001l0?ooo`<00000703oool3
00000180oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`080?ooo`00O`3oool20000
01P0oooo0P00000E0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0203oool00840
oooo0`00000B0?ooo`<000005`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00T0
oooo00240?oooa8000006`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo
002a0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02@3oool00;80oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?ooo`00/P3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo00X0oooo002b0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool02`3oool00;<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;0?ooo`00/`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo002d0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0303oool00;@0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`0=0?ooo`00]@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00h0
oooo002f0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03P3oool00;H0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0?0?ooo`00]`3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo00l0oooo002h0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0403oool00;T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`00
^@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0180oooo002j0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool04P3oool00;/0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0C0?ooo`00_03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
01@0oooo002m0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool00;h0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0F0?ooo`00_`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo01L0oooo00300?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0603oool00<40oooo0P0000100?ooo`8000006`3oool00<<0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0K0?ooo`00a03oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo01`0oooo00350?ooo`800000>03oool2000001l0oooo00370?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool07`3oool00<P0oooo0P00000b0?ooo`8000008P3oool00<X0
oooo0P00000^0?ooo`800000903oool00<`0oooo0P00000Z0?ooo`8000009P3oool00<h0oooo0`00
000T0?ooo`<00000:03oool00=40oooo0P00000P0?ooo`800000:`3oool00=<0oooo0`00000J0?oo
o`<00000;@3oool00=H0oooo2000000:0?ooo`P00000<03oool00=h0oooo2P00000h0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {110.063, 0}} -> {2.01007, -0.150032, \
0.0572409, 0.0572409}}]
}, Open  ]],

Cell["\<\
The sequence of radii form a geometric sequence. Let us call its ratio r.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r = \(Last[#] &\) /@ c\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({3, 1\/25\ \((81 - 6\ \@26)\), 
      3\/625\ \((27 - 2\ \@26)\)\^2, \(-\(\(3\ \((\(-27\) + 2\ \
\@26)\)\^3\)\/15625\)\), \(-\(\(3\ \((\(-997153\) + 
                  179928\ \@26)\)\)\/390625\)\)}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      3\ \((\(-\(1\/25\)\)\ \((\(-27\) + 2\ \@26)\))\)\^Range[0, 4] - 
        r]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[
      NestList[{u = \(First[#]\^2 + 2\ Last[#]\ \((Last[#] - \@\(Last[#]\^2 + \
First[#]\^2\))\)\)\/First[#], \(Last[#]\/First[#]\) u} &, {3, 3}, 
        4]]\), "\[IndentingNewLine]", 
    \(shG[\(Circle[#, Last[#]] &\) /@ %]\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \({{3, 3}, {9 - 6\ \@2, 9 - 6\ \@2}, {51 - 36\ \@2, 
        51 - 36\ \@2}, {297 - 210\ \@2, 297 - 210\ \@2}, {1731 - 1224\ \@2, 
        1731 - 1224\ \@2}}\)], "Output",
  CellLabel->"Out[58]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.0238095 0.15873 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
newpath
.10551 .10551 .0817 0 365.73 arc
s
newpath
.03783 .03783 .01402 0 365.73 arc
s
newpath
.02621 .02621 .00241 0 365.73 arc
s
newpath
.02422 .02422 .00041 0 365.73 arc
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool200000080oooo0P00000A0?ooo`@00000J@3oool;000008/0
oooo00060?ooo`@000000P3oool00`000000oooo0?ooo`090?ooo`D00000103oool4000005T0oooo
3000000;0?ooo``00000O`3oool000L0oooo0P0000040?ooo`030000003oool0oooo00@0oooo1000
000=0?ooo`800000D03oool7000002<0oooo1`00001h0?ooo`001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo0P00000C0?ooo`<00000B03oool500000340oooo1@00001c
0?ooo`001P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000001P0oooo0P000013
0?ooo`<00000>`3oool300000700oooo00060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`0000006`3oool00`000000oooo0?ooo`0k0?ooo`D00000@@3oool5000006/0oooo00070?ooo`03
0000003oool0oooo00<0oooo0`00000M0?ooo`030000003oool0oooo03L0oooo0`00001;0?ooo`<0
0000J03oool000L0oooo0P0000030?ooo`800000803oool00`000000oooo0?ooo`0c0?ooo`<00000
D@3oool4000006@0oooo00090?ooo`<0000000<0oooo0000003oool0803oool00`000000oooo0?oo
o`0`0?ooo`800000F03oool00`000000oooo0?ooo`1Q0?ooo`00303oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02`0oooo0`00001K0?ooo`<00000H03oool000/0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0Y0?ooo`<00000H@3oool4000005`0oooo000:0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool2000006P0oooo00<000000?ooo`3o
ool0F@3oool000X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0S0?ooo`<00000
J`3oool3000005P0oooo00090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803o
ool200000740oooo0P00001F0?ooo`002@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1C0?ooo`00203oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo01/0oooo0`00001g0?ooo`<00000DP3oool000P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`800000O@3oool200000500
oooo00070?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo04d0oooo00070?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool05@3oool2000008<0oooo0P00001=0?ooo`001`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0180oooo0P0000270?ooo`800000B`3oool000L0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0@0?ooo`800000R`3oool2000004T0oooo00070?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool03P3oool2000008l0oooo0P0000170?ooo`00
1P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`140?ooo`001P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00/0oooo0P00002E0?ooo`800000A03oool000H0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0@@3oool0
00H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`800000V`3oool20000
0440oooo00060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo03h0oooo00070?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2O0?ooo`800000?P3oool000L0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0>`3oool000L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`03
0?ooo`800000YP3oool00`000000oooo0?ooo`0j0?ooo`001`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0i0?oo
o`001`3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0?ooo`800000Z`3oool20000
03T0oooo00080?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000002_0?oo
o`030000003oool0oooo03H0oooo00080?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3o
ool00000/@3oool00`000000oooo0?ooo`0e0?ooo`002@3oool00`000000oooo0?ooo`0V0?ooo`05
0000003oool0oooo0?ooo`000000/@3oool00`000000oooo0?ooo`0e0?ooo`002@3oool00`000000
oooo0?ooo`0V0?ooo`040000003oool0oooo00000;<0oooo00<000000?ooo`3oool0=03oool000X0
oooo00<000000?ooo`3oool0903oool010000000oooo00000000002e0?ooo`800000=03oool000X0
oooo00<000000?ooo`3oool0903oool200000;T0oooo00<000000?ooo`3oool0<@3oool000/0oooo
00<000000?ooo`3oool08P3oool200000;/0oooo00<000000?ooo`3oool0<03oool000`0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo02l0oooo000=
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0^
0?ooo`003P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0;@3oool000l0oooo00<000000?ooo`3oool06P3oool200000<<0oooo00<000000?ooo`3o
ool0;03oool00100oooo00<000000?ooo`3oool0603oool200000<D0oooo00<000000?ooo`3oool0
:`3oool00140oooo0P00000F0?ooo`<00000a`3oool00`000000oooo0?ooo`0Z0?ooo`004`3oool2
000001<0oooo00<000000?ooo`000000b@3oool00`000000oooo0?ooo`0Y0?ooo`005@3oool30000
00`0oooo100000020?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0:@3oool001P0
oooo300000050?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0:03oool002L0oooo
0P00003=0?ooo`800000:03oool002H0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`0U0?ooo`009@3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo02@0oooo000U0?oo
o`030000003oool0oooo0=40oooo00<000000?ooo`3oool0903oool002@0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`0S0?ooo`008`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0280oooo000R0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool08P3o
ool00240oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0Q0?ooo`008@3oool00`00
0000oooo0?ooo`3I0?ooo`030000003oool0oooo0200oooo000P0?ooo`030000003oool0oooo0=/0
oooo00<000000?ooo`3oool07`3oool001l0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo01h0oooo000N
0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?oo
o`3oool0h@3oool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`3Q0?ooo`03
0000003oool0oooo01`0oooo000L0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0
6`3oool001/0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool0
0`000000oooo0?ooo`3U0?ooo`030000003oool0oooo01X0oooo000J0?ooo`030000003oool0oooo
0>L0oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0i`3oool00`000000
oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo01P0oooo
000I0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0603oool001P0oooo00<00000
0?ooo`3oool0j`3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`3[0?oo
o`030000003oool0oooo01L0oooo000G0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3o
ool05P3oool001H0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0E0?ooo`005@3o
ool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo01D0oooo000E0?ooo`030000003oool0
oooo0?40oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0l@3oool00`00
0000oooo0?ooo`0D0?ooo`00503oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo01@0
oooo000D0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool04`3oool001<0oooo00<0
00000?ooo`3oool0m@3oool00`000000oooo0?ooo`0B0?ooo`004P3oool00`000000oooo0?ooo`3f
0?ooo`030000003oool0oooo0180oooo000B0?ooo`030000003oool0oooo0?L0oooo00<000000?oo
o`3oool04@3oool00180oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`0A0?ooo`00
4@3oool00`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0140oooo000A0?ooo`030000003o
ool0oooo0?T0oooo00<000000?ooo`3oool0403oool00100oooo00<000000?ooo`3oool0nP3oool0
0`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo
00l0oooo000@0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?oo
o`3m0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo0?d0oooo00<00000
0?ooo`3oool03P3oool000h0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0>0?oo
o`003P3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00d0oooo000=0?ooo`030000
003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`0=0?ooo`003@3oool00`000000oooo0?oo
o`3o0?ooo`80oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`030000003oool0oooo00`0oooo000<0?ooo`030000003oool0oooo0?l0oooo0`3oool00`00
0000oooo0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3o
ool02`3oool000`0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00/0oooo
000;0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`0;0?ooo`002`3oool0
0`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?oo
o`3oool0o`3oool60?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0?l0
oooo1P3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo
00<000000?ooo`3oool02P3oool000X0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003o
ool0oooo00X0oooo000:0?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo00T0oooo00090?ooo`030000
003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3o
ool0203oool000P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0
oooo303oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?ooo``0oooo
00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003o
ool0oooo00L0oooo00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`06
0?ooo`001`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0
oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000
003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?oo
o`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0o`3oool>
0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`00
0000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3o
ool01P3oool000L0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo00H0oooo
00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool0
0`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000H0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`00
0000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo00H0oooo
00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool0
0`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?oo
o`3oool0o`3oool>0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo0?l0
oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo
00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`06
0?ooo`001`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0
oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000
003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?oo
o`3o0?ooo`h0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo0?l0oooo303oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo
00080?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`070?ooo`00203oool0
0`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?oo
o`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo0?l0
oooo2P3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo
00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003o
ool0oooo00P0oooo00090?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`08
0?ooo`002@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0203oool000X0
oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`3o0?ooo`P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0o`3oool7
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`00
0000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo00X0oooo
000;0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0:0?ooo`002`3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?oo
o`3oool0o`3oool40?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo0?l0
oooo103oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`3o0?ooo`<0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0o`3oool20?ooo`030000003o
ool0oooo00`0oooo000=0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo
0?ooo`3n0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo0?d0oooo00<0
00000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0>
0?ooo`003`3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00l0oooo000@0?ooo`03
0000003oool0oooo0?/0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0
n`3oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo0?ooo`3k0?ooo`030000003o
ool0oooo00l0oooo000A0?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3oool0403oool0
0140oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000
oooo0?ooo`3g0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo0?L0oooo
00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo0180oooo000D0?oo
o`030000003oool0oooo0?<0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3o
ool0lP3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`3a0?ooo`030000
003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0503o
ool001H0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`00
0000oooo0?ooo`3_0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo0>d0
oooo00<000000?ooo`3oool05P3oool001P0oooo00<000000?ooo`3oool0j`3oool00`000000oooo
0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo01L0oooo000I
0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?oo
o`3oool0j@3oool00`000000oooo0?ooo`0H0?ooo`006P3oool00`000000oooo0?ooo`3W0?ooo`03
0000003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0
6@3oool001/0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool0
0`000000oooo0?ooo`3U0?ooo`030000003oool0oooo01X0oooo000L0?ooo`030000003oool0oooo
0><0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0h@3oool00`000000
oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo01`0oooo
000N0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool07@3oool001l0oooo00<00000
0?ooo`3oool0g@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo01h0oooo000P0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3o
ool07`3oool00240oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0P0?ooo`008@3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0
oooo0=L0oooo00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`0R0?ooo`00903oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo02<0
oooo000U0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo02D0oooo000W0?ooo`800000c@3oool2000002P0oooo000Y0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool0:03oool002X0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo02T0oooo000[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0:P3oool0
02`0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0[0?ooo`00;@3oool00`000000
oooo0?ooo`310?ooo`030000003oool0oooo02`0oooo000^0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0;@3oool002l0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`0^0?ooo`00<03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo02l0oooo000a0?oo
o`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0<03oool00380oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0a0?ooo`00<`3oool200000;D0oooo0P00000d0?ooo`00=@3o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo03H0
oooo000h0?ooo`800000Z`3oool2000003T0oooo000j0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool0>@3oool003/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0j
0?ooo`00?03oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo03/0oooo000m0?ooo`80
0000X@3oool2000003h0oooo000o0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
?P3oool00400oooo0P00002K0?ooo`800000@@3oool00480oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`110?ooo`00@`3oool2000009D0oooo0P0000140?ooo`00A@3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo04@0oooo00160?ooo`800000S`3oool2000004L0oooo
00180?ooo`800000R`3oool2000004T0oooo001:0?ooo`800000Q`3oool2000004/0oooo001<0?oo
o`800000P`3oool2000004d0oooo001>0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool0C@3oool004l0oooo0P00001m0?ooo`800000D03oool00540oooo0P00001i0?ooo`800000DP3o
ool005<0oooo0P00001e0?ooo`800000E03oool005D0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`1D0?ooo`00EP3oool3000006d0oooo0`00001G0?ooo`00F@3oool2000006T0oooo
0P00001J0?ooo`00F`3oool3000006<0oooo0`00001L0?ooo`00GP3oool3000005d0oooo0`00001O
0?ooo`00H@3oool2000005T0oooo0P00001R0?ooo`00H`3oool3000005<0oooo0`00001T0?ooo`00
IP3oool3000004d0oooo0`00001W0?ooo`00J@3oool5000004<0oooo1@00001Z0?ooo`00KP3oool4
000003/0oooo1000001_0?ooo`00LP3oool500000340oooo1@00001c0?ooo`00M`3oool6000002D0
oooo1P00001h0?ooo`00O@3oool<000000d0oooo3000001n0?ooo`00R@3oool=000008X0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.150032, -0.150032, 0.0219515, \
0.0219515}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem: If we have n circles and the first one has radius h and the last one \
radius k,what is the radius of the i-th one? For instance, if n = 5, h = 9, k \
= 4 and i = 3 (see Which way did the bicycle go? J.Kohnhauser, D.Velleman, \
S.Wagon.  Mathematical Association of America)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[a, n, h, k, i]\), "\[IndentingNewLine]", 
    \(NestList[{u = \(First[#]\^2 + 2\ Last[#]\ \((Last[#] - \@\(Last[#]\^2 + \
First[#]\^2\))\)\)\/First[#], \(Last[#]\/First[#]\) u} &, {a, h}, 
      1]\)}], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \({{a, 
        h}, {\(a\^2 + 2\ h\ \((h - \@\(a\^2 + h\^2\))\)\)\/a, \(h\ \((a\^2 + \
2\ h\ \((h - \@\(a\^2 + h\^2\))\))\)\)\/a\^2}}\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
      h \((\(a\^2 + 2\ h\ \((h - \@\(a\^2 + h\^2\))\)\)\/a\^2)\)\^\(n - 1\) == 
        k, {a}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[62]:="],

Cell[BoxData[
    \({{a \[Rule] \(-\(\(2\ h\ \@\((k\/h)\)\^\(1\/\(\(-1\) + n\)\)\)\/\@\(1 - \
2\ \((k\/h)\)\^\(1\/\(\(-1\) + n\)\) + \((k\/h)\)\^\(2\/\(\(-1\) + \
n\)\)\)\)\)}, {a \[Rule] \(2\ h\ \@\((k\/h)\)\^\(1\/\(\(-1\) + n\)\)\)\/\@\(1 \
- 2\ \((k\/h)\)\^\(1\/\(\(-1\) + n\)\) + \((k\/h)\)\^\(2\/\(\(-1\) + \
n\)\)\)}}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      h \((\(a\^2 + 2\ h\ \((h - \@\(a\^2 + h\^2\))\)\)\/a\^2)\)\^\(i - 1\) /. 
        a \[Rule] \(2\ h\ \@\((k\/h)\)\^\(1\/\(\(-1\) + n\)\)\)\/\@\(1 - 2\ \
\((k\/h)\)\^\(1\/\(\(-1\) + n\)\) + \((k\/h)\)\^\(2\/\(\(-1\) + n\)\)\), {n \
\[Element] Integers, n > 2, i \[Element] Integers, i \[GreaterEqual] 0, 
        i \[LessEqual] n, h > k, k > 0}]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(2\^\(1 - i\)\ h\ \((k\/h)\)\^\(\(1 - i\)\/\(\(-1\) + n\)\)\ \((1 + \((k\
\/h)\)\^\(2\/\(\(-1\) + n\)\) - \((\(-1\) + \((k\/h)\)\^\(2\/\(\(-1\) + \
n\)\))\)\ Sign[\(-1\) + \((k\/h)\)\^\(1\/\(\(-1\) + n\)\)])\)\^\(\(-1\) + i\)\
\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell["Finally, the answer is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[% /. {n \[Rule] 5, h \[Rule] 9, k \[Rule] 4, 
          i \[Rule] 3}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuing ...", "Subsection"],

Cell["\<\
We have at the first stage of our procedure that a figure of type 0 gives \
rise to three figures of type 1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(\(Solve[
        disP2Seg[{x, y}, triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]\^2 == 
          disP2Cir[{x, y}, {1\/3, 1\/\(3\ \@3\)}, 1\/\(3\ \@3\)]\^2 \[Equal] 
          disP2Cir[{x, y}, {1, 1\/\@3}, 1\/\@3]\^2];\)\), \
"\[IndentingNewLine]", 
    \(centers = FullSimplify[{x, y} /. %]\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[{Line[
              triangle], \(Circle[#, 
                  disP2Seg[#, 
                    triangle\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\), 
                    triangle\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]] &\) /@ centers}], 
        AspectRatio \[Rule] Automatic];\)\)}], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[65]:="],

Cell[BoxData[
    \({{1\/3, 1\/\(3\ \@3\)}, {1, 1\/\@3}, {\(-\(1\/\@3\)\), 
        1\/2 + 1\/\@3}, {1\/\@3, \(-\(1\/2\)\) + 1\/\@3}}\)], "Output",
  CellLabel->"Out[67]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58957 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.455009 0.260591 0.0140374 0.260591 [
[ 0 0 0 0 ]
[ 1 .58957 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .58957 L
0 .58957 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.45501 .01404 m
.97619 .01404 L
.7156 .46539 L
.45501 .01404 L
s
newpath
.54187 .06419 .05015 0 365.73 arc
s
newpath
.7156 .16449 .15045 0 365.73 arc
s
newpath
.30456 .29478 .28075 0 365.73 arc
s
newpath
.60546 .03419 .02016 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 169.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ZB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00C@3ooolE00000200ooooUP00
00080?ooo`00A`3oool6000001D0oooo1P00000K0?ooo`030000003oool0oooo0100oooo0P000009
0?ooo`8000001P3oool2000000H0oooo00<000000?ooo`3oool03@3oool400000100oooo1000000m
0?ooo`030000003oool0oooo00L0oooo00130?ooo`@000008@3oool4000001L0oooo00<000000?oo
o`3oool03@3oool3000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00X0oooo0P00000H0?ooo`800000>`3oool00`000000oooo0?ooo`070?oo
o`00?`3oool4000002T0oooo1000000D0?ooo`030000003oool0oooo00X0oooo0P00000A0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`080?ooo`800000703oool20000
03P0oooo00<000000?ooo`3oool0203oool003d0oooo0P00000a0?ooo`8000004P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`050?ooo`800000803oool2000003H0oooo00<000000?ooo`3oool0203oool003X0oooo
0`00000e0?ooo`<00000403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo
0P00000;0?ooo`030000003oool0oooo00<0oooo0P00000T0?ooo`800000<`3oool00`000000oooo
0?ooo`090?ooo`00>03oool2000003/0oooo0P00000>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`800000
:03oool200000340oooo00<000000?ooo`3oool02@3oool003H0oooo0P00000o0?ooo`8000003@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203o
ool010000000oooo00000000000/0?ooo`800000;P3oool00`000000oooo0?ooo`0:0?ooo`00=03o
ool2000004<0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`080?ooo`800000<03oool2000002/0oooo00<000000?ooo`3oool02`3o
ool00380oooo0P0000170?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01P3oool2000003<0oooo0P00000Y0?ooo`030000003oool0
oooo00/0oooo000a0?ooo`030000003oool0oooo04T0oooo0P0000090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool06@3oool2000000H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo000_0?ooo`800000CP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000
oooo00000005000003P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`00
;@3oool200000540oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo0P00000T0?ooo`030000003oool0oooo00d0
oooo000[0?ooo`800000E@3oool2000000H0oooo00@000000?ooo`3oool000006`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0=0?ooo`00:P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000006`3oool01@000000oooo0?ooo`3oool0000003h0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0>0?ooo`00:03oool2000005/0oooo0P0000040?ooo`03
0000003oool0000001/0oooo00@000000?ooo`3oool00000@03oool2000001l0oooo00<000000?oo
o`3oool03`3oool002L0oooo00<000000?ooo`3oool0G@3oool200000080oooo00<000000?ooo`00
00006`3oool00`000000oooo000000120?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool03`3oool002D0oooo0P00001R0?ooo`030000003oool0oooo008000006`3oool2000004@0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0@0?ooo`00903oool00`000000oooo0?oo
o`1S0?ooo`040000003oool00000000001/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0100oooo000S0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`0000006P3oool2000004H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0A0?ooo`008P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0000001T0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo000Q0?oo
o`030000003oool0oooo06T0oooo0P00000H0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`00803oool00`000000oooo0?ooo`1[0?ooo`80
00005`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool001l0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`007@3o
ool200000740oooo0P00000C0?ooo`800000C@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01@0oooo000L0?ooo`030000003oool0oooo0780oooo0P00000A0?ooo`800000CP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo000K0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`0000003P3oool2000000030?ooo`000000oooo04d0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0000000800000203oool300000080oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo000J0?ooo`030000003oool0oooo07D0oooo
00D000000?ooo`3oool000000?ooo`08000000D0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`0000003P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0N03oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo000G
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0603oool001H0oooo00<000000?oo
o`3oool0O03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`005@3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0000000X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01X0oooo000E0?ooo`030000003oool0oooo07h0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool06P3oool001@0oooo00<000000?ooo`3oool0P03oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?oo
o`00503oool00`000000oooo0?ooo`210?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo000C0?ooo`03
0000003oool0oooo0880oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000
oooo0?ooo`240?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo000A0?ooo`030000003oool0oooo08D0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`00403oool00`000000oooo0?ooo`270?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01h0oooo000@0?ooo`030000003oool0oooo08L0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo`00403oool00`000000oooo0?ooo`280?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool000l0oooo00<000000?ooo`3oool0RP3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?oo
o`003`3oool00`000000oooo0?ooo`2:0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo000>0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0803oool000h0oooo00<000000?ooo`3oool0
S03oool01P000000oooo0?ooo`000000oooo000005D0oooo00D000000?ooo`3oool0oooo0000000S
0?ooo`003@3oool00`000000oooo0?ooo`2>0?ooo`050000003oool000000?ooo`000000E03oool0
1@000000oooo0?ooo`3oool0000002@0oooo000=0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool00P00001D0?ooo`050000003oool0oooo0?ooo`000000903oool000`0oooo00<00000
0?ooo`3oool0T03oool010000000oooo00000000001D0?ooo`040000003oool0oooo000002D0oooo
000<0?ooo`030000003oool0oooo0940oooo00@000000?ooo`0000000000D`3oool010000000oooo
0?ooo`00000U0?ooo`00303oool00`000000oooo0?ooo`2A0?ooo`040000003oool0000000000580
oooo00@000000?ooo`3oool000009P3oool000`0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0000001B0?ooo`040000003oool0oooo000002H0oooo000;0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`000000DP3oool00`000000oooo0000000W0?ooo`002`3oool00`000000oooo
0?ooo`2D0?ooo`<00000D@3oool2000002P0oooo000:0?ooo`030000003oool0oooo09H0oooo0P00
001A0?ooo`800000:03oool000X0oooo00<000000?ooo`3oool0UP3oool200000500oooo0P00000Y
0?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo04h0oooo0P00000Y0?oo
o`002@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo04d0oooo0P00000Z0?ooo`00
2@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo04`0oooo0P00000Z0?ooo`002@3o
ool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0:@3o
ool000T0oooo00<000000?ooo`3oool0V@3oool2000004`0oooo0P00000[0?ooo`00203oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0000004/0oooo00<000000?ooo`3oool0:P3oool000P0
oooo00<000000?ooo`3oool0V`3oool2000004X0oooo00<000000?ooo`3oool0:`3oool000P0oooo
00<000000?ooo`3oool0V`3oool00`000000oooo000000180?ooo`800000;@3oool000P0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo000000170?ooo`800000;P3oool000P0oooo00<00000
0?ooo`3oool0V`3oool010000000oooo0?ooo`0000160?ooo`800000;P3oool000P0oooo00<00000
0?ooo`3oool0W03oool010000000oooo0000000000140?ooo`800000;`3oool000L0oooo00<00000
0?ooo`3oool0W@3oool010000000oooo0?ooo`0000140?ooo`030000003oool0oooo02h0oooo0007
0?ooo`030000003oool0oooo09d0oooo00D000000?ooo`3oool0oooo000000120?ooo`800000<03o
ool000L0oooo00<000000?ooo`3oool0W@3oool010000000oooo0?ooo`3oool200000440oooo00<0
00000?ooo`3oool0;`3oool000L0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`02
0?ooo`800000?P3oool300000340oooo00070?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000l0?ooo`030000003oool000000380oooo00070?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000k0?ooo`03
0000003oool000000380oooo00070?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0000000h0?ooo`80000000<0oooo0000003oool0<P3oool000L0oooo00<0
00000?ooo`3oool0W@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00800000=@3o
ool010000000oooo0?ooo`00000d0?ooo`001`3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`050000003oool0oooo0?ooo`00
0000=03oool000L0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool0000003D0
oooo00070?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02`0oooo0P0000040?ooo`030000003oool0oooo03<0oooo
00070?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`800000:P3oool2000000D0oooo00<000000?ooo`3oool0=03oool000L0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0P00000V
0?ooo`8000001`3oool00`000000oooo0?ooo`0d0?ooo`001`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool200000280oooo0P0000080?oo
o`030000003oool0oooo03D0oooo00070?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`8000007P3oool2000000T0oooo00<000000?ooo`3o
ool0=P3oool000L0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo1000000F0?ooo`@000002`3oool00`000000oooo0?ooo`0f0?ooo`001`3o
ool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool4000000h0oooo1000000>0?ooo`030000003oool0oooo03L0oooo00070?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`h000004P3oool0
0`000000oooo0?ooo`0g0?ooo`001`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0h0?ooo`001`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0h0?ooo`001`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0i0?ooo`001`3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0j0?ooo`001`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0j0?ooo`00203oool00`000000oooo0?ooo`2L0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0k0?oo
o`00203oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0k0?ooo`00203oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0l0?ooo`00203o
ool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0l0?ooo`00203oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`00203oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0n0?ooo`002@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0n0?ooo`002@3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0o0?ooo`002@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0o0?ooo`002@3oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`10
0?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`110?ooo`002P3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`110?ooo`00
2P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`120?ooo`002P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`120?ooo`002`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`130?ooo`002`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`130?ooo`00303oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`140?ooo`00303oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`150?ooo`00303oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`150?ooo`003@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`160?ooo`003@3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`160?oo
o`003P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`170?ooo`003P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`170?ooo`003`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`180?ooo`003`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`190?ooo`00403oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`190?ooo`00403oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1:0?ooo`00403oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1:0?ooo`004@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1;0?ooo`004@3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1;
0?ooo`004P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1<0?ooo`004`3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`00
503oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1=0?ooo`005@3oool00`000000oooo0?ooo`210?ooo`800000<03o
ool01@000000oooo0?ooo`3oool000000500oooo000E0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool000000500oooo000F0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0000001A0?ooo`005P3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0380oooo00<000000?ooo`000000D@3oool0
01L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0500oooo000H0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0Q`3oool001T0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`280?ooo`006P3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo08P0oooo000K0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0R@3oool001/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`2:0?oo
o`00703oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo08/0oooo000M0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0S03oool001h0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo08h0oooo000P0?ooo`800000J`3oool200000940oooo000R0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0T@3oool00280oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`2B0?ooo`008`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0980oooo000T
0?ooo`800000H`3oool2000009D0oooo000V0?ooo`800000H03oool00`000000oooo0?ooo`2E0?oo
o`00:03oool00`000000oooo0?ooo`1K0?ooo`800000V03oool002T0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`2H0?ooo`00:P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo09T0oooo000[0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0VP3oool0
02`0oooo0P00001C0?ooo`800000W@3oool002h0oooo0P00001?0?ooo`800000W`3oool00300oooo
0P00001;0?ooo`800000X@3oool00380oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`2Q0?ooo`00<`3oool400000440oooo1000002T0?ooo`00=`3oool2000003d0oooo0P00002X0?oo
o`00>@3oool2000003T0oooo0P00002Z0?ooo`00>`3oool3000003<0oooo0`00002/0?ooo`00?P3o
ool4000002/0oooo1000002_0?ooo`00@P3oool4000002<0oooo1000002c0?ooo`00AP3oool40000
01/0oooo1000002g0?ooo`00BP3ooolK00000;/0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {168.75, 0}} -> {-1.75128, -0.0538789, \
0.0134072, 0.0134072}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Solve[
        disP2Cir[{x, y}, {1\/\@3, \(-\(1\/2\)\) + 1\/\@3}, \(-\(1\/2\)\) + \
1\/\@3]\^2 == 
          disP2Cir[{x, y}, {1\/3, 1\/\(3\ \@3\)}, 1\/\(3\ \@3\)]\^2 \[Equal] 
          disP2Cir[{x, y}, {1, 1\/\@3}, 1\/\@3]\^2];\)\), \
"\[IndentingNewLine]", 
    \(centers = FullSimplify[{x, y} /. %]\), "\[IndentingNewLine]", 
    \(\(Show[
        Graphics[{Line[
              triangle], \(Circle[#, 
                  disP2Cir[#, {1\/\@3, \(-\(1\/2\)\) + 
                        1\/\@3}, \(-\(1\/2\)\) + 1\/\@3]] &\) /@ centers}], 
        AspectRatio \[Rule] Automatic];\)\)}], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message",
  CellLabel->"From In[69]:="],

Cell[BoxData[
    \({{1\/3, 1\/\(3\ \@3\)}, {1, 
        1\/\@3}, {1\/\@3, \(-\(1\/2\)\) + 1\/\@3}, {2\/39\ \((9 + \@3)\), 
        7\/156\ \((\(-3\) + 4\ \@3)\)}}\)], "Output",
  CellLabel->"Out[70]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48113 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0114554 0.47619 [
[ 0 0 0 0 ]
[ 1 .48113 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .48113 L
0 .48113 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01146 m
.97619 .01146 L
s
.97619 .01146 m
.70503 .48113 L
s
.29497 .48113 m
.02381 .01146 L
s
newpath
.18254 .1031 .09164 0 365.73 arc
s
newpath
.5 .28638 .27493 0 365.73 arc
s
newpath
.29874 .04829 .03683 0 365.73 arc
s
newpath
.28589 .09539 .01199 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{288, 138.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`001`3ooooo000001800000203oool000P0oooo00<0
00000?ooo`3oool08`3oool2000000P0oooo1@00000E0?ooo`8000000`3oool4000002H0oooo2000
000=0?ooo`P00000N03oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0P
0?ooo`<000003`3oool200000140oooo0P0000090?ooo`030000003oool0oooo0200oooo0`00000M
0?ooo`@00000M03oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0M0?oo
o`800000503oool2000000d0oooo0P00000<0?ooo`030000003oool0oooo01/0oooo1000000T0?oo
o`<00000L03oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`0K0?ooo`80
0000603oool2000000X0oooo00<000000?ooo`3oool03@3oool2000001L0oooo1000000[0?ooo`@0
0000K03oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`800000
703oool2000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`800000
<`3oool2000006T0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0>0?ooo`@00000=`3oool4000006D0oooo00<000000?ooo`3oool02@3o
ool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo00D000000?ooo`3oool0oooo0000000D
0?ooo`030000003oool0oooo00X0oooo0P0000110?ooo`800000H03oool00`000000oooo0?ooo`0;
0?ooo`00303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02<0oooo00D000000?oo
o`3oool0oooo0000000D0?ooo`030000003oool0oooo00P0oooo0P0000150?ooo`800000GP3oool0
0`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02D0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`060?ooo`800000B@3oool2
000005/0oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Y0?ooo`800000503oool00`000000
oooo0?ooo`030?ooo`800000C`3oool2000005L0oooo00<000000?ooo`3oool03@3oool000h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Y0?ooo`800000503oool010000000oooo
0?ooo`3oool2000005<0oooo0P00001E0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0:`3oool200000180oooo00D000000?ooo`3oool0
oooo0000001G0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool03P3oool00100oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0[0?ooo`8000004P3oool010000000oooo
00000000001I0?ooo`800000D03oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0000001M0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool03`3oool00140oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0]0?ooo`800000403oool2000005l0oooo0P00
001<0?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0;P3oool2000000h0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool00P0000090?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool0oooo2@00001Y0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0a0?ooo`050000003oool000000000003oool00P0000040?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0C0?ooo`00
503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo0P0000040?ooo`050000
003oool0oooo0?ooo`000000K@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01<0
oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`040?ooo`<00000K`3oool200000400oooo00<000000?ooo`3oool0503oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01@0oooo000F
0?ooo`050000003oool0oooo0?ooo`000000<`3oool2000000@0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo000G0?ooo`040000003oool0
oooo000003<0oooo0`0000030?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0F0?ooo`005`3oool010000000oooo0?ooo`00000c0?ooo`030000003o
ool0oooo00<00000M`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01H0oooo000H
0?ooo`030000003oool0000003<0oooo00D000000?ooo`3oool0oooo0000001h0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`000000<`3oool0
1@000000oooo0?ooo`3oool0000007T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0G0?ooo`006@3oool2000003<0oooo00@000000?ooo`0000000000N`3oool2000003H0oooo00<0
00000?ooo`3oool0603oool001T0oooo00<000000?ooo`000000<P3oool2000007h0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0H0?ooo`006P3oool200000340oooo00<000000?oo
o`000000O`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01T0oooo000K0?ooo`03
0000003oool0oooo02l0oooo0P0000200?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool06P3oool001/0oooo0P00000`0?ooo`800000P@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01X0oooo000L0?ooo`030000003oool0oooo02d0oooo0P0000230?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool06`3oool001`0oooo0P00000^0?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`00
0000oooo0?ooo`0[0?ooo`800000Q@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01`0oooo000M0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01`0oooo000N0?ooo`030000003oool0oooo02T0oooo
0P0000270?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool07@3oool001h0oooo0P00
000Z0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0N0?ooo`007`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`00803oool00`000000oooo0?ooo`0U0?oo
o`800000R`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01l0oooo000P0?ooo`80
00009@3oool2000008`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`00
8@3oool2000002@0oooo0P00002=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
803oool00240oooo00<000000?ooo`0000008P3oool2000008h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0P0?ooo`008P3oool00`000000oooo0000000O0?ooo`80000000<0oooo
0000003oool0SP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo000S0?oo
o`030000003oool0000001`0oooo0P0000030?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`02000001T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08P3oool002@0oooo00@000000?ooo`3oool0oooo0`00000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo02<0oooo000T0?ooo`030000003oool0oooo00@0oooo0P00000@0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
8`3oool002D0oooo00<000000?ooo`3oool01@3oool6000000D0oooo1@0000080?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0T0?ooo`009@3oool0
0`000000oooo0?ooo`0;0?ooo`D00000303oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0903oool002H0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool09@3oool002L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09P3oool002P0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09`3oool002T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0:03oool002T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0:03oool002X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
:@3oool002/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`2G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool0
02`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool002d0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool002h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0;@3oool002l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0;P3oool00300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;`3o
ool00340oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0<03oool00380oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool00380
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<P3oool003<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0<P3oool003@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<`3oool003D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
=@3oool003H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0=@3oool003L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=P3oool0
03L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0=P3oool003P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool003P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>03oool003X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0>@3oool003X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0>P3oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0>P3oool003`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3o
ool003`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03oool003h0
oooo00D000000?ooo`3oool0oooo0000002I0?ooo`050000003oool0oooo0?ooo`000000?`3oool0
03h0oooo00D000000?ooo`3oool0oooo0000002I0?ooo`050000003oool0oooo0?ooo`000000?`3o
ool003l0oooo00@000000?ooo`3oool00000V03oool01@000000oooo0?ooo`3oool000000400oooo
000o0?ooo`050000003oool0oooo0?ooo`000000U`3oool01@000000oooo0?ooo`3oool000000400
oooo00100?ooo`040000003oool0oooo000009L0oooo00@000000?ooo`3oool00000@@3oool00400
oooo00@000000?ooo`3oool00000U`3oool010000000oooo0?ooo`0000110?ooo`00@@3oool00`00
0000oooo0000002F0?ooo`040000003oool0oooo00000480oooo00120?ooo`030000003oool00000
09D0oooo00<000000?ooo`000000@`3oool00480oooo00<000000?ooo`000000U@3oool00`000000
oooo000000130?ooo`00@`3oool2000009D0oooo0P0000140?ooo`00@`3oool2000009@0oooo00<0
00000?ooo`000000A03oool004@0oooo0P00002C0?ooo`800000A@3oool004@0oooo0P00002B0?oo
o`030000003oool0000004D0oooo00150?ooo`800000T@3oool2000004H0oooo00160?ooo`800000
S`3oool2000004L0oooo00160?ooo`800000S`3oool2000004L0oooo00170?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0AP3oool004L0oooo00<000000?ooo`3oool0S03oool20000
04P0oooo00180?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0A`3oool004P0oooo
0P00002;0?ooo`030000003oool0oooo04P0oooo00190?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0B03oool004X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`19
0?ooo`00BP3oool00`000000oooo0?ooo`260?ooo`800000B`3oool004/0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`1:0?ooo`00B`3oool00`000000oooo0?ooo`240?ooo`800000
C03oool004`0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`1;0?ooo`00C@3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo04`0oooo001=0?ooo`030000003oool0oooo
0800oooo0P00001>0?ooo`00CP3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo04d0
oooo001>0?ooo`030000003oool0oooo07h0oooo0P00001?0?ooo`00C`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo04h0oooo001?0?ooo`800000O@3oool200000500oooo001@0?oo
o`800000N`3oool200000540oooo001A0?ooo`800000N@3oool200000580oooo001A0?ooo`030000
003oool0000007L0oooo00<000000?ooo`000000DP3oool00580oooo00<000000?ooo`000000M@3o
ool00`000000oooo0000001C0?ooo`00DP3oool00`000000oooo0000001e0?ooo`030000003oool0
000005<0oooo001C0?ooo`030000003oool0000007<0oooo00<000000?ooo`000000E03oool005<0
oooo00@000000?ooo`3oool00000L@3oool010000000oooo0?ooo`00001D0?ooo`00E03oool01000
0000oooo0?ooo`00001_0?ooo`040000003oool0oooo000005D0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {137.563, 0}} -> {-0.0539935, -0.0240614, \
0.00734491, 0.00734491}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CIRCLE TANGENT TO A TRIANGLE OF TYPE 1: two segments and a tangent circle\
\>", "Section"],

Cell[BoxData[
    \(type[1, a_, b_, c_, p_, r_] := 
      Module[{m, x, 
          y}, \[IndentingNewLine]m = \(b - a\)\/size[b - a] + \(c - \
a\)\/size[c - a]; \[IndentingNewLine]m = m\/size[m]; \[IndentingNewLine]x = 
          If[First[m] \[NotEqual] 
                0, \(First[p] - First[a]\)\/First[m], \(Last[p] - \
Last[a]\)\/Last[m]] - r; \[IndentingNewLine]y = 
          r\/size[p - a]; \[IndentingNewLine]{a + \(x\/\(y + 1\)\) 
              m, \(x\ y\)\/\(y + 1\)}]\)], "Input",
  CellLabel->"In[72]:=",
  InitializationCell->True],

Cell["Testing with random circles:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]{icp, icr} = 
            incircle[a, b, c]; \[IndentingNewLine]{c1, r1} = 
            type[1, a, b, c, icp, icr]; \[IndentingNewLine]{c2, r2} = 
            type[1, b, a, c, icp, icr]; \[IndentingNewLine]{c3, r3} = 
            type[1, c, b, a, icp, 
              icr]; \[IndentingNewLine]Graphics[{{LightSlateGray, 
                Polygon[{a, b, c, a}]}, {Burlywood, 
                Disk[icp, icr]}, {Chartreuse, Disk[c1, r1], Disk[c2, r2], 
                Disk[c3, r3]}}, AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {12}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 6]]];\)\)}], "Input",
  CellLabel->"In[81]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63518 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.0151234 0.15873 [
[ 0 0 0 0 ]
[ 1 .63518 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .63518 L
0 .63518 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0151234 0.17033 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.342606 1.65403 -0.103581 1.65403 [
[ 0 0 0 0 ]
[ 1 .74564 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .61334 m
.12862 .01775 L
.02381 .72788 L
.97619 .61334 L
F
.871 .722 .529 r
.31286 .44649 m
.31286 .44649 .24486 0 365.73 arc
F
.498 1 0 r
.66259 .53446 m
.66259 .53446 .11576 0 365.73 arc
F
.18605 .15139 m
.18605 .15139 .07633 0 365.73 arc
F
.0945 .65907 m
.0945 .65907 .05988 0 365.73 arc
F
0 0 m
1 0 L
1 .74564 L
0 .74564 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.0151234 0.331502 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.058615 1.70952 -0.446553 1.70952 [
[ 0 0 0 0 ]
[ 1 .60986 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.63345 .01452 m
.97619 .59534 L
.02381 .41378 L
.63345 .01452 L
F
.871 .722 .529 r
.56543 .3064 m
.56543 .3064 .20691 0 365.73 arc
F
.498 1 0 r
.62099 .06798 m
.62099 .06798 .0379 0 365.73 arc
F
.80514 .47502 m
.80514 .47502 .08616 0 365.73 arc
F
.27016 .36494 m
.27016 .36494 .09411 0 365.73 arc
F
0 0 m
1 0 L
1 .60986 L
0 .60986 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.0151234 0.492674 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.00617 2.51218 -1.13906 2.51218 [
[ 0 0 0 0 ]
[ 1 .24448 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .00582 m
.97619 .23866 L
.35854 .0613 L
.02381 .00582 L
F
.871 .722 .529 r
.35572 .0738 m
.35572 .0738 .01279 0 365.73 arc
F
.498 1 0 r
.33157 .06885 m
.33157 .06885 .01186 0 365.73 arc
F
.37996 .08024 m
.37996 .08024 .01229 0 365.73 arc
F
.35854 .06131 m
.35854 .06131 1e-005 0 365.73 arc
F
0 0 m
1 0 L
1 .24448 L
0 .24448 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.0151234 0.653846 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.165704 1.24204 -0.311259 1.24204 [
[ 0 0 0 0 ]
[ 1 .93665 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .37065 m
.36876 .0223 L
.97619 .91435 L
.02381 .37065 L
F
.871 .722 .529 r
.34082 .32734 m
.34082 .32734 .19478 0 365.73 arc
F
.498 1 0 r
.1009 .36012 m
.1009 .36012 .04737 0 365.73 arc
F
.36254 .0902 m
.36254 .0902 .04335 0 365.73 arc
F
.57437 .54311 m
.57437 .54311 .12318 0 365.73 arc
F
0 0 m
1 0 L
1 .93665 L
0 .93665 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.0151234 0.815018 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.73337 4.27055 -1.35765 4.27055 [
[ 0 0 0 0 ]
[ 1 2.60516 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.96986 2.20878 m
.97619 2.54314 L
.02381 .06203 L
.96986 2.20878 L
F
.871 .722 .529 r
.91337 2.22124 m
.91337 2.22124 .05671 0 365.73 arc
F
.498 1 0 r
.9693 2.20891 m
.9693 2.20891 .00056 0 365.73 arc
F
.93189 2.31615 m
.93189 2.31615 .03999 0 365.73 arc
F
.87119 2.11885 m
.87119 2.11885 .05402 0 365.73 arc
F
0 0 m
1 0 L
1 2.60516 L
0 2.60516 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.0151234 0.97619 0.303187 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.252784 1.52451 -0.191907 1.52451 [
[ 0 0 0 0 ]
[ 1 .93246 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.09731 .78943 m
.97619 .91026 L
.02381 .0222 L
.09731 .78943 L
F
.871 .722 .529 r
.30413 .59095 m
.30413 .59095 .2248 0 365.73 arc
F
.498 1 0 r
.12232 .76543 m
.12232 .76543 .02718 0 365.73 arc
F
.61599 .73912 m
.61599 .73912 .12048 0 365.73 arc
F
.15739 .29323 m
.15739 .29323 .10712 0 365.73 arc
F
0 0 m
1 0 L
1 .93246 L
0 .93246 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.331994 0.17033 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.263333 2.94506 -0.471 2.94506 [
[ 0 0 0 0 ]
[ 1 1.96604 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 1.70682 m
.02381 1.91923 L
.70432 .04681 L
.97619 1.70682 L
F
.871 .722 .529 r
.57463 1.43532 m
.57463 1.43532 .3524 0 365.73 arc
F
.498 1 0 r
.91271 1.6639 m
.91271 1.6639 .05571 0 365.73 arc
F
.21702 1.74949 m
.21702 1.74949 .12361 0 365.73 arc
F
.62695 .87513 m
.62695 .87513 .21023 0 365.73 arc
F
0 0 m
1 0 L
1 1.96604 L
0 1.96604 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.331994 0.331502 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.07198 2.71701 -1.15247 2.71701 [
[ 0 0 0 0 ]
[ 1 1.47873 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.61962 1.44353 m
.97619 .93598 L
.02381 .03521 L
.61962 1.44353 L
F
.871 .722 .529 r
.67039 .96679 m
.67039 .96679 .23251 0 365.73 arc
F
.498 1 0 r
.63723 1.27818 m
.63723 1.27818 .08064 0 365.73 arc
F
.9338 .94025 m
.9338 .94025 .03223 0 365.73 arc
F
.45036 .64977 m
.45036 .64977 .15339 0 365.73 arc
F
0 0 m
1 0 L
1 1.47873 L
0 1.47873 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.331994 0.492674 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.45125 1.50524 -0.719289 1.50524 [
[ 0 0 0 0 ]
[ 1 .69834 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .44851 m
.97619 .01663 L
.41546 .68172 L
.02381 .44851 L
F
.871 .722 .529 r
.37957 .46833 m
.37957 .46833 .16498 0 365.73 arc
F
.498 1 0 r
.15438 .45578 m
.15438 .45578 .06055 0 365.73 arc
F
.59512 .30514 m
.59512 .30514 .10538 0 365.73 arc
F
.41062 .65296 m
.41062 .65296 .02224 0 365.73 arc
F
0 0 m
1 0 L
1 .69834 L
0 .69834 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.331994 0.653846 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.625017 1.81941 -1.38872 1.81941 [
[ 0 0 0 0 ]
[ 1 .24218 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .07344 m
.49612 .23641 L
.02381 .00577 L
.97619 .07344 L
F
.871 .722 .529 r
.5026 .13447 m
.5026 .13447 .09444 0 365.73 arc
F
.498 1 0 r
.65901 .11432 m
.65901 .11432 .06325 0 365.73 arc
F
.49637 .23242 m
.49637 .23242 .0037 0 365.73 arc
F
.34937 .09328 m
.34937 .09328 .06422 0 365.73 arc
F
0 0 m
1 0 L
1 .24218 L
0 .24218 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.331994 0.815018 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.253247 1.41843 -0.188841 1.41843 [
[ 0 0 0 0 ]
[ 1 1.22749 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .02923 m
.11429 1.16554 L
.97619 1.19826 L
.02381 .02923 L
F
.871 .722 .529 r
.37195 .89696 m
.37195 .89696 .27816 0 365.73 arc
F
.498 1 0 r
.2123 .49903 m
.2123 .49903 .1506 0 365.73 arc
F
.15154 1.12671 m
.15154 1.12671 .04022 0 365.73 arc
F
.72455 1.07278 m
.72455 1.07278 .11584 0 365.73 arc
F
0 0 m
1 0 L
1 1.22749 L
0 1.22749 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.331994 0.97619 0.620058 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.181593 1.81893 -0.344693 1.81893 [
[ 0 0 0 0 ]
[ 1 1.50905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 1.47312 m
.02381 .03593 L
.2426 .67802 L
.97619 1.47312 L
F
.871 .722 .529 r
.31749 .63345 m
.31749 .63345 .08526 0 365.73 arc
F
.498 1 0 r
.41495 .75769 m
.41495 .75769 .07264 0 365.73 arc
F
.25081 .49779 m
.25081 .49779 .0659 0 365.73 arc
F
.24342 .67753 m
.24342 .67753 .00093 0 365.73 arc
F
0 0 m
1 0 L
1 1.50905 L
0 1.50905 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{612, 388.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0001Q2000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo
003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00
o`3ooonW0?ooo`0307N8V@3oool0oooo0;/0oooo003o0?ooool0ooooIP3oool00?l0ooooZ03oool0
0`1gR9T0oooo0?ooo`2j0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
Z@3oool00`1gR9T0oooo0?ooo`2i0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooojX0oooo00<0MhRI
0?ooo`3oool0^03oool00?l0ooooo`3ooomV0?ooo`00o`3ooon[0?ooo`0307N8V@3oool0oooo0;L0
oooo003o0?oooj/0oooo00<0MhRI0?ooo`3oool0]`3oool00?l0oooo[03oool00`1gR9T0oooo0?oo
o`2f0?ooo`00o`3ooon/0?ooo`0307N8V@3oool0oooo0;H0oooo003o0?oooj`0oooo00<0MhRI0?oo
o`3oool0]P3oool00?l0oooo[@3oool00`1gR9T0oooo0?ooo`2e0?ooo`00o`3ooon]0?ooo`0307N8
V@3oool0oooo0;D0oooo003o0?ooojh0oooo00<0MhRI0?ooo`3oool0]03oool00?l0oooo[P3oool0
0`1gR9T0oooo0?ooo`2d0?ooo`00o`3ooon^0?ooo`80MhRI]@3oool00?l0oooo[`3oool00`1gR9T0
oooo0?ooo`2c0?ooo`00o`3ooon_0?ooo`80MhRI]03oool00?l0oooo/03oool00`1gR9T0oooo0?oo
o`2b0?ooo`00o`3ooon`0?ooo`0307N8V@3oool0oooo0;80oooo003o0?oook00oooo0P1gR9Vc0?oo
o`00o`3ooona0?ooo`0307N8V@3oool0oooo0;40oooo003o0?oook40oooo0P1gR9Vb0?ooo`00o`3o
oona0?ooo`80MhRI/P3oool00?l0oooo/P3oool207N8VK40oooo003o0?oook80oooo0P1gR9Va0?oo
o`00o`3ooonc0?ooo`80MhRI/03oool00?l0oooo/`3oool207N8VK00oooo003o0?oook<0oooo0P1g
R9V`0?ooo`00o`3ooond0?ooo`80MhRI[`3oool00?l0oooo]03oool207N8VJl0oooo003o0?oookD0
oooo0P1gR9V^0?ooo`00o`3ooone0?ooo`80MhRI[P3oool00?l0oooo]@3oool307N8VJd0oooo003o
0?oookH0oooo0P1gR9V]0?ooo`00o`3ooonf0?ooo`80MhRI[@3oool00?l0oooo]`3oool207N8VJ`0
oooo003o0?oooeL0oooo00<0MhRI0?ooo`3oool0G@3oool207N8VDD0oooo00<0MhRI0?ooo`3oool0
I03oool00?l0ooooEP3oool307N8VEh0oooo0`1gR9U40?ooo`80MhRII@3oool00?l0ooooE03oool5
07oo000307N8V@3oool0oooo05`0oooo0P1gR9U40?ooo`<0MhRII03oool00?l0ooooE03oool607oo
05h0oooo0`1gR9U30?ooo`@0MhRIH`3oool00?l0ooooD`3oool00`1gR9T0Ool007oo000507oo05d0
oooo0`1gR9U30?ooo`D0MhRIHP3oool00?l0ooooDP3oool00`1gR9T0Ool007oo000607oo000307N8
V@3oool0oooo05/0oooo0`1gR9U20?ooo`H0MhRIH@3oool00?l0ooooD@3oool307N8V@L0Ool000<0
MhRI0?ooo`3oool0F`3oool307N8VD80oooo1`1gR9UP0?ooo`00o`3ooom@0?ooo`@0MhRI1`1oo`02
07N8VEd0oooo0P1gR9U20?ooo`P0MhRIG`3oool001X0oooo0P1gR9Wo0?oooc<0oooo1@1gR9T607oo
00@0MhRIG03oool307N8VD40oooo2@1gR9UN0?ooo`006P3oool307N8VOl0oooo<@3oool@07N8VE`0
oooo0`1gR9U20?ooo`T0MhRIG@3oool001X0oooo1@1gR9Wo0?ooobh0oooo0P1gR9T;0=jhQ`D0MhRI
G03oool307N8VD40oooo2P1gR9UL0?ooo`006P3oool607N8VOl0oooo;03ooolA0=jhQ`<0MhRIF`3o
ool307N8VD40oooo2`1gR9UK0?ooo`006P3oool807N8VOl0oooo:@3ooolD0=jhQ`0307N8V@3oool0
oooo05X0oooo0`1gR9U00?ooo``0MhRIFP3oool001X0oooo0`1gR9T507oo000307N8V@3oool0oooo
0?l0oooo903ooolG0=jhQ`0307N8V@3oool0oooo05T0oooo0`1gR9U00?ooo`h0MhRIF03oool001T0
oooo00<0MhRI07oo001oo`001`1oo`0207N8VH<0oooo0P1gR9VN0?oooaP0g[R700<0MhRI0?ooo`3o
ool0F03oool407N8VCl0oooo3`1gR9UG0?ooo`006@3oool00`1gR9T0Ool007oo000807oo0080MhRI
P03oool407oo000307N8V@3oool0oooo09X0oooo6P3N^8MK0?ooo`<0MhRI?`3oool507N8V@X0Ool0
00<0MhRI0?ooo`3oool0E03oool001T0oooo301oo`0207N8VGh0oooo00<0MhRI07oo001oo`000`1o
o`2K0?oooa`0g[R7FP3oool307N8VCl0oooo101gR9T=07oo05D0oooo000I0?ooo``0Ool0101gR9Uj
0?ooo`<0MhRI1P1oo`2I0?ooo`0307N8V@3N^8L0g[R701/0g[R7F@3oool407N8VCh0oooo101gR9T>
07oo05@0oooo000I0?ooo`d0Ool0101gR9Uh0?ooo`<0MhRI1`1oo`2H0?ooo`0307N8V@3N^8L0g[R7
01`0g[R700<0MhRI0?ooo`3oool0E`3oool307N8VCh0oooo0`1gR9T@07oo05<0oooo000H0?ooo`h0
Ool01P1gR9Ud0?ooo`H0MhRI1P1oo`000`1gR9T0oooo0?ooo`2D0?ooo`0307N8V@3N^8L0g[R701h0
g[R7F@3oool407N8VCh0oooo00<0MhRI07oo001oo`003`1oo`000`1gR9T0oooo0?ooo`1@0?ooo`00
603oool>07oo00L0MhRILP3oool707N8V@D0Ool00`1gR9VD0?ooo`80MhRI803N^8L00`1gR9T0oooo
0?ooo`1G0?ooo`<0MhRI?P3oool00`1gR9T0Ool007oo000?07oo0080MhRID@3oool001P0oooo3P1o
o`0907N8VFh0oooo4@1gR9VC0?ooo`<0MhRI8@3N^8L00`1gR9T0oooo0?ooo`1F0?ooo`@0MhRI?@3o
oolB07oo00<0MhRID03oool001P0oooo00<0MhRI07oo001oo`002P1oo`0;07N8VF`0oooo00<0MhRI
0=jhQ`3N^8L02`3N^8L507N8VI40oooo0`1gR9TR0=jhQ`0307N8V@3oool0oooo05H0oooo101gR9Tm
0?oooa<0Ool00`1gR9U?0?ooo`00603oool207N8V@/0Ool0301gR9UY0?oooa80g[R70`1gR9V@0?oo
o`@0MhRI8P3N^8L207N8VEP0oooo101gR9Tl0?oooa<0Ool0101gR9U>0?ooo`00603oool207N8V@X0
Ool03`1gR9UV0?oooa@0g[R70`1gR9V>0?ooo`D0MhRI8P3N^8L307N8VEL0oooo101gR9Tl0?oooa<0
Ool01@1gR9U=0?ooo`00603oool407N8V@D0Ool00P1gR9T?0=jhQ`80MhRIH`3ooolH0=jhQ`80MhRI
S03oool607N8VB80g[R70`1gR9UH0?ooo`<0MhRI?03ooolC07oo00H0MhRIC03oool001P0oooo2@1g
R9TC0=jhQ`80MhRIH03oool00`1gR9T0g[R70=jhQ`0G0=jhQ`0307N8V@3oool0oooo08T0oooo1@1o
o`0207N8VB80g[R7101gR9UG0?ooo`@0MhRI>`3ooolC07oo00P0MhRIBP3oool001L0oooo201gR9TG
0=jhQ`0307N8V@3oool0oooo05/0oooo0P1gR9TK0=jhQ`0307N8V@3oool0oooo08L0oooo00<0MhRI
07oo001oo`00101oo`000`1gR9T0g[R70=jhQ`0P0=jhQ`D0MhRIEP3oool407N8VC/0oooo4P1oo`0:
07N8VDT0oooo000G0?ooo`H0MhRI6`3N^8L00`1gR9T0oooo0?ooo`1H0?ooo`80MhRI7@3N^8N80?oo
o`0307N8V@1oo`00Ool000H0Ool08P3N^8L507N8VEL0oooo101gR9Tj0?ooo`0307N8V@1oo`00Ool0
00l0Ool02`1gR9U80?ooo`005`3oool507N8VAd0g[R700<0MhRI0?ooo`3oool0E@3oool207N8VB00
g[R7QP3oool00`1gR9T0Ool007oo000707oo0280g[R71P1gR9UF0?ooo`@0MhRI>`3oool00`1gR9T0
Ool007oo000=07oo00d0MhRIA`3oool001L0oooo101gR9TO0=jhQ`0307N8V@3oool0oooo05<0oooo
0`1gR9TQ0=jhQbH0oooo0`1gR9UK0?ooo`80MhRI2@1oo`0R0=jhQ`L0MhRIEP3oool407N8VCX0oooo
00<0MhRI07oo001oo`00301oo`0?07N8VDH0oooo000G0?ooo`<0MhRI8@3N^8L207N8VE40oooo1@1g
R9TQ0=jhQbX0oooo1P1gR9UF0?ooo`P0Ool000<0MhRI0=jhQ`3N^8L0803N^8L707N8VEH0oooo101g
R9Tj0?ooo`<0MhRI2`1oo`000`1gR9T0g[R70=jhQ`0:0=jhQ`@0MhRIA@3oool001L0oooo0P1gR9TS
0=jhQ`80MhRIC`3oool607N8VB40g[R700<0MhRI0?ooo`3oool0:`3oool:07N8VDl0oooo1P1oo`03
07N8VB40g[R7201gR9UE0?ooo`@0MhRI>P3oool407N8V@T0Ool04P3N^8L00`1gR9T0oooo0?ooo`12
0?ooo`005P3oool307N8VB<0g[R7101gR9U;0?ooo`L0MhRI8`3N^8La0?ooo`d0MhRI00<0Ool00?oo
o`3oool0B03oool207oo00@0MhRI803N^8L:07N8VED0oooo101gR9Ti0?ooo`H0MhRI101oo`000`1g
R9T0g[R70=jhQ`0C0=jhQ`0307N8V@3oool0oooo0440oooo000F0?ooo`80MhRI9@3N^8L407N8VDT0
oooo1`1gR9TT0=jhQ`0307N8V@3oool0oooo03<0oooo1@1gR9T207oo0080g[R70`1gR9U80?ooo`D0
MhRI803N^8L;07N8VE@0oooo101gR9Ti0?ooo`X0MhRI603N^8M20?ooo`005P3oool207N8VBH0g[R7
1@1gR9U50?ooo`T0MhRI903N^8L207N8VCP0oooo00<0MhRI07oo001gR9T00P3N^8L207oo00@0MhRI
A`3oool407N8VAh0g[R7301gR9UD0?ooo`D0MhRI>03oool807N8VA/0g[R7@@3oool001H0oooo00<0
MhRI0=jhQ`3N^8L09@3N^8L607N8VD<0oooo2P1gR9TU0=jhQ`0307N8V@3oool0oooo03X0oooo00<0
MhRI07oo001oo`00201gR9U50?ooo`<0MhRI703N^8L00`1gR9T0Ool007oo000907oo0080MhRIE03o
ool407N8VCP0oooo1`1gR9TM0=jhQd00oooo000F0?ooo`0307N8V@3N^8L0g[R702D0g[R7201gR9To
0?ooo`P0Ool0101gR9TU0=jhQ`80MhRI?`3oool:07N8VD@0oooo0P1gR9TK0=jhQ`h0Ool000<0MhRI
0?ooo`3oool0D@3oool507N8VCL0oooo1P1gR9TO0=jhQcl0oooo000F0?ooobT0g[R7201gR9Tl0?oo
o`/0Ool00`1gR9TU0=jhQ`80MhRIA03oool907N8VD40oooo00<0MhRI0=jhQ`3N^8L0603N^8L@07oo
05@0oooo101gR9Tg0?ooo`D0MhRI8@3N^8Ln0?ooo`005@3oool00`1gR9T0g[R70=jhQ`0W0=jhQ`T0
MhRI>P3oool00`1gR9T0Ool007oo000:07oo0080MhRI9@3N^8L307N8VDL0oooo201gR9U00?ooo`03
07N8V@3N^8L0g[R701D0g[R74@1oo`000`1gR9T0oooo0?ooo`1A0?ooo`D0MhRI=`3oool407N8VB40
g[R700<0MhRI0?ooo`3oool0>`3oool001D0oooo:`3N^8L:07N8VCL0oooo00<0MhRI07oo001oo`00
301oo`000`1gR9T0g[R70=jhQ`0S0=jhQ`@0MhRIBP3oool807N8VCh0oooo5@3N^8L00`1gR9T0Ool0
07oo000@07oo000307N8V@3oool0oooo0500oooo1@1gR9Tg0?ooo`<0MhRI8`3N^8L207N8VC/0oooo
000E0?ooob/0g[R72`1gR9Td0?ooo`80MhRI401oo`0U0=jhQ`@0MhRICP3oool707N8VCd0oooo4@3N
^8L207N8VA@0Ool0D`3oool407N8VCL0oooo0P1gR9TU0=jhQ`80MhRI>P3oool001D0oooo:`3N^8L=
07N8VC40oooo0`1gR9T@07oo02D0g[R71@1gR9UB0?ooo`D0MhRI>`3oool?0=jhQ`<0MhRI501oo`00
0`1gR9T0oooo0?ooo`1@0?ooo`D0MhRI=P3oool207N8VBD0g[R70`1gR9Ti0?ooo`005@3oool[0=jh
Q`h0MhRI;P3oool507N8VA00Ool0903N^8L607N8VEH0oooo1@1gR9Th0?ooo``0g[R7101gR9TF07oo
000307N8V@3oool0oooo0500oooo101gR9Tf0?ooo`80MhRI9P3N^8L307N8VCP0oooo000D0?ooob`0
g[R71P1gR9T807oo0080MhRI:`3oool507N8VA40Ool0903N^8L707N8VET0oooo101gR9Th0?ooo`04
07N8V@3N^8L0g[R70=jhQ`T0MhRI5P1oo`000`1gR9T0oooo0?ooo`1@0?ooo`D0MhRI=@3oool207N8
VBH0g[R7101gR9Tg0?ooo`00503oool/0=jhQ`@0MhRI301oo`000`1gR9T0oooo0?ooo`0V0?ooo`P0
MhRI401oo`000`1gR9T0g[R70=jhQ`0Q0=jhQ`P0MhRIG03oool407N8VCH0oooo2`1gR9TF07oo0080
MhRID@3oool507N8VCD0oooo00<0MhRI0=jhQ`3N^8L09@3N^8L507N8VCH0oooo000D0?ooob`0g[R7
0`1gR9T>07oo000307N8V@3oool0oooo02@0oooo2@1gR9T@07oo0080MhRI8@3N^8L907N8VF40oooo
0P1gR9Td0?ooo`X0MhRI5P1oo`0307N8VE40oooo1@1gR9Td0?ooo`0307N8V@3N^8L0g[R702D0g[R7
1P1gR9Te0?ooo`00503oool/0=jhQ`0307N8V@1oo`00Ool000h0Ool00`1gR9TR0?ooo`/0MhRI401o
o`0207N8VB40g[R7101gR9T407oo0080MhRII03oool207N8VC80oooo201gR9TF07oo00<0MhRID@3o
ool507N8VC@0oooo00<0MhRI0=jhQ`3N^8L09@3N^8L707N8VC@0oooo000D0?ooo`0307N8V@3N^8L0
g[R702T0g[R700<0MhRI07oo001oo`00401oo`0207N8VB00oooo3@1gR9T?07oo0080MhRI8@3N^8L:
07oo06P0oooo00<0MhRI0?ooo`3oool0;`3oool607N8VAH0Ool0101gR9U@0?ooo`H0MhRI<`3oool0
0`1gR9T0g[R70=jhQ`0U0=jhQ`P0MhRI<`3oool001@0oooo00<0MhRI0=jhQ`3N^8L0:@3N^8LC07oo
00@0MhRI703oool@07N8V@d0Ool00`1gR9TP0=jhQ`0307N8V@1oo`00Ool000T0Ool0VP3oool507N8
VAH0Ool01@1gR9U@0?ooo`D0MhRI<`3ooolY0=jhQ`P0MhRI<P3oool001@0oooo00<0MhRI0=jhQ`3N
^8L0:@3N^8LC07oo00D0MhRI8@3oool:07N8V@`0Ool01@1gR9TN0=jhQ`0307N8V@1oo`00Ool000/0
Ool0V`3oool407N8VA@0Ool01`1gR9U?0?ooo`D0MhRI<`3ooolY0=jhQ`T0MhRI<@3oool001@0oooo
00<0MhRI0=jhQ`3N^8L0:@3N^8LD07oo00H0MhRI903oool607N8V@X0Ool01`1gR9TL0=jhQ`0307N8
V@1oo`00Ool000`0Ool0W@3oool207N8VA@0Ool01`1gR9U@0?ooo`D0MhRI<P3ooolY0=jhQ`X0MhRI
<03oool001<0oooo0`1gR9TY0=jhQ`0307N8V@1oo`00Ool00180Ool01`1gR9TX0?ooo`80MhRI1`1o
o`0:07N8VAX0g[R70P1gR9T>07oo000307N8V@3oool0oooo09`0oooo00<0MhRI07oo001oo`00401o
o`0907N8VDl0oooo1@1gR9Tc0?ooobL0g[R7301gR9T_0?ooo`004`3oool307N8VBT0g[R75@1oo`08
07N8VB/0oooo0`1oo`0=07N8VAP0g[R70`1gR9T>07oo000307N8V@3oool0oooo09d0oooo00<0MhRI
07oo001oo`003`1oo`0:07N8VDh0oooo1P1gR9Tb0?ooobL0g[R73P1gR9T]0?ooo`004`3oool407N8
VBL0g[R700<0MhRI07oo001oo`004`1oo`0:07N8VC00oooo2P1gR9TF0=jhQ`<0MhRI3`1oo`0207N8
VJ00oooo3`1oo`0;07N8VDl0oooo1@1gR9Tb0?ooobL0g[R70`1gR9T:07oo0080MhRI;03oool001<0
oooo101gR9TW0=jhQ`0307N8V@1oo`00Ool001<0Ool02`1gR9Td0?ooo`L0MhRI4`3N^8L407N8V@l0
Ool00`1gR9VO0?ooo`d0Ool03P1gR9U>0?ooo`H0MhRI<@3ooolW0=jhQ`0307N8V@1oo`00Ool000`0
Ool000<0MhRI0?ooo`3oool0:@3oool001<0oooo1@1gR9TU0=jhQ`<0MhRI501oo`0=07N8VCP0oooo
0`1gR9T@0=jhQ`D0MhRI3`1oo`0307N8VJ40oooo2@1oo`0A07N8VDh0oooo1@1gR9Ta0?ooo`0307N8
V@3N^8L0g[R702@0g[R700<0MhRI07oo001oo`003P1oo`0Z0?ooo`004`3oool507N8VBD0g[R70`1g
R9TC07oo00l0MhRI>`3oool;0=jhQ`T0MhRI3`1oo`0407N8VJ<0oooo5`1gR9U>0?ooo`H0MhRI<03o
ool00`1gR9T0g[R70=jhQ`0T0=jhQa80Ool0:@3oool001<0oooo1P1gR9TS0=jhQ`D0MhRI4P1oo`0A
07N8VCl0oooo0P3N^8L=07N8V@h0Ool0101gR9VU0?oooaH0MhRIC@3oool607N8VC00oooo00<0MhRI
0=jhQ`3N^8L08`3N^8L00`1gR9T0Ool007oo000@07oo000307N8V@3oool0oooo02H0oooo000B0?oo
o`L0MhRI8`3N^8L507N8VA40Ool04`1gR9U40?ooo`X0MhRI301oo`0607N8VJH0oooo5@1gR9U=0?oo
o`D0MhRI<@3ooolU0=jhQa@0Ool000<0MhRI0?ooo`3oool09@3oool00180oooo0P1gR9T507oo0003
07N8V@3N^8L0g[R701l0g[R71`1gR9T@07oo01@0MhRIB03oool707N8V@T0Ool0201gR9VW0?oooa<0
MhRIC@3oool607N8VC00oooo00<0MhRI0=jhQ`3N^8L08@3N^8L00`1gR9T0Ool007oo000B07oo0080
MhRI9P3oool00180oooo00<0MhRI07oo001oo`001P1oo`0O0=jhQ`T0MhRI3P1oo`0>07N8VE@0oooo
0`1gR9T607oo00X0MhRIZ03ooolC07N8VDd0oooo1@1gR9T`0?ooo`0307N8V@3N^8L0g[R70200g[R7
00<0MhRI07oo001oo`004`1oo`0307N8VBD0oooo000B0?ooo`X0Ool07@3N^8L;07N8V@/0Ool0201g
R9UR0?ooo`0307oo001gR9T0MhRI00/0MhRIZ@3ooolB07N8VD`0oooo1P1gR9T_0?ooo`80MhRI8@3N
^8L00`1gR9T0Ool007oo000C07oo00@0MhRI903oool00180oooo2P1oo`000`1gR9T0g[R70=jhQ`0I
0=jhQ`d0MhRI201oo`0207N8VFl0oooo2@1gR9V[0?oooa00MhRIC03oool607N8VBl0oooo0`1gR9TO
0=jhQ`80MhRI5@1oo`0507N8VB<0oooo000A0?ooo`/0Ool00P1gR9TH0=jhQa40MhRI101oo`1h0?oo
o`D0MhRIZ`3oool@07N8VD`0oooo1P1gR9T^0?ooo`0407N8V@1oo`00Ool007oo01d0g[R70`1gR9TE
07oo00H0MhRI8P3oool00140oooo00<0MhRI07oo001oo`00201oo`0307N8VAD0g[R72`1gR9Wo0?oo
ocL0oooo3`1gR9U;0?ooo`H0MhRI;P3oool00`1gR9T0Ool007oo000207oo000307N8V@3N^8L0g[R7
01P0g[R7101gR9TE07oo00L0MhRI8@3oool00140oooo00<0MhRI07oo001oo`00201oo`0507N8VA40
g[R71P1gR9Wo0?oood00oooo3P1gR9U:0?ooo`H0MhRI;P3oool507oo0080MhRI603N^8L507N8VAD0
Ool02@1gR9TO0?ooo`004@3oool207N8V@T0Ool02@1gR9T;0=jhQol0ooooBP3oool<07N8VD/0oooo
1P1gR9T]0?ooo`@0Ool0101gR9TE0=jhQ`L0MhRI5@1oo`0:07N8VAh0oooo000A0?ooo`80MhRI1`1o
o`0>07N8VOl0ooooD`3oool<07N8VDX0oooo1P1gR9T]0?ooo`P0MhRI503N^8L907N8VA<0Ool0301g
R9TM0?ooo`004@3oool407N8V@D0Ool01P1gR9Wo0?oooed0oooo2`1gR9U:0?ooo`H0MhRI=03oool4
07N8V@h0g[R72`1gR9TB07oo00h0MhRI703oool00140oooo1P1gR9T207oo0?l0ooooIP3oool907N8
VDX0oooo1P1gR9Tj0?ooo`P0g[R7401gR9TA07oo00l0MhRI6`3oool00?l0ooooP@3oool807N8VDT0
oooo1`1gR9U10?oooa00MhRI401oo`0A07N8VAX0oooo003o0?oooh80oooo201gR9U90?ooo`H0MhRI
B03oool;07N8V@`0Ool0501gR9TI0?ooo`00o`3ooon40?ooo`H0MhRIB@3oool707N8VDh0oooo1P1g
R9T807oo01L0MhRI603oool00?l0ooooQP3oool507N8VDT0oooo1P1gR9UF0?ooo`@0Ool06P1gR9TG
0?ooo`00o`3ooon80?ooo`@0MhRIB03oool607N8VEd0oooo601gR9TF0?ooo`00o`3ooon90?ooo`<0
MhRIB03oool707N8VF<0oooo4P1gR9TE0?ooo`00o`3ooon;0?ooo`80MhRIB03oool607N8VFX0oooo
301gR9TD0?ooo`00o`3ooon=0?ooo`0307N8V@3oool0oooo04D0oooo1`1gR9U`0?ooo`H0MhRI4`3o
ool00?l0ooooe@3oool707N8VHT0oooo003o0?ooomH0oooo1`1gR9V80?ooo`00o`3ooooF0?ooo`L0
MhRIR03oool00?l0ooooe`3oool707N8VHL0oooo003o0?ooomL0oooo1`1gR9V70?ooo`00o`3ooooG
0?ooo`L0MhRIQ`3oool00?l0oooof03oool707N8VHH0oooo003o0?ooomP0oooo1`1gR9V60?ooo`00
o`3ooooI0?ooo`L0MhRIQ@3oool00?l0oooof@3oool707N8VHD0oooo003o0?ooomT0oooo201gR9V4
0?ooo`00o`3ooooJ0?ooo`L0MhRIQ03oool00?l0oooofP3oool207N8V@@0Ool00P1gR9V30?ooo`00
o`3ooooK0?ooo`0307N8V@1oo`00Ool000<0Ool000<0MhRI0?ooo`3oool0P@3oool00?l0oooof`3o
ool00`1gR9T0Ool007oo000407oo08<0oooo003o0?ooom/0oooo1`1oo`000`1gR9T0oooo0?ooo`20
0?ooo`00o`3ooooL0?ooo`H0Ool000<0MhRI0?ooo`3oool0P03oool00?l0oooog03oool607oo0080
MhRIP@3oool00?l0oooog03oool507oo00<0MhRIP@3oool00?l0oooog@3oool207N8V@D0g[R700<0
MhRI0?ooo`3oool0OP3oool00?l0oooog@3oool207N8V@H0g[R7P03oool00?l0oooogP3oool00`1g
R9T0g[R70=jhQ`040=jhQ`0307oo003oool0oooo07d0oooo003o0?ooomh0oooo1`3N^8L00`1gR9T0
oooo0?ooo`1m0?ooo`00o`3ooooN0?ooo`0307N8V@3N^8L0g[R700@0g[R700<0MhRI0?ooo`3oool0
O@3oool00?l0oooog`3oool60=jhQ`0307N8V@3oool0oooo07d0oooo003o0?oooml0oooo1@3N^8L2
07N8VGl0oooo003o0?ooon00oooo1P1gR9Uo0?ooo`00o`3ooooP0?ooo`0307N8V@1oo`00Ool00080
Ool000<0MhRI0?ooo`3oool0O@3oool00?l0ooooh03oool507oo000307N8V@3oool0oooo07d0oooo
003o0?ooon40oooo101oo`000`1gR9T0oooo0?ooo`1m0?ooo`00o`3ooooQ0?ooo`@0Ool000<0MhRI
0?ooo`3oool0O@3oool00?l0ooooh@3oool507N8VGl0oooo003o0?ooon80oooo101gR9Uo0?ooo`00
o`3ooooR0?ooo`@0MhRIO`3oool00?l0ooooh`3oool307N8VGl0oooo003o0?ooon<0oooo0`1gR9Uo
0?ooo`00o`3ooooS0?ooo`<0MhRIO`3oool00?l0ooooi03oool207N8VGl0oooo003o0?ooon@0oooo
0P1gR9Uo0?ooo`00o`3ooooU0?ooo`0307N8V@3oool0oooo07d0oooo003o0?ooonD0oooo00<0MhRI
0?ooo`3oool0O@3oool00?l0ooooi@3oool00`1gR9T0oooo0?ooo`1m0?ooo`00o`3ooooo0?ooofH0
oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?oo
ool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?oo
o`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo
003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
04d0oooo00<0MhRI0?ooo`3oool0o`3ooooo0?oooaH0oooo001=0?ooo`0307N8V@3oool0oooo0?l0
ooooo`3ooolF0?ooo`00C03oool207N8VOl0ooooo`3ooolH0?ooo`00C03oool207N8VOl0ooooo`3o
oolH0?ooo`00C03oool207N8VOl0ooooo`3ooolH0?ooo`00B`3oool407N8VOl0ooooo`3ooolG0?oo
o`00B`3oool407N8VOl0ooooo`3ooolG0?ooo`00B`3oool407N8VOl0ooooo`3ooolG0?ooo`00BP3o
ool507N8VOl0ooooo`3ooolG0?ooo`00BP3oool507N8VOl0ooooo`3ooolG0?ooo`00B@3oool607N8
VOl0ooooo`3ooolG0?ooo`00B@3oool707N8VOl0ooooo`3ooolF0?ooo`00B@3oool707N8VOl0oooo
o`3ooolF0?ooo`00B03oool807N8VOl0ooooo`3ooolF0?ooo`00B03oool807N8VOl0ooooo`3ooolF
0?ooo`00B03oool807N8VOl0ooooo`3ooolF0?ooo`00A`3oool907N8VOl0ooooo`3ooolF0?ooo`00
A`3oool:07N8VOl0ooooo`3ooolE0?ooo`00A`3oool:07N8VOl0ooooo`3ooolE0?ooo`00AP3oool;
07N8VOl0ooooo`3ooolE0?ooo`00AP3oool;07N8VB<0oooo00<0MhRI0?ooo`3oool0o`3ooon70?oo
o`0307N8V@3oool0oooo06@0oooo00150?ooo``0MhRI8`3oool207N8VOl0ooook`3oool004D0oooo
301gR9TT0?ooo`80MhRIo`3ooon80?ooo`0307N8V@3oool0oooo06<0oooo00150?ooo`d0MhRI8`3o
ool307N8VOl0ooooQ`3oool207N8VF@0oooo00140?ooo`h0MhRI903oool307N8VOl0ooooQ`3oool0
0`1gR9T0oooo0?ooo`1R0?ooo`00A03oool>07N8VB@0oooo101gR9Wo0?ooohH0oooo0P1gR9US0?oo
o`00A03oool>07N8VB@0oooo1@1gR9Wo0?ooohD0oooo0`1gR9UR0?ooo`00@`3oool?07N8VBD0oooo
1@1gR9Wo0?ooohD0oooo0P1gR9UR0?ooo`00@`3oool?07N8VBD0oooo1P1gR9Wo0?oooh@0oooo0`1g
R9UQ0?ooo`00@`3oool@07N8VBD0oooo1P1gR9Wo0?oooh<0oooo101gR9UP0?ooo`00@P3ooolA07N8
VBD0oooo1`1gR9Wo0?oooh<0oooo0`1gR9UP0?ooo`00@P3ooolA07N8VBH0oooo1`1gR9Wo0?oooh80
oooo101gR9UO0?ooo`00@@3ooolB07N8VBH0oooo201gR9Wo0?oooa/0oooo00<0MhRI0?ooo`3oool0
H`3oool507N8VEh0oooo00110?oooa80MhRI9P3oool907N8VOl0oooo6P3oool207N8VFD0oooo101g
R9UN0?ooo`00@@3ooolB07N8VBL0oooo2@1gR9Wo0?oooaT0oooo0`1gR9UT0?ooo`D0MhRIG@3oool0
0400oooo501gR9TV0?ooo`X0MhRIo`3ooolH0?ooo`@0MhRIH`3oool607N8VE`0oooo00100?oooa@0
MhRI9`3oool:07N8VOl0oooo5`3oool407N8VF@0oooo1@1gR9UL0?ooo`00@03ooolD07N8VBL0oooo
2`1gR9Wo0?oooaH0oooo1@1gR9US0?ooo`H0MhRIF`3oool003l0oooo5@1gR9TW0?ooo``0MhRIo`3o
oolE0?ooo`H0MhRIHP3oool707N8VEX0oooo000o0?oooaD0MhRI:03oool<07N8VOl0oooo503oool7
07N8VF80oooo1P1gR9UJ0?ooo`00?`3ooolE07N8VBP0oooo3P1gR9Wo0?oooa80oooo201gR9UQ0?oo
o`L0MhRIF@3oool003h0oooo5`1gR9TX0?ooo`h0MhRIo`3ooolA0?ooo`P0MhRIH@3oool807N8VEP0
oooo000n0?oooaL0MhRI:03oool?07N8VOl0oooo403oool907N8VF40oooo1`1gR9UH0?ooo`00?@3o
oolH07N8VBT0oooo3`1gR9Wo0?oooa00oooo2@1gR9UP0?ooo`P0MhRIE`3oool003d0oooo601gR9TY
0?oooa00MhRIo`3oool?0?ooo`X0MhRIG`3oool907N8VEH0oooo000m0?oooaP0MhRI:@3ooolA07N8
VOl0oooo3P3oool;07N8VEl0oooo201gR9UF0?ooo`00?03ooolI07N8VBX0oooo4@1gR9Wo0?ooo`d0
oooo2`1gR9UO0?ooo`T0MhRIE@3oool003`0oooo6P1gR9TY0?oooa80MhRIo`3oool<0?ooo``0MhRI
GP3oool:07N8VE@0oooo000l0?oooaX0MhRI:P3ooolB07N8VOl0oooo2`3oool=07N8VEh0oooo2@1g
R9UD0?ooo`00>`3ooolK07N8VBX0oooo4`1gR9Wo0?ooo`X0oooo3P1gR9UM0?ooo`X0MhRID`3oool0
03/0oooo6`1gR9T[0?oooa<0MhRIo`3oool90?ooo`l0MhRIG@3oool:07N8VE80oooo000k0?oooa/0
MhRI:`3ooolD07N8VOl0oooo203oool?07N8VEd0oooo2P1gR9UB0?ooo`00>P3ooolL07N8VB/0oooo
5@1gR9Wo0?ooo`L0oooo401gR9UL0?ooo`/0MhRID@3oool003X0oooo7@1gR9T[0?oooaD0MhRIo`3o
ool60?oooa40MhRIG03oool;07N8VE00oooo000i0?oooah0MhRI:`3ooolF07N8VI00oooo0P1gR9Ub
0?oooa80MhRIF`3oool;07N8VE00oooo000i0?ooo`L0MhRI2`1oo`0<07N8VB`0oooo5P1gR9V=0?oo
o`<0MhRIL`3ooolC07N8VEX0oooo101gR9T707oo000307N8V@3oool0oooo04d0oooo000i0?ooo`H0
MhRI401oo`0807N8VB`0oooo5`1gR9V:0?ooo`@0MhRIM@3ooolC07N8VEX0oooo0P1gR9T907oo0003
07N8V@3oool0oooo04`0oooo000h0?ooo`@0MhRI5@1oo`0607N8VB`0oooo601gR9V70?ooo`D0MhRI
MP3ooolC07N8VEX0oooo00<0MhRI07oo001oo`002@1oo`1>0?ooo`00>03oool307N8VAL0Ool01@1g
R9T]0?oooaP0MhRIP`3oool707N8VGL0oooo501gR9UI0?ooo`0307N8V@1oo`00Ool000T0Ool000<0
MhRI0?ooo`3oool0B`3oool003P0oooo0P1gR9TI07oo00D0MhRI;03ooolI07N8VH00oooo201gR9Uh
0?oooaD0MhRIF@3oool<07oo000307N8V@3oool0oooo04X0oooo000g0?ooo`80MhRI6`1oo`0407N8
VBd0oooo6P1gR9Ul0?ooo`X0MhRIN03oool707N8V@d0Ool00P1gR9UH0?ooo``0Ool000<0MhRI0?oo
o`3oool0BP3oool003L0oooo7P1oo`0307N8VBd0oooo6`1gR9Ui0?ooo`/0MhRIN@3oool607N8V@l0
Ool00P1gR9UG0?ooo``0Ool00P1gR9U;0?ooo`00=P3oool00`1gR9T0Ool007oo000M07oo0080MhRI
;P3oool<07N8V@d0Ool00P1gR9Ue0?ooo`d0MhRINP3oool507N8VA40Ool000<0MhRI0?ooo`3oool0
EP3oool:07oo00@0MhRIBP3oool003H0oooo8@1oo`000`1gR9T0oooo0?ooo`0/0?ooo`/0MhRI401o
o`000`1gR9T0oooo0?ooo`1`0?ooo`h0MhRIN`3oool407N8VA@0Ool0E`3oool:07oo00@0MhRIBP3o
ool003H0oooo8@1oo`000`1gR9T0oooo0?ooo`0/0?ooo`X0MhRI4P1oo`000`1gR9T0oooo0?ooo`1]
0?ooo`l0MhRIO03oool307N8VAH0Ool0EP3oool00`1gR9T0Ool007oo000607oo00H0MhRIB@3oool0
03D0oooo8`1oo`000`1gR9T0oooo0?ooo`0/0?ooo`P0MhRI501oo`000`1gR9T0oooo0?ooo`1Z0?oo
oa00MhRIO@3oool307N8VAL0Ool0EP3oool00`1gR9T0Ool007oo000307oo00L0g[R70P1gR9U80?oo
o`00=@3ooolS07oo000307N8V@3oool0oooo02`0oooo1`1gR9TE07oo0080MhRIJ03ooolB07N8VGh0
oooo0P1gR9TH07oo000307N8V@3oool0oooo05<0oooo1@1gR9T90=jhQ`0307N8V@3oool0oooo04H0
oooo000e0?ooob<0Ool000<0MhRI0?ooo`3oool0;@3oool607N8VAH0Ool00P1gR9UU0?oooa@0MhRI
OP3oool207N8VAT0Ool0E@3oool407N8V@/0g[R700<0MhRI0?ooo`3oool0A@3oool003@0oooo9@1o
o`0_0?ooo`D0MhRI601oo`0207N8VF80oooo5@1gR9Uo0?ooo`80MhRI6@1oo`000`1gR9T0oooo0?oo
o`1C0?ooo`80MhRI3@3N^8L00`1gR9T0oooo0?ooo`140?ooo`00=03ooolU07oo0300oooo101gR9TI
07oo0080MhRIG`3ooolF07N8VH40oooo6P1oo`0207N8VE@0oooo0P1gR9T>0=jhQdH0oooo000d0?oo
obD0Ool0<03oool407N8VAT0Ool00`1gR9UK0?ooo`0307N8V@1oo`00Ool000H0Ool03`1gR9V20?oo
oaX0Ool00`1gR9UC0?ooo`80MhRI3P3N^8L00`1gR9T0oooo0?ooo`130?ooo`00<`3oool00`1gR9T0
Ool007oo000S07oo000307N8V@3oool0oooo02d0oooo0`1gR9TK07oo00<0MhRIF03oool=07oo00`0
MhRIPP3ooolK07oo00@0MhRID`3oool?0=jhQ`80MhRIA03oool003<0oooo00<0MhRI07oo001oo`00
8`1oo`000`1gR9T0oooo0?ooo`0^0?ooo`80MhRI6`1oo`0407N8VED0oooo0P1gR9T>07oo00X0MhRI
P`3ooolK07oo00@0MhRID`3oool?0=jhQ`80MhRIA03oool00380oooo0P1gR9TU07oo000307N8V@3o
ool0oooo02h0oooo0P1gR9TK07oo00D0MhRIDP3oool307N8VA00Ool02@1gR9TP0?ooo`d0MhRIEP3o
oolK07oo00D0MhRIDP3oool?0=jhQ`<0MhRI@`3oool00380oooo0P1gR9TU07oo000307N8V@3oool0
oooo02l0oooo701oo`0607N8VDl0oooo101gR9TA07oo00P0MhRI8`3ooolI07N8VDP0oooo6`1oo`06
07N8VE40oooo3`3N^8L407N8VD80oooo000b0?ooo`80MhRI9@1oo`000`1gR9T0oooo0?ooo`0_0?oo
oa`0Ool01`1gR9U;0?ooo`L0MhRI4@1oo`0707N8VBH0oooo501gR9T507oo00`0MhRI>`3ooolJ07oo
00L0MhRID@3oool00`1oo`00g[R70=jhQ`0;0=jhQ`@0MhRI@P3oool00340oooo0`1gR9TU07oo0080
MhRI<03ooolL07oo00P0MhRIB03oool807N8VA80Ool01P1gR9TY0?oooa40MhRI201oo`0707N8V@H0
g[R72`1gR9T]0?oooaX0Ool0201gR9U@0?ooo`0307oo003N^8L0g[R700X0g[R71P1gR9U10?ooo`00
<@3oool307N8VBD0Ool00P1gR9Ta0?oooaX0Ool02P1gR9U50?ooo`X0MhRI4`1oo`0407N8VB`0oooo
3P1gR9T:07oo00<0MhRI2`3N^8L607N8V@D0Ool0301gR9TO0?oooaT0Ool02P1gR9U@0?ooo`/0g[R7
1P1oo`0207N8VD00oooo000a0?ooo`@0MhRI8`1oo`0307N8VC40oooo6P1oo`0;07N8VD80oooo301g
R9TC07oo00<0MhRI;`3oool<07N8V@X0Ool00`1gR9T<0=jhQ`@0MhRI201oo`0H07N8VA40oooo00<0
MhRI07oo001oo`005P1oo`0:07N8VE40oooo00<0MhRI0=jhQ`3N^8L01P3N^8L907oo0400oooo000`
0?ooo`D0MhRI8`1oo`0307N8VC40oooo6P1oo`0<07N8VCh0oooo2@3N^8L607N8VA<0Ool00P1gR9Tb
0?ooo`X0MhRI2P1oo`0207N8V@h0g[R700<0MhRI07oo001oo`002@1oo`0E07N8VA<0oooo00<0MhRI
07oo001oo`005P1oo`0;07N8VE40oooo0`1gR9T30=jhQ`0307N8V@1oo`00Ool000T0Ool0?`3oool0
0300oooo1@1gR9TS07oo00<0MhRI<P3ooolI07oo00h0MhRI>P3oool>0=jhQ`<0MhRI4`1oo`0207N8
VC@0oooo1`1gR9T;07oo000307N8V@3N^8L0g[R700d0g[R700<0MhRI07oo001oo`002@1oo`0B07N8
VAH0oooo0P1gR9TF07oo00d0MhRID@3oool507N8V@d0Ool0?P3oool00300oooo1@1gR9TS07oo00<0
MhRI<P3ooolH07oo0100MhRI=`3oool00`1gR9T0g[R70=jhQ`0?0=jhQ`0307N8V@1oo`00Ool00140
Ool000<0MhRI0?ooo`3oool0=@3oool507N8V@/0Ool0403N^8L00`1gR9T0Ool007oo000907oo00l0
MhRI6@3oool307N8VA@0Ool03`1gR9UA0?ooo`@0MhRI3@1oo`0n0?ooo`00;`3oool707N8VB40Ool0
1@1gR9Ta0?oooaL0Ool04P1gR9Td0?ooo`0307N8V@3N^8L0g[R70180g[R74P1oo`000`1gR9T0oooo
0?ooo`0h0?ooo`<0MhRI2`1oo`0A0=jhQ`/0Ool0301gR9TM0?ooo`<0MhRI4P1oo`0A07N8VE40oooo
0`1gR9T=07oo000307N8V@3oool0oooo03/0oooo000_0?ooo`L0MhRI801oo`0607N8VC80oooo5P1o
o`0207N8V@`0g[R71@1gR9T`0?ooo`<0MhRI5P3N^8LA07oo03d0oooo0P1gR9T:07oo0140g[R72`1o
o`0907N8VB00oooo101gR9T?07oo01<0MhRIDP3oool207N8V@d0Ool00P1gR9Tl0?ooo`00;P3oool9
07N8VAh0Ool01`1gR9Tc0?oooa@0Ool000<0MhRI0=jhQ`3N^8L0403N^8L207N8VBd0oooo101gR9TG
0=jhQ`0307N8V@1oo`00Ool000d0Ool0@03oool907oo000307N8V@3N^8L0g[R700l0g[R72`1oo`06
07N8VB<0oooo1P1gR9T<07oo00l0g[R71P1gR9UB0?ooo`0307N8V@1oo`00Ool000/0Ool00P1gR9Tl
0?ooo`00;P3oool:07N8VA`0Ool0201gR9Tc0?ooo`80MhRI4@1oo`0F0=jhQ`0307N8V@3oool0oooo
02P0oooo1P1gR9TH0=jhQ`h0Ool0@`3oool507oo00<0MhRI4@3N^8L00`1gR9T0Ool007oo000707oo
00@0MhRI9P3oool907N8V@P0Ool04P3N^8L507N8VE80oooo301oo`0407N8VC/0oooo000^0?ooo`/0
MhRI6P1oo`0907N8VC@0oooo0P1gR9T>07oo000307N8V@3N^8L0g[R701L0g[R79`3oool807N8VAT0
g[R700<0MhRI07oo001oo`00201oo`0207N8VDD0oooo1P1gR9TA0=jhQ`0307N8V@1oo`00Ool000H0
Ool00`1gR9TX0?ooo`h0MhRI5`3N^8L407N8VE80oooo2`1oo`0507N8VCX0oooo000]0?ooo`d0MhRI
6@1oo`0907N8VC@0oooo0`1gR9T;07oo000307N8V@3N^8L0g[R701X0g[R78`3oool:07N8VA/0g[R7
00<0MhRI07oo001oo`001P1oo`0207N8VDP0oooo1@1gR9T?0=jhQ`@0MhRI101oo`0207N8VB/0oooo
3@1gR9TK0=jhQ`80MhRIDP3oool907oo00H0MhRI>P3oool002d0oooo3P1gR9TG07oo00/0MhRI=03o
ool507N8V@D0Ool00`1gR9TN0=jhQb00oooo00<0MhRI07oo001oo`001P1oo`0307N8VA/0g[R70`1g
R9T407oo00<0MhRIB`3oool407N8V@h0g[R71`1gR9T^0?ooo``0MhRI7P3N^8MC0?ooo`L0Ool0201g
R9Ti0?ooo`00;@3oool@07N8VA@0Ool0301gR9Td0?ooo``0MhRI803N^8LM0?ooo`<0MhRI2@1oo`00
0`1gR9T0g[R70=jhQ`0J0=jhQ`T0MhRICP3oool207N8V@d0g[R71@1gR9Ta0?ooo`X0MhRI8@3N^8MC
0?ooo`D0Ool02P1gR9Th0?ooo`00;03ooolC07N8V@h0Ool0401gR9Td0?ooo`/0MhRI8P3N^8LJ0?oo
o`@0MhRI2P1oo`000`1gR9T0g[R70=jhQ`0K0=jhQ`L0MhRID@3oool207N8V@X0g[R70`1gR9Td0?oo
o`T0MhRI8P3N^8L00`1gR9T0oooo0?ooo`1A0?ooo`h0MhRI>03oool002`0oooo501gR9T;07oo0180
MhRI=@3oool:07N8VB80g[R700<0MhRI0?ooo`3oool0503oool707N8V@X0Ool000<0MhRI0=jhQ`3N
^8L06`3N^8L607N8VE@0oooo00<0MhRI0=jhQ`3N^8L0103N^8L307N8VCL0oooo201gR9TT0=jhQ`03
07N8V@3oool0oooo0500oooo3`1gR9Tg0?ooo`00;03ooolB07N8V@P0g[R75`1gR9Te0?ooo`T0MhRI
903N^8L00`1gR9T0oooo0?ooo`0E0?ooo`@0MhRI2`1oo`0N0=jhQ`D0MhRIE`3oool01@1gR9T0g[R7
07oo003N^8L0MhRI03X0oooo1`1gR9TV0=jhQ`0307N8V@3oool0oooo0500oooo3`1gR9Tf0?ooo`00
:`3oool=07N8VAD0g[R7401gR9Tf0?ooo`P0MhRI903N^8L207N8VAP0oooo0`1gR9T:07oo01h0g[R7
1@1gR9UI0?ooo`0307oo003oool0oooo03X0oooo1P1gR9TX0=jhQe<0oooo3P1gR9Tf0?ooo`00:`3o
ool:07N8VAX0g[R73`1gR9Te0?ooo`L0MhRI9P3N^8L207N8VAP0oooo0P1gR9T:07oo01h0g[R7101g
R9VH0?ooo`D0MhRI:@3N^8MC0?ooo`h0MhRI=@3oool002X0oooo2P1gR9TL0=jhQ`h0MhRI=@3oool7
07N8VBH0g[R70`1gR9TI0?ooo`0307N8V@1oo`00Ool000L0Ool07P3N^8L307N8VIT0oooo101gR9T[
0=jhQe<0oooo3P1gR9Td0?ooo`00:P3oool807N8VB40g[R72`1gR9Tf0?ooo`D0MhRI:03N^8L307N8
VAT0oooo201oo`0207N8VA`0g[R70`1gR9VJ0?ooo`@0MhRI:`3N^8L00`1gR9T0oooo0?ooo`1A0?oo
o`d0MhRI=03oool002X0oooo1@1gR9TU0=jhQ`X0MhRI=P3oool507N8VBP0g[R7101gR9TJ0?ooo`@0
Ool0101gR9TL0=jhQ`80MhRIV`3oool307N8VBd0g[R700<0MhRI0?ooo`3oool0D@3oool=07N8VC<0
oooo000Y0?ooo`D0MhRI9`3N^8L907N8VCL0oooo0`1gR9TY0=jhQ`0307N8V@1oo`00Ool00080Ool0
6`3oool607N8VA`0g[R700<0MhRI0?ooo`3oool0VP3oool307N8VBd0g[R70P1gR9UC0?ooo`d0MhRI
<P3oool002T0oooo101gR9TZ0=jhQ`L0MhRI=`3oool307N8VBT0g[R700<0MhRI07oo001oo`000`1o
o`0L0?ooo`D0MhRI6`3N^8L00`1gR9T0oooo0?ooo`2J0?ooo`80MhRI;`3N^8L00`1gR9T0oooo0?oo
o`1B0?ooo``0MhRI<P3oool002T0oooo0`1gR9T/0=jhQ`L0MhRI=`3oool207N8VBT0g[R71P1oo`00
0`1gR9T0oooo0?ooo`0J0?ooo`@0MhRI6P3N^8L00`1gR9T0oooo0?ooo`2K0?ooo`80MhRI;`3N^8L2
07N8VE@0oooo301gR9Ta0?ooo`00:03oool307N8VBh0g[R71P1gR9Tg0?ooo`80MhRI:@3N^8L00`1g
R9T0Ool007oo000307oo000307N8V@3oool0oooo01`0oooo0P1gR9TI0=jhQ`0307N8V@3oool0oooo
09`0oooo0P1gR9T_0=jhQ`<0MhRIE03oool<07N8VC00oooo000X0?ooo`<0MhRI;`3N^8L507N8VCL0
oooo0P1gR9TY0=jhQ`0307N8V@1oo`00Ool00080Ool000<0MhRI0?ooo`3oool07`3oool00`1gR9T0
g[R70=jhQ`0F0=jhQil0oooo00<0MhRI0=jhQ`3N^8L0;P3N^8L407N8VE@0oooo2`1gR9T`0?ooo`00
:03oool207N8VC00g[R71@1gR9Th0?ooo`0307N8V@3N^8L0g[R702L0g[R71@1gR9TS0?ooo`0307N8
V@3N^8L0g[R701@0g[R7X03oool00`1gR9T0g[R70=jhQ`0^0=jhQ`D0MhRIE03oool;07N8VBl0oooo
000W0?ooo`80MhRI<P3N^8L407N8VCP0oooo00<0MhRI0=jhQ`3N^8L09`3N^8L507N8VBD0oooo503N
^8NQ0?oooc80g[R7101gR9UE0?ooo`/0MhRI;P3oool002L0oooo00<0MhRI0=jhQ`3N^8L0<P3N^8L3
07N8VCT0oooo:@3N^8L407N8VBL0oooo4@3N^8L00`1gR9T0oooo0?ooo`2P0?oooc80g[R71@1gR9UD
0?ooo`/0MhRI;P3oool002H0oooo00<0MhRI0=jhQ`3N^8L0=03N^8L307N8VCP0oooo:@3N^8L307N8
VBX0oooo00<0MhRI0=jhQ`3N^8L02`3N^8L207N8VJ80oooo<P3N^8L607N8VE@0oooo2`1gR9T]0?oo
o`009P3oool00`1gR9T0g[R70=jhQ`0d0=jhQ`<0MhRI>03ooolY0=jhQ`<0MhRI;03oool207N8V@P0
g[R70`1gR9VS0?oooc80g[R71`1gR9UD0?ooo`/0MhRI;03oool002H0oooo=`3N^8L307N8VCP0oooo
:@3N^8L207N8VBl0oooo0`1gR9T30=jhQ`@0MhRIY03ooolb0=jhQ`P0MhRIE03oool:07N8VB`0oooo
000U0?ooocT0g[R70P1gR9Ti0?ooobP0g[R700<0MhRI0?ooo`3oool0;`3oool307N8V@@0Ool000<0
MhRI0?ooo`3oool0X`3ooolb0=jhQ`P0MhRIE@3oool:07N8VB/0oooo000U0?ooocX0g[R700<0MhRI
0?ooo`3oool0=`3ooolX0=jhQc@0oooo00<0MhRI07oo001oo`000P1oo`2V0?oooc80g[R72@1gR9UE
0?ooo`X0MhRI:P3oool002D0oooo>P3N^8L00`1gR9T0oooo0?ooo`0h0?ooobH0g[R700<0MhRI0?oo
o`3oool0<`3oool307oo0:L0oooo<P3N^8L:07N8VED0oooo2@1gR9TZ0?ooo`00903oooll0=jhQ`03
07N8V@3oool0oooo03L0oooo9P3N^8OQ0?oooc40g[R72`1gR9UE0?ooo`T0MhRI:@3oool002@0oooo
?03N^8L00`1gR9T0oooo0?ooo`0h0?ooob@0g[R7hP3oool`0=jhQ`d0MhRIE@3oool907N8VBP0oooo
000S0?ooo`0307N8V@3N^8L0g[R703X0g[R700<0MhRI0?ooo`3oool0>03ooolS0=jhQ`0307N8V@3o
ool0oooo0>00oooo<03N^8L407N8V@P0Ool000<0MhRI0?ooo`3oool0E03oool807N8VBP0oooo000S
0?ooocd0g[R700<0MhRI0?ooo`3oool0>@3ooolR0=jhQn<0oooo00<0MhRI0=jhQ`3N^8L0;@3N^8L2
07N8V@`0Ool0EP3oool807N8VBL0oooo000S0?oooch0g[R7>`3oool00`1gR9T0g[R70=jhQ`0N0=jh
Qn@0oooo00<0MhRI0=jhQ`3N^8L0;@3N^8L00`1gR9T0Ool007oo000<07oo05H0oooo201gR9TV0?oo
o`008P3oool00`1gR9T0g[R70=jhQ`0l0=jhQc`0oooo7`3N^8OU0?ooo`80MhRI;@3N^8LA07oo05H0
oooo1`1gR9TV0?ooo`008P3oool00`1gR9T0g[R70=jhQ`0l0=jhQ`0307N8V@3oool0oooo03T0oooo
0P1gR9TL0=jhQ`0307N8V@3oool0oooo0><0oooo0P1gR9T]0=jhQa80Ool0EP3oool707N8VBD0oooo
000R0?ooo`0307N8V@3N^8L0g[R703`0g[R700<0MhRI0?ooo`3oool0>P3oool207N8VAX0g[R700<0
MhRI0?ooo`3oool0i03oool307N8VB/0g[R7501oo`1E0?ooo`P0MhRI903oool00240oooo00<0MhRI
0=jhQ`3N^8L0?@3N^8L00`1gR9T0oooo0?ooo`0j0?ooo`<0MhRI5`3N^8L207N8VNP0oooo0P1gR9T[
0=jhQa@0Ool0EP3oool707N8VB@0oooo000Q0?ooo`0307N8V@3N^8L0g[R703d0g[R700<0MhRI0?oo
o`3oool0>P3oool407N8VA@0g[R7101gR9WX0?ooo`80MhRI:`3N^8LD07oo000307N8V@3oool0oooo
05@0oooo1`1gR9TS0?ooo`008@3oool00`1gR9T0g[R70=jhQ`0m0=jhQ`0307N8V@3oool0oooo03/0
oooo1@1gR9T@0=jhQ`D0MhRIj@3oool307N8VBT0g[R700<0MhRI07oo001oo`004P1oo`0207N8VEH0
oooo1`1gR9TR0?ooo`00803oool207N8VCl0g[R700<0MhRI0?ooo`3oool0>`3oool907N8V@X0g[R7
1P1gR9WZ0?ooo`<0MhRI:03N^8L00`1gR9T0Ool007oo000C07oo00<0MhRIEP3oool607N8VB80oooo
000P0?ooo`80MhRI?`3N^8L207N8VCd0oooo1`1gR9T607oo00X0MhRIj`3oool407N8VBH0g[R70P1g
R9TE07oo00@0MhRIEP3oool607N8VB40oooo000O0?ooo`<0MhRI?`3N^8L207N8VCd0oooo1@1gR9T9
07oo00T0MhRIj`3oool507N8VB@0g[R70`1gR9TE07oo00@0MhRIE`3oool607N8VB00oooo000O0?oo
o`<0MhRI?`3N^8L207N8VCh0oooo0`1gR9T;07oo00L0MhRIk03oool00`1gR9T0Ool007oo000307oo
000307N8V@3N^8L0g[R701l0g[R71@1gR9TD07oo00D0MhRIE`3oool507N8VB00oooo000O0?ooo`@0
MhRI?P3N^8L207N8VCh0oooo0P1gR9T=07oo00D0MhRIk@3oool00`1gR9T0Ool007oo000407oo0003
07N8V@3N^8L0g[R701d0g[R71P1gR9TC07oo00L0MhRIE`3oool507N8VAl0oooo000N0?ooo`D0MhRI
?P3N^8L207N8VCh0oooo0P1gR9T>07oo00@0MhRIk@3oool707oo0080MhRI7@3N^8L807N8VA80Ool0
201gR9UG0?ooo`D0MhRI7P3oool001h0oooo1@1gR9Tn0=jhQ`80MhRI?`3oool00`1gR9T0Ool007oo
000<07oo00<0MhRIkP3oool00`1gR9T0Ool007oo000407oo00@0MhRI6P3N^8L907N8VA40Ool02P1g
R9UG0?ooo`@0MhRI7P3oool001h0oooo1@1gR9Tn0=jhQ`<0MhRI?P3oool?07oo0080MhRIk`3oool0
0`1gR9T0Ool007oo000407oo00H0MhRI5@3N^8L=07N8VA00Ool02P1gR9UH0?ooo`@0MhRI7@3oool0
01d0oooo1P1gR9Tm0=jhQ`@0MhRI?`3oool>07oo000307N8V@3oool0oooo0>h0oooo00<0MhRI07oo
001oo`000`1oo`0907N8VA40g[R7401gR9T>07oo00`0MhRIF03oool407N8VA`0oooo000M0?ooo`L0
MhRI?03N^8L407N8VCl0oooo3P1oo`000`1gR9T0oooo0?ooo`3^0?oooa80MhRI303N^8LC07N8V@/0
Ool03`1gR9UH0?ooo`<0MhRI703oool001d0oooo1`1gR9Tl0=jhQ`@0MhRI?`3oool=07oo000307N8
V@3oool0oooo0?l0oooo1P3oool30=jhQ`030?ooo`1gR9T0MhRI01H0MhRI201oo`0B07N8VEL0oooo
101gR9TK0?ooo`00703oool807N8VC`0g[R7101gR9U00?ooo``0Ool0o`3ooolW0?ooo`@0Ool05@1g
R9UG0?ooo`@0MhRI6P3oool001`0oooo2@1gR9Tj0=jhQ`D0MhRI@03oool<07oo0?l0ooooV03oool3
07N8VAX0oooo000K0?ooo`X0MhRI>P3N^8L607N8VD00oooo00<0MhRI07oo001oo`001`1oo`3o0?oo
oiX0oooo0`1gR9TI0?ooo`006`3oool:07N8VCT0g[R71`1gR9U00?ooo`80MhRI1@1oo`0207N8VOl0
ooooW03oool307N8VAP0oooo000K0?ooo`/0MhRI=`3N^8L807N8VD40oooo1`1gR9Wo0?oooih0oooo
0P1gR9TH0?ooo`006P3oool=07N8VCH0g[R700<0MhRI07oo001oo`000P1oo`0307N8VD40oooo1`1g
R9Wo0?oooil0oooo0P1gR9TG0?ooo`006P3oool>07N8VCD0g[R71`1oo`000`1gR9T0oooo0?ooo`0o
0?ooo`H0MhRIo`3ooonQ0?ooo`80MhRI5P3oool001X0oooo0P1gR9T;07oo0080MhRI<P3N^8L:07oo
0480oooo101gR9Wo0?oooj<0oooo00<0MhRI0?ooo`3oool0503oool001T0oooo0P1gR9T>07oo0380
g[R72P1oo`000`1gR9T0oooo0?ooo`0o0?ooo`@0MhRIo`3ooonT0?ooo`0307N8V@3oool0oooo01<0
oooo000I0?ooo`0307N8V@1oo`00Ool000h0Ool0<03N^8L00`1gR9T0Ool007oo000807oo000307N8
V@3oool0oooo0400oooo0P1gR9Wo0?ooojH0oooo00<0MhRI0?ooo`3oool04P3oool001T0oooo4@1o
o`000`1gR9T0g[R70=jhQ`0/0=jhQ`80MhRI2P1oo`000`1gR9T0oooo0?ooo`100?ooo`0307N8V@3o
ool0oooo0?l0oooo^P3oool001P0oooo00<0MhRI07oo001oo`00401oo`000`1gR9T0g[R70=jhQ`0Z
0=jhQ`<0MhRI2P1oo`000`1gR9T0oooo0?ooo`3o0?ooood0oooo000H0?oooa<0Ool00P1gR9TZ0=jh
Q`D0MhRI201oo`0207N8VOl0ooooo`3oool001L0oooo00<0MhRI07oo001oo`004P1oo`0207N8VBL0
g[R71`1gR9T707oo00<0MhRIo`3ooooo0?ooo`005`3ooolE07oo00<0MhRI9@3N^8L:07N8V@@0Ool0
o`3ooooo0?ooo`@0oooo000G0?oooaH0Ool0101gR9TR0=jhQ`X0MhRIo`3ooooo0?ooo`T0oooo000F
0?ooo`0307N8V@1oo`00Ool001@0Ool01@1gR9TP0=jhQ`L0MhRIo`3ooooo0?ooo`d0oooo000F0?oo
o`0307N8V@1oo`00Ool001@0Ool01`1gR9TL0=jhQ`@0MhRIo`3ooooo0?oooa80oooo000F0?ooo`03
07N8V@1oo`00Ool001@0Ool0201gR9TH0=jhQ`<0MhRIo`3ooooo0?oooaH0oooo000E0?ooo`80MhRI
5P1oo`0;07N8VA80g[R700<0MhRI0?ooo`3oool0o`3ooooo0?oooaT0oooo000E0?ooo`80MhRI5P1o
o`0>07N8V@h0g[R7o`3ooooo0?oooad0oooo000E0?ooo`80MhRI5@1oo`0F07N8VOl0ooooo`3ooolT
0?ooo`00503oool407N8VA@0Ool04P1gR9Wo0?ooool0oooo:03oool001@0oooo101gR9TC07oo00h0
MhRIo`3ooooo0?ooobd0oooo000C0?ooo`L0MhRI401oo`0;07N8VOl0ooooo`3ooola0?ooo`004`3o
ool807N8V@h0Ool01`1gR9Wo0?ooool0oooo=P3oool001<0oooo201gR9T=07oo00@0MhRIo`3ooooo
0?ooocX0oooo000B0?ooo`/0MhRI2@1oo`000`1gR9T0oooo0?ooo`3o0?ooool0oooo?@3oool00180
oooo3@1gR9T507oo0?l0ooooo`3ooom20?ooo`004P3oool<07N8VOl0ooooo`3ooom80?ooo`004@3o
ool907N8VOl0ooooo`3ooom<0?ooo`004@3oool407N8VOl0ooooo`3ooomA0?ooo`00o`3ooooo0?oo
ofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o
0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0oooo
IP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0
ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00001\
\>"],
  ImageRangeCache->{{{0, 611}, {387.75, 0}} -> {-0.152834, -0.0952975, \
0.0103203, 0.0103203}, {{14.75, 104.25}, {378.5, 202.625}} -> {0.107492, \
-0.368496, 0.0067552, 0.0067552}, {{113.188, 202.625}, {378.5, 202.625}} -> \
{-0.706018, -0.196067, 0.00654049, 0.00654049}, {{211.563, 301}, {378.5, \
202.625}} -> {-0.541099, 0.0695159, 0.00445076, 0.00445076}, {{309.938, \
399.375}, {378.5, 202.625}} -> {-2.65671, -0.247238, 0.00900221, 0.00900221}, \
{{408.313, 497.75}, {378.5, 202.625}} -> {-1.0484, 0.285823, 0.00346857, \
0.00346857}, {{506.688, 596.188}, {378.5, 202.625}} -> {-3.54776, -0.280594, \
0.00732911, 0.00732911}, {{14.75, 104.25}, {185.063, 9.1875}} -> {0.0333434, \
-0.609427, 0.00379576, 0.00379576}, {{113.188, 202.625}, {185.063, 9.1875}} -> \
{-0.0712497, -0.499694, 0.00411522, 0.00411522}, {{211.563, 301}, {185.063, \
9.1875}} -> {-1.27173, -1.44897, 0.00742812, 0.00742812}, {{309.938, \
399.375}, {185.063, 9.1875}} -> {-1.56118, -0.956188, 0.00614546, \
0.00614546}, {{408.313, 497.75}, {185.063, 9.1875}} -> {-3.04008, -1.72509, \
0.00788273, 0.00788273}, {{506.688, 596.188}, {185.063, 9.1875}} -> \
{-3.01264, -1.18093, 0.00614279, 0.00614279}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CIRCLE TANGENT TO A TRIANGLE OF TYPE 2: one segment and two tangent circles\
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[x, a, b, c, xb]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[
      Solve[{size[{x, c} - {0, a}] \[Equal] a + c, 
          size[{x, c} - {xb, b}] \[Equal] b + c, 
          size[{0, a} - {xb, b}] \[Equal] a + b}, {x, c, xb}]]\)}], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \({{x \[Rule] \(2\ a\ \@b\)\/\(\(-\@a\) + \@b\), 
        xb \[Rule] \(-2\)\ \@a\ \@b, 
        c \[Rule] \(a\ b\)\/\((\@a - \@b)\)\^2}, {x \[Rule] \(2\ a\ \@b\)\/\(\
\@a - \@b\), xb \[Rule] 2\ \@a\ \@b, 
        c \[Rule] \(a\ b\)\/\((\@a - \@b)\)\^2}, {x \[Rule] \(-\(\(2\ a\ \
\@b\)\/\(\@a + \@b\)\)\), xb \[Rule] \(-2\)\ \@a\ \@b, 
        c \[Rule] \(a\ b\)\/\((\@a + \@b)\)\^2}, {x \[Rule] \(2\ a\ \@b\)\/\(\
\@a + \@b\), xb \[Rule] 2\ \@a\ \@b, 
        c \[Rule] \(a\ b\)\/\((\@a + \@b)\)\^2}}\)], "Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell["The one we need is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, c, 
        xb} = {x, c, xb} /. {x \[Rule] \(2\ a\ \@b\)\/\(\@a + \@b\), 
          xb \[Rule] 2\ \@a\ \@b, 
          c \[Rule] \(a\ b\)\/\((\@a + \@b)\)\^2}\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \({\(2\ a\ \@b\)\/\(\@a + \@b\), \(a\ b\)\/\((\@a + \@b)\)\^2, 
      2\ \@a\ \@b}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell[BoxData[
    \(type[2, a_, b_, p1_, r1_, p2_, r2_] := 
      Module[{r, u, v, h, 
          k}, \[IndentingNewLine]r = \(r1\ r2\)\/\((\@r1 + \@r2)\)\^2; \
\[IndentingNewLine]u = \(b - a\)\/size[b - a]; \[IndentingNewLine]h = 
          a + \((p1 - a)\) . u\ u; \[IndentingNewLine]k = 
          a + \((p2 - a)\) . 
                u\ u; \[IndentingNewLine]v = \(k - h\)\/size[k - h]; \
\[IndentingNewLine]{h + 2\ \ \(\@\(r\ r1\)\) v + \ 
            r\ \(p1 - h\)\/size[p1 - h], r}]\)], "Input",
  CellLabel->"In[86]:=",
  InitializationCell->True],

Cell["Testing with random circles:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]{icp, icr} = 
            incircle[a, b, c]; \[IndentingNewLine]{c1, r1} = 
            type[1, a, b, c, icp, icr]; \[IndentingNewLine]{c2, r2} = 
            type[1, b, a, c, icp, icr]; \[IndentingNewLine]{c3, r3} = 
            type[1, c, b, a, icp, icr]; \[IndentingNewLine]{c4, r4} = 
            type[2, a, b, icp, icr, c1, r1]; \[IndentingNewLine]{c5, r5} = 
            type[2, a, b, icp, icr, c2, r2]; \[IndentingNewLine]{c6, r6} = 
            type[2, b, c, icp, icr, c2, r2]; \[IndentingNewLine]{c7, r7} = 
            type[2, b, c, icp, icr, c3, r3]; \[IndentingNewLine]{c8, r8} = 
            type[2, a, c, icp, icr, c3, r3]; \[IndentingNewLine]{c9, r9} = 
            type[2, a, c, icp, icr, c1, 
              r1]; \[IndentingNewLine]Graphics[{{LightSlateGray, 
                Polygon[{a, b, c, a}]}, {Burlywood, 
                Disk[icp, icr]}, {Chartreuse, Disk[c1, r1], Disk[c2, r2], 
                Disk[c3, r3]}, {CadmiumOrange, Disk[c4, r4], Disk[c5, r5], 
                Disk[c6, r6], Disk[c7, r7], Disk[c8, r8], Disk[c9, r9]}}, 
            AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {12}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 6]]];\)\)}], "Input",
  CellLabel->"In[105]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .32463 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.00772926 0.15873 [
[ 0 0 0 0 ]
[ 1 .32463 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .32463 L
0 .32463 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00772926 0.17033 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.439 2.48002 -1.01622 2.48002 [
[ 0 0 0 0 ]
[ 1 1.45626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 1.42159 m
.02381 .03467 L
.09903 .72689 L
.97619 1.42159 L
F
.871 .722 .529 r
.24959 .64374 m
.24959 .64374 .15866 0 365.73 arc
F
.498 1 0 r
.4381 .84555 m
.4381 .84555 .1175 0 365.73 arc
F
.16095 .40462 m
.16095 .40462 .09637 0 365.73 arc
F
.10511 .72354 m
.10511 .72354 .0064 0 365.73 arc
F
1 .38 .01 r
.43548 .69413 m
.43548 .69413 .03394 0 365.73 arc
F
.27661 .45659 m
.27661 .45659 .03044 0 365.73 arc
F
.1071 .51942 m
.1071 .51942 .03044 0 365.73 arc
F
.102 .71316 m
.102 .71316 .00444 0 365.73 arc
F
.11224 .73169 m
.11224 .73169 .00444 0 365.73 arc
F
.28721 .83263 m
.28721 .83263 .03394 0 365.73 arc
F
0 0 m
1 0 L
1 1.45626 L
0 1.45626 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.00772926 0.331502 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.14141 1.15823 -0.297358 1.15823 [
[ 0 0 0 0 ]
[ 1 .47441 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .46311 m
.1641 .0113 L
.02381 .30618 L
.97619 .46311 L
F
.871 .722 .529 r
.2248 .2011 m
.2248 .2011 .13636 0 365.73 arc
F
.498 1 0 r
.44463 .27776 m
.44463 .27776 .09646 0 365.73 arc
F
.17548 .04688 m
.17548 .04688 .02556 0 365.73 arc
F
.07386 .28001 m
.07386 .28001 .03396 0 365.73 arc
F
1 .38 .01 r
.38613 .16739 m
.38613 .16739 .02846 0 365.73 arc
F
.21303 .05277 m
.21303 .05277 .01245 0 365.73 arc
F
.14831 .07346 m
.14831 .07346 .01245 0 365.73 arc
F
.07631 .231 m
.07631 .231 .01511 0 365.73 arc
F
.11551 .30597 m
.11551 .30597 .01511 0 365.73 arc
F
.33018 .32782 m
.33018 .32782 .02846 0 365.73 arc
F
0 0 m
1 0 L
1 .47441 L
0 .47441 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.00772926 0.492674 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.297706 1.58852 -0.392462 1.58852 [
[ 0 0 0 0 ]
[ 1 .4716 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .01123 m
.02381 .1189 L
.64988 .46037 L
.97619 .01123 L
F
.871 .722 .529 r
.5983 .2314 m
.5983 .2314 .17632 0 365.73 arc
F
.498 1 0 r
.81545 .10488 m
.81545 .10488 .075 0 365.73 arc
F
.33233 .17932 m
.33233 .17932 .09469 0 365.73 arc
F
.64255 .42784 m
.64255 .42784 .02505 0 365.73 arc
F
1 .38 .01 r
.7199 .06785 m
.7199 .06785 .02747 0 365.73 arc
F
.43384 .10428 m
.43384 .10428 .03154 0 365.73 arc
F
.39804 .28709 m
.39804 .28709 .03154 0 365.73 arc
F
.60494 .42081 m
.60494 .42081 .01321 0 365.73 arc
F
.67352 .40536 m
.67352 .40536 .01321 0 365.73 arc
F
.80054 .20626 m
.80054 .20626 .02747 0 365.73 arc
F
0 0 m
1 0 L
1 .4716 L
0 .4716 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.00772926 0.653846 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.209406 6.27546 -0.539892 6.27546 [
[ 0 0 0 0 ]
[ 1 3.12671 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.81524 3.05227 m
.02381 .07445 L
.97619 2.89115 L
.81524 3.05227 L
F
.871 .722 .529 r
.86549 2.8653 m
.86549 2.8653 .09659 0 365.73 arc
F
.498 1 0 r
.83204 2.98976 m
.83204 2.98976 .03229 0 365.73 arc
F
.8115 2.68628 m
.8115 2.68628 .09039 0 365.73 arc
F
.96719 2.88905 m
.96719 2.88905 .00785 0 365.73 arc
F
1 .38 .01 r
.80285 2.95518 m
.80285 2.95518 .01296 0 365.73 arc
F
.77031 2.79231 m
.77031 2.79231 .02335 0 365.73 arc
F
.90444 2.75186 m
.90444 2.75186 .02335 0 365.73 arc
F
.96621 2.87648 m
.96621 2.87648 .00475 0 365.73 arc
F
.96075 2.89989 m
.96075 2.89989 .00475 0 365.73 arc
F
.87463 2.97447 m
.87463 2.97447 .01296 0 365.73 arc
F
0 0 m
1 0 L
1 3.12671 L
0 3.12671 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.00772926 0.815018 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0887136 1.77755 -0.191061 1.77755 [
[ 0 0 0 0 ]
[ 1 .55458 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .0132 m
.97619 .02757 L
.69897 .54138 L
.02381 .0132 L
F
.871 .722 .529 r
.63357 .22853 m
.63357 .22853 .20611 0 365.73 arc
F
.498 1 0 r
.33882 .12445 m
.33882 .12445 .10648 0 365.73 arc
F
.86767 .09122 m
.86767 .09122 .06528 0 365.73 arc
F
.68485 .47383 m
.68485 .47383 .0445 0 365.73 arc
F
1 .38 .01 r
.46377 .05589 m
.46377 .05589 .03604 0 365.73 arc
F
.78471 .05141 m
.78471 .05141 .02673 0 365.73 arc
F
.86192 .18306 m
.86192 .18306 .02673 0 365.73 arc
F
.73461 .43164 m
.73461 .43164 .02074 0 365.73 arc
F
.62236 .4551 m
.62236 .4551 .02074 0 365.73 arc
F
.39301 .25626 m
.39301 .25626 .03604 0 365.73 arc
F
0 0 m
1 0 L
1 .55458 L
0 .55458 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.00772926 0.97619 0.154953 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.35178 2.09404 -0.262946 2.09404 [
[ 0 0 0 0 ]
[ 1 1.75848 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .71375 m
.02381 .04187 L
.67748 1.71661 L
.97619 .71375 L
F
.871 .722 .529 r
.64082 .82992 m
.64082 .82992 .28825 0 365.73 arc
F
.498 1 0 r
.94143 .72579 m
.94143 .72579 .02988 0 365.73 arc
F
.36489 .4775 m
.36489 .4775 .15934 0 365.73 arc
F
.6588 1.26471 m
.6588 1.26471 .14691 0 365.73 arc
F
1 .38 .01 r
.91186 .68929 m
.91186 .68929 .0171 0 365.73 arc
F
.57588 .49549 m
.57588 .49549 .05242 0 365.73 arc
F
.33174 .68665 m
.33174 .68665 .05242 0 365.73 arc
F
.5062 1.14024 m
.5062 1.14024 .05001 0 365.73 arc
F
.8006 1.12807 m
.8006 1.12807 .05001 0 365.73 arc
F
.94077 .77276 m
.94077 .77276 .0171 0 365.73 arc
F
0 0 m
1 0 L
1 1.75848 L
0 1.75848 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.169676 0.17033 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.358873 1.49241 -0.416489 1.49241 [
[ 0 0 0 0 ]
[ 1 1.0048 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .21632 m
.95747 .98088 L
.02381 .02392 L
.97619 .21632 L
F
.871 .722 .529 r
.73328 .41015 m
.73328 .41015 .23809 0 365.73 arc
F
.498 1 0 r
.94403 .24199 m
.94403 .24199 .03153 0 365.73 arc
F
.85869 .72941 m
.85869 .72941 .10491 0 365.73 arc
F
.41026 .2343 m
.41026 .2343 .12969 0 365.73 arc
F
1 .38 .01 r
.95747 .28856 m
.95747 .28856 .01695 0 365.73 arc
F
.92877 .60498 m
.92877 .60498 .0379 0 365.73 arc
F
.72266 .68594 m
.72266 .68594 .0379 0 365.73 arc
F
.45238 .40171 m
.45238 .40171 .04293 0 365.73 arc
F
.57372 .17882 m
.57372 .17882 .04293 0 365.73 arc
F
.9016 .21854 m
.9016 .21854 .01695 0 365.73 arc
F
0 0 m
1 0 L
1 1.0048 L
0 1.0048 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.184982 0.169676 0.331502 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499436 1.13872 -0.304199 1.13872 [
[ 0 0 0 0 ]
[ 1 .53272 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .20786 m
.68574 .01268 L
.02381 .52003 L
.97619 .20786 L
F
.871 .722 .529 r
.69059 .16835 m
.69059 .16835 .1265 0 365.73 arc
F
.498 1 0 r
.86478 .19245 m
.86478 .19245 .04935 0 365.73 arc
F
.68624 .02881 m
.68624 .02881 .01311 0 365.73 arc
F
.49896 .26942 m
.49896 .26942 .09015 0 365.73 arc
F
1 .38 .01 r
.83145 .13312 m
.83145 .13312 .0187 0 365.73 arc
F
.70582 .03522 m
.70582 .03522 .0075 0 365.73 arc
F
.66709 .03643 m
.66709 .03643 .0075 0 365.73 arc
F
.53784 .15944 m
.53784 .15944 .02651 0 365.73 arc
F
.61168 .29944 m
.61168 .29944 .02651 0 365.73 arc
F
.81659 .2405 m
.81659 .2405 .0187 0 365.73 arc
F
0 0 m
1 0 L
1 .53272 L
0 .53272 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.346154 0.169676 0.492674 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.42932 4.1085 -1.1178 4.1085 [
[ 0 0 0 0 ]
[ 1 1.38827 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .75566 m
.15045 1.35522 L
.02381 .03305 L
.97619 .75566 L
F
.871 .722 .529 r
.42344 .74984 m
.42344 .74984 .32947 0 365.73 arc
F
.498 1 0 r
.83628 .75418 m
.83628 .75418 .08339 0 365.73 arc
F
.24239 1.15134 m
.24239 1.15134 .11096 0 365.73 arc
F
.19448 .33918 m
.19448 .33918 .14071 0 365.73 arc
F
1 .38 .01 r
.77381 .85699 m
.77381 .85699 .03691 0 365.73 arc
F
.39511 1.12266 m
.39511 1.12266 .04443 0 365.73 arc
F
.16277 1.01789 m
.16277 1.01789 .04443 0 365.73 arc
F
.12187 .5171 m
.12187 .5171 .05146 0 365.73 arc
F
.38401 .37095 m
.38401 .37095 .05146 0 365.73 arc
F
.77598 .65008 m
.77598 .65008 .03691 0 365.73 arc
F
0 0 m
1 0 L
1 1.38827 L
0 1.38827 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.507326 0.169676 0.653846 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.704779 2.0443 -0.244701 2.0443 [
[ 0 0 0 0 ]
[ 1 1.3559 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.57274 1.32362 m
.02381 .64738 L
.97619 .03228 L
.57274 1.32362 L
F
.871 .722 .529 r
.45621 .71616 m
.45621 .71616 .29237 0 365.73 arc
F
.498 1 0 r
.53102 1.10611 m
.53102 1.10611 .10469 0 365.73 arc
F
.10995 .66109 m
.10995 .66109 .05824 0 365.73 arc
F
.72027 .36887 m
.72027 .36887 .1439 0 365.73 arc
F
1 .38 .01 r
.399 1.04456 m
.399 1.04456 .04098 0 365.73 arc
F
.13711 .74278 m
.13711 .74278 .02784 0 365.73 arc
F
.16111 .59185 m
.16111 .59185 .02784 0 365.73 arc
F
.52708 .38151 m
.52708 .38151 .0497 0 365.73 arc
F
.75974 .55841 m
.75974 .55841 .0497 0 365.73 arc
F
.63089 1.00008 m
.63089 1.00008 .04098 0 365.73 arc
F
0 0 m
1 0 L
1 1.3559 L
0 1.3559 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.668498 0.169676 0.815018 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.242419 1.29605 0.00682303 1.29605 [
[ 0 0 0 0 ]
[ 1 .95926 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.35614 .02284 m
.97619 .26497 L
.02381 .93642 L
.35614 .02284 L
F
.871 .722 .529 r
.49226 .32376 m
.49226 .32376 .23079 0 365.73 arc
F
.498 1 0 r
.38028 .0762 m
.38028 .0762 .04092 0 365.73 arc
F
.80325 .28598 m
.80325 .28598 .08248 0 365.73 arc
F
.27647 .60599 m
.27647 .60599 .12448 0 365.73 arc
F
1 .38 .01 r
.44144 .0779 m
.44144 .0779 .02026 0 365.73 arc
F
.72533 .20169 m
.72533 .20169 .03231 0 365.73 arc
F
.74778 .38647 m
.74778 .38647 .03231 0 365.73 arc
F
.44167 .59119 m
.44167 .59119 .04138 0 365.73 arc
F
.24745 .44269 m
.24745 .44269 .04138 0 365.73 arc
F
.34117 .12326 m
.34117 .12326 .02026 0 365.73 arc
F
0 0 m
1 0 L
1 .95926 L
0 .95926 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.82967 0.169676 0.97619 0.3169 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0160285 1.01834 -0.00771683 1.01834 [
[ 0 0 0 0 ]
[ 1 .77395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .75552 m
.55359 .43931 L
.97619 .01843 L
.02381 .75552 L
F
.871 .722 .529 r
.53074 .40991 m
.53074 .40991 .03695 0 365.73 arc
F
.498 1 0 r
.47314 .44918 m
.47314 .44918 .03275 0 365.73 arc
F
.5535 .4392 m
.5535 .4392 .00014 0 365.73 arc
F
.58299 .36399 m
.58299 .36399 .03262 0 365.73 arc
F
1 .38 .01 r
.51445 .45255 m
.51445 .45255 .00869 0 365.73 arc
F
.55328 .43935 m
.55328 .43935 .00012 0 365.73 arc
F
.5537 .43902 m
.5537 .43902 .00012 0 365.73 arc
F
.57606 .40469 m
.57606 .40469 .00867 0 365.73 arc
F
.54174 .36564 m
.54174 .36564 .00867 0 365.73 arc
F
.4851 .4095 m
.4851 .4095 .00869 0 365.73 arc
F
0 0 m
1 0 L
1 .77395 L
0 .77395 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[105]:=",
  ImageSize->{727.125, 236.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;G0000k2000`400?l00000o`00003oo`3ooooo
0?ooomT0oooo003o0?ooool0oooof@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo
003o0?ooool0oooof@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0
oooof@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0ooooM03oool0
0`1gR9T0oooo0?ooo`1R0?ooo`009@3oool00`1gR9T0oooo0?ooo`3o0?ooool0ooooC03oool207N8
VF<0oooo000U0?ooo`80MhRIo`3ooooo0?ooodh0oooo0`1gR9UQ0?ooo`009@3oool207N8VOl0oooo
o`3ooom>0?ooo`@0MhRIH03oool002D0oooo0`1gR9Wo0?ooool0ooooC@3oool607N8VEh0oooo000U
0?ooo`@0MhRIo`3ooooo0?ooodd0oooo1P1gR9UM0?ooo`009@3oool407N8VOl0ooooK`3oool00`1g
R9T0oooo0?ooo`3J0?ooo`P0MhRIF`3oool002D0oooo1@1gR9Wo0?ooool0ooooC@3oool807N8VEX0
oooo000U0?ooo`H0MhRIo`3ooooo0?oood`0oooo2P1gR9UH0?ooo`009@3oool607N8VOl0ooooKP3o
ool00`1gR9T0oooo0?ooo`3J0?ooo`/0MhRIE`3oool002H0oooo1P1gR9Wo0?ooofd0oooo00<0MhRI
0?ooo`3oool0f`3oool;07N8VEH0oooo000V0?ooo`L0MhRIo`3ooooo0?oood/0oooo3@1gR9UD0?oo
o`009P3oool807N8VOl0ooooK03oool00`1gR9T0oooo0?ooo`3K0?ooo`d0MhRID`3oool002H0oooo
201gR9Wo0?ooof`0oooo00<0MhRI0?ooo`3oool0f`3oool?07N8VE40oooo000V0?ooo`T0MhRIo`3o
oooo0?ooodX0oooo401gR9U@0?ooo`009P3oool:07N8VOl0ooooJ`3oool00`1gR9T0oooo0?ooo`3K
0?oooa40MhRICP3oool002H0oooo2P1gR9Wo0?ooof/0oooo00<0MhRI0?ooo`3oool0f`3oool;07N8
V@H0Ool000<0MhRI0?ooo`3oool0B`3oool002H0oooo2`1gR9Wo0?ooofX0oooo00<0MhRI0?ooo`3o
ool0g03oool807N8V@/0Ool0B`3oool002H0oooo301gR9Wo0?ooofX0oooo00<0MhRI0?ooo`3oool0
f`3oool707N8V@d0Ool0BP3oool002H0oooo301gR9Wo0?ooofX0oooo00<0MhRI0?ooo`3oool0f`3o
ool607N8V@h0Ool000<0MhRI0?ooo`3oool0A`3oool002L0oooo0P1gR9T907oo000307N8V@3oool0
oooo0?l0ooooI`3oool00`1gR9T0oooo0?ooo`3L0?ooo`@0MhRI4@1oo`000`1gR9T0oooo0?ooo`15
0?ooo`009`3oool207N8V@X0Ool000<0MhRI0?ooo`3oool0o`3ooomV0?ooo`80MhRIg@3oool307N8
VA80Ool00P1gR9U60?ooo`009`3oool207N8V@/0Ool0o`3ooomY0?ooo`0307N8V@3oool0oooo04X0
oooo<@1gR9UQ0?ooo`80MhRI4P1oo`0407N8VD@0oooo000W0?ooo`0307N8V@1oo`00Ool000/0Ool0
o`3ooomX0?ooo`0307N8V@3oool0oooo04/0oooo6@1gR9T;07oo00D0MhRI1P3oH@8<07N8V@L0g[R7
801gR9T_0?ooo`80MhRI4`1oo`0407N8VD<0oooo000W0?ooo`0307N8V@1oo`00Ool000/0Ool000<0
MhRI0?ooo`3oool0o`3ooomU0?ooo`80MhRIC@3ooolG07N8V@h0Ool00`1gR9T70?mQ0PD0MhRI4@3N
^8L607N8V@@0of420P1gR9T907oo00L0MhRI;`3oool207N8VA<0Ool000<0MhRI0?mQ0P3oH@800P3o
H@800`1gR9T0oooo0?ooo`0o0?ooo`009`3oool>07oo0080MhRIo`3ooomV0?ooo`80MhRIC`3ooolD
07N8VA00Ool00P1gR9T70?mQ0P<0MhRI5@3N^8L307N8V@H0of4200<0MhRI07oo001oo`00201oo`05
07N8VC40oooo501oo`000`1gR9T0of420?mQ0P030?mQ0P0307N8V@3oool0oooo03h0oooo000W0?oo
o`h0Ool00P1gR9UQ0?ooo`80MhRIo`3oool40?ooo`0307N8V@3oool0oooo04h0oooo4@1gR9TB07oo
000307N8V@3oH@80of4200H0of4200<0MhRI0=jhQ`3N^8L05`3N^8L207N8V@D0of42301oo`0407N8
VC40oooo00<0MhRI07oo001oo`004@1oo`060?mQ0P<0MhRI?P3oool002L0oooo3P1oo`0307N8VEl0
oooo101oo`000`1gR9T0oooo0?ooo`2l0?ooo`T0MhRI>P3oool207N8VE00oooo401gR9TC07oo0003
07N8V@3oH@80of4200D0of426`3N^8L00`1gR9T0of420?mQ0P020?mQ0Pd0Ool00`1gR9Tc0?oooa<0
Ool000<0MhRI0?mQ0P3oH@800`3oH@8407N8VCd0oooo000W0?ooo`d0Ool000D0MhRI0?mQ0P3oH@80
of4207N8V@1N0?ooo`D0Ool00P1gR9Vc0?oooa40MhRI>`3oool207N8VE40oooo3P1gR9TD07oo0003
07N8V@3oH@80of4200@0of427@3N^8L407N8V@d0Ool00`1gR9Tc0?oooa<0Ool000<0MhRI0?mQ0P3o
H@800P3oH@8707N8VC/0oooo000W0?ooo`0307N8V@1oo`00Ool000X0Ool01@3oH@9M0?ooo`H0Ool0
0P3oH@8207N8VJP0oooo1P1gR9T907oo00X0MhRI?@3oool00`1gR9T0oooo0?ooo`1A0?ooo``0MhRI
5@1oo`0207N8V@<0of427`3N^8L307N8V@d0Ool00P1gR9Td0?ooo`0307N8V@1oo`00Ool000l0Ool0
3P1gR9Tj0?ooo`00:03oool00`1gR9T0Ool007oo000907oo000307N8V@3oH@80of420080of4200<0
MhRI0?ooo`3oool0FP3oool00`1gR9T0Ool007oo000307oo0080of420`1gR9VN0?ooo`L0MhRI103o
H@8207N8V@`0Ool02@1gR9Tm0?ooo`80MhRID`3oool;07N8VAD0Ool0101gR9TR0=jhQ`0307N8V@1o
o`00Ool000/0Ool00P1gR9Te0?oooa00Ool00`1gR9T;0=jhQ`80MhRI>@3oool002P0oooo0P1gR9T9
07oo0080MhRI0`3oH@8307N8VE/0oooo00<0MhRI07oo001oo`000P1oo`000`1gR9T0of420?mQ0P05
07N8VI<0oooo2P3N^8L507N8V@D0of4200<0MhRI07oo001oo`00301oo`0707N8VCh0oooo0P1gR9UD
0?ooo`X0MhRI5P1oo`0207N8VB@0g[R73P1oo`0f0?ooo`0307N8V@1oo`00Ool000d0Ool04@3N^8L0
0`1gR9T0oooo0?ooo`0e0?ooo`00:03oool307N8V@H0Ool02P1gR9UJ0?ooo`80of420`1gR9T80=jh
Q`<0MhRIQ`3oool707N8VA00g[R70P1gR9T50?mQ0Pl0Ool01P1gR9To0?ooo`80MhRIEP3oool807N8
VAH0Ool00P1gR9TT0=jhQ`d0Ool000<0MhRI0?ooo`3oool0=@3oool>07oo01@0g[R7=P3oool002P0
oooo00@0MhRI0?mQ0P3oH@80of420`1gR9T;0=jhQ`80MhRIF@3oool20?mQ0Ph0g[R70P1gR9Ul0?oo
o`@0MhRI1@3oH@8507N8VA@0g[R71@3oH@8?07oo00D0MhRI@@3oool207N8VEH0oooo1P1gR9TG07oo
000307N8V@3N^8L0g[R702@0g[R7301oo`0h0?ooo`0307N8V@1oo`00Ool000T0Ool05`3N^8L00`1g
R9T0oooo0?ooo`0b0?ooo`00:03oool40?mQ0P0307N8V@3N^8L0g[R700d0g[R700<0MhRI0?ooo`3o
ool0E@3oool207N8VA40g[R70P1gR9Ua0?ooo`0307N8V@1oo`00Ool000@0Ool01P1gR9T50?mQ0P@0
MhRI5@3N^8L50?mQ0Q00Ool0101gR9U10?ooo`80MhRIE`3oool507N8VAL0Ool000<0MhRI0=jhQ`3N
^8L0903N^8L00`1gR9T0Ool007oo000807oo000307N8V@3oool0oooo03H0oooo0`1gR9T807oo0003
07N8V@3N^8L0g[R701H0g[R700<0MhRI0?ooo`3oool0<@3oool002P0oooo103oH@8A0=jhQeL0oooo
00<0MhRI0=jhQ`3N^8L04@3N^8L207N8VFL0oooo201gR9T;07oo0080MhRI1P3oH@8207N8VAT0g[R7
0`1gR9T@07oo00<0MhRI@P3oool207N8VEP0oooo101gR9TG07oo02P0g[R700<0MhRI07oo001oo`00
1P1oo`000`1gR9T0oooo0?ooo`0h0?ooo`H0MhRI0P1oo`0207N8VAX0g[R70P1gR9Ta0?ooo`00:03o
ool40?mQ0Q40g[R700<0MhRI0?ooo`3oool0D`3oool00`1gR9T0g[R70=jhQ`0C0=jhQ`<0MhRIG03o
ool@07N8V@d0Ool00P1gR9T60?mQ0P0307N8V@3N^8L0g[R701P0g[R70P1gR9T@07oo0080MhRI@`3o
ool307N8VET0oooo0`1gR9TF07oo02P0g[R70P1gR9T507oo00<0MhRI>P3oool207N8V@D0of420P1g
R9TL0=jhQ`80MhRI<03oool002P0oooo0`1gR9TC0=jhQ`0307N8V@3oool0oooo0580oooo5`3N^8L4
07N8VE00oooo601gR9T@07oo000307N8V@3oH@80of4200@0of42703N^8L00`1gR9T0Ool007oo000=
07oo0080MhRIA@3oool207N8VEX0oooo0P1gR9TF07oo02T0g[R7201gR9Tl0?ooo`0307N8V@3oH@80
of4200<0of420P1gR9TM0=jhQ`<0MhRI;P3oool002P0oooo0P1gR9TE0=jhQ`0307N8V@3oool0oooo
0500oooo6@3N^8L507N8VE00oooo5P1gR9TA07oo00D0of427P3N^8L?07oo0080MhRIA@3oool207N8
VE/0oooo0P1gR9TD07oo02X0g[R700<0MhRI0?mQ0P3oH@800P3oH@8207N8VCd0oooo1P3oH@800`1g
R9T0g[R70=jhQ`0L0=jhQ`80of420P1gR9T]0?ooo`00:03oool207N8VAH0g[R7D@3ooolJ0=jhQ`L0
MhRID03ooolC07N8VA80Ool0101gR9TP0=jhQ`h0Ool000<0MhRI0?ooo`3oool0A03oool307N8VE`0
oooo501oo`0Z0=jhQ`H0of4200<0MhRI0?ooo`3oool0>`3oool00`1gR9T0of420?mQ0P030?mQ0Ql0
g[R70P3oH@8207oo000307N8V@3oool0oooo02X0oooo000Y0?oooaL0g[R700<0MhRI0?ooo`3oool0
CP3ooolK0=jhQ`0307N8V@3oH@80of4200<0of4200<0MhRI0?ooo`3oool0C`3ooolA07N8VA<0Ool0
0`1gR9TP0=jhQ`0307N8V@1oo`00Ool000X0Ool000<0MhRI0?ooo`3oool0A@3oool307N8VEd0oooo
4P1oo`000`1gR9T0g[R70=jhQ`0X0=jhQ`0307N8V@3oH@80of4200<0of42?`3oool40?mQ0R40g[R7
101oo`0/0?ooo`00:@3ooolG0=jhQ`80MhRIC`3ooolK0=jhQ`0307N8V@3oH@80of4200<0of420`1g
R9UA0?ooo`l0MhRI4`1oo`0207N8VB80g[R72`1oo`000`1gR9T0oooo0?ooo`170?ooo`80MhRIG@3o
ool@07oo0080MhRI;03N^8L40?mQ0P0307N8V@3oool0oooo03d0oooo101gR9TR0=jhQ`80Ool000<0
MhRI0?ooo`3oool0:P3oool002T0oooo5`3N^8L207N8VDh0oooo703N^8L60?mQ0PD0MhRID@3oool=
07N8VA<0Ool00P1gR9TR0=jhQ`0307N8V@1oo`00Ool000L0Ool00P1gR9U90?ooo`<0MhRIGP3oool>
07oo0080MhRI;03N^8L407N8VD40oooo0`1gR9TR0=jhQ`<0MhRI;03oool002T0oooo5`3N^8L307N8
VDd0oooo7@3N^8L50?mQ0PL0MhRID03oool;07N8VA@0Ool000<0MhRI0=jhQ`3N^8L08P3N^8L00`1g
R9T0Ool007oo000507oo0080MhRIBP3oool307N8VF00oooo2`1oo`0307N8VB`0g[R7101gR9U10?oo
o`<0MhRI8P3N^8L20?mQ0Rd0oooo000Y0?oooaL0g[R7101gR9U<0?oooad0g[R71@3oH@8207N8V@@0
Ool00`1gR9U@0?ooo`T0MhRI501oo`0U0=jhQ`0307N8V@3oH@80of420080of42101gR9U<0?ooo`80
MhRIH@3oool00`1gR9T0Ool007oo000407oo00@0of420P1gR9T/0=jhQ`<0MhRI@P3oool307N8VB80
g[R70P3oH@8]0?ooo`00:@3ooolG0=jhQ`@0of42B`3oool00`1gR9T0g[R70=jhQ`0K0=jhQ`<0MhRI
2P1oo`0207N8VE40oooo1`1gR9TD07oo02D0g[R700<0MhRI0?mQ0P3oH@800`3oH@8207N8VDd0oooo
0`1gR9UQ0?ooo`H0MhRI1@3oH@800`1gR9T0g[R70=jhQ`0Z0=jhQ`<0MhRI@`3oool207N8VB80g[R7
0P1gR9T]0?ooo`00:@3oool00`1gR9T0g[R70=jhQ`0D0=jhQ`D0of42BP3oool00`1gR9T0g[R70=jh
Q`0K0=jhQ`80MhRI3@1oo`0207N8VE40oooo1P1gR9TC07oo02D0g[R71P3oH@8207N8VDd0oooo0`1g
R9US0?ooo`<0MhRI1`3oH@8/0=jhQ`80MhRIA03oool00`1gR9T0g[R70=jhQ`0Q0=jhQ`0307N8V@3o
ool0oooo02`0oooo000Y0?ooo`0307N8V@3N^8L0g[R701@0g[R71@3oH@800`1gR9T0oooo0?ooo`16
0?ooo`80MhRI7@3N^8L@07oo00<0MhRID@3oool407N8VA<0Ool09@3N^8L00`1gR9T0of420?mQ0P03
0?mQ0P0307N8V@3oool0oooo04`0oooo0`1gR9UT0?ooo`0307N8V@3oH@80of4200H0of42;03N^8L2
07N8VDD0oooo8`3N^8L00`1gR9T0oooo0?ooo`0/0?ooo`00:@3oool20?mQ0Q@0g[R700<0MhRI0?mQ
0P3oH@800`3oH@800`1gR9T0oooo0?ooo`150?ooo`<0of42703N^8L00`1gR9T0Ool007oo000?07oo
00@0MhRID@3oool307N8VA80Ool09@3N^8L00`1gR9T0of420?mQ0P020?mQ0P0307N8V@3oool0oooo
04h0oooo0`1gR9UT0?ooo`0307N8V@3oH@80of4200D0of4200<0MhRI0=jhQ`3N^8L0:@3N^8L00`1g
R9T0oooo0?ooo`140?ooo`0307N8V@3N^8L0g[R70200g[R700<0MhRI0?ooo`3oool0;03oool002T0
oooo0P1oo`0D0=jhQ`0307N8V@3oH@80of420080of420`1gR9U60?ooo`<0of4200<0MhRI0=jhQ`3N
^8L06@3N^8LC07oo00@0MhRID@3oool207N8VA40Ool000<0MhRI0=jhQ`3N^8L08`3N^8L507N8VE40
oooo0`1gR9UU0?ooo`L0of4200<0MhRI0=jhQ`3N^8L0:03N^8L207N8VDH0oooo00<0MhRI0=jhQ`3N
^8L0803N^8L00`1gR9T0oooo0?ooo`0/0?ooo`00:P3oool20?mQ0Q80g[R70P1gR9T507oo00<0MhRI
A@3oool30?mQ0P0307N8V@3N^8L0g[R701T0g[R74`1oo`0607N8VE40oooo00<0MhRI07oo001oo`00
3@1oo`0207N8VBD0g[R71@1gR9UA0?ooo`<0MhRII@3oool60?mQ0P80MhRI:P3N^8L00`1gR9T0oooo
0?ooo`160?ooob80g[R7;`3oool002`0oooo4P3N^8L00`1gR9T0Ool007oo000707oo000307N8V@3o
ool0oooo0440oooo101oo`0207N8VAX0g[R74`1oo`0807N8VE40oooo3@1oo`0307N8VBD0g[R7101g
R9UB0?ooo`@0MhRII`3oool507N8VBX0g[R7B@3ooolR0=jhQbl0oooo000]0?oooa00g[R7301oo`13
0?ooo`D0Ool000<0MhRI0=jhQ`3N^8L0603N^8LD07oo00T0MhRID03oool:07oo00@0of4200<0MhRI
0=jhQ`3N^8L08`3N^8L307N8VE@0oooo0`1gR9UX0?ooo`@0MhRI:P3N^8M90?ooob80g[R7;`3oool0
02h0oooo3@3N^8L00`1gR9T0Ool007oo000<07oo0440oooo00<0MhRI07oo001oo`00101oo`0I0=jh
QaD0Ool02`1gR9U?0?ooo`P0Ool000<0MhRI0?mQ0P3oH@800`3oH@8U0=jhQ`80MhRIE@3oool307N8
VFX0oooo0`1gR9TX0=jhQd/0oooo803N^8L`0?ooo`00<03oool90=jhQ`80MhRI3`1oo`000`1gR9T0
oooo0?ooo`0n0?ooo`L0Ool000<0MhRI0=jhQ`3N^8L05@3N^8L00`1gR9T0Ool007oo000C07oo00`0
MhRIDP3oool507N8V@H0of42903N^8L207N8VED0oooo101gR9UZ0?ooo`80MhRI:03N^8M;0?ooob00
g[R7<03oool00340oooo00<0MhRI0=jhQ`3N^8L00P3N^8L507N8V@l0Ool000<0MhRI0?ooo`3oool0
?@3oool207N8V@H0Ool00P1gR9TE0=jhQ`80MhRI5@1oo`0>07N8VE40oooo0`1gR9T70?mQ0R@0g[R7
00<0MhRI0?ooo`3oool0E03oool407N8VF/0oooo0P1gR9TV0=jhQdd0oooo7P3N^8L00`1gR9T0oooo
0?ooo`0^0?ooo`00<P3oool407N8V@@0of424@1oo`000`1gR9T0oooo0?ooo`0l0?ooo`80MhRI1@1o
o`00101gR9T0of420?mQ0P1gR9TC0=jhQ`@0MhRI501oo`0@07N8VE40oooo0P1gR9T60?mQ0P0307N8
V@3N^8L0g[R70200g[R700<0MhRI0?ooo`3oool0EP3oool307N8VF`0oooo00<0MhRI0=jhQ`3N^8L0
903N^8M=0?ooo`0307N8V@3N^8L0g[R701X0g[R700<0MhRI0?ooo`3oool0;`3oool003@0oooo00<0
MhRI0?mQ0P3oH@800`3oH@8A07oo0080MhRI?03oool407N8V@<0Ool000@0MhRI0?mQ0P3oH@80of42
0P1gR9TA0=jhQ`D0of42501oo`0B07N8VE40oooo1@3oH@8207N8VB80g[R7F@3oool407N8VFd0oooo
903N^8M>0?ooo`80MhRI6`3N^8L00`1gR9T0oooo0?ooo`0_0?ooo`00=@3oool50?mQ0Q40Ool00P1g
R9U30?ooo`80MhRI0P3oH@8307N8V@l0g[R700<0MhRI0?mQ0P3oH@800`3oH@800`1gR9T0Ool007oo
000@07oo01D0MhRID@3oool607N8VB00g[R700<0MhRI0?ooo`3oool0E`3oool407N8VFh0oooo8P3N
^8L00`1gR9T0oooo0?ooo`1=0?ooo`0307N8V@3N^8L0g[R701P0g[R70P1gR9Ta0?ooo`00=@3oool4
0?mQ0P0307N8V@1oo`00Ool000l0Ool00`1gR9U80?ooo`80MhRI303N^8L207N8V@H0of4200<0MhRI
07oo001oo`003`1oo`0G07N8VE80oooo101gR9TO0=jhQ`0307N8V@3oool0oooo05T0oooo0`1gR9U_
0?ooob00g[R700<0MhRI0?ooo`3oool0CP3oool207N8VAP0g[R70`1gR9Ta0?ooo`00>03oool207N8
VA40Ool0101gR9U<0?ooo`H0g[R71P1gR9T50?mQ0P80MhRI401oo`0I07N8VE80oooo0`1gR9TN0=jh
Qe`0oooo101gR9U_0?oooah0g[R70P1gR9UA0?ooo`80MhRI5P3N^8L307N8VC80oooo000i0?ooo`03
07N8V@1oo`00Ool000h0Ool01@1gR9UD0?ooo`@0MhRI1@3oH@8207N8V@l0Ool0701gR9UA0?ooo`<0
MhRI703N^8MM0?ooo`@0MhRIK`3ooolL0=jhQ`<0MhRIDP3oool307N8VA<0g[R71@1gR9Tb0?ooo`00
>P3oool00`1gR9T0Ool007oo000=07oo00H0MhRIF@3oool707N8V@/0Ool0801gR9UA0?ooo`0307N8
V@3N^8L0g[R701T0g[R700<0MhRI0?ooo`3oool0F`3oool407N8VG40oooo6P3N^8L307N8VE80oooo
1P1gR9T?0=jhQ`<0of420`1gR9Tb0?ooo`00>`3oool00`1gR9T0Ool007oo000;07oo00P0MhRIGP3o
ool207N8V@P0Ool0901gR9UA0?ooo`0307N8V@3N^8L0g[R701H0g[R700<0MhRI0?ooo`3oool0G@3o
ool407N8VG80oooo5`3N^8L307N8VE@0oooo0P1gR9T40?mQ0P`0g[R700<0MhRI0?mQ0P3oH@800`3o
H@800`1gR9T0oooo0?ooo`0a0?ooo`00?03oool<07oo00X0MhRIH@3oool407oo02L0MhRIDP3ooolF
0=jhQ`0307N8V@3oool0oooo05h0oooo101gR9Ud0?oooa<0g[R7101gR9UE0?ooo`80MhRI1@3oH@83
07N8V@D0g[R70`1gR9T70?mQ0S<0oooo000n0?ooo`T0Ool02`1gR9UZ0?ooob@0MhRID@3ooolD0=jh
Q`0307N8V@3oool0oooo05l0oooo101gR9Ue0?ooo`0307N8V@3N^8L0g[R700d0g[R700<0MhRI0?mQ
0P3oH@800P3oH@800`1gR9T0oooo0?ooo`1D0?ooo`H0of4200<0MhRI07oo001oo`001`1oo`0207N8
V@H0of42<`3oool003l0oooo1P1oo`0>07N8VFl0oooo801gR9UA0?oooa00g[R70`1gR9UQ0?ooo`D0
MhRIM@3oool207N8V@T0g[R7101gR9T50?mQ0UL0oooo1P3oH@8<07oo00H0of42<`3oool00400oooo
501gR9Ue0?oooa/0MhRID@3oool;0=jhQ`0507N8V@3oH@80of420?mQ0P1gR9T0H`3oool407N8VGL0
oooo0P1gR9T30?mQ0P80MhRI1`1oo`030?mQ0P0307N8V@3oool0oooo05D0oooo1@3oH@800`1gR9T0
Ool007oo000:07oo00D0of42=03oool00480oooo4P1gR9Uk0?oooaL0MhRID@3oool307N8V@80g[R7
0P1gR9T307oo000307N8V@3oH@80of4206@0oooo101gR9Uh0?ooo`D0of422@1oo`0207N8VET0oooo
101gR9T?07oo00<0MhRI=03oool004<0oooo4P1gR9V00?oooa80MhRIDP3oool01@1gR9T0of420?mQ
0P3oH@80MhRI00@0Ool000<0MhRI0?ooo`3oool0H`3oool507N8VGP0oooo103oH@8907oo0080MhRI
F@3oool307N8VA00Ool00`1gR9Td0?ooo`00A03ooolB07N8VHH0oooo3@1gR9UA0?ooo`80of4200<0
MhRI07oo001oo`000`1oo`000`1gR9T0oooo0?ooo`1S0?ooo`D0MhRIN03oool30?mQ0PX0Ool000<0
MhRI0?ooo`3oool0F@3oool207N8VA00Ool00P1gR9Te0?ooo`00AP3oool@07N8VH`0oooo2@1gR9UB
0?ooo`D0Ool0I`3oool407N8VG/0oooo00<0MhRI07oo001oo`001`1oo`000`1gR9T0oooo0?ooo`1I
0?ooo`0307N8V@1oo`00Ool00100Ool000<0MhRI0?ooo`3oool0<`3oool004L0oooo401gR9VA0?oo
o`D0MhRID03oool407oo06P0oooo1@1gR9Uk0?ooo`T0Ool0G03oool00`1gR9T0Ool007oo000@07oo
000307N8V@3oool0oooo03<0oooo00180?oooa00MhRIo`3ooomB0?ooo`D0MhRIO03oool707oo0003
07N8V@3oool0oooo05/0oooo4P1oo`0f0?ooo`00B@3oool?07N8VOl0ooooD`3oool407N8VGd0oooo
1@1oo`000`1gR9T0oooo0?ooo`1L0?oooa80Ool0=P3oool004/0oooo3P1gR9Wo0?oooe80oooo1@1g
R9Ul0?ooo`@0Ool00P1gR9UO0?oooa40Ool0=P3oool004`0oooo3P1gR9Wo0?oooe40oooo1@1gR9Uo
0?ooo`80MhRIH03oool@07oo000307N8V@3oool0oooo03@0oooo001=0?ooo`h0MhRIo`3ooom@0?oo
o`D0MhRIh@3oool00`1gR9T0Ool007oo000=07oo03L0oooo001>0?ooo`d0MhRIo`3ooomA0?ooo`D0
MhRIh@3oool>07oo000307N8V@3oool0oooo03D0oooo001@0?ooo``0MhRIo`3ooom@0?ooo`D0MhRI
h@3oool=07oo0080MhRI=`3oool00540oooo301gR9Wo0?ooodl0oooo1@1gR9WR0?ooo`0307N8V@1o
o`00Ool000P0Ool00P1gR9Th0?ooo`00DP3oool;07N8VOl0ooooC`3oool607N8VN40oooo0P1gR9T7
07oo00@0MhRI>03oool005@0oooo2P1gR9Wo0?ooodl0oooo1@1gR9WQ0?ooo`H0MhRI00<0Ool007N8
V@1gR9T0101gR9Th0?ooo`00E@3oool:07N8VOl0ooooCP3oool507N8VN80oooo301gR9Th0?ooo`00
EP3oool907N8VOl0ooooCP3oool607N8VN40oooo2`1gR9Ti0?ooo`00E`3oool907N8VOl0ooooC@3o
ool607N8VN80oooo2P1gR9Ti0?ooo`00F@3oool807N8VOl0ooooC@3oool507oo0>80oooo2P1gR9Ti
0?ooo`00FP3oool707N8VOl0ooooC@3oool607oo0>40oooo2@1gR9Tj0?ooo`00F`3oool707N8VOl0
ooooB`3oool707oo0>80oooo201gR9Tj0?ooo`00G03oool707N8VOl0ooooB`3oool607oo0>80oooo
201gR9Tj0?ooo`00GP3oool607N8VOl0ooooBP3oool507oo00030?mQ0P1gR9T0oooo0>40oooo1P1g
R9Tk0?ooo`00G`3oool507N8VOl0ooooB`3oool00`3oH@80g[R70=jhQ`020=jhQ`0307N8V@3oool0
oooo0>00oooo1P1gR9Tk0?ooo`00H03oool507N8VOl0ooooBP3oool00`3oH@80g[R70=jhQ`030=jh
Qn80oooo1P1gR9Tk0?ooo`00HP3oool407N8VOl0ooooBP3oool60=jhQn80oooo1@1gR9Tk0?ooo`00
H`3oool307N8VOl0ooooB@3oool70=jhQ`030?mQ0P3oool0oooo0=l0oooo101gR9Tl0?ooo`00I03o
ool307N8VOl0ooooB@3oool50=jhQ`80of42hP3oool307N8VC`0oooo001U0?ooo`<0MhRIo`3ooom8
0?ooo`D0g[R7i03oool307N8VC`0oooo001W0?ooo`0307N8V@3oool0oooo0?l0ooooAP3oool20?mQ
0P80MhRIi@3oool207N8VCd0oooo001X0?ooo`0307N8V@3oool0oooo0?l0ooooA@3oool207oo0003
0?mQ0P3oool0oooo0>D0oooo00<0MhRI0?ooo`3oool0>`3oool006T0oooo00<0MhRI0?ooo`3oool0
o`3ooom40?ooo`80Ool0j03oool00`1gR9T0oooo0?ooo`0k0?ooo`00o`3ooooo0?ooomT0oooo003o
0?ooool0oooof@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooo
f@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooof@3oool00?l0
ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooof@3oool00?l0ooooo`3ooooI
0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooof@3oool00?l0ooooo`3ooooI0?ooo`00o`3o
oooo0?ooomT0oooo003o0?ooool0oooof@3oool001D0oooo1@1gR9Wc0?ooo`0307N8V@3oool0oooo
0;T0oooo00<0MhRI0?ooo`3oool0o`3oool<0?ooo`005P3oool907N8VNh0oooo0P1gR9Vh0?ooo`<0
MhRIo`3oool>0?ooo`005`3oool=07N8VNT0oooo0`1gR9Vf0?ooo`@0MhRI@03oool307N8VLX0oooo
000H0?oooa40MhRIi03oool507N8VK80oooo1@1gR9U10?ooo`H0MhRIa`3oool001T0oooo5@1gR9WO
0?ooo`H0MhRI/03oool607N8VD00oooo00<0MhRI07oo001oo`00101oo`0207N8VLD0oooo000J0?oo
oaT0MhRIfP3oool707N8VJd0oooo201gR9U00?ooo`P0Ool0101gR9W20?ooo`006`3ooolM07N8VMD0
oooo2@1gR9VZ0?ooo`P0MhRI@@3oool807oo000407N8V@3oH@80of420?mQ0P80MhRI`03oool001`0
oooo8@1gR9W@0?ooo`X0MhRIY`3oool:07N8VD00oooo00<0MhRI07oo001oo`001P1oo`050?mQ0P@0
MhRI_@3oool001d0oooo7`1gR9T507oo000307N8V@3oool0oooo0<T0oooo2`1gR9VT0?ooo``0MhRI
@03oool00`1gR9T0Ool007oo000607oo000307N8V@3oH@80of420080of421P1gR9Vk0?ooo`007P3o
oolH07N8V@h0Ool00`1gR9W60?ooo`d0MhRIX@3oool<07N8VD40oooo0P1gR9T707oo0080MhRI0P3o
H@8:07N8VKP0oooo000O0?oooaH0MhRI4@1oo`0607N8VL40oooo3P1gR9VN0?ooo`h0MhRI@03oool3
07N8V@H0Ool000<0MhRI0=jhQ`3N^8L0303N^8L207N8VKH0oooo000P0?oooa@0MhRI4`1oo`0:07N8
VKd0oooo3P1gR9VL0?ooo`l0MhRI@03oool40?mQ0P<0Ool000<0MhRI0=jhQ`3N^8L04`3N^8Nc0?oo
o`008@3ooolB07N8VAD0Ool0101gR9T60?mQ0P@0MhRI^03oool@07N8VIP0oooo4@1gR9U00?ooo`@0
of420P1gR9TH0=jhQ`0307N8V@3oool0oooo0:l0oooo000R0?oooa00MhRI5`1oo`0207N8V@P0of42
201gR9Vc0?ooo`D0MhRI2`1oo`000`1gR9T0oooo0?ooo`2D0?oooa40MhRI@03oool0101gR9T0of42
0?mQ0P3oH@8L0=jhQ`<0MhRI[P3oool002<0oooo3`1gR9TG07oo0080MhRI203oH@8=07N8VJh0oooo
101gR9T=07oo000307N8V@3oool0oooo0940oooo4`1gR9U00?ooo`@0MhRI7P3N^8L307N8VJ`0oooo
000T0?ooo`d0MhRI601oo`000`1gR9T0of420?mQ0P070?mQ0Q80MhRIZ@3oool307N8VA00Ool000<0
MhRI0?ooo`3oool0S@3oool207N8V@P0Ool02`1gR9To0?ooo`@0MhRI803N^8L507N8VHh0oooo00<0
MhRI0?ooo`3oool0603oool002D0oooo301gR9TI07oo00T0of42101gR9T?0=jhQ`@0MhRIY03oool2
07N8VA80Ool000<0MhRI0?ooo`3oool0R`3oool00`1gR9T0Ool007oo000:07oo00P0MhRI@03oool2
07N8VB<0g[R71`1gR9V:0?ooo`0307N8V@3oool0oooo01T0oooo000V0?ooo`/0MhRI6@1oo`090?mQ
0P80MhRI5P3N^8L407N8VIl0oooo0P1gR9TB07oo0080MhRIRP3oool00`1gR9T0Ool007oo000=07oo
00L0MhRI@03oool00`1gR9T0g[R70=jhQ`0T0=jhQ`L0MhRIQ`3oool00`1gR9T0oooo0?ooo`0J0?oo
o`009`3oool907N8VA/0Ool0203oH@8I0=jhQ`P0MhRIVP3oool00`1gR9T0Ool007oo000B07oo00<0
MhRIQ`3ooolB07oo00H0MhRI?`3oool00`1gR9T0g[R70=jhQ`0V0=jhQ`80MhRI1@3oH@8207N8VH80
oooo0P1gR9TM0?ooo`00:03oool807N8VA/0Ool00P1gR9T50?mQ0Q/0g[R70`1gR9T30?mQ0PH0MhRI
U@3oool00`1gR9T0Ool007oo000B07oo00@0MhRIQ03oool207N8VA<0Ool0101gR9U00?ooo`0307N8
V@3N^8L0g[R702H0g[R70P1gR9T60?mQ0P<0MhRIO`3oool207N8VAh0oooo000Y0?ooo`L0MhRI6`1o
o`0307N8V@80of427`3N^8L01@1gR9T0of420?mQ0P3oH@80MhRI00@0Ool000<0MhRI0?ooo`3oool0
T`3ooolE07oo00D0MhRIPP3oool207N8VA@0Ool0101gR9U00?ooobX0g[R71`3oH@8607N8VG/0oooo
0P1gR9TO0?ooo`00:P3oool607N8VA/0Ool0101gR9TQ0=jhQ`<0of4200<0MhRI07oo001oo`000`1o
o`2E0?oooaD0Ool01`1gR9Un0?ooo`@0MhRI5@1oo`0307N8VCl0oooo00<0MhRI0=jhQ`3N^8L0:03N
^8L00`1gR9T0of420?mQ0P040?mQ0P80MhRI1@1oo`000`1gR9T0oooo0?ooo`1f0?ooo`80MhRI803o
ool002/0oooo1@1gR9TK07oo00<0MhRI8`3N^8L207N8V@H0Ool0U@3ooolE07oo0080MhRI1@3oH@80
0`1gR9T0oooo0?ooo`1j0?ooo`D0MhRI5@1oo`0207N8VD00oooo;03N^8L60?mQ0P0307N8V@1oo`00
Ool000L0Ool000<0MhRI0?ooo`3oool0L@3oool307N8VB40oooo000/0?ooo`@0MhRI6`1oo`0207N8
VBD0g[R700<0MhRI07oo001oo`00101oo`2E0?oooaH0Ool000<0MhRI0?mQ0P3oH@80103oH@800`1g
R9T0oooo0?ooo`1f0?ooo`D0of420P1gR9TF07oo0080MhRI@03oool/0=jhQ`0307N8V@3oH@80of42
0080of42301oo`0207N8VG00oooo0`1gR9TR0?ooo`00;@3oool307N8VA/0Ool000<0MhRI0=jhQ`3N
^8L09@3N^8L507oo000307N8V@3oool0oooo05<0oooo0P1oo`000`1gR9T0oooo0?ooo`0k0?oooaH0
Ool01`3oH@8307N8VGD0oooo00<0MhRI0?mQ0P3oH@80103oH@800`1gR9T0Ool007oo000D07oo0080
MhRI?`3oool00`1gR9T0g[R70=jhQ`0Z0=jhQ`@0MhRI3P1oo`0407N8VF`0oooo0`1gR9TS0?ooo`00
;P3oool207N8VA/0Ool0:@3N^8L507N8VE@0oooo00H0of4207oo001oo`00MhRI0?mQ0P1gR9Tl0?oo
oa@0Ool0203oH@8407N8VG<0oooo0P1gR9T70?mQ0QH0Ool00P1gR9To0?ooobh0g[R70P1gR9T?07oo
00H0MhRIJ03oool407N8VB@0oooo000_0?ooo`0307N8V@1oo`00Ool001T0Ool0:@3N^8L207N8V@<0
of42D`3oool00`1gR9T0of4207N8V@0207N8V@030?mQ0P1gR9T0MhRI03/0oooo501oo`000`1gR9T0
of420?mQ0P050?mQ0PD0MhRIL03oool307N8V@P0of425`1oo`0o0?ooo`0307N8V@3N^8L0g[R702`0
g[R70P1gR9T@07oo00P0MhRII03oool407N8VBD0oooo000`0?ooo`0307N8V@1oo`00Ool001L0Ool0
:`3N^8L0101gR9T0of420?mQ0P3oH@9A0?ooo`0307N8V@3N^8L0g[R700T0g[R7>@3oool00`1gR9T0
Ool007oo000A07oo000307N8V@3oH@80of4200D0of421`1gR9U]0?ooo`D0MhRI1`3oH@8G07oo03l0
oooo<03N^8LA07oo00X0MhRIH@3oool407N8VBH0oooo000a0?ooo`0307N8V@1oo`00Ool001H0Ool0
;03N^8L30?mQ0U00oooo3P3N^8Lh0?ooo`0307N8V@1oo`00Ool00100Ool0101gR9T40?mQ0PT0MhRI
JP3oool707N8V@L0of4200<0MhRI07oo001oo`004`1oo`000`1gR9T0oooo0?ooo`0m0?oooc00g[R7
4@1oo`0907N8VF00oooo1@1gR9TW0?ooo`00<P3oool00`1gR9T0Ool007oo000D07oo02h0g[R70P1g
R9U>0?oooa40g[R700<0MhRI0?ooo`3oool0=03oool207N8VA00Ool04`1gR9UX0?ooo`P0MhRI1P3o
H@8207N8VAD0Ool0?`3oool00`1gR9T0g[R70=jhQ`0^0=jhQa40Ool0201gR9UP0?ooo`D0MhRI:03o
ool003<0oooo5@1oo`000`1gR9T0g[R70=jhQ`0/0=jhQ`80MhRIC@3ooolC0=jhQ`0307N8V@3oool0
oooo03<0oooo0P1gR9T?07oo0080MhRI3`3N^8L507N8VF@0oooo4`1gR9TD07oo03l0oooo00<0MhRI
0=jhQ`3N^8L0;P3N^8LB07oo00D0MhRIH@3oool507N8VBT0oooo000c0?oooa@0Ool000<0MhRI0=jh
Q`3N^8L0;P3N^8L00`1gR9T0oooo0?ooo`1:0?oooaD0g[R70P1gR9Tc0?ooo`<0MhRI3@1oo`000`1g
R9T0g[R70=jhQ`0D0=jhQ`0307N8V@3oool0oooo05l0oooo0P1gR9T@0=jhQ`<0MhRI501oo`0o0?oo
o`0307N8V@3N^8L0g[R702h0g[R700<0MhRI07oo001oo`003P1oo`0507N8VF40oooo1@1gR9TZ0?oo
o`00=@3ooolA07oo0080MhRI<03N^8L00`1gR9T0oooo0?ooo`190?ooo`0307N8V@3N^8L0g[R701@0
g[R70P1gR9Tb0?ooo`D0MhRI2@1oo`000`1gR9T0g[R70=jhQ`0G0=jhQ`0307N8V@3oool0oooo05d0
oooo00<0MhRI0=jhQ`3N^8L04P3N^8L207N8VA80Ool0?`3oool00`1gR9T0g[R70=jhQ`0_0=jhQ`03
07N8V@1oo`00Ool000h0Ool00`1gR9UQ0?ooo`H0MhRI:`3oool003H0oooo00<0MhRI07oo001oo`00
301oo`0307N8VC00g[R700<0MhRI0?ooo`3oool0B03oool00`1gR9T0g[R70=jhQ`0E0=jhQ`@0MhRI
<@3oool00`1gR9T0of420?mQ0P030?mQ0PD0Ool000<0MhRI0=jhQ`3N^8L06P3N^8L207N8VE/0oooo
00<0MhRI0=jhQ`3N^8L05P3N^8L@07oo0080MhRI?`3oool00`1gR9T0g[R70=jhQ`0_0=jhQ`80MhRI
3`1oo`0207N8VF40oooo1P1gR9T/0?ooo`00=`3oool00`1gR9T0Ool007oo000807oo00D0MhRI<@3N
^8L00`1gR9T0oooo0?ooo`160?ooo`<0MhRI603N^8L507N8VBl0oooo00<0MhRI0?mQ0P3oH@80103o
H@8407N8VAl0g[R700<0MhRI0?ooo`3oool0E`3ooolK0=jhQ`h0Ool00`1gR9To0?ooo`0307N8V@3N
^8L0g[R702l0g[R70P1gR9T>07oo0080MhRIH@3oool607N8VBd0oooo000h0?ooo`80MhRI1P1oo`04
0?mQ0P<0MhRI<@3N^8L00`1gR9T0oooo0?ooo`150?ooo`@0MhRI6@3N^8L40?mQ0P0307N8V@3oool0
oooo02`0oooo1`3oH@8307N8VB40g[R700<0MhRI0?ooo`3oool0E03ooolN0=jhQ``0Ool00`1gR9To
0?ooo`<0MhRI<03N^8L207N8V@d0Ool000<0MhRI0?ooo`3oool0G`3oool707N8VBh0oooo000i0?oo
o`H0MhRI1P3oH@8207N8VC80g[R7A@3oool40?mQ0P0307N8V@3N^8L0g[R701P0g[R7103oH@8307N8
VB/0oooo203oH@8207N8VB<0g[R70P1gR9UC0?ooo`0307N8V@3N^8L0g[R701d0g[R700<0MhRI07oo
001oo`001P1oo`0507N8VCl0oooo0`1gR9T`0=jhQ`@0MhRI2P1oo`000`1gR9T0oooo0?ooo`1O0?oo
o`L0MhRI;`3oool003X0oooo101gR9T80?mQ0P0307N8V@3N^8L0g[R70300g[R7A03oool00`1gR9T0
of420?mQ0P020?mQ0P0307N8V@3N^8L0g[R701P0g[R70`3oH@8507N8VB/0oooo1`3oH@800`1gR9T0
g[R70=jhQ`0S0=jhQ`80MhRID03oool207N8VB40g[R71@1gR9T40?mQ0P@0MhRI?`3oool307N8VC00
g[R700<0MhRI0?mQ0P3oH@800P3oH@8707oo000307N8V@3oool0oooo0600oooo1`1gR9T`0?ooo`00
>`3oool307N8V@P0of4200<0MhRI0=jhQ`3N^8L0<03N^8M30?ooo`0307N8V@3oH@80of4200<0of42
00<0MhRI0=jhQ`3N^8L0603N^8L207N8V@L0Ool000<0MhRI0?ooo`3oool09`3oool70?mQ0RL0g[R7
0P1gR9U>0?ooo`80MhRI8`3N^8L407N8V@D0of420`1gR9Tn0?ooo`@0MhRI<03N^8L00`1gR9T0of42
0?mQ0P030?mQ0P0407N8V@1oo`00Ool007oo0080MhRIHP3oool707N8VC40oooo000l0?ooo`0307N8
V@3oH@80of4200L0of42<`3N^8M20?ooo`80MhRI1@3oH@8K0=jhQ`0307N8V@1oo`00Ool000L0Ool0
00<0MhRI0?ooo`3oool09P3oool60?mQ0RT0g[R70`1gR9U:0?ooo`<0MhRI9@3N^8L207N8V@L0of42
00<0MhRI0?ooo`3oool0?@3oool407N8VC00g[R71P3oH@8407N8VF80oooo201gR9Tb0?ooo`00?@3o
ool90?mQ0S<0g[R7@03oool407N8V@@0of4200<0MhRI0=jhQ`3N^8L06@3N^8L:07oo00<0MhRI9P3o
ool607N8VBT0g[R7101gR9U70?ooo`D0MhRI9@3N^8L00`1gR9T0of420?mQ0P060?mQ0P0307N8V@3o
ool0oooo03`0oooo1P1gR9T^0=jhQ`L0of420`1gR9UR0?ooo`P0MhRI<`3oool003d0oooo2@3oH@8c
0=jhQcl0oooo1P1oo`0407N8VA/0g[R72P1oo`0407N8VBD0oooo1@1gR9T[0=jhQ`@0MhRIA@3oool5
07N8VBL0g[R700<0MhRI0?mQ0P3oH@801@3oH@800`1gR9T0oooo0?ooo`0l0?ooo`H0MhRI;P3N^8L0
0`1gR9T0of420?mQ0P040?mQ0P80MhRIHP3oool807N8VC@0oooo000n0?ooo`L0of420P1gR9Tb0=jh
Qch0oooo2P1oo`0207N8VAX0g[R72P1oo`0607N8VB<0oooo1@1gR9T/0=jhQ`D0MhRI@@3oool207N8
V@<0of420P1gR9TX0=jhQ`L0of42?`3oool00`1gR9T0of420?mQ0P020?mQ0P80MhRI;@3N^8L00`1g
R9T0of420?mQ0P030?mQ0P0307N8V@3oool0oooo0600oooo2@1gR9Te0?ooo`00@03oool30?mQ0P@0
MhRI<P3N^8Ll0?ooo`d0Ool000<0MhRI0=jhQ`3N^8L0603N^8L:07oo00L0MhRI8P3oool407N8VBh0
g[R71@1gR9To0?ooo`80MhRI103oH@800`1gR9T0g[R70=jhQ`0W0=jhQ`H0of4200<0MhRI0?ooo`3o
ool0?03oool00`1gR9T0of420?mQ0P040?mQ0P0307N8V@3N^8L0g[R702X0g[R71`1gR9UR0?ooo`T0
MhRI=P3oool00440oooo1P1gR9Tb0=jhQc/0oooo00<0MhRI07oo001oo`00301oo`0I0=jhQ`0307N8
V@1oo`00Ool000P0Ool01@1gR9TU0?ooo`<0MhRI;P3N^8L207N8V@@0of42?03oool507N8V@<0of42
00<0MhRI0=jhQ`3N^8L0:03N^8L607N8VCh0oooo203oH@8/0=jhQ`D0MhRIH`3oool907N8VCL0oooo
00120?ooo`D0MhRI<@3N^8L00`1gR9T0oooo0?ooo`0h0?ooo`0307N8V@1oo`00Ool000h0Ool0603N
^8L207N8V@T0Ool00P1gR9TX0?ooo`80MhRI;`3N^8L207N8V@@0of420P1gR9Ti0?ooo`L0Ool00P1g
R9T[0=jhQ`D0MhRI?P3oool90?mQ0P0307N8V@3N^8L0g[R702P0g[R71@1gR9UR0?ooo`D0Ool01@1g
R9Th0?ooo`00@`3oool407N8VC40g[R700<0MhRI0?ooo`3oool0=`3oool00`1gR9T0Ool007oo000?
07oo01P0g[R70`3oH@8707oo02/0oooo0P1gR9T_0=jhQ`0307N8V@3oH@80of4200<0of420`1gR9Tf
0?ooo`0307N8V@1oo`00Ool000L0Ool000<0MhRI0=jhQ`3N^8L0:@3N^8L507N8VCh0oooo00<0MhRI
0?mQ0P3oH@801P3oH@800`1gR9T0g[R70=jhQ`0X0=jhQ`<0MhRIH`3oool00`1gR9T0Ool007oo0004
07oo00<0MhRI>@3oool004@0oooo101gR9T`0=jhQ`0307N8V@3oool0oooo03D0oooo0`1gR9TA07oo
000307N8V@3N^8L0g[R701@0g[R7103oH@800`1gR9T0Ool007oo000207oo02d0oooo0P1gR9T`0=jh
Q`D0of42101gR9Tc0?ooo`<0MhRI2@1oo`0]0=jhQ`@0MhRI?P3oool00`1gR9T0of420?mQ0P060?mQ
0P80MhRI:03N^8L307N8VF80oooo00<0of4207N8V@1oo`001P1oo`0207N8VCX0oooo00150?ooo`<0
MhRI<03N^8L00`1gR9T0oooo0?ooo`0d0?ooo`<0MhRI4`1oo`000`1gR9T0g[R70=jhQ`0B0=jhQ`80
MhRI0P3oH@8207N8VC40oooo00<0MhRI0=jhQ`3N^8L0;`3N^8L40?mQ0PL0MhRI<P3oool207N8V@T0
Ool0;@3N^8L307N8VCl0oooo0P1gR9T70?mQ0P80MhRI:03N^8L207N8VF<0oooo00<0of4207N8V@1g
R9T01P1oo`000`1gR9T0oooo0?ooo`0i0?ooo`00AP3oool307N8VBl0g[R700<0MhRI0?ooo`3oool0
<`3oool407N8VA<0Ool00P1gR9TB0=jhQ`@0MhRI=03oool00`1gR9T0g[R70=jhQ`0_0=jhQ`<0MhRI
1`1oo`0207N8VC80oooo00<0MhRI07oo001oo`001`1oo`0]0=jhQ`<0MhRI?P3oool307N8V@H0of42
101gR9TV0=jhQ`0307N8V@3oool0oooo0600oooo1@3N^8L00`1gR9T0Ool007oo000407oo03`0oooo
00160?ooo`<0MhRI;P3N^8L207N8VC<0oooo1P1gR9TC07oo00<0MhRI3`3N^8L307N8VCL0oooo<P3N
^8L207N8V@X0Ool000<0MhRI0?ooo`3oool0<03oool807oo000307N8V@3N^8L0g[R702/0g[R70`1g
R9Tn0?ooo`@0MhRI0`3oH@8707N8VB@0g[R700<0MhRI0?ooo`3oool0H@3oool60=jhQ`D0Ool0?@3o
ool004L0oooo0P1gR9T^0=jhQ`80MhRI<P3oool707N8VA<0Ool0103oH@800`1gR9T0g[R70=jhQ`0:
0=jhQ`0307N8V@3oool0oooo03P0oooo<P3N^8L00`1gR9T0Ool007oo000:07oo0080MhRI<@3oool7
07oo02h0g[R70`1gR9Tm0?ooo`H0MhRI2P1oo`000`1gR9T0g[R70=jhQ`0O0=jhQf@0oooo00<0MhRI
0=jhQ`3N^8L0103N^8L407N8VCh0oooo00180?ooo`80MhRI;03N^8L307N8VC40oooo201gR9TC07oo
00D0of420`1gR9T80=jhQc`0oooo<`3N^8L<07oo00<0MhRI<@3oool507oo000307N8V@3N^8L0g[R7
02`0g[R70P1gR9Tn0?ooo`<0MhRI3P1oo`000`1gR9T0g[R70=jhQ`0L0=jhQ`0307N8V@3oool0oooo
0640oooo0P3oH@870=jhQ`0307N8V@3oH@80MhRI03l0oooo00190?ooo`0307N8V@3N^8L0g[R702T0
g[R7101gR9T`0?ooo`T0MhRI4`1oo`050?mQ0PL0MhRI@03ooolc0=jhQ``0Ool0101gR9T`0?ooo`80
MhRI0P1oo`0207N8VBh0g[R70P1gR9Tn0?ooo`0307N8V@1oo`00Ool000l0Ool07@3N^8L00`1gR9T0
oooo0?ooo`1Q0?ooo`0407N8V@3oH@80MhRI07N8V@H0g[R70P1gR9U00?ooo`00BP3oool00`1gR9T0
g[R70=jhQ`0W0=jhQ`D0MhRI;P3oool<07N8VA40Ool000<0MhRI0?mQ0P3oH@800`3oH@8407N8VD<0
oooo<`3N^8L<07oo00D0MhRI<03oool207N8V@@0of42;@3N^8L207N8VCd0oooo00<0MhRI07oo001o
o`004@1oo`0207N8VAT0g[R7H`3oool507oo000307N8V@3N^8L0g[R700@0g[R700<0MhRI0?ooo`3o
ool0?`3oool004/0oooo:@3N^8L507N8VBd0oooo3@1gR9T@07oo0080MhRI103oH@8207N8VDH0oooo
<`3N^8L<07oo00@0MhRI<P3oool50?mQ0Rd0g[R700<0MhRI0?ooo`3oool0?03ooolE07oo00<0MhRI
5@3N^8L00`1gR9T0oooo0?ooo`1R0?ooo`H0Ool01@3N^8L00`3oH@80oooo0?ooo`100?ooo`00C03o
oolW0=jhQ`H0MhRI;03oool?07N8V@l0Ool01@1gR9U90?oooc80g[R700<0MhRI07oo001oo`002P1o
o`0307N8VC@0oooo0`3oH@800`1gR9T0g[R70=jhQ`0[0=jhQ`0307N8V@3oool0oooo03`0oooo5P1o
o`0407N8VA40g[R700<0MhRI0?ooo`3oool0HP3oool00`1gR9T0Ool007oo000507oo00@0MhRIA03o
ool004d0oooo9@3N^8L40?mQ0P<0MhRI:P3ooolB07N8V@d0Ool00`1gR9U<0?oooc80g[R70P1gR9T;
07oo000307N8V@3oool0oooo03D0oooo0`1gR9T]0=jhQ`0307N8V@3oool0oooo03/0oooo5`1oo`06
07N8V@`0g[R70`1gR9UT0?ooo`<0MhRI1P1oo`030?mQ0TD0oooo001>0?ooob<0g[R700<0MhRI0?mQ
0P3oH@800`3oH@8207N8VBT0oooo501gR9T;07oo000307N8V@3oool0oooo04d0oooo<P3N^8L207N8
V@X0Ool000<0MhRI0?ooo`3oool0=`3oool207N8VBd0g[R7?P3ooolH07oo00<0MhRI1@3oH@8207N8
V@<0g[R71@1gR9UU0?ooo`@0MhRI1P1oo`000`1gR9T0oooo0?ooo`150?ooo`00C`3ooolQ0=jhQ`03
07N8V@3oH@80of4200D0of4200<0MhRI0?ooo`3oool09P3ooolF07N8V@P0Ool0D`3ooola0=jhQ`80
MhRI2@1oo`000`1gR9T0oooo0?ooo`0h0?ooo`<0MhRI:`3N^8L00`1gR9T0oooo0?ooo`0l0?oooaT0
Ool000<0MhRI0?mQ0P3oH@801@3oH@8807N8VF@0oooo1P1gR9T507oo04T0oooo001@0?ooo`0307N8
V@3N^8L0g[R701`0g[R700<0MhRI0?mQ0P3oH@801P3oH@8X0?oooa`0MhRIEP3ooola0=jhQ`@0of42
1@1oo`000`1gR9T0oooo0?ooo`0k0?ooo`80MhRI:`3N^8L00`1gR9T0oooo0?ooo`0k0?oooaX0Ool0
2@3oH@8607N8VF@0oooo2P1gR9U;0?ooo`00D@3oool00`1gR9T0g[R70=jhQ`0I0=jhQ`@0MhRI1`3o
H@8V0?oooa/0MhRIF@3oool00`1gR9T0g[R70=jhQ`0]0=jhQ`0307N8V@3oH@80of4200<0of42101g
R9To0?ooo`80MhRI:P3N^8Ln0?oooaX0Ool02@3oH@8407N8VFD0oooo2P1gR9U<0?ooo`00DP3oool0
0`1gR9T0g[R70=jhQ`0F0=jhQ`H0MhRI1`3oH@8U0?oooaT0MhRIG03oool00`1gR9T0g[R70=jhQ`0]
0=jhQ`H0of420P1gR9U20?ooo`0307N8V@3N^8L0g[R702P0g[R7?@3oool00`1gR9T0Ool007oo000H
07oo00T0of420`1gR9UT0?ooo`X0MhRICP3oool005<0oooo0P1gR9TD0=jhQ`P0MhRI1P3oH@800`1g
R9T0oooo0?ooo`0R0?oooaL0MhRIG`3oool00`1gR9T0g[R70=jhQ`0]0=jhQ`0307N8V@3oH@80of42
00<0of4200<0MhRI0?ooo`3oool0@P3ooolZ0=jhQcd0oooo00<0MhRI07oo001oo`00601oo`080?mQ
0P80MhRII@3oool907N8VE00oooo001D0?ooo`<0MhRI3`3N^8L00`1gR9T0Ool007oo000907oo0004
07N8V@3oH@80of420?mQ0P80MhRI8P3ooolF07N8VF80oooo0P1gR9T^0=jhQ`0307N8V@3oH@80of42
0080of4200<0MhRI0?ooo`3oool0A03ooolX0=jhQ`0307N8V@3oool0oooo03/0oooo00<0MhRI07oo
001oo`00601oo`000`1gR9T0of420?mQ0P050?mQ0P0307N8V@3oool0oooo06<0oooo2@1gR9UA0?oo
o`00E@3oool707N8V@P0g[R700<0MhRI07oo001oo`003@1oo`0407N8VB40oooo501gR9UU0?ooo`80
MhRI;P3N^8L407N8VDP0oooo9`3N^8L00`1gR9T0oooo0?ooo`0k0?ooo`80MhRI6P1oo`0307N8V@@0
of42IP3oool807N8VE<0oooo001F0?ooo`H0MhRI103oH@8507N8VA00Ool00`1gR9TP0?oooa80MhRI
J03oool307N8VB`0g[R7101gR9U:0?ooobD0g[R70P1gR9Tm0?ooo`80MhRI6P1oo`0407N8V@80of42
I@3oool807N8VED0oooo001G0?ooo`D0MhRI1@3oH@8307N8VA40Ool00`1gR9TN0?oooa40MhRIK03o
ool207N8VB/0g[R70`1gR9U<0?ooob@0g[R70`1gR9Tm0?ooo`80MhRI6P1oo`0507N8VFD0oooo201g
R9UF0?ooo`00F03oool307N8V@L0of420P1gR9TC07oo000307N8V@3oool0oooo01/0oooo3`1gR9U_
0?ooo`<0MhRI:@3N^8L307N8VDl0oooo8@3N^8L307N8VCd0oooo0`1gR9TI07oo00@0MhRIIP3oool7
07N8VEP0oooo001I0?ooo`0307N8V@3oH@80of4200H0of4200<0MhRI07oo001oo`004P1oo`000`1g
R9T0oooo0?ooo`0J0?ooo`d0MhRILP3oool307N8VBT0g[R70P1gR9UA0?oooal0g[R7101gR9Tm0?oo
o`@0MhRI601oo`0307N8VFD0oooo1`1gR9UJ0?ooo`00FP3oool00`1gR9T0of420?mQ0P050?mQ0P03
07N8V@1oo`00Ool00180Ool000<0MhRI0?ooo`3oool06@3oool;07N8VGD0oooo101gR9TW0=jhQ`03
07N8V@3oool0oooo0540oooo7`3N^8L407N8VCd0oooo1@1gR9TF07oo0080MhRIIP3oool707N8VE/0
oooo001K0?ooo`L0of425P1oo`0I0?ooo`X0MhRIN03oool507N8VBD0g[R700<0MhRI0?ooo`3oool0
D`3oool00`1gR9T0g[R70=jhQ`0J0=jhQ`@0MhRI?@3oool707N8VA@0Ool00P1gR9UV0?ooo`H0MhRI
G@3oool005/0oooo1P3oH@800`1gR9T0Ool007oo000D07oo01P0oooo201gR9Uk0?ooo`0307N8V@3o
H@80of4200<0of428`3N^8MH0?ooo`0307N8V@3N^8L0g[R701L0g[R71P1gR9Tm0?ooo`L0MhRI4`1o
o`000`1gR9T0oooo0?ooo`1U0?ooo`D0MhRIG`3oool005d0oooo1@1gR9TF07oo01L0oooo1P1gR9Un
0?ooo`0307N8V@3oH@80of4200@0of428@3N^8MJ0?ooo`0307N8V@3N^8L0g[R701@0g[R700<0MhRI
0?mQ0P3oH@800`3oH@8207N8VCd0oooo201gR9TA07oo000307N8V@3oool0oooo06@0oooo1P1gR9UP
0?ooo`00GP3oool407N8VAH0Ool05@3oool507N8VH40oooo1`3oH@8207N8VAh0g[R7G03oool207N8
VA80g[R70`1gR9T50?mQ0P0307N8V@3oool0oooo03/0oooo2P1gR9T?07oo000307N8V@3oool0oooo
06@0oooo1@1gR9UR0?ooo`00G`3oool307N8VAH0Ool0503oool307N8VH@0oooo00<0MhRI0?mQ0P3o
H@80103oH@8307N8VA/0g[R7G`3oool507N8V@`0g[R7101gR9T60?mQ0P0307N8V@3oool0oooo03/0
oooo301gR9T;07oo000307N8V@3oool0oooo06D0oooo1@1gR9US0?ooo`00H03oool207N8VAH0Ool0
4`3oool00`1gR9T0oooo0?ooo`250?ooo`0307N8V@3oH@80of4200@0of42101gR9TH0=jhQ`0307N8
V@3oool0oooo05l0oooo0`1gR9T40?mQ0P80MhRI0P3N^8L00`1gR9T0Ool007oo000507oo0080MhRI
1@3oH@800`1gR9T0oooo0?ooo`0j0?oooa00MhRI1@1oo`0307N8VFH0oooo1@1gR9UU0?ooo`00H@3o
ool00`1gR9T0Ool007oo000D07oo09/0oooo00<0MhRI0?mQ0P3oH@800`3oH@800`1gR9T0Ool007oo
000307oo000307N8V@3N^8L0g[R70180g[R700<0MhRI0?ooo`3oool0H@3oool307N8V@D0of420P1g
R9T;07oo00@0of420P1gR9Tl0?oooaH0MhRII`3oool407N8VFL0oooo001R0?oooaD0Ool000<0MhRI
0?ooo`3oool0VP3oool307N8V@/0Ool03`3N^8L307N8VFD0oooo00<0MhRI0?mQ0P3oH@80103oH@82
07N8V@`0Ool0101gR9Tm0?oooaD0MhRII`3oool407N8VFP0oooo001S0?oooa@0Ool000<0MhRI0?oo
o`3oool0VP3oool307N8V@`0Ool00P1gR9T:0=jhQ`@0MhRII`3oool00`1gR9T0of420?mQ0P030?mQ
0P0307N8V@1oo`00Ool000`0Ool00`1gR9Tl0?oooaD0MhRIIP3oool407N8VFX0oooo001S0?oooa<0
Ool00P1gR9VL0?ooo`80MhRI3P1oo`0207N8V@D0of421P1gR9UZ0?ooo`D0of423`1oo`0307N8VC`0
oooo4`1gR9UW0?ooo`<0MhRIK03oool006D0oooo4@1oo`0207N8VI`0oooo00<0MhRI07oo001oo`00
3P1oo`000`1gR9T0of420?mQ0P040?mQ0P@0MhRIJ`3oool40?mQ0Q00Ool00P1gR9Tm0?oooa80MhRI
I`3oool307N8VFd0oooo001V0?ooo`l0Ool00`1gR9VL0?ooo`0307N8V@1oo`00Ool000h0Ool01`3o
H@8307N8VFh0oooo0P1gR9TA07oo000307N8V@3oool0oooo03X0oooo4@1gR9UX0?ooo`80MhRIK`3o
ool006H0oooo3@1oo`0507N8VI`0oooo4@1oo`000`1gR9T0of420?mQ0P040?mQ0P0307N8V@3oool0
oooo06h0oooo0P1gR9TA07oo000307N8V@3oool0oooo03X0oooo401gR9UW0?ooo`80MhRIL@3oool0
06P0oooo2@1oo`0707N8VI`0oooo4@1oo`000`1gR9T0of420?mQ0P040?mQ0W80oooo00<0MhRI07oo
001oo`003`1oo`0m0?ooo`h0MhRIJ03oool207N8VG80oooo001Y0?ooo`0307N8V@1oo`00Ool000<0
Ool02@1gR9VL0?oooa40Ool000<0MhRI0?mQ0P3oH@800`3oH@9d0?oooa00Ool000<0MhRI0?ooo`3o
ool0>P3oool>07N8VFP0oooo00<0MhRI0?ooo`3oool0LP3oool006X0oooo3P1gR9VL0?oooa40Ool0
101gR9Ug0?ooo`l0Ool000<0MhRI0?ooo`3oool0>P3oool=07N8VFL0oooo00<0MhRI0?ooo`3oool0
M03oool006/0oooo3@1gR9VL0?oooa40Ool00`1gR9Ui0?ooo`h0Ool0?03oool<07N8VFP0oooo00<0
MhRI0?ooo`3oool0M@3oool006`0oooo301gR9VL0?oooa00Ool00P1gR9Uk0?ooo`d0Ool000<0MhRI
0?ooo`3oool0>P3oool;07N8VN40oooo001]0?ooo`/0MhRIW@3oool?07oo000307N8V@3oool0oooo
07X0oooo301oo`0207N8VC`0oooo2@1gR9WS0?ooo`00KP3oool:07N8VId0oooo00<0MhRI07oo001o
o`002`1oo`200?ooo`T0Ool00`1gR9Tk0?ooo`T0MhRIi03oool006l0oooo2@1gR9VM0?ooo`0307N8
V@1oo`00Ool000X0Ool0PP3oool607oo00@0MhRI?03oool707N8VNH0oooo001`0?ooo`P0MhRIW@3o
ool307N8V@T0Ool0Q03oool907N8VC`0oooo1P1gR9WW0?ooo`00L@3oool707N8VId0oooo101gR9T7
07oo08H0oooo201gR9Tk0?ooo`H0MhRIj03oool00780oooo1P1gR9VM0?ooo`T0MhRIR@3oool607N8
VC`0oooo101gR9WZ0?ooo`00L`3oool507N8VId0oooo1`1gR9V;0?ooo`H0MhRI?03oool307N8VN/0
oooo001d0?ooo`@0MhRIW@3oool607N8VHd0oooo1@1gR9Tk0?ooo`80MhRIk@3oool007D0oooo0`1g
R9VM0?ooo`D0MhRIS`3oool307N8VC`0oooo00<0MhRI0?ooo`3oool0k03oool007H0oooo0P1gR9VM
0?ooo`<0MhRITP3oool207N8VOl0oooo;03oool007L0oooo00<0MhRI0?ooo`3oool0V`3oool207N8
VI@0oooo00<0MhRI0?ooo`3oool0o`3ooolZ0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooo
f@3oool00?l0ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooof@3oool00?l0
ooooo`3ooooI0?ooo`00o`3ooooo0?ooomT0oooo003o0?ooool0oooof@3oool00?l0ooooo`3ooooI
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 726.125}, {235.063, 0}} -> {-0.158869, -0.0487046, \
0.00870063, 0.00870063}, {{18.25, 124.313}, {229.438, 122.813}} -> {0.38929, \
0.378782, 0.00550718, 0.00550718}, {{134.938, 241}, {229.438, 122.813}} -> \
{-0.976363, -0.0182425, 0.00814044, 0.00814044}, {{251.625, 357.75}, \
{229.438, 122.813}} -> {-1.30521, 0.04589, 0.0059319, 0.0059319}, {{368.313, \
474.438}, {229.438, 122.813}} -> {-1.856, 0.0597447, 0.00467291, 0.00467291}, \
{{485.063, 591.125}, {229.438, 122.813}} -> {-2.52297, -0.0491356, \
0.00530421, 0.00530421}, {{601.75, 707.813}, {229.438, 122.813}} -> {-4.7502, \
0.0812629, 0.00787586, 0.00787586}, {{18.25, 124.313}, {112.188, 5.5625}} -> \
{0.125165, -0.49738, 0.00631763, 0.00631763}, {{134.938, 241}, {112.188, \
5.5625}} -> {-1.07342, -0.957763, 0.00827991, 0.00827991}, {{251.625, \
357.75}, {112.188, 5.5625}} -> {-0.495993, -0.117335, 0.0031691, 0.0031691}, \
{{368.313, 474.438}, {112.188, 5.5625}} -> {-2.03185, -0.644653, 0.00622054, \
0.00622054}, {{485.063, 591.125}, {112.188, 5.5625}} -> {-3.34169, -0.916922, \
0.00727479, 0.00727479}, {{601.75, 707.813}, {112.188, 5.5625}} -> {-5.55568, \
-1.24368, 0.00925869, 0.00925869}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
CIRCLE TANGENT TO A TRIANGLE OF TYPE 3: three tangent circles\
\>", "Section"],

Cell["\<\
Consider three circles of centres at {0, 0}, {a + b,0} and {x, y} of radius \
a, b and c respectively\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[x, y, a, b, c]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Solve[{size[{x, y}] \[Equal] a + c, 
        size[{x, y} - {a + b, 0}] \[Equal] b + c}, {x, y}]\)}], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \({{y \[Rule] \(-\@\(a\^2 + 2\ a\ c + c\^2 - \((a\^2 + a\ b + a\ c - b\ \
c)\)\^2\/\((a + b)\)\^2\)\), 
        x \[Rule] \(a\^2 + a\ b + a\ c - b\ c\)\/\(a + b\)}, {y \[Rule] \@\(a\
\^2 + 2\ a\ c + c\^2 - \((a\^2 + a\ b + a\ c - b\ c)\)\^2\/\((a + b)\)\^2\), 
        x \[Rule] \(a\^2 + a\ b + a\ c - b\ c\)\/\(a + b\)}}\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[{y \[Rule] \@\(a\^2 + 2\ a\ c + c\^2 - \((a\^2 + a\ b + a\ \
c - b\ c)\)\^2\/\((a + b)\)\^2\), 
        x \[Rule] \(a\^2 + a\ b + a\ c - b\ c\)\/\(a + b\)}, {a > 0, b > 0, 
        c > 0}]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \({y \[Rule] 2\ \@\(\(a\ b\ c\ \((a + b + c)\)\)\/\((a + b)\)\^2\), 
      x \[Rule] a + \(\((a - b)\)\ c\)\/\(a + b\)}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell["\<\
For instance, if a = b then the third tangent circle of radius c will have \
centre at:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({x, 
          y} /. {y \[Rule] 
            2\ \@\(\(a\ b\ c\ \((a + b + c)\)\)\/\((a + b)\)\^2\), 
          x \[Rule] a + \(\((a - b)\)\ c\)\/\(a + b\)}\) /. {b \[Rule] 
          a}\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \({a, \@\(c\ \((2\ a + c)\)\)}\)], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[x, y, r, r1, r2, r3, x3, y3]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\({y3, 
          x3} = \(({2\ \@\(\(a\ b\ c\ \((a + b + c)\)\)\/\((a + b)\)\^2\), 
              a + \(\((a - b)\)\ c\)\/\(a + b\)} /. {a \[Rule] r1, 
              b \[Rule] r2, c \[Rule] r3})\);\)\), "\[IndentingNewLine]", 
    \(\({y, 
          x} = \(({2\ \@\(\(a\ b\ c\ \((a + b + c)\)\)\/\((a + b)\)\^2\), 
              a + \(\((a - b)\)\ c\)\/\(a + b\)} /. {a \[Rule] r1, 
              b \[Rule] r2, c \[Rule] r})\);\)\), "\[IndentingNewLine]", 
    \(FullSimplify[Solve[{size[{x, y} - {x3, y3}] \[Equal] r3 + r}, r], 
      r1 > 0 && r2 > 0 && r3 > 0 && r > 0]\)}], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \({{r \[Rule] \(r1\ r2\ r3\)\/\(r2\ r3 + r1\ \((r2 + r3)\) + 2\ \@\(r1\ \
r2\ r3\ \((r1 + r2 + r3)\)\)\)}, {r \[Rule] \(r1\ r2\ r3\)\/\(r2\ r3 + r1\ \
\((r2 + r3)\) - 2\ \@\(r1\ r2\ r3\ \((r1 + r2 + r3)\)\)\)}}\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[\((r2\ r3 + r1\ \((r2 + r3)\))\)\^2 - 
        4  r1\ r2\ r3\ \((r1 + r2 + r3)\), 
      r1 > 0 && r2 > 0 && r3 > 0]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(\(-4\)\ r1\ r2\ r3\ \((r1 + r2 + 
            r3)\) + \((r2\ r3 + r1\ \((r2 + r3)\))\)\^2\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell["\<\
 If r1 = r2 = r3,  the fourth circle tangent to all three will have radius \
equal to:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[{{r \[Rule] \(r1\ r2\ r3\)\/\(r2\ r3 + r1\ \((r2 + r3)\) + \
2\ \@\(r1\ r2\ r3\ \((r1 + r2 + r3)\)\)\)}, {r \[Rule] \(r1\ r2\ r3\)\/\(r2\ \
r3 + r1\ \((r2 + r3)\) - 2\ \@\(r1\ r2\ r3\ \((r1 + r2 + r3)\)\)\)}} /. {r2 \
\[Rule] r1, r3 \[Rule] r1}, r1 > 0]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({{r \[Rule] \((\(-1\) + 2\/\@3)\)\ r1}, {r \[Rule] \((\(-1\) - 
                2\/\@3)\)\ r1}}\)], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell["and centre at:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, y}\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \({r1 + \(r\ \((r1 - r2)\)\)\/\(r1 + r2\), 
      2\ \@\(\(r\ r1\ r2\ \((r + r1 + r2)\)\)\/\((r1 + r2)\)\^2\)}\)], \
"Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear[r1, r2, r3, x3, y3]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[
      Solve[{size[{x3, y3}] \[Equal] r1 + r3, 
          size[{x3, y3} - {r1 + r2, 0}] \[Equal] r2 + r3}, {y3, r3}], 
      r1 > 0 && r2 > 0 && r3 > 0]\)}], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \({{r3 \[Rule] \(-r2\) + \@\(\((r1\^2 + r2\^2 - \((r1 + r2)\)\ x3)\)\^2\/\
\((r1 - r2)\)\^2\), 
        y3 \[Rule] \(-\(\(2\ \@\(r1\ r2\ \((r1 - x3)\)\ \((r2 - \
x3)\)\)\)\/Abs[r1 - 
                    r2]\)\)}, {r3 \[Rule] \(-r2\) + \@\(\((r1\^2 + r2\^2 - \
\((r1 + r2)\)\ x3)\)\^2\/\((r1 - r2)\)\^2\), 
        y3 \[Rule] \(2\ \@\(r1\ r2\ \((r1 - x3)\)\ \((r2 - x3)\)\)\)\/Abs[r1 \
- r2]}}\)], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[r, x, y]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(r1 = \(r2 = \(r3 = 1\)\);\)\), "\[IndentingNewLine]", 
    \(\({x3, y3} = {1, \@3};\)\), "\[IndentingNewLine]", 
    \(Solve[{size[{x, y}] \[Equal] r1 + r, 
        size[{x, y} - {r1 + r2, 0}] \[Equal] r2 + r, 
        size[{x, y} - {x3, y3}] \[Equal] r3 + r}, {x, y, r}]\)}], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \({{r \[Rule] \(-1\) + 2\/\@3, x \[Rule] 1, 
        y \[Rule] 1\/\@3}}\)], "Output",
  CellLabel->"Out[149]="]
}, Open  ]],

Cell[BoxData[
    \(type[3, p1_, r1_, p2_, r2_, p3_, r3_] := 
      Module[{x, y, 
          r}, \[IndentingNewLine]First[{{x, y}, r} /. 
            Solve[{size[{x, y} - p1] \[Equal] r1 + r, 
                size[{x, y} - p2] \[Equal] r2 + r, 
                size[{x, y} - p3] \[Equal] r3 + r}, {x, y, r}]]]\)], "Input",
  CellLabel->"In[150]:=",
  InitializationCell->True],

Cell["Testing with random circles:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[a = {Random[], Random[]}; \[IndentingNewLine]b = {Random[], 
              Random[]}; \[IndentingNewLine]c = {Random[], 
              Random[]}; \[IndentingNewLine]{icp, icr} = 
            incircle[a, b, c]; \[IndentingNewLine]{c1, r1} = 
            type[1, a, b, c, icp, icr]; \[IndentingNewLine]{c2, r2} = 
            type[1, b, a, c, icp, icr]; \[IndentingNewLine]{c3, r3} = 
            type[1, c, b, a, icp, icr]; \[IndentingNewLine]{c4, r4} = 
            type[2, a, b, icp, icr, c1, r1]; \[IndentingNewLine]{c5, r5} = 
            type[2, a, b, icp, icr, c2, r2]; \[IndentingNewLine]{c6, r6} = 
            type[2, b, c, icp, icr, c2, r2]; \[IndentingNewLine]{c7, r7} = 
            type[2, b, c, icp, icr, c3, r3]; \[IndentingNewLine]{c8, r8} = 
            type[2, a, c, icp, icr, c3, r3]; \[IndentingNewLine]{c9, r9} = 
            type[2, a, c, icp, icr, c1, r1]; \[IndentingNewLine]{c10, r10} = 
            type[3, c1, r1, c4, r4, icp, icr]; \[IndentingNewLine]{c11, 
              r11} = type[3, c2, r2, c5, r5, icp, 
              icr]; \[IndentingNewLine]{c12, r12} = 
            type[3, c2, r2, c6, r6, icp, icr]; \[IndentingNewLine]{c13, 
              r13} = type[3, c3, r3, c7, r7, icp, 
              icr]; \[IndentingNewLine]{c14, r14} = 
            type[3, c3, r3, c8, r8, icp, icr]; \[IndentingNewLine]{c15, 
              r15} = type[3, c1, r1, c9, r9, icp, 
              icr]; \[IndentingNewLine]Graphics[{{LightSlateGray, 
                Polygon[{a, b, c, a}]}, {Burlywood, 
                Disk[icp, icr]}, {DarkSeaGreen, Disk[c1, r1], Disk[c2, r2], 
                Disk[c3, r3]}, {Beige, Disk[c4, r4], Disk[c5, r5], 
                Disk[c6, r6], Disk[c7, r7], Disk[c8, r8], 
                Disk[c9, r9]}, {IvoryBlack, Disk[c10, r10], Disk[c11, r11], 
                Disk[c12, r12], Disk[c13, r13], Disk[c14, r14], 
                Disk[c15, r15]}}, AspectRatio \[Rule] Automatic, 
            PlotRange \[Rule] All], {6}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[t, 3]]];\)\)}], "Input",
  CellLabel->"In[308]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44199 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0105235 0.31746 [
[ 0 0 0 0 ]
[ 1 .44199 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44199 L
0 .44199 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0105235 0.321429 0.21097 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00778055 1.01921 -0.434652 1.01921 [
[ 0 0 0 0 ]
[ 1 .36486 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.02381 .35617 m
.6267 .00869 L
.97619 .32255 L
.02381 .35617 L
F
.871 .722 .529 r
.60781 .18882 m
.60781 .18882 .14664 0 365.73 arc
F
.561 .737 .561 r
.3807 .2539 m
.3807 .2539 .08961 0 365.73 arc
F
.62471 .02764 m
.62471 .02764 .01543 0 365.73 arc
F
.80843 .26165 m
.80843 .26165 .06678 0 365.73 arc
F
.64 .58 .5 r
.4372 .15049 m
.4372 .15049 .02823 0 365.73 arc
F
.60121 .03353 m
.60121 .03353 .0088 0 365.73 arc
F
.64647 .03827 m
.64647 .03827 .0088 0 365.73 arc
F
.77781 .17639 m
.77781 .17639 .02381 0 365.73 arc
F
.73024 .30741 m
.73024 .30741 .02381 0 365.73 arc
F
.48339 .3117 m
.48339 .3117 .02823 0 365.73 arc
F
.16 .14 .13 r
.45186 .1851 m
.45186 .1851 .00936 0 365.73 arc
F
.61102 .03952 m
.61102 .03952 .0027 0 365.73 arc
F
.63564 .0421 m
.63564 .0421 .0027 0 365.73 arc
F
.76159 .20356 m
.76159 .20356 .00784 0 365.73 arc
F
.73523 .27616 m
.73523 .27616 .00784 0 365.73 arc
F
.47749 .27457 m
.47749 .27457 .00936 0 365.73 arc
F
0 0 m
1 0 L
1 .36486 L
0 .36486 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0105235 0.64881 0.21097 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.136775 1.77648 -0.413197 1.77648 [
[ 0 0 0 0 ]
[ 1 1.03898 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 1.01424 m
.02381 .66284 L
.51043 .02474 L
.97619 1.01424 L
F
.871 .722 .529 r
.45601 .5372 m
.45601 .5372 .26748 0 365.73 arc
F
.561 .737 .561 r
.74193 .79941 m
.74193 .79941 .12046 0 365.73 arc
F
.1338 .63086 m
.1338 .63086 .06807 0 365.73 arc
F
.4932 .18699 m
.4932 .18699 .08469 0 365.73 arc
F
.64 .58 .5 r
.5799 .82204 m
.5799 .82204 .04314 0 365.73 arc
F
.20554 .69783 m
.20554 .69783 .03007 0 365.73 arc
F
.15846 .53587 m
.15846 .53587 .03007 0 365.73 arc
F
.38771 .24286 m
.38771 .24286 .03468 0 365.73 arc
F
.58461 .26376 m
.58461 .26376 .03468 0 365.73 arc
F
.75049 .63603 m
.75049 .63603 .04314 0 365.73 arc
F
.16 .14 .13 r
.60985 .77316 m
.60985 .77316 .0142 0 365.73 arc
F
.20661 .6581 m
.20661 .6581 .00967 0 365.73 arc
F
.18066 .56884 m
.18066 .56884 .00967 0 365.73 arc
F
.43049 .25962 m
.43049 .25962 .01127 0 365.73 arc
F
.53926 .27117 m
.53926 .27117 .01127 0 365.73 arc
F
.70437 .67009 m
.70437 .67009 .0142 0 365.73 arc
F
0 0 m
1 0 L
1 1.03898 L
0 1.03898 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0105235 0.97619 0.21097 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.297372 2.54682 -0.111808 2.54682 [
[ 0 0 0 0 ]
[ 1 2.46375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.7822 .05866 m
.97619 .42124 L
.02381 2.40509 L
.7822 .05866 L
F
.871 .722 .529 r
.81499 .42477 m
.81499 .42477 .1438 0 365.73 arc
F
.561 .737 .561 r
.79655 .21887 m
.79655 .21887 .06293 0 365.73 arc
F
.96697 .42145 m
.96697 .42145 .00822 0 365.73 arc
F
.71503 .67496 m
.71503 .67496 .12563 0 365.73 arc
F
.64 .58 .5 r
.86767 .26672 m
.86767 .26672 .02279 0 365.73 arc
F
.96324 .40839 m
.96324 .40839 .00535 0 365.73 arc
F
.96382 .43465 m
.96382 .43465 .00535 0 365.73 arc
F
.85424 .59773 m
.85424 .59773 .03356 0 365.73 arc
F
.66737 .52307 m
.66737 .52307 .03356 0 365.73 arc
F
.73507 .2786 m
.73507 .2786 .02279 0 365.73 arc
F
.16 .14 .13 r
.83863 .27533 m
.83863 .27533 .00749 0 365.73 arc
F
.96001 .41454 m
.96001 .41454 .00159 0 365.73 arc
F
.96032 .42865 m
.96032 .42865 .00159 0 365.73 arc
F
.81327 .57974 m
.81327 .57974 .01118 0 365.73 arc
F
.70946 .53826 m
.70946 .53826 .01118 0 365.73 arc
F
.76518 .28191 m
.76518 .28191 .00749 0 365.73 arc
F
0 0 m
1 0 L
1 2.46375 L
0 2.46375 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.231015 0.321429 0.431462 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.316451 1.29781 -0.162051 1.29781 [
[ 0 0 0 0 ]
[ 1 .6735 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.97619 .65747 m
.81917 .01604 L
.02381 .56083 L
.97619 .65747 L
F
.871 .722 .529 r
.67436 .39491 m
.67436 .39491 .23074 0 365.73 arc
F
.561 .737 .561 r
.89518 .587 m
.89518 .587 .06193 0 365.73 arc
F
.77938 .12015 m
.77938 .12015 .06341 0 365.73 arc
F
.34157 .47979 m
.34157 .47979 .11271 0 365.73 arc
F
.64 .58 .5 r
.90983 .49941 m
.90983 .49941 .02687 0 365.73 arc
F
.83424 .19237 m
.83424 .19237 .02729 0 365.73 arc
F
.69033 .13737 m
.69033 .13737 .02729 0 365.73 arc
F
.40941 .34404 m
.40941 .34404 .03905 0 365.73 arc
F
.46613 .56646 m
.46613 .56646 .03905 0 365.73 arc
F
.81047 .61364 m
.81047 .61364 .02687 0 365.73 arc
F
.16 .14 .13 r
.87963 .51814 m
.87963 .51814 .00867 0 365.73 arc
F
.79823 .18986 m
.79823 .18986 .00881 0 365.73 arc
F
.71884 .15952 m
.71884 .15952 .00881 0 365.73 arc
F
.43076 .39138 m
.43076 .39138 .01288 0 365.73 arc
F
.46221 .51468 m
.46221 .51468 .01288 0 365.73 arc
F
.82483 .58113 m
.82483 .58113 .00867 0 365.73 arc
F
0 0 m
1 0 L
1 .6735 L
0 .6735 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.231015 0.64881 0.431462 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.476829 1.68123 -0.0414897 1.68123 [
[ 0 0 0 0 ]
[ 1 .8854 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.64372 .86432 m
.97619 .02108 L
.02381 .09079 L
.64372 .86432 L
F
.871 .722 .529 r
.56228 .32551 m
.56228 .32551 .2734 0 365.73 arc
F
.561 .737 .561 r
.61669 .68554 m
.61669 .68554 .09072 0 365.73 arc
F
.84978 .11405 m
.84978 .11405 .0835 0 365.73 arc
F
.22023 .17641 m
.22023 .17641 .09973 0 365.73 arc
F
.64 .58 .5 r
.70934 .59832 m
.70934 .59832 .03652 0 365.73 arc
F
.85579 .23203 m
.85579 .23203 .03464 0 365.73 arc
F
.73895 .07317 m
.73895 .07317 .03464 0 365.73 arc
F
.3398 .10653 m
.3398 .10653 .03876 0 365.73 arc
F
.25042 .31157 m
.25042 .31157 .03876 0 365.73 arc
F
.50241 .62959 m
.50241 .62959 .03652 0 365.73 arc
F
.16 .14 .13 r
.66121 .59309 m
.66121 .59309 .01189 0 365.73 arc
F
.8196 .20384 m
.8196 .20384 .01123 0 365.73 arc
F
.75508 .11612 m
.75508 .11612 .01123 0 365.73 arc
F
.33097 .15719 m
.33097 .15719 .01266 0 365.73 arc
F
.28153 .27062 m
.28153 .27062 .01266 0 365.73 arc
F
.54685 .61038 m
.54685 .61038 .01189 0 365.73 arc
F
0 0 m
1 0 L
1 .8854 L
0 .8854 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.231015 0.97619 0.431462 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.24879 3.93084 -0.515326 3.93084 [
[ 0 0 0 0 ]
[ 1 2.63293 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.467 .533 .6 r
.07986 .79479 m
.02381 .06269 L
.97619 2.57025 L
.07986 .79479 L
F
.871 .722 .529 r
.18099 .76658 m
.18099 .76658 .10299 0 365.73 arc
F
.561 .737 .561 r
.08083 .79452 m
.08083 .79452 .00099 0 365.73 arc
F
.14171 .59068 m
.14171 .59068 .07725 0 365.73 arc
F
.25996 .94569 m
.25996 .94569 .09276 0 365.73 arc
F
.64 .58 .5 r
.08053 .79273 m
.08053 .79273 .00082 0 365.73 arc
F
.09313 .67744 m
.09313 .67744 .02218 0 365.73 arc
F
.22258 .64853 m
.22258 .64853 .02218 0 365.73 arc
F
.29005 .83245 m
.29005 .83245 .02442 0 365.73 arc
F
.15605 .89152 m
.15605 .89152 .02442 0 365.73 arc
F
.0815 .7962 m
.0815 .7962 .00082 0 365.73 arc
F
.16 .14 .13 r
.08133 .7934 m
.08133 .7934 .00022 0 365.73 arc
F
.12237 .67307 m
.12237 .67307 .00738 0 365.73 arc
F
.19426 .65702 m
.19426 .65702 .00738 0 365.73 arc
F
.25993 .8448 m
.25993 .8448 .00814 0 365.73 arc
F
.18549 .87762 m
.18549 .87762 .00814 0 365.73 arc
F
.08183 .79521 m
.08183 .79521 .00022 0 365.73 arc
F
0 0 m
1 0 L
1 2.63293 L
0 2.63293 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[308]:=",
  ImageSize->{783.375, 346.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<?0001FR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00
o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB
0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0oooo
o`3ooolB0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?oo
ool0ooooo`3ooolB0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooR@3oool00`1gR9T0oooo
0?ooo`3o0?ooo`h0oooo00<0MhRI0?ooo`3oool0M03oool00?l0ooooR03oool207N8VOl0oooo403o
ool207N8VGD0oooo003o0?ooohL0oooo101gR9Wo0?ooo`l0oooo0P1gR9Ue0?ooo`00o`3ooon60?oo
o`D0MhRIo`3oool>0?ooo`@0MhRIM03oool00?l0ooooQP3oool607N8VOl0oooo3@3oool407N8VG@0
oooo003o0?ooohD0oooo1`1gR9Wo0?ooo`d0oooo1@1gR9Uc0?ooo`00o`3ooon40?ooo`T0MhRIo`3o
ool;0?ooo`0307N8V@2?_8l0Skb?0080Skb?00<0MhRI0?ooo`3oool0L@3oool00?l0ooooP`3oool:
07N8VOl0oooo2`3oool00`1gR9T0Skb?08nlS`0308nlS`0307N8V@3oool0oooo0700oooo003o0?oo
oh<0oooo2`1gR9Wo0?ooo`X0oooo1`2?_8l00`1gR9T0oooo0?ooo`1_0?ooo`00o`3ooon20?ooo``0
MhRIo`3oool90?ooo`P0Skb?00<0MhRI0?ooo`3oool0K`3oool00?l0ooooP@3oool>07N8VOl0oooo
203oool00`1gR9T0Skb?08nlS`0508nlS`80MhRIL03oool00?l0ooooP03oool?07N8VOl0oooo203o
ool00`1gR9T0Skb?08nlS`0508nlS`80MhRIL03oool00?l0ooooP03oool307N8V@T0Skb?101gR9Wo
0?ooo`H0oooo0P1gR9T608nlS`<0XiAo00<0MhRI0?ooo`3oool0K@3oool00?l0ooooO`3oool00`1g
R9T0Skb?08nlS`0<08nlS`80MhRIo`3oool60?ooo`<0XiAo0P0X8b4207N8V@80:2<Q0P2SU7l00`1g
R9T0oooo0?ooo`1]0?ooo`00o`3ooomn0?oooa40Skb?0P1gR9Wo0?ooo`D0oooo0P2SU7l00`1gR9T0
:2<Q0=jhQ`040=jhQ`@0MhRIKP3oool00?l0ooooO@3ooolC08nlS`0307N8V@3oool0oooo0?l0oooo
0P3oool307N8V@X0g[R70P1gR9U]0?ooo`00o`3oooml0?oooaD0Skb?o`3oool40?ooo`0307N8V@3N
^8L0g[R700/0g[R700<0MhRI0?ooo`3oool0J`3oool00?l0ooooO03ooolF08nlSol0oooo0`3oool0
0`1gR9T0g[R70=jhQ`0;0=jhQ`80MhRIK03oool00?l0ooooN`3ooolG08nlSol0oooo0P3oool00`1g
R9T0g[R70=jhQ`0=0=jhQ`0307N8V@3oool0oooo06X0oooo003o0?ooogX0oooo00<0MhRI08nlS`2?
_8l05P2?_8oo0?ooo`40oooo4@3N^8L00`1gR9T0oooo0?ooo`1Y0?ooo`00o`3ooomj0?ooo`0307N8
V@2?_8l0Skb?01H0Skb?o`3oool10?oooa40g[R700<0MhRI0?ooo`3oool0J@3oool00?l0ooooN@3o
ool00`1gR9T0Skb?08nlS`0G08nlS`0307N8V@3oool0oooo0?`0oooo00<0MhRI0=jhQ`3N^8L03`3N
^8L20:>DOfX0oooo003o0?ooogP0oooo0P1gR9TI08nlS`0307N8V@3oool0oooo0?`0oooo4P3N^8L0
0`1gR9T0:2<Q08nlS`1Y0?ooo`00o`3ooomg0?ooo`<0MhRI6@2?_8l207N8VOd0oooo4`3N^8L00`0X
8b40oooo0?ooo`1X0?ooo`00o`3ooomf0?ooo`@0MhRI6@2?_8l207N8VO`0oooo00<0MhRI0=jhQ`3N
^8L0403N^8L207N8VFX0oooo003o0?ooogH0oooo101gR9TI08nlS`<0MhRIn`3oool207N8VA40g[R7
00<0MhRI0?ooo`3oool0J@3oool00?l0ooooM@3oool507N8VAT0Skb?0`1gR9Wk0?ooo`80MhRI4@3N
^8L00`1gR9T0oooo0?ooo`1Y0?ooo`00o`3ooomd0?ooo`L0MhRI602?_8l407N8VOT0oooo101gR9T@
0=jhQf`0oooo003o0?ooog<0oooo1`2SU7l00`1gR9T0Skb?08nlS`0F08nlS`@0MhRIn@3oool01@1g
R9T0XiAo0:>DO`2SU7l0MhRI00h0g[R700<0MhRI0?ooo`3oool0JP3oool00?l0ooooL`3oool80:>D
O`0307N8V@2?_8l0Skb?01@0Skb?1P1gR9Wh0?ooo`@0XiAo00<0MhRI0=jhQ`3N^8L02`3N^8L00`1g
R9T0oooo0?ooo`1[0?ooo`00o`3ooomb0?ooo`X0XiAo5P2?_8l607N8VOP0oooo102SU7l202PS8@03
07N8V@3N^8L0g[R700P0g[R70P1gR9U]0?ooo`00o`3oooma0?ooo`0307N8V@2SU7l0XiAo00P0XiAo
00<0MhRI08nlS`2?_8l04P2?_8l60:>DO`80MhRImP3oool407N8V@H0Skb?1P3N^8L307N8VFh0oooo
003o0?ooog00oooo0P1gR9T:0:>DO`0307N8V@2?_8l0Skb?0180Skb?1`2SU7l00`1gR9T0oooo0?oo
o`3d0?ooo`0307N8V@2?_8l0Skb?00P0Skb?00<0MhRI02PS8@0X8b400`2SU7l207N8VFh0oooo003o
0?ooog00oooo0P1gR9T:0:>DO`80MhRI4P2?_8l90:>DOoH0oooo00<0MhRI08nlS`2?_8l02@2?_8l0
0`0X8b40XiAo0:>DO`020:>DO`0307N8V@3oool0oooo06d0oooo002S0?ooo`<0MhRIb03oool307N8
V@X0XiAo0P0X8b400`1gR9T0Skb?08nlS`0=08nlS`80MhRI2@2SU7l00`1gR9T0oooo0?ooo`3b0?oo
o`0307N8V@2?_8l0Skb?00/0Skb?102SU7l00`1gR9T0oooo0?ooo`1]0?ooo`00X@3oool00`1gR9T0
Skb?08nlS`0308nlSlH0oooo1@1gR9T80:>DO`@0:2<Q0P1gR9T<08nlS`80MhRI2`2SU7od0?ooo`h0
Skb?0`2SU7l00`1gR9T0oooo0?ooo`1^0?ooo`00W`3oool307N8V@H0Skb?a03oool607N8V@L0XiAo
0P1gR9T202PS8@H0MhRI1`2?_8l0101gR9T0:2<Q02PS8@0X8b4;0:>DO`0307N8V@3oool0oooo0?00
oooo402?_8l307N8VG00oooo002N0?ooo`<0MhRI1`2?_8l00`1gR9T0oooo0?ooo`310?ooo`P0MhRI
102SU7l00`1gR9T0g[R70=jhQ`0<0=jhQ`@0MhRI0`0X8b4:0:>DO`80MhRIlP3oool@08nlS`80MhRI
L@3oool009`0oooo00@0MhRI0:>DO`2SU7l0XiAo202?_8l207N8VL40oooo2P1gR9TF0=jhQ`<0:2<Q
00<0MhRI0:>DO`2SU7l01`2SU7l307N8VO40oooo402?_8l207N8VG40oooo002J0?ooo`80MhRI1@2S
U7l608nlS`0407N8V@2SU7l0XiAo0:>DOkl0oooo1`1gR9TN0=jhQ`0307N8V@2SU7l0XiAo00D0XiAo
101gR9Wa0?oooa00Skb?00<0MhRI0?ooo`3oool0L03oool009P0oooo1@1gR9T40:>DO`D0Skb?00<0
MhRI0:>DO`2SU7l00P2SU7l00`1gR9T0oooo0?ooo`2k0?ooo`H0MhRI8P3N^8L40:>DO`L0MhRIk`3o
ool00`1gR9T0Skb?08nlS`0>08nlS`0307N8V@3oool0oooo0700oooo002G0?ooo`H0MhRI0`2SU7l2
02PS8@@0MhRI0P0X8b430:>DO`80MhRI_03oool507N8VB@0g[R72P1gR9W_0?ooo`80MhRI3P2?_8l0
0`1gR9T0oooo0?ooo`1a0?ooo`00U@3oool507N8V@`0g[R700@0:2<Q0:>DO`2SU7l0XiAo1@1gR9Vi
0?ooo`@0MhRI:03N^8L907N8VNh0oooo0`1gR9T=08nlS`0307N8V@3oool0oooo0740oooo002C0?oo
o`80MhRI5P3N^8L507N8VKL0oooo0`1gR9T/0=jhQ`L0MhRIk@3oool407N8V@d0Skb?M03oool00940
oooo0`1gR9TH0=jhQ`D0MhRI]@3oool307N8VBl0g[R71P1gR9W/0?ooo`@0MhRI302?_8l00`1gR9T0
oooo0?ooo`1b0?ooo`00T03oool00`1gR9T0g[R70=jhQ`0M0=jhQ`80MhRI]03oool00`1gR9T0g[R7
0=jhQ`0`0=jhQ`D0MhRIk03oool607N8V@T0Skb?00<0MhRI0?ooo`3oool0L`3oool008h0oooo00<0
MhRI0=jhQ`3N^8L08@3N^8L00`1gR9T0oooo0?ooo`2`0?ooocD0g[R71@1gR9WZ0?ooo`P0MhRI1P2?
_8l307N8VGD0oooo002<0?ooo`80MhRI9@3N^8L00`1gR9T0oooo0?ooo`2^0?ooocL0g[R7101gR9WZ
0?oooa00MhRIMP3oool008/0oooo00<0MhRI0=jhQ`3N^8L09P3N^8L00`1gR9T0oooo0?ooo`2/0?oo
ocT0g[R7101gR9WY0?oooa00MhRIMP3oool008T0oooo0P1gR9TZ0=jhQ`0307N8V@3oool0oooo0:X0
oooo>`3N^8L307N8VNP0oooo401gR9Ug0?ooo`00Q`3oool207N8VBh0g[R700<0MhRI0?ooo`3oool0
Z03oooll0=jhQ`80MhRIj03oool@07N8VGL0oooo00250?ooo`<0MhRI<03N^8L00`1gR9T0oooo0?oo
o`2V0?oooch0g[R70P1gR9WW0?ooo`l0MhRIN03oool008@0oooo0`1gR9Tb0=jhQ`0307N8V@3oool0
oooo0:@0oooo@03N^8L00`1gR9T0oooo0?ooo`3T0?oooa00MhRIN03oool00880oooo1@1gR9Tc0=jh
Q`0307N8V@3oool0oooo0:80oooo00<0MhRI0=jhQ`3N^8L0?`3N^8L00`1gR9T0oooo0?ooo`3S0?oo
o`l0MhRIN@3oool00800oooo1P1gR9Te0=jhQ`0307N8V@3oool0oooo0:40oooo@P3N^8L00`1gR9T0
oooo0?ooo`3S0?ooo`l0MhRIN@3oool007h0oooo1`1gR9Tg0=jhQ`0307N8V@3oool0oooo09l0oooo
A03N^8L00`1gR9T0oooo0?ooo`3Q0?oooa00MhRIN@3oool007d0oooo1`1gR9Th0=jhQ`80MhRIW`3o
ool00`1gR9T0g[R70=jhQ`130=jhQn<0oooo3`1gR9Uj0?ooo`00N`3oool807N8VCX0g[R70P1gR9VM
0?ooo`0307N8V@3N^8L0g[R704@0g[R700<0MhRI0?ooo`3oool0h03oool?07N8VGX0oooo001i0?oo
o`X0MhRI>`3N^8L307N8VI/0oooo00<0MhRI0=jhQ`3N^8L0A@3N^8OQ0?ooo`l0MhRIN`3oool007P0
oooo2P1gR9Tl0=jhQ`@0MhRIV@3oool00`1gR9T0g[R70=jhQ`160=jhQ`0307N8V@3oool0oooo0=h0
oooo3`1gR9Uk0?ooo`00MP3oool;07N8VCh0g[R7101gR9VG0?ooo`80MhRIB@3N^8OP0?ooo`h0MhRI
O03oool007@0oooo1`2SU7l607N8VCh0g[R71@1gR9VE0?ooo`80MhRIBP3N^8L00`1gR9T0oooo0?oo
o`3M0?ooo`h0MhRIO03oool00780oooo0P1gR9T90:>DO`@0MhRI?P3N^8L607N8VI@0oooo0P1gR9U;
0=jhQmh0oooo3P1gR9Um0?ooo`00L@3oool207N8V@/0XiAo0`1gR9To0=jhQ`H0MhRITP3oool207N8
VD`0g[R700<0MhRI0?ooo`3oool0f`3oool>07N8VGd0oooo001_0?ooo`<0MhRI3@2SU7l00`1gR9T0
g[R70=jhQ`0n0=jhQ`L0MhRIT03oool307N8VDd0g[R7g@3oool=07N8VGh0oooo001]0?ooo`D0MhRI
3@2SU7m20=jhQ`L0MhRISP3oool407N8VDd0g[R700<0MhRI0?ooo`3oool0f@3oool>07N8VGh0oooo
001[0?ooo`L0MhRI3@2SU7m20=jhQ`T0MhRIS03oool307N8VDh0g[R700<0MhRI0?ooo`3oool0f@3o
ool=07N8VGl0oooo001Z0?ooo`P0MhRI3@2SU7m20=jhQ`X0MhRIRP3oool407N8VDh0g[R700<0MhRI
0?ooo`3oool0f@3oool=07N8VGl0oooo001X0?ooo`X0MhRI3@2SU7m20=jhQ`<0MhRI1`2SU7l00`1g
R9T0oooo0?ooo`260?ooo`D0MhRIC`3N^8L00`1gR9T0oooo0?ooo`3G0?ooo`d0MhRIP03oool006H0
oooo301gR9T<0:>DO`0307N8V@3N^8L0g[R70400g[R70`1gR9T80:>DO`0307N8V@3oool0oooo08@0
oooo1P1gR9U?0=jhQ`0307N8V@3oool0oooo0=L0oooo3@1gR9V00?ooo`00I@3oool>07N8V@/0XiAo
A03N^8L00`1gR9T0XiAo0:>DO`080:>DO`0307N8V@3oool0oooo08<0oooo1@1gR9U@0=jhQ`80MhRI
f03oool<07N8VH40oooo001S0?ooo`80MhRI3P2?_8l00`1gR9T0XiAo0:>DO`070:>DO`0307N8V@3N
^8L0g[R70480g[R700<0MhRI0:>DO`2SU7l0202SU7l207N8VH<0oooo1P1gR9U@0=jhQ`80MhRIe`3o
ool=07N8VH40oooo001Q0?oooa@0Skb?00<0MhRI0:>DO`2SU7l00`2SU7l307N8VD@0g[R72`2SU7l3
07N8VH40oooo1`1gR9U@0=jhQ`<0MhRIeP3oool<07N8VH80oooo001O0?oooaP0Skb?0`1gR9T302PS
8@0307N8V@3N^8L0g[R70480g[R72`2SU7l407N8VGl0oooo1`2SU7l00`1gR9T0g[R70=jhQ`1>0=jh
Q`<0MhRIeP3oool<07N8VH80oooo001N0?oooaX0Skb?0P1gR9T402PS8D@0g[R72`2SU7l607N8VG`0
oooo2@2SU7m@0=jhQ`@0MhRIe03oool<07N8VH<0oooo001L0?ooo`0307N8V@2?_8l0Skb?01X0Skb?
00<0MhRI02PS8@0X8b400P0X8b540=jhQ`0307N8V@2SU7l0XiAo00P0XiAo1`1gR9Uk0?ooo`T0XiAo
D03N^8L407N8VM@0oooo301gR9V30?ooo`00FP3oool207N8VAh0Skb?0`0X8b400`1gR9T0g[R70=jh
Q`120=jhQ`0307N8V@2SU7l0XiAo00H0XiAo2P1gR9Ui0?ooo`0307N8V@2SU7l0XiAo00L0XiAoD03N
^8L507N8VM<0oooo2`1gR9V40?ooo`00F03oool407N8VAl0Skb?0`1gR9U40=jhQ`<0MhRI1P2SU7l;
07N8VGL0oooo0P1gR9T90:>DOe00g[R71@1gR9WB0?ooo``0MhRIQ03oool005L0oooo101gR9TQ08nl
S`80MhRIA03N^8L00`1gR9T0:2<Q02PS8@0207N8V@<0XiAo302?_8l00`1gR9T0oooo0?ooo`1c0?oo
o`<0MhRI202SU7l00`1gR9T0g[R70=jhQ`1>0=jhQ`H0MhRId@3oool;07N8VHD0oooo001E0?ooo`D0
MhRI8P2?_8l207N8VD@0g[R7100X8b400`1gR9T0Skb?08nlS`0>08nlS`0307N8V@3oool0oooo0780
oooo101gR9T60:>DO`80MhRID03N^8L607N8VM40oooo2`1gR9V50?ooo`00D`3oool607N8VBD0Skb?
A03N^8L302PS8@0307N8V@2?_8l0Skb?0100Skb?00<0MhRI0?ooo`3oool0L03oool607N8V@@0XiAo
0`1gR9U@0=jhQ`L0MhRIc`3oool;07N8VHH0oooo001B0?ooo`H0MhRI9P2?_8l00`1gR9T0g[R70=jh
Q`110=jhQ`80MhRI5P2?_8m`0?ooo`80MhRI1P2?_8l307N8V@<0:2<QD03N^8L707N8VLl0oooo2`1g
R9V60?ooo`00D03oool807N8VBH0Skb?00<0MhRI0=jhQ`3N^8L0@03N^8L207N8VAP0Skb?00<0MhRI
0?ooo`3oool0J`3oool00`1gR9T0Skb?08nlS`0908nlS`<0:2<QD03N^8L707N8VLl0oooo2P1gR9V7
0?ooo`00CP3oool:07N8VBL0Skb?@P3N^8L00`1gR9T0Skb?08nlS`0H08nlS`0307N8V@3oool0oooo
06X0oooo3@2?_8l307N8VDl0g[R7201gR9W=0?ooo`/0MhRIQ`3oool004`0oooo301gR9TW08nlSd80
g[R700<0MhRI08nlS`2?_8l0602?_8l207N8VFT0oooo402?_8l207N8VDl0g[R7201gR9W=0?ooo`X0
MhRIR03oool004/0oooo301gR9TY08nlSd40g[R76`2?_8l307N8VFP0oooo4@2?_8l00`1gR9T0g[R7
0=jhQ`1=0=jhQ`T0MhRIc03oool:07N8VHP0oooo00190?ooo`h0MhRI:@2?_8m10=jhQa`0Skb?0`1g
R9UV0?oooa80Skb?00<0MhRI0=jhQ`3N^8L0C03N^8L00`1gR9T0XiAo0:>DO`050:>DO`80MhRIb`3o
ool;07N8VHP0oooo00170?oooa00MhRI:@2?_8m00=jhQ`0307N8V@2?_8l0Skb?01X0Skb?101gR9UU
0?oooa<0Skb?00<0MhRI0=jhQ`3N^8L0B`3N^8L00`1gR9T0XiAo0:>DO`070:>DO`0307N8V@3oool0
oooo0<P0oooo2P1gR9V90?ooo`00A@3ooolB07N8VBT0Skb?00<0MhRI0=jhQ`3N^8L0?@3N^8LM08nl
S`D0MhRIH`3oool00`1gR9T0Skb?08nlS`0A08nlS`0307N8V@3N^8L0g[R704/0g[R700<0MhRI0:>D
O`2SU7l0202SU7o:0?ooo`X0MhRIR@3oool004@0oooo4P1gR9TZ08nlS`0307N8V@3N^8L0g[R703`0
g[R700<0MhRI08nlS`2?_8l0702?_8l507N8VF40oooo0P1gR9TD08nlSdd0g[R7302SU7o90?ooo`T0
MhRIRP3oool00480oooo501gR9TZ08nlS`0307N8V@3N^8L0g[R703`0g[R77`2?_8l707N8VEh0oooo
0P1gR9TE08nlSd`0g[R700<0MhRI0:>DO`2SU7l02P2SU7o80?ooo`X0MhRIRP3oool00400oooo5P1g
R9TZ08nlS`80MhRI?@3N^8LO08nlS`P0MhRIG@3oool207N8VAD0Skb?00<0MhRI0=jhQ`3N^8L0B@3N
^8L=0:>DO`0307N8V@3oool0oooo0<D0oooo2@1gR9V;0?ooo`00?`3ooolH07N8VBT0Skb?0`1gR9Tk
0=jhQ`0307N8V@2?_8l0Skb?01d0Skb?2@1gR9UK0?ooo`<0MhRI5@2?_8l00`1gR9T0g[R70=jhQ`18
0=jhQ`0307N8V@2SU7l0XiAo00/0XiAo00<0MhRI0?ooo`3oool0a@3oool907N8VH/0oooo000m0?oo
oaX0MhRI:@2?_8l307N8VCX0g[R70P1gR9TO08nlS`X0MhRIF@3oool507N8VA@0Skb?0P1gR9U90=jh
Q`0307N8V@2SU7l0XiAo00/0XiAo0P1gR9W50?ooo`T0MhRIS03oool003/0oooo701gR9TY08nlS`<0
:2<Q00<0MhRI0=jhQ`3N^8L0=P3N^8L307N8VAl0Skb?2`1gR9UG0?ooo`H0MhRI4`2?_8l302PS8DP0
g[R70P1gR9T<0:>DO`<0MhRIa@3oool907N8VH`0oooo000i0?oooah0MhRI:@2?_8l402PS8@0307N8
V@3N^8L0g[R703D0g[R70`0X8b4O08nlS``0MhRIE@3oool807N8VA80Skb?0`0X8b400`1gR9T0g[R7
0=jhQ`150=jhQ`<0:2<Q2`2SU7l407N8VL@0oooo201gR9V=0?ooo`00>03ooolO07N8VBT0Skb?100X
8b400`1gR9T0g[R70=jhQ`0d0=jhQ`0507N8V@0X8b40:2<Q02PS8@1gR9T07P2?_8l=07N8VEL0oooo
1@1gR9TA08nlS`0307N8V@0X8b40:2<Q0080MhRIAP3N^8L502PS8@T0XiAo1@1gR9W30?ooo`T0MhRI
S@3oool003H0oooo8P1gR9TW08nlS`0407N8V@0X8b40:2<Q02PS8@<0MhRI=03N^8L207N8V@<0:2<Q
00<0MhRI08nlS`2?_8l0702?_8l>07N8VET0oooo0`1gR9T?08nlS`D0XiAo0P1gR9U40=jhQ`80MhRI
100X8b4207N8V@D0XiAo201gR9W20?ooo`P0MhRISP3oool003@0oooo901gR9TV08nlS`<0MhRI1@2S
U7l00`1gR9T0g[R70=jhQ`0a0=jhQ`0307N8V@2SU7l0XiAo0080XiAo00<0MhRI08nlS`2?_8l06`2?
_8lA07N8VEX0oooo3`2?_8l70:>DO`0307N8V@3N^8L0g[R70440g[R70P1gR9T302PS8A00MhRI`P3o
ool807N8VHh0oooo000b0?ooobH0MhRI9P2?_8l00`1gR9T0XiAo0:>DO`060:>DO`0307N8V@3N^8L0
g[R702l0g[R7202SU7lL08nlSa80MhRIFP3oool<08nlS`0307N8V@2SU7l0XiAo00L0XiAo@P3N^8L4
07N8V@d0Skb?1@1gR9W10?ooo`P0MhRIS`3oool00340oooo:01gR9TT08nlS`0307N8V@2SU7l0XiAo
00P0XiAo00<0MhRI0=jhQ`3N^8L0;03N^8L;0:>DOaX0Skb?501gR9UK0?ooo`P0Skb?0`1gR9T90:>D
O`0307N8V@3N^8L0g[R703l0g[R700<0MhRI08nlS`2?_8l03`2?_8l507N8VL00oooo201gR9V?0?oo
o`00;`3ooolZ07N8VB@0Skb?302SU7l^0=jhQ`/0XiAo6@2?_8lF07N8VE`0oooo102?_8l507N8V@T0
XiAo00<0MhRI0=jhQ`3N^8L0?P3N^8L00`1gR9T0Skb?08nlS`0B08nlS`<0MhRI`03oool707N8VI00
oooo000]0?ooobd0MhRI8P2?_8l00`1gR9T0XiAo0:>DO`0:0:>DO`80MhRI:P3N^8L207N8V@/0XiAo
00<0MhRI08nlS`2?_8l05@2?_8lH07N8VF00oooo101gR9T80:>DO`<0MhRI?P3N^8LG08nlS`<0MhRI
_P3oool807N8VI00oooo000/0?ooobl0MhRI8@2?_8l00`1gR9T0XiAo0:>DO`0;0:>DO`80MhRI:03N
^8L307N8V@/0XiAo00<0MhRI08nlS`2?_8l0502?_8lJ07N8VF80oooo0P1gR9T70:>DO`@0MhRI?03N
^8L00`1gR9T0Skb?08nlS`0G08nlS`0307N8V@3oool0oooo0;`0oooo1`1gR9VA0?ooo`00:P3ooolb
07N8VAl0Skb?0P1gR9T=0:>DO`@0MhRI9@3N^8L407N8V@/0XiAo0`1gR9TC08nlSa`0MhRIH`3oool6
0:>DO`D0MhRI>`3N^8L00`1gR9T0Skb?08nlS`0I08nlS`0307N8V@3oool0oooo0;/0oooo1`1gR9VA
0?ooo`00:03ooold07N8VAh0Skb?0`1gR9T=0:>DO`D0MhRI8`3N^8L507N8V@/0XiAo101gR9TA08nl
Sah0MhRIH`3oool40:>DO`L0MhRI>@3N^8L00`1gR9T0Skb?08nlS`0K08nlSk`0oooo1`1gR9VB0?oo
o`009P3ooolg07N8VA`0Skb?101gR9T<0:>DO`T0MhRI7P3N^8L807N8V@T0XiAo1`1gR9T>08nlSb00
MhRII`3oool707N8VCL0g[R700<0MhRI08nlS`2?_8l07@2?_8nk0?ooo`L0MhRITP3oool002D0oooo
>P1gR9TI08nlS`H0MhRI2`2SU7l;07N8VAP0g[R7301gR9T80:>DO`/0MhRI2@2?_8l707N8VHD0oooo
1@1gR9Te0=jhQ`80MhRI7`2?_8nk0?ooo`H0MhRIT`3oool002<0oooo?P1gR9TF08nlS`L0MhRI2`2S
U7l<07N8VAH0g[R73`1gR9T40:>DO`0307N8V@3oool0oooo00`0oooo0`2?_8nC0?ooo`@0MhRI<P3N
^8L207N8VB40Skb?^@3oool707N8VI<0oooo000Q0?oood80MhRI4P2?_8l:07N8V@T0XiAo401gR9T@
0=jhQkd0oooo0`1gR9T`0=jhQ`<0MhRI8@2?_8ni0?ooo`H0MhRIU03oool001l0ooooAP1gR9T>08nl
S`d0MhRI1@2SU7l207N8VN40oooo0P1gR9T/0=jhQ`@0MhRI8P2?_8l00`1gR9T0oooo0?ooo`2f0?oo
o`H0MhRIU03oool001h0ooooB@1gR9T808nlSo`0oooo00<0MhRI0=jhQ`3N^8L09P3N^8L207N8V@<0
:2<Q00<0MhRI08nlS`2?_8l0802?_8l00`1gR9T0oooo0?ooo`2e0?ooo`H0MhRIU@3oool001`0oooo
=01gR9Wo0?oooah0oooo00<0MhRI0=jhQ`3N^8L08P3N^8L307N8V@@0:2<Q00<0MhRI08nlS`2?_8l0
8@2?_8l00`1gR9T0oooo0?ooo`2d0?ooo`H0MhRIU@3oool001X0oooo6P1gR9Wo0?oooc`0oooo8P3N
^8L507N8V@<0:2<Q902?_8l00`1gR9T0oooo0?ooo`2d0?ooo`D0MhRIUP3oool00?l0ooooLP3ooolM
0=jhQ`P0XiAo00<0MhRI02PS8@0X8b40902?_8l207N8VK@0oooo1P1gR9VF0?ooo`00o`3ooomd0?oo
oaX0g[R700<0MhRI0:>DO`2SU7l0202SU7l00`1gR9T0Skb?08nlS`0R08nlS`80MhRI]03oool507N8
VIL0oooo003o0?ooogP0oooo4P3N^8L507N8V@/0XiAo902?_8l207N8VK@0oooo1@1gR9VG0?ooo`00
o`3oooml0?ooo`80MhRI1P3N^8L:07N8V@`0XiAo902?_8l307N8VK80oooo1P1gR9VG0?ooo`00o`3o
oomo0?ooo`l0MhRI302SU7lT08nlS`<0MhRI/P3oool507N8VIP0oooo003o0?oooh40oooo301gR9T=
0:>DOb@0Skb?101gR9Va0?ooo`D0MhRIV03oool00?l0ooooQ03oool:07N8V@`0XiAo00<0MhRI08nl
S`2?_8l08@2?_8l407N8VK40oooo101gR9VI0?ooo`00o`3ooon70?ooo`L0MhRI302SU7l00`1gR9T0
Skb?08nlS`0P08nlS`H0MhRI[`3oool507N8VIT0oooo003o0?ooohT0oooo1@1gR9T<0:>DO`0307N8
V@2?_8l0Skb?0200Skb?1P1gR9V_0?ooo`@0MhRIVP3oool00?l0ooooS03oool307N8V@X0XiAo0`1g
R9TQ08nlS`L0MhRI[P3oool407N8VIX0oooo003o0?ooohl0oooo2@2SU7l407N8VB40Skb?1`1gR9V]
0?ooo`@0MhRIV`3oool00?l0ooooT@3oool50:>DO`L0MhRI7`2?_8l907N8VJ`0oooo101gR9VK0?oo
o`00o`3ooonD0?ooo`X0MhRI7@2?_8l:07N8VJ`0oooo0`1gR9VL0?ooo`00o`3ooonG0?ooo`P0MhRI
702?_8l;07N8VJX0oooo101gR9VL0?ooo`00o`3ooonJ0?ooo`D0MhRI6`2?_8l<07N8VJX0oooo0`1g
R9VM0?ooo`00o`3ooonL0?ooo`@0MhRI6@2?_8l>07N8VJT0oooo0`1gR9VM0?ooo`00o`3ooonO0?oo
o`80MhRI5`2?_8l?07N8VJP0oooo0`1gR9VN0?ooo`00o`3ooonR0?oooa@0Skb?4P1gR9VW0?ooo`<0
MhRIWP3oool00?l0ooooX`3ooolA08nlSa@0MhRIY`3oool207N8VIl0oooo003o0?ooojD0oooo3P2?
_8lE07N8VJH0oooo0`1gR9VO0?ooo`00o`3ooonX0?ooo`L0Skb?6P1gR9VU0?ooo`80MhRIX03oool0
0?l0oooo[03ooolM07N8VJD0oooo0P1gR9VP0?ooo`00o`3ooon_0?oooa/0MhRIX`3oool207N8VJ40
oooo003o0?oook80oooo601gR9VS0?ooo`80MhRIX@3oool00?l0oooo]@3ooolF07N8VJ80oooo00<0
MhRI0?ooo`3oool0X03oool00?l0oooo]`3ooolD07N8VJ40oooo0P1gR9VR0?ooo`00o`3ooonj0?oo
oa80MhRIX03oool00`1gR9T0oooo0?ooo`2Q0?ooo`00o`3ooonm0?ooo`l0MhRIX03oool00`1gR9T0
oooo0?ooo`2Q0?ooo`00o`3ooono0?ooo`h0MhRIWP3oool00`1gR9T0oooo0?ooo`2R0?ooo`00o`3o
ooo20?ooo`/0MhRIWP3oool00`1gR9T0oooo0?ooo`2R0?ooo`00o`3oooo50?ooo`T0MhRIo`3ooom3
0?ooo`00o`3oooo70?ooo`L0MhRIW03oool00`1gR9T0oooo0?ooo`2S0?ooo`00o`3oooo:0?ooo`D0
MhRIo`3ooom20?ooo`00o`3oooo=0?ooo`80MhRIo`3ooom20?ooo`00o`3ooooo0?ooool0oooo4P3o
ool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00o`3ooooo0?ooool0
oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00o`3ooooo
0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00
o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB
0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0oooo
o`3ooolB0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?oo
ool0ooooo`3ooolB0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo
003o0?ooool0ooooo`3ooolB0?ooo`00o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oo
oa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00d03oool207N8VO`0oooo3@1gR9Wo0?ooocD0oooo
003?0?ooo`<0MhRIk`3ooolJ07N8VOl0oooo=@3oool00<d0oooo1@1gR9WR0?ooo``0MhRI2@2?_8lA
07N8VI40oooo00<0MhRI0?ooo`3oool0X@3oool00<`0oooo1P1gR9WE0?oooaH0MhRI3P2?_8l?07N8
VI40oooo00<0MhRI0?ooo`3oool0X@3oool00<X0oooo2@1gR9W70?oooa<0MhRI202SU7l707N8VA80
Skb?301gR9VA0?ooo`0307N8V@3oool0oooo0:40oooo00390?ooo`X0MhRI^P3ooolO07N8V@X0XiAo
1@1gR9TD08nlS`X0MhRITP3oool207N8VJ80oooo00370?ooo``0MhRI[@3oool907N8VA40g[R74@1g
R9T<0:>DO`<0MhRI5P2?_8l907N8VI80oooo0P1gR9VR0?ooo`00aP3oool=07N8VJ00oooo4P1gR9TJ
0=jhQ``0MhRI302SU7l207N8VAP0Skb?1`1gR9VC0?ooo`<0MhRIX@3oool00<@0oooo401gR9VB0?oo
oaX0MhRI8`3N^8L807N8V@`0XiAo0P1gR9TH08nlS`L0MhRIT`3oool307N8VJ40oooo00330?oooa40
MhRIQ@3oool=07N8V@T0XiAo3`1gR9TX0=jhQ`D0MhRI302SU7l00`1gR9T0Skb?08nlS`0G08nlS`L0
MhRIT`3oool307N8VJ40oooo00310?ooo`80MhRI2`2?_8l607N8VGP0oooo1@1gR9T708nlS`h0MhRI
2P2SU7l<07N8VB`0g[R70`1gR9T<0:>DOa/0Skb?1@1gR9VD0?ooo`@0MhRIX03oool00<00oooo00<0
MhRI08nlS`2?_8l0302?_8l507N8VF/0oooo3`1gR9T>08nlS`T0MhRI302SU7l907N8VC00g[R700<0
MhRI0:>DO`2SU7l02P2SU7lL08nlS`@0MhRIU03oool407N8VJ00oooo002o0?ooo`0307N8V@2?_8l0
Skb?00l0Skb?101gR9UM0?oooaX0MhRI4`2?_8l507N8V@d0XiAo201gR9Tb0=jhQ`0307N8V@2SU7l0
XiAo00P0XiAo7@2?_8l307N8VID0oooo101gR9VP0?ooo`00_@3oool00`1gR9T0Skb?08nlS`0B08nl
S`<0MhRIGP3ooolH07N8VAD0Skb?101gR9T=0:>DO`H0MhRI=@3N^8L90:>DO`0307N8V@2?_8l0Skb?
01/0Skb?0`1gR9VE0?ooo`D0MhRIW`3oool00;`0oooo00<0MhRI08nlS`2?_8l0502?_8l207N8VEl0
oooo5P1gR9TG08nlS`80MhRI3P2SU7l407N8VCT0g[R71@2SU7l307N8VAd0Skb?0`1gR9VF0?ooo`@0
MhRIW`3oool00;X0oooo0P1gR9TH08nlS`0307N8V@3oool0oooo05h0oooo501gR9TI08nlS`80MhRI
3@2SU7l407N8VCX0g[R70`1gR9T302PS8@0307N8V@2?_8l0Skb?01/0Skb?0P1gR9VG0?ooo`D0MhRI
WP3oool00;T0oooo0`1gR9TI08nlS`0307N8V@3oool0oooo05h0oooo4@1gR9TL08nlS`0307N8V@2S
U7l0XiAo00/0XiAo0`1gR9Tl0=jhQ`80MhRI100X8b4M08nlS`80MhRIU`3oool507N8VIh0oooo002g
0?ooo`@0MhRI6P2?_8l00`1gR9T0oooo0?ooo`1O0?oooa00MhRI7@2?_8l=0:>DO`0307N8V@3N^8L0
g[R703h0g[R7100X8b4M08nlS`0307N8V@3oool0oooo09H0oooo1@1gR9VN0?ooo`00]P3oool507N8
VA/0Skb?H@3oool?07N8VAl0Skb?2`2SU7l00`1gR9T0g[R70=jhQ`0o0=jhQ`<0:2<Q00<0MhRI08nl
S`2?_8l06`2?_8l00`1gR9T0oooo0?ooo`2F0?ooo`H0MhRIW@3oool00;@0oooo1`1gR9TK08nlSf80
oooo3@1gR9TP08nlS`X0XiAo00<0MhRI0=jhQ`3N^8L0@@3N^8L407N8VA`0Skb?00<0MhRI0?ooo`3o
ool0UP3oool607N8VId0oooo002c0?ooo`L0MhRI7@2?_8mR0?ooo``0MhRI802?_8l207N8V@L0XiAo
A`3N^8L207N8VA`0Skb?V@3oool607N8VId0oooo002a0?ooo`T0MhRI7@2?_8mS0?ooo`/0MhRI8@2?
_8l207N8V@D0XiAo00<0MhRI0=jhQ`3N^8L0AP3N^8L00`1gR9T0Skb?08nlS`0J08nlSiT0oooo1`1g
R9VL0?ooo`00/03oool00`1gR9T0XiAo0:>DO`030:>DO`@0MhRI7@2?_8mT0?ooo`X0MhRI8@2?_8l0
101gR9T0:2<Q02PS8@0X8b4307N8VDX0g[R700<0MhRI08nlS`2?_8l0602?_8nJ0?ooo`L0MhRIW03o
ool00:l0oooo202SU7l207N8VAh0Skb?I03oool907N8VB80Skb?00<0MhRI02PS8@0X8b400P0X8b40
0`1gR9T0g[R70=jhQ`1:0=jhQaX0Skb?VP3oool807N8VI/0oooo002]0?ooo`0307N8V@2SU7l0XiAo
00P0XiAo00<0MhRI08nlS`2?_8l0702?_8l00`1gR9T0oooo0?ooo`1R0?ooo`P0MhRI8`2?_8l402PS
8Dd0g[R76@2?_8l00`1gR9T0oooo0?ooo`2H0?ooo`P0MhRIV`3oool00:`0oooo00<0MhRI0:>DO`2S
U7l02P2SU7lN08nlS`0307N8V@3oool0oooo06<0oooo1`1gR9TS08nlS`<0:2<Q00<0MhRI0=jhQ`3N
^8L0C03N^8LG08nlS`0307N8V@3oool0oooo09T0oooo201gR9VK0?ooo`00ZP3oool307N8V@`0XiAo
7P2?_8l00`1gR9T0oooo0?ooo`1T0?ooo`H0MhRI8`2?_8l307N8VE00g[R75@2?_8l207N8VI/0oooo
2@1gR9VJ0?ooo`00Z@3oool407N8V@`0XiAo00<0MhRI08nlS`2?_8l06P2?_8l207N8VFL0oooo1@1g
R9TS08nlS`80MhRIDP3N^8LC08nlS`80MhRIW03oool407N8V@<0Skb?0P1gR9VJ0?ooo`00Y`3oool6
07N8V@`0XiAo00<0MhRI08nlS`2?_8l06P2?_8l307N8VFH0oooo1@1gR9TS08nlS`0307N8V@3N^8L0
g[R70540g[R700<0MhRI08nlS`2?_8l03`2?_8l307N8VI`0oooo0P1gR9T708nlS`0307N8V@3oool0
oooo09L0oooo002V0?ooo`L0MhRI3@2SU7lK08nlS`@0MhRII`3oool407N8VB<0Skb?00<0MhRI0=jh
Q`3N^8L0DP3N^8L207N8V@h0Skb?101gR9VM0?ooo`P0Skb?00<0MhRI0?ooo`3oool0U`3oool00:@0
oooo2@1gR9T<0:>DO`80MhRI6P2?_8l407N8VFP0oooo0`1gR9TR08nlS`0307N8V@3N^8L0g[R705<0
g[R71@1gR9T908nlS`D0MhRIWP3oool808nlS`0307N8V@3oool0oooo09L0oooo002S0?ooo`/0MhRI
2`2SU7l207N8VAX0Skb?101gR9UY0?ooo`80MhRI8P2?_8l00`1gR9T0g[R70=jhQ`1D0=jhQ`0407N8
V@0X8b40:2<Q02PS8@h0MhRIW@3oool:08nlS`0307N8V@3oool0oooo09H0oooo002Q0?ooo`h0MhRI
2@2SU7l302PS8@0307N8V@2?_8l0Skb?01H0Skb?1P1gR9UY0?ooo`80MhRI8@2?_8mG0=jhQ`@0:2<Q
00<0MhRI0:>DO`2SU7l01@2SU7l607N8VIh0oooo2@2?_8l00`1gR9T0oooo0?ooo`2F0?ooo`00X03o
oolA07N8V@H0XiAo00<0MhRI02PS8@0X8b400P0X8b400`1gR9T0Skb?08nlS`0D08nlS`L0MhRIJ@3o
ool207N8VB40Skb?F03N^8L302PS8@T0XiAo101gR9VO0?ooo`0307N8V@2?_8l0Skb?00D0Skb?0P1g
R9VH0?ooo`00W`3ooolD07N8V@<0XiAo0P1gR9T302PS8@80MhRI5@2?_8l807N8VFX0oooo00<0MhRI
08nlS`2?_8l07P2?_8l00`1gR9T0g[R70=jhQ`1F0=jhQ`80MhRI2`2SU7l307N8VIl0oooo00<0MhRI
08nlS`2?_8l0102?_8l0101gR9T0XiAo0:>DO`1gR9VG0?ooo`00W@3oool907N8VA<0g[R71@1gR9TC
08nlS`0307N8V@2SU7l0XiAo00@0XiAo0P1gR9U[0?ooob00Skb?F@3N^8L207N8V@/0XiAo0P1gR9VP
0?ooo`80MhRI102?_8l01@1gR9T0:2<Q02PS8@2SU7l0MhRI09L0oooo002L0?ooo`D0MhRI7@3N^8L0
0`1gR9T0Skb?08nlS`0?08nlS`T0XiAo0P1gR9U[0?oooal0Skb?FP3N^8L=0:>DO`0307N8V@3oool0
oooo09h0oooo0P2SU7l202PS8@D0g[R70`1gR9VF0?ooo`00VP3oool407N8VB<0g[R700<0MhRI08nl
S`2?_8l02@2?_8l307N8V@X0XiAo00<0MhRI0?ooo`3oool0JP3ooolM08nlSe/0g[R700<0MhRI0:>D
O`2SU7l02P2SU7l00`1gR9T0oooo0?ooo`2N0?ooo`80XiAo2@3N^8L00`1gR9T0oooo0?ooo`2D0?oo
o`00V@3oool307N8VBL0g[R70P1gR9T508nlS`D0MhRI302SU7m/0?ooo`0307N8V@2?_8l0Skb?01X0
Skb?G03N^8L<0:>DOj40oooo0P1gR9T:0=jhQiH0oooo002G0?ooo`80MhRI;@3N^8L507N8V@<0:2<Q
00<0MhRI0:>DO`2SU7l02P2SU7m]0?oooa/0Skb?G@3N^8L;0:>DO`0307N8V@3oool0oooo09l0oooo
00<0MhRI0=jhQ`3N^8L02@3N^8L00`1gR9T0oooo0?ooo`2C0?ooo`00UP3oool00`1gR9T0g[R70=jh
Q`0_0=jhQ`80MhRI100X8b4=0:>DO`0307N8V@3oool0oooo06/0oooo00<0MhRI08nlS`2?_8l05P2?
_8l00`1gR9T0g[R70=jhQ`1L0=jhQ`X0XiAoXP3oool00`1gR9T0g[R70=jhQ`090=jhQ`0307N8V@3o
ool0oooo09<0oooo002D0?ooo`0307N8V@3N^8L0g[R703<0g[R700D0MhRI02PS8@0X8b40:2<Q07N8
V@0<0:>DO`0307N8V@3oool0oooo06`0oooo00<0MhRI08nlS`2?_8l0502?_8l207N8VEh0g[R72@2S
U7l00`1gR9T0oooo0?ooo`2P0?ooo`d0g[R7U@3oool00980oooo>`3N^8L207N8V@`0XiAo00<0MhRI
0?ooo`3oool0K@3oool207N8VA80Skb?0`0X8b400`1gR9T0g[R70=jhQ`1L0=jhQ`80MhRI1@2SU7l3
07N8VJ80oooo00<0MhRI0=jhQ`3N^8L02P3N^8L00`1gR9T0oooo0?ooo`2B0?ooo`00T@3ooolm0=jh
Q`0307N8V@2SU7l0XiAo00T0XiAo0P1gR9U_0?ooo`<0MhRI3`2?_8l00`1gR9T0:2<Q02PS8@0202PS
8@0307N8V@3N^8L0g[R705`0g[R72@1gR9VS0?ooo`80:2<Q2`3N^8L00`1gR9T0oooo0?ooo`2B0?oo
o`00T03ooolo0=jhQ`0307N8V@2SU7l0XiAo00P0XiAo0`1gR9U_0?ooo`@0MhRI2P2?_8l407N8V@@0
:2<QG`3N^8L907N8VJ@0oooo00<0MhRI0=jhQ`3N^8L0203N^8L307N8VI<0oooo002>0?ooo`0307N8
V@3N^8L0g[R703l0g[R72@2SU7l407N8VG00oooo201gR9T208nlS`L0XiAo100X8b5O0=jhQ`P0MhRI
YP3oool90=jhQ`<0XiAo00<0MhRI0?ooo`3oool0T@3oool008d0oooo00<0MhRI0=jhQ`3N^8L0@@3N
^8L00`1gR9T0XiAo0:>DO`030:>DO`H0MhRIL@3oool807N8V@X0XiAo0P1gR9UO0=jhQ`P0MhRIYP3o
ool00`1gR9T0g[R70=jhQ`060=jhQ`80:2<Q00<0XiAo07N8V@3oool0TP3oool008`0ooooA`3N^8L:
07N8VG80oooo1P1gR9T<0:>DO`0307N8V@3N^8L0g[R705h0g[R71`1gR9VW0?ooo`0307N8V@3N^8L0
g[R700<0g[R71@2?_8l207N8VI80oooo002:0?ooo`0307N8V@3N^8L0g[R704L0g[R72P1gR9Ua0?oo
o`D0MhRI3@2SU7l00`1gR9T0g[R70=jhQ`1N0=jhQ`H0MhRIZ03oool00`1gR9T0XiAo0:>DO`0202PS
8@L0Skb?00<0MhRI0?ooo`3oool0T03oool008T0oooo00<0MhRI0=jhQ`3N^8L0B@3N^8L907N8VG80
oooo101gR9T=0:>DO`0307N8V@3N^8L0g[R705h0g[R71P1gR9VX0?ooo`<0XiAo00<0MhRI08nlS`2?
_8l01`2?_8nB0?ooo`00Q`3oool207N8VDd0g[R7201gR9Uc0?ooo`<0MhRI3@2SU7l00`1gR9T0g[R7
0=jhQ`1N0=jhQ`D0MhRIZP3oool20:>DO`X0Skb?00<0MhRI0?ooo`3oool0S`3oool008H0oooo0P1g
R9U?0=jhQ`L0MhRIM03oool207N8V@d0XiAoH@3N^8L507N8VJ/0oooo00<0MhRI08nlS`2?_8l02@2?
_8nA0?ooo`00Q03oool307N8VE40g[R71`1gR9Ud0?ooo`0307N8V@2SU7l0XiAo00/0XiAoH@3N^8L5
07N8VJ/0oooo00<0MhRI08nlS`2?_8l02@2?_8l00`1gR9T0oooo0?ooo`2>0?ooo`00P`3oool307N8
VE<0g[R71P1gR9Ud0?ooo`0307N8V@2SU7l0XiAo00/0XiAoH@3N^8L407N8VJd0oooo2`2?_8l00`1g
R9T0oooo0?ooo`2>0?ooo`00P@3oool507N8VE@0g[R71@1gR9Ue0?ooo`0307N8V@2SU7l0XiAo00X0
XiAoH@3N^8L407N8VJd0oooo2P2?_8l207N8VI00oooo00200?ooo`D0MhRIE@3N^8L507N8VGH0oooo
00<0MhRI0:>DO`2SU7l0202SU7l00`1gR9T0g[R70=jhQ`1O0=jhQ`<0MhRI[`3oool908nlS`<0MhRI
S`3oool007h0oooo1P1gR9UG0=jhQ`D0MhRIMP3oool90:>DO`80MhRIH@3N^8L307N8VJl0oooo202?
_8l407N8VHl0oooo001m0?ooo`H0MhRIF@3N^8L407N8VGL0oooo00<0MhRI0:>DO`2SU7l00`2SU7l5
07N8VF00g[R70`1gR9V`0?ooo`0307N8V@2?_8l0Skb?0080Skb?1`1gR9V>0?ooo`00O03oool707N8
VEX0g[R70`1gR9Ug0?ooo`/0MhRIH03N^8L207N8VK40oooo301gR9V>0?ooo`00NP3oool907N8VEX0
g[R70`1gR9Uh0?ooo`X0MhRIH03N^8L207N8VK80oooo2`1gR9V>0?ooo`00N@3oool907N8VE/0g[R7
101gR9Uh0?ooo`T0MhRIH03N^8L207N8VK80oooo301gR9V=0?ooo`00M`3oool:07N8VEd0g[R70`1g
R9Ui0?ooo`P0MhRIG`3N^8L207N8VK@0oooo2`1gR9V=0?ooo`00MP3oool:07N8VEl0g[R70P1gR9Uj
0?ooo`L0MhRIG`3N^8L207N8VK@0oooo2`1gR9V=0?ooo`00M03oool<07N8VF00g[R700<0MhRI0?oo
o`3oool0N03oool707N8VEl0g[R700<0MhRI0?ooo`3oool0]03oool;07N8VH`0oooo001c0?ooo``0
MhRIH@3N^8L207N8VGX0oooo1`1gR9UN0=jhQ`0307N8V@3oool0oooo0;@0oooo2`1gR9V<0?ooo`00
L@3oool>07N8VF80g[R700<0MhRI0?ooo`3oool0N@3oool607N8VEh0g[R700<0MhRI0?ooo`3oool0
]@3oool;07N8VH/0oooo001`0?ooo`l0MhRIHP3N^8L00`1gR9T0oooo0?ooo`1j0?ooo`D0MhRIGP3N
^8Nh0?ooo`/0MhRIR`3oool006h0oooo401gR9US0=jhQ`0307N8V@3oool0oooo07/0oooo101gR9UN
0=jhQkT0oooo2P1gR9V;0?ooo`00K@3oool90:>DO`P0MhRII03N^8L00`1gR9T0oooo0?ooo`1j0?oo
o`@0MhRIG@3N^8Nj0?ooo`/0MhRIRP3oool006`0oooo302SU7l507N8VFD0g[R700<0MhRI0?ooo`3o
ool0N`3oool407N8VE`0g[R7^`3oool:07N8VHX0oooo001Z0?ooo`80MhRI3@2SU7l407N8VFH0g[R7
OP3oool307N8VE/0g[R700<0MhRI0?ooo`3oool0^@3oool:07N8VHX0oooo001Y0?ooo`80MhRI3`2S
U7l307N8VFH0g[R7O`3oool307N8VEX0g[R7_@3oool:07N8VHT0oooo001W0?ooo`<0MhRI4@2SU7l0
0`1gR9T0g[R70=jhQ`1U0=jhQ`0307N8V@3oool0oooo07d0oooo0P1gR9UI0=jhQ`0307N8V@3oool0
oooo0;/0oooo2P1gR9V90?ooo`00IP3oool307N8VA80XiAo00<0MhRI0=jhQ`3N^8L0I@3N^8L00`1g
R9T0oooo0?ooo`1m0?ooo`<0MhRIF03N^8No0?ooo`X0MhRIR03oool006@0oooo1@1gR9TB0:>DOfP0
g[R700<0MhRI0?ooo`3oool0OP3oool207N8VEL0g[R700<0MhRI0?ooo`3oool0_@3oool:07N8VHP0
oooo001S0?ooo`H0MhRI4P2SU7mY0=jhQh40oooo0P1gR9UF0=jhQ`0307N8V@3oool0oooo0;h0oooo
2@1gR9V80?ooo`00H@3oool807N8VA80XiAoJ@3N^8N20?ooo`0307N8V@3N^8L0g[R705<0g[R700<0
MhRI0?ooo`3oool0_`3oool:07N8VHL0oooo001P0?ooo`T0MhRI4P2SU7mY0=jhQ`0307N8V@3oool0
oooo0800oooo00<0MhRI0=jhQ`3N^8L0DP3N^8L00`1gR9T0oooo0?ooo`300?ooo`T0MhRIQ`3oool0
05h0oooo2`1gR9TB0:>DOfX0g[R7PP3oool00`1gR9T0g[R70=jhQ`1B0=jhQl<0oooo2P1gR9V60?oo
o`00G@3oool<07N8VA40XiAo00<0MhRI0=jhQ`3N^8L0J03N^8N30?oooe<0g[R700<0MhRI0?ooo`3o
ool0`P3oool907N8VHH0oooo001L0?ooo`h0MhRI402SU7m[0=jhQh@0ooooDP3N^8L00`1gR9T0oooo
0?ooo`320?ooo`T0MhRIQP3oool005X0oooo4@1gR9T>0:>DO`0307N8V@3N^8L0g[R706T0g[R700<0
MhRI0?ooo`3oool0PP3ooom@0=jhQ`0307N8V@3oool0oooo0<@0oooo2@1gR9V50?ooo`00F@3oool3
07N8V@d0Skb?0P1gR9T=0:>DO`80MhRIJ`3N^8L00`1gR9T0oooo0?ooo`230?ooodd0g[R70`1gR9W6
0?ooo`T0MhRIQ@3oool005L0oooo5@2?_8l00`1gR9T0XiAo0:>DO`080:>DO`<0MhRIJ`3N^8L00`1g
R9T0oooo0?ooo`240?oood`0g[R70P1gR9W80?ooo`P0MhRIQ@3oool005H0oooo602?_8l70:>DO`D0
MhRIJ`3N^8L00`1gR9T0oooo0?ooo`240?ooo`0307N8V@3N^8L0g[R704P0g[R70`1gR9W80?ooo`T0
MhRIQ03oool005@0oooo00<0MhRI08nlS`2?_8l06@2?_8l30:>DO`80MhRI100X8b400`1gR9T0g[R7
0=jhQ`1Y0=jhQ`80MhRIQP3oool00`1gR9T0g[R70=jhQ`160=jhQ`@0MhRIb@3oool807N8VH@0oooo
001C0?oooah0Skb?101gR9T502PS8F/0g[R70P1gR9V70?ooodL0g[R7101gR9W:0?ooo`T0MhRIP`3o
ool00540oooo00<0MhRI08nlS`2?_8l07P2?_8l207N8V@H0:2<QJ`3N^8L207N8VHP0ooooA@3N^8L5
07N8VL/0oooo201gR9V30?ooo`00D03oool00`1gR9T0Skb?08nlS`0P08nlS`80MhRI1@0X8b5[0=jh
Q`80MhRIR@3ooom30=jhQ`D0MhRIc03oool807N8VH<0oooo001>0?ooo`0307N8V@2?_8l0Skb?02<0
Skb?00<0MhRI02PS8@0X8b400P0X8b400`1gR9T0g[R70=jhQ`1Y0=jhQ`<0MhRIR03oool00`1gR9T0
g[R70=jhQ`100=jhQ`D0MhRIc@3oool807N8VH80oooo001=0?ooo`0307N8V@2?_8l0Skb?02H0Skb?
101gR9U[0=jhQ`<0MhRIR@3oool00`1gR9T0g[R70=jhQ`0n0=jhQ`H0MhRIc@3oool807N8VH80oooo
001;0?ooo`80MhRI:P2?_8l307N8VF/0g[R70`1gR9V:0?ooo`80MhRI?03N^8L707N8VLl0oooo1`1g
R9V20?ooo`00BP3oool307N8VB/0Skb?0P1gR9U[0=jhQ`<0MhRIR`3oool207N8VCX0g[R7201gR9W?
0?ooo`P0MhRIP@3oool004T0oooo101gR9T[08nlS`80MhRIJ`3N^8L407N8VH/0oooo00<0MhRI0=jh
Q`3N^8L0=`3N^8L907N8VM00oooo1`1gR9V10?ooo`00A`3oool507N8VBd0Skb?00<0MhRI0=jhQ`3N
^8L0J@3N^8L407N8VH/0oooo0`1gR9Te0=jhQ`X0MhRId@3oool807N8VH00oooo00160?ooo`H0MhRI
;@2?_8l00`1gR9T0g[R70=jhQ`1Y0=jhQ`@0MhRIS03oool407N8VC40g[R7301gR9WB0?ooo`L0MhRI
P03oool004@0oooo1`1gR9T_08nlSf/0g[R7101gR9V=0?ooo`H0MhRI;03N^8L00`1gR9T0XiAo0:>D
O`040:>DO`H0MhRId`3oool707N8VH00oooo00130?ooo`L0MhRI<02?_8l00`1gR9T0g[R70=jhQ`1X
0=jhQ`D0MhRIS@3oool707N8VBP0g[R700<0MhRI0:>DO`2SU7l0202SU7l407N8VM@0oooo1`1gR9Uo
0?ooo`00@@3oool807N8VC80Skb?J@3N^8L607N8VHh0oooo201gR9TS0=jhQ`@0MhRI2`2SU7l307N8
VMD0oooo1P1gR9Uo0?ooo`00@03oool907N8VC80Skb?J@3N^8L607N8VHh0oooo2P1gR9TO0=jhQ`D0
MhRI302SU7l207N8VMH0oooo1P1gR9Uo0?ooo`00?P3oool;07N8VC80Skb?J@3N^8L607N8VHl0oooo
301gR9TJ0=jhQ`<0MhRI0`0X8b400`1gR9T0XiAo0:>DO`0:0:>DO`80MhRIe`3oool607N8VGh0oooo
000m0?ooo``0MhRI<`2?_8mW0=jhQ`P0MhRIS`3oool?07N8VA40g[R71`1gR9T402PS8@d0XiAo00<0
MhRI0?ooo`3oool0eP3oool607N8VGh0oooo000k0?ooo`h0MhRI<`2?_8mW0=jhQ`P0MhRIT03oool8
07N8V@P0XiAo0`1gR9T70=jhQ`0307N8V@2?_8l0Skb?00P0Skb?0P1gR9T302PS8@0307N8V@2SU7l0
XiAo00X0XiAo00<0MhRI0?ooo`3oool0e`3oool607N8VGd0oooo000j0?ooo`h0MhRI=02?_8mW0=jh
Q`P0MhRIT@3oool607N8V@X0XiAo0P1gR9T302PS8@80MhRI402?_8l307N8V@`0XiAo00<0MhRI0?oo
o`3oool0e`3oool607N8VGd0oooo000i0?ooo`l0MhRI=02?_8l00`1gR9T0g[R70=jhQ`1T0=jhQ`P0
MhRIT@3oool507N8V@`0XiAo100X8b400`1gR9T0Skb?08nlS`0A08nlS`0307N8V@2SU7l0XiAo00X0
XiAof`3oool507N8VGd0oooo000g0?oooa40MhRI=02?_8l00`1gR9T0g[R70=jhQ`1T0=jhQ`T0MhRI
T@3oool407N8V@`0XiAo0`0X8b400`1gR9T0Skb?08nlS`0C08nlS`0307N8V@2SU7l0XiAo00P0XiAo
00<0MhRI0?ooo`3oool0f@3oool607N8VG`0oooo000f0?oooa80MhRI=02?_8l00`1gR9T0g[R70=jh
Q`1S0=jhQ`X0MhRITP3oool307N8V@d0XiAo0P1gR9TG08nlS`T0XiAo00<0MhRI0?ooo`3oool0f`3o
ool507N8VG`0oooo000d0?oooa@0MhRI=02?_8l207N8VF@0g[R7202SU7l207N8VI<0oooo0P1gR9T=
0:>DO`0307N8V@2?_8l0Skb?01L0Skb?00<0MhRI0:>DO`2SU7l0102SU7l207N8VMd0oooo1P1gR9Uk
0?ooo`00<`3ooolE07N8VC@0Skb?0P1gR9US0=jhQ`0307N8V@2SU7l0XiAo00L0XiAo00<0MhRI0?oo
o`3oool0TP3oool00`1gR9T0XiAo0:>DO`0;0:>DO`0307N8V@2?_8l0Skb?01P0Skb?0`1gR9T20:>D
O`<0MhRIgP3oool507N8VG/0oooo000a0?oooaL0MhRI=02?_8l307N8VF80g[R72`2SU7l00`1gR9T0
oooo0?ooo`2A0?ooo`0307N8V@2SU7l0XiAo00/0XiAo6`2?_8l707N8VMl0oooo1@1gR9Uk0?ooo`00
<03ooolH07N8VC@0Skb?0`1gR9UR0=jhQ`/0XiAo00<0MhRI0?ooo`3oool0TP3oool00`1gR9T0XiAo
0:>DO`090:>DOad0Skb?1P1gR9WP0?ooo`D0MhRINP3oool002h0oooo6P1gR9Td08nlS`<0MhRIH@3N
^8L00`1gR9T0XiAo0:>DO`090:>DO`0307N8V@3oool0oooo09<0oooo2`2SU7lN08nlS`@0MhRIh@3o
ool507N8VGX0oooo000]0?oooa`0MhRI<`2?_8l407N8VF00g[R7302SU7l00`1gR9T0oooo0?ooo`2D
0?ooo`T0XiAo00<0MhRI08nlS`2?_8l0702?_8l407N8VN80oooo101gR9Uj0?ooo`00:`3ooolN07N8
VC<0Skb?100X8b5O0=jhQ`0307N8V@2SU7l0XiAo00X0XiAo0P1gR9VF0?ooo`D0XiAo0`1gR9TO08nl
S`@0MhRIhP3oool507N8VGT0oooo000Z0?oooal0MhRI<`2?_8l502PS8Eh0g[R700<0MhRI0:>DO`2S
U7l02P2SU7l207N8VIH0oooo201gR9TO08nlS`<0MhRIi03oool407N8VGT0oooo000Y0?ooob00MhRI
<P2?_8l602PS8@0307N8V@3N^8L0g[R705X0g[R70`0X8b4;0:>DO`80MhRIU`3oool607N8VB00Skb?
0`1gR9WT0?ooo`D0MhRIN03oool002L0oooo8P1gR9Tb08nlS`0307N8V@0X8b40:2<Q00<0:2<Q00<0
MhRI0=jhQ`3N^8L0F@3N^8L402PS8@0307N8V@2SU7l0XiAo00L0XiAo0`1gR9VH0?ooo`D0MhRI802?
_8l207N8VNH0oooo101gR9Uh0?ooo`009P3ooolT07N8VC00Skb?0P1gR9T502PS8@80MhRIFP3N^8L0
101gR9T0:2<Q02PS8@0X8b4207N8V@L0XiAo1@1gR9VH0?ooo`@0MhRI802?_8l207N8VNH0oooo101g
R9Uh0?ooo`00903ooolW07N8VBl0Skb?101gR9T202PS8@<0MhRIF@3N^8L207N8V@<0:2<Q0`1gR9T4
0:>DO`L0MhRIV@3oool307N8VB00Skb?0P1gR9WW0?ooo`@0MhRIM`3oool002<0oooo:01gR9T_08nl
S`80MhRI1P2SU7l207N8VEL0g[R70`1gR9T;08nlS`H0MhRIV@3oool307N8VB00Skb?00<0MhRI0?oo
o`3oool0iP3oool407N8VGL0oooo000Q0?ooob/0MhRI;@2?_8l207N8V@T0XiAo00<0MhRI0=jhQ`3N
^8L0D`3N^8L207N8V@l0Skb?101gR9VJ0?ooo`<0MhRI7`2?_8l00`1gR9T0oooo0?ooo`3W0?ooo`<0
MhRIM`3oool00200oooo;01gR9T]08nlS``0XiAo00<0MhRI0=jhQ`3N^8L0D@3N^8LC08nlS`@0MhRI
VP3oool207N8VAl0Skb?00<0MhRI0?ooo`3oool0i`3oool407N8VGH0oooo000N0?ooobl0MhRI:`2?
_8l>0:>DOe<0g[R7502?_8l307N8VI/0oooo00<0MhRI08nlS`2?_8l07@2?_8o[0?ooo`<0MhRIMP3o
ool001d0oooo<01gR9TZ08nlSa00XiAoD@3N^8LF08nlS`80MhRIW03oool00`1gR9T0Skb?08nlS`0K
08nlS`0307N8V@3oool0oooo0>T0oooo101gR9Ue0?ooo`006`3ooolc07N8VBP0Skb?00<0MhRI0:>D
O`2SU7l03`2SU7m?0=jhQaP0Skb?00<0MhRI0?ooo`3oool0VP3oool207N8VA`0Skb?k@3oool307N8
VGD0oooo000J0?ooocD0MhRI9P2?_8l00`1gR9T0XiAo0:>DO`0@0:>DO`0307N8V@3N^8L0g[R704/0
g[R700<0MhRI08nlS`2?_8l05P2?_8l207N8VI`0oooo00<0MhRI08nlS`2?_8l06P2?_8o]0?ooo`<0
MhRIM@3oool001P0oooo>01gR9TT08nlS`80MhRI4P2SU7l207N8VD/0g[R700<0MhRI08nlS`2?_8l0
602?_8l00`1gR9T0oooo0?ooo`2K0?ooo`0307N8V@2?_8l0Skb?01P0Skb?00<0MhRI0?ooo`3oool0
k03oool307N8VG@0oooo000R0?ooobl0MhRI8P2?_8l307N8VA80XiAo0`1gR9U90=jhQ`80MhRI6`2?
_8nN0?ooo`0307N8V@2?_8l0Skb?01H0Skb?00<0MhRI0?ooo`3oool0k@3oool307N8VG@0oooo000/
0?ooobH0MhRI802?_8l407N8VA80XiAo101gR9U70=jhQ`<0MhRI6`2?_8nO0?oooaH0Skb?0`1gR9W`
0?ooo`<0MhRIL`3oool003D0oooo7P1gR9TM08nlS`H0MhRI4P2SU7l607N8VD<0g[R7101gR9TL08nl
S`0307N8V@3oool0oooo09`0oooo00<0MhRI08nlS`2?_8l04P2?_8l307N8VO40oooo0`1gR9Uc0?oo
o`00?`3ooolF07N8VAX0Skb?201gR9TA0:>DO`L0MhRI@@3N^8L01@1gR9T0:2<Q02PS8@0X8b40MhRI
01`0Skb?00<0MhRI0?ooo`3oool0W@3oool00`1gR9T0Skb?08nlS`0@08nlS`@0MhRIlP3oool207N8
VG<0oooo00190?ooo`h0MhRI5`2?_8l907N8VA00XiAo2@1gR9To0=jhQ`0307N8V@0X8b40:2<Q0080
:2<Q7@2?_8l00`1gR9T0oooo0?ooo`2N0?ooo`80MhRI3`2?_8l507N8VO80oooo0`1gR9Ub0?ooo`00
DP3oool807N8VA80Skb?2`1gR9T@0:>DO`X0MhRI?@3N^8L307N8V@<0:2<Q00<0MhRI08nlS`2?_8l0
6P2?_8l00`1gR9T0oooo0?ooo`2O0?ooo`80MhRI302?_8l607N8VO@0oooo0P1gR9Ub0?ooo`00G03o
ool=08nlS`l0MhRI3P2SU7l<07N8VCX0g[R71P2SU7l307N8VA`0Skb?0P1gR9VQ0?ooo`@0MhRI1P2?
_8l907N8VO@0oooo0P1gR9Ub0?ooo`00IP3ooolB07N8V@d0XiAo401gR9Te0=jhQ`0307N8V@2SU7l0
XiAo00L0XiAo00<0MhRI08nlS`2?_8l06P2?_8l207N8VJ40oooo4P1gR9Wf0?ooo`80MhRIL@3oool0
06l0oooo2`1gR9T:0:>DOa<0MhRI<@3N^8L207N8V@/0XiAo702?_8l207N8VJ80oooo4@1gR9Wf0?oo
o`80MhRIL@3oool007T0oooo0P1gR9T70:>DOaL0MhRI;@3N^8L307N8V@`0XiAo702?_8l207N8VJ<0
oooo401gR9Wg0?ooo`80MhRIL03oool008<0oooo6@1gR9TW0=jhQ`H0MhRI302SU7lL08nlS`<0MhRI
X`3oool>07N8VOP0oooo0P1gR9U`0?ooo`00S03ooolB07N8VB<0g[R7201gR9T<0:>DO`0307N8V@2?
_8l0Skb?01P0Skb?101gR9VT0?ooo`d0MhRIn@3oool00`1gR9T0oooo0?ooo`1^0?ooo`00UP3oool;
07N8VAd0g[R72`1gR9T<0:>DO`80MhRI6@2?_8l407N8VJ@0oooo301gR9Wj0?ooo`80MhRIK`3oool0
0:00oooo101gR9TG0=jhQ`h0MhRI302SU7l207N8VAP0Skb?1@1gR9VU0?ooo`/0MhRIn`3oool00`1g
R9T0oooo0?ooo`1]0?ooo`00Z@3oool=0=jhQa<0MhRI302SU7l307N8VAL0Skb?1P1gR9VU0?ooo`X0
MhRIn`3oool00`1gR9T0oooo0?ooo`1]0?ooo`00/`3ooolG07N8V@X0XiAo101gR9TF08nlS`L0MhRI
YP3oool807N8VOd0oooo00<0MhRI0?ooo`3oool0K03oool00;d0oooo3P1gR9T80:>DO`H0MhRI502?
_8l807N8VJL0oooo1`1gR9Wm0?ooo`0307N8V@3oool0oooo06`0oooo00360?ooo`L0MhRI102SU7l9
07N8VA40Skb?2P1gR9VW0?ooo`H0MhRIo`3oool00`1gR9T0oooo0?ooo`1[0?ooo`00d03oool=07N8
V@d0Skb?301gR9VW0?ooo`D0MhRIo`3oool00`1gR9T0oooo0?ooo`1[0?ooo`00fP3oool607N8V@P0
Skb?3P1gR9VX0?ooo`@0MhRIo`3ooom^0?ooo`00h`3ooolC07N8VJT0oooo0P1gR9Wo0?ooo`80oooo
00<0MhRI0?ooo`3oool0JP3oool00>d0oooo2@1gR9VZ0?ooo`0307N8V@3oool0oooo0?l0ooooK@3o
ool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00o`3ooooo0?ooool0
oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00o`3ooooo
0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB0?ooo`00
o`3ooooo0?ooool0oooo4P3oool00?l0ooooo`3ooooo0?oooa80oooo003o0?ooool0ooooo`3ooolB
0?ooo`00o`3ooooo0?ooool0oooo4P3oool00001\
\>"],
  ImageRangeCache->{{{0, 782.375}, {345.25, 0}} -> {-0.0775336, -0.033156, \
0.00403268, 0.00403268}, {{19.1875, 251.688}, {337, 180.438}} -> {-0.0733432, \
0.240285, 0.00422005, 0.00422005}, {{274.938, 507.375}, {337, 180.438}} -> \
{-1.10277, 0.201771, 0.00373563, 0.00373563}, {{530.625, 763.125}, {337, \
180.438}} -> {-3.68393, -0.00708019, 0.00617895, 0.00617895}, {{19.1875, \
251.688}, {164.75, 8.1875}} -> {0.180166, -0.473439, 0.00331469, 0.00331469}, \
{{274.938, 507.375}, {164.75, 8.1875}} -> {-0.734747, -0.582489, 0.00336379, \
0.00336379}, {{530.625, 763.125}, {164.75, 8.1875}} -> {-2.06823, -0.641137, \
0.00427829, 0.00427829}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting Everything Together", "Section"],

Cell["We add type 0 and an extra parameter n", "Text"],

Cell[BoxData[{
    \(\(\(type[0, a_, b_, c_, n_] := 
      Module[{iC}, \[IndentingNewLine]{icp, icr} = 
          incircle[a, b, c]; \[IndentingNewLine]Join[{{icp, icr}}, 
          type[1, a, b, c, icp, icr, n - 1], 
          type[1, b, a, c, icp, icr, n - 1], 
          type[1, c, a, b, icp, icr, n - 1]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(type[1, _, _, _, _, _, 0] := {}\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(type[1, a_, b_, c_, p_, r_, n_] := 
      Module[{p2, r2}, \[IndentingNewLine]{p2, r2} = 
          type[1, a, b, c, p, r]; \[IndentingNewLine]Join[{{p2, r2}}, 
          type[1, a, b, c, p2, r2, n - 1], 
          type[2, a, b, p, r, p2, r2, n - 1], 
          type[2, a, c, p, r, p2, r2, n - 1]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(type[2, _, _, _, _, _, _, 0] := {}\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(type[2, a_, b_, p1_, r1_, p2_, r2_, n_] := 
      Module[{p3, r3}, \[IndentingNewLine]{p3, r3} = 
          type[2, a, b, p1, r1, p2, r2]; \[IndentingNewLine]Join[{{p3, r3}}, 
          type[2, a, b, p1, r1, p3, r3, n - 1], 
          type[2, a, b, p2, r2, p3, r3, n - 1], 
          type[3, p1, r1, p2, r2, p3, r3, n - 1]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(type[3, _, _, _, _, _, _, 0] := {}\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(type[3, p1_, r1_, p2_, r2_, p3_, r3_, n_] := 
      Module[{p4, r4}, \[IndentingNewLine]{p4, r4} = 
          type[3, p1, r1, p2, r2, p3, 
            r3]; \[IndentingNewLine]Join[{{p4, r4}}, 
          type[3, p1, r1, p2, r2, p4, r4, n - 1], 
          type[3, p1, r1, p3, r3, p4, r4, n - 1], 
          type[3, p2, r2, p3, r3, p4, r4, n - 1]]]\)}], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[type[0, {0, 0}, {2, 0}, {1, \@3}, 3]]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \({{{1, 1\/\@3}, 1\/\@3}, {{1\/3, 1\/\(3\ \@3\)}, 
        1\/\(3\ \@3\)}, {{1\/9, 1\/\(9\ \@3\)}, 
        1\/\(9\ \@3\)}, {{1\/\@3, \(-\(1\/2\)\) + 1\/\@3}, \(-\(1\/2\)\) + 
          1\/\@3}, {{1\/12\ \((6 - \@3)\), 
          1\/12\ \((9 - 2\ \@3)\)}, \(-\(1\/2\)\) + 1\/\@3}, {{5\/3, 
          1\/\(3\ \@3\)}, 1\/\(3\ \@3\)}, {{17\/9, 1\/\(9\ \@3\)}, 
        1\/\(9\ \@3\)}, {{2 - 1\/\@3, \(-\(1\/2\)\) + 
            1\/\@3}, \(-\(1\/2\)\) + 1\/\@3}, {{1\/12\ \((18 + \@3)\), 
          1\/12\ \((9 - 2\ \@3)\)}, \(-\(1\/2\)\) + 1\/\@3}, {{1, 
          7\/\(3\ \@3\)}, 1\/\(3\ \@3\)}, {{1, 25\/\(9\ \@3\)}, 
        1\/\(9\ \@3\)}, {{3\/2 - 5\/\(4\ \@3\), \(-\(1\/4\)\) + 
            5\/\(2\ \@3\)}, \(-\(1\/2\)\) + 
          1\/\@3}, {{1\/12\ \((6 + 5\ \@3)\), \(-\(1\/4\)\) + 
            5\/\(2\ \@3\)}, \(-\(1\/2\)\) + 1\/\@3}}\)], "Output",
  CellLabel->"Out[151]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gallery", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cir = 
        type[0, {0, 0}, {2, 0}, {1. , \@3}, 6];\)\), "\[IndentingNewLine]", 
    \(shG[\({Khaki, Disk[First[#], Last[#]], Indigo, 
            Circle[First[#], Last[#]]} &\) /@ cir]\)}], "Input",
  CellLabel->"In[152]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86634 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0229798 0.47702 0.0206272 0.47702 [
[ 0 0 0 0 ]
[ 1 .86634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.941 .902 .549 r
.5 .29603 m
.5 .29603 .27541 0 365.73 arc
F
.03 .18 .33 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .29603 .27541 0 365.73 arc
s
.941 .902 .549 r
.18199 .11243 m
.18199 .11243 .0918 0 365.73 arc
F
.03 .18 .33 r
newpath
.18199 .11243 .0918 0 365.73 arc
s
.941 .902 .549 r
.07598 .05123 m
.07598 .05123 .0306 0 365.73 arc
F
.03 .18 .33 r
newpath
.07598 .05123 .0306 0 365.73 arc
s
.941 .902 .549 r
.04065 .03083 m
.04065 .03083 .0102 0 365.73 arc
F
.03 .18 .33 r
newpath
.04065 .03083 .0102 0 365.73 arc
s
.941 .902 .549 r
.02887 .02403 m
.02887 .02403 .0034 0 365.73 arc
F
.03 .18 .33 r
newpath
.02887 .02403 .0034 0 365.73 arc
s
.941 .902 .549 r
.02494 .02176 m
.02494 .02176 .00113 0 365.73 arc
F
.03 .18 .33 r
newpath
.02494 .02176 .00113 0 365.73 arc
s
.941 .902 .549 r
.03318 .02199 m
.03318 .02199 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.03318 .02199 .00137 0 365.73 arc
s
.941 .902 .549 r
.02926 .02878 m
.02926 .02878 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.02926 .02878 .00137 0 365.73 arc
s
.941 .902 .549 r
.05358 .02473 m
.05358 .02473 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.05358 .02473 .0041 0 365.73 arc
s
.941 .902 .549 r
.05958 .02282 m
.05958 .02282 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.05958 .02282 .0022 0 365.73 arc
s
.941 .902 .549 r
.04856 .02216 m
.04856 .02216 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.04856 .02216 .00154 0 365.73 arc
s
.941 .902 .549 r
.05215 .02997 m
.05215 .02997 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.05215 .02997 .00133 0 365.73 arc
s
.941 .902 .549 r
.04183 .04508 m
.04183 .04508 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.04183 .04508 .0041 0 365.73 arc
s
.941 .902 .549 r
.04318 .05123 m
.04318 .05123 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.04318 .05123 .0022 0 365.73 arc
s
.941 .902 .549 r
.0371 .04201 m
.0371 .04201 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.0371 .04201 .00154 0 365.73 arc
s
.941 .902 .549 r
.04566 .04122 m
.04566 .04122 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.04566 .04122 .00133 0 365.73 arc
s
.941 .902 .549 r
.11478 .03293 m
.11478 .03293 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.11478 .03293 .0123 0 365.73 arc
s
.941 .902 .549 r
.13279 .02722 m
.13279 .02722 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.13279 .02722 .00659 0 365.73 arc
s
.941 .902 .549 r
.14319 .02473 m
.14319 .02473 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.14319 .02473 .0041 0 365.73 arc
s
.941 .902 .549 r
.12518 .02282 m
.12518 .02282 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.12518 .02282 .0022 0 365.73 arc
s
.941 .902 .549 r
.12898 .03498 m
.12898 .03498 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.12898 .03498 .00205 0 365.73 arc
s
.941 .902 .549 r
.09973 .02523 m
.09973 .02523 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.09973 .02523 .00461 0 365.73 arc
s
.941 .902 .549 r
.09309 .02302 m
.09309 .02302 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.09309 .02302 .00239 0 365.73 arc
s
.941 .902 .549 r
.10544 .0224 m
.10544 .0224 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.10544 .0224 .00177 0 365.73 arc
s
.941 .902 .549 r
.10108 .0312 m
.10108 .0312 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.10108 .0312 .00151 0 365.73 arc
s
.941 .902 .549 r
.11049 .04865 m
.11049 .04865 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.11049 .04865 .004 0 365.73 arc
s
.941 .902 .549 r
.10842 .05427 m
.10842 .05427 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.10842 .05427 .00198 0 365.73 arc
s
.941 .902 .549 r
.11569 .04673 m
.11569 .04673 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.11569 .04673 .00154 0 365.73 arc
s
.941 .902 .549 r
.10723 .04435 m
.10723 .04435 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.10723 .04435 .0014 0 365.73 arc
s
.941 .902 .549 r
.07953 .09398 m
.07953 .09398 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.07953 .09398 .0123 0 365.73 arc
s
.941 .902 .549 r
.08359 .11243 m
.08359 .11243 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.08359 .11243 .00659 0 365.73 arc
s
.941 .902 .549 r
.08663 .12268 m
.08663 .12268 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.08663 .12268 .0041 0 365.73 arc
s
.941 .902 .549 r
.07598 .10804 m
.07598 .10804 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.07598 .10804 .0022 0 365.73 arc
s
.941 .902 .549 r
.08841 .10526 m
.08841 .10526 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.08841 .10526 .00205 0 365.73 arc
s
.941 .902 .549 r
.06534 .08479 m
.06534 .08479 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.06534 .08479 .00461 0 365.73 arc
s
.941 .902 .549 r
.06011 .08015 m
.06011 .08015 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.06011 .08015 .00239 0 365.73 arc
s
.941 .902 .549 r
.06575 .09116 m
.06575 .09116 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.06575 .09116 .00177 0 365.73 arc
s
.941 .902 .549 r
.07119 .08298 m
.07119 .08298 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.07119 .08298 .00151 0 365.73 arc
s
.941 .902 .549 r
.09101 .0824 m
.09101 .0824 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.09101 .0824 .004 0 365.73 arc
s
.941 .902 .549 r
.09483 .0778 m
.09483 .0778 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.09483 .0778 .00198 0 365.73 arc
s
.941 .902 .549 r
.09194 .08786 m
.09194 .08786 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.09194 .08786 .00154 0 365.73 arc
s
.941 .902 .549 r
.08565 .08173 m
.08565 .08173 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.08565 .08173 .0014 0 365.73 arc
s
.941 .902 .549 r
.29839 .05752 m
.29839 .05752 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.29839 .05752 .0369 0 365.73 arc
s
.941 .902 .549 r
.35241 .0404 m
.35241 .0404 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.35241 .0404 .01977 0 365.73 arc
s
.941 .902 .549 r
.3836 .03293 m
.3836 .03293 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.3836 .03293 .0123 0 365.73 arc
s
.941 .902 .549 r
.40391 .02901 m
.40391 .02901 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.40391 .02901 .00838 0 365.73 arc
s
.941 .902 .549 r
.36985 .02447 m
.36985 .02447 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.36985 .02447 .00384 0 365.73 arc
s
.941 .902 .549 r
.37508 .04646 m
.37508 .04646 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.37508 .04646 .00369 0 365.73 arc
s
.941 .902 .549 r
.32958 .02722 m
.32958 .02722 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.32958 .02722 .00659 0 365.73 arc
s
.941 .902 .549 r
.32031 .02388 m
.32031 .02388 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.32031 .02388 .00326 0 365.73 arc
s
.941 .902 .549 r
.33793 .02328 m
.33793 .02328 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.33793 .02328 .00265 0 365.73 arc
s
.941 .902 .549 r
.33093 .03588 m
.33093 .03588 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.33093 .03588 .00218 0 365.73 arc
s
.941 .902 .549 r
.34099 .06367 m
.34099 .06367 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.34099 .06367 .00615 0 365.73 arc
s
.941 .902 .549 r
.33584 .0712 m
.33584 .0712 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.33584 .0712 .00298 0 365.73 arc
s
.941 .902 .549 r
.34951 .06244 m
.34951 .06244 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.34951 .06244 .00246 0 365.73 arc
s
.941 .902 .549 r
.33736 .05627 m
.33736 .05627 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.33736 .05627 .0021 0 365.73 arc
s
.941 .902 .549 r
.25322 .03445 m
.25322 .03445 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.25322 .03445 .01382 0 365.73 arc
s
.941 .902 .549 r
.23331 .0278 m
.23331 .0278 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.23331 .0278 .00717 0 365.73 arc
s
.941 .902 .549 r
.2221 .02501 m
.2221 .02501 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.2221 .02501 .00438 0 365.73 arc
s
.941 .902 .549 r
.24165 .02305 m
.24165 .02305 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.24165 .02305 .00242 0 365.73 arc
s
.941 .902 .549 r
.23727 .03635 m
.23727 .03635 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.23727 .03635 .00225 0 365.73 arc
s
.941 .902 .549 r
.27037 .02595 m
.27037 .02595 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.27037 .02595 .00532 0 365.73 arc
s
.941 .902 .549 r
.27808 .02342 m
.27808 .02342 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.27808 .02342 .00279 0 365.73 arc
s
.941 .902 .549 r
.26381 .02265 m
.26381 .02265 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.26381 .02265 .00203 0 365.73 arc
s
.941 .902 .549 r
.2687 .0328 m
.2687 .0328 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.2687 .0328 .00174 0 365.73 arc
s
.941 .902 .549 r
.25728 .05234 m
.25728 .05234 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.25728 .05234 .00453 0 365.73 arc
s
.941 .902 .549 r
.25926 .05883 m
.25926 .05883 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.25926 .05883 .00225 0 365.73 arc
s
.941 .902 .549 r
.25153 .0499 m
.25153 .0499 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.25153 .0499 .00172 0 365.73 arc
s
.941 .902 .549 r
.26119 .04764 m
.26119 .04764 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.26119 .04764 .00159 0 365.73 arc
s
.941 .902 .549 r
.28551 .10471 m
.28551 .10471 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.28551 .10471 .01201 0 365.73 arc
s
.941 .902 .549 r
.2793 .12155 m
.2793 .12155 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.2793 .12155 .00594 0 365.73 arc
s
.941 .902 .549 r
.27564 .13029 m
.27564 .13029 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.27564 .13029 .00354 0 365.73 arc
s
.941 .902 .549 r
.2867 .11867 m
.2867 .11867 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.2867 .11867 .002 0 365.73 arc
s
.941 .902 .549 r
.27568 .11458 m
.27568 .11458 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.27568 .11458 .00192 0 365.73 arc
s
.941 .902 .549 r
.3011 .09894 m
.3011 .09894 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.3011 .09894 .00461 0 365.73 arc
s
.941 .902 .549 r
.30739 .0958 m
.30739 .0958 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.30739 .0958 .00243 0 365.73 arc
s
.941 .902 .549 r
.29924 .10499 m
.29924 .10499 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.29924 .10499 .00172 0 365.73 arc
s
.941 .902 .549 r
.29578 .09587 m
.29578 .09587 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.29578 .09587 .00154 0 365.73 arc
s
.941 .902 .549 r
.27573 .0918 m
.27573 .0918 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.27573 .0918 .00419 0 365.73 arc
s
.941 .902 .549 r
.27227 .08652 m
.27227 .08652 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.27227 .08652 .00213 0 365.73 arc
s
.941 .902 .549 r
.27412 .09732 m
.27412 .09732 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.27412 .09732 .00157 0 365.73 arc
s
.941 .902 .549 r
.28137 .0919 m
.28137 .0919 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.28137 .0919 .00145 0 365.73 arc
s
.941 .902 .549 r
.19264 .24069 m
.19264 .24069 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.19264 .24069 .0369 0 365.73 arc
s
.941 .902 .549 r
.20482 .29603 m
.20482 .29603 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.20482 .29603 .01977 0 365.73 arc
s
.941 .902 .549 r
.21394 .32678 m
.21394 .32678 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.21394 .32678 .0123 0 365.73 arc
s
.941 .902 .549 r
.2207 .34633 m
.2207 .34633 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.2207 .34633 .00838 0 365.73 arc
s
.941 .902 .549 r
.19974 .3191 m
.19974 .3191 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.19974 .3191 .00384 0 365.73 arc
s
.941 .902 .549 r
.2214 .31264 m
.2214 .31264 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.2214 .31264 .00369 0 365.73 arc
s
.941 .902 .549 r
.18199 .28285 m
.18199 .28285 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.18199 .28285 .00659 0 365.73 arc
s
.941 .902 .549 r
.17447 .2765 m
.17447 .2765 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.17447 .2765 .00326 0 365.73 arc
s
.941 .902 .549 r
.18275 .29206 m
.18275 .29206 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.18275 .29206 .00265 0 365.73 arc
s
.941 .902 .549 r
.19017 .27969 m
.19017 .27969 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.19017 .27969 .00218 0 365.73 arc
s
.941 .902 .549 r
.21927 .27451 m
.21927 .27451 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.21927 .27451 .00615 0 365.73 arc
s
.941 .902 .549 r
.22321 .26628 m
.22321 .26628 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.22321 .26628 .00298 0 365.73 arc
s
.941 .902 .549 r
.22246 .28251 m
.22246 .28251 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.22246 .28251 .00246 0 365.73 arc
s
.941 .902 .549 r
.21104 .27507 m
.21104 .27507 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.21104 .27507 .0021 0 365.73 arc
s
.941 .902 .549 r
.15007 .21311 m
.15007 .21311 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.15007 .21311 .01382 0 365.73 arc
s
.941 .902 .549 r
.13436 .19919 m
.13436 .19919 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.13436 .19919 .00717 0 365.73 arc
s
.941 .902 .549 r
.12633 .19088 m
.12633 .19088 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.12633 .19088 .00438 0 365.73 arc
s
.941 .902 .549 r
.13441 .20879 m
.13441 .20879 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.13441 .20879 .00242 0 365.73 arc
s
.941 .902 .549 r
.14374 .19835 m
.14374 .19835 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.14374 .19835 .00225 0 365.73 arc
s
.941 .902 .549 r
.15128 .23221 m
.15128 .23221 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.15128 .23221 .00532 0 365.73 arc
s
.941 .902 .549 r
.15295 .24015 m
.15295 .24015 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.15295 .24015 .00279 0 365.73 arc
s
.941 .902 .549 r
.14515 .22818 m
.14515 .22818 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.14515 .22818 .00203 0 365.73 arc
s
.941 .902 .549 r
.15638 .22734 m
.15638 .22734 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.15638 .22734 .00174 0 365.73 arc
s
.941 .902 .549 r
.1676 .20768 m
.1676 .20768 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.1676 .20768 .00453 0 365.73 arc
s
.941 .902 .549 r
.1742 .20616 m
.1742 .20616 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.1742 .20616 .00225 0 365.73 arc
s
.941 .902 .549 r
.1626 .20392 m
.1626 .20392 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.1626 .20392 .00172 0 365.73 arc
s
.941 .902 .549 r
.16548 .21342 m
.16548 .21342 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.16548 .21342 .00159 0 365.73 arc
s
.941 .902 .549 r
.22706 .20595 m
.22706 .20595 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.22706 .20595 .01201 0 365.73 arc
s
.941 .902 .549 r
.23854 .19215 m
.23854 .19215 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.23854 .19215 .00594 0 365.73 arc
s
.941 .902 .549 r
.24428 .18461 m
.24428 .18461 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.24428 .18461 .00354 0 365.73 arc
s
.941 .902 .549 r
.23975 .19999 m
.23975 .19999 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.23975 .19999 .002 0 365.73 arc
s
.941 .902 .549 r
.23069 .1925 m
.23069 .1925 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.23069 .1925 .00192 0 365.73 arc
s
.941 .902 .549 r
.22986 .22233 m
.22986 .22233 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.22986 .22233 .00461 0 365.73 arc
s
.941 .902 .549 r
.23029 .22935 m
.23029 .22935 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.23029 .22935 .00243 0 365.73 arc
s
.941 .902 .549 r
.23417 .2177 m
.23417 .2177 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.23417 .2177 .00172 0 365.73 arc
s
.941 .902 .549 r
.22454 .21926 m
.22454 .21926 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.22454 .21926 .00154 0 365.73 arc
s
.941 .902 .549 r
.21099 .20393 m
.21099 .20393 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.21099 .20393 .00419 0 365.73 arc
s
.941 .902 .549 r
.20469 .20357 m
.20469 .20357 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.20469 .20357 .00213 0 365.73 arc
s
.941 .902 .549 r
.21497 .19978 m
.21497 .19978 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.21497 .19978 .00157 0 365.73 arc
s
.941 .902 .549 r
.2139 .20877 m
.2139 .20877 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.2139 .20877 .00145 0 365.73 arc
s
.941 .902 .549 r
.81801 .11243 m
.81801 .11243 .0918 0 365.73 arc
F
.03 .18 .33 r
newpath
.81801 .11243 .0918 0 365.73 arc
s
.941 .902 .549 r
.92402 .05123 m
.92402 .05123 .0306 0 365.73 arc
F
.03 .18 .33 r
newpath
.92402 .05123 .0306 0 365.73 arc
s
.941 .902 .549 r
.95935 .03083 m
.95935 .03083 .0102 0 365.73 arc
F
.03 .18 .33 r
newpath
.95935 .03083 .0102 0 365.73 arc
s
.941 .902 .549 r
.97113 .02403 m
.97113 .02403 .0034 0 365.73 arc
F
.03 .18 .33 r
newpath
.97113 .02403 .0034 0 365.73 arc
s
.941 .902 .549 r
.97506 .02176 m
.97506 .02176 .00113 0 365.73 arc
F
.03 .18 .33 r
newpath
.97506 .02176 .00113 0 365.73 arc
s
.941 .902 .549 r
.96682 .02199 m
.96682 .02199 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.96682 .02199 .00137 0 365.73 arc
s
.941 .902 .549 r
.97074 .02878 m
.97074 .02878 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.97074 .02878 .00137 0 365.73 arc
s
.941 .902 .549 r
.94642 .02473 m
.94642 .02473 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.94642 .02473 .0041 0 365.73 arc
s
.941 .902 .549 r
.94042 .02282 m
.94042 .02282 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.94042 .02282 .0022 0 365.73 arc
s
.941 .902 .549 r
.95144 .02216 m
.95144 .02216 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.95144 .02216 .00154 0 365.73 arc
s
.941 .902 .549 r
.94785 .02997 m
.94785 .02997 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.94785 .02997 .00133 0 365.73 arc
s
.941 .902 .549 r
.95817 .04508 m
.95817 .04508 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.95817 .04508 .0041 0 365.73 arc
s
.941 .902 .549 r
.95682 .05123 m
.95682 .05123 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.95682 .05123 .0022 0 365.73 arc
s
.941 .902 .549 r
.9629 .04201 m
.9629 .04201 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.9629 .04201 .00154 0 365.73 arc
s
.941 .902 .549 r
.95434 .04122 m
.95434 .04122 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.95434 .04122 .00133 0 365.73 arc
s
.941 .902 .549 r
.88522 .03293 m
.88522 .03293 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.88522 .03293 .0123 0 365.73 arc
s
.941 .902 .549 r
.86721 .02722 m
.86721 .02722 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.86721 .02722 .00659 0 365.73 arc
s
.941 .902 .549 r
.85681 .02473 m
.85681 .02473 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.85681 .02473 .0041 0 365.73 arc
s
.941 .902 .549 r
.87482 .02282 m
.87482 .02282 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.87482 .02282 .0022 0 365.73 arc
s
.941 .902 .549 r
.87102 .03498 m
.87102 .03498 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.87102 .03498 .00205 0 365.73 arc
s
.941 .902 .549 r
.90027 .02523 m
.90027 .02523 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.90027 .02523 .00461 0 365.73 arc
s
.941 .902 .549 r
.90691 .02302 m
.90691 .02302 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.90691 .02302 .00239 0 365.73 arc
s
.941 .902 .549 r
.89456 .0224 m
.89456 .0224 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.89456 .0224 .00177 0 365.73 arc
s
.941 .902 .549 r
.89892 .0312 m
.89892 .0312 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.89892 .0312 .00151 0 365.73 arc
s
.941 .902 .549 r
.88951 .04865 m
.88951 .04865 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.88951 .04865 .004 0 365.73 arc
s
.941 .902 .549 r
.89158 .05427 m
.89158 .05427 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.89158 .05427 .00198 0 365.73 arc
s
.941 .902 .549 r
.88431 .04673 m
.88431 .04673 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.88431 .04673 .00154 0 365.73 arc
s
.941 .902 .549 r
.89277 .04435 m
.89277 .04435 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.89277 .04435 .0014 0 365.73 arc
s
.941 .902 .549 r
.92047 .09398 m
.92047 .09398 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.92047 .09398 .0123 0 365.73 arc
s
.941 .902 .549 r
.91641 .11243 m
.91641 .11243 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.91641 .11243 .00659 0 365.73 arc
s
.941 .902 .549 r
.91337 .12268 m
.91337 .12268 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.91337 .12268 .0041 0 365.73 arc
s
.941 .902 .549 r
.92402 .10804 m
.92402 .10804 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.92402 .10804 .0022 0 365.73 arc
s
.941 .902 .549 r
.91159 .10526 m
.91159 .10526 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.91159 .10526 .00205 0 365.73 arc
s
.941 .902 .549 r
.93466 .08479 m
.93466 .08479 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.93466 .08479 .00461 0 365.73 arc
s
.941 .902 .549 r
.93989 .08015 m
.93989 .08015 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.93989 .08015 .00239 0 365.73 arc
s
.941 .902 .549 r
.93425 .09116 m
.93425 .09116 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.93425 .09116 .00177 0 365.73 arc
s
.941 .902 .549 r
.92881 .08298 m
.92881 .08298 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.92881 .08298 .00151 0 365.73 arc
s
.941 .902 .549 r
.90899 .0824 m
.90899 .0824 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.90899 .0824 .004 0 365.73 arc
s
.941 .902 .549 r
.90517 .0778 m
.90517 .0778 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.90517 .0778 .00198 0 365.73 arc
s
.941 .902 .549 r
.90806 .08786 m
.90806 .08786 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.90806 .08786 .00154 0 365.73 arc
s
.941 .902 .549 r
.91435 .08173 m
.91435 .08173 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.91435 .08173 .0014 0 365.73 arc
s
.941 .902 .549 r
.70161 .05752 m
.70161 .05752 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.70161 .05752 .0369 0 365.73 arc
s
.941 .902 .549 r
.64759 .0404 m
.64759 .0404 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.64759 .0404 .01977 0 365.73 arc
s
.941 .902 .549 r
.6164 .03293 m
.6164 .03293 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.6164 .03293 .0123 0 365.73 arc
s
.941 .902 .549 r
.59609 .02901 m
.59609 .02901 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.59609 .02901 .00838 0 365.73 arc
s
.941 .902 .549 r
.63015 .02447 m
.63015 .02447 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.63015 .02447 .00384 0 365.73 arc
s
.941 .902 .549 r
.62492 .04646 m
.62492 .04646 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.62492 .04646 .00369 0 365.73 arc
s
.941 .902 .549 r
.67042 .02722 m
.67042 .02722 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.67042 .02722 .00659 0 365.73 arc
s
.941 .902 .549 r
.67969 .02388 m
.67969 .02388 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.67969 .02388 .00326 0 365.73 arc
s
.941 .902 .549 r
.66207 .02328 m
.66207 .02328 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.66207 .02328 .00265 0 365.73 arc
s
.941 .902 .549 r
.66907 .03588 m
.66907 .03588 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.66907 .03588 .00218 0 365.73 arc
s
.941 .902 .549 r
.65901 .06367 m
.65901 .06367 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.65901 .06367 .00615 0 365.73 arc
s
.941 .902 .549 r
.66416 .0712 m
.66416 .0712 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.66416 .0712 .00298 0 365.73 arc
s
.941 .902 .549 r
.65049 .06244 m
.65049 .06244 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.65049 .06244 .00246 0 365.73 arc
s
.941 .902 .549 r
.66264 .05627 m
.66264 .05627 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.66264 .05627 .0021 0 365.73 arc
s
.941 .902 .549 r
.74678 .03445 m
.74678 .03445 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.74678 .03445 .01382 0 365.73 arc
s
.941 .902 .549 r
.76669 .0278 m
.76669 .0278 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.76669 .0278 .00717 0 365.73 arc
s
.941 .902 .549 r
.7779 .02501 m
.7779 .02501 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.7779 .02501 .00438 0 365.73 arc
s
.941 .902 .549 r
.75835 .02305 m
.75835 .02305 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.75835 .02305 .00242 0 365.73 arc
s
.941 .902 .549 r
.76273 .03635 m
.76273 .03635 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.76273 .03635 .00225 0 365.73 arc
s
.941 .902 .549 r
.72963 .02595 m
.72963 .02595 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.72963 .02595 .00532 0 365.73 arc
s
.941 .902 .549 r
.72192 .02342 m
.72192 .02342 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.72192 .02342 .00279 0 365.73 arc
s
.941 .902 .549 r
.73619 .02265 m
.73619 .02265 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.73619 .02265 .00203 0 365.73 arc
s
.941 .902 .549 r
.7313 .0328 m
.7313 .0328 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.7313 .0328 .00174 0 365.73 arc
s
.941 .902 .549 r
.74272 .05234 m
.74272 .05234 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.74272 .05234 .00453 0 365.73 arc
s
.941 .902 .549 r
.74074 .05883 m
.74074 .05883 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.74074 .05883 .00225 0 365.73 arc
s
.941 .902 .549 r
.74847 .0499 m
.74847 .0499 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.74847 .0499 .00172 0 365.73 arc
s
.941 .902 .549 r
.73881 .04764 m
.73881 .04764 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.73881 .04764 .00159 0 365.73 arc
s
.941 .902 .549 r
.71449 .10471 m
.71449 .10471 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.71449 .10471 .01201 0 365.73 arc
s
.941 .902 .549 r
.7207 .12155 m
.7207 .12155 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.7207 .12155 .00594 0 365.73 arc
s
.941 .902 .549 r
.72436 .13029 m
.72436 .13029 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.72436 .13029 .00354 0 365.73 arc
s
.941 .902 .549 r
.7133 .11867 m
.7133 .11867 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.7133 .11867 .002 0 365.73 arc
s
.941 .902 .549 r
.72432 .11458 m
.72432 .11458 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.72432 .11458 .00192 0 365.73 arc
s
.941 .902 .549 r
.6989 .09894 m
.6989 .09894 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.6989 .09894 .00461 0 365.73 arc
s
.941 .902 .549 r
.69261 .0958 m
.69261 .0958 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.69261 .0958 .00243 0 365.73 arc
s
.941 .902 .549 r
.70076 .10499 m
.70076 .10499 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.70076 .10499 .00172 0 365.73 arc
s
.941 .902 .549 r
.70422 .09587 m
.70422 .09587 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.70422 .09587 .00154 0 365.73 arc
s
.941 .902 .549 r
.72427 .0918 m
.72427 .0918 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.72427 .0918 .00419 0 365.73 arc
s
.941 .902 .549 r
.72773 .08652 m
.72773 .08652 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.72773 .08652 .00213 0 365.73 arc
s
.941 .902 .549 r
.72588 .09732 m
.72588 .09732 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.72588 .09732 .00157 0 365.73 arc
s
.941 .902 .549 r
.71863 .0919 m
.71863 .0919 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.71863 .0919 .00145 0 365.73 arc
s
.941 .902 .549 r
.80736 .24069 m
.80736 .24069 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.80736 .24069 .0369 0 365.73 arc
s
.941 .902 .549 r
.79518 .29603 m
.79518 .29603 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.79518 .29603 .01977 0 365.73 arc
s
.941 .902 .549 r
.78606 .32678 m
.78606 .32678 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.78606 .32678 .0123 0 365.73 arc
s
.941 .902 .549 r
.7793 .34633 m
.7793 .34633 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.7793 .34633 .00838 0 365.73 arc
s
.941 .902 .549 r
.80026 .3191 m
.80026 .3191 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.80026 .3191 .00384 0 365.73 arc
s
.941 .902 .549 r
.7786 .31264 m
.7786 .31264 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.7786 .31264 .00369 0 365.73 arc
s
.941 .902 .549 r
.81801 .28285 m
.81801 .28285 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.81801 .28285 .00659 0 365.73 arc
s
.941 .902 .549 r
.82553 .2765 m
.82553 .2765 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.82553 .2765 .00326 0 365.73 arc
s
.941 .902 .549 r
.81725 .29206 m
.81725 .29206 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.81725 .29206 .00265 0 365.73 arc
s
.941 .902 .549 r
.80983 .27969 m
.80983 .27969 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.80983 .27969 .00218 0 365.73 arc
s
.941 .902 .549 r
.78073 .27451 m
.78073 .27451 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.78073 .27451 .00615 0 365.73 arc
s
.941 .902 .549 r
.77679 .26628 m
.77679 .26628 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.77679 .26628 .00298 0 365.73 arc
s
.941 .902 .549 r
.77754 .28251 m
.77754 .28251 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.77754 .28251 .00246 0 365.73 arc
s
.941 .902 .549 r
.78896 .27507 m
.78896 .27507 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.78896 .27507 .0021 0 365.73 arc
s
.941 .902 .549 r
.84993 .21311 m
.84993 .21311 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.84993 .21311 .01382 0 365.73 arc
s
.941 .902 .549 r
.86564 .19919 m
.86564 .19919 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.86564 .19919 .00717 0 365.73 arc
s
.941 .902 .549 r
.87367 .19088 m
.87367 .19088 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.87367 .19088 .00438 0 365.73 arc
s
.941 .902 .549 r
.86559 .20879 m
.86559 .20879 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.86559 .20879 .00242 0 365.73 arc
s
.941 .902 .549 r
.85626 .19835 m
.85626 .19835 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.85626 .19835 .00225 0 365.73 arc
s
.941 .902 .549 r
.84872 .23221 m
.84872 .23221 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.84872 .23221 .00532 0 365.73 arc
s
.941 .902 .549 r
.84705 .24015 m
.84705 .24015 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.84705 .24015 .00279 0 365.73 arc
s
.941 .902 .549 r
.85485 .22818 m
.85485 .22818 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.85485 .22818 .00203 0 365.73 arc
s
.941 .902 .549 r
.84362 .22734 m
.84362 .22734 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.84362 .22734 .00174 0 365.73 arc
s
.941 .902 .549 r
.8324 .20768 m
.8324 .20768 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.8324 .20768 .00453 0 365.73 arc
s
.941 .902 .549 r
.8258 .20616 m
.8258 .20616 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.8258 .20616 .00225 0 365.73 arc
s
.941 .902 .549 r
.8374 .20392 m
.8374 .20392 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.8374 .20392 .00172 0 365.73 arc
s
.941 .902 .549 r
.83452 .21342 m
.83452 .21342 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.83452 .21342 .00159 0 365.73 arc
s
.941 .902 .549 r
.77294 .20595 m
.77294 .20595 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.77294 .20595 .01201 0 365.73 arc
s
.941 .902 .549 r
.76146 .19215 m
.76146 .19215 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.76146 .19215 .00594 0 365.73 arc
s
.941 .902 .549 r
.75572 .18461 m
.75572 .18461 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.75572 .18461 .00354 0 365.73 arc
s
.941 .902 .549 r
.76025 .19999 m
.76025 .19999 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.76025 .19999 .002 0 365.73 arc
s
.941 .902 .549 r
.76931 .1925 m
.76931 .1925 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.76931 .1925 .00192 0 365.73 arc
s
.941 .902 .549 r
.77014 .22233 m
.77014 .22233 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.77014 .22233 .00461 0 365.73 arc
s
.941 .902 .549 r
.76971 .22935 m
.76971 .22935 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.76971 .22935 .00243 0 365.73 arc
s
.941 .902 .549 r
.76583 .2177 m
.76583 .2177 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.76583 .2177 .00172 0 365.73 arc
s
.941 .902 .549 r
.77546 .21926 m
.77546 .21926 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.77546 .21926 .00154 0 365.73 arc
s
.941 .902 .549 r
.78901 .20393 m
.78901 .20393 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.78901 .20393 .00419 0 365.73 arc
s
.941 .902 .549 r
.79531 .20357 m
.79531 .20357 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.79531 .20357 .00213 0 365.73 arc
s
.941 .902 .549 r
.78503 .19978 m
.78503 .19978 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.78503 .19978 .00157 0 365.73 arc
s
.941 .902 .549 r
.7861 .20877 m
.7861 .20877 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.7861 .20877 .00145 0 365.73 arc
s
.941 .902 .549 r
.5 .66325 m
.5 .66325 .0918 0 365.73 arc
F
.03 .18 .33 r
newpath
.5 .66325 .0918 0 365.73 arc
s
.941 .902 .549 r
.5 .78565 m
.5 .78565 .0306 0 365.73 arc
F
.03 .18 .33 r
newpath
.5 .78565 .0306 0 365.73 arc
s
.941 .902 .549 r
.5 .82645 m
.5 .82645 .0102 0 365.73 arc
F
.03 .18 .33 r
newpath
.5 .82645 .0102 0 365.73 arc
s
.941 .902 .549 r
.5 .84005 m
.5 .84005 .0034 0 365.73 arc
F
.03 .18 .33 r
newpath
.5 .84005 .0034 0 365.73 arc
s
.941 .902 .549 r
.5 .84458 m
.5 .84458 .00113 0 365.73 arc
F
.03 .18 .33 r
newpath
.5 .84458 .00113 0 365.73 arc
s
.941 .902 .549 r
.49608 .83733 m
.49608 .83733 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.49608 .83733 .00137 0 365.73 arc
s
.941 .902 .549 r
.50392 .83733 m
.50392 .83733 .00137 0 365.73 arc
F
.03 .18 .33 r
newpath
.50392 .83733 .00137 0 365.73 arc
s
.941 .902 .549 r
.48825 .8183 m
.48825 .8183 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.48825 .8183 .0041 0 365.73 arc
s
.941 .902 .549 r
.4836 .81405 m
.4836 .81405 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.4836 .81405 .0022 0 365.73 arc
s
.941 .902 .549 r
.48854 .82393 m
.48854 .82393 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.48854 .82393 .00154 0 365.73 arc
s
.941 .902 .549 r
.49351 .81692 m
.49351 .81692 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.49351 .81692 .00133 0 365.73 arc
s
.941 .902 .549 r
.51175 .8183 m
.51175 .8183 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.51175 .8183 .0041 0 365.73 arc
s
.941 .902 .549 r
.5164 .81405 m
.5164 .81405 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.5164 .81405 .0022 0 365.73 arc
s
.941 .902 .549 r
.51146 .82393 m
.51146 .82393 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.51146 .82393 .00154 0 365.73 arc
s
.941 .902 .549 r
.50649 .81692 m
.50649 .81692 .00133 0 365.73 arc
F
.03 .18 .33 r
newpath
.50649 .81692 .00133 0 365.73 arc
s
.941 .902 .549 r
.46475 .7612 m
.46475 .7612 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.46475 .7612 .0123 0 365.73 arc
s
.941 .902 .549 r
.4508 .74846 m
.4508 .74846 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.4508 .74846 .00659 0 365.73 arc
s
.941 .902 .549 r
.44345 .7407 m
.44345 .7407 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.44345 .7407 .0041 0 365.73 arc
s
.941 .902 .549 r
.4508 .75724 m
.4508 .75724 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.4508 .75724 .0022 0 365.73 arc
s
.941 .902 .549 r
.45942 .74787 m
.45942 .74787 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.45942 .74787 .00205 0 365.73 arc
s
.941 .902 .549 r
.46562 .77808 m
.46562 .77808 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.46562 .77808 .00461 0 365.73 arc
s
.941 .902 .549 r
.46702 .78494 m
.46702 .78494 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.46702 .78494 .00239 0 365.73 arc
s
.941 .902 .549 r
.4603 .77455 m
.4603 .77455 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.4603 .77455 .00177 0 365.73 arc
s
.941 .902 .549 r
.4701 .77393 m
.4701 .77393 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.4701 .77393 .00151 0 365.73 arc
s
.941 .902 .549 r
.48052 .75705 m
.48052 .75705 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.48052 .75705 .004 0 365.73 arc
s
.941 .902 .549 r
.48641 .75604 m
.48641 .75604 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.48641 .75604 .00198 0 365.73 arc
s
.941 .902 .549 r
.47625 .75351 m
.47625 .75351 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.47625 .75351 .00154 0 365.73 arc
s
.941 .902 .549 r
.47842 .76203 m
.47842 .76203 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.47842 .76203 .0014 0 365.73 arc
s
.941 .902 .549 r
.53525 .7612 m
.53525 .7612 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.53525 .7612 .0123 0 365.73 arc
s
.941 .902 .549 r
.5492 .74846 m
.5492 .74846 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.5492 .74846 .00659 0 365.73 arc
s
.941 .902 .549 r
.55655 .7407 m
.55655 .7407 .0041 0 365.73 arc
F
.03 .18 .33 r
newpath
.55655 .7407 .0041 0 365.73 arc
s
.941 .902 .549 r
.5492 .75724 m
.5492 .75724 .0022 0 365.73 arc
F
.03 .18 .33 r
newpath
.5492 .75724 .0022 0 365.73 arc
s
.941 .902 .549 r
.54058 .74787 m
.54058 .74787 .00205 0 365.73 arc
F
.03 .18 .33 r
newpath
.54058 .74787 .00205 0 365.73 arc
s
.941 .902 .549 r
.53438 .77808 m
.53438 .77808 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.53438 .77808 .00461 0 365.73 arc
s
.941 .902 .549 r
.53298 .78494 m
.53298 .78494 .00239 0 365.73 arc
F
.03 .18 .33 r
newpath
.53298 .78494 .00239 0 365.73 arc
s
.941 .902 .549 r
.5397 .77455 m
.5397 .77455 .00177 0 365.73 arc
F
.03 .18 .33 r
newpath
.5397 .77455 .00177 0 365.73 arc
s
.941 .902 .549 r
.5299 .77393 m
.5299 .77393 .00151 0 365.73 arc
F
.03 .18 .33 r
newpath
.5299 .77393 .00151 0 365.73 arc
s
.941 .902 .549 r
.51948 .75705 m
.51948 .75705 .004 0 365.73 arc
F
.03 .18 .33 r
newpath
.51948 .75705 .004 0 365.73 arc
s
.941 .902 .549 r
.51359 .75604 m
.51359 .75604 .00198 0 365.73 arc
F
.03 .18 .33 r
newpath
.51359 .75604 .00198 0 365.73 arc
s
.941 .902 .549 r
.52375 .75351 m
.52375 .75351 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.52375 .75351 .00154 0 365.73 arc
s
.941 .902 .549 r
.52158 .76203 m
.52158 .76203 .0014 0 365.73 arc
F
.03 .18 .33 r
newpath
.52158 .76203 .0014 0 365.73 arc
s
.941 .902 .549 r
.39425 .58989 m
.39425 .58989 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.39425 .58989 .0369 0 365.73 arc
s
.941 .902 .549 r
.35241 .55167 m
.35241 .55167 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.35241 .55167 .01977 0 365.73 arc
s
.941 .902 .549 r
.33034 .5284 m
.33034 .5284 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.33034 .5284 .0123 0 365.73 arc
s
.941 .902 .549 r
.3168 .51277 m
.3168 .51277 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.3168 .51277 .00838 0 365.73 arc
s
.941 .902 .549 r
.3299 .54453 m
.3299 .54453 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.3299 .54453 .00384 0 365.73 arc
s
.941 .902 .549 r
.34632 .52901 m
.34632 .52901 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.34632 .52901 .00369 0 365.73 arc
s
.941 .902 .549 r
.35241 .57803 m
.35241 .57803 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.35241 .57803 .00659 0 365.73 arc
s
.941 .902 .549 r
.35415 .58773 m
.35415 .58773 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.35415 .58773 .00326 0 365.73 arc
s
.941 .902 .549 r
.34482 .57277 m
.34482 .57277 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.34482 .57277 .00265 0 365.73 arc
s
.941 .902 .549 r
.35924 .57253 m
.35924 .57253 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.35924 .57253 .00218 0 365.73 arc
s
.941 .902 .549 r
.37827 .54992 m
.37827 .54992 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.37827 .54992 .00615 0 365.73 arc
s
.941 .902 .549 r
.38737 .55062 m
.38737 .55062 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.38737 .55062 .00298 0 365.73 arc
s
.941 .902 .549 r
.37295 .54315 m
.37295 .54315 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.37295 .54315 .00246 0 365.73 arc
s
.941 .902 .549 r
.37368 .55677 m
.37368 .55677 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.37368 .55677 .0021 0 365.73 arc
s
.941 .902 .549 r
.39685 .64054 m
.39685 .64054 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.39685 .64054 .01382 0 365.73 arc
s
.941 .902 .549 r
.40105 .66111 m
.40105 .66111 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.40105 .66111 .00717 0 365.73 arc
s
.941 .902 .549 r
.40424 .67222 m
.40424 .67222 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.40424 .67222 .00438 0 365.73 arc
s
.941 .902 .549 r
.39276 .65626 m
.39276 .65626 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.39276 .65626 .00242 0 365.73 arc
s
.941 .902 .549 r
.40647 .65341 m
.40647 .65341 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.40647 .65341 .00225 0 365.73 arc
s
.941 .902 .549 r
.38091 .62994 m
.38091 .62994 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.38091 .62994 .00532 0 365.73 arc
s
.941 .902 .549 r
.37487 .62453 m
.37487 .62453 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.37487 .62453 .00279 0 365.73 arc
s
.941 .902 .549 r
.38134 .63728 m
.38134 .63728 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.38134 .63728 .00203 0 365.73 arc
s
.941 .902 .549 r
.38768 .62797 m
.38768 .62797 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.38768 .62797 .00174 0 365.73 arc
s
.941 .902 .549 r
.41031 .62808 m
.41031 .62808 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.41031 .62808 .00453 0 365.73 arc
s
.941 .902 .549 r
.41494 .62312 m
.41494 .62312 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.41494 .62312 .00225 0 365.73 arc
s
.941 .902 .549 r
.41107 .63429 m
.41107 .63429 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.41107 .63429 .00172 0 365.73 arc
s
.941 .902 .549 r
.40428 .62705 m
.40428 .62705 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.40428 .62705 .00159 0 365.73 arc
s
.941 .902 .549 r
.44155 .57745 m
.44155 .57745 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.44155 .57745 .01201 0 365.73 arc
s
.941 .902 .549 r
.45924 .57441 m
.45924 .57441 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.45924 .57441 .00594 0 365.73 arc
s
.941 .902 .549 r
.46864 .57321 m
.46864 .57321 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.46864 .57321 .00354 0 365.73 arc
s
.941 .902 .549 r
.45305 .56944 m
.45305 .56944 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.45305 .56944 .002 0 365.73 arc
s
.941 .902 .549 r
.45501 .58103 m
.45501 .58103 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.45501 .58103 .00192 0 365.73 arc
s
.941 .902 .549 r
.42876 .56684 m
.42876 .56684 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.42876 .56684 .00461 0 365.73 arc
s
.941 .902 .549 r
.4229 .56296 m
.4229 .56296 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.4229 .56296 .00243 0 365.73 arc
s
.941 .902 .549 r
.43493 .56542 m
.43493 .56542 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.43493 .56542 .00172 0 365.73 arc
s
.941 .902 .549 r
.42876 .57298 m
.42876 .57298 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.42876 .57298 .00154 0 365.73 arc
s
.941 .902 .549 r
.43526 .59238 m
.43526 .59238 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.43526 .59238 .00419 0 365.73 arc
s
.941 .902 .549 r
.43242 .59801 m
.43242 .59801 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.43242 .59801 .00213 0 365.73 arc
s
.941 .902 .549 r
.44085 .59101 m
.44085 .59101 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.44085 .59101 .00157 0 365.73 arc
s
.941 .902 .549 r
.43252 .58744 m
.43252 .58744 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.43252 .58744 .00145 0 365.73 arc
s
.941 .902 .549 r
.60575 .58989 m
.60575 .58989 .0369 0 365.73 arc
F
.03 .18 .33 r
newpath
.60575 .58989 .0369 0 365.73 arc
s
.941 .902 .549 r
.64759 .55167 m
.64759 .55167 .01977 0 365.73 arc
F
.03 .18 .33 r
newpath
.64759 .55167 .01977 0 365.73 arc
s
.941 .902 .549 r
.66966 .5284 m
.66966 .5284 .0123 0 365.73 arc
F
.03 .18 .33 r
newpath
.66966 .5284 .0123 0 365.73 arc
s
.941 .902 .549 r
.6832 .51277 m
.6832 .51277 .00838 0 365.73 arc
F
.03 .18 .33 r
newpath
.6832 .51277 .00838 0 365.73 arc
s
.941 .902 .549 r
.6701 .54453 m
.6701 .54453 .00384 0 365.73 arc
F
.03 .18 .33 r
newpath
.6701 .54453 .00384 0 365.73 arc
s
.941 .902 .549 r
.65368 .52901 m
.65368 .52901 .00369 0 365.73 arc
F
.03 .18 .33 r
newpath
.65368 .52901 .00369 0 365.73 arc
s
.941 .902 .549 r
.64759 .57803 m
.64759 .57803 .00659 0 365.73 arc
F
.03 .18 .33 r
newpath
.64759 .57803 .00659 0 365.73 arc
s
.941 .902 .549 r
.64585 .58773 m
.64585 .58773 .00326 0 365.73 arc
F
.03 .18 .33 r
newpath
.64585 .58773 .00326 0 365.73 arc
s
.941 .902 .549 r
.65518 .57277 m
.65518 .57277 .00265 0 365.73 arc
F
.03 .18 .33 r
newpath
.65518 .57277 .00265 0 365.73 arc
s
.941 .902 .549 r
.64076 .57253 m
.64076 .57253 .00218 0 365.73 arc
F
.03 .18 .33 r
newpath
.64076 .57253 .00218 0 365.73 arc
s
.941 .902 .549 r
.62173 .54992 m
.62173 .54992 .00615 0 365.73 arc
F
.03 .18 .33 r
newpath
.62173 .54992 .00615 0 365.73 arc
s
.941 .902 .549 r
.61263 .55062 m
.61263 .55062 .00298 0 365.73 arc
F
.03 .18 .33 r
newpath
.61263 .55062 .00298 0 365.73 arc
s
.941 .902 .549 r
.62705 .54315 m
.62705 .54315 .00246 0 365.73 arc
F
.03 .18 .33 r
newpath
.62705 .54315 .00246 0 365.73 arc
s
.941 .902 .549 r
.62632 .55677 m
.62632 .55677 .0021 0 365.73 arc
F
.03 .18 .33 r
newpath
.62632 .55677 .0021 0 365.73 arc
s
.941 .902 .549 r
.60315 .64054 m
.60315 .64054 .01382 0 365.73 arc
F
.03 .18 .33 r
newpath
.60315 .64054 .01382 0 365.73 arc
s
.941 .902 .549 r
.59895 .66111 m
.59895 .66111 .00717 0 365.73 arc
F
.03 .18 .33 r
newpath
.59895 .66111 .00717 0 365.73 arc
s
.941 .902 .549 r
.59576 .67222 m
.59576 .67222 .00438 0 365.73 arc
F
.03 .18 .33 r
newpath
.59576 .67222 .00438 0 365.73 arc
s
.941 .902 .549 r
.60724 .65626 m
.60724 .65626 .00242 0 365.73 arc
F
.03 .18 .33 r
newpath
.60724 .65626 .00242 0 365.73 arc
s
.941 .902 .549 r
.59353 .65341 m
.59353 .65341 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.59353 .65341 .00225 0 365.73 arc
s
.941 .902 .549 r
.61909 .62994 m
.61909 .62994 .00532 0 365.73 arc
F
.03 .18 .33 r
newpath
.61909 .62994 .00532 0 365.73 arc
s
.941 .902 .549 r
.62513 .62453 m
.62513 .62453 .00279 0 365.73 arc
F
.03 .18 .33 r
newpath
.62513 .62453 .00279 0 365.73 arc
s
.941 .902 .549 r
.61866 .63728 m
.61866 .63728 .00203 0 365.73 arc
F
.03 .18 .33 r
newpath
.61866 .63728 .00203 0 365.73 arc
s
.941 .902 .549 r
.61232 .62797 m
.61232 .62797 .00174 0 365.73 arc
F
.03 .18 .33 r
newpath
.61232 .62797 .00174 0 365.73 arc
s
.941 .902 .549 r
.58969 .62808 m
.58969 .62808 .00453 0 365.73 arc
F
.03 .18 .33 r
newpath
.58969 .62808 .00453 0 365.73 arc
s
.941 .902 .549 r
.58506 .62312 m
.58506 .62312 .00225 0 365.73 arc
F
.03 .18 .33 r
newpath
.58506 .62312 .00225 0 365.73 arc
s
.941 .902 .549 r
.58893 .63429 m
.58893 .63429 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.58893 .63429 .00172 0 365.73 arc
s
.941 .902 .549 r
.59572 .62705 m
.59572 .62705 .00159 0 365.73 arc
F
.03 .18 .33 r
newpath
.59572 .62705 .00159 0 365.73 arc
s
.941 .902 .549 r
.55845 .57745 m
.55845 .57745 .01201 0 365.73 arc
F
.03 .18 .33 r
newpath
.55845 .57745 .01201 0 365.73 arc
s
.941 .902 .549 r
.54076 .57441 m
.54076 .57441 .00594 0 365.73 arc
F
.03 .18 .33 r
newpath
.54076 .57441 .00594 0 365.73 arc
s
.941 .902 .549 r
.53136 .57321 m
.53136 .57321 .00354 0 365.73 arc
F
.03 .18 .33 r
newpath
.53136 .57321 .00354 0 365.73 arc
s
.941 .902 .549 r
.54695 .56944 m
.54695 .56944 .002 0 365.73 arc
F
.03 .18 .33 r
newpath
.54695 .56944 .002 0 365.73 arc
s
.941 .902 .549 r
.54499 .58103 m
.54499 .58103 .00192 0 365.73 arc
F
.03 .18 .33 r
newpath
.54499 .58103 .00192 0 365.73 arc
s
.941 .902 .549 r
.57124 .56684 m
.57124 .56684 .00461 0 365.73 arc
F
.03 .18 .33 r
newpath
.57124 .56684 .00461 0 365.73 arc
s
.941 .902 .549 r
.5771 .56296 m
.5771 .56296 .00243 0 365.73 arc
F
.03 .18 .33 r
newpath
.5771 .56296 .00243 0 365.73 arc
s
.941 .902 .549 r
.56507 .56542 m
.56507 .56542 .00172 0 365.73 arc
F
.03 .18 .33 r
newpath
.56507 .56542 .00172 0 365.73 arc
s
.941 .902 .549 r
.57124 .57298 m
.57124 .57298 .00154 0 365.73 arc
F
.03 .18 .33 r
newpath
.57124 .57298 .00154 0 365.73 arc
s
.941 .902 .549 r
.56474 .59238 m
.56474 .59238 .00419 0 365.73 arc
F
.03 .18 .33 r
newpath
.56474 .59238 .00419 0 365.73 arc
s
.941 .902 .549 r
.56758 .59801 m
.56758 .59801 .00213 0 365.73 arc
F
.03 .18 .33 r
newpath
.56758 .59801 .00213 0 365.73 arc
s
.941 .902 .549 r
.55915 .59101 m
.55915 .59101 .00157 0 365.73 arc
F
.03 .18 .33 r
newpath
.55915 .59101 .00157 0 365.73 arc
s
.941 .902 .549 r
.56748 .58744 m
.56748 .58744 .00145 0 365.73 arc
F
.03 .18 .33 r
newpath
.56748 .58744 .00145 0 365.73 arc
s
0 0 m
1 0 L
1 .86634 L
0 .86634 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[152]:=",
  ImageSize->{288, 249.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000nB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`001P3oool400L^E0030?ooo`07;U@0oooo00D01biD00<0oooo00L^E007;U@01007;U@00`3o
ool01biD00L^E00300L^E0040?ooo`07;U@01biD0?ooo`@01biD00@0oooo00L^E007;U@01biD1@3o
ool:00L^E0@0oooo2007;U@20?ooo`801biD00<0oooo00L^E007;U@01007;U@00`3oool01biD00L^
E00500L^E080oooo1007;U@0103oool01biD00L^E03oool300L^E0<0oooo0`07;U@00`3oool01biD
00L^E0050?ooo`0300L^E03oool0oooo0100oooo4@07;U@C0?ooo`0300L^E03oool0oooo0080oooo
0P07;U@20?ooo`801biD0P3oool300L^E080oooo1007;U@0103oool01biD00L^E03oool800L^E003
0?ooo`07;U@01biD00@01biD00D0oooo00L^E007;U@01biD0?ooo`0400L^E0040?ooo`07;U@01biD
00L^E0D0oooo2P07;U@50?ooo`@01biD00@0oooo00L^E007;U@0oooo0P07;U@00`3oool01biD00L^
E00300L^E0030?ooo`07;U@01biD00@01biD00<0oooo00L^E007;U@00`07;U@00`3oool01biD0?oo
o`0400L^E0L0oooo00070?ooo`0500L^E03`iX`01biD00L^E03`iX`00`07;U@0103`iX`01biD00L^
E007;U@60?3VS0<01biD00@0l>J<00L^E007;U@01biD0P3`iX`300L^E080l>J<00<01biD0?3VS03`
iX`01P07;U@:0?3VS0801biD0P3oool01007;U@0l>J<0?3VS007;U@20?3VS0@01biD0P3`iX`300L^
E0030?3VS007;U@01biD00801biD1`3`iX`400L^E080l>J<1007;U@30?3VS0801biD00<0oooo00L^
E03`iX`00P07;U@20?3VS0801biD00D0oooo00L^E007;U@0l>J<00L^E0090?ooo`P01biD4@3`iX`8
00L^E0T0oooo0P07;U@00`3`iX`01biD0?ooo`0200L^E080l>J<0P07;U@0103`iX`01biD00L^E007
;U@30?3VS0@01biD0P3`iX`400L^E0P0l>J<0`07;U@20?3VS0<01biD0`3`iX`300L^E080l>J<00<0
1biD0?3VS03`iX`01P07;U@:0?3VS0<01biD00H0oooo00L^E03`iX`0l>J<00L^E03`iX`400L^E080
l>J<0`07;U@0103`iX`01biD00L^E007;U@60?3VS0<01biD00D0l>J<00L^E007;U@01biD0?3VS002
00L^E0030?3VS007;U@0oooo00L0oooo00070?ooo`<01biD0`3`iX`400L^E0T0l>J<0P07;U@00`3`
iX`01biD0?3VS0040?3VS0801biD0`3`iX`300L^E140l>J<1@07;U@40?3VS00300L^E03`iX`0l>J<
00<0l>J<0P07;U@00`3`iX`01biD00L^E00;0?3VS0801biD0`3`iX`00`07;U@0l>J<0?3VS0050?3V
S0<01biD1@3`iX`200L^E0<0l>J<0P07;U@50?ooo`<01biD8@3`iX`400L^E0@0oooo00@01biD0?3V
S03`iX`0l>J<0P07;U@50?3VS0<01biD1`3`iX`200L^E0<0l>J<0P07;U@;0?3VS0801biD00<0l>J<
00L^E007;U@01@3`iX`00`07;U@0l>J<0?3VS0020?3VS0<01biD4P3`iX`400L^E0<0l>J<00<01biD
0?3VS03`iX`00`3`iX`200L^E0030?3VS007;U@0l>J<00T0l>J<0`07;U@40?3VS0<01biD203oool0
00P0oooo00<01biD0?3VS03`iX`00`3`iX`200L^E0`0l>J<0P07;U@60?3VS0801biD00<0l>J<00L^
E007;U@05P3`iX`300L^E080l>J<0P07;U@60?3VS0<01biD3@3`iX`200L^E0030?3VS007;U@01biD
00P0l>J<0P07;U@60?3VS00400L^E03`iX`0l>J<0?3VS0801biD00<0oooo00L^E007;U@00P07;U@X
0?3VS0<01biD00<0oooo00L^E03`iX`00P3`iX`200L^E0H0l>J<00<01biD0?3VS03`iX`01`3`iX`0
0`07;U@0l>J<0?3VS00200L^E0d0l>J<0`07;U@70?3VS00300L^E03`iX`0l>J<00801biD5P3`iX`3
00L^E0030?3VS007;U@01biD00H0l>J<0P07;U@<0?3VS0801biD1@3`iX`00`07;U@0oooo0?ooo`07
0?ooo`00203oool00`07;U@0l>J<0?3VS0020?3VS0801biD3P3`iX`00`07;U@0l>J<0?3VS0040?3V
S0<01biD6P3`iX`400L^E0L0l>J<0P07;U@?0?3VS0<01biD2P3`iX`00`07;U@0l>J<0?3VS0040?3V
S0801biD0P3`iX`300L^E2l0l>J<0`07;U@20?3VS0801biD1P3`iX`00`07;U@0l>J<0?3VS0080?3V
S0<01biD3`3`iX`200L^E0L0l>J<0`07;U@K0?3VS0<01biD1P3`iX`200L^E0d0l>J<00<01biD0?3V
S03`iX`00P3`iX`00`07;U@0oooo0?ooo`080?ooo`002@3oool01@07;U@0l>J<0?3VS03`iX`01biD
00l0l>J<0P07;U@40?3VS0<01biD7@3`iX`200L^E0L0l>J<00<01biD0?3VS03`iX`03`3`iX`200L^
E0X0l>J<0P07;U@40?3VS00300L^E03oool01biD00<01biD<`3`iX`400L^E0030?ooo`07;U@0l>J<
00<0l>J<0P07;U@:0?3VS0801biD4@3`iX`00`07;U@0l>J<0?3VS0050?3VS0801biD7@3`iX`300L^
E0@0l>J<0P07;U@>0?3VS0801biD0`3`iX`00`07;U@0oooo0?ooo`080?ooo`002P3oool400L^E100
l>J<0P07;U@20?3VS0801biD803`iX`200L^E0D0l>J<0P07;U@A0?3VS0801biD2P3`iX`300L^E0<0
l>J<0P07;U@k0?3VS0801biD0`3`iX`300L^E0X0l>J<00<01biD0?3VS03`iX`0403`iX`200L^E0D0
l>J<0P07;U@P0?3VS00400L^E03`iX`0l>J<0?3VS0801biD403`iX`400L^E0/0oooo000:0?ooo`04
00L^E03`iX`0l>J<00L^E100l>J<1@07;U@R0?3VS0801biD0`3`iX`200L^E1<0l>J<00<01biD0?3V
S03`iX`0203`iX`00`07;U@0l>J<00L^E00300L^E3l0l>J<1007;U@00`3`iX`01biD0?3VS0090?3V
S00300L^E03`iX`0l>J<0140l>J<0P07;U@30?3VS0801biD8P3`iX`500L^E100l>J<00@01biD0?3V
S03`iX`01biD2`3oool000/0oooo0`07;U@@0?3VS00400L^E03`iX`01biD00L^E2D0l>J<1@07;U@C
0?3VS00300L^E03`iX`0l>J<00P0l>J<1@07;UA20?3VS0@01biD2P3`iX`00`07;U@0l>J<0?3VS00A
0?3VS0H01biD903`iX`200L^E0030?3VS007;U@0l>J<00l0l>J<0`07;U@<0?ooo`002`3oool300L^
E100l>J<0`07;U@V0?3VS0801biD0P3`iX`00`07;U@0l>J<0?3VS00B0?3VS0801biD1`3`iX`01007
;U@0oooo00L^E007;UA50?3VS0801biD00<0oooo00L^E03`iX`01`3`iX`00`07;U@0l>J<0?3VS00B
0?3VS00300L^E03`iX`0l>J<00801biD9P3`iX`300L^E100l>J<0`07;U@<0?ooo`003@3oool00`07
;U@0l>J<0?3VS00>0?3VS0801biD:03`iX`400L^E1@0l>J<0P07;U@70?3VS0801biDB@3`iX`300L^
E0H0l>J<0P07;U@D0?3VS0@01biD:03`iX`200L^E100l>J<00<01biD0?ooo`3oool0303oool000d0
oooo00<01biD0?3VS03`iX`03@3`iX`200L^E2X0l>J<0`07;U@D0?3VS0T01biDC@3`iX`900L^E1@0
l>J<0`07;U@Z0?3VS00300L^E03`iX`0l>J<00h0l>J<00<01biD0?ooo`3oool0303oool000d0oooo
00<01biD0?3VS03`iX`03@3`iX`200L^E2/0l>J<0P07;U@D0?3VS00300L^E03`iX`0l>J<00<01biD
DP3`iX`400L^E080l>J<00<01biD0?3VS03`iX`04P3`iX`200L^E2/0l>J<00<01biD0?3VS03`iX`0
3P3`iX`00`07;U@0oooo0?ooo`0<0?ooo`003P3oool00`07;U@0l>J<0?3VS00<0?3VS00300L^E03`
iX`0l>J<02/0l>J<00<01biD0?3VS03`iX`04P3`iX`00`07;U@0l>J<0?3VS00200L^E5@0l>J<0`07
;U@20?3VS00300L^E03`iX`0l>J<0180l>J<0P07;U@/0?3VS00300L^E03`iX`0l>J<00`0l>J<00<0
1biD0?ooo`3oool03@3oool000h0oooo00<01biD0?3VS03`iX`02`3`iX`00`07;U@0l>J<0?3VS00/
0?3VS00300L^E03`iX`0l>J<0140l>J<1@07;UAG0?3VS0D01biD4`3`iX`00`07;U@0l>J<0?3VS00[
0?3VS00300L^E03`iX`0l>J<00`0l>J<00<01biD0?ooo`3oool03@3oool000l0oooo00<01biD0?3V
S03`iX`02P3`iX`00`07;U@0l>J<0?3VS00/0?3VS00300L^E03`iX`0l>J<0140l>J<1007;UAJ0?3V
S0<01biD4`3`iX`00`07;U@0l>J<0?3VS00[0?3VS0801biD303`iX`00`07;U@0oooo0?ooo`0>0?oo
o`00403oool200L^E0P0l>J<0P07;U@`0?3VS00300L^E03`iX`0l>J<00l0l>J<0`07;UAM0?3VS0<0
1biD4@3`iX`00`07;U@0l>J<0?3VS00]0?3VS0<01biD203`iX`200L^E140oooo000@0?ooo``01biD
<03`iX`00`07;U@0l>J<0?3VS00>0?3VS0801biDH@3`iX`00`07;U@0l>J<0?3VS00>0?3VS00300L^
E03`iX`0l>J<02h0l>J<3@07;U@A0?ooo`004@3oool00`07;U@0l>J<0?3VS00200L^E080l>J<1007
;U@a0?3VS0801biD3P3`iX`00`07;U@0l>J<0?3VS01Q0?3VS00300L^E03`iX`0l>J<00`0l>J<0P07
;U@a0?3VS00400L^E03`iX`01biD00L^E080l>J<0P07;U@20?3VS00300L^E03oool0oooo0100oooo
000A0?ooo`0400L^E03`iX`01biD00L^E0@0l>J<0P07;U@b0?3VS0<01biD2`3`iX`200L^E6D0l>J<
0P07;U@;0?3VS0<01biD<@3`iX`300L^E0@0l>J<0P07;U@00`3`iX`01biD0?ooo`0A0?ooo`004P3o
ool200L^E0D0l>J<0P07;U@b0?3VS00300L^E03`iX`0l>J<00801biD1`3`iX`300L^E6L0l>J<0P07
;U@80?3VS0801biD00<0l>J<00L^E007;U@0<P3`iX`00`07;U@0l>J<0?3VS0030?3VS0<01biD4`3o
ool00180oooo0P07;U@60?3VS00300L^E03`iX`0l>J<0340l>J<00<01biD0?3VS007;U@02P07;UAY
0?3VS0/01biD00<0l>J<00L^E03`iX`0<P3`iX`00`07;U@0l>J<0?3VS0040?3VS0801biD4`3oool0
01<0oooo00<01biD0?3VS03`iX`00`3`iX`200L^E3<0l>J<0P07;U@30?3VS0<01biD00<0l>J<00L^
E007;U@0K@3`iX`200L^E0030?3VS007;U@01biD00<0l>J<0`07;U@c0?3VS00300L^E03`iX`0l>J<
00<0l>J<00<01biD0?ooo`3oool04`3oool001@0oooo00@01biD0?3VS03`iX`0l>J<0`07;U@c0?3V
S00300L^E03`iX`0l>J<00<0l>J<0P07;U@00`3`iX`01biD0?3VS01^0?3VS00300L^E03`iX`01biD
00D0l>J<0P07;U@c0?3VS0<01biD0`3`iX`00`07;U@0oooo0?ooo`0C0?ooo`005@3oool600L^E3<0
l>J<00<01biD0?3VS03`iX`0103`iX`200L^E740l>J<0P07;U@60?3VS00300L^E03`iX`0l>J<0340
l>J<1P07;U@F0?ooo`005@3oool300L^E0030?3VS007;U@0l>J<03<0l>J<00<01biD0?3VS03`iX`0
0`3`iX`200L^E7<0l>J<00<01biD0?3VS03`iX`00`3`iX`200L^E3<0l>J<0`07;U@00`3`iX`01biD
00L^E00F0?ooo`005@3oool200L^E080l>J<00<01biD0?3VS03`iX`0<P3`iX`200L^E0<0l>J<0P07
;UAe0?3VS00400L^E03`iX`0l>J<0?3VS0<01biD=03`iX`00`07;U@0l>J<0?3VS00200L^E1H0oooo
000F0?ooo`0400L^E03`iX`0l>J<00L^E3@0l>J<1P07;UAg0?3VS0H01biD=03`iX`01007;U@0l>J<
0?3VS007;U@G0?ooo`005P3oool400L^E3@0l>J<0P07;U@00`3`iX`01biD00L^E01i0?3VS0801biD
00<0l>J<00L^E007;U@0<`3`iX`500L^E1L0oooo000G0?ooo`0400L^E03`iX`0l>J<00L^E3<0l>J<
00<01biD0?3VS03`iX`00P07;UAi0?3VS0801biD0P3`iX`00`07;U@0l>J<0?3VS00a0?3VS00400L^
E03`iX`0l>J<00L^E1P0oooo000H0?ooo`<01biD<`3`iX`200L^E0030?3VS007;U@0l>J<07X0l>J<
00@01biD0?3VS007;U@01biD<`3`iX`300L^E1T0oooo000J0?ooo`0300L^E03`iX`0l>J<0340l>J<
0`07;UAm0?3VS0<01biD<`3`iX`00`07;U@0oooo0?ooo`0I0?ooo`006P3oool00`07;U@0l>J<0?3V
S00a0?3VS0801biDOP3`iX`400L^E380l>J<00<01biD0?ooo`3oool06@3oool001X0oooo00<01biD
0?3VS03`iX`0<03`iX`00`07;U@0oooo00L^E01o0?3VS00300L^E03oool01biD0340l>J<00<01biD
0?ooo`3oool06P3oool001X0oooo00<01biD0?3VS03`iX`0<03`iX`200L^E840l>J<0P07;U@a0?3V
S00300L^E03oool0oooo01X0oooo000K0?ooo`0300L^E03`iX`0l>J<02h0l>J<0P07;UB20?3VS080
1biD<03`iX`00`07;U@0oooo0?ooo`0K0?ooo`006`3oool00`07;U@0l>J<0?3VS00^0?3VS0801biD
P`3`iX`00`07;U@0l>J<0?3VS00^0?3VS00300L^E03oool0oooo01/0oooo000L0?ooo`0300L^E03`
iX`0l>J<02d0l>J<00<01biD0?3VS03`iX`0PP3`iX`200L^E2l0l>J<00<01biD0?ooo`3oool06`3o
ool001`0oooo00<01biD0?3VS03`iX`0;03`iX`200L^E8D0l>J<00<01biD0?3VS03`iX`0;03`iX`0
0`07;U@0oooo0?ooo`0L0?ooo`00703oool00`07;U@0l>J<0?3VS00/0?3VS00300L^E03`iX`0l>J<
08D0l>J<00<01biD0?3VS03`iX`0:`3`iX`00`07;U@0oooo0?ooo`0L0?ooo`007@3oool00`07;U@0
l>J<0?3VS00Z0?3VS00300L^E03`iX`0l>J<08H0l>J<0P07;U@[0?3VS00300L^E03oool0oooo01d0
oooo000N0?ooo`0300L^E03`iX`0l>J<02T0l>J<00<01biD0?3VS03`iX`0Q`3`iX`00`07;U@0l>J<
0?3VS00Y0?3VS00300L^E03oool0oooo01d0oooo000O0?ooo`0300L^E03`iX`0l>J<02L0l>J<00<0
1biD0?3VS03`iX`0R03`iX`200L^E2T0l>J<00<01biD0?ooo`3oool07P3oool001l0oooo00<01biD
0?3VS03`iX`09P3`iX`200L^E8/0l>J<0P07;U@W0?3VS00300L^E03oool0oooo01l0oooo000P0?oo
o`0300L^E03`iX`0l>J<02@0l>J<0P07;UB<0?3VS00300L^E03oool01biD02D0l>J<00<01biD0?oo
o`3oool0803oool00240oooo00<01biD0?3VS03`iX`08P3`iX`00`07;U@0oooo00L^E02=0?3VS003
00L^E03oool01biD02@0l>J<00<01biD0?ooo`3oool0803oool00280oooo00<01biD0?3VS03`iX`0
803`iX`300L^E8l0l>J<0`07;U@R0?3VS00300L^E03oool0oooo0240oooo000S0?ooo`801biD7`3`
iX`200L^E0030?3VS007;U@0l>J<08h0l>J<00@01biD0?3VS007;U@01biD7`3`iX`200L^E2@0oooo
000S0?ooo`0300L^E03`iX`01biD01`0l>J<0P07;U@00`3`iX`01biD00L^E02A0?3VS0801biD00<0
l>J<00L^E03`iX`0703`iX`00`07;U@0l>J<00L^E00T0?ooo`008`3oool00`07;U@0l>J<00L^E002
00L^E1T0l>J<0P07;U@30?3VS00300L^E03`iX`0l>J<08l0l>J<00@01biD0?3VS03`iX`0l>J<0P07
;U@I0?3VS0<01biD00<0l>J<00L^E03oool08`3oool002<0oooo0`07;U@0103`iX`01biD00L^E007
;U@D0?3VS0H01biD00<0l>J<00L^E03`iX`0TP3`iX`00`07;U@0l>J<00L^E00500L^E1@0l>J<0`07
;U@0103`iX`01biD00L^E007;U@T0?ooo`00903oool01007;U@0l>J<0?3VS03`iX`500L^E0l0l>J<
0`07;U@30?3VS0@01biDT`3`iX`300L^E0<0l>J<1007;U@@0?3VS0@01biD0`3`iX`00`07;U@0oooo
0?ooo`0S0?ooo`00903oool01007;U@0l>J<0?3VS03`iX`200L^E080l>J<1`07;U@50?3VS0@01biD
00<0l>J<00L^E007;U@0103`iX`300L^E9<0l>J<0P07;U@50?3VS0801biD00<0l>J<00L^E007;U@0
1007;U@40?3VS0H01biD0P3`iX`200L^E080l>J<00<01biD0?ooo`3oool0903oool002D0oooo1007
;U@50?3VS0801biD00<0l>J<00L^E007;U@01@07;U@01P3`iX`01biD00L^E007;U@0l>J<00L^E0H0
l>J<00<01biD0?3VS03`iX`0TP3`iX`200L^E0H0l>J<00<01biD0?3VS007;U@01007;U@00`3`iX`0
1biD00L^E00300L^E0030?3VS007;U@01biD00D0l>J<1007;U@V0?ooo`009@3oool300L^E0H0l>J<
0P07;U@00`3`iX`01biD00L^E0080?3VS0<01biD1P3`iX`00`07;U@0l>J<0?3VS02C0?3VS00300L^
E03`iX`0l>J<00@0l>J<0`07;U@70?3VS0<01biD00<0l>J<00L^E007;U@01@3`iX`400L^E2H0oooo
000V0?ooo`801biD1`3`iX`300L^E0/0l>J<0P07;U@40?3VS0801biDU@3`iX`200L^E0@0l>J<0P07
;U@;0?3VS0<01biD1`3`iX`200L^E2L0oooo000W0?ooo`0300L^E03`iX`0l>J<00@0l>J<0P07;U@>
0?3VS0<01biD00@0l>J<00L^E007;U@01biDU@3`iX`700L^E0h0l>J<00<01biD0?3VS03`iX`01@3`
iX`00`07;U@0oooo0?ooo`0V0?ooo`00:03oool00`07;U@0l>J<0?3VS0030?3VS00300L^E03`iX`0
l>J<00h0l>J<1@07;UBF0?3VS0<01biD00<0l>J<00L^E007;U@03`3`iX`200L^E0D0l>J<00<01biD
0?ooo`3oool09`3oool002P0oooo0P07;U@30?3VS00300L^E03`iX`0l>J<0100l>J<00@01biD0?3V
S03`iX`01biDU`3`iX`01007;U@0l>J<0?3VS007;U@A0?3VS0801biD0`3`iX`200L^E2T0oooo000Y
0?ooo`D01biD4P3`iX`300L^E9T0l>J<0P07;U@B0?3VS0H01biD:P3oool002T0oooo0P07;U@00`3`
iX`01biD00L^E00C0?3VS0801biDV@3`iX`200L^E1<0l>J<0P07;U@00`3`iX`01biD00L^E00Z0?oo
o`00:@3oool00`07;U@0l>J<0?3VS00200L^E1<0l>J<0P07;UBI0?3VS0801biD4`3`iX`200L^E080
l>J<00<01biD0?ooo`3oool0:03oool002X0oooo0`07;U@D0?3VS0801biDV@3`iX`200L^E1@0l>J<
0`07;U@[0?ooo`00:`3oool200L^E1@0l>J<0P07;UBI0?3VS0801biD503`iX`200L^E2`0oooo000[
0?ooo`801biD503`iX`00`07;U@0l>J<0?3VS02H0?3VS0801biD503`iX`200L^E2`0oooo000/0?oo
o`0300L^E03`iX`0l>J<0180l>J<00<01biD0?3VS03`iX`0V@3`iX`00`07;U@0l>J<0?3VS00B0?3V
S00300L^E03oool0oooo02/0oooo000/0?ooo`0300L^E03`iX`0l>J<0180l>J<00<01biD0?3VS03`
iX`0V@3`iX`00`07;U@0l>J<0?3VS00A0?3VS00300L^E03oool0oooo02`0oooo000]0?ooo`0300L^
E03`iX`0l>J<0140l>J<00<01biD0?3VS03`iX`0V@3`iX`00`07;U@0l>J<0?3VS00A0?3VS00300L^
E03oool0oooo02`0oooo000]0?ooo`0300L^E03`iX`0l>J<0100l>J<0P07;UBK0?3VS00300L^E03`
iX`0l>J<0100l>J<00<01biD0?ooo`3oool0;@3oool002h0oooo00<01biD0?3VS03`iX`03`3`iX`2
00L^E9/0l>J<0P07;U@A0?3VS00300L^E03oool0oooo02d0oooo000_0?ooo`0300L^E03`iX`0l>J<
00d0l>J<0P07;UBL0?3VS0<01biD3`3`iX`00`07;U@0oooo0?ooo`0^0?ooo`00<03oool00`07;U@0
l>J<0?3VS00:0?3VS0@01biDW@3`iX`300L^E0h0l>J<00<01biD0?ooo`3oool0;P3oool00340oooo
0P07;U@90?3VS0801biD0P3`iX`00`07;U@0l>J<0?3VS02K0?3VS00300L^E03`iX`0l>J<00801biD
2@3`iX`300L^E340oooo000a0?ooo`D01biD0`3`iX`500L^E080l>J<00<01biD0?3VS03`iX`0V`3`
iX`00`07;U@0l>J<0?3VS00500L^E0<0l>J<1@07;U@b0?ooo`00<@3oool300L^E0030?3VS007;U@0
1biD00@01biD00@0l>J<00L^E007;U@0l>J<0P07;UBM0?3VS0801biD00D0l>J<00L^E007;U@01biD
0?3VS00500L^E0040?3VS007;U@01biD00L^E380oooo000b0?ooo`0400L^E03`iX`0l>J<0?3VS0<0
1biD1@3`iX`300L^E9d0l>J<1007;U@50?3VS0801biD0`3`iX`00`07;U@0oooo0?ooo`0a0?ooo`00
<P3oool00`07;U@0l>J<0?3VS00200L^E0P0l>J<0P07;UBM0?3VS0801biD203`iX`200L^E080l>J<
00<01biD0?ooo`3oool0<@3oool003<0oooo0`07;U@:0?3VS00300L^E03`iX`0l>J<09/0l>J<0P07
;U@90?3VS0<01biD=03oool003<0oooo00<01biD0?3VS007;U@02P3`iX`00`07;U@0l>J<0?3VS02K
0?3VS00300L^E03`iX`0l>J<00P0l>J<00<01biD0?3VS007;U@0=03oool003@0oooo0P07;U@:0?3V
S00300L^E03`iX`0l>J<09/0l>J<00<01biD0?3VS03`iX`0203`iX`200L^E3D0oooo000e0?ooo`03
00L^E03`iX`0l>J<00P0l>J<00<01biD0?3VS03`iX`0V`3`iX`00`07;U@0l>J<0?3VS0080?3VS003
00L^E03oool0oooo03@0oooo000e0?ooo`0300L^E03`iX`0l>J<00P0l>J<00<01biD0?3VS03`iX`0
V`3`iX`00`07;U@0l>J<0?3VS0080?3VS00300L^E03oool0oooo03@0oooo000e0?ooo`0300L^E03`
iX`0l>J<00L0l>J<0P07;UBM0?3VS0801biD203`iX`00`07;U@0oooo0?ooo`0e0?ooo`00=P3oool0
0`07;U@0l>J<0?3VS0050?3VS0<01biDW@3`iX`300L^E0L0l>J<00<01biD0?ooo`3oool0=@3oool0
03L0oooo0`07;U@20?3VS0<01biD00<0l>J<00L^E03`iX`0W03`iX`00`07;U@0l>J<00L^E00200L^
E080l>J<0`07;U@h0?ooo`00>03oool00`07;U@0l>J<00L^E00200L^E080l>J<0P07;UBM0?3VS0<0
1biD0P3`iX`200L^E0030?3VS007;U@0oooo03P0oooo000h0?ooo`0300L^E03`iX`01biD00D0l>J<
00<01biD0?3VS03`iX`0V`3`iX`200L^E0@0l>J<00<01biD0?3VS007;U@0>@3oool003T0oooo0P07
;U@50?3VS00300L^E03`iX`0l>J<09/0l>J<00<01biD0?3VS03`iX`0103`iX`00`07;U@0oooo0?oo
o`0h0?ooo`00>@3oool00`07;U@0l>J<0?3VS0040?3VS00300L^E03`iX`0l>J<09X0l>J<0P07;U@6
0?3VS00300L^E03oool0oooo03P0oooo000i0?ooo`0300L^E03`iX`0l>J<00<0l>J<00<01biD0?oo
o`07;U@0V`3`iX`200L^E0D0l>J<00<01biD0?ooo`3oool0>@3oool003X0oooo0P07;U@30?3VS003
00L^E03oool01biD09/0l>J<0`07;U@30?3VS0801biD>`3oool003`0oooo1007;U@00`3oool01biD
0?3VS02J0?3VS00300L^E03oool01biD00<01biD?@3oool003d0oooo0P07;U@00`3`iX`01biD00L^
E02K0?3VS0801biD00<0l>J<00L^E007;U@0?P3oool003`0oooo00<01biD0?3VS03`iX`00P3`iX`0
0`07;U@0l>J<0?3VS02I0?3VS00400L^E03`iX`0l>J<0?3VS0801biD?@3oool003`0oooo00<01biD
0?3VS03`iX`00P3`iX`00`07;U@0l>J<0?3VS02H0?3VS0801biD0`3`iX`200L^E3d0oooo000m0?oo
o`0400L^E03`iX`0l>J<0?3VS0801biDV@3`iX`200L^E0<0l>J<00<01biD0?ooo`3oool0?03oool0
03h0oooo0`07;U@00`3oool01biD0?3VS02H0?3VS00300L^E03oool01biD00801biD?`3oool00480
oooo00<01biD0?3VS03`iX`0U`3`iX`00`07;U@0oooo0?ooo`110?ooo`00@P3oool00`07;U@0l>J<
0?3VS02G0?3VS00300L^E03oool0oooo0440oooo00120?ooo`0300L^E03`iX`0l>J<09H0l>J<00<0
1biD0?ooo`3oool0@P3oool004<0oooo00<01biD0?3VS03`iX`0U@3`iX`00`07;U@0oooo0?ooo`12
0?ooo`00@`3oool00`07;U@0l>J<0?3VS02D0?3VS00300L^E03oool0oooo04<0oooo00140?ooo`03
00L^E03`iX`0l>J<09<0l>J<00<01biD0?ooo`3oool0@`3oool004@0oooo00<01biD0?3VS03`iX`0
T`3`iX`00`07;U@0oooo0?ooo`130?ooo`00A03oool00`07;U@0l>J<0?3VS02C0?3VS00300L^E03o
ool0oooo04<0oooo00140?ooo`0300L^E03`iX`0l>J<0980l>J<00<01biD0?ooo`3oool0A03oool0
04D0oooo00<01biD0?3VS03`iX`0T@3`iX`00`07;U@0oooo0?ooo`140?ooo`00A@3oool00`07;U@0
l>J<0?3VS02A0?3VS00300L^E03oool0oooo04@0oooo00150?ooo`0300L^E03`iX`0l>J<0940l>J<
00<01biD0?ooo`3oool0A03oool004D0oooo00<01biD0?3VS03`iX`0T03`iX`00`07;U@0oooo0?oo
o`150?ooo`00AP3oool00`07;U@0l>J<0?3VS02?0?3VS00300L^E03oool0oooo04D0oooo00170?oo
o`0300L^E03`iX`0l>J<08d0l>J<00<01biD0?ooo`3oool0AP3oool004L0oooo00<01biD0?3VS03`
iX`0S03`iX`00`07;U@0oooo0?ooo`170?ooo`00B03oool00`07;U@0l>J<0?3VS02;0?3VS00300L^
E03oool0oooo04L0oooo00180?ooo`0300L^E03`iX`0l>J<08X0l>J<00<01biD0?ooo`3oool0B03o
ool004T0oooo00<01biD0?3VS03`iX`0R@3`iX`00`07;U@0oooo0?ooo`180?ooo`00B@3oool00`07
;U@0l>J<0?3VS0280?3VS00300L^E03oool0oooo04T0oooo001:0?ooo`0300L^E03`iX`0l>J<08L0
l>J<00<01biD0?ooo`3oool0B@3oool004/0oooo00<01biD0?3VS03`iX`0Q@3`iX`00`07;U@0oooo
0?ooo`1:0?ooo`00B`3oool00`07;U@0l>J<0?3VS0240?3VS00300L^E03oool0oooo04/0oooo001<
0?ooo`0300L^E03`iX`0l>J<08<0l>J<00<01biD0?ooo`3oool0B`3oool004`0oooo00<01biD0?3V
S03`iX`0PP3`iX`00`07;U@0oooo0?ooo`1<0?ooo`00C@3oool00`07;U@0l>J<0?3VS0210?3VS003
00L^E03oool0oooo04`0oooo001>0?ooo`0300L^E03`iX`0l>J<07l0l>J<00<01biD0?ooo`3oool0
C@3oool004h0oooo00<01biD0?3VS03`iX`0OP3`iX`00`07;U@0oooo0?ooo`1>0?ooo`00C`3oool0
0`07;U@0l>J<0?3VS01m0?3VS00300L^E03oool0oooo04h0oooo001?0?ooo`0300L^E03`iX`0l>J<
07`0l>J<00<01biD0?ooo`3oool0C`3oool00500oooo00<01biD0?3VS03`iX`0N`3`iX`00`07;U@0
oooo0?ooo`1?0?ooo`00D@3oool00`07;U@0l>J<0?3VS01i0?3VS00300L^E03oool0oooo0500oooo
001A0?ooo`0300L^E03`iX`0l>J<07P0l>J<00<01biD0?ooo`3oool0D@3oool00580oooo00<01biD
0?3VS03`iX`0M`3`iX`00`07;U@0oooo0?ooo`1A0?ooo`00D`3oool00`07;U@0l>J<0?3VS01e0?3V
S00300L^E03oool0oooo0580oooo001D0?ooo`0300L^E03`iX`0l>J<07<0l>J<00<01biD0?ooo`3o
ool0D`3oool005D0oooo00<01biD0?3VS03`iX`0L@3`iX`00`07;U@0oooo0?ooo`1D0?ooo`00EP3o
ool200L^E6l0l>J<0P07;UAG0?ooo`00F03oool00`07;U@0l>J<0?3VS01[0?3VS00300L^E03oool0
oooo05L0oooo001I0?ooo`0300L^E03`iX`0l>J<06T0l>J<00<01biD0?ooo`3oool0F03oool005X0
oooo00<01biD0?3VS03`iX`0I`3`iX`00`07;U@0oooo0?ooo`1I0?ooo`00F`3oool00`07;U@0l>J<
0?3VS01U0?3VS00300L^E03oool0oooo05X0oooo001I0?ooo`@01biDI@3`iX`300L^E5/0oooo001H
0?ooo`0400L^E03`iX`0l>J<0?3VS0801biDH`3`iX`01@07;U@0l>J<0?3VS03`iX`01biD05X0oooo
001H0?ooo`0300L^E03`iX`0l>J<0080l>J<0P07;UAQ0?3VS0801biD103`iX`00`07;U@0oooo0?oo
o`1G0?ooo`00F03oool01P07;U@0l>J<0?3VS03`iX`01biD0?ooo`801biDG`3`iX`300L^E0<0l>J<
00<01biD0?ooo`3oool0F03oool005T0oooo1@07;U@20?3VS0801biDF`3`iX`200L^E080l>J<1@07
;UAJ0?ooo`00F`3oool00`07;U@0l>J<0?3VS0030?3VS0801biDF@3`iX`00`07;U@0l>J<0?3VS003
0?3VS00300L^E03oool0oooo05/0oooo001K0?ooo`0300L^E03`iX`0l>J<00@0l>J<0`07;UAE0?3V
S0<01biD1P3`iX`00`07;U@0oooo0?ooo`1J0?ooo`00F`3oool00`07;U@0l>J<0?3VS0040?3VS003
00L^E03`iX`01biD00801biDD@3`iX`300L^E0030?3VS007;U@0l>J<00D0l>J<00<01biD0?ooo`3o
ool0FP3oool005`0oooo00<01biD0?3VS03`iX`00P3`iX`00`07;U@0oooo00L^E00400L^E4h0l>J<
2007;U@40?3VS00300L^E03oool0oooo05/0oooo001L0?ooo`0400L^E03`iX`0l>J<0?3VS0<01biD
1@3`iX`200L^E4/0l>J<0`07;U@50?3VS0801biD0`3`iX`00`07;U@0oooo0?ooo`1K0?ooo`00G@3o
ool400L^E0P0l>J<0`07;UA70?3VS0<01biD203`iX`400L^E5h0oooo001M0?ooo`0400L^E03`iX`0
1biD00L^E0P0l>J<1@07;UA30?3VS0@01biD2@3`iX`200L^E0030?3VS007;U@0oooo05d0oooo001M
0?ooo`<01biD2P3`iX`00`07;U@0l>J<0?3VS00300L^E3l0l>J<0P07;U@20?3VS0801biD2P3`iX`3
00L^E5h0oooo001O0?ooo`0300L^E03`iX`0l>J<00P0l>J<00H01biD0?3VS03`iX`0l>J<00L^E03`
iX`300L^E3T0l>J<0`07;U@00`3`iX`01biD0?3VS0020?3VS00300L^E03`iX`0l>J<00P0l>J<00<0
1biD0?ooo`3oool0GP3oool005l0oooo00<01biD0?3VS03`iX`0203`iX`;00L^E3D0l>J<2`07;U@:
0?3VS00300L^E03oool0oooo05h0oooo001O0?ooo`0300L^E03`iX`0l>J<00P0l>J<0`07;U@80?3V
S0@01biD;@3`iX`400L^E0L0l>J<1007;U@:0?3VS00300L^E03oool0oooo05h0oooo001P0?ooo`03
00L^E03`iX`0l>J<00H0l>J<0P07;U@;0?3VS0L01biD9@3`iX`600L^E0/0l>J<0P07;U@90?3VS003
00L^E03oool0oooo05l0oooo001Q0?ooo`0300L^E03`iX`0l>J<00D0l>J<00<01biD0?3VS03`iX`0
303`iX`300L^E0030?3VS007;U@01biD00801biD7`3`iX`800L^E0h0l>J<00<01biD0?3VS03`iX`0
1@3`iX`00`07;U@0oooo0?ooo`1P0?ooo`00HP3oool200L^E0@0l>J<00<01biD0?3VS03`iX`03P3`
iX`200L^E0030?3VS007;U@01biD0080l>J<1`07;U@A0?3VS0L01biD0P3`iX`200L^E080l>J<00<0
1biD0?3VS03`iX`03P3`iX`200L^E0@0l>J<00<01biD0?ooo`3oool0H@3oool00680oooo1P07;U@B
0?3VS0801biD1@3`iX`200L^E0040?3VS007;U@01biD0?3VS1401biD00@0l>J<00L^E03`iX`0l>J<
0P07;U@40?3VS0<01biD4P3`iX`600L^E6<0oooo001R0?ooo`801biD0P3`iX`200L^E180l>J<0P07
;U@60?3VS00300L^E03`iX`0l>J<00H01biD2P3`iX`500L^E080l>J<00<01biD0?3VS03`iX`0103`
iX`200L^E180l>J<0P07;U@0103`iX`01biD00L^E007;UAS0?ooo`00H`3oool01@07;U@0l>J<0?3V
S03`iX`01biD01<0l>J<00<01biD0?3VS03`iX`0103`iX`400L^E180l>J<1@07;U@60?3VS00300L^
E03`iX`0l>J<0140l>J<00D01biD0?3VS03`iX`0l>J<00L^E01T0?ooo`00H`3oool01007;U@0l>J<
0?3VS007;U@D0?3VS0801biD103`iX`300L^E1H0l>J<1007;U@40?3VS0801biD4`3`iX`200L^E080
l>J<00<01biD0?ooo`3oool0HP3oool006@0oooo0`07;U@D0?3VS0801biD0`3`iX`200L^E1X0l>J<
0`07;U@30?3VS0801biD503`iX`300L^E6D0oooo001T0?ooo`0300L^E03`iX`01biD01@0l>J<1P07
;U@M0?3VS0H01biD503`iX`300L^E6D0oooo001U0?ooo`801biD503`iX`00`07;U@0l>J<0?3VS002
00L^E1l0l>J<0P07;U@20?3VS00300L^E03`iX`0l>J<0180l>J<0P07;UAV0?ooo`00IP3oool00`07
;U@0l>J<0?3VS00B0?3VS0<01biD8P3`iX`400L^E1@0l>J<00<01biD0?ooo`3oool0I@3oool006H0
oooo00<01biD0?3VS03`iX`04@3`iX`300L^E2D0l>J<0P07;U@C0?3VS00300L^E03oool0oooo06H0
oooo001W0?ooo`0300L^E03`iX`0l>J<0100l>J<0P07;U@W0?3VS00300L^E03`iX`0l>J<0140l>J<
00<01biD0?ooo`3oool0IP3oool006L0oooo00<01biD0?3VS03`iX`03`3`iX`200L^E2P0l>J<00<0
1biD0?3VS03`iX`0403`iX`00`07;U@0oooo0?ooo`1W0?ooo`00J03oool00`07;U@0l>J<0?3VS00>
0?3VS0801biD:@3`iX`00`07;U@0l>J<0?3VS00?0?3VS00300L^E03oool0oooo06L0oooo001Y0?oo
o`0300L^E03`iX`0l>J<00`0l>J<0P07;U@[0?3VS0801biD3P3`iX`00`07;U@0oooo0?ooo`1X0?oo
o`00J@3oool00`07;U@0l>J<0?3VS00<0?3VS0801biD;03`iX`00`07;U@0l>J<0?3VS00<0?3VS003
00L^E03oool0oooo06P0oooo001Z0?ooo`801biD2P3`iX`300L^E2d0l>J<0`07;U@:0?3VS0801biD
J`3oool006X0oooo1007;U@60?3VS0@01biD;P3`iX`500L^E0H0l>J<0P07;U@00`3`iX`01biD0?oo
o`1Z0?ooo`00J`3oool200L^E0030?3VS007;U@01biD00D01biD0P3`iX`00`07;U@0l>J<0?3VS00]
0?3VS00300L^E03`iX`0l>J<00L01biD00<0l>J<00L^E007;U@0K03oool006/0oooo00<01biD0?3V
S03`iX`00`07;U@20?3VS0@01biD<03`iX`500L^E0<0l>J<0P07;U@20?3VS00300L^E03oool0oooo
06X0oooo001/0?ooo`<01biD1@3`iX`300L^E340l>J<0`07;U@50?3VS0<01biDK@3oool006`0oooo
0`07;U@60?3VS00300L^E03`iX`0l>J<0300l>J<0P07;U@60?3VS0<01biDK@3oool006d0oooo00<0
1biD0?3VS03`iX`01@3`iX`00`07;U@0l>J<0?3VS00a0?3VS00300L^E03`iX`0l>J<00D0l>J<00<0
1biD0?ooo`3oool0K03oool006h0oooo00<01biD0?3VS03`iX`0103`iX`00`07;U@0l>J<0?3VS00a
0?3VS00300L^E03`iX`0l>J<00@0l>J<00<01biD0?ooo`3oool0K@3oool006l0oooo00<01biD0?3V
S03`iX`00P3`iX`200L^E3<0l>J<0P07;U@50?3VS00300L^E03oool0oooo06d0oooo001`0?ooo`03
00L^E03`iX`0l>J<00<01biD<`3`iX`300L^E080l>J<0P07;UA`0?ooo`00L03oool600L^E3<0l>J<
1P07;UAa0?ooo`00L03oool200L^E080l>J<0P07;U@c0?3VS00400L^E03`iX`0l>J<0?3VS0801biD
L@3oool00740oooo00D01biD0?3VS03`iX`0l>J<00L^E00c0?3VS00500L^E03`iX`0l>J<0?3VS007
;U@0LP3oool00740oooo00<01biD0?3VS03`iX`00P07;U@c0?3VS0801biD0P3`iX`00`07;U@0oooo
0?ooo`1`0?ooo`00LP3oool400L^E3<0l>J<1007;UAc0?ooo`00LP3oool01007;U@0l>J<0?3VS007
;U@c0?3VS00400L^E03`iX`0l>J<00L^E7<0oooo001c0?ooo`<01biD<`3`iX`300L^E7@0oooo001e
0?ooo`0300L^E03`iX`0l>J<0340l>J<00<01biD0?ooo`3oool0M03oool007D0oooo00<01biD0?3V
S03`iX`0<@3`iX`00`07;U@0oooo0?ooo`1d0?ooo`00M@3oool00`07;U@0l>J<0?3VS00`0?3VS003
00L^E03oool0oooo07D0oooo001e0?ooo`0300L^E03`iX`0l>J<0300l>J<00<01biD0?ooo`3oool0
M@3oool007H0oooo00<01biD0?3VS03`iX`0;P3`iX`00`07;U@0oooo0?ooo`1f0?ooo`00MP3oool0
0`07;U@0l>J<0?3VS00^0?3VS00300L^E03oool0oooo07H0oooo001g0?ooo`0300L^E03`iX`0l>J<
02d0l>J<00<01biD0?ooo`3oool0MP3oool007L0oooo00<01biD0?3VS03`iX`0;03`iX`00`07;U@0
oooo0?ooo`1g0?ooo`00N03oool00`07;U@0l>J<0?3VS00[0?3VS00300L^E03oool0oooo07L0oooo
001i0?ooo`0300L^E03`iX`0l>J<02T0l>J<00<01biD0?ooo`3oool0N03oool007T0oooo00<01biD
0?3VS03`iX`0:@3`iX`00`07;U@0oooo0?ooo`1h0?ooo`00NP3oool00`07;U@0l>J<0?3VS00W0?3V
S00300L^E03oool0oooo07T0oooo001k0?ooo`0300L^E03`iX`0l>J<02D0l>J<00<01biD0?ooo`3o
ool0NP3oool007`0oooo00<01biD0?3VS03`iX`08`3`iX`00`07;U@0oooo0?ooo`1k0?ooo`00O@3o
ool00`07;U@0l>J<0?3VS00Q0?3VS00300L^E03oool0oooo07`0oooo001n0?ooo`0300L^E03`iX`0
l>J<01l0l>J<00<01biD0?ooo`3oool0O@3oool007l0oooo00<01biD0?3VS03`iX`07@3`iX`00`07
;U@0oooo0?ooo`1n0?ooo`00OP3oool00`07;U@0l>J<00L^E00L0?3VS0801biD00<0l>J<00L^E03o
ool0OP3oool007h0oooo00<01biD0?3VS007;U@00P07;U@I0?3VS0<01biD00<0l>J<00L^E03oool0
OP3oool007l0oooo00<01biD0?3VS03`iX`01007;U@D0?3VS0801biD0`3`iX`00`07;U@0oooo0?oo
o`1n0?ooo`00O`3oool01007;U@0l>J<0?3VS03`iX`500L^E100l>J<1007;U@30?3VS00300L^E03o
ool0oooo07h0oooo00200?ooo`0300L^E03`iX`01biD00801biD0P3`iX`600L^E0H0l>J<1P07;U@2
0?3VS0801biD00<0l>J<00L^E03oool0P03oool00800oooo0`07;U@50?3VS00300L^E03`iX`0l>J<
00T01biD0P3`iX`00`07;U@0l>J<0?3VS0030?3VS0<01biDP@3oool00800oooo0P07;U@60?3VS0@0
1biD1P3`iX`500L^E0H0l>J<0P07;UB10?ooo`00P@3oool00`07;U@0l>J<0?3VS0040?3VS0801biD
2P3`iX`300L^E0H0l>J<00<01biD0?ooo`3oool0P03oool00880oooo00<01biD0?3VS03`iX`00P3`
iX`200L^E0d0l>J<0P07;U@40?3VS00300L^E03oool0oooo0840oooo00220?ooo`801biD0`3`iX`2
00L^E0h0l>J<00@01biD0?3VS03`iX`0l>J<0P07;UB30?ooo`00P`3oool500L^E0l0l>J<1@07;UB4
0?ooo`00P`3oool200L^E0030?3VS007;U@0l>J<00l0l>J<0P07;U@00`3`iX`01biD00L^E0240?oo
o`00Q03oool00`07;U@0l>J<00L^E00A0?3VS0<01biDQ@3oool008D0oooo0P07;U@A0?3VS0801biD
QP3oool008D0oooo0P07;U@A0?3VS0801biDQP3oool008H0oooo00<01biD0?3VS03`iX`03`3`iX`0
0`07;U@0oooo0?ooo`250?ooo`00Q`3oool00`07;U@0l>J<0?3VS00=0?3VS00300L^E03oool0oooo
08H0oooo00280?ooo`0300L^E03`iX`0l>J<00`0l>J<00<01biD0?ooo`3oool0QP3oool008P0oooo
00<01biD0?3VS03`iX`02`3`iX`00`07;U@0oooo0?ooo`270?ooo`00R@3oool00`07;U@0l>J<0?3V
S00:0?3VS00300L^E03oool0oooo08L0oooo002:0?ooo`0300L^E03`iX`0l>J<00P0l>J<00<01biD
0?ooo`3oool0R03oool008X0oooo0P07;U@70?3VS0801biDR`3oool008X0oooo2`07;UB;0?ooo`00
RP3oool00`07;U@0l>J<0?3VS00200L^E0030?3VS007;U@01biD0080l>J<00<01biD0?ooo`3oool0
R@3oool008/0oooo0P07;U@40?3VS0<01biDS03oool008/0oooo0P07;U@50?3VS0801biDS03oool0
08`0oooo00<01biD0?3VS03`iX`00P3`iX`00`07;U@0oooo0?ooo`2<0?ooo`00S@3oool01@07;U@0
l>J<0?3VS03`iX`01biD08h0oooo002=0?ooo`D01biDSP3oool008h0oooo00<01biD0?3VS007;U@0
S`3oool008h0oooo0`07;UB?0?ooo`00S`3oool00`07;U@0oooo0?ooo`2>0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {248.5, 0}} -> {-0.0487624, -0.0432418, \
0.00730845, 0.00730845}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cir = 
        type[0, {0, 0}, {4. , 0}, {4. , 3. }, 
          5];\)\), "\[IndentingNewLine]", 
    \(shG[\({Peacock, Disk[First[#], Last[#]], Black, 
            Circle[First[#], Last[#]]} &\) /@ cir]\)}], "Input",
  CellLabel->"In[154]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77282 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.012183 0.247093 0.0184005 0.247093 [
[ 0 0 0 0 ]
[ 1 .77282 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.2 .63 .79 r
.7291 .26549 m
.7291 .26549 .24709 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.7291 .26549 .24709 0 365.73 arc
s
.2 .63 .79 r
.37291 .14676 m
.37291 .14676 .12836 0 365.73 arc
F
0 0 0 r
newpath
.37291 .14676 .12836 0 365.73 arc
s
.2 .63 .79 r
.18787 .08508 m
.18787 .08508 .06668 0 365.73 arc
F
0 0 0 r
newpath
.18787 .08508 .06668 0 365.73 arc
s
.2 .63 .79 r
.09174 .05304 m
.09174 .05304 .03464 0 365.73 arc
F
0 0 0 r
newpath
.09174 .05304 .03464 0 365.73 arc
s
.2 .63 .79 r
.04181 .0364 m
.04181 .0364 .018 0 365.73 arc
F
0 0 0 r
newpath
.04181 .0364 .018 0 365.73 arc
s
.2 .63 .79 r
.13201 .0301 m
.13201 .0301 .0117 0 365.73 arc
F
0 0 0 r
newpath
.13201 .0301 .0117 0 365.73 arc
s
.2 .63 .79 r
.11019 .09555 m
.11019 .09555 .0117 0 365.73 arc
F
0 0 0 r
newpath
.11019 .09555 .0117 0 365.73 arc
s
.2 .63 .79 r
.26537 .04092 m
.26537 .04092 .02252 0 365.73 arc
F
0 0 0 r
newpath
.26537 .04092 .02252 0 365.73 arc
s
.2 .63 .79 r
.29712 .02959 m
.29712 .02959 .01119 0 365.73 arc
F
0 0 0 r
newpath
.29712 .02959 .01119 0 365.73 arc
s
.2 .63 .79 r
.23689 .02741 m
.23689 .02741 .00901 0 365.73 arc
F
0 0 0 r
newpath
.23689 .02741 .00901 0 365.73 arc
s
.2 .63 .79 r
.26054 .07049 m
.26054 .07049 .00744 0 365.73 arc
F
0 0 0 r
newpath
.26054 .07049 .00744 0 365.73 arc
s
.2 .63 .79 r
.22338 .16692 m
.22338 .16692 .02252 0 365.73 arc
F
0 0 0 r
newpath
.22338 .16692 .02252 0 365.73 arc
s
.2 .63 .79 r
.24197 .19503 m
.24197 .19503 .01119 0 365.73 arc
F
0 0 0 r
newpath
.24197 .19503 .01119 0 365.73 arc
s
.2 .63 .79 r
.19248 .16064 m
.19248 .16064 .00901 0 365.73 arc
F
0 0 0 r
newpath
.19248 .16064 .00901 0 365.73 arc
s
.2 .63 .79 r
.23725 .14036 m
.23725 .14036 .00744 0 365.73 arc
F
0 0 0 r
newpath
.23725 .14036 .00744 0 365.73 arc
s
.2 .63 .79 r
.5221 .06175 m
.5221 .06175 .04335 0 365.73 arc
F
0 0 0 r
newpath
.5221 .06175 .04335 0 365.73 arc
s
.2 .63 .79 r
.58321 .03993 m
.58321 .03993 .02153 0 365.73 arc
F
0 0 0 r
newpath
.58321 .03993 .02153 0 365.73 arc
s
.2 .63 .79 r
.61646 .03124 m
.61646 .03124 .01284 0 365.73 arc
F
0 0 0 r
newpath
.61646 .03124 .01284 0 365.73 arc
s
.2 .63 .79 r
.55795 .02581 m
.55795 .02581 .00741 0 365.73 arc
F
0 0 0 r
newpath
.55795 .02581 .00741 0 365.73 arc
s
.2 .63 .79 r
.57207 .06599 m
.57207 .06599 .0068 0 365.73 arc
F
0 0 0 r
newpath
.57207 .06599 .0068 0 365.73 arc
s
.2 .63 .79 r
.46727 .03574 m
.46727 .03574 .01734 0 365.73 arc
F
0 0 0 r
newpath
.46727 .03574 .01734 0 365.73 arc
s
.2 .63 .79 r
.44191 .02767 m
.44191 .02767 .00927 0 365.73 arc
F
0 0 0 r
newpath
.44191 .02767 .00927 0 365.73 arc
s
.2 .63 .79 r
.48851 .02491 m
.48851 .02491 .00651 0 365.73 arc
F
0 0 0 r
newpath
.48851 .02491 .00651 0 365.73 arc
s
.2 .63 .79 r
.47325 .05794 m
.47325 .05794 .00565 0 365.73 arc
F
0 0 0 r
newpath
.47325 .05794 .00565 0 365.73 arc
s
.2 .63 .79 r
.5128 .11867 m
.5128 .11867 .01432 0 365.73 arc
F
0 0 0 r
newpath
.5128 .11867 .01432 0 365.73 arc
s
.2 .63 .79 r
.50821 .13963 m
.50821 .13963 .00713 0 365.73 arc
F
0 0 0 r
newpath
.50821 .13963 .00713 0 365.73 arc
s
.2 .63 .79 r
.53038 .10977 m
.53038 .10977 .00537 0 365.73 arc
F
0 0 0 r
newpath
.53038 .10977 .00537 0 365.73 arc
s
.2 .63 .79 r
.49949 .10457 m
.49949 .10457 .00507 0 365.73 arc
F
0 0 0 r
newpath
.49949 .10457 .00507 0 365.73 arc
s
.2 .63 .79 r
.44126 .30429 m
.44126 .30429 .04335 0 365.73 arc
F
0 0 0 r
newpath
.44126 .30429 .04335 0 365.73 arc
s
.2 .63 .79 r
.47705 .35841 m
.47705 .35841 .02153 0 365.73 arc
F
0 0 0 r
newpath
.47705 .35841 .02153 0 365.73 arc
s
.2 .63 .79 r
.49843 .38532 m
.49843 .38532 .01284 0 365.73 arc
F
0 0 0 r
newpath
.49843 .38532 .01284 0 365.73 arc
s
.2 .63 .79 r
.44837 .35455 m
.44837 .35455 .00741 0 365.73 arc
F
0 0 0 r
newpath
.44837 .35455 .00741 0 365.73 arc
s
.2 .63 .79 r
.48377 .33089 m
.48377 .33089 .0068 0 365.73 arc
F
0 0 0 r
newpath
.48377 .33089 .0068 0 365.73 arc
s
.2 .63 .79 r
.38178 .2922 m
.38178 .2922 .01734 0 365.73 arc
F
0 0 0 r
newpath
.38178 .2922 .01734 0 365.73 arc
s
.2 .63 .79 r
.35665 .28344 m
.35665 .28344 .00927 0 365.73 arc
F
0 0 0 r
newpath
.35665 .28344 .00927 0 365.73 arc
s
.2 .63 .79 r
.39228 .31361 m
.39228 .31361 .00651 0 365.73 arc
F
0 0 0 r
newpath
.39228 .31361 .00651 0 365.73 arc
s
.2 .63 .79 r
.39989 .27803 m
.39989 .27803 .00565 0 365.73 arc
F
0 0 0 r
newpath
.39989 .27803 .00565 0 365.73 arc
s
.2 .63 .79 r
.46797 .25317 m
.46797 .25317 .01432 0 365.73 arc
F
0 0 0 r
newpath
.46797 .25317 .01432 0 365.73 arc
s
.2 .63 .79 r
.47687 .23365 m
.47687 .23365 .00713 0 365.73 arc
F
0 0 0 r
newpath
.47687 .23365 .00713 0 365.73 arc
s
.2 .63 .79 r
.47669 .27084 m
.47669 .27084 .00537 0 365.73 arc
F
0 0 0 r
newpath
.47669 .27084 .00537 0 365.73 arc
s
.2 .63 .79 r
.44886 .25647 m
.44886 .25647 .00507 0 365.73 arc
F
0 0 0 r
newpath
.44886 .25647 .00507 0 365.73 arc
s
.2 .63 .79 r
.9338 .0608 m
.9338 .0608 .04239 0 365.73 arc
F
0 0 0 r
newpath
.9338 .0608 .04239 0 365.73 arc
s
.2 .63 .79 r
.96892 .02567 m
.96892 .02567 .00727 0 365.73 arc
F
0 0 0 r
newpath
.96892 .02567 .00727 0 365.73 arc
s
.2 .63 .79 r
.97494 .01965 m
.97494 .01965 .00125 0 365.73 arc
F
0 0 0 r
newpath
.97494 .01965 .00125 0 365.73 arc
s
.2 .63 .79 r
.97598 .01861 m
.97598 .01861 .00021 0 365.73 arc
F
0 0 0 r
newpath
.97598 .01861 .00021 0 365.73 arc
s
.2 .63 .79 r
.97318 .01902 m
.97318 .01902 .00062 0 365.73 arc
F
0 0 0 r
newpath
.97318 .01902 .00062 0 365.73 arc
s
.2 .63 .79 r
.97557 .02141 m
.97557 .02141 .00062 0 365.73 arc
F
0 0 0 r
newpath
.97557 .02141 .00062 0 365.73 arc
s
.2 .63 .79 r
.95863 .02204 m
.95863 .02204 .00364 0 365.73 arc
F
0 0 0 r
newpath
.95863 .02204 .00364 0 365.73 arc
s
.2 .63 .79 r
.953 .02058 m
.953 .02058 .00218 0 365.73 arc
F
0 0 0 r
newpath
.953 .02058 .00218 0 365.73 arc
s
.2 .63 .79 r
.96289 .01965 m
.96289 .01965 .00125 0 365.73 arc
F
0 0 0 r
newpath
.96289 .01965 .00125 0 365.73 arc
s
.2 .63 .79 r
.96053 .02643 m
.96053 .02643 .00115 0 365.73 arc
F
0 0 0 r
newpath
.96053 .02643 .00115 0 365.73 arc
s
.2 .63 .79 r
.97255 .03596 m
.97255 .03596 .00364 0 365.73 arc
F
0 0 0 r
newpath
.97255 .03596 .00364 0 365.73 arc
s
.2 .63 .79 r
.97401 .04159 m
.97401 .04159 .00218 0 365.73 arc
F
0 0 0 r
newpath
.97401 .04159 .00218 0 365.73 arc
s
.2 .63 .79 r
.97494 .0317 m
.97494 .0317 .00125 0 365.73 arc
F
0 0 0 r
newpath
.97494 .0317 .00125 0 365.73 arc
s
.2 .63 .79 r
.96816 .03406 m
.96816 .03406 .00115 0 365.73 arc
F
0 0 0 r
newpath
.96816 .03406 .00115 0 365.73 arc
s
.2 .63 .79 r
.87384 .0396 m
.87384 .0396 .0212 0 365.73 arc
F
0 0 0 r
newpath
.87384 .0396 .0212 0 365.73 arc
s
.2 .63 .79 r
.84105 .03108 m
.84105 .03108 .01268 0 365.73 arc
F
0 0 0 r
newpath
.84105 .03108 .01268 0 365.73 arc
s
.2 .63 .79 r
.82037 .02683 m
.82037 .02683 .00843 0 365.73 arc
F
0 0 0 r
newpath
.82037 .02683 .00843 0 365.73 arc
s
.2 .63 .79 r
.85535 .02243 m
.85535 .02243 .00403 0 365.73 arc
F
0 0 0 r
newpath
.85535 .02243 .00403 0 365.73 arc
s
.2 .63 .79 r
.84946 .04531 m
.84946 .04531 .00384 0 365.73 arc
F
0 0 0 r
newpath
.84946 .04531 .00384 0 365.73 arc
s
.2 .63 .79 r
.89868 .02567 m
.89868 .02567 .00727 0 365.73 arc
F
0 0 0 r
newpath
.89868 .02567 .00727 0 365.73 arc
s
.2 .63 .79 r
.90896 .02204 m
.90896 .02204 .00364 0 365.73 arc
F
0 0 0 r
newpath
.90896 .02204 .00364 0 365.73 arc
s
.2 .63 .79 r
.8895 .02129 m
.8895 .02129 .00289 0 365.73 arc
F
0 0 0 r
newpath
.8895 .02129 .00289 0 365.73 arc
s
.2 .63 .79 r
.89703 .03521 m
.89703 .03521 .0024 0 365.73 arc
F
0 0 0 r
newpath
.89703 .03521 .0024 0 365.73 arc
s
.2 .63 .79 r
.88491 .06519 m
.88491 .06519 .00668 0 365.73 arc
F
0 0 0 r
newpath
.88491 .06519 .00668 0 365.73 arc
s
.2 .63 .79 r
.89001 .07371 m
.89001 .07371 .00325 0 365.73 arc
F
0 0 0 r
newpath
.89001 .07371 .00325 0 365.73 arc
s
.2 .63 .79 r
.87577 .06336 m
.87577 .06336 .00264 0 365.73 arc
F
0 0 0 r
newpath
.87577 .06336 .00264 0 365.73 arc
s
.2 .63 .79 r
.88925 .05733 m
.88925 .05733 .00229 0 365.73 arc
F
0 0 0 r
newpath
.88925 .05733 .00229 0 365.73 arc
s
.2 .63 .79 r
.95499 .12075 m
.95499 .12075 .0212 0 365.73 arc
F
0 0 0 r
newpath
.95499 .12075 .0212 0 365.73 arc
s
.2 .63 .79 r
.96351 .15354 m
.96351 .15354 .01268 0 365.73 arc
F
0 0 0 r
newpath
.96351 .15354 .01268 0 365.73 arc
s
.2 .63 .79 r
.96776 .17422 m
.96776 .17422 .00843 0 365.73 arc
F
0 0 0 r
newpath
.96776 .17422 .00843 0 365.73 arc
s
.2 .63 .79 r
.97216 .13924 m
.97216 .13924 .00403 0 365.73 arc
F
0 0 0 r
newpath
.97216 .13924 .00403 0 365.73 arc
s
.2 .63 .79 r
.94928 .14513 m
.94928 .14513 .00384 0 365.73 arc
F
0 0 0 r
newpath
.94928 .14513 .00384 0 365.73 arc
s
.2 .63 .79 r
.96892 .09592 m
.96892 .09592 .00727 0 365.73 arc
F
0 0 0 r
newpath
.96892 .09592 .00727 0 365.73 arc
s
.2 .63 .79 r
.97255 .08563 m
.97255 .08563 .00364 0 365.73 arc
F
0 0 0 r
newpath
.97255 .08563 .00364 0 365.73 arc
s
.2 .63 .79 r
.9733 .10509 m
.9733 .10509 .00289 0 365.73 arc
F
0 0 0 r
newpath
.9733 .10509 .00289 0 365.73 arc
s
.2 .63 .79 r
.95938 .09756 m
.95938 .09756 .0024 0 365.73 arc
F
0 0 0 r
newpath
.95938 .09756 .0024 0 365.73 arc
s
.2 .63 .79 r
.92941 .10968 m
.92941 .10968 .00668 0 365.73 arc
F
0 0 0 r
newpath
.92941 .10968 .00668 0 365.73 arc
s
.2 .63 .79 r
.92088 .10458 m
.92088 .10458 .00325 0 365.73 arc
F
0 0 0 r
newpath
.92088 .10458 .00325 0 365.73 arc
s
.2 .63 .79 r
.93123 .11882 m
.93123 .11882 .00264 0 365.73 arc
F
0 0 0 r
newpath
.93123 .11882 .00264 0 365.73 arc
s
.2 .63 .79 r
.93726 .10534 m
.93726 .10534 .00229 0 365.73 arc
F
0 0 0 r
newpath
.93726 .10534 .00229 0 365.73 arc
s
.2 .63 .79 r
.88181 .57092 m
.88181 .57092 .09438 0 365.73 arc
F
0 0 0 r
newpath
.88181 .57092 .09438 0 365.73 arc
s
.2 .63 .79 r
.94014 .68758 m
.94014 .68758 .03605 0 365.73 arc
F
0 0 0 r
newpath
.94014 .68758 .03605 0 365.73 arc
s
.2 .63 .79 r
.96242 .73214 m
.96242 .73214 .01377 0 365.73 arc
F
0 0 0 r
newpath
.96242 .73214 .01377 0 365.73 arc
s
.2 .63 .79 r
.97093 .74916 m
.97093 .74916 .00526 0 365.73 arc
F
0 0 0 r
newpath
.97093 .74916 .00526 0 365.73 arc
s
.2 .63 .79 r
.9437 .72874 m
.9437 .72874 .00526 0 365.73 arc
F
0 0 0 r
newpath
.9437 .72874 .00526 0 365.73 arc
s
.2 .63 .79 r
.97093 .71512 m
.97093 .71512 .00526 0 365.73 arc
F
0 0 0 r
newpath
.97093 .71512 .00526 0 365.73 arc
s
.2 .63 .79 r
.89112 .67867 m
.89112 .67867 .01377 0 365.73 arc
F
0 0 0 r
newpath
.89112 .67867 .01377 0 365.73 arc
s
.2 .63 .79 r
.87124 .67196 m
.87124 .67196 .00721 0 365.73 arc
F
0 0 0 r
newpath
.87124 .67196 .00721 0 365.73 arc
s
.2 .63 .79 r
.89963 .69569 m
.89963 .69569 .00526 0 365.73 arc
F
0 0 0 r
newpath
.89963 .69569 .00526 0 365.73 arc
s
.2 .63 .79 r
.90519 .667 m
.90519 .667 .00451 0 365.73 arc
F
0 0 0 r
newpath
.90519 .667 .00451 0 365.73 arc
s
.2 .63 .79 r
.96242 .64302 m
.96242 .64302 .01377 0 365.73 arc
F
0 0 0 r
newpath
.96242 .64302 .01377 0 365.73 arc
s
.2 .63 .79 r
.96898 .62309 m
.96898 .62309 .00721 0 365.73 arc
F
0 0 0 r
newpath
.96898 .62309 .00721 0 365.73 arc
s
.2 .63 .79 r
.97093 .66004 m
.97093 .66004 .00526 0 365.73 arc
F
0 0 0 r
newpath
.97093 .66004 .00526 0 365.73 arc
s
.2 .63 .79 r
.94465 .64727 m
.94465 .64727 .00451 0 365.73 arc
F
0 0 0 r
newpath
.94465 .64727 .00451 0 365.73 arc
s
.2 .63 .79 r
.75348 .54759 m
.75348 .54759 .03605 0 365.73 arc
F
0 0 0 r
newpath
.75348 .54759 .03605 0 365.73 arc
s
.2 .63 .79 r
.70144 .53002 m
.70144 .53002 .01888 0 365.73 arc
F
0 0 0 r
newpath
.70144 .53002 .01888 0 365.73 arc
s
.2 .63 .79 r
.6734 .51811 m
.6734 .51811 .01159 0 365.73 arc
F
0 0 0 r
newpath
.6734 .51811 .01159 0 365.73 arc
s
.2 .63 .79 r
.71145 .55318 m
.71145 .55318 .00635 0 365.73 arc
F
0 0 0 r
newpath
.71145 .55318 .00635 0 365.73 arc
s
.2 .63 .79 r
.72333 .51842 m
.72333 .51842 .0059 0 365.73 arc
F
0 0 0 r
newpath
.72333 .51842 .0059 0 365.73 arc
s
.2 .63 .79 r
.77576 .59215 m
.77576 .59215 .01377 0 365.73 arc
F
0 0 0 r
newpath
.77576 .59215 .01377 0 365.73 arc
s
.2 .63 .79 r
.78777 .60935 m
.78777 .60935 .00721 0 365.73 arc
F
0 0 0 r
newpath
.78777 .60935 .00721 0 365.73 arc
s
.2 .63 .79 r
.75704 .58874 m
.75704 .58874 .00526 0 365.73 arc
F
0 0 0 r
newpath
.75704 .58874 .00526 0 365.73 arc
s
.2 .63 .79 r
.78302 .57537 m
.78302 .57537 .00451 0 365.73 arc
F
0 0 0 r
newpath
.78302 .57537 .00451 0 365.73 arc
s
.2 .63 .79 r
.79031 .51704 m
.79031 .51704 .0118 0 365.73 arc
F
0 0 0 r
newpath
.79031 .51704 .0118 0 365.73 arc
s
.2 .63 .79 r
.80472 .50686 m
.80472 .50686 .00585 0 365.73 arc
F
0 0 0 r
newpath
.80472 .50686 .00585 0 365.73 arc
s
.2 .63 .79 r
.77455 .51294 m
.77455 .51294 .00449 0 365.73 arc
F
0 0 0 r
newpath
.77455 .51294 .00449 0 365.73 arc
s
.2 .63 .79 r
.7909 .53296 m
.7909 .53296 .00413 0 365.73 arc
F
0 0 0 r
newpath
.7909 .53296 .00413 0 365.73 arc
s
.2 .63 .79 r
.94014 .45426 m
.94014 .45426 .03605 0 365.73 arc
F
0 0 0 r
newpath
.94014 .45426 .03605 0 365.73 arc
s
.2 .63 .79 r
.95731 .40208 m
.95731 .40208 .01888 0 365.73 arc
F
0 0 0 r
newpath
.95731 .40208 .01888 0 365.73 arc
s
.2 .63 .79 r
.9646 .37251 m
.9646 .37251 .01159 0 365.73 arc
F
0 0 0 r
newpath
.9646 .37251 .01159 0 365.73 arc
s
.2 .63 .79 r
.96984 .42399 m
.96984 .42399 .00635 0 365.73 arc
F
0 0 0 r
newpath
.96984 .42399 .00635 0 365.73 arc
s
.2 .63 .79 r
.9349 .41264 m
.9349 .41264 .0059 0 365.73 arc
F
0 0 0 r
newpath
.9349 .41264 .0059 0 365.73 arc
s
.2 .63 .79 r
.96242 .49882 m
.96242 .49882 .01377 0 365.73 arc
F
0 0 0 r
newpath
.96242 .49882 .01377 0 365.73 arc
s
.2 .63 .79 r
.96898 .51875 m
.96898 .51875 .00721 0 365.73 arc
F
0 0 0 r
newpath
.96898 .51875 .00721 0 365.73 arc
s
.2 .63 .79 r
.97093 .4818 m
.97093 .4818 .00526 0 365.73 arc
F
0 0 0 r
newpath
.97093 .4818 .00526 0 365.73 arc
s
.2 .63 .79 r
.94465 .49456 m
.94465 .49456 .00451 0 365.73 arc
F
0 0 0 r
newpath
.94465 .49456 .00451 0 365.73 arc
s
.2 .63 .79 r
.89361 .4654 m
.89361 .4654 .0118 0 365.73 arc
F
0 0 0 r
newpath
.89361 .4654 .0118 0 365.73 arc
s
.2 .63 .79 r
.87682 .47082 m
.87682 .47082 .00585 0 365.73 arc
F
0 0 0 r
newpath
.87682 .47082 .00585 0 365.73 arc
s
.2 .63 .79 r
.89979 .45032 m
.89979 .45032 .00449 0 365.73 arc
F
0 0 0 r
newpath
.89979 .45032 .00449 0 365.73 arc
s
.2 .63 .79 r
.90599 .47542 m
.90599 .47542 .00413 0 365.73 arc
F
0 0 0 r
newpath
.90599 .47542 .00413 0 365.73 arc
s
0 0 m
1 0 L
1 .77282 L
0 .77282 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[154]:=",
  ImageSize->{288, 222.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000gR000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`002P3oool3
000000`0oooo0`0000090?ooo`800000303oool5000000`0oooo00<000000?ooo`3oool01@3oool2
000000L0oooo00<000000?ooo`3oool03P3oool:000000l0oooo00<000000?ooo`3oool00P3oool3
000000D0oooo00<000000?ooo`3oool0103oool5000000P0oooo00<000000?ooo`3oool0103oool2
000000L0oooo0P00000I0?ooo``00000503oool00`000000oooo0?ooo`020?ooo`8000000`3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool2000000050?ooo`000000oooo0?ooo`0000001@3o
ool400000080oooo1@000000103oool000000000000000070?ooo`002@3oool010000000<j7:03>Q
bP0cXLX2000000P0oooo0P00000303>QbP<00000103oool200000080<j7:0P0000060?ooo`@00000
1@0cXLX4000000H0oooo0P0000000`0cXLX00000000000020?ooo`<000000P0cXLX2000000<0oooo
0P0000000`0cXLX000000000000:0?ooo`@000002P0cXLX4000000T0oooo0P0000000`0cXLX00000
0?ooo`02000000<0<j7:0P0000001@3oool000000000000cXLX0000000<0oooo0P00000503>QbP80
0000103oool20000000303>QbP000000oooo0080oooo0P00000203>QbP8000000`3oool200000080
<j7:00<000000?ooo`3oool03`3oool7000000`0<j7:1`00000;0?ooo`80000000<0<j7:00000000
00000P00000203>QbP<0000000<0<j7:0000003oool00P00000203>QbPD0000000H0<j7:00000000
0000<j7:0000003oool3000000@0<j7:100000001@0cXLX00000000000000000<j7:008000001`3o
ool000P0oooo00<0000003>QbP0cXLX0100cXLX2000000@0oooo0P00000803>QbP80000000<0oooo
0000000cXLX0100cXLX00`000000oooo0?ooo`030?ooo`030000000cXLX0<j7:00/0<j7:0`000002
0?ooo`030000000cXLX0<j7:0080<j7:0`00000703>QbP030000003oool0000000@0<j7:00<00000
0?ooo`3oool01@3oool300000180<j7:0`0000050?ooo`040000000cXLX0<j7:03>QbP8000001`0c
XLX2000000<0<j7:0`00000903>QbP80000000<0oooo0000000cXLX00P0cXLX4000000H0<j7:0P00
00000`3oool0000003>QbP0303>QbP030000003oool0oooo00T0oooo1@00000J03>QbPD000001@3o
ool00`000000<j7:03>QbP0203>QbP8000001@0cXLX010000000<j7:00000000000603>QbP800000
0`0cXLX4000000T0<j7:1000000303>QbP8000001`3oool000L0oooo00<0000003>QbP0cXLX01P0c
XLX00`000000oooo0?ooo`02000000`0<j7:0P00000603>QbP030000003oool0oooo008000004@0c
XLX3000000@0<j7:00<0000003>QbP0cXLX0200cXLX2000000D0<j7:00<000000?ooo`3oool01000
000H03>QbP@0000000<0oooo0000000cXLX00`0cXLX00`000000<j7:03>QbP0503>QbP8000000P0c
XLX2000000d0<j7:0P00000303>QbP8000002@0cXLX2000000D0<j7:00<000000?ooo`3oool01P3o
ool3000002@0<j7:100000000`3oool0000003>QbP0303>QbP030000000cXLX0<j7:00@0<j7:0P00
000903>QbP040000000cXLX0<j7:03>QbP8000003@0cXLX2000000<0<j7:0P0000070?ooo`001P3o
ool00`000000<j7:03>QbP0803>QbP8000003`0cXLX00`000000<j7:03>QbP0403>QbP<000005@0c
XLX010000000<j7:03>QbP0cXLX2000000X0<j7:0P00000503>QbP030000003oool000000200<j7:
0P00000303>QbP800000200cXLX300000140<j7:1000000;03>QbP030000000cXLX0<j7:00@0<j7:
00@000000?ooo`3oool0oooo1000000[03>QbP<000000`0cXLX00`000000<j7:03>QbP0403>QbP80
00002P0cXLX400000100<j7:1@0000070?ooo`001P3oool00`000000<j7:03>QbP0803>QbP030000
000cXLX0<j7:00l0<j7:00<0000003>QbP0cXLX00P0cXLX2000001P0<j7:1000000<03>QbP030000
000cXLX0<j7:0080<j7:0`00000R03>QbP040000000cXLX0<j7:03>QbP800000200cXLX2000001<0
<j7:00<000000?ooo`0000002`0cXLX00`000000<j7:03>QbP0403>QbP040000003oool0oooo0000
0380<j7:1000000503>QbP8000002`0cXLX300000180<j7:100000070?ooo`001P3oool00`000000
<j7:03>QbP0703>QbP8000004@0cXLX010000000<j7:03>QbP0cXLX2000001X0<j7:00<000000?oo
o`000000300cXLX2000000<0<j7:00<0000003>QbP0cXLX08`0cXLX3000000030?ooo`000000<j7:
00L0<j7:0P00000C03>QbP030000003oool0000000/0<j7:0P00000403>QbP@00000=@0cXLX40000
00<0<j7:0P00000;03>QbP8000004`0cXLX3000000P0oooo00070?ooo`030000000cXLX0<j7:00H0
<j7:00<0000003>QbP0cXLX0400cXLX5000001`0<j7:0P00000<03>QbP030000003oool000000080
0000:@0cXLX2000000P0<j7:00<0000003>QbP0cXLX04`0cXLX2000000/0<j7:00<000000?ooo`00
00000P0cXLX2000003/0<j7:1P00000;03>QbP030000000cXLX0<j7:01<0<j7:0`0000070?ooo`00
1`3oool00`000000<j7:03>QbP0503>QbP8000004P0cXLX010000000oooo0?ooo`00000M03>QbP03
0000003oool0000000/0<j7:0`00000/03>QbP030000000cXLX0<j7:00D0<j7:0P00000E03>QbP80
00002`0cXLX00`000000oooo0?ooo`02000003h0<j7:0`0000000`0cXLX0000003>QbP0:03>QbP03
0000000cXLX0<j7:01<0<j7:00<000000?ooo`3oool01`3oool000P0oooo00<0000003>QbP0cXLX0
100cXLX2000001<0<j7:0P00000O03>QbP8000002`0cXLX00`000000<j7:03>QbP0]03>QbP030000
000cXLX0<j7:00@0<j7:00<0000003>QbP0cXLX05@0cXLX00`000000<j7:03>QbP0903>QbP030000
003oool000000480<j7:1000000:03>QbP030000000cXLX0<j7:01@0<j7:00<000000?ooo`3oool0
1P3oool000T0oooo0P00000303>QbP030000003oool0000001<0<j7:00<0000003>QbP0cXLX07`0c
XLX00`000000<j7:03>QbP0803>QbP030000000cXLX0<j7:02l0<j7:1`00000G03>QbP8000002@0c
XLX3000004D0<j7:00<000000?ooo`000000200cXLX2000001H0<j7:00<000000?ooo`3oool01P3o
ool000/0oooo0`0000020?ooo`030000000cXLX0<j7:0140<j7:00<0000003>QbP0cXLX07`0cXLX2
000000P0<j7:0P00000b03>QbP040000003oool0000003>QbP800000600cXLX00`000000<j7:03>Q
bP0603>QbP800000B00cXLX3000000H0<j7:0P00000G03>QbP030000003oool0oooo00H0oooo000@
0?ooo`030000000cXLX0<j7:0140<j7:00<0000003>QbP0cXLX0800cXLX2000000H0<j7:0P00000d
03>QbP8000000P0cXLX00`000000<j7:03>QbP0F03>QbP@000000`0cXLX2000004`0<j7:2@00000G
03>QbP8000001`3oool00100oooo00<0000003>QbP0cXLX0400cXLX200000280<j7:00<000000?oo
o`0000001P00000f03>QbP@00000600cXLX00`000000<j7:03>QbP05000004h0<j7:1000000303>Q
bP030000000cXLX0<j7:01D0<j7:0P0000070?ooo`004@3oool00`000000<j7:03>QbP0?03>QbP03
0000000cXLX0<j7:0280<j7:0`000000100cXLX000000?ooo`00000i03>QbP800000600cXLX01000
0000<j7:03>QbP0cXLX200000580<j7:0P00000303>QbP030000000cXLX0<j7:01D0<j7:00<00000
0?ooo`3oool01P3oool00140oooo00<0000003>QbP0cXLX03P0cXLX2000002@0<j7:00@0000003>Q
bP0cXLX0<j7:0P00000j03>QbP800000600cXLX00`000000<j7:03>QbP02000005@0<j7:0P000000
100cXLX0000000000000000F03>QbP030000003oool0oooo00H0oooo000B0?ooo`030000000cXLX0
<j7:00d0<j7:0P00000T03>QbP050000000cXLX0<j7:03>QbP000000?00cXLX2000001H0<j7:00<0
00000?ooo`0000000P00001G03>QbP80000000<0<j7:0000000cXLX05@0cXLX00`000000oooo0?oo
o`060?ooo`004`3oool00`000000<j7:03>QbP0;03>QbP8000009P0cXLX4000003`0<j7:0P00000F
03>QbP040000003oool00000000005T0<j7:0`00000F03>QbP030000003oool0oooo00H0oooo000D
0?ooo`030000000cXLX0<j7:00P0<j7:0P0000000`3oool0000003>QbP0U03>QbP030000003oool0
000003h0<j7:00<0000003>QbP0cXLX0500cXLX2000005d0<j7:00<0000003>QbP0cXLX04`0cXLX2
000000P0oooo000E0?ooo`8000001`0cXLX3000000030?ooo`000000<j7:02D0<j7:0P00001003>Q
bP030000000cXLX0<j7:0180<j7:0P00001O03>QbP030000000cXLX0<j7:0140<j7:100000070?oo
o`005`3oool800000080<j7:0P00000V03>QbP030000000cXLX0<j7:03l0<j7:00<0000003>QbP0c
XLX04P0cXLX00`000000<j7:03>QbP1N03>QbP030000000cXLX0<j7:0100<j7:00<000000?ooo`00
00000P0000070?ooo`00703oool00`000000<j7:03>QbP0303>QbP030000000cXLX0<j7:02@0<j7:
00<0000003>QbP0cXLX0@00cXLX00`000000<j7:03>QbP0@03>QbP030000000cXLX0<j7:0600<j7:
00<0000003>QbP0cXLX03`0cXLX4000000P0oooo000L0?ooo`030000000cXLX0<j7:00@0<j7:00<0
000003>QbP0cXLX08P0cXLX200000480<j7:0P00000@03>QbP030000000cXLX0<j7:0680<j7:0P00
000=03>QbP8000000`0cXLX2000000L0oooo000L0?ooo`030000000cXLX0<j7:00@0<j7:00<00000
03>QbP0cXLX08P0cXLX200000480<j7:00@000000?ooo`0000000000300cXLX2000006L0<j7:0`00
000:03>QbP8000000`0cXLX2000000L0oooo000M0?ooo`030000000cXLX0<j7:0080<j7:0P00000T
03>QbP030000000cXLX0<j7:0480<j7:0P0000000`0cXLX000000000000703>QbP@00000J@0cXLX5
0000000303>QbP000000000000@0000000@0<j7:000000000000<j7:0P0000080?ooo`007@3oool0
10000000<j7:03>QbP0cXLX3000002@0<j7:00<0000003>QbP0cXLX0@P0cXLX01@000000<j7:03>Q
bP000000oooo00P0000000<0oooo0000000cXLX0J@0cXLX20000000303>QbP000000<j7:00@00000
1P0cXLX4000000L0oooo000N0?ooo`<000000`3oool00`000000<j7:03>QbP0P03>QbP030000000c
XLX0<j7:04@0<j7:1000000303>QbP8000000P0cXLX2000006`0<j7:0P00000303>QbP800000200c
XLX2000000P0oooo000T0?ooo`030000000cXLX0<j7:0200<j7:00<0000003>QbP0cXLX0A00cXLX0
0`000000oooo0000000503>QbP80000000<0<j7:0000000cXLX0K@0cXLX00`000000<j7:03>QbP02
000000T0<j7:00<000000?ooo`3oool01`3oool002@0oooo00<0000003>QbP0cXLX07`0cXLX20000
04H0<j7:0P00000703>QbP<00000K`0cXLX3000000/0<j7:00<000000?ooo`3oool01P3oool002D0
oooo00<0000003>QbP0cXLX07@0cXLX2000004L0<j7:0P00000703>QbP030000000cXLX0<j7:0700
<j7:0P00000;03>QbP030000003oool0oooo00H0oooo000U0?ooo`030000000cXLX0<j7:01d0<j7:
0P00001803>QbP030000000cXLX0<j7:00D0<j7:00<0000003>QbP0cXLX0L00cXLX2000000/0<j7:
0P0000070?ooo`009P3oool00`000000<j7:03>QbP0K03>QbP030000003oool0000004P0<j7:0P00
000503>QbP030000000cXLX0<j7:0780<j7:0P00000:03>QbP030000003oool0oooo00H0oooo000W
0?ooo`8000006`0cXLX00`000000oooo0000001803>QbP<000000`0cXLX2000007D0<j7:00<00000
03>QbP0cXLX0200cXLX00`000000oooo0?ooo`060?ooo`00:@3oool00`000000<j7:03>QbP0G03>Q
bP80000000<0oooo0000000cXLX0A`0cXLX7000007H0<j7:00<0000003>QbP0cXLX01`0cXLX00`00
0000oooo0?ooo`070?ooo`00:@3oool00`000000<j7:03>QbP0E03>QbP<0000000<0<j7:00000000
0000B00cXLX010000000<j7:03>QbP0cXLX2000007P0<j7:00<0000003>QbP0cXLX01P0cXLX20000
00P0oooo000Z0?ooo`030000000cXLX0<j7:01<0<j7:00<000000?ooo`0000000`0cXLX00`000000
<j7:03>QbP1603>QbP050000000cXLX0<j7:03>QbP000000N@0cXLX400000080<j7:0`00000203>Q
bP030000003oool0oooo00D0oooo000[0?ooo`8000004@0cXLX500000080<j7:0P00001803>QbP80
00000P0cXLX00`000000<j7:03>QbP1h03>QbP80000000<0<j7:0000000000000P0cXLX3000000P0
oooo000]0?ooo`<000003@0cXLX300000080<j7:1@00001803>QbP040000003oool00000000007`0
<j7:00<0000003>QbP0000001@0cXLX00`000000oooo0?ooo`060?ooo`00<03oool=000000L0<j7:
00<000000?ooo`000000B00cXLX010000000oooo0?ooo`00001l03>QbP8000001P0cXLX00`000000
oooo0?ooo`060?ooo`00=@3oool20000000403>QbP0000000000000000X0<j7:0P00001803>QbP04
0000003oool0oooo000007d0<j7:00<0000003>QbP0cXLX01@0cXLX00`000000oooo0?ooo`050?oo
o`00=03oool00`000000<j7:03>QbP0203>QbP8000002P0cXLX2000004P0<j7:00<000000?ooo`00
0000OP0cXLX00`000000<j7:03>QbP0403>QbP030000003oool0oooo00H0oooo000d0?ooo`030000
000cXLX0<j7:0080<j7:00<0000003>QbP0cXLX02P0cXLX00`000000<j7:03>QbP1603>QbP800000
P00cXLX00`000000<j7:03>QbP0303>QbP030000003oool0oooo00H0oooo000d0?ooo`030000000c
XLX0<j7:0080<j7:00<0000003>QbP0cXLX02P0cXLX00`000000<j7:03>QbP1603>QbP800000P00c
XLX30000000303>QbP000000000000T0oooo000e0?ooo`050000000cXLX0<j7:03>QbP000000300c
XLX00`000000<j7:03>QbP1603>QbP030000000cXLX0<j7:07l0<j7:00D000000?ooo`3oool00000
03>QbP02000000P0oooo000f0?ooo`<0000000<0oooo0000000cXLX02P0cXLX00`000000<j7:03>Q
bP1603>QbP030000000cXLX0<j7:0800<j7:0P00000303>QbP030000003oool0oooo00H0oooo000j
0?ooo`030000000cXLX0<j7:00T0<j7:00<0000003>QbP0cXLX0A@0cXLX2000008<0<j7:00<00000
03>QbP0cXLX00P0cXLX00`000000oooo0?ooo`050?ooo`00>P3oool00`000000<j7:03>QbP0803>Q
bP030000003oool0000004H0<j7:00<0000003>QbP0cXLX0PP0cXLX01@000000<j7:03>QbP0cXLX0
000000P0oooo000k0?ooo`030000000cXLX0<j7:00H0<j7:00@000000?ooo`3oool00000AP0cXLX0
0`000000<j7:03>QbP2203>QbPD00000203oool003`0oooo00<0000003>QbP0cXLX0100cXLX30000
00030?ooo`000000<j7:04D0<j7:00<0000003>QbP0cXLX0PP0cXLX00`000000oooo0?ooo`0:0?oo
o`00?@3oool700000080<j7:0P00001503>QbP030000000cXLX0<j7:08@0<j7:00<000000?ooo`3o
ool02@3oool00480oooo00<0000003>QbP0cXLX00P0cXLX2000004@0<j7:00<0000003>QbP0cXLX0
Q00cXLX00`000000oooo0?ooo`090?ooo`00@P3oool00`000000<j7:03>QbP0303>QbP800000@P0c
XLX00`000000<j7:03>QbP2503>QbP030000003oool0oooo00T0oooo00120?ooo`030000000cXLX0
<j7:0080<j7:00<000000?ooo`000000@P0cXLX00`000000<j7:03>QbP2603>QbP030000003oool0
oooo00P0oooo00130?ooo`070000000cXLX0<j7:03>QbP000000oooo0000001203>QbP030000000c
XLX0<j7:08H0<j7:00<000000?ooo`3oool0203oool004@0oooo0`0000020?ooo`030000000cXLX0
<j7:03l0<j7:0P00002803>QbP030000003oool0oooo00P0oooo001:0?ooo`030000000cXLX0<j7:
03h0<j7:0P00002903>QbP030000003oool0oooo00L0oooo001;0?ooo`030000000cXLX0<j7:03`0
<j7:0P00002:03>QbP030000003oool0oooo00L0oooo001;0?ooo`030000000cXLX0<j7:03/0<j7:
00<000000?ooo`000000RP0cXLX00`000000oooo0?ooo`070?ooo`00C03oool00`000000<j7:03>Q
bP0j03>QbP030000003oool0000008X0<j7:00<000000?ooo`3oool01`3oool004d0oooo00<00000
03>QbP0cXLX0>00cXLX010000000oooo0?ooo`00002:03>QbP030000003oool0oooo00L0oooo001>
0?ooo`030000000cXLX0<j7:03H0<j7:0`0000000`3oool0000003>QbP2903>QbP030000003oool0
oooo00L0oooo001?0?ooo`030000000cXLX0<j7:03@0<j7:00D0000003>QbP0cXLX0<j7:0000002<
03>QbP030000003oool0oooo00H0oooo001@0?ooo`030000000cXLX0<j7:0380<j7:0P00000303>Q
bP030000000cXLX0<j7:08X0<j7:00<000000?ooo`3oool01P3oool00540oooo00<0000003>QbP0c
XLX0<00cXLX400000080<j7:00<0000003>QbP0cXLX0RP0cXLX00`000000oooo0?ooo`060?ooo`00
D@3oool00`000000<j7:03>QbP0_03>QbP8000000P0cXLX4000008`0<j7:00<000000?ooo`3oool0
1P3oool00580oooo00<0000003>QbP0cXLX0;P0cXLX00`000000<j7:03>QbP0303>QbP800000S00c
XLX00`000000oooo0?ooo`060?ooo`00D`3oool2000002d0<j7:00<0000003>QbP0cXLX01@0cXLX0
0`000000<j7:03>QbP2:03>QbP030000003oool0oooo00H0oooo001E0?ooo`030000000cXLX0<j7:
02L0<j7:1000000703>QbP030000000cXLX0<j7:08X0<j7:00<000000?ooo`3oool01P3oool005H0
oooo0P00000W03>QbP040000000cXLX00000000000L0<j7:00<0000003>QbP0cXLX0RP0cXLX00`00
0000oooo0?ooo`060?ooo`00F03oool00`000000<j7:03>QbP0R03>QbP<0000000@0<j7:00000000
000000001@0cXLX2000008`0<j7:00<000000?ooo`3oool01P3oool005T0oooo0P00000O03>QbPX0
00001@0cXLX2000008`0<j7:00<000000?ooo`3oool01P3oool005/0oooo0`00000J03>QbP800000
2@0cXLX30000000503>QbP00000000000?ooo`000000S@0cXLX00`000000oooo0?ooo`050?ooo`00
GP3oool4000001<0<j7:0`00000=03>QbP<0000000<0<j7:000000000000S00cXLX00`000000oooo
0?ooo`060?ooo`00HP3oool3000000`0<j7:100000000`3oool0000003>QbP0?03>QbP040000000c
XLX0<j7:000008`0<j7:00<000000?ooo`3oool01P3oool006@0oooo3P000000100cXLX000000000
0000000A03>QbP@00000S00cXLX00`000000oooo0?ooo`060?ooo`00H`3oool00`000000<j7:03>Q
bP0203>QbP040000003oool00000000000@0<j7:0P00000203>QbP030000000cXLX0<j7:0140<j7:
00<000000?ooo`000000S00cXLX00`000000oooo0?ooo`060?ooo`00H`3oool00`000000<j7:03>Q
bP0303>QbP030000000cXLX0<j7:00D0<j7:0`00000E03>QbP800000S00cXLX00`000000oooo0?oo
o`060?ooo`00H`3oool00`000000<j7:03>QbP0203>QbP800000200cXLX2000001D0<j7:0P00002<
03>QbP030000003oool0oooo00H0oooo001T0?ooo`050000000cXLX0<j7:03>QbP0000002@0cXLX0
0`000000<j7:03>QbP0E03>QbP030000000cXLX0<j7:08X0<j7:00<000000?ooo`3oool01P3oool0
06D0oooo1000000903>QbP030000000cXLX0<j7:01D0<j7:00<0000003>QbP0cXLX0RP0cXLX00`00
0000oooo0?ooo`060?ooo`00J03oool00`000000<j7:03>QbP0703>QbP030000000cXLX0<j7:01D0
<j7:00<0000003>QbP0cXLX0RP0cXLX00`000000oooo0?ooo`060?ooo`00J03oool00`000000<j7:
03>QbP0703>QbP030000000cXLX0<j7:01H0<j7:00<0000003>QbP0cXLX0R@0cXLX00`000000oooo
0?ooo`060?ooo`00J@3oool00`000000<j7:03>QbP0503>QbP800000600cXLX00`000000<j7:03>Q
bP2903>QbP030000003oool0oooo00H0oooo001Z0?ooo`8000000`0cXLX2000000030?ooo`000000
<j7:01L0<j7:00<0000003>QbP0cXLX0R00cXLX00`000000oooo0?ooo`070?ooo`00K03oool30000
0080<j7:0P00000G03>QbP800000RP0cXLX00`000000oooo0?ooo`070?ooo`00KP3oool01@000000
<j7:03>QbP0cXLX0000001L0<j7:0P00002:03>QbP030000003oool0oooo00L0oooo001_0?ooo`04
0000000cXLX00000000001L0<j7:0P00002:03>QbP030000003oool0oooo00L0oooo001`0?ooo`04
0000003oool0oooo000001H0<j7:00<000000?ooo`000000R@0cXLX00`000000oooo0?ooo`070?oo
o`00L`3oool00`000000<j7:03>QbP0C03>QbP80000000<0oooo0000000cXLX0Q`0cXLX00`000000
oooo0?ooo`080?ooo`00M03oool00`000000<j7:03>QbP0A03>QbP030000000cXLX0<j7:00800000
R00cXLX00`000000oooo0?ooo`080?ooo`00M03oool00`000000<j7:03>QbP0@03>QbP8000000`0c
XLX00`000000<j7:03>QbP2603>QbP030000003oool0oooo00P0oooo001e0?ooo`030000000cXLX0
<j7:00l0<j7:00<000000?ooo`0000000P0cXLX00`000000<j7:03>QbP2503>QbP030000003oool0
oooo00T0oooo001f0?ooo`8000003P0cXLX6000000030?ooo`000000<j7:08D0<j7:00<000000?oo
o`3oool02@3oool007P0oooo00<0000003>QbP0cXLX02@0cXLX2000000H0<j7:0P00002603>QbP03
0000003oool0oooo00T0oooo001i0?ooo`@000000`0cXLX4000000T0<j7:0P00002503>QbP030000
003oool0oooo00T0oooo001m0?ooo`<0000000@0<j7:00000000000000002@0cXLX2000008@0<j7:
00<000000?ooo`3oool02P3oool007h0oooo00D0000003>QbP0cXLX0<j7:0000000;03>QbP030000
000cXLX0<j7:0880<j7:00<000000?ooo`3oool02P3oool007h0oooo00D0000003>QbP0cXLX0<j7:
0000000;03>QbP800000P`0cXLX00`000000oooo0?ooo`0:0?ooo`00O`3oool010000000<j7:03>Q
bP00000<03>QbP030000000cXLX0<j7:0800<j7:00<000000?ooo`0000002`3oool00800oooo0P00
00000`3oool0000003>QbP0903>QbP800000PP0cXLX20000000303>QbP000000000000T0oooo0023
0?ooo`030000000cXLX0<j7:00P0<j7:00<000000?ooo`000000P00cXLX2000000@0<j7:00<00000
0?ooo`3oool01P3oool008<0oooo00<0000003>QbP0cXLX01`0cXLX010000000oooo0?ooo`000020
03>QbP030000000cXLX0<j7:00<0<j7:00<000000?ooo`3oool01P3oool008@0oooo00<0000003>Q
bP0cXLX01P0cXLX3000000030?ooo`000000<j7:07h0<j7:00<0000003>QbP0cXLX0100cXLX00`00
0000oooo0?ooo`050?ooo`00Q@3oool2000000<0<j7:1000000203>QbP<00000O@0cXLX2000000D0
<j7:00<000000?ooo`3oool01P3oool008L0oooo0`0000000`3oool0000003>QbP0403>QbP800000
O00cXLX010000000oooo0?ooo`00000303>QbP800000203oool008/0oooo00<0000003>QbP0cXLX0
100cXLX00`000000<j7:03>QbP1j03>QbPL000002P3oool008/0oooo00<0000003>QbP0cXLX0100c
XLX2000007X0<j7:0P00000503>QbP030000003oool0oooo00P0oooo002<0?ooo`030000000cXLX0
<j7:0080<j7:00<000000?ooo`000000N@0cXLX2000000L0<j7:00<000000?ooo`3oool01`3oool0
08`0oooo00@0000003>QbP0cXLX0<j7:0P0000020?ooo`030000000cXLX0<j7:07H0<j7:00<00000
03>QbP0cXLX01P0cXLX00`000000oooo0?ooo`070?ooo`00S@3oool3000000D0oooo00<0000003>Q
bP0cXLX0M00cXLX2000000T0<j7:00<000000?ooo`3oool01P3oool009D0oooo00<0000003>QbP0c
XLX0M00cXLX2000000T0<j7:0P0000070?ooo`00UP3oool00`000000<j7:03>QbP1b03>QbP030000
003oool0000000T0<j7:00<000000?ooo`3oool01P3oool009L0oooo00<0000003>QbP0cXLX0L00c
XLX4000000T0<j7:00<000000?ooo`3oool01P3oool009L0oooo00<0000003>QbP0cXLX0L00cXLX0
10000000<j7:03>QbP00000803>QbP030000003oool0oooo00L0oooo002H0?ooo`030000000cXLX0
<j7:06h0<j7:0P00000203>QbP8000001`0cXLX00`000000oooo0?ooo`070?ooo`00V@3oool00`00
0000<j7:03>QbP1/03>QbP030000003oool0000000H000000`0cXLX4000000P0oooo002I0?ooo`03
0000000cXLX0<j7:06`0<j7:0P00000703>QbP@000000P0cXLX2000000L0oooo002J0?ooo`030000
000cXLX0<j7:06T0<j7:0P00000;03>QbP8000000P0cXLX2000000L0oooo002K0?ooo`800000J00c
XLX00`000000<j7:03>QbP0<03>QbP@00000203oool009d0oooo00<0000003>QbP0cXLX0I@0cXLX0
0`000000<j7:03>QbP0=03>QbP030000003oool0oooo00P0oooo002N0?ooo`030000000cXLX0<j7:
06<0<j7:00<0000003>QbP0cXLX03`0cXLX00`000000oooo0?ooo`070?ooo`00WP3oool00`000000
<j7:03>QbP1R03>QbP8000004@0cXLX00`000000oooo0?ooo`070?ooo`00W`3oool00`000000<j7:
03>QbP1P03>QbP8000004`0cXLX00`000000oooo0?ooo`060?ooo`00X03oool2000005l0<j7:0`00
000C03>QbP030000003oool0oooo00H0oooo002R0?ooo`030000000cXLX0<j7:05/0<j7:00@00000
03>QbP0cXLX000004`0cXLX00`000000oooo0?ooo`060?ooo`00X`3oool2000005T0<j7:1P00000C
03>QbP8000001`3oool00:D0oooo00<0000003>QbP0cXLX0E@0cXLX30000000403>QbP0000000000
000001<0<j7:00<000000?ooo`3oool01P3oool00:H0oooo00<0000003>QbP0cXLX0D`0cXLX20000
00@0<j7:0P00000C03>QbP030000003oool0oooo00H0oooo002V0?ooo`030000000cXLX0<j7:0580
<j7:0P00000603>QbP030000000cXLX0<j7:0140<j7:00<000000?ooo`3oool01P3oool00:L0oooo
00<0000003>QbP0cXLX0D00cXLX00`000000<j7:0000000603>QbP030000000cXLX0<j7:0140<j7:
00<000000?ooo`3oool01P3oool00:P0oooo0P00001>03>QbP8000000`0cXLX00`000000<j7:03>Q
bP0203>QbP<000004@0cXLX00`000000oooo0?ooo`070?ooo`00ZP3oool2000004X0<j7:0P000002
0?ooo`030000000cXLX00000008000000`0cXLX010000000<j7:03>QbP00000@03>QbP030000003o
ool0oooo00L0oooo002/0?ooo`800000AP0cXLXC000000h0<j7:0`0000080?ooo`00[P3oool20000
04<0<j7:0`00000=03>QbP@000003@0cXLX200000080<j7:00<000000?ooo`3oool01@3oool00;00
oooo00<0000003>QbP0cXLX0?P0cXLX2000001@0<j7:00<0000003>QbP0cXLX02@0cXLX300000003
03>QbP000000oooo00L0oooo002a0?ooo`800000?00cXLX2000001L0<j7:1000000303>QbP@00000
0`0cXLX2000000P0oooo002c0?ooo`<00000=P0cXLX3000001/0<j7:1P0000000`3oool0000003>Q
bP0403>QbP030000003oool0oooo00H0oooo002f0?ooo`800000<`0cXLX00`000000oooo0000000N
03>QbP8000000P0cXLX00`000000<j7:03>QbP0503>QbP030000003oool0oooo00D0oooo002h0?oo
o`<00000;00cXLX600000240<j7:0`00000703>QbP030000003oool0oooo00D0oooo002k0?ooo`<0
00009P0cXLX5000000030?ooo`000000<j7:02<0<j7:0P00000603>QbP030000003oool0oooo00H0
oooo002n0?ooo`H000006`0cXLX5000000040?ooo`000000<j7:03>QbP8000009P0cXLX2000000D0
<j7:00<000000?ooo`3oool01P3oool00;l0oooo0P0000000`0cXLX0000000000006000000l0<j7:
2@00000203>QbP8000000P0cXLX00`000000<j7:03>QbP0V03>QbP040000000cXLX0<j7:03>QbP80
00002@3oool00;h0oooo00<0000003>QbP0cXLX00P0cXLX010000000oooo0?ooo`3oool200000003
03>QbP000000000000l0000000D0oooo0000000cXLX0<j7:0000000503>QbP<00000:P0cXLX60000
00P0oooo002m0?ooo`030000000cXLX0<j7:00@0<j7:0`00000503>QbP8000000P0cXLX010000000
oooo0?ooo`00000703>QbPD000001P0cXLX00`000000<j7:03>QbP0Z03>QbP050000000cXLX0<j7:
03>QbP000000203oool00;d0oooo00<0000003>QbP0cXLX0100cXLX00`000000<j7:03>QbP0603>Q
bP040000000cXLX0<j7:03>QbP8000002P0cXLX3000000H0<j7:00<0000003>QbP0cXLX0:P0cXLX0
0`000000<j7:03>QbP0203>QbP030000003oool0oooo00D0oooo002n0?ooo`030000000cXLX0<j7:
0080<j7:0P00000903>QbP<000003P0cXLX2000000@0<j7:00<0000003>QbP0cXLX0;00cXLX01000
0000<j7:03>QbP0000080?ooo`00_P3oool2000000<0<j7:00<0000003>QbP0cXLX0200cXLX20000
0100<j7:0P00000203>QbP800000;P0cXLX3000000T0oooo00300?ooo`@000002P0cXLX00`000000
<j7:03>QbP0@03>QbP@00000;`0cXLX00`000000oooo0?ooo`090?ooo`00``3oool00`000000<j7:
03>QbP0803>QbP030000000cXLX0<j7:0100<j7:00@0000003>QbP0cXLX00000<00cXLX00`000000
oooo0?ooo`080?ooo`00a03oool00`000000<j7:03>QbP0703>QbP030000000cXLX0<j7:0140<j7:
0P00000a03>QbP030000003oool0oooo00P0oooo00340?ooo`030000000cXLX0<j7:00H0<j7:00<0
000003>QbP0cXLX04P0cXLX200000380<j7:00<000000?ooo`3oool01`3oool00<D0oooo00<00000
03>QbP0cXLX01@0cXLX00`000000<j7:03>QbP0B03>QbP030000000cXLX0<j7:0340<j7:00<00000
0?ooo`3oool01`3oool00<H0oooo2000000D03>QbP030000000cXLX0<j7:0340<j7:00<000000?oo
o`3oool01`3oool00<X0oooo00@0000003>QbP0cXLX00000500cXLX00`000000<j7:03>QbP0b03>Q
bP030000003oool0oooo00H0oooo003:0?ooo`040000000cXLX0<j7:000001@0<j7:00<0000003>Q
bP0cXLX0<P0cXLX00`000000oooo0?ooo`060?ooo`00bP3oool500000180<j7:0P00000d03>QbP03
0000003oool0oooo00H0oooo003>0?ooo`030000000cXLX0<j7:0100<j7:00<0000003>QbP0cXLX0
<`0cXLX00`000000oooo0?ooo`060?ooo`00c`3oool00`000000<j7:03>QbP0>03>QbP800000=@0c
XLX00`000000oooo0?ooo`060?ooo`00c`3oool00`000000<j7:03>QbP0>03>QbP800000=P0cXLX0
0`000000oooo0?ooo`050?ooo`00d03oool00`000000<j7:03>QbP0<03>QbP<00000=P0cXLX00`00
0000oooo0?ooo`050?ooo`00d@3oool2000000/0<j7:0P0000000`0cXLX0000003>QbP0d03>QbP03
0000003oool0oooo00H0oooo003C0?ooo`030000000cXLX0<j7:00L0<j7:1@00000e03>QbP030000
003oool0oooo00H0oooo003D0?ooo`T000000`0cXLX3000003@0<j7:00<000000?ooo`3oool01P3o
ool00=P0oooo00@0000003>QbP00000000001@0cXLX2000003@0<j7:00<000000?ooo`3oool01P3o
ool00=L0oooo00@0000003>QbP0cXLX000001`0cXLX00`000000<j7:03>QbP0b03>QbP030000003o
ool0oooo00H0oooo003H0?ooo`<000001`0cXLX00`000000<j7:03>QbP0b03>QbP030000003oool0
oooo00H0oooo003J0?ooo`030000000cXLX0<j7:00D0<j7:00<0000003>QbP0cXLX0<@0cXLX00`00
0000oooo0?ooo`070?ooo`00f`3oool00`000000<j7:03>QbP0303>QbP030000003oool000000380
<j7:00<000000?ooo`3oool01`3oool00=`0oooo0P00000203>QbP@00000<@0cXLX00`000000oooo
0?ooo`080?ooo`00gP3oool2000000<0<j7:00<0000003>QbP0cXLX0;`0cXLX00`000000oooo0?oo
o`080?ooo`00g`3oool00`000000<j7:03>QbP0203>QbP030000000cXLX0<j7:02h0<j7:00<00000
0?ooo`3oool0203oool00>00oooo00<0000003>QbP0cXLX00P00000_03>QbP030000003oool0oooo
00T0oooo003Q0?ooo`8000000P3oool00`000000<j7:03>QbP0/03>QbP@00000203oool00>D0oooo
00<0000003>QbP0cXLX0:`0cXLX01@000000<j7:03>QbP0cXLX0000000P0oooo003V0?ooo`030000
000cXLX0<j7:02X0<j7:00<0000003>QbP0cXLX00P0cXLX00`000000oooo0?ooo`050?ooo`00i`3o
ool00`000000<j7:03>QbP0X03>QbP<000000P0cXLX00`000000oooo0?ooo`060?ooo`00j03oool0
0`000000<j7:03>QbP0V03>QbP8000000P0cXLX2000000T0oooo003Y0?ooo`030000000cXLX0<j7:
02@0<j7:0P00000503>QbP030000003oool0oooo00H0oooo003Z0?ooo`030000000cXLX0<j7:0280
<j7:0P00000603>QbP030000003oool0oooo00H0oooo003[0?ooo`030000000cXLX0<j7:0200<j7:
0`00000703>QbP030000003oool0oooo00D0oooo003/0?ooo`030000000cXLX0<j7:01h0<j7:1000
000603>QbP8000001`3oool00>d0oooo00<0000003>QbP0cXLX06`0cXLX2000000030?ooo`000000
0000008000001@0cXLX00`000000oooo0?ooo`060?ooo`00kP3oool2000001X0<j7:2000000303>Q
bP8000002@3oool00?00oooo0`00000E03>QbP8000001`0cXLX7000000P0oooo003c0?ooo`800000
4@0cXLX2000000/0<j7:0`00000203>QbP030000003oool0oooo00D0oooo003e0?ooo`H000001@0c
XLX6000000l0<j7:00<0000003>QbP000000203oool00?P0oooo2@0000000`3oool0000003>QbP02
000000l0<j7:0P0000090?ooo`00m`3oool01P000000<j7:03>QbP0cXLX000000?ooo`8000000P0c
XLX400000140<j7:00<000000?ooo`3oool01`3oool00?L0oooo00@0000003>QbP0cXLX0<j7:0P00
000503>QbP030000003oool000000140<j7:00<000000?ooo`3oool01`3oool00?P0oooo00@00000
03>QbP0cXLX000001`0cXLX00`000000<j7:03>QbP0A03>QbP030000003oool0oooo00H0oooo003i
0?ooo`<000001`0cXLX00`000000<j7:03>QbP0A03>QbP030000003oool0oooo00H0oooo003l0?oo
o`030000000cXLX0<j7:00<0<j7:0P00000C03>QbP030000003oool0oooo00H0oooo003l0?ooo`80
00000`0cXLX3000001<0<j7:0P0000070?ooo`00oP3oool6000001<0<j7:00<000000?ooo`3oool0
1P3oool00?l0oooo0@3oool010000000<j7:03>QbP00000C03>QbP030000003oool0oooo00H0oooo
003o0?ooo`40oooo00@0000003>QbP0cXLX000004`0cXLX00`000000oooo0?ooo`060?ooo`00o`3o
ool20?ooo`<000004`0cXLX00`000000oooo0?ooo`060?ooo`00o`3oool50?ooo`030000000cXLX0
<j7:00l0<j7:00<000000?ooo`3oool01`3oool00?l0oooo1P3oool00`000000<j7:03>QbP0>03>Q
bP030000003oool0oooo00L0oooo003o0?ooo`L0oooo00<0000003>QbP0cXLX02`0cXLX200000003
03>QbP000000oooo00L0oooo003o0?ooo`P0oooo00<0000003>QbP0cXLX02@0cXLX00`000000oooo
0000000203>QbP030000003oool0oooo00D0oooo003o0?ooo`T0oooo0P00000903>QbPD00000203o
ool00?l0oooo2`3oool9000000<0<j7:0P0000080?ooo`00o`3oool>0?ooo`050000000cXLX00000
0?ooo`0000001@0cXLX00`000000oooo0?ooo`060?ooo`00o`3oool>0?ooo`040000000cXLX0<j7:
000000L0<j7:00<000000?ooo`3oool01@3oool00?l0oooo3P3oool4000000L0<j7:00<000000?oo
o`3oool01@3oool00?l0oooo4@3oool00`000000<j7:03>QbP0403>QbP030000003oool0oooo00H0
oooo003o0?oooa80oooo00<0000003>QbP0cXLX00`0cXLX00`000000oooo0?ooo`060?ooo`00o`3o
oolB0?ooo`040000000cXLX0<j7:03>QbP8000002@3oool00?l0oooo4`3oool40000000303>QbP00
0000oooo00L0oooo003o0?oooaH0oooo00@0000003>QbP0cXLX000001`3oool00?l0oooo5P3oool3
000000P0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {221.563, 0}} -> {0.047122, -0.0744836, \
0.0141165, 0.0141165}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({p, r} = {{0, 0}, 1};\)\), "\[IndentingNewLine]", 
    \(\(cir = 
        Join[{{p, r}}, type[1, {1, 1}, {1. , 0}, {0. , 1. }, p, r, 5], 
          type[1, {\(-1\), 1}, {1. , 1}, {\(-1\), \(-1. \)}, p, r, 5], 
          type[1, {\(-1\), \(-1\)}, {1. , \(-1\)}, {\(-1. \), 1. }, p, r, 5], 
          type[1, {1, \(-1\)}, {1. , 0}, {\(-1\), \(-1. \)}, p, r, 
            5]];\)\), "\[IndentingNewLine]", 
    \(shG[\({Burlywood, Disk[First[#], Last[#]], VanDykeBrown, 
            Circle[First[#], Last[#]]} &\) /@ cir]\)}], "Input",
  CellLabel->"In[156]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.871 .722 .529 r
.5 .5 m
.5 .5 .47619 0 365.73 arc
F
.37 .15 .02 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.871 .722 .529 r
.89449 .89449 m
.89449 .89449 .0817 0 365.73 arc
F
.37 .15 .02 r
newpath
.89449 .89449 .0817 0 365.73 arc
s
.871 .722 .529 r
.96217 .96217 m
.96217 .96217 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.96217 .96217 .01402 0 365.73 arc
s
.871 .722 .529 r
.97379 .97379 m
.97379 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.97578 .97578 m
.97578 .97578 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97578 .97578 .00041 0 365.73 arc
s
.871 .722 .529 r
.97612 .97612 m
.97612 .97612 7e-005 0 365.73 arc
F
.37 .15 .02 r
newpath
.97612 .97612 7e-005 0 365.73 arc
s
.871 .722 .529 r
.97598 .97519 m
.97598 .97519 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97598 .97519 .00021 0 365.73 arc
s
.871 .722 .529 r
.97519 .97598 m
.97519 .97598 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97519 .97598 .00021 0 365.73 arc
s
.871 .722 .529 r
.97499 .97038 m
.97499 .97038 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97499 .97038 .0012 0 365.73 arc
s
.871 .722 .529 r
.97547 .96852 m
.97547 .96852 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.97547 .96852 .00072 0 365.73 arc
s
.871 .722 .529 r
.97578 .97179 m
.97578 .97179 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97578 .97179 .00041 0 365.73 arc
s
.871 .722 .529 r
.97354 .97101 m
.97354 .97101 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.97354 .97101 .00038 0 365.73 arc
s
.871 .722 .529 r
.97038 .97499 m
.97038 .97499 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97038 .97499 .0012 0 365.73 arc
s
.871 .722 .529 r
.96852 .97547 m
.96852 .97547 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.96852 .97547 .00072 0 365.73 arc
s
.871 .722 .529 r
.97179 .97578 m
.97179 .97578 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97179 .97578 .00041 0 365.73 arc
s
.871 .722 .529 r
.97101 .97354 m
.97101 .97354 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.97101 .97354 .00038 0 365.73 arc
s
.871 .722 .529 r
.96918 .94235 m
.96918 .94235 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.96918 .94235 .00701 0 365.73 arc
s
.871 .722 .529 r
.972 .93151 m
.972 .93151 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.972 .93151 .00419 0 365.73 arc
s
.871 .722 .529 r
.9734 .92467 m
.9734 .92467 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.9734 .92467 .00279 0 365.73 arc
s
.871 .722 .529 r
.97486 .93624 m
.97486 .93624 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.97486 .93624 .00133 0 365.73 arc
s
.871 .722 .529 r
.96729 .93429 m
.96729 .93429 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.96729 .93429 .00127 0 365.73 arc
s
.871 .722 .529 r
.97379 .95056 m
.97379 .95056 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .95056 .00241 0 365.73 arc
s
.871 .722 .529 r
.97499 .95396 m
.97499 .95396 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97499 .95396 .0012 0 365.73 arc
s
.871 .722 .529 r
.97523 .94753 m
.97523 .94753 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.97523 .94753 .00096 0 365.73 arc
s
.871 .722 .529 r
.97063 .95002 m
.97063 .95002 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.97063 .95002 .00079 0 365.73 arc
s
.871 .722 .529 r
.96072 .94601 m
.96072 .94601 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.96072 .94601 .00221 0 365.73 arc
s
.871 .722 .529 r
.9579 .9477 m
.9579 .9477 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.9579 .9477 .00108 0 365.73 arc
s
.871 .722 .529 r
.96132 .94299 m
.96132 .94299 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.96132 .94299 .00087 0 365.73 arc
s
.871 .722 .529 r
.96332 .94744 m
.96332 .94744 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.96332 .94744 .00076 0 365.73 arc
s
.871 .722 .529 r
.94235 .96918 m
.94235 .96918 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.94235 .96918 .00701 0 365.73 arc
s
.871 .722 .529 r
.93151 .972 m
.93151 .972 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.93151 .972 .00419 0 365.73 arc
s
.871 .722 .529 r
.92467 .9734 m
.92467 .9734 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.92467 .9734 .00279 0 365.73 arc
s
.871 .722 .529 r
.93624 .97486 m
.93624 .97486 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.93624 .97486 .00133 0 365.73 arc
s
.871 .722 .529 r
.93429 .96729 m
.93429 .96729 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.93429 .96729 .00127 0 365.73 arc
s
.871 .722 .529 r
.95056 .97379 m
.95056 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.95056 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.95396 .97499 m
.95396 .97499 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.95396 .97499 .0012 0 365.73 arc
s
.871 .722 .529 r
.94753 .97523 m
.94753 .97523 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.94753 .97523 .00096 0 365.73 arc
s
.871 .722 .529 r
.95002 .97063 m
.95002 .97063 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.95002 .97063 .00079 0 365.73 arc
s
.871 .722 .529 r
.94601 .96072 m
.94601 .96072 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.94601 .96072 .00221 0 365.73 arc
s
.871 .722 .529 r
.9477 .9579 m
.9477 .9579 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.9477 .9579 .00108 0 365.73 arc
s
.871 .722 .529 r
.94299 .96132 m
.94299 .96132 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.94299 .96132 .00087 0 365.73 arc
s
.871 .722 .529 r
.94744 .96332 m
.94744 .96332 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.94744 .96332 .00076 0 365.73 arc
s
.871 .722 .529 r
.93534 .77895 m
.93534 .77895 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.93534 .77895 .04085 0 365.73 arc
s
.871 .722 .529 r
.95175 .71575 m
.95175 .71575 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.95175 .71575 .02444 0 365.73 arc
s
.871 .722 .529 r
.95995 .6759 m
.95995 .6759 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.95995 .6759 .01624 0 365.73 arc
s
.871 .722 .529 r
.96462 .64848 m
.96462 .64848 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.96462 .64848 .01157 0 365.73 arc
s
.871 .722 .529 r
.97126 .6938 m
.97126 .6938 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.97126 .6938 .00493 0 365.73 arc
s
.871 .722 .529 r
.94272 .68796 m
.94272 .68796 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.94272 .68796 .00478 0 365.73 arc
s
.871 .722 .529 r
.96842 .74331 m
.96842 .74331 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.96842 .74331 .00777 0 365.73 arc
s
.871 .722 .529 r
.97242 .75413 m
.97242 .75413 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.97242 .75413 .00377 0 365.73 arc
s
.871 .722 .529 r
.97301 .73338 m
.97301 .73338 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.97301 .73338 .00318 0 365.73 arc
s
.871 .722 .529 r
.95816 .742 m
.95816 .742 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.95816 .742 .00258 0 365.73 arc
s
.871 .722 .529 r
.92434 .73196 m
.92434 .73196 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.92434 .73196 .00741 0 365.73 arc
s
.871 .722 .529 r
.91596 .73901 m
.91596 .73901 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.91596 .73901 .00354 0 365.73 arc
s
.871 .722 .529 r
.92492 .72155 m
.92492 .72155 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.92492 .72155 .00302 0 365.73 arc
s
.871 .722 .529 r
.93355 .73562 m
.93355 .73562 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.93355 .73562 .00251 0 365.73 arc
s
.871 .722 .529 r
.96217 .82681 m
.96217 .82681 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.96217 .82681 .01402 0 365.73 arc
s
.871 .722 .529 r
.96918 .84663 m
.96918 .84663 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.96918 .84663 .00701 0 365.73 arc
s
.871 .722 .529 r
.972 .85747 m
.972 .85747 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.972 .85747 .00419 0 365.73 arc
s
.871 .722 .529 r
.97379 .83842 m
.97379 .83842 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .83842 .00241 0 365.73 arc
s
.871 .722 .529 r
.96072 .84297 m
.96072 .84297 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.96072 .84297 .00221 0 365.73 arc
s
.871 .722 .529 r
.97062 .80913 m
.97062 .80913 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.97062 .80913 .00557 0 365.73 arc
s
.871 .722 .529 r
.97322 .80099 m
.97322 .80099 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.97322 .80099 .00297 0 365.73 arc
s
.871 .722 .529 r
.97409 .81596 m
.97409 .81596 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97409 .81596 .0021 0 365.73 arc
s
.871 .722 .529 r
.96347 .81102 m
.96347 .81102 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.96347 .81102 .00182 0 365.73 arc
s
.871 .722 .529 r
.9438 .82363 m
.9438 .82363 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.9438 .82363 .00463 0 365.73 arc
s
.871 .722 .529 r
.93705 .82207 m
.93705 .82207 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.93705 .82207 .0023 0 365.73 arc
s
.871 .722 .529 r
.94662 .82934 m
.94662 .82934 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.94662 .82934 .00174 0 365.73 arc
s
.871 .722 .529 r
.9484 .81938 m
.9484 .81938 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.9484 .81938 .00163 0 365.73 arc
s
.871 .722 .529 r
.88603 .80029 m
.88603 .80029 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.88603 .80029 .01288 0 365.73 arc
s
.871 .722 .529 r
.86959 .81011 m
.86959 .81011 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.86959 .81011 .00627 0 365.73 arc
s
.871 .722 .529 r
.86137 .81577 m
.86137 .81577 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.86137 .81577 .0037 0 365.73 arc
s
.871 .722 .529 r
.87108 .80183 m
.87108 .80183 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.87108 .80183 .00215 0 365.73 arc
s
.871 .722 .529 r
.87752 .81251 m
.87752 .81251 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.87752 .81251 .00201 0 365.73 arc
s
.871 .722 .529 r
.88954 .78266 m
.88954 .78266 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.88954 .78266 .0051 0 365.73 arc
s
.871 .722 .529 r
.89193 .77522 m
.89193 .77522 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.89193 .77522 .00272 0 365.73 arc
s
.871 .722 .529 r
.88328 .78577 m
.88328 .78577 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.88328 .78577 .0019 0 365.73 arc
s
.871 .722 .529 r
.89377 .78795 m
.89377 .78795 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.89377 .78795 .00168 0 365.73 arc
s
.871 .722 .529 r
.90117 .80863 m
.90117 .80863 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.90117 .80863 .00441 0 365.73 arc
s
.871 .722 .529 r
.90715 .81152 m
.90715 .81152 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.90715 .81152 .00223 0 365.73 arc
s
.871 .722 .529 r
.89567 .81115 m
.89567 .81115 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.89567 .81115 .00164 0 365.73 arc
s
.871 .722 .529 r
.90025 .80274 m
.90025 .80274 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.90025 .80274 .00155 0 365.73 arc
s
.871 .722 .529 r
.77895 .93534 m
.77895 .93534 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.77895 .93534 .04085 0 365.73 arc
s
.871 .722 .529 r
.71575 .95175 m
.71575 .95175 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.71575 .95175 .02444 0 365.73 arc
s
.871 .722 .529 r
.6759 .95995 m
.6759 .95995 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.6759 .95995 .01624 0 365.73 arc
s
.871 .722 .529 r
.64848 .96462 m
.64848 .96462 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.64848 .96462 .01157 0 365.73 arc
s
.871 .722 .529 r
.6938 .97126 m
.6938 .97126 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.6938 .97126 .00493 0 365.73 arc
s
.871 .722 .529 r
.68796 .94272 m
.68796 .94272 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.68796 .94272 .00478 0 365.73 arc
s
.871 .722 .529 r
.74331 .96842 m
.74331 .96842 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.74331 .96842 .00777 0 365.73 arc
s
.871 .722 .529 r
.75413 .97242 m
.75413 .97242 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.75413 .97242 .00377 0 365.73 arc
s
.871 .722 .529 r
.73338 .97301 m
.73338 .97301 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.73338 .97301 .00318 0 365.73 arc
s
.871 .722 .529 r
.742 .95816 m
.742 .95816 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.742 .95816 .00258 0 365.73 arc
s
.871 .722 .529 r
.73196 .92434 m
.73196 .92434 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.73196 .92434 .00741 0 365.73 arc
s
.871 .722 .529 r
.73901 .91596 m
.73901 .91596 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.73901 .91596 .00354 0 365.73 arc
s
.871 .722 .529 r
.72155 .92492 m
.72155 .92492 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.72155 .92492 .00302 0 365.73 arc
s
.871 .722 .529 r
.73562 .93355 m
.73562 .93355 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.73562 .93355 .00251 0 365.73 arc
s
.871 .722 .529 r
.82681 .96217 m
.82681 .96217 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.82681 .96217 .01402 0 365.73 arc
s
.871 .722 .529 r
.84663 .96918 m
.84663 .96918 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.84663 .96918 .00701 0 365.73 arc
s
.871 .722 .529 r
.85747 .972 m
.85747 .972 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.85747 .972 .00419 0 365.73 arc
s
.871 .722 .529 r
.83842 .97379 m
.83842 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.83842 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.84297 .96072 m
.84297 .96072 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.84297 .96072 .00221 0 365.73 arc
s
.871 .722 .529 r
.80913 .97062 m
.80913 .97062 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.80913 .97062 .00557 0 365.73 arc
s
.871 .722 .529 r
.80099 .97322 m
.80099 .97322 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.80099 .97322 .00297 0 365.73 arc
s
.871 .722 .529 r
.81596 .97409 m
.81596 .97409 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.81596 .97409 .0021 0 365.73 arc
s
.871 .722 .529 r
.81102 .96347 m
.81102 .96347 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.81102 .96347 .00182 0 365.73 arc
s
.871 .722 .529 r
.82363 .9438 m
.82363 .9438 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.82363 .9438 .00463 0 365.73 arc
s
.871 .722 .529 r
.82207 .93705 m
.82207 .93705 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.82207 .93705 .0023 0 365.73 arc
s
.871 .722 .529 r
.82934 .94662 m
.82934 .94662 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.82934 .94662 .00174 0 365.73 arc
s
.871 .722 .529 r
.81938 .9484 m
.81938 .9484 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.81938 .9484 .00163 0 365.73 arc
s
.871 .722 .529 r
.80029 .88603 m
.80029 .88603 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.80029 .88603 .01288 0 365.73 arc
s
.871 .722 .529 r
.81011 .86959 m
.81011 .86959 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.81011 .86959 .00627 0 365.73 arc
s
.871 .722 .529 r
.81577 .86137 m
.81577 .86137 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.81577 .86137 .0037 0 365.73 arc
s
.871 .722 .529 r
.80183 .87108 m
.80183 .87108 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.80183 .87108 .00215 0 365.73 arc
s
.871 .722 .529 r
.81251 .87752 m
.81251 .87752 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.81251 .87752 .00201 0 365.73 arc
s
.871 .722 .529 r
.78266 .88954 m
.78266 .88954 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.78266 .88954 .0051 0 365.73 arc
s
.871 .722 .529 r
.77522 .89193 m
.77522 .89193 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.77522 .89193 .00272 0 365.73 arc
s
.871 .722 .529 r
.78577 .88328 m
.78577 .88328 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.78577 .88328 .0019 0 365.73 arc
s
.871 .722 .529 r
.78795 .89377 m
.78795 .89377 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.78795 .89377 .00168 0 365.73 arc
s
.871 .722 .529 r
.80863 .90117 m
.80863 .90117 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.80863 .90117 .00441 0 365.73 arc
s
.871 .722 .529 r
.81152 .90715 m
.81152 .90715 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.81152 .90715 .00223 0 365.73 arc
s
.871 .722 .529 r
.81115 .89567 m
.81115 .89567 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.81115 .89567 .00164 0 365.73 arc
s
.871 .722 .529 r
.80274 .90025 m
.80274 .90025 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.80274 .90025 .00155 0 365.73 arc
s
.871 .722 .529 r
.10551 .89449 m
.10551 .89449 .0817 0 365.73 arc
F
.37 .15 .02 r
newpath
.10551 .89449 .0817 0 365.73 arc
s
.871 .722 .529 r
.03783 .96217 m
.03783 .96217 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.03783 .96217 .01402 0 365.73 arc
s
.871 .722 .529 r
.02621 .97379 m
.02621 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.02422 .97578 m
.02422 .97578 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02422 .97578 .00041 0 365.73 arc
s
.871 .722 .529 r
.02388 .97612 m
.02388 .97612 7e-005 0 365.73 arc
F
.37 .15 .02 r
newpath
.02388 .97612 7e-005 0 365.73 arc
s
.871 .722 .529 r
.02481 .97598 m
.02481 .97598 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02481 .97598 .00021 0 365.73 arc
s
.871 .722 .529 r
.02402 .97519 m
.02402 .97519 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02402 .97519 .00021 0 365.73 arc
s
.871 .722 .529 r
.02962 .97499 m
.02962 .97499 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02962 .97499 .0012 0 365.73 arc
s
.871 .722 .529 r
.03148 .97547 m
.03148 .97547 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.03148 .97547 .00072 0 365.73 arc
s
.871 .722 .529 r
.02821 .97578 m
.02821 .97578 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02821 .97578 .00041 0 365.73 arc
s
.871 .722 .529 r
.02899 .97354 m
.02899 .97354 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.02899 .97354 .00038 0 365.73 arc
s
.871 .722 .529 r
.02501 .97038 m
.02501 .97038 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02501 .97038 .0012 0 365.73 arc
s
.871 .722 .529 r
.02453 .96852 m
.02453 .96852 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.02453 .96852 .00072 0 365.73 arc
s
.871 .722 .529 r
.02422 .97179 m
.02422 .97179 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02422 .97179 .00041 0 365.73 arc
s
.871 .722 .529 r
.02646 .97101 m
.02646 .97101 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.02646 .97101 .00038 0 365.73 arc
s
.871 .722 .529 r
.05765 .96918 m
.05765 .96918 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.05765 .96918 .00701 0 365.73 arc
s
.871 .722 .529 r
.06849 .972 m
.06849 .972 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.06849 .972 .00419 0 365.73 arc
s
.871 .722 .529 r
.07533 .9734 m
.07533 .9734 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.07533 .9734 .00279 0 365.73 arc
s
.871 .722 .529 r
.06376 .97486 m
.06376 .97486 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.06376 .97486 .00133 0 365.73 arc
s
.871 .722 .529 r
.06571 .96729 m
.06571 .96729 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.06571 .96729 .00127 0 365.73 arc
s
.871 .722 .529 r
.04944 .97379 m
.04944 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.04944 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.04604 .97499 m
.04604 .97499 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.04604 .97499 .0012 0 365.73 arc
s
.871 .722 .529 r
.05247 .97523 m
.05247 .97523 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.05247 .97523 .00096 0 365.73 arc
s
.871 .722 .529 r
.04998 .97063 m
.04998 .97063 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.04998 .97063 .00079 0 365.73 arc
s
.871 .722 .529 r
.05399 .96072 m
.05399 .96072 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.05399 .96072 .00221 0 365.73 arc
s
.871 .722 .529 r
.0523 .9579 m
.0523 .9579 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.0523 .9579 .00108 0 365.73 arc
s
.871 .722 .529 r
.05701 .96132 m
.05701 .96132 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.05701 .96132 .00087 0 365.73 arc
s
.871 .722 .529 r
.05256 .96332 m
.05256 .96332 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.05256 .96332 .00076 0 365.73 arc
s
.871 .722 .529 r
.03082 .94235 m
.03082 .94235 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.03082 .94235 .00701 0 365.73 arc
s
.871 .722 .529 r
.028 .93151 m
.028 .93151 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.028 .93151 .00419 0 365.73 arc
s
.871 .722 .529 r
.0266 .92467 m
.0266 .92467 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.0266 .92467 .00279 0 365.73 arc
s
.871 .722 .529 r
.02514 .93624 m
.02514 .93624 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.02514 .93624 .00133 0 365.73 arc
s
.871 .722 .529 r
.03271 .93429 m
.03271 .93429 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.03271 .93429 .00127 0 365.73 arc
s
.871 .722 .529 r
.02621 .95056 m
.02621 .95056 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .95056 .00241 0 365.73 arc
s
.871 .722 .529 r
.02501 .95396 m
.02501 .95396 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02501 .95396 .0012 0 365.73 arc
s
.871 .722 .529 r
.02477 .94753 m
.02477 .94753 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.02477 .94753 .00096 0 365.73 arc
s
.871 .722 .529 r
.02937 .95002 m
.02937 .95002 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.02937 .95002 .00079 0 365.73 arc
s
.871 .722 .529 r
.03928 .94601 m
.03928 .94601 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.03928 .94601 .00221 0 365.73 arc
s
.871 .722 .529 r
.0421 .9477 m
.0421 .9477 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.0421 .9477 .00108 0 365.73 arc
s
.871 .722 .529 r
.03868 .94299 m
.03868 .94299 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.03868 .94299 .00087 0 365.73 arc
s
.871 .722 .529 r
.03668 .94744 m
.03668 .94744 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.03668 .94744 .00076 0 365.73 arc
s
.871 .722 .529 r
.22105 .93534 m
.22105 .93534 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.22105 .93534 .04085 0 365.73 arc
s
.871 .722 .529 r
.28425 .95175 m
.28425 .95175 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.28425 .95175 .02444 0 365.73 arc
s
.871 .722 .529 r
.3241 .95995 m
.3241 .95995 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.3241 .95995 .01624 0 365.73 arc
s
.871 .722 .529 r
.35152 .96462 m
.35152 .96462 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.35152 .96462 .01157 0 365.73 arc
s
.871 .722 .529 r
.3062 .97126 m
.3062 .97126 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.3062 .97126 .00493 0 365.73 arc
s
.871 .722 .529 r
.31204 .94272 m
.31204 .94272 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.31204 .94272 .00478 0 365.73 arc
s
.871 .722 .529 r
.25669 .96842 m
.25669 .96842 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.25669 .96842 .00777 0 365.73 arc
s
.871 .722 .529 r
.24587 .97242 m
.24587 .97242 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.24587 .97242 .00377 0 365.73 arc
s
.871 .722 .529 r
.26662 .97301 m
.26662 .97301 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.26662 .97301 .00318 0 365.73 arc
s
.871 .722 .529 r
.258 .95816 m
.258 .95816 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.258 .95816 .00258 0 365.73 arc
s
.871 .722 .529 r
.26804 .92434 m
.26804 .92434 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.26804 .92434 .00741 0 365.73 arc
s
.871 .722 .529 r
.26099 .91596 m
.26099 .91596 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.26099 .91596 .00354 0 365.73 arc
s
.871 .722 .529 r
.27845 .92492 m
.27845 .92492 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.27845 .92492 .00302 0 365.73 arc
s
.871 .722 .529 r
.26438 .93355 m
.26438 .93355 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.26438 .93355 .00251 0 365.73 arc
s
.871 .722 .529 r
.17319 .96217 m
.17319 .96217 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.17319 .96217 .01402 0 365.73 arc
s
.871 .722 .529 r
.15337 .96918 m
.15337 .96918 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.15337 .96918 .00701 0 365.73 arc
s
.871 .722 .529 r
.14253 .972 m
.14253 .972 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.14253 .972 .00419 0 365.73 arc
s
.871 .722 .529 r
.16158 .97379 m
.16158 .97379 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.16158 .97379 .00241 0 365.73 arc
s
.871 .722 .529 r
.15703 .96072 m
.15703 .96072 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.15703 .96072 .00221 0 365.73 arc
s
.871 .722 .529 r
.19087 .97062 m
.19087 .97062 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.19087 .97062 .00557 0 365.73 arc
s
.871 .722 .529 r
.19901 .97322 m
.19901 .97322 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.19901 .97322 .00297 0 365.73 arc
s
.871 .722 .529 r
.18404 .97409 m
.18404 .97409 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.18404 .97409 .0021 0 365.73 arc
s
.871 .722 .529 r
.18898 .96347 m
.18898 .96347 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.18898 .96347 .00182 0 365.73 arc
s
.871 .722 .529 r
.17637 .9438 m
.17637 .9438 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.17637 .9438 .00463 0 365.73 arc
s
.871 .722 .529 r
.17793 .93705 m
.17793 .93705 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.17793 .93705 .0023 0 365.73 arc
s
.871 .722 .529 r
.17066 .94662 m
.17066 .94662 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.17066 .94662 .00174 0 365.73 arc
s
.871 .722 .529 r
.18062 .9484 m
.18062 .9484 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.18062 .9484 .00163 0 365.73 arc
s
.871 .722 .529 r
.19971 .88603 m
.19971 .88603 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.19971 .88603 .01288 0 365.73 arc
s
.871 .722 .529 r
.18989 .86959 m
.18989 .86959 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.18989 .86959 .00627 0 365.73 arc
s
.871 .722 .529 r
.18423 .86137 m
.18423 .86137 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.18423 .86137 .0037 0 365.73 arc
s
.871 .722 .529 r
.19817 .87108 m
.19817 .87108 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.19817 .87108 .00215 0 365.73 arc
s
.871 .722 .529 r
.18749 .87752 m
.18749 .87752 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.18749 .87752 .00201 0 365.73 arc
s
.871 .722 .529 r
.21734 .88954 m
.21734 .88954 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.21734 .88954 .0051 0 365.73 arc
s
.871 .722 .529 r
.22478 .89193 m
.22478 .89193 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.22478 .89193 .00272 0 365.73 arc
s
.871 .722 .529 r
.21423 .88328 m
.21423 .88328 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.21423 .88328 .0019 0 365.73 arc
s
.871 .722 .529 r
.21205 .89377 m
.21205 .89377 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.21205 .89377 .00168 0 365.73 arc
s
.871 .722 .529 r
.19137 .90117 m
.19137 .90117 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.19137 .90117 .00441 0 365.73 arc
s
.871 .722 .529 r
.18848 .90715 m
.18848 .90715 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.18848 .90715 .00223 0 365.73 arc
s
.871 .722 .529 r
.18885 .89567 m
.18885 .89567 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.18885 .89567 .00164 0 365.73 arc
s
.871 .722 .529 r
.19726 .90025 m
.19726 .90025 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.19726 .90025 .00155 0 365.73 arc
s
.871 .722 .529 r
.06466 .77895 m
.06466 .77895 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.06466 .77895 .04085 0 365.73 arc
s
.871 .722 .529 r
.04825 .71575 m
.04825 .71575 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.04825 .71575 .02444 0 365.73 arc
s
.871 .722 .529 r
.04005 .6759 m
.04005 .6759 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.04005 .6759 .01624 0 365.73 arc
s
.871 .722 .529 r
.03538 .64848 m
.03538 .64848 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.03538 .64848 .01157 0 365.73 arc
s
.871 .722 .529 r
.02874 .6938 m
.02874 .6938 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.02874 .6938 .00493 0 365.73 arc
s
.871 .722 .529 r
.05728 .68796 m
.05728 .68796 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.05728 .68796 .00478 0 365.73 arc
s
.871 .722 .529 r
.03158 .74331 m
.03158 .74331 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.03158 .74331 .00777 0 365.73 arc
s
.871 .722 .529 r
.02758 .75413 m
.02758 .75413 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.02758 .75413 .00377 0 365.73 arc
s
.871 .722 .529 r
.02699 .73338 m
.02699 .73338 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.02699 .73338 .00318 0 365.73 arc
s
.871 .722 .529 r
.04184 .742 m
.04184 .742 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.04184 .742 .00258 0 365.73 arc
s
.871 .722 .529 r
.07566 .73196 m
.07566 .73196 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.07566 .73196 .00741 0 365.73 arc
s
.871 .722 .529 r
.08404 .73901 m
.08404 .73901 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.08404 .73901 .00354 0 365.73 arc
s
.871 .722 .529 r
.07508 .72155 m
.07508 .72155 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.07508 .72155 .00302 0 365.73 arc
s
.871 .722 .529 r
.06645 .73562 m
.06645 .73562 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.06645 .73562 .00251 0 365.73 arc
s
.871 .722 .529 r
.03783 .82681 m
.03783 .82681 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.03783 .82681 .01402 0 365.73 arc
s
.871 .722 .529 r
.03082 .84663 m
.03082 .84663 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.03082 .84663 .00701 0 365.73 arc
s
.871 .722 .529 r
.028 .85747 m
.028 .85747 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.028 .85747 .00419 0 365.73 arc
s
.871 .722 .529 r
.02621 .83842 m
.02621 .83842 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .83842 .00241 0 365.73 arc
s
.871 .722 .529 r
.03928 .84297 m
.03928 .84297 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.03928 .84297 .00221 0 365.73 arc
s
.871 .722 .529 r
.02938 .80913 m
.02938 .80913 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.02938 .80913 .00557 0 365.73 arc
s
.871 .722 .529 r
.02678 .80099 m
.02678 .80099 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.02678 .80099 .00297 0 365.73 arc
s
.871 .722 .529 r
.02591 .81596 m
.02591 .81596 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02591 .81596 .0021 0 365.73 arc
s
.871 .722 .529 r
.03653 .81102 m
.03653 .81102 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.03653 .81102 .00182 0 365.73 arc
s
.871 .722 .529 r
.0562 .82363 m
.0562 .82363 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.0562 .82363 .00463 0 365.73 arc
s
.871 .722 .529 r
.06295 .82207 m
.06295 .82207 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.06295 .82207 .0023 0 365.73 arc
s
.871 .722 .529 r
.05338 .82934 m
.05338 .82934 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.05338 .82934 .00174 0 365.73 arc
s
.871 .722 .529 r
.0516 .81938 m
.0516 .81938 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.0516 .81938 .00163 0 365.73 arc
s
.871 .722 .529 r
.11397 .80029 m
.11397 .80029 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.11397 .80029 .01288 0 365.73 arc
s
.871 .722 .529 r
.13041 .81011 m
.13041 .81011 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.13041 .81011 .00627 0 365.73 arc
s
.871 .722 .529 r
.13863 .81577 m
.13863 .81577 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.13863 .81577 .0037 0 365.73 arc
s
.871 .722 .529 r
.12892 .80183 m
.12892 .80183 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.12892 .80183 .00215 0 365.73 arc
s
.871 .722 .529 r
.12248 .81251 m
.12248 .81251 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.12248 .81251 .00201 0 365.73 arc
s
.871 .722 .529 r
.11046 .78266 m
.11046 .78266 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.11046 .78266 .0051 0 365.73 arc
s
.871 .722 .529 r
.10807 .77522 m
.10807 .77522 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.10807 .77522 .00272 0 365.73 arc
s
.871 .722 .529 r
.11672 .78577 m
.11672 .78577 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.11672 .78577 .0019 0 365.73 arc
s
.871 .722 .529 r
.10623 .78795 m
.10623 .78795 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.10623 .78795 .00168 0 365.73 arc
s
.871 .722 .529 r
.09883 .80863 m
.09883 .80863 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.09883 .80863 .00441 0 365.73 arc
s
.871 .722 .529 r
.09285 .81152 m
.09285 .81152 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.09285 .81152 .00223 0 365.73 arc
s
.871 .722 .529 r
.10433 .81115 m
.10433 .81115 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.10433 .81115 .00164 0 365.73 arc
s
.871 .722 .529 r
.09975 .80274 m
.09975 .80274 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.09975 .80274 .00155 0 365.73 arc
s
.871 .722 .529 r
.10551 .10551 m
.10551 .10551 .0817 0 365.73 arc
F
.37 .15 .02 r
newpath
.10551 .10551 .0817 0 365.73 arc
s
.871 .722 .529 r
.03783 .03783 m
.03783 .03783 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.03783 .03783 .01402 0 365.73 arc
s
.871 .722 .529 r
.02621 .02621 m
.02621 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.02422 .02422 m
.02422 .02422 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02422 .02422 .00041 0 365.73 arc
s
.871 .722 .529 r
.02388 .02388 m
.02388 .02388 7e-005 0 365.73 arc
F
.37 .15 .02 r
newpath
.02388 .02388 7e-005 0 365.73 arc
s
.871 .722 .529 r
.02481 .02402 m
.02481 .02402 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02481 .02402 .00021 0 365.73 arc
s
.871 .722 .529 r
.02402 .02481 m
.02402 .02481 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02402 .02481 .00021 0 365.73 arc
s
.871 .722 .529 r
.02962 .02501 m
.02962 .02501 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02962 .02501 .0012 0 365.73 arc
s
.871 .722 .529 r
.03148 .02453 m
.03148 .02453 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.03148 .02453 .00072 0 365.73 arc
s
.871 .722 .529 r
.02821 .02422 m
.02821 .02422 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02821 .02422 .00041 0 365.73 arc
s
.871 .722 .529 r
.02899 .02646 m
.02899 .02646 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.02899 .02646 .00038 0 365.73 arc
s
.871 .722 .529 r
.02501 .02962 m
.02501 .02962 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02501 .02962 .0012 0 365.73 arc
s
.871 .722 .529 r
.02453 .03148 m
.02453 .03148 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.02453 .03148 .00072 0 365.73 arc
s
.871 .722 .529 r
.02422 .02821 m
.02422 .02821 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.02422 .02821 .00041 0 365.73 arc
s
.871 .722 .529 r
.02646 .02899 m
.02646 .02899 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.02646 .02899 .00038 0 365.73 arc
s
.871 .722 .529 r
.05765 .03082 m
.05765 .03082 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.05765 .03082 .00701 0 365.73 arc
s
.871 .722 .529 r
.06849 .028 m
.06849 .028 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.06849 .028 .00419 0 365.73 arc
s
.871 .722 .529 r
.07533 .0266 m
.07533 .0266 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.07533 .0266 .00279 0 365.73 arc
s
.871 .722 .529 r
.06376 .02514 m
.06376 .02514 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.06376 .02514 .00133 0 365.73 arc
s
.871 .722 .529 r
.06571 .03271 m
.06571 .03271 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.06571 .03271 .00127 0 365.73 arc
s
.871 .722 .529 r
.04944 .02621 m
.04944 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.04944 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.04604 .02501 m
.04604 .02501 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.04604 .02501 .0012 0 365.73 arc
s
.871 .722 .529 r
.05247 .02477 m
.05247 .02477 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.05247 .02477 .00096 0 365.73 arc
s
.871 .722 .529 r
.04998 .02937 m
.04998 .02937 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.04998 .02937 .00079 0 365.73 arc
s
.871 .722 .529 r
.05399 .03928 m
.05399 .03928 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.05399 .03928 .00221 0 365.73 arc
s
.871 .722 .529 r
.0523 .0421 m
.0523 .0421 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.0523 .0421 .00108 0 365.73 arc
s
.871 .722 .529 r
.05701 .03868 m
.05701 .03868 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.05701 .03868 .00087 0 365.73 arc
s
.871 .722 .529 r
.05256 .03668 m
.05256 .03668 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.05256 .03668 .00076 0 365.73 arc
s
.871 .722 .529 r
.03082 .05765 m
.03082 .05765 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.03082 .05765 .00701 0 365.73 arc
s
.871 .722 .529 r
.028 .06849 m
.028 .06849 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.028 .06849 .00419 0 365.73 arc
s
.871 .722 .529 r
.0266 .07533 m
.0266 .07533 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.0266 .07533 .00279 0 365.73 arc
s
.871 .722 .529 r
.02514 .06376 m
.02514 .06376 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.02514 .06376 .00133 0 365.73 arc
s
.871 .722 .529 r
.03271 .06571 m
.03271 .06571 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.03271 .06571 .00127 0 365.73 arc
s
.871 .722 .529 r
.02621 .04944 m
.02621 .04944 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .04944 .00241 0 365.73 arc
s
.871 .722 .529 r
.02501 .04604 m
.02501 .04604 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.02501 .04604 .0012 0 365.73 arc
s
.871 .722 .529 r
.02477 .05247 m
.02477 .05247 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.02477 .05247 .00096 0 365.73 arc
s
.871 .722 .529 r
.02937 .04998 m
.02937 .04998 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.02937 .04998 .00079 0 365.73 arc
s
.871 .722 .529 r
.03928 .05399 m
.03928 .05399 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.03928 .05399 .00221 0 365.73 arc
s
.871 .722 .529 r
.0421 .0523 m
.0421 .0523 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.0421 .0523 .00108 0 365.73 arc
s
.871 .722 .529 r
.03868 .05701 m
.03868 .05701 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.03868 .05701 .00087 0 365.73 arc
s
.871 .722 .529 r
.03668 .05256 m
.03668 .05256 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.03668 .05256 .00076 0 365.73 arc
s
.871 .722 .529 r
.22105 .06466 m
.22105 .06466 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.22105 .06466 .04085 0 365.73 arc
s
.871 .722 .529 r
.28425 .04825 m
.28425 .04825 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.28425 .04825 .02444 0 365.73 arc
s
.871 .722 .529 r
.3241 .04005 m
.3241 .04005 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.3241 .04005 .01624 0 365.73 arc
s
.871 .722 .529 r
.35152 .03538 m
.35152 .03538 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.35152 .03538 .01157 0 365.73 arc
s
.871 .722 .529 r
.3062 .02874 m
.3062 .02874 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.3062 .02874 .00493 0 365.73 arc
s
.871 .722 .529 r
.31204 .05728 m
.31204 .05728 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.31204 .05728 .00478 0 365.73 arc
s
.871 .722 .529 r
.25669 .03158 m
.25669 .03158 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.25669 .03158 .00777 0 365.73 arc
s
.871 .722 .529 r
.24587 .02758 m
.24587 .02758 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.24587 .02758 .00377 0 365.73 arc
s
.871 .722 .529 r
.26662 .02699 m
.26662 .02699 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.26662 .02699 .00318 0 365.73 arc
s
.871 .722 .529 r
.258 .04184 m
.258 .04184 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.258 .04184 .00258 0 365.73 arc
s
.871 .722 .529 r
.26804 .07566 m
.26804 .07566 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.26804 .07566 .00741 0 365.73 arc
s
.871 .722 .529 r
.26099 .08404 m
.26099 .08404 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.26099 .08404 .00354 0 365.73 arc
s
.871 .722 .529 r
.27845 .07508 m
.27845 .07508 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.27845 .07508 .00302 0 365.73 arc
s
.871 .722 .529 r
.26438 .06645 m
.26438 .06645 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.26438 .06645 .00251 0 365.73 arc
s
.871 .722 .529 r
.17319 .03783 m
.17319 .03783 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.17319 .03783 .01402 0 365.73 arc
s
.871 .722 .529 r
.15337 .03082 m
.15337 .03082 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.15337 .03082 .00701 0 365.73 arc
s
.871 .722 .529 r
.14253 .028 m
.14253 .028 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.14253 .028 .00419 0 365.73 arc
s
.871 .722 .529 r
.16158 .02621 m
.16158 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.16158 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.15703 .03928 m
.15703 .03928 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.15703 .03928 .00221 0 365.73 arc
s
.871 .722 .529 r
.19087 .02938 m
.19087 .02938 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.19087 .02938 .00557 0 365.73 arc
s
.871 .722 .529 r
.19901 .02678 m
.19901 .02678 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.19901 .02678 .00297 0 365.73 arc
s
.871 .722 .529 r
.18404 .02591 m
.18404 .02591 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.18404 .02591 .0021 0 365.73 arc
s
.871 .722 .529 r
.18898 .03653 m
.18898 .03653 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.18898 .03653 .00182 0 365.73 arc
s
.871 .722 .529 r
.17637 .0562 m
.17637 .0562 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.17637 .0562 .00463 0 365.73 arc
s
.871 .722 .529 r
.17793 .06295 m
.17793 .06295 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.17793 .06295 .0023 0 365.73 arc
s
.871 .722 .529 r
.17066 .05338 m
.17066 .05338 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.17066 .05338 .00174 0 365.73 arc
s
.871 .722 .529 r
.18062 .0516 m
.18062 .0516 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.18062 .0516 .00163 0 365.73 arc
s
.871 .722 .529 r
.19971 .11397 m
.19971 .11397 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.19971 .11397 .01288 0 365.73 arc
s
.871 .722 .529 r
.18989 .13041 m
.18989 .13041 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.18989 .13041 .00627 0 365.73 arc
s
.871 .722 .529 r
.18423 .13863 m
.18423 .13863 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.18423 .13863 .0037 0 365.73 arc
s
.871 .722 .529 r
.19817 .12892 m
.19817 .12892 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.19817 .12892 .00215 0 365.73 arc
s
.871 .722 .529 r
.18749 .12248 m
.18749 .12248 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.18749 .12248 .00201 0 365.73 arc
s
.871 .722 .529 r
.21734 .11046 m
.21734 .11046 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.21734 .11046 .0051 0 365.73 arc
s
.871 .722 .529 r
.22478 .10807 m
.22478 .10807 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.22478 .10807 .00272 0 365.73 arc
s
.871 .722 .529 r
.21423 .11672 m
.21423 .11672 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.21423 .11672 .0019 0 365.73 arc
s
.871 .722 .529 r
.21205 .10623 m
.21205 .10623 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.21205 .10623 .00168 0 365.73 arc
s
.871 .722 .529 r
.19137 .09883 m
.19137 .09883 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.19137 .09883 .00441 0 365.73 arc
s
.871 .722 .529 r
.18848 .09285 m
.18848 .09285 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.18848 .09285 .00223 0 365.73 arc
s
.871 .722 .529 r
.18885 .10433 m
.18885 .10433 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.18885 .10433 .00164 0 365.73 arc
s
.871 .722 .529 r
.19726 .09975 m
.19726 .09975 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.19726 .09975 .00155 0 365.73 arc
s
.871 .722 .529 r
.06466 .22105 m
.06466 .22105 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.06466 .22105 .04085 0 365.73 arc
s
.871 .722 .529 r
.04825 .28425 m
.04825 .28425 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.04825 .28425 .02444 0 365.73 arc
s
.871 .722 .529 r
.04005 .3241 m
.04005 .3241 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.04005 .3241 .01624 0 365.73 arc
s
.871 .722 .529 r
.03538 .35152 m
.03538 .35152 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.03538 .35152 .01157 0 365.73 arc
s
.871 .722 .529 r
.02874 .3062 m
.02874 .3062 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.02874 .3062 .00493 0 365.73 arc
s
.871 .722 .529 r
.05728 .31204 m
.05728 .31204 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.05728 .31204 .00478 0 365.73 arc
s
.871 .722 .529 r
.03158 .25669 m
.03158 .25669 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.03158 .25669 .00777 0 365.73 arc
s
.871 .722 .529 r
.02758 .24587 m
.02758 .24587 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.02758 .24587 .00377 0 365.73 arc
s
.871 .722 .529 r
.02699 .26662 m
.02699 .26662 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.02699 .26662 .00318 0 365.73 arc
s
.871 .722 .529 r
.04184 .258 m
.04184 .258 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.04184 .258 .00258 0 365.73 arc
s
.871 .722 .529 r
.07566 .26804 m
.07566 .26804 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.07566 .26804 .00741 0 365.73 arc
s
.871 .722 .529 r
.08404 .26099 m
.08404 .26099 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.08404 .26099 .00354 0 365.73 arc
s
.871 .722 .529 r
.07508 .27845 m
.07508 .27845 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.07508 .27845 .00302 0 365.73 arc
s
.871 .722 .529 r
.06645 .26438 m
.06645 .26438 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.06645 .26438 .00251 0 365.73 arc
s
.871 .722 .529 r
.03783 .17319 m
.03783 .17319 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.03783 .17319 .01402 0 365.73 arc
s
.871 .722 .529 r
.03082 .15337 m
.03082 .15337 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.03082 .15337 .00701 0 365.73 arc
s
.871 .722 .529 r
.028 .14253 m
.028 .14253 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.028 .14253 .00419 0 365.73 arc
s
.871 .722 .529 r
.02621 .16158 m
.02621 .16158 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.02621 .16158 .00241 0 365.73 arc
s
.871 .722 .529 r
.03928 .15703 m
.03928 .15703 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.03928 .15703 .00221 0 365.73 arc
s
.871 .722 .529 r
.02938 .19087 m
.02938 .19087 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.02938 .19087 .00557 0 365.73 arc
s
.871 .722 .529 r
.02678 .19901 m
.02678 .19901 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.02678 .19901 .00297 0 365.73 arc
s
.871 .722 .529 r
.02591 .18404 m
.02591 .18404 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.02591 .18404 .0021 0 365.73 arc
s
.871 .722 .529 r
.03653 .18898 m
.03653 .18898 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.03653 .18898 .00182 0 365.73 arc
s
.871 .722 .529 r
.0562 .17637 m
.0562 .17637 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.0562 .17637 .00463 0 365.73 arc
s
.871 .722 .529 r
.06295 .17793 m
.06295 .17793 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.06295 .17793 .0023 0 365.73 arc
s
.871 .722 .529 r
.05338 .17066 m
.05338 .17066 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.05338 .17066 .00174 0 365.73 arc
s
.871 .722 .529 r
.0516 .18062 m
.0516 .18062 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.0516 .18062 .00163 0 365.73 arc
s
.871 .722 .529 r
.11397 .19971 m
.11397 .19971 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.11397 .19971 .01288 0 365.73 arc
s
.871 .722 .529 r
.13041 .18989 m
.13041 .18989 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.13041 .18989 .00627 0 365.73 arc
s
.871 .722 .529 r
.13863 .18423 m
.13863 .18423 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.13863 .18423 .0037 0 365.73 arc
s
.871 .722 .529 r
.12892 .19817 m
.12892 .19817 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.12892 .19817 .00215 0 365.73 arc
s
.871 .722 .529 r
.12248 .18749 m
.12248 .18749 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.12248 .18749 .00201 0 365.73 arc
s
.871 .722 .529 r
.11046 .21734 m
.11046 .21734 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.11046 .21734 .0051 0 365.73 arc
s
.871 .722 .529 r
.10807 .22478 m
.10807 .22478 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.10807 .22478 .00272 0 365.73 arc
s
.871 .722 .529 r
.11672 .21423 m
.11672 .21423 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.11672 .21423 .0019 0 365.73 arc
s
.871 .722 .529 r
.10623 .21205 m
.10623 .21205 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.10623 .21205 .00168 0 365.73 arc
s
.871 .722 .529 r
.09883 .19137 m
.09883 .19137 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.09883 .19137 .00441 0 365.73 arc
s
.871 .722 .529 r
.09285 .18848 m
.09285 .18848 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.09285 .18848 .00223 0 365.73 arc
s
.871 .722 .529 r
.10433 .18885 m
.10433 .18885 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.10433 .18885 .00164 0 365.73 arc
s
.871 .722 .529 r
.09975 .19726 m
.09975 .19726 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.09975 .19726 .00155 0 365.73 arc
s
.871 .722 .529 r
.89449 .10551 m
.89449 .10551 .0817 0 365.73 arc
F
.37 .15 .02 r
newpath
.89449 .10551 .0817 0 365.73 arc
s
.871 .722 .529 r
.96217 .03783 m
.96217 .03783 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.96217 .03783 .01402 0 365.73 arc
s
.871 .722 .529 r
.97379 .02621 m
.97379 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.97578 .02422 m
.97578 .02422 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97578 .02422 .00041 0 365.73 arc
s
.871 .722 .529 r
.97612 .02388 m
.97612 .02388 7e-005 0 365.73 arc
F
.37 .15 .02 r
newpath
.97612 .02388 7e-005 0 365.73 arc
s
.871 .722 .529 r
.97598 .02481 m
.97598 .02481 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97598 .02481 .00021 0 365.73 arc
s
.871 .722 .529 r
.97519 .02402 m
.97519 .02402 .00021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97519 .02402 .00021 0 365.73 arc
s
.871 .722 .529 r
.97499 .02962 m
.97499 .02962 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97499 .02962 .0012 0 365.73 arc
s
.871 .722 .529 r
.97547 .03148 m
.97547 .03148 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.97547 .03148 .00072 0 365.73 arc
s
.871 .722 .529 r
.97578 .02821 m
.97578 .02821 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97578 .02821 .00041 0 365.73 arc
s
.871 .722 .529 r
.97354 .02899 m
.97354 .02899 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.97354 .02899 .00038 0 365.73 arc
s
.871 .722 .529 r
.97038 .02501 m
.97038 .02501 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97038 .02501 .0012 0 365.73 arc
s
.871 .722 .529 r
.96852 .02453 m
.96852 .02453 .00072 0 365.73 arc
F
.37 .15 .02 r
newpath
.96852 .02453 .00072 0 365.73 arc
s
.871 .722 .529 r
.97179 .02422 m
.97179 .02422 .00041 0 365.73 arc
F
.37 .15 .02 r
newpath
.97179 .02422 .00041 0 365.73 arc
s
.871 .722 .529 r
.97101 .02646 m
.97101 .02646 .00038 0 365.73 arc
F
.37 .15 .02 r
newpath
.97101 .02646 .00038 0 365.73 arc
s
.871 .722 .529 r
.96918 .05765 m
.96918 .05765 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.96918 .05765 .00701 0 365.73 arc
s
.871 .722 .529 r
.972 .06849 m
.972 .06849 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.972 .06849 .00419 0 365.73 arc
s
.871 .722 .529 r
.9734 .07533 m
.9734 .07533 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.9734 .07533 .00279 0 365.73 arc
s
.871 .722 .529 r
.97486 .06376 m
.97486 .06376 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.97486 .06376 .00133 0 365.73 arc
s
.871 .722 .529 r
.96729 .06571 m
.96729 .06571 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.96729 .06571 .00127 0 365.73 arc
s
.871 .722 .529 r
.97379 .04944 m
.97379 .04944 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .04944 .00241 0 365.73 arc
s
.871 .722 .529 r
.97499 .04604 m
.97499 .04604 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.97499 .04604 .0012 0 365.73 arc
s
.871 .722 .529 r
.97523 .05247 m
.97523 .05247 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.97523 .05247 .00096 0 365.73 arc
s
.871 .722 .529 r
.97063 .04998 m
.97063 .04998 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.97063 .04998 .00079 0 365.73 arc
s
.871 .722 .529 r
.96072 .05399 m
.96072 .05399 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.96072 .05399 .00221 0 365.73 arc
s
.871 .722 .529 r
.9579 .0523 m
.9579 .0523 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.9579 .0523 .00108 0 365.73 arc
s
.871 .722 .529 r
.96132 .05701 m
.96132 .05701 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.96132 .05701 .00087 0 365.73 arc
s
.871 .722 .529 r
.96332 .05256 m
.96332 .05256 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.96332 .05256 .00076 0 365.73 arc
s
.871 .722 .529 r
.94235 .03082 m
.94235 .03082 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.94235 .03082 .00701 0 365.73 arc
s
.871 .722 .529 r
.93151 .028 m
.93151 .028 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.93151 .028 .00419 0 365.73 arc
s
.871 .722 .529 r
.92467 .0266 m
.92467 .0266 .00279 0 365.73 arc
F
.37 .15 .02 r
newpath
.92467 .0266 .00279 0 365.73 arc
s
.871 .722 .529 r
.93624 .02514 m
.93624 .02514 .00133 0 365.73 arc
F
.37 .15 .02 r
newpath
.93624 .02514 .00133 0 365.73 arc
s
.871 .722 .529 r
.93429 .03271 m
.93429 .03271 .00127 0 365.73 arc
F
.37 .15 .02 r
newpath
.93429 .03271 .00127 0 365.73 arc
s
.871 .722 .529 r
.95056 .02621 m
.95056 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.95056 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.95396 .02501 m
.95396 .02501 .0012 0 365.73 arc
F
.37 .15 .02 r
newpath
.95396 .02501 .0012 0 365.73 arc
s
.871 .722 .529 r
.94753 .02477 m
.94753 .02477 .00096 0 365.73 arc
F
.37 .15 .02 r
newpath
.94753 .02477 .00096 0 365.73 arc
s
.871 .722 .529 r
.95002 .02937 m
.95002 .02937 .00079 0 365.73 arc
F
.37 .15 .02 r
newpath
.95002 .02937 .00079 0 365.73 arc
s
.871 .722 .529 r
.94601 .03928 m
.94601 .03928 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.94601 .03928 .00221 0 365.73 arc
s
.871 .722 .529 r
.9477 .0421 m
.9477 .0421 .00108 0 365.73 arc
F
.37 .15 .02 r
newpath
.9477 .0421 .00108 0 365.73 arc
s
.871 .722 .529 r
.94299 .03868 m
.94299 .03868 .00087 0 365.73 arc
F
.37 .15 .02 r
newpath
.94299 .03868 .00087 0 365.73 arc
s
.871 .722 .529 r
.94744 .03668 m
.94744 .03668 .00076 0 365.73 arc
F
.37 .15 .02 r
newpath
.94744 .03668 .00076 0 365.73 arc
s
.871 .722 .529 r
.93534 .22105 m
.93534 .22105 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.93534 .22105 .04085 0 365.73 arc
s
.871 .722 .529 r
.95175 .28425 m
.95175 .28425 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.95175 .28425 .02444 0 365.73 arc
s
.871 .722 .529 r
.95995 .3241 m
.95995 .3241 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.95995 .3241 .01624 0 365.73 arc
s
.871 .722 .529 r
.96462 .35152 m
.96462 .35152 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.96462 .35152 .01157 0 365.73 arc
s
.871 .722 .529 r
.97126 .3062 m
.97126 .3062 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.97126 .3062 .00493 0 365.73 arc
s
.871 .722 .529 r
.94272 .31204 m
.94272 .31204 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.94272 .31204 .00478 0 365.73 arc
s
.871 .722 .529 r
.96842 .25669 m
.96842 .25669 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.96842 .25669 .00777 0 365.73 arc
s
.871 .722 .529 r
.97242 .24587 m
.97242 .24587 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.97242 .24587 .00377 0 365.73 arc
s
.871 .722 .529 r
.97301 .26662 m
.97301 .26662 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.97301 .26662 .00318 0 365.73 arc
s
.871 .722 .529 r
.95816 .258 m
.95816 .258 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.95816 .258 .00258 0 365.73 arc
s
.871 .722 .529 r
.92434 .26804 m
.92434 .26804 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.92434 .26804 .00741 0 365.73 arc
s
.871 .722 .529 r
.91596 .26099 m
.91596 .26099 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.91596 .26099 .00354 0 365.73 arc
s
.871 .722 .529 r
.92492 .27845 m
.92492 .27845 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.92492 .27845 .00302 0 365.73 arc
s
.871 .722 .529 r
.93355 .26438 m
.93355 .26438 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.93355 .26438 .00251 0 365.73 arc
s
.871 .722 .529 r
.96217 .17319 m
.96217 .17319 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.96217 .17319 .01402 0 365.73 arc
s
.871 .722 .529 r
.96918 .15337 m
.96918 .15337 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.96918 .15337 .00701 0 365.73 arc
s
.871 .722 .529 r
.972 .14253 m
.972 .14253 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.972 .14253 .00419 0 365.73 arc
s
.871 .722 .529 r
.97379 .16158 m
.97379 .16158 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.97379 .16158 .00241 0 365.73 arc
s
.871 .722 .529 r
.96072 .15703 m
.96072 .15703 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.96072 .15703 .00221 0 365.73 arc
s
.871 .722 .529 r
.97062 .19087 m
.97062 .19087 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.97062 .19087 .00557 0 365.73 arc
s
.871 .722 .529 r
.97322 .19901 m
.97322 .19901 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.97322 .19901 .00297 0 365.73 arc
s
.871 .722 .529 r
.97409 .18404 m
.97409 .18404 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.97409 .18404 .0021 0 365.73 arc
s
.871 .722 .529 r
.96347 .18898 m
.96347 .18898 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.96347 .18898 .00182 0 365.73 arc
s
.871 .722 .529 r
.9438 .17637 m
.9438 .17637 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.9438 .17637 .00463 0 365.73 arc
s
.871 .722 .529 r
.93705 .17793 m
.93705 .17793 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.93705 .17793 .0023 0 365.73 arc
s
.871 .722 .529 r
.94662 .17066 m
.94662 .17066 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.94662 .17066 .00174 0 365.73 arc
s
.871 .722 .529 r
.9484 .18062 m
.9484 .18062 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.9484 .18062 .00163 0 365.73 arc
s
.871 .722 .529 r
.88603 .19971 m
.88603 .19971 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.88603 .19971 .01288 0 365.73 arc
s
.871 .722 .529 r
.86959 .18989 m
.86959 .18989 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.86959 .18989 .00627 0 365.73 arc
s
.871 .722 .529 r
.86137 .18423 m
.86137 .18423 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.86137 .18423 .0037 0 365.73 arc
s
.871 .722 .529 r
.87108 .19817 m
.87108 .19817 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.87108 .19817 .00215 0 365.73 arc
s
.871 .722 .529 r
.87752 .18749 m
.87752 .18749 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.87752 .18749 .00201 0 365.73 arc
s
.871 .722 .529 r
.88954 .21734 m
.88954 .21734 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.88954 .21734 .0051 0 365.73 arc
s
.871 .722 .529 r
.89193 .22478 m
.89193 .22478 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.89193 .22478 .00272 0 365.73 arc
s
.871 .722 .529 r
.88328 .21423 m
.88328 .21423 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.88328 .21423 .0019 0 365.73 arc
s
.871 .722 .529 r
.89377 .21205 m
.89377 .21205 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.89377 .21205 .00168 0 365.73 arc
s
.871 .722 .529 r
.90117 .19137 m
.90117 .19137 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.90117 .19137 .00441 0 365.73 arc
s
.871 .722 .529 r
.90715 .18848 m
.90715 .18848 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.90715 .18848 .00223 0 365.73 arc
s
.871 .722 .529 r
.89567 .18885 m
.89567 .18885 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.89567 .18885 .00164 0 365.73 arc
s
.871 .722 .529 r
.90025 .19726 m
.90025 .19726 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.90025 .19726 .00155 0 365.73 arc
s
.871 .722 .529 r
.77895 .06466 m
.77895 .06466 .04085 0 365.73 arc
F
.37 .15 .02 r
newpath
.77895 .06466 .04085 0 365.73 arc
s
.871 .722 .529 r
.71575 .04825 m
.71575 .04825 .02444 0 365.73 arc
F
.37 .15 .02 r
newpath
.71575 .04825 .02444 0 365.73 arc
s
.871 .722 .529 r
.6759 .04005 m
.6759 .04005 .01624 0 365.73 arc
F
.37 .15 .02 r
newpath
.6759 .04005 .01624 0 365.73 arc
s
.871 .722 .529 r
.64848 .03538 m
.64848 .03538 .01157 0 365.73 arc
F
.37 .15 .02 r
newpath
.64848 .03538 .01157 0 365.73 arc
s
.871 .722 .529 r
.6938 .02874 m
.6938 .02874 .00493 0 365.73 arc
F
.37 .15 .02 r
newpath
.6938 .02874 .00493 0 365.73 arc
s
.871 .722 .529 r
.68796 .05728 m
.68796 .05728 .00478 0 365.73 arc
F
.37 .15 .02 r
newpath
.68796 .05728 .00478 0 365.73 arc
s
.871 .722 .529 r
.74331 .03158 m
.74331 .03158 .00777 0 365.73 arc
F
.37 .15 .02 r
newpath
.74331 .03158 .00777 0 365.73 arc
s
.871 .722 .529 r
.75413 .02758 m
.75413 .02758 .00377 0 365.73 arc
F
.37 .15 .02 r
newpath
.75413 .02758 .00377 0 365.73 arc
s
.871 .722 .529 r
.73338 .02699 m
.73338 .02699 .00318 0 365.73 arc
F
.37 .15 .02 r
newpath
.73338 .02699 .00318 0 365.73 arc
s
.871 .722 .529 r
.742 .04184 m
.742 .04184 .00258 0 365.73 arc
F
.37 .15 .02 r
newpath
.742 .04184 .00258 0 365.73 arc
s
.871 .722 .529 r
.73196 .07566 m
.73196 .07566 .00741 0 365.73 arc
F
.37 .15 .02 r
newpath
.73196 .07566 .00741 0 365.73 arc
s
.871 .722 .529 r
.73901 .08404 m
.73901 .08404 .00354 0 365.73 arc
F
.37 .15 .02 r
newpath
.73901 .08404 .00354 0 365.73 arc
s
.871 .722 .529 r
.72155 .07508 m
.72155 .07508 .00302 0 365.73 arc
F
.37 .15 .02 r
newpath
.72155 .07508 .00302 0 365.73 arc
s
.871 .722 .529 r
.73562 .06645 m
.73562 .06645 .00251 0 365.73 arc
F
.37 .15 .02 r
newpath
.73562 .06645 .00251 0 365.73 arc
s
.871 .722 .529 r
.82681 .03783 m
.82681 .03783 .01402 0 365.73 arc
F
.37 .15 .02 r
newpath
.82681 .03783 .01402 0 365.73 arc
s
.871 .722 .529 r
.84663 .03082 m
.84663 .03082 .00701 0 365.73 arc
F
.37 .15 .02 r
newpath
.84663 .03082 .00701 0 365.73 arc
s
.871 .722 .529 r
.85747 .028 m
.85747 .028 .00419 0 365.73 arc
F
.37 .15 .02 r
newpath
.85747 .028 .00419 0 365.73 arc
s
.871 .722 .529 r
.83842 .02621 m
.83842 .02621 .00241 0 365.73 arc
F
.37 .15 .02 r
newpath
.83842 .02621 .00241 0 365.73 arc
s
.871 .722 .529 r
.84297 .03928 m
.84297 .03928 .00221 0 365.73 arc
F
.37 .15 .02 r
newpath
.84297 .03928 .00221 0 365.73 arc
s
.871 .722 .529 r
.80913 .02938 m
.80913 .02938 .00557 0 365.73 arc
F
.37 .15 .02 r
newpath
.80913 .02938 .00557 0 365.73 arc
s
.871 .722 .529 r
.80099 .02678 m
.80099 .02678 .00297 0 365.73 arc
F
.37 .15 .02 r
newpath
.80099 .02678 .00297 0 365.73 arc
s
.871 .722 .529 r
.81596 .02591 m
.81596 .02591 .0021 0 365.73 arc
F
.37 .15 .02 r
newpath
.81596 .02591 .0021 0 365.73 arc
s
.871 .722 .529 r
.81102 .03653 m
.81102 .03653 .00182 0 365.73 arc
F
.37 .15 .02 r
newpath
.81102 .03653 .00182 0 365.73 arc
s
.871 .722 .529 r
.82363 .0562 m
.82363 .0562 .00463 0 365.73 arc
F
.37 .15 .02 r
newpath
.82363 .0562 .00463 0 365.73 arc
s
.871 .722 .529 r
.82207 .06295 m
.82207 .06295 .0023 0 365.73 arc
F
.37 .15 .02 r
newpath
.82207 .06295 .0023 0 365.73 arc
s
.871 .722 .529 r
.82934 .05338 m
.82934 .05338 .00174 0 365.73 arc
F
.37 .15 .02 r
newpath
.82934 .05338 .00174 0 365.73 arc
s
.871 .722 .529 r
.81938 .0516 m
.81938 .0516 .00163 0 365.73 arc
F
.37 .15 .02 r
newpath
.81938 .0516 .00163 0 365.73 arc
s
.871 .722 .529 r
.80029 .11397 m
.80029 .11397 .01288 0 365.73 arc
F
.37 .15 .02 r
newpath
.80029 .11397 .01288 0 365.73 arc
s
.871 .722 .529 r
.81011 .13041 m
.81011 .13041 .00627 0 365.73 arc
F
.37 .15 .02 r
newpath
.81011 .13041 .00627 0 365.73 arc
s
.871 .722 .529 r
.81577 .13863 m
.81577 .13863 .0037 0 365.73 arc
F
.37 .15 .02 r
newpath
.81577 .13863 .0037 0 365.73 arc
s
.871 .722 .529 r
.80183 .12892 m
.80183 .12892 .00215 0 365.73 arc
F
.37 .15 .02 r
newpath
.80183 .12892 .00215 0 365.73 arc
s
.871 .722 .529 r
.81251 .12248 m
.81251 .12248 .00201 0 365.73 arc
F
.37 .15 .02 r
newpath
.81251 .12248 .00201 0 365.73 arc
s
.871 .722 .529 r
.78266 .11046 m
.78266 .11046 .0051 0 365.73 arc
F
.37 .15 .02 r
newpath
.78266 .11046 .0051 0 365.73 arc
s
.871 .722 .529 r
.77522 .10807 m
.77522 .10807 .00272 0 365.73 arc
F
.37 .15 .02 r
newpath
.77522 .10807 .00272 0 365.73 arc
s
.871 .722 .529 r
.78577 .11672 m
.78577 .11672 .0019 0 365.73 arc
F
.37 .15 .02 r
newpath
.78577 .11672 .0019 0 365.73 arc
s
.871 .722 .529 r
.78795 .10623 m
.78795 .10623 .00168 0 365.73 arc
F
.37 .15 .02 r
newpath
.78795 .10623 .00168 0 365.73 arc
s
.871 .722 .529 r
.80863 .09883 m
.80863 .09883 .00441 0 365.73 arc
F
.37 .15 .02 r
newpath
.80863 .09883 .00441 0 365.73 arc
s
.871 .722 .529 r
.81152 .09285 m
.81152 .09285 .00223 0 365.73 arc
F
.37 .15 .02 r
newpath
.81152 .09285 .00223 0 365.73 arc
s
.871 .722 .529 r
.81115 .10433 m
.81115 .10433 .00164 0 365.73 arc
F
.37 .15 .02 r
newpath
.81115 .10433 .00164 0 365.73 arc
s
.871 .722 .529 r
.80274 .09975 m
.80274 .09975 .00155 0 365.73 arc
F
.37 .15 .02 r
newpath
.80274 .09975 .00155 0 365.73 arc
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[156]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3oool;05hV1@050?ooo`1N9PD0GRH50?ooo`1N9PD01`3oool405hV
1@L0oooo00L0GRH50?ooo`3oool0oooo05hV1@3oool0GRH50080oooo0P1N9PD0103oool0GRH50?oo
o`1N9PD20?ooo`0405hV1@3oool0oooo0?ooo`@0GRH51@3oool0101N9PD0oooo0?ooo`1N9PD20?oo
o`0305hV1@3oool0oooo0080oooo0P1N9PD40?ooo`0305hV1@3oool0oooo00<0oooo00<0GRH50?oo
o`3oool0103oool205hV1B@0oooo2`1N9PDT0?ooo`80GRH51`3oool00`1N9PD0oooo0?ooo`020?oo
o`0305hV1@3oool0oooo00<0oooo0P1N9PD30?ooo`0405hV1@3oool0oooo05hV1@80oooo00<0GRH5
0?ooo`3oool00P3oool405hV1@@0oooo00<0GRH50?ooo`3oool00`1N9PD00`3oool0GRH505hV1@02
0?ooo`0405hV1@3oool0oooo05hV1@80oooo00<0GRH50?ooo`3oool01P3oool405hV1@H0oooo00D0
GRH50?ooo`1N9PD0GRH50?ooo`0;05hV1@L0oooo00060?ooo`@0GRH50P3N^8L405hV1@040=jhQ`1N
9PD0GRH50=jhQ`<0GRH500<0oooo05hV1@1N9PD00`1N9PD40=jhQ`@0GRH50P3oool505hV1@030=jh
Q`1N9PD0GRH50080GRH50P3N^8L305hV1@050=jhQ`1N9PD0GRH505hV1@3oool00P1N9PD40=jhQ`80
GRH50P3oool01@1N9PD0g[R705hV1@1N9PD0g[R70080GRH500<0g[R705hV1@1N9PD00P1N9PD20=jh
Q`80GRH500<0oooo05hV1@3N^8L01@1N9PD00`3N^8L0GRH505hV1@020?ooo`80GRH50P3N^8L00`1N
9PD0oooo0?ooo`0E0?ooo``0GRH52`3N^8L<05hV1AH0oooo0P1N9PD20=jhQ`0305hV1@3oool0oooo
00@0GRH500P0g[R705hV1@1N9PD0oooo05hV1@3N^8L0GRH50?ooo`<0GRH50P3N^8L305hV1@040=jh
Q`1N9PD0GRH50=jhQ`80GRH500<0g[R705hV1@3oool00P1N9PD40=jhQ`80GRH50P3oool305hV1@04
0=jhQ`1N9PD0GRH505hV1@80g[R71@1N9PD01@3N^8L0GRH505hV1@3N^8L0GRH500<0oooo101N9PD4
0=jhQ`P0GRH500@0g[R705hV1@1N9PD0g[R7101N9PD20=jhQ`@0GRH51`3oool000H0oooo0`1N9PD4
0=jhQ`80GRH50`3N^8L00`1N9PD0g[R705hV1@0305hV1@d0g[R70P1N9PD0103oool0GRH505hV1@1N
9PD20=jhQ`80GRH51@3N^8L205hV1@80g[R70`1N9PD80=jhQ`D0GRH50`3N^8L305hV1@L0g[R70P1N
9PD20=jhQ`0305hV1@3N^8L0g[R700@0g[R70P1N9PD50=jhQ`0305hV1@3oool0oooo00d0oooo1`1N
9PDS0=jhQ`L0GRH53P3oool00`1N9PD0g[R70=jhQ`030=jhQ`80GRH51`3N^8L00`1N9PD0g[R70=jh
Q`0205hV1@L0g[R70`1N9PD30=jhQ`@0GRH5203N^8L405hV1@80g[R70P1N9PD50=jhQ`80GRH50P3N
^8L705hV1@d0g[R70`1N9PD0103N^8L0GRH50=jhQ`3N^8L305hV1@D0g[R70P1N9PD70?ooo`001P3o
ool205hV1@D0g[R70P1N9PD20=jhQ`<0GRH54`3N^8L405hV1@80g[R70P1N9PD50=jhQ`D0GRH5303N
^8L305hV1@<0g[R700<0GRH50=jhQ`3N^8L0203N^8L305hV1@L0g[R70P1N9PD50=jhQ`0305hV1@3o
ool0oooo00P0oooo1@1N9PDa0=jhQ`D0GRH52@3oool00`1N9PD0g[R70=jhQ`030=jhQ`80GRH51`3N
^8L405hV1@T0g[R70P1N9PD30=jhQ`80GRH5303N^8L505hV1@H0g[R700@0GRH50=jhQ`3N^8L0g[R7
0`1N9PDC0=jhQ`<0GRH50P3N^8L205hV1@H0g[R70P1N9PD70?ooo`001P3oool00`1N9PD0g[R70=jh
Q`050=jhQ`@0GRH5603N^8L405hV1@L0g[R70P1N9PD@0=jhQ`80GRH50P3N^8L00`1N9PD0g[R70=jh
Q`090=jhQ`80GRH5203N^8L00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3oool0oooo00@0oooo0`1N
9PDk0=jhQ`<0GRH51P3oool00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3N^8L0g[R700H0g[R70P1N
9PD;0=jhQ`0405hV1@3N^8L0g[R705hV1A00g[R70`1N9PD70=jhQ`@0GRH55`3N^8L505hV1@L0g[R7
00<0GRH50?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L01@3N^8L305hV1A/0g[R70P1N
9PD70=jhQ`80GRH54@3N^8L405hV1@`0g[R700<0GRH50=jhQ`3N^8L01P3N^8L205hV1@@0g[R700<0
GRH50?ooo`3oool01@1N9PE10=jhQ`D0GRH50P3oool00`1N9PD0g[R70=jhQ`020=jhQ`80GRH5203N
^8L205hV1@`0g[R70`1N9PDA0=jhQ`80GRH51`3N^8L305hV1AX0g[R70`1N9PD60=jhQ`80GRH51`3o
ool000H0oooo0P1N9PD50=jhQ`<0GRH57@3N^8L205hV1@D0g[R70P1N9PDC0=jhQ`80GRH53@3N^8L0
0`1N9PD0g[R70=jhQ`060=jhQ`80GRH50`3N^8L405hV1D/0g[R7101N9PD30=jhQ`80GRH5203N^8L0
0`1N9PD0g[R70=jhQ`0;0=jhQ`80GRH54`3N^8L205hV1@D0g[R70`1N9PDL0=jhQ`<0GRH51@3N^8L2
05hV1@L0oooo00060?ooo`<0GRH50`3N^8L205hV1B00g[R70P1N9PD30=jhQ`80GRH5503N^8L205hV
1@d0g[R700<0GRH50=jhQ`3N^8L01P3N^8L00`1N9PD0oooo05hV1@0305hV1E40g[R7101N9PD00`3o
ool0GRH50=jhQ`070=jhQ`0305hV1@3N^8L0g[R700/0g[R700<0GRH50=jhQ`3N^8L04P3N^8L305hV
1@<0g[R70P1N9PDP0=jhQ`80GRH50`3N^8L305hV1@L0oooo00060?ooo`P0GRH58@3N^8L605hV1AD0
g[R700<0GRH50=jhQ`3N^8L02`3N^8L205hV1@H0g[R700@0GRH50?ooo`1N9PD0GRH5F03N^8L00`1N
9PD0oooo05hV1@060=jhQ`80GRH53@3N^8L00`1N9PD0g[R70=jhQ`0C0=jhQ`H0GRH58@3N^8L805hV
1@L0oooo00060?ooo`80GRH500<0g[R705hV1@1N9PD00P1N9PDS0=jhQ`80GRH500<0g[R705hV1@1N
9PD05@3N^8L00`1N9PD0g[R70=jhQ`0;0=jhQ`@0GRH50P3N^8L405hV1E/0g[R7101N9PD20=jhQ`@0
GRH5303N^8L205hV1AD0g[R70P1N9PD00`3N^8L0GRH505hV1@0S0=jhQ`@0GRH500<0g[R705hV1@1N
9PD01`3oool000H0oooo00@0GRH50=jhQ`3N^8L0g[R70P1N9PDT0=jhQ`80GRH500<0g[R705hV1@3N
^8L05@3N^8L00`1N9PD0g[R70=jhQ`0;0=jhQ`0405hV1@3N^8L0GRH50?ooo`<0GRH5H@3N^8L505hV
1@030=jhQ`1N9PD0g[R700/0g[R700<0GRH50=jhQ`3N^8L0503N^8L205hV1@030=jhQ`1N9PD0GRH5
02@0g[R70P1N9PD30=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`0405hV1@3N^8L0g[R705hV
1BH0g[R70`1N9PDG0=jhQ`0305hV1@3N^8L0g[R700T0g[R71@1N9PEX0=jhQ`@0GRH52P3N^8L205hV
1AL0g[R70`1N9PDV0=jhQ`0405hV1@3N^8L0g[R705hV1@P0oooo00060?ooo`D0GRH59P3N^8L305hV
1AL0g[R70P1N9PD90=jhQ`@0GRH5J`3N^8L405hV1@T0g[R70P1N9PDG0=jhQ`80GRH59`3N^8L505hV
1@L0oooo00060?ooo`0405hV1@3N^8L0g[R705hV1BP0g[R70P1N9PDF0=jhQ`@0GRH51`3N^8L205hV
1G40g[R70P1N9PD60=jhQ`@0GRH55`3N^8L00`1N9PD0g[R70=jhQ`0W0=jhQ`0405hV1@3N^8L0g[R7
05hV1@L0oooo00070?ooo`<0GRH5:03N^8L205hV1AH0g[R70`1N9PD00`3N^8L0GRH505hV1@0505hV
1GD0g[R7201N9PD00`3N^8L0GRH50=jhQ`0F0=jhQ`0305hV1@3N^8L0g[R702L0g[R70`1N9PD80?oo
o`001P3oool305hV1BX0g[R700<0GRH50=jhQ`3N^8L0503N^8L00`1N9PD0g[R70=jhQ`020=jhQ`D0
GRH5M`3N^8L505hV1@@0g[R700<0GRH50=jhQ`3N^8L0503N^8L00`1N9PD0g[R70=jhQ`0X0=jhQ`<0
GRH51`3oool000L0oooo0P1N9PDZ0=jhQ`80GRH55@3N^8L0101N9PD0g[R70=jhQ`3N^8L305hV1Gd0
g[R70P1N9PD30=jhQ`80GRH55@3N^8L00`1N9PD0g[R70=jhQ`0Y0=jhQ`80GRH5203oool000L0oooo
00<0GRH50=jhQ`3N^8L0:P3N^8L00`1N9PD0g[R70=jhQ`0C0=jhQ`D0GRH5P@3N^8L505hV1AD0g[R7
00<0GRH50=jhQ`3N^8L0:P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jh
Q`0Z0=jhQ`80GRH54`3N^8L505hV1H<0g[R71@1N9PDC0=jhQ`0305hV1@3N^8L0g[R702/0g[R700<0
GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0:`3N^8L00`1N9PD0g[R70=jhQ`0A
0=jhQ`<0GRH5Q`3N^8L305hV1A<0g[R700<0GRH50=jhQ`3N^8L0:`3N^8L00`1N9PD0oooo0?ooo`06
0?ooo`001`3oool00`1N9PD0g[R70=jhQ`0[0=jhQ`80GRH5403N^8L305hV1H/0g[R70P1N9PD@0=jh
Q`<0GRH5;@3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0[0=jhQ`<0
GRH53P3N^8L205hV1Hl0g[R700<0GRH50=jhQ`3N^8L0303N^8L405hV1Bh0g[R700<0GRH50?ooo`3o
ool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L0;03N^8L00`1N9PD0g[R70=jhQ`0205hV1@/0g[R7
00<0GRH50=jhQ`3N^8L0T03N^8L00`1N9PD0g[R70=jhQ`0:0=jhQ`80GRH50P3N^8L00`1N9PD0g[R7
0=jhQ`0/0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R702`0g[R72@1N
9PD50=jhQ`80GRH5U03N^8L505hV1@D0g[R71`1N9PD^0=jhQ`0305hV1@3oool0oooo00D0oooo0006
0?ooo`0305hV1@3N^8L0g[R702`0g[R70P1N9PD40=jhQ`P0GRH5V@3N^8L705hV1@@0g[R70`1N9PD^
0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R702`0g[R700<0GRH50=jh
Q`3N^8L0103N^8L00`1N9PD0g[R70=jhQ`0305hV1I/0g[R70`1N9PD20=jhQ`0305hV1@3N^8L0g[R7
00<0g[R70P1N9PD^0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R702`0
g[R700<0GRH50=jhQ`3N^8L0103N^8L205hV1@030=jhQ`1N9PD0g[R709h0g[R700<0GRH50=jhQ`1N
9PD01`3N^8L00`1N9PD0g[R70=jhQ`0/0=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`0305hV
1@3N^8L0g[R702/0g[R700<0GRH50=jhQ`3N^8L0103N^8L305hV1J40g[R70`1N9PD60=jhQ`0305hV
1@3N^8L0g[R702/0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0:`3N
^8L205hV1@D0g[R70P1N9PFS0=jhQ`80GRH51@3N^8L205hV1Bd0g[R700<0GRH50?ooo`3oool01P3o
ool000L0oooo00<0GRH50=jhQ`3N^8L0:`3N^8L305hV1@<0g[R70P1N9PFU0=jhQ`80GRH50`3N^8L3
05hV1Bd0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0:P3N^8L205hV
1@030=jhQ`1N9PD0GRH50080GRH5Z@3N^8L405hV1@030=jhQ`1N9PD0g[R702`0g[R700<0GRH50?oo
o`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0:P3N^8L0101N9PD0g[R70=jhQ`3N^8L205hV
1J/0g[R70P1N9PD30=jhQ`0305hV1@3N^8L0g[R702X0g[R700<0GRH50?ooo`3oool01P3oool000P0
oooo00<0GRH50=jhQ`3N^8L0:03N^8L305hV1@030=jhQ`1N9PD0g[R70:h0g[R700@0GRH50=jhQ`1N
9PD0GRH5:`3N^8L00`1N9PD0oooo0?ooo`070?ooo`00203oool00`1N9PD0g[R70=jhQ`0X0=jhQ`04
05hV1@3N^8L0GRH505hV1K40g[R7101N9PDZ0=jhQ`80GRH5203oool000H0oooo101N9PDX0=jhQ`03
05hV1@3oool0GRH50080GRH5/@3N^8L405hV1BT0g[R7101N9PD70?ooo`001`3oool305hV1BP0g[R7
00@0GRH50?ooo`3oool0GRH5/`3N^8L00`1N9PD0oooo05hV1@0Y0=jhQ`@0GRH51`3oool000L0oooo
101N9PDV0=jhQ`0405hV1@3oool0GRH505hV1KD0g[R70`1N9PDW0=jhQ`@0GRH5203oool000H0oooo
00D0GRH50=jhQ`3N^8L0g[R705hV1@0V0=jhQ`80GRH5^@3N^8L205hV1BH0g[R700@0GRH50=jhQ`3N
^8L0GRH5203oool000H0oooo00@0GRH50=jhQ`3N^8L0g[R70P1N9PDT0=jhQ`80GRH5^`3N^8L205hV
1B@0g[R70P1N9PD30=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`80GRH500@0g[R705hV1@1N
9PD0GRH58`3N^8L00`1N9PD0g[R70=jhQ`2k0=jhQ`0305hV1@3N^8L0g[R70240g[R70`1N9PD20=jh
Q`80GRH51`3oool000H0oooo101N9PD20=jhQ`80GRH58@3N^8L00`1N9PD0g[R70=jhQ`2m0=jhQ`03
05hV1@3N^8L0g[R701l0g[R70P1N9PD20=jhQ`@0GRH51`3oool000L0oooo00<0GRH50=jhQ`3N^8L0
0`3N^8L205hV1Al0g[R700<0GRH50=jhQ`3N^8L0_`3N^8L205hV1Al0g[R700<0GRH50=jhQ`3N^8L0
0`3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`030=jhQ`<0GRH5703N
^8L205hV1L<0g[R70P1N9PDL0=jhQ`80GRH51P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001P3oool0
0`1N9PD0g[R70=jhQ`050=jhQ`@0GRH56@3N^8L205hV1LD0g[R70P1N9PDI0=jhQ`@0GRH51`3N^8L0
0`1N9PD0oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jhQ`050=jhQ`0305hV1@3N^8L0g[R7
0080GRH55P3N^8L305hV1LL0g[R70`1N9PDF0=jhQ`80GRH50P3N^8L00`1N9PD0g[R70=jhQ`040=jh
Q`80GRH51`3oool000L0oooo00<0GRH50=jhQ`3N^8L00`3N^8L805hV1A80g[R70P1N9PD00`3oool0
GRH50=jhQ`380=jhQ`0405hV1@3oool0GRH505hV1A80g[R7201N9PD50=jhQ`0305hV1@3oool0oooo
00H0oooo00060?ooo`<0GRH50`3N^8L405hV1@@0g[R7101N9PD<0=jhQ`D0GRH500<0oooo05hV1@3N
^8L0b03N^8L0101N9PD0oooo05hV1@3N^8L205hV1@`0g[R7101N9PD40=jhQ`D0GRH50`3N^8L305hV
1@L0oooo00060?ooo`P0GRH5203N^8L?05hV1@030=jhQ`1N9PD0GRH50080GRH5b`3N^8L405hV1@03
0=jhQ`1N9PD0GRH500`0GRH5203N^8L205hV1@030?ooo`1N9PD0GRH500<0GRH5203oool000H0oooo
00<0GRH50=jhQ`3N^8L00`1N9PD<0=jhQ`@0GRH500@0g[R705hV1@1N9PD0GRH50P3N^8L205hV1@<0
g[R70P1N9PG=0=jhQ`80GRH50`3N^8L205hV1@<0g[R70P1N9PD0103N^8L0GRH505hV1@1N9PD<0=jh
Q`@0GRH50P3N^8L00`1N9PD0oooo0?ooo`050?ooo`001`3oool00`1N9PD0g[R705hV1@0@0=jhQ`80
GRH500<0g[R705hV1@1N9PD0103N^8L205hV1@030=jhQ`1N9PD0g[R70=00g[R700@0GRH50=jhQ`1N
9PD0GRH51@3N^8L00`1N9PD0g[R705hV1@0@0=jhQ`80GRH500<0g[R705hV1@3oool01`3oool000L0
oooo0`1N9PDA0=jhQ`<0GRH51P3N^8L205hV1M<0g[R70P1N9PD60=jhQ`<0GRH54@3N^8L305hV1@P0
oooo00060?ooo`<0GRH54`3N^8L205hV1@H0g[R70P1N9PGC0=jhQ`80GRH51P3N^8L205hV1A<0g[R7
0`1N9PD70?ooo`001`3oool00`1N9PD0g[R70=jhQ`0B0=jhQ`80GRH51@3N^8L205hV1MD0g[R700<0
GRH50=jhQ`3N^8L00`3N^8L205hV1A@0g[R700<0GRH50?ooo`3oool01`3oool000L0oooo00<0GRH5
0=jhQ`3N^8L04`3N^8L205hV1@@0g[R700<0GRH50=jhQ`3N^8L0e@3N^8L00`1N9PD0g[R70=jhQ`02
0=jhQ`80GRH55@3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0C0=jh
Q`<0GRH500<0g[R705hV1@1N9PD0f03N^8L305hV1@040=jhQ`1N9PD0GRH505hV1AD0g[R700<0GRH5
0?ooo`3oool01P3oool000H0oooo00<0GRH50=jhQ`3N^8L05@3N^8L00`1N9PD0g[R705hV1@0205hV
1MT0g[R70`1N9PD00`3N^8L0GRH50=jhQ`0F0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`03
05hV1@3N^8L0g[R701D0g[R700@0GRH50=jhQ`3N^8L0GRH5f`3N^8L0101N9PD0g[R70=jhQ`1N9PDG
0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R701D0g[R70`1N9PGM0=jh
Q`<0GRH55`3N^8L00`1N9PD0oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jhQ`0E0=jhQ`80
GRH5g`3N^8L205hV1AH0g[R70P1N9PD70?ooo`001P3oool00`1N9PD0g[R70=jhQ`0E0=jhQ`80GRH5
g`3N^8L205hV1AH0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo00<0GRH50=jhQ`3N^8L0503N
^8L205hV1N40g[R700<0GRH50=jhQ`3N^8L0503N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool0
0`1N9PD0g[R70=jhQ`0C0=jhQ`0305hV1@3N^8L0g[R70>40g[R700<0GRH50=jhQ`3N^8L04`3N^8L0
0`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0C0=jhQ`0305hV1@3N^8L0g[R7
0>40g[R700<0GRH50=jhQ`3N^8L04`3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool205hV1A<0
g[R700<0GRH50=jhQ`3N^8L0h`3N^8L00`1N9PD0g[R70=jhQ`0A0=jhQ`80GRH5203oool000H0oooo
00@0GRH50=jhQ`1N9PD0GRH54P3N^8L00`1N9PD0g[R70=jhQ`3S0=jhQ`0305hV1@3N^8L0g[R70140
g[R700<0GRH50=jhQ`1N9PD01`3oool000L0oooo0`1N9PD@0=jhQ`80GRH5i`3N^8L00`1N9PD0g[R7
0=jhQ`0>0=jhQ`@0GRH5203oool000H0oooo00@0GRH50=jhQ`3N^8L0g[R70P1N9PD=0=jhQ`80GRH5
j@3N^8L205hV1@d0g[R700D0GRH50=jhQ`3N^8L0g[R705hV1@080?ooo`001P3oool00`1N9PD0g[R7
0=jhQ`020=jhQ`80GRH52`3N^8L00`1N9PD0oooo05hV1@3Y0=jhQ`0305hV1@3oool0GRH500/0g[R7
0P1N9PD40=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0405hV1@3N^8L0g[R70=jhQ`L0GRH5
0`3N^8L605hV1N/0g[R71P1N9PD30=jhQ`H0GRH50`3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3o
ool405hV1@D0g[R71@1N9PD00`3N^8L0GRH505hV1@0205hV1N/0g[R7101N9PD00`3N^8L0GRH505hV
1@0205hV1@D0g[R71@1N9PD80?ooo`001P3oool0101N9PD0g[R705hV1@1N9PD80=jhQ`80GRH50`3N
^8L205hV1Nd0g[R70P1N9PD20=jhQ`<0GRH5203N^8L205hV1@030=jhQ`1N9PD0oooo00H0oooo0007
0?ooo`80GRH52P3N^8L0101N9PD0g[R70=jhQ`3N^8L205hV1Nd0g[R70P1N9PD20=jhQ`80GRH52P3N
^8L205hV1@P0oooo00070?ooo`0305hV1@3N^8L0g[R700T0g[R70P1N9PD20=jhQ`0305hV1@3N^8L0
g[R70>d0g[R700@0GRH50=jhQ`3N^8L0GRH52`3N^8L00`1N9PD0oooo0?ooo`070?ooo`001`3oool0
0`1N9PD0g[R70=jhQ`0:0=jhQ`<0GRH5l@3N^8L305hV1@`0g[R700<0GRH50?ooo`3oool01P3oool0
00H0oooo00<0GRH50=jhQ`3N^8L02`3N^8L305hV1O40g[R70`1N9PD<0=jhQ`0305hV1@3oool0oooo
00H0oooo00060?ooo`0305hV1@3N^8L0g[R700/0g[R70P1N9PGc0=jhQ`80GRH53@3N^8L00`1N9PD0
oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jhQ`0;0=jhQ`80GRH5l`3N^8L205hV1@d0g[R7
00<0GRH50?ooo`3oool01@3oool000L0oooo00<0GRH50=jhQ`3N^8L02P3N^8L00`1N9PD0g[R70=jh
Q`3b0=jhQ`80GRH5303N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0:
0=jhQ`0305hV1@3N^8L0g[R70?<0g[R70P1N9PD;0=jhQ`0305hV1@3oool0oooo00H0oooo00080?oo
o`0305hV1@3N^8L0g[R700P0g[R700<0GRH50=jhQ`3N^8L0m@3N^8L00`1N9PD0g[R70=jhQ`080=jh
Q`0305hV1@3oool0oooo00L0oooo00070?ooo`<0GRH5203N^8L00`1N9PD0g[R70=jhQ`3f0=jhQ`80
GRH5203N^8L305hV1@P0oooo00060?ooo`0305hV1@3N^8L0g[R700<0GRH51@3N^8L205hV1OT0g[R7
0`1N9PD50=jhQ`80GRH500<0g[R705hV1@1N9PD01`3oool000L0oooo00<0GRH50=jhQ`1N9PD02@1N
9PGi0=jhQ`X0GRH500<0g[R705hV1@1N9PD01`3oool000P0oooo0P1N9PD40=jhQ`80GRH500<0g[R7
05hV1@3N^8L0n@3N^8L205hV1@040=jhQ`1N9PD0GRH505hV1@@0g[R700<0GRH50?ooo`3oool01`3o
ool000L0oooo00<0GRH50=jhQ`3N^8L01@3N^8L305hV1O/0g[R70`1N9PD70=jhQ`0305hV1@3oool0
oooo00H0oooo00060?ooo`0305hV1@3N^8L0g[R700H0g[R70P1N9PGl0=jhQ`80GRH5203N^8L00`1N
9PD0oooo0?ooo`060?ooo`001P3oool00`1N9PD0g[R70=jhQ`060=jhQ`80GRH5o@3N^8L00`1N9PD0
g[R70=jhQ`060=jhQ`0305hV1@3oool0oooo00H0oooo00060?ooo`0305hV1@3N^8L0g[R700L0g[R7
00<0GRH50=jhQ`3N^8L0n`3N^8L00`1N9PD0g[R70=jhQ`070=jhQ`0305hV1@3oool0oooo00D0oooo
00070?ooo`0305hV1@3N^8L0g[R700D0g[R700<0GRH50=jhQ`3N^8L0o03N^8L205hV1@L0g[R700<0
GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0103N^8L205hV1Ol0g[R700<0GRH5
0=jhQ`3N^8L0103N^8L00`1N9PD0oooo0?ooo`070?ooo`00203oool00`1N9PD0g[R70=jhQ`030=jh
Q`80GRH5o`3N^8L205hV1@D0g[R700<0GRH50?ooo`3oool01`3oool000T0oooo1P1N9PGo0=jhQ`40
g[R700<0GRH50?ooo`1N9PD0101N9PD:0?ooo`001`3oool205hV1@80g[R70P1N9PD00`3oool0GRH5
0=jhQ`3o0=jhQ`40g[R700@0GRH50?ooo`1N9PD0GRH50P3N^8L205hV1@P0oooo00060?ooo`0305hV
1@3N^8L0g[R700<0g[R70P1N9PGo0=jhQ`<0g[R70P1N9PD50=jhQ`0305hV1@3oool0oooo00H0oooo
00060?ooo`0305hV1@3N^8L0g[R700@0g[R700<0GRH50=jhQ`3N^8L0o`3N^8L20=jhQ`0305hV1@3N
^8L0g[R700@0g[R700<0GRH50?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L0103N^8L0
0`1N9PD0g[R70=jhQ`3o0=jhQ`80g[R700<0GRH50=jhQ`3N^8L0103N^8L00`1N9PD0oooo0?ooo`05
0?ooo`001`3oool00`1N9PD0g[R70=jhQ`020=jhQ`0305hV1@3N^8L0g[R70?l0g[R70`3N^8L205hV
1@@0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo0P1N9PD30=jhQ`0305hV1@3N^8L0g[R70?l0
g[R7103N^8L0101N9PD0g[R70=jhQ`3N^8L205hV1@P0oooo00090?ooo`@0GRH5o`3N^8L60=jhQ`@0
GRH52P3oool000/0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L50=jhQ`0305hV1@3oool0oooo00/0oooo
000;0?ooo`0305hV1@3N^8L0g[R70?l0g[R71P3N^8L00`1N9PD0oooo0?ooo`0:0?ooo`002`3oool0
0`1N9PD0g[R70=jhQ`3o0=jhQ`H0g[R700<0GRH50?ooo`3oool02P3oool000/0oooo00<0GRH50=jh
Q`3N^8L0o`3N^8L60=jhQ`0305hV1@3oool0oooo00X0oooo000;0?ooo`0305hV1@3N^8L0g[R70?l0
g[R71P3N^8L00`1N9PD0oooo0?ooo`0:0?ooo`002P3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`L0g[R7
00<0GRH50?ooo`3oool02P3oool000X0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L80=jhQ`0305hV1@3o
ool0oooo00T0oooo000:0?ooo`0305hV1@3N^8L0g[R70?l0g[R7203N^8L00`1N9PD0oooo0?ooo`09
0?ooo`002P3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`P0g[R700<0GRH50?ooo`3oool02@3oool000T0
oooo00<0GRH50=jhQ`3N^8L0o`3N^8L:0=jhQ`0305hV1@3oool0oooo00P0oooo00090?ooo`0305hV
1@3N^8L0g[R70?l0g[R72P3N^8L00`1N9PD0oooo0?ooo`080?ooo`002@3oool00`1N9PD0g[R70=jh
Q`3o0=jhQ`X0g[R700<0GRH50?ooo`3oool0203oool000T0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L:
0=jhQ`0305hV1@3oool0oooo00P0oooo00090?ooo`0305hV1@3N^8L0g[R70?l0g[R72P3N^8L00`1N
9PD0oooo0?ooo`080?ooo`00203oool00`1N9PD0g[R70=jhQ`3o0=jhQ``0g[R700<0GRH50?ooo`3o
ool01`3oool000P0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L<0=jhQ`0305hV1@3oool0oooo00L0oooo
00080?ooo`0305hV1@3N^8L0g[R70?l0g[R7303N^8L00`1N9PD0oooo0?ooo`070?ooo`00203oool0
0`1N9PD0g[R70=jhQ`3o0=jhQ``0g[R700<0GRH50?ooo`3oool01`3oool000P0oooo00<0GRH50=jh
Q`3N^8L0o`3N^8L<0=jhQ`0305hV1@3oool0oooo00L0oooo00080?ooo`0305hV1@3N^8L0g[R70?l0
g[R7303N^8L00`1N9PD0oooo0?ooo`070?ooo`001`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`d0g[R7
00<0GRH50?ooo`3oool01`3oool000L0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3o
ool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`06
0?ooo`001`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`h0g[R700<0GRH50?ooo`3oool01P3oool000L0
oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV
1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jh
Q`3o0=jhQ`h0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>
0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R70?l0g[R73P3N^8L00`1N
9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`h0g[R700<0GRH50?ooo`3o
ool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3oool0oooo00H0oooo
00070?ooo`0305hV1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001P3oool0
0`1N9PD0g[R70=jhQ`3o0=jhQ`l0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo00<0GRH50=jh
Q`3N^8L0o`3N^8L@0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R70?l0
g[R7403N^8L00`1N9PD0oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jhQ`3o0=jhQa00g[R7
00<0GRH50?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L@0=jhQ`0305hV1@3o
ool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R70?l0g[R7403N^8L00`1N9PD0oooo0?ooo`05
0?ooo`001P3oool00`1N9PD0g[R70=jhQ`3o0=jhQa00g[R700<0GRH50?ooo`3oool01@3oool000H0
oooo00<0GRH50=jhQ`3N^8L0o`3N^8L@0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV
1@3N^8L0g[R70?l0g[R7403N^8L00`1N9PD0oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jh
Q`3o0=jhQa00g[R700<0GRH50?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L@
0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R70?l0g[R7403N^8L00`1N
9PD0oooo0?ooo`050?ooo`001P3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`l0g[R700<0GRH50?ooo`3o
ool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3oool0oooo00H0oooo
00070?ooo`0305hV1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool0
0`1N9PD0g[R70=jhQ`3o0=jhQ`h0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jh
Q`3N^8L0o`3N^8L>0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R70?l0
g[R73P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`h0g[R7
00<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3o
ool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`06
0?ooo`001`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`h0g[R700<0GRH50?ooo`3oool01P3oool000L0
oooo00<0GRH50=jhQ`3N^8L0o`3N^8L>0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV
1@3N^8L0g[R70?l0g[R73P3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jh
Q`3o0=jhQ`d0g[R700<0GRH50?ooo`3oool01`3oool000P0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L<
0=jhQ`0305hV1@3oool0oooo00L0oooo00080?ooo`0305hV1@3N^8L0g[R70?l0g[R7303N^8L00`1N
9PD0oooo0?ooo`070?ooo`00203oool00`1N9PD0g[R70=jhQ`3o0=jhQ``0g[R700<0GRH50?ooo`3o
ool01`3oool000P0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L<0=jhQ`0305hV1@3oool0oooo00L0oooo
00080?ooo`0305hV1@3N^8L0g[R70?l0g[R7303N^8L00`1N9PD0oooo0?ooo`070?ooo`00203oool0
0`1N9PD0g[R70=jhQ`3o0=jhQ``0g[R700<0GRH50?ooo`3oool01`3oool000T0oooo00<0GRH50=jh
Q`3N^8L0o`3N^8L:0=jhQ`0305hV1@3oool0oooo00P0oooo00090?ooo`0305hV1@3N^8L0g[R70?l0
g[R72P3N^8L00`1N9PD0oooo0?ooo`080?ooo`002@3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`X0g[R7
00<0GRH50?ooo`3oool0203oool000T0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L:0=jhQ`0305hV1@3o
ool0oooo00P0oooo00090?ooo`0305hV1@3N^8L0g[R70?l0g[R72P3N^8L00`1N9PD0oooo0?ooo`08
0?ooo`002P3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`P0g[R700<0GRH50?ooo`3oool02@3oool000X0
oooo00<0GRH50=jhQ`3N^8L0o`3N^8L80=jhQ`0305hV1@3oool0oooo00T0oooo000:0?ooo`0305hV
1@3N^8L0g[R70?l0g[R7203N^8L00`1N9PD0oooo0?ooo`090?ooo`002P3oool00`1N9PD0g[R70=jh
Q`3o0=jhQ`L0g[R700<0GRH50?ooo`3oool02P3oool000/0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L6
0=jhQ`0305hV1@3oool0oooo00X0oooo000;0?ooo`0305hV1@3N^8L0g[R70?l0g[R71P3N^8L00`1N
9PD0oooo0?ooo`0:0?ooo`002`3oool00`1N9PD0g[R70=jhQ`3o0=jhQ`H0g[R700<0GRH50?ooo`3o
ool02P3oool000/0oooo00<0GRH50=jhQ`3N^8L0o`3N^8L60=jhQ`0305hV1@3oool0oooo00X0oooo
000;0?ooo`0305hV1@3N^8L0g[R70?l0g[R71@3N^8L00`1N9PD0oooo0?ooo`0;0?ooo`002@3oool2
05hV1@030?ooo`1N9PD0g[R70?l0g[R71@3N^8L0101N9PD0oooo05hV1@1N9PD:0?ooo`001`3oool2
05hV1@80g[R70P1N9PGo0=jhQ`H0g[R70P1N9PD20=jhQ`80GRH5203oool000H0oooo00<0GRH50=jh
Q`3N^8L00`3N^8L00`1N9PD0g[R70=jhQ`3o0=jhQ`<0g[R700<0GRH50=jhQ`3N^8L00`3N^8L00`1N
9PD0oooo0?ooo`060?ooo`001P3oool00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3N^8L0g[R70?l0
g[R70P3N^8L00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV
1@3N^8L0g[R700@0g[R700<0GRH50=jhQ`3N^8L0o`3N^8L20=jhQ`0305hV1@3N^8L0g[R700@0g[R7
00<0GRH50?ooo`3oool01@3oool000L0oooo00<0GRH50=jhQ`3N^8L00P3N^8L205hV1Ol0g[R7103N
^8L205hV1@@0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo0P1N9PD30=jhQ`0305hV1@3oool0
GRH50?l0g[R70P3N^8L00`1N9PD0oooo05hV1@030=jhQ`80GRH5203oool000T0oooo1P1N9PGo0=jh
Q`40g[R700<0GRH50?ooo`3oool0101N9PD:0?ooo`00203oool205hV1@@0g[R70P1N9PGo0=jhQ`<0
GRH5103N^8L205hV1@P0oooo00070?ooo`0305hV1@3N^8L0g[R700D0g[R700<0GRH50=jhQ`3N^8L0
o@3N^8L00`1N9PD0g[R70=jhQ`050=jhQ`0305hV1@3oool0oooo00H0oooo00060?ooo`0305hV1@3N
^8L0g[R700H0g[R700<0GRH50=jhQ`3N^8L0o03N^8L00`1N9PD0g[R70=jhQ`060=jhQ`0305hV1@3o
ool0oooo00H0oooo00060?ooo`0305hV1@3N^8L0g[R700H0g[R70P1N9PGm0=jhQ`0305hV1@3N^8L0
g[R700H0g[R70P1N9PD70?ooo`001P3oool00`1N9PD0g[R70=jhQ`060=jhQ`80GRH5o@3N^8L00`1N
9PD0g[R70=jhQ`060=jhQ`80GRH51`3oool000L0oooo00<0GRH50=jhQ`3N^8L01@3N^8L205hV1Od0
g[R70P1N9PD70=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R700@0g[R7
101N9PGk0=jhQ`<0GRH51P3N^8L00`1N9PD0oooo0?ooo`070?ooo`00203oool00`1N9PD0g[R70=jh
Q`030=jhQ`80GRH500<0g[R705hV1@3N^8L0n@3N^8L205hV1@030=jhQ`1N9PD0GRH500D0g[R700<0
GRH50?ooo`3oool01`3oool000L0oooo00<0GRH50=jhQ`1N9PD02@1N9PGi0=jhQ`X0GRH500<0g[R7
05hV1@3oool01`3oool000H0oooo00<0GRH50=jhQ`3N^8L00P1N9PD50=jhQ`<0GRH5n@3N^8L205hV
1@D0g[R70`1N9PD20=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`<0GRH5203N^8L205hV1OL0
g[R70P1N9PD80=jhQ`<0GRH5203oool000P0oooo00<0GRH50=jhQ`3N^8L0203N^8L00`1N9PD0g[R7
0=jhQ`3e0=jhQ`0305hV1@3N^8L0g[R700P0g[R700<0GRH50?ooo`3oool01`3oool000L0oooo00<0
GRH50=jhQ`3N^8L02P3N^8L00`1N9PD0g[R70=jhQ`3c0=jhQ`0305hV1@3N^8L0g[R700X0g[R700<0
GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L02P3N^8L00`1N9PD0g[R70=jhQ`3b
0=jhQ`80GRH5303N^8L00`1N9PD0oooo0?ooo`060?ooo`001P3oool00`1N9PD0g[R70=jhQ`0;0=jh
Q`80GRH5l`3N^8L205hV1@`0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo00<0GRH50=jhQ`3N
^8L02`3N^8L205hV1O<0g[R70P1N9PD=0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV
1@3N^8L0g[R700/0g[R70`1N9PGa0=jhQ`<0GRH53@3N^8L00`1N9PD0oooo0?ooo`050?ooo`001`3o
ool00`1N9PD0g[R70=jhQ`0:0=jhQ`<0GRH5l@3N^8L305hV1@`0g[R700<0GRH50?ooo`3oool01P3o
ool000L0oooo00<0GRH50=jhQ`3N^8L02P3N^8L0101N9PD0g[R705hV1@1N9PG_0=jhQ`80GRH500<0
g[R705hV1@1N9PD02`3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool205hV1@X0g[R700@0GRH5
0=jhQ`3N^8L0g[R70P1N9PG]0=jhQ`80GRH50P3N^8L205hV1@X0g[R70P1N9PD80?ooo`001P3oool0
0`1N9PD0g[R705hV1@090=jhQ`80GRH50`3N^8L205hV1Nd0g[R70P1N9PD30=jhQ`80GRH5203N^8L2
05hV1@030=jhQ`1N9PD0oooo00H0oooo00070?ooo`D0GRH50`3N^8L605hV1@80g[R70`1N9PG[0=jh
Q`<0GRH50P3N^8L505hV1@<0g[R71P1N9PD80?ooo`001P3oool0101N9PD0g[R70=jhQ`3N^8L605hV
1@@0g[R71P1N9PG[0=jhQ`D0GRH5103N^8L605hV1@<0g[R700<0GRH50?ooo`3oool01P3oool000H0
oooo00<0GRH50=jhQ`3N^8L00P3N^8L305hV1@P0g[R70`1N9PD00`3oool0GRH50=jhQ`3X0=jhQ`04
05hV1@3oool0GRH505hV1@P0g[R7101N9PD40=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`03
05hV1@3N^8L0g[R70080GRH5303N^8L305hV1NT0g[R70P1N9PD<0=jhQ`<0GRH50P3N^8L00`1N9PD0
oooo0?ooo`060?ooo`001`3oool305hV1A00g[R70P1N9PGW0=jhQ`0305hV1@3N^8L0g[R700h0g[R7
101N9PD80?ooo`001P3oool0101N9PD0g[R705hV1@1N9PDA0=jhQ`0305hV1@3N^8L0g[R70>D0g[R7
00<0GRH50=jhQ`3N^8L03`3N^8L205hV1@030=jhQ`1N9PD0oooo00H0oooo00070?ooo`80GRH54`3N
^8L00`1N9PD0g[R70=jhQ`3S0=jhQ`0305hV1@3N^8L0g[R70140g[R70P1N9PD80?ooo`001`3oool0
0`1N9PD0g[R70=jhQ`0B0=jhQ`80GRH5h`3N^8L00`1N9PD0g[R70=jhQ`0B0=jhQ`0305hV1@3oool0
oooo00L0oooo00070?ooo`0305hV1@3N^8L0g[R701<0g[R700<0GRH50=jhQ`3N^8L0h@3N^8L00`1N
9PD0g[R70=jhQ`0C0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R701<0
g[R70P1N9PGQ0=jhQ`80GRH55@3N^8L00`1N9PD0oooo0?ooo`060?ooo`001P3oool00`1N9PD0g[R7
0=jhQ`0D0=jhQ`<0GRH5g`3N^8L205hV1AH0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo00<0
GRH50=jhQ`3N^8L05@3N^8L205hV1Ml0g[R70P1N9PDG0=jhQ`0305hV1@3oool0oooo00D0oooo0006
0?ooo`0305hV1@3N^8L0g[R701D0g[R70`1N9PGM0=jhQ`<0GRH55`3N^8L00`1N9PD0oooo0?ooo`05
0?ooo`001P3oool00`1N9PD0g[R70=jhQ`0E0=jhQ`0405hV1@3N^8L0g[R705hV1M/0g[R700@0GRH5
0=jhQ`3N^8L0GRH55P3N^8L205hV1@L0oooo00060?ooo`0305hV1@3N^8L0g[R701D0g[R700<0GRH5
0=jhQ`1N9PD00P1N9PGI0=jhQ`<0GRH500<0g[R705hV1@3N^8L05@3N^8L00`1N9PD0oooo0?ooo`06
0?ooo`001P3oool00`1N9PD0g[R70=jhQ`0E0=jhQ`80GRH500<0g[R705hV1@1N9PD0f03N^8L305hV
1@030=jhQ`1N9PD0GRH501H0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N
^8L04`3N^8L205hV1@@0g[R700<0GRH50=jhQ`3N^8L0e@3N^8L00`1N9PD0g[R70=jhQ`030=jhQ`03
05hV1@3N^8L0g[R701<0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L0
4`3N^8L00`1N9PD0g[R70=jhQ`030=jhQ`80GRH5e@3N^8L00`1N9PD0g[R70=jhQ`040=jhQ`0305hV
1@3N^8L0g[R701<0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo0`1N9PDC0=jhQ`80GRH51P3N
^8L205hV1M<0g[R70P1N9PD60=jhQ`80GRH54`3N^8L305hV1@L0oooo00070?ooo`80GRH54`3N^8L2
05hV1@H0g[R70P1N9PGC0=jhQ`80GRH51P3N^8L205hV1A<0g[R70P1N9PD80?ooo`001`3oool00`1N
9PD0g[R705hV1@0@0=jhQ`80GRH500<0g[R705hV1@1N9PD0103N^8L205hV1@030=jhQ`1N9PD0g[R7
0=00g[R700@0GRH50=jhQ`1N9PD0GRH5103N^8L205hV1@030=jhQ`1N9PD0g[R700l0g[R70P1N9PD0
0`3N^8L0GRH50?ooo`070?ooo`001P3oool00`1N9PD0g[R70=jhQ`0305hV1@d0g[R70`1N9PD00`3N
^8L0GRH505hV1@030=jhQ`80GRH50`3N^8L205hV1Ld0g[R70P1N9PD30=jhQ`80GRH50`3N^8L205hV
1@030=jhQ`1N9PD0GRH500h0g[R70`1N9PD20=jhQ`0305hV1@3oool0oooo00D0oooo00070?ooo`D0
GRH5303N^8L=05hV1@030=jhQ`1N9PD0GRH50080GRH5b`3N^8L405hV1@030=jhQ`1N9PD0GRH500X0
GRH5303N^8L705hV1@L0oooo00060?ooo`@0GRH50P3N^8L505hV1@D0g[R70P1N9PD;0=jhQ`H0GRH5
00<0oooo05hV1@3N^8L0b03N^8L00`1N9PD0oooo05hV1@0405hV1@/0g[R71@1N9PD40=jhQ`@0GRH5
0`3N^8L305hV1@L0oooo00070?ooo`0305hV1@3N^8L0g[R700<0g[R72@1N9PDA0=jhQ`80GRH500<0
oooo05hV1@3N^8L0b03N^8L00`1N9PD0oooo05hV1@0205hV1A40g[R7201N9PD50=jhQ`0305hV1@3o
ool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0g[R700@0g[R700<0GRH50=jhQ`3N^8L00`1N9PDE
0=jhQ`<0GRH5a`3N^8L305hV1AH0g[R70P1N9PD20=jhQ`0305hV1@3N^8L0g[R700D0g[R700<0GRH5
0?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L01@3N^8L405hV1AT0g[R70P1N9PG50=jh
Q`80GRH56@3N^8L405hV1@L0g[R700<0GRH50?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N
^8L01@3N^8L205hV1A`0g[R70P1N9PG30=jhQ`80GRH56`3N^8L305hV1@H0g[R700<0GRH50?ooo`3o
ool01P3oool000L0oooo00<0GRH50=jhQ`3N^8L00`3N^8L205hV1Ah0g[R70P1N9PG10=jhQ`80GRH5
7P3N^8L205hV1@D0g[R700<0GRH50?ooo`3oool01P3oool000H0oooo0`1N9PD30=jhQ`80GRH58@3N
^8L00`1N9PD0g[R70=jhQ`2m0=jhQ`80GRH5803N^8L205hV1@<0g[R70`1N9PD70?ooo`001`3oool6
05hV1B<0g[R700<0GRH50=jhQ`3N^8L0^`3N^8L00`1N9PD0g[R70=jhQ`0Q0=jhQ`H0GRH5203oool0
00H0oooo00@0GRH50=jhQ`3N^8L0g[R70P1N9PDT0=jhQ`80GRH5^`3N^8L205hV1B@0g[R70P1N9PD2
0=jhQ`80GRH51`3oool000H0oooo00D0GRH50=jhQ`3N^8L0g[R705hV1@0V0=jhQ`80GRH5^@3N^8L2
05hV1BH0g[R700<0GRH50=jhQ`3N^8L00P1N9PD70?ooo`001`3oool405hV1BH0g[R700@0GRH50?oo
o`1N9PD0GRH5]@3N^8L305hV1BL0g[R7101N9PD80?ooo`001`3oool305hV1BP0g[R700@0GRH50?oo
o`3oool0GRH5/`3N^8L00`1N9PD0oooo05hV1@0Y0=jhQ`<0GRH5203oool000H0oooo101N9PDX0=jh
Q`0305hV1@3oool0GRH50080GRH5/@3N^8L405hV1BT0g[R7101N9PD70?ooo`00203oool00`1N9PD0
g[R70=jhQ`0X0=jhQ`@0GRH5/@3N^8L405hV1BX0g[R700<0GRH50?ooo`3oool01`3oool000P0oooo
00<0GRH50=jhQ`3N^8L0:03N^8L305hV1@030=jhQ`1N9PD0g[R70:h0g[R700@0GRH50=jhQ`1N9PD0
GRH5:`3N^8L00`1N9PD0oooo0?ooo`070?ooo`001`3oool00`1N9PD0g[R70=jhQ`0Z0=jhQ`0405hV
1@3N^8L0g[R70=jhQ`80GRH5Z`3N^8L205hV1@<0g[R700<0GRH50=jhQ`3N^8L0:P3N^8L00`1N9PD0
oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0Z0=jhQ`80GRH500<0g[R705hV1@1N9PD0
0P1N9PFY0=jhQ`@0GRH500<0g[R705hV1@3N^8L0;03N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3o
ool00`1N9PD0g[R70=jhQ`0[0=jhQ`<0GRH50`3N^8L205hV1JH0g[R70P1N9PD20=jhQ`<0GRH5;@3N
^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0[0=jhQ`80GRH51@3N^8L2
05hV1J<0g[R70P1N9PD50=jhQ`80GRH5;@3N^8L00`1N9PD0oooo0?ooo`060?ooo`001`3oool00`1N
9PD0g[R70=jhQ`0[0=jhQ`0305hV1@3N^8L0g[R700@0g[R70`1N9PFQ0=jhQ`<0GRH51P3N^8L00`1N
9PD0g[R70=jhQ`0[0=jhQ`0305hV1@3oool0oooo00H0oooo00060?ooo`0305hV1@3N^8L0g[R702`0
g[R700<0GRH50=jhQ`3N^8L0103N^8L205hV1@030=jhQ`1N9PD0g[R709h0g[R700<0GRH50=jhQ`1N
9PD01`3N^8L00`1N9PD0g[R70=jhQ`0/0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV
1@3N^8L0g[R702`0g[R700<0GRH50=jhQ`3N^8L0103N^8L00`1N9PD0g[R70=jhQ`0305hV1I/0g[R7
0`1N9PD20=jhQ`0305hV1@3N^8L0g[R700<0g[R70P1N9PD^0=jhQ`0305hV1@3oool0oooo00D0oooo
00060?ooo`0305hV1@3N^8L0g[R702`0g[R70`1N9PD30=jhQ`P0GRH5V@3N^8L805hV1@<0g[R70`1N
9PD^0=jhQ`0305hV1@3oool0oooo00D0oooo00060?ooo`0305hV1@3N^8L0g[R702`0g[R7201N9PD4
0=jhQ`@0GRH5U@3N^8L305hV1@@0g[R70P1N9PD00`3oool0GRH505hV1@0405hV1Bh0g[R700<0GRH5
0?ooo`3oool01@3oool000H0oooo00<0GRH50=jhQ`3N^8L0;03N^8L00`1N9PD0g[R70=jhQ`0305hV
1@P0g[R70`1N9PFC0=jhQ`80GRH5203N^8L405hV1@80g[R700<0GRH50=jhQ`3N^8L0;03N^8L00`1N
9PD0oooo0?ooo`050?ooo`001`3oool00`1N9PD0g[R70=jhQ`0[0=jhQ`@0GRH5303N^8L305hV1Hl0
g[R70P1N9PD<0=jhQ`D0GRH5;P3N^8L00`1N9PD0oooo0?ooo`050?ooo`001`3oool00`1N9PD0g[R7
0=jhQ`0[0=jhQ`80GRH5403N^8L305hV1H/0g[R70P1N9PD@0=jhQ`<0GRH5;@3N^8L00`1N9PD0oooo
0?ooo`060?ooo`001`3oool00`1N9PD0g[R70=jhQ`0[0=jhQ`80GRH54@3N^8L0101N9PD0oooo05hV
1@1N9PF70=jhQ`80GRH500<0oooo05hV1@3N^8L0403N^8L205hV1Bd0g[R700<0GRH50?ooo`3oool0
1P3oool000L0oooo00<0GRH50=jhQ`3N^8L0:P3N^8L205hV1A<0g[R71@1N9PF30=jhQ`D0GRH54`3N
^8L00`1N9PD0g[R70=jhQ`0[0=jhQ`0305hV1@3oool0oooo00H0oooo00070?ooo`0305hV1@3N^8L0
g[R702X0g[R700<0GRH50=jhQ`3N^8L04P3N^8L605hV1H40g[R71@1N9PDD0=jhQ`0305hV1@3N^8L0
g[R702/0g[R700<0GRH50?ooo`3oool01P3oool000L0oooo0P1N9PDZ0=jhQ`80GRH55@3N^8L0101N
9PD0g[R70=jhQ`3N^8L305hV1Gd0g[R70P1N9PD30=jhQ`80GRH55@3N^8L00`1N9PD0g[R70=jhQ`0Y
0=jhQ`80GRH5203oool000H0oooo0`1N9PDZ0=jhQ`80GRH55@3N^8L00`1N9PD0g[R70=jhQ`020=jh
Q`@0GRH5N@3N^8L405hV1@@0g[R700<0GRH50=jhQ`3N^8L04`3N^8L00`1N9PD0g[R70=jhQ`0Y0=jh
Q`<0GRH51`3oool000L0oooo0`1N9PDX0=jhQ`80GRH55`3N^8L00`1N9PD0g[R70=jhQ`0705hV1GD0
g[R71`1N9PD20=jhQ`0305hV1@3N^8L0g[R701D0g[R700<0GRH50=jhQ`3N^8L09`3N^8L305hV1@P0
oooo00060?ooo`0405hV1@3N^8L0g[R705hV1BP0g[R70P1N9PDG0=jhQ`<0GRH51`3N^8L00`1N9PD0
g[R70=jhQ`1`0=jhQ`80GRH51`3N^8L305hV1AL0g[R700<0GRH50=jhQ`3N^8L09`3N^8L0101N9PD0
g[R70=jhQ`1N9PD70?ooo`001P3oool505hV1BH0g[R70`1N9PDG0=jhQ`80GRH52@3N^8L305hV1Fd0
g[R70`1N9PD90=jhQ`80GRH55`3N^8L205hV1BL0g[R71@1N9PD70?ooo`001P3oool205hV1@030=jh
Q`1N9PD0GRH502H0g[R70`1N9PDF0=jhQ`80GRH52`3N^8L405hV1FT0g[R7101N9PD;0=jhQ`0305hV
1@3N^8L0g[R701D0g[R70`1N9PDV0=jhQ`0405hV1@3N^8L0g[R705hV1@P0oooo00060?ooo`0405hV
1@3N^8L0g[R70=jhQ`80GRH5903N^8L205hV1@030=jhQ`1N9PD0g[R701D0g[R70P1N9PD;0=jhQ`80
GRH500<0g[R705hV1@1N9PD00P1N9PES0=jhQ`@0GRH500<0g[R705hV1@1N9PD02`3N^8L00`1N9PD0
g[R70=jhQ`0E0=jhQ`0405hV1@3N^8L0GRH505hV1B@0g[R70P1N9PD30=jhQ`0305hV1@3oool0oooo
00D0oooo00060?ooo`80GRH50P3N^8L305hV1B<0g[R70P1N9PD00`3N^8L0GRH505hV1@0E0=jhQ`03
05hV1@3N^8L0g[R700/0g[R71@1N9PD0103N^8L0GRH505hV1@1N9PEM0=jhQ`@0GRH500<0g[R705hV
1@1N9PD00P1N9PD=0=jhQ`0305hV1@3N^8L0g[R701<0g[R70P1N9PD00`3N^8L0GRH505hV1@0S0=jh
Q`<0GRH50P3N^8L205hV1@L0oooo00060?ooo`P0GRH58@3N^8L605hV1AD0g[R700<0GRH50=jhQ`3N
^8L02`3N^8L305hV1@D0g[R70`1N9PEI0=jhQ`@0GRH51@3N^8L205hV1@d0g[R700<0GRH50=jhQ`3N
^8L04`3N^8L605hV1B40g[R7201N9PD70?ooo`001P3oool405hV1@80g[R70P1N9PDP0=jhQ`<0GRH5
0P3N^8L205hV1AD0g[R700<0GRH50=jhQ`3N^8L02`3N^8L00`1N9PD0g[R70=jhQ`050=jhQ`0305hV
1@3oool0oooo00<0GRH5D`3N^8L305hV1@030?ooo`1N9PD0g[R700H0g[R70P1N9PD=0=jhQ`0305hV
1@3N^8L0g[R701<0g[R70P1N9PD30=jhQ`80GRH5803N^8L205hV1@<0g[R70`1N9PD70?ooo`001P3o
ool205hV1@D0g[R70`1N9PDM0=jhQ`80GRH51@3N^8L205hV1A<0g[R70P1N9PD=0=jhQ`0305hV1@3N
^8L0g[R700H0g[R70`1N9PD20=jhQ`<0GRH5C@3N^8L305hV1@80g[R70`1N9PD80=jhQ`0305hV1@3N
^8L0g[R700X0g[R70`1N9PDC0=jhQ`0305hV1@3N^8L0g[R700@0g[R70P1N9PDM0=jhQ`80GRH51P3N
^8L205hV1@L0oooo00060?ooo`0305hV1@3N^8L0g[R700D0g[R70`1N9PDK0=jhQ`80GRH51`3N^8L2
05hV1A80g[R70P1N9PD=0=jhQ`0305hV1@3N^8L0g[R700H0g[R700<0GRH50=jhQ`3N^8L00`3N^8L0
0`1N9PD0oooo05hV1@0405hV1D<0g[R71P1N9PD50=jhQ`80GRH5203N^8L00`1N9PD0g[R70=jhQ`0:
0=jhQ`<0GRH54P3N^8L205hV1@L0g[R70`1N9PDJ0=jhQ`<0GRH51`3N^8L00`1N9PD0oooo0?ooo`05
0?ooo`001P3oool00`1N9PD0g[R70=jhQ`050=jhQ`D0GRH55`3N^8L405hV1@L0g[R70P1N9PD@0=jh
Q`80GRH500<0g[R705hV1@1N9PD02`3N^8L205hV1@P0g[R700<0GRH50=jhQ`3N^8L0103N^8L00`1N
9PD0oooo0?ooo`030?ooo`@0GRH5>`3N^8L405hV1@D0oooo00<0GRH50=jhQ`3N^8L0103N^8L00`1N
9PD0g[R70=jhQ`060=jhQ`80GRH52`3N^8L205hV1@030=jhQ`1N9PD0GRH500l0g[R70`1N9PD70=jh
Q`@0GRH5603N^8L405hV1@L0g[R700<0GRH50?ooo`3oool01@3oool000H0oooo0P1N9PD60=jhQ`04
05hV1@3N^8L0g[R70=jhQ`80GRH5503N^8L305hV1@80g[R70P1N9PD60=jhQ`@0GRH53@3N^8L205hV
1@<0g[R70P1N9PD90=jhQ`<0GRH5203N^8L00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3oool0oooo
00L0oooo1@1N9PDa0=jhQ`D0GRH52@3oool00`1N9PD0g[R70=jhQ`040=jhQ`0305hV1@3N^8L0g[R7
00H0g[R70`1N9PD90=jhQ`80GRH50`3N^8L205hV1@d0g[R71@1N9PD50=jhQ`0405hV1@3N^8L0g[R7
0=jhQ`<0GRH5503N^8L205hV1@80g[R700<0GRH50?ooo`1N9PD01@3N^8L205hV1@L0oooo00060?oo
o`80GRH51@3N^8L205hV1@<0g[R700<0GRH50=jhQ`1N9PD00`1N9PD>0=jhQ`D0GRH50P3N^8L205hV
1@D0g[R70P1N9PD20=jhQ`80GRH52`3N^8L305hV1@<0g[R70`1N9PD80=jhQ`0405hV1@3N^8L0g[R7
05hV1@H0g[R700<0GRH50?ooo`1N9PD0103N^8L00`1N9PD0oooo0?ooo`0=0?ooo`H0GRH59@3N^8L6
05hV1@l0oooo00<0GRH50=jhQ`3N^8L00P3N^8L00`1N9PD0oooo05hV1@060=jhQ`0305hV1@3N^8L0
g[R70080GRH51`3N^8L305hV1@80g[R7101N9PD;0=jhQ`80GRH50P3N^8L205hV1@D0g[R700@0GRH5
0=jhQ`3N^8L0g[R70P1N9PD0103N^8L0GRH505hV1@1N9PD>0=jhQ`<0GRH500<0g[R705hV1@3N^8L0
0P3N^8L205hV1@D0g[R70P1N9PD70?ooo`001P3oool405hV1@80g[R7101N9PD0103N^8L0GRH505hV
1@3N^8L305hV1@030?ooo`1N9PD0GRH50080GRH51P3N^8L405hV1@80oooo0`1N9PD20=jhQ`@0GRH5
0P3N^8L305hV1@030=jhQ`1N9PD0GRH500D0GRH50`3N^8L505hV1@030=jhQ`1N9PD0GRH50080g[R7
00<0GRH50=jhQ`1N9PD00P1N9PD30=jhQ`@0GRH500<0g[R705hV1@3oool00P1N9PD20=jhQ`80GRH5
0P3oool0101N9PD0g[R70=jhQ`3N^8L205hV1AD0oooo301N9PD=0=jhQ``0GRH55@3oool205hV1@<0
g[R700<0GRH50?ooo`3oool00P1N9PD20=jhQ`80GRH500D0oooo05hV1@3N^8L0GRH50?ooo`0205hV
1@<0g[R70`1N9PD0103N^8L0GRH50=jhQ`3N^8L205hV1@030=jhQ`1N9PD0GRH500<0GRH50`3N^8L7
05hV1@030=jhQ`1N9PD0GRH50080GRH50P3N^8L305hV1@80g[R7101N9PD20?ooo`D0GRH51@3N^8L7
05hV1@040=jhQ`1N9PD0GRH50=jhQ`D0GRH500<0g[R705hV1@1N9PD00P1N9PD70?ooo`001P3oool;
05hV1@050?ooo`1N9PD0GRH50?ooo`1N9PD01P3oool605hV1@H0oooo00<0GRH50?ooo`3oool00P1N
9PD0103oool0GRH50?ooo`3oool205hV1@040?ooo`1N9PD0oooo05hV1@80oooo00<0GRH50?ooo`3o
ool00P3oool305hV1@D0oooo00<0GRH50?ooo`3oool00P1N9PD00`3oool0GRH50?ooo`020?ooo`<0
GRH5103oool00`1N9PD0oooo0?ooo`020?ooo`80GRH51@3oool305hV1B<0oooo3@1N9PDS0?ooo`<0
GRH51@3oool205hV1@@0oooo00<0GRH50?ooo`3oool00P3oool305hV1@<0oooo00@0GRH50?ooo`1N
9PD0GRH50P3oool00`1N9PD0oooo0?ooo`030?ooo`<0GRH5103oool01P1N9PD0oooo0?ooo`1N9PD0
oooo05hV1@80oooo0P1N9PD00`3oool0GRH50?ooo`0205hV1@80oooo00<0GRH50?ooo`3oool01P3o
ool505hV1@D0oooo00<0GRH50?ooo`1N9PD01`1N9PD00`3oool0GRH505hV1@0305hV1@L0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.05001, -1.05001, 0.00731715, \
0.00731715}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = \(m = 5\);\)\), "\[IndentingNewLine]", 
    \(\(t = 
        Table[{Cos[i], Sin[i]}, {i, 0, 
            2.  \[Pi] + \(2  \[Pi]\)\/n, \(2  \[Pi]\)\/n}];\)\), "\
\[IndentingNewLine]", 
    \(\(par = Partition[t, 3, 1];\)\), "\[IndentingNewLine]", 
    \(\({p, r} = {{0. , 0}, 1.  Cos[\[Pi]\/n]};\)\), "\[IndentingNewLine]", 
    \(\(cir = 
        Join[{{p, r}}, 
          Flatten[\(type[
                  1, #\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\
\)\), #\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\), #\_\(\(\
\[LeftDoubleBracket]\)\(3\)\(\[RightDoubleBracket]\)\), p, r, m] &\) /@ par, 
            1]];\)\), "\[IndentingNewLine]", 
    \(shG[\({LightSeaGreen, Disk[First[#], Last[#]], PrussianBlue, 
            Circle[First[#], Last[#]]} &\) /@ cir]\)}], "Input",
  CellLabel->"In[165]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05146 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.449728 0.526464 0.525731 0.526464 [
[ 0 0 0 0 ]
[ 1 1.05146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.126 .698 .667 r
.44973 .52573 m
.44973 .52573 .42592 0 365.73 arc
F
.18 .18 .31 r
.5 Mabswid
[ ] 0 setdash
newpath
.44973 .52573 .42592 0 365.73 arc
s
.126 .698 .667 r
.59524 .97357 m
.59524 .97357 .04497 0 365.73 arc
F
.18 .18 .31 r
newpath
.59524 .97357 .04497 0 365.73 arc
s
.126 .698 .667 r
.6106 1.02085 m
.6106 1.02085 .00475 0 365.73 arc
F
.18 .18 .31 r
newpath
.6106 1.02085 .00475 0 365.73 arc
s
.126 .698 .667 r
.61222 1.02584 m
.61222 1.02584 .0005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61222 1.02584 .0005 0 365.73 arc
s
.126 .698 .667 r
.61239 1.02637 m
.61239 1.02637 5e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61239 1.02637 5e-005 0 365.73 arc
s
.126 .698 .667 r
.61241 1.02642 m
.61241 1.02642 1e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61241 1.02642 1e-005 0 365.73 arc
s
.126 .698 .667 r
.61246 1.02631 m
.61246 1.02631 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61246 1.02631 3e-005 0 365.73 arc
s
.126 .698 .667 r
.61231 1.02636 m
.61231 1.02636 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61231 1.02636 3e-005 0 365.73 arc
s
.126 .698 .667 r
.61284 1.02535 m
.61284 1.02535 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61284 1.02535 .00029 0 365.73 arc
s
.126 .698 .667 r
.61319 1.02504 m
.61319 1.02504 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.61319 1.02504 .00018 0 365.73 arc
s
.126 .698 .667 r
.61281 1.02573 m
.61281 1.02573 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61281 1.02573 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61247 1.02531 m
.61247 1.02531 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61247 1.02531 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61144 1.02581 m
.61144 1.02581 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61144 1.02581 .00029 0 365.73 arc
s
.126 .698 .667 r
.61097 1.02576 m
.61097 1.02576 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.61097 1.02576 .00018 0 365.73 arc
s
.126 .698 .667 r
.61169 1.02609 m
.61169 1.02609 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61169 1.02609 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61171 1.02555 m
.61171 1.02555 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61171 1.02555 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61647 1.01625 m
.61647 1.01625 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.61647 1.01625 .0027 0 365.73 arc
s
.126 .698 .667 r
.6198 1.0133 m
.6198 1.0133 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.6198 1.0133 .00174 0 365.73 arc
s
.126 .698 .667 r
.62193 1.01125 m
.62193 1.01125 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.62193 1.01125 .00122 0 365.73 arc
s
.126 .698 .667 r
.61964 1.01558 m
.61964 1.01558 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.61964 1.01558 .00054 0 365.73 arc
s
.126 .698 .667 r
.61754 1.01321 m
.61754 1.01321 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.61754 1.01321 .00052 0 365.73 arc
s
.126 .698 .667 r
.61613 1.01982 m
.61613 1.01982 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.61613 1.01982 .00088 0 365.73 arc
s
.126 .698 .667 r
.61577 1.02107 m
.61577 1.02107 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.61577 1.02107 .00043 0 365.73 arc
s
.126 .698 .667 r
.61721 1.01922 m
.61721 1.01922 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.61721 1.01922 .00036 0 365.73 arc
s
.126 .698 .667 r
.61529 1.01901 m
.61529 1.01901 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61529 1.01901 .00029 0 365.73 arc
s
.126 .698 .667 r
.61296 1.01579 m
.61296 1.01579 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.61296 1.01579 .00083 0 365.73 arc
s
.126 .698 .667 r
.61173 1.01583 m
.61173 1.01583 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.61173 1.01583 .0004 0 365.73 arc
s
.126 .698 .667 r
.61373 1.01492 m
.61373 1.01492 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.61373 1.01492 .00034 0 365.73 arc
s
.126 .698 .667 r
.61352 1.01675 m
.61352 1.01675 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.61352 1.01675 .00028 0 365.73 arc
s
.126 .698 .667 r
.60315 1.02058 m
.60315 1.02058 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.60315 1.02058 .0027 0 365.73 arc
s
.126 .698 .667 r
.59873 1.02015 m
.59873 1.02015 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.59873 1.02015 .00174 0 365.73 arc
s
.126 .698 .667 r
.59579 1.01975 m
.59579 1.01975 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.59579 1.01975 .00122 0 365.73 arc
s
.126 .698 .667 r
.60019 1.02189 m
.60019 1.02189 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.60019 1.02189 .00054 0 365.73 arc
s
.126 .698 .667 r
.6005 1.01875 m
.6005 1.01875 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.6005 1.01875 .00052 0 365.73 arc
s
.126 .698 .667 r
.60552 1.02326 m
.60552 1.02326 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.60552 1.02326 .00088 0 365.73 arc
s
.126 .698 .667 r
.60655 1.02407 m
.60655 1.02407 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.60655 1.02407 .00043 0 365.73 arc
s
.126 .698 .667 r
.6043 1.02342 m
.6043 1.02342 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.6043 1.02342 .00036 0 365.73 arc
s
.126 .698 .667 r
.60572 1.02211 m
.60572 1.02211 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.60572 1.02211 .00029 0 365.73 arc
s
.126 .698 .667 r
.60572 1.01815 m
.60572 1.01815 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.60572 1.01815 .00083 0 365.73 arc
s
.126 .698 .667 r
.60673 1.01745 m
.60673 1.01745 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.60673 1.01745 .0004 0 365.73 arc
s
.126 .698 .667 r
.60458 1.01789 m
.60458 1.01789 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.60458 1.01789 .00034 0 365.73 arc
s
.126 .698 .667 r
.60583 1.01925 m
.60583 1.01925 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.60583 1.01925 .00028 0 365.73 arc
s
.126 .698 .667 r
.65079 .93003 m
.65079 .93003 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.65079 .93003 .02562 0 365.73 arc
s
.126 .698 .667 r
.68233 .90209 m
.68233 .90209 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.68233 .90209 .01652 0 365.73 arc
s
.126 .698 .667 r
.70259 .88269 m
.70259 .88269 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.70259 .88269 .01153 0 365.73 arc
s
.126 .698 .667 r
.71668 .86845 m
.71668 .86845 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.71668 .86845 .0085 0 365.73 arc
s
.126 .698 .667 r
.70177 .89762 m
.70177 .89762 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.70177 .89762 .00342 0 365.73 arc
s
.126 .698 .667 r
.68772 .88297 m
.68772 .88297 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.68772 .88297 .00334 0 365.73 arc
s
.126 .698 .667 r
.68081 .92364 m
.68081 .92364 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.68081 .92364 .00508 0 365.73 arc
s
.126 .698 .667 r
.67882 .93088 m
.67882 .93088 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.67882 .93088 .00243 0 365.73 arc
s
.126 .698 .667 r
.68707 .9201 m
.68707 .9201 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.68707 .9201 .0021 0 365.73 arc
s
.126 .698 .667 r
.6758 .91909 m
.6758 .91909 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.6758 .91909 .00169 0 365.73 arc
s
.126 .698 .667 r
.66092 .90124 m
.66092 .90124 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.66092 .90124 .00491 0 365.73 arc
s
.126 .698 .667 r
.65376 .90225 m
.65376 .90225 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.65376 .90225 .00233 0 365.73 arc
s
.126 .698 .667 r
.66496 .89561 m
.66496 .89561 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.66496 .89561 .00202 0 365.73 arc
s
.126 .698 .667 r
.66472 .90659 m
.66472 .90659 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.66472 .90659 .00165 0 365.73 arc
s
.126 .698 .667 r
.64762 .96381 m
.64762 .96381 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.64762 .96381 .00832 0 365.73 arc
s
.126 .698 .667 r
.64422 .97573 m
.64422 .97573 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.64422 .97573 .00407 0 365.73 arc
s
.126 .698 .667 r
.64189 .98176 m
.64189 .98176 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.64189 .98176 .0024 0 365.73 arc
s
.126 .698 .667 r
.64919 .97341 m
.64919 .97341 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.64919 .97341 .00141 0 365.73 arc
s
.126 .698 .667 r
.64143 .97116 m
.64143 .97116 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.64143 .97116 .00129 0 365.73 arc
s
.126 .698 .667 r
.65785 .95815 m
.65785 .95815 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.65785 .95815 .00338 0 365.73 arc
s
.126 .698 .667 r
.66202 .95506 m
.66202 .95506 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.66202 .95506 .00182 0 365.73 arc
s
.126 .698 .667 r
.65714 .96273 m
.65714 .96273 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.65714 .96273 .00126 0 365.73 arc
s
.126 .698 .667 r
.65366 .95659 m
.65366 .95659 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.65366 .95659 .0011 0 365.73 arc
s
.126 .698 .667 r
.63966 .95612 m
.63966 .95612 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.63966 .95612 .00276 0 365.73 arc
s
.126 .698 .667 r
.63682 .95312 m
.63682 .95312 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.63682 .95312 .00137 0 365.73 arc
s
.126 .698 .667 r
.63915 .95987 m
.63915 .95987 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.63915 .95987 .00103 0 365.73 arc
s
.126 .698 .667 r
.64335 .95556 m
.64335 .95556 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.64335 .95556 .00098 0 365.73 arc
s
.126 .698 .667 r
.6176 .92571 m
.6176 .92571 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.6176 .92571 .00786 0 365.73 arc
s
.126 .698 .667 r
.60596 .92602 m
.60596 .92602 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.60596 .92602 .00378 0 365.73 arc
s
.126 .698 .667 r
.6 .92663 m
.6 .92663 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.6 .92663 .00222 0 365.73 arc
s
.126 .698 .667 r
.60918 .92208 m
.60918 .92208 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.60918 .92208 .00131 0 365.73 arc
s
.126 .698 .667 r
.60941 .92962 m
.60941 .92962 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.60941 .92962 .00121 0 365.73 arc
s
.126 .698 .667 r
.6249 .91744 m
.6249 .91744 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.6249 .91744 .00317 0 365.73 arc
s
.126 .698 .667 r
.62853 .91418 m
.62853 .91418 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.62853 .91418 .00171 0 365.73 arc
s
.126 .698 .667 r
.62056 .91717 m
.62056 .91717 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.62056 .91717 .00118 0 365.73 arc
s
.126 .698 .667 r
.6255 .92161 m
.6255 .92161 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.6255 .92161 .00104 0 365.73 arc
s
.126 .698 .667 r
.62291 .9348 m
.62291 .9348 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.62291 .9348 .00267 0 365.73 arc
s
.126 .698 .667 r
.62509 .93816 m
.62509 .93816 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.62509 .93816 .00134 0 365.73 arc
s
.126 .698 .667 r
.61927 .9344 m
.61927 .9344 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.61927 .9344 .00099 0 365.73 arc
s
.126 .698 .667 r
.62427 .93145 m
.62427 .93145 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.62427 .93145 .00094 0 365.73 arc
s
.126 .698 .667 r
.52471 .971 m
.52471 .971 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.52471 .971 .02562 0 365.73 arc
s
.126 .698 .667 r
.48277 .96693 m
.48277 .96693 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.48277 .96693 .01652 0 365.73 arc
s
.126 .698 .667 r
.45497 .96315 m
.45497 .96315 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.45497 .96315 .01153 0 365.73 arc
s
.126 .698 .667 r
.4352 .95991 m
.4352 .95991 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.4352 .95991 .0085 0 365.73 arc
s
.126 .698 .667 r
.46442 .97474 m
.46442 .97474 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.46442 .97474 .00342 0 365.73 arc
s
.126 .698 .667 r
.46717 .95464 m
.46717 .95464 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.46717 .95464 .00334 0 365.73 arc
s
.126 .698 .667 r
.49666 .98347 m
.49666 .98347 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.49666 .98347 .00508 0 365.73 arc
s
.126 .698 .667 r
.50253 .98817 m
.50253 .98817 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.50253 .98817 .00243 0 365.73 arc
s
.126 .698 .667 r
.48952 .98429 m
.48952 .98429 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.48952 .98429 .0021 0 365.73 arc
s
.126 .698 .667 r
.49804 .97685 m
.49804 .97685 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.49804 .97685 .00169 0 365.73 arc
s
.126 .698 .667 r
.49959 .95366 m
.49959 .95366 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.49959 .95366 .00491 0 365.73 arc
s
.126 .698 .667 r
.50597 .95027 m
.50597 .95027 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.50597 .95027 .00233 0 365.73 arc
s
.126 .698 .667 r
.49301 .95148 m
.49301 .95148 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.49301 .95148 .00202 0 365.73 arc
s
.126 .698 .667 r
.49965 .96022 m
.49965 .96022 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.49965 .96022 .00165 0 365.73 arc
s
.126 .698 .667 r
.54713 .99647 m
.54713 .99647 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.54713 .99647 .00832 0 365.73 arc
s
.126 .698 .667 r
.55688 1.00411 m
.55688 1.00411 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.55688 1.00411 .00407 0 365.73 arc
s
.126 .698 .667 r
.56231 1.00762 m
.56231 1.00762 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.56231 1.00762 .0024 0 365.73 arc
s
.126 .698 .667 r
.5515 1.00516 m
.5515 1.00516 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.5515 1.00516 .00141 0 365.73 arc
s
.126 .698 .667 r
.55645 .99877 m
.55645 .99877 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.55645 .99877 .00129 0 365.73 arc
s
.126 .698 .667 r
.53552 .99789 m
.53552 .99789 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.53552 .99789 .00338 0 365.73 arc
s
.126 .698 .667 r
.53033 .99785 m
.53033 .99785 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.53033 .99785 .00182 0 365.73 arc
s
.126 .698 .667 r
.53879 1.00118 m
.53879 1.00118 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.53879 1.00118 .00126 0 365.73 arc
s
.126 .698 .667 r
.53799 .99417 m
.53799 .99417 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.53799 .99417 .0011 0 365.73 arc
s
.126 .698 .667 r
.54905 .98556 m
.54905 .98556 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.54905 .98556 .00276 0 365.73 arc
s
.126 .698 .667 r
.54958 .98147 m
.54958 .98147 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.54958 .98147 .00137 0 365.73 arc
s
.126 .698 .667 r
.55167 .9883 m
.55167 .9883 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.55167 .9883 .00103 0 365.73 arc
s
.126 .698 .667 r
.54573 .98728 m
.54573 .98728 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.54573 .98728 .00098 0 365.73 arc
s
.126 .698 .667 r
.54902 .94799 m
.54902 .94799 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.54902 .94799 .00786 0 365.73 arc
s
.126 .698 .667 r
.55861 .9414 m
.55861 .9414 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.55861 .9414 .00378 0 365.73 arc
s
.126 .698 .667 r
.5638 .93839 m
.5638 .93839 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.5638 .93839 .00222 0 365.73 arc
s
.126 .698 .667 r
.5537 .94011 m
.5537 .94011 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.5537 .94011 .00131 0 365.73 arc
s
.126 .698 .667 r
.55794 .94635 m
.55794 .94635 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.55794 .94635 .00121 0 365.73 arc
s
.126 .698 .667 r
.53825 .94559 m
.53825 .94559 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.53825 .94559 .00317 0 365.73 arc
s
.126 .698 .667 r
.5334 .94509 m
.5334 .94509 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.5334 .94509 .00171 0 365.73 arc
s
.126 .698 .667 r
.54161 .94283 m
.54161 .94283 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.54161 .94283 .00118 0 365.73 arc
s
.126 .698 .667 r
.54022 .94932 m
.54022 .94932 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.54022 .94932 .00104 0 365.73 arc
s
.126 .698 .667 r
.55006 .95847 m
.55006 .95847 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.55006 .95847 .00267 0 365.73 arc
s
.126 .698 .667 r
.55028 .96247 m
.55028 .96247 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.55028 .96247 .00134 0 365.73 arc
s
.126 .698 .667 r
.55277 .95601 m
.55277 .95601 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.55277 .95601 .00099 0 365.73 arc
s
.126 .698 .667 r
.547 .95656 m
.547 .95656 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.547 .95656 .00094 0 365.73 arc
s
.126 .698 .667 r
.06877 .80251 m
.06877 .80251 .04497 0 365.73 arc
F
.18 .18 .31 r
newpath
.06877 .80251 .04497 0 365.73 arc
s
.126 .698 .667 r
.02856 .83173 m
.02856 .83173 .00475 0 365.73 arc
F
.18 .18 .31 r
newpath
.02856 .83173 .00475 0 365.73 arc
s
.126 .698 .667 r
.02431 .83481 m
.02431 .83481 .0005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02431 .83481 .0005 0 365.73 arc
s
.126 .698 .667 r
.02386 .83514 m
.02386 .83514 5e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02386 .83514 5e-005 0 365.73 arc
s
.126 .698 .667 r
.02382 .83517 m
.02382 .83517 1e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02382 .83517 1e-005 0 365.73 arc
s
.126 .698 .667 r
.02393 .83519 m
.02393 .83519 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02393 .83519 3e-005 0 365.73 arc
s
.126 .698 .667 r
.02384 .83506 m
.02384 .83506 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02384 .83506 3e-005 0 365.73 arc
s
.126 .698 .667 r
.02496 .83525 m
.02496 .83525 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.02496 .83525 .00029 0 365.73 arc
s
.126 .698 .667 r
.02537 .83549 m
.02537 .83549 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.02537 .83549 .00018 0 365.73 arc
s
.126 .698 .667 r
.02459 .83534 m
.02459 .83534 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02459 .83534 9e-005 0 365.73 arc
s
.126 .698 .667 r
.0249 .83489 m
.0249 .83489 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.0249 .83489 9e-005 0 365.73 arc
s
.126 .698 .667 r
.0241 .83406 m
.0241 .83406 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.0241 .83406 .00029 0 365.73 arc
s
.126 .698 .667 r
.02399 .8336 m
.02399 .8336 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.02399 .8336 .00018 0 365.73 arc
s
.126 .698 .667 r
.0239 .83438 m
.0239 .83438 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.0239 .83438 9e-005 0 365.73 arc
s
.126 .698 .667 r
.02442 .83424 m
.02442 .83424 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02442 .83424 9e-005 0 365.73 arc
s
.126 .698 .667 r
.03474 .83589 m
.03474 .83589 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.03474 .83589 .0027 0 365.73 arc
s
.126 .698 .667 r
.03857 .83814 m
.03857 .83814 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.03857 .83814 .00174 0 365.73 arc
s
.126 .698 .667 r
.04118 .83954 m
.04118 .83954 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.04118 .83954 .00122 0 365.73 arc
s
.126 .698 .667 r
.03636 .83869 m
.03636 .83869 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.03636 .83869 .00054 0 365.73 arc
s
.126 .698 .667 r
.03796 .83596 m
.03796 .83596 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.03796 .83596 .00052 0 365.73 arc
s
.126 .698 .667 r
.03124 .83667 m
.03124 .83667 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.03124 .83667 .00088 0 365.73 arc
s
.126 .698 .667 r
.02994 .83672 m
.02994 .83672 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.02994 .83672 .00043 0 365.73 arc
s
.126 .698 .667 r
.03215 .83751 m
.03215 .83751 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.03215 .83751 .00036 0 365.73 arc
s
.126 .698 .667 r
.03176 .83562 m
.03176 .83562 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.03176 .83562 .00029 0 365.73 arc
s
.126 .698 .667 r
.03409 .83241 m
.03409 .83241 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.03409 .83241 .00083 0 365.73 arc
s
.126 .698 .667 r
.03368 .83126 m
.03368 .83126 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.03368 .83126 .0004 0 365.73 arc
s
.126 .698 .667 r
.03516 .83288 m
.03516 .83288 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.03516 .83288 .00034 0 365.73 arc
s
.126 .698 .667 r
.03335 .83324 m
.03335 .83324 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.03335 .83324 .00028 0 365.73 arc
s
.126 .698 .667 r
.02651 .82456 m
.02651 .82456 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.02651 .82456 .0027 0 365.73 arc
s
.126 .698 .667 r
.02555 .82022 m
.02555 .82022 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.02555 .82022 .00174 0 365.73 arc
s
.126 .698 .667 r
.02503 .81731 m
.02503 .81731 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.02503 .81731 .00122 0 365.73 arc
s
.126 .698 .667 r
.02435 .82215 m
.02435 .82215 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.02435 .82215 .00054 0 365.73 arc
s
.126 .698 .667 r
.02743 .82148 m
.02743 .82148 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.02743 .82148 .00052 0 365.73 arc
s
.126 .698 .667 r
.02469 .82765 m
.02469 .82765 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.02469 .82765 .00088 0 365.73 arc
s
.126 .698 .667 r
.02424 .82887 m
.02424 .82887 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.02424 .82887 .00043 0 365.73 arc
s
.126 .698 .667 r
.02417 .82653 m
.02417 .82653 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.02417 .82653 .00036 0 365.73 arc
s
.126 .698 .667 r
.02585 .82748 m
.02585 .82748 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.02585 .82748 .00029 0 365.73 arc
s
.126 .698 .667 r
.02962 .82625 m
.02962 .82625 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.02962 .82625 .00083 0 365.73 arc
s
.126 .698 .667 r
.03059 .827 m
.03059 .827 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.03059 .827 .0004 0 365.73 arc
s
.126 .698 .667 r
.02951 .8251 m
.02951 .8251 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.02951 .8251 .00034 0 365.73 arc
s
.126 .698 .667 r
.0286 .8267 m
.0286 .8267 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.0286 .8267 .00028 0 365.73 arc
s
.126 .698 .667 r
.12735 .84189 m
.12735 .84189 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.12735 .84189 .02562 0 365.73 arc
s
.126 .698 .667 r
.16367 .86325 m
.16367 .86325 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.16367 .86325 .01652 0 365.73 arc
s
.126 .698 .667 r
.18838 .87653 m
.18838 .87653 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.18838 .87653 .01153 0 365.73 arc
s
.126 .698 .667 r
.20627 .88553 m
.20627 .88553 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.20627 .88553 .0085 0 365.73 arc
s
.126 .698 .667 r
.17392 .88035 m
.17392 .88035 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.17392 .88035 .00342 0 365.73 arc
s
.126 .698 .667 r
.18351 .86247 m
.18351 .86247 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.18351 .86247 .00334 0 365.73 arc
s
.126 .698 .667 r
.14271 .86847 m
.14271 .86847 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.14271 .86847 .00508 0 365.73 arc
s
.126 .698 .667 r
.1352 .86881 m
.1352 .86881 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.1352 .86881 .00243 0 365.73 arc
s
.126 .698 .667 r
.148 .87332 m
.148 .87332 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.148 .87332 .0021 0 365.73 arc
s
.126 .698 .667 r
.14549 .8623 m
.14549 .8623 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.14549 .8623 .00169 0 365.73 arc
s
.126 .698 .667 r
.15786 .84263 m
.15786 .84263 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.15786 .84263 .00491 0 365.73 arc
s
.126 .698 .667 r
.15469 .83613 m
.15469 .83613 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.15469 .83613 .00233 0 365.73 arc
s
.126 .698 .667 r
.16446 .84473 m
.16446 .84473 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.16446 .84473 .00202 0 365.73 arc
s
.126 .698 .667 r
.15395 .84789 m
.15395 .84789 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.15395 .84789 .00165 0 365.73 arc
s
.126 .698 .667 r
.09424 .84932 m
.09424 .84932 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.09424 .84932 .00832 0 365.73 arc
s
.126 .698 .667 r
.08186 .84976 m
.08186 .84976 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.08186 .84976 .00407 0 365.73 arc
s
.126 .698 .667 r
.0754 .84941 m
.0754 .84941 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.0754 .84941 .0024 0 365.73 arc
s
.126 .698 .667 r
.08559 .85377 m
.08559 .85377 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.08559 .85377 .00141 0 365.73 arc
s
.126 .698 .667 r
.08534 .84569 m
.08534 .84569 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.08534 .84569 .00129 0 365.73 arc
s
.126 .698 .667 r
.10279 .85729 m
.10279 .85729 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.10279 .85729 .00338 0 365.73 arc
s
.126 .698 .667 r
.10702 .8603 m
.10702 .8603 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.10702 .8603 .00182 0 365.73 arc
s
.126 .698 .667 r
.09821 .85803 m
.09821 .85803 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.09821 .85803 .00126 0 365.73 arc
s
.126 .698 .667 r
.10298 .85282 m
.10298 .85282 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.10298 .85282 .0011 0 365.73 arc
s
.126 .698 .667 r
.09909 .83936 m
.09909 .83936 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.09909 .83936 .00276 0 365.73 arc
s
.126 .698 .667 r
.10107 .83574 m
.10107 .83574 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.10107 .83574 .00137 0 365.73 arc
s
.126 .698 .667 r
.09537 .84004 m
.09537 .84004 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.09537 .84004 .00103 0 365.73 arc
s
.126 .698 .667 r
.10077 .8427 m
.10077 .8427 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.10077 .8427 .00098 0 365.73 arc
s
.126 .698 .667 r
.1212 .80898 m
.1212 .80898 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.1212 .80898 .00786 0 365.73 arc
s
.126 .698 .667 r
.11731 .79802 m
.11731 .79802 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.11731 .79802 .00378 0 365.73 arc
s
.126 .698 .667 r
.11489 .79253 m
.11489 .79253 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.11489 .79253 .00222 0 365.73 arc
s
.126 .698 .667 r
.12205 .79986 m
.12205 .79986 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.12205 .79986 .00131 0 365.73 arc
s
.126 .698 .667 r
.11495 .80241 m
.11495 .80241 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.11495 .80241 .00121 0 365.73 arc
s
.126 .698 .667 r
.13132 .81337 m
.13132 .81337 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.13132 .81337 .00317 0 365.73 arc
s
.126 .698 .667 r
.13555 .81582 m
.13555 .81582 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.13555 .81582 .00171 0 365.73 arc
s
.126 .698 .667 r
.13023 .80916 m
.13023 .80916 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.13023 .80916 .00118 0 365.73 arc
s
.126 .698 .667 r
.12754 .81523 m
.12754 .81523 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.12754 .81523 .00104 0 365.73 arc
s
.126 .698 .667 r
.1142 .81685 m
.1142 .81685 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.1142 .81685 .00267 0 365.73 arc
s
.126 .698 .667 r
.11167 .81996 m
.11167 .81996 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.11167 .81996 .00134 0 365.73 arc
s
.126 .698 .667 r
.11346 .81326 m
.11346 .81326 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.11346 .81326 .00099 0 365.73 arc
s
.126 .698 .667 r
.1178 .8171 m
.1178 .8171 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.1178 .8171 .00094 0 365.73 arc
s
.126 .698 .667 r
.04942 .73463 m
.04942 .73463 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.04942 .73463 .02562 0 365.73 arc
s
.126 .698 .667 r
.04033 .69349 m
.04033 .69349 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.04033 .69349 .01652 0 365.73 arc
s
.126 .698 .667 r
.03534 .66589 m
.03534 .66589 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.03534 .66589 .01153 0 365.73 arc
s
.126 .698 .667 r
.03231 .64609 m
.03231 .64609 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.03231 .64609 .0085 0 365.73 arc
s
.126 .698 .667 r
.02723 .67845 m
.02723 .67845 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.02723 .67845 .00342 0 365.73 arc
s
.126 .698 .667 r
.0472 .67486 m
.0472 .67486 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.0472 .67486 .00334 0 365.73 arc
s
.126 .698 .667 r
.02889 .71182 m
.02889 .71182 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.02889 .71182 .00508 0 365.73 arc
s
.126 .698 .667 r
.02624 .71885 m
.02624 .71885 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.02624 .71885 .00243 0 365.73 arc
s
.126 .698 .667 r
.02591 .70528 m
.02591 .70528 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.02591 .70528 .0021 0 365.73 arc
s
.126 .698 .667 r
.03562 .71108 m
.03562 .71108 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.03562 .71108 .00169 0 365.73 arc
s
.126 .698 .667 r
.05815 .70539 m
.05815 .70539 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.05815 .70539 .00491 0 365.73 arc
s
.126 .698 .667 r
.06335 .71041 m
.06335 .71041 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.06335 .71041 .00233 0 365.73 arc
s
.126 .698 .667 r
.05819 .69846 m
.05819 .69846 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.05819 .69846 .00202 0 365.73 arc
s
.126 .698 .667 r
.05193 .70748 m
.05193 .70748 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.05193 .70748 .00165 0 365.73 arc
s
.126 .698 .667 r
.03213 .76383 m
.03213 .76383 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.03213 .76383 .00832 0 365.73 arc
s
.126 .698 .667 r
.02788 .77546 m
.02788 .77546 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.02788 .77546 .00407 0 365.73 arc
s
.126 .698 .667 r
.02621 .78172 m
.02621 .78172 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.02621 .78172 .0024 0 365.73 arc
s
.126 .698 .667 r
.02522 .77067 m
.02522 .77067 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.02522 .77067 .00141 0 365.73 arc
s
.126 .698 .667 r
.03282 .77341 m
.03282 .77341 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.03282 .77341 .00129 0 365.73 arc
s
.126 .698 .667 r
.02718 .75323 m
.02718 .75323 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.02718 .75323 .00338 0 365.73 arc
s
.126 .698 .667 r
.02563 .74828 m
.02563 .74828 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.02563 .74828 .00182 0 365.73 arc
s
.126 .698 .667 r
.02507 .75735 m
.02507 .75735 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.02507 .75735 .00126 0 365.73 arc
s
.126 .698 .667 r
.03149 .75443 m
.03149 .75443 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.03149 .75443 .0011 0 365.73 arc
s
.126 .698 .667 r
.04309 .76229 m
.04309 .76229 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.04309 .76229 .00276 0 365.73 arc
s
.126 .698 .667 r
.04715 .76153 m
.04715 .76153 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.04715 .76153 .00137 0 365.73 arc
s
.126 .698 .667 r
.0413 .76562 m
.0413 .76562 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.0413 .76562 .00103 0 365.73 arc
s
.126 .698 .667 r
.04044 .75966 m
.04044 .75966 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.04044 .75966 .00098 0 365.73 arc
s
.126 .698 .667 r
.07882 .75065 m
.07882 .75065 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.07882 .75065 .00786 0 365.73 arc
s
.126 .698 .667 r
.08805 .75774 m
.08805 .75774 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.08805 .75774 .00378 0 365.73 arc
s
.126 .698 .667 r
.09251 .76174 m
.09251 .76174 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.09251 .76174 .00222 0 365.73 arc
s
.126 .698 .667 r
.08776 .75266 m
.08776 .75266 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.08776 .75266 .00131 0 365.73 arc
s
.126 .698 .667 r
.08314 .75862 m
.08314 .75862 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.08314 .75862 .00121 0 365.73 arc
s
.126 .698 .667 r
.07777 .73967 m
.07777 .73967 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.07777 .73967 .00317 0 365.73 arc
s
.126 .698 .667 r
.07675 .73489 m
.07675 .73489 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.07675 .73489 .00171 0 365.73 arc
s
.126 .698 .667 r
.08144 .742 m
.08144 .742 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.08144 .742 .00118 0 365.73 arc
s
.126 .698 .667 r
.07483 .74269 m
.07483 .74269 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.07483 .74269 .00104 0 365.73 arc
s
.126 .698 .667 r
.06918 .75488 m
.06918 .75488 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.06918 .75488 .00267 0 365.73 arc
s
.126 .698 .667 r
.06544 .75632 m
.06544 .75632 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.06544 .75632 .00134 0 365.73 arc
s
.126 .698 .667 r
.07235 .75669 m
.07235 .75669 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.07235 .75669 .00099 0 365.73 arc
s
.126 .698 .667 r
.07005 .75137 m
.07005 .75137 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.07005 .75137 .00094 0 365.73 arc
s
.126 .698 .667 r
.06877 .24895 m
.06877 .24895 .04497 0 365.73 arc
F
.18 .18 .31 r
newpath
.06877 .24895 .04497 0 365.73 arc
s
.126 .698 .667 r
.02856 .21973 m
.02856 .21973 .00475 0 365.73 arc
F
.18 .18 .31 r
newpath
.02856 .21973 .00475 0 365.73 arc
s
.126 .698 .667 r
.02431 .21665 m
.02431 .21665 .0005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02431 .21665 .0005 0 365.73 arc
s
.126 .698 .667 r
.02386 .21632 m
.02386 .21632 5e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02386 .21632 5e-005 0 365.73 arc
s
.126 .698 .667 r
.02382 .21629 m
.02382 .21629 1e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02382 .21629 1e-005 0 365.73 arc
s
.126 .698 .667 r
.02384 .2164 m
.02384 .2164 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02384 .2164 3e-005 0 365.73 arc
s
.126 .698 .667 r
.02393 .21628 m
.02393 .21628 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02393 .21628 3e-005 0 365.73 arc
s
.126 .698 .667 r
.0241 .2174 m
.0241 .2174 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.0241 .2174 .00029 0 365.73 arc
s
.126 .698 .667 r
.02399 .21786 m
.02399 .21786 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.02399 .21786 .00018 0 365.73 arc
s
.126 .698 .667 r
.0239 .21708 m
.0239 .21708 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.0239 .21708 9e-005 0 365.73 arc
s
.126 .698 .667 r
.02442 .21723 m
.02442 .21723 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02442 .21723 9e-005 0 365.73 arc
s
.126 .698 .667 r
.02496 .21621 m
.02496 .21621 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.02496 .21621 .00029 0 365.73 arc
s
.126 .698 .667 r
.02537 .21597 m
.02537 .21597 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.02537 .21597 .00018 0 365.73 arc
s
.126 .698 .667 r
.02459 .21613 m
.02459 .21613 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.02459 .21613 9e-005 0 365.73 arc
s
.126 .698 .667 r
.0249 .21658 m
.0249 .21658 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.0249 .21658 9e-005 0 365.73 arc
s
.126 .698 .667 r
.02651 .2269 m
.02651 .2269 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.02651 .2269 .0027 0 365.73 arc
s
.126 .698 .667 r
.02555 .23124 m
.02555 .23124 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.02555 .23124 .00174 0 365.73 arc
s
.126 .698 .667 r
.02503 .23416 m
.02503 .23416 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.02503 .23416 .00122 0 365.73 arc
s
.126 .698 .667 r
.02435 .22931 m
.02435 .22931 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.02435 .22931 .00054 0 365.73 arc
s
.126 .698 .667 r
.02743 .22999 m
.02743 .22999 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.02743 .22999 .00052 0 365.73 arc
s
.126 .698 .667 r
.02469 .22382 m
.02469 .22382 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.02469 .22382 .00088 0 365.73 arc
s
.126 .698 .667 r
.02424 .22259 m
.02424 .22259 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.02424 .22259 .00043 0 365.73 arc
s
.126 .698 .667 r
.02417 .22493 m
.02417 .22493 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.02417 .22493 .00036 0 365.73 arc
s
.126 .698 .667 r
.02585 .22398 m
.02585 .22398 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.02585 .22398 .00029 0 365.73 arc
s
.126 .698 .667 r
.02962 .22521 m
.02962 .22521 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.02962 .22521 .00083 0 365.73 arc
s
.126 .698 .667 r
.03059 .22446 m
.03059 .22446 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.03059 .22446 .0004 0 365.73 arc
s
.126 .698 .667 r
.02951 .22637 m
.02951 .22637 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.02951 .22637 .00034 0 365.73 arc
s
.126 .698 .667 r
.0286 .22476 m
.0286 .22476 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.0286 .22476 .00028 0 365.73 arc
s
.126 .698 .667 r
.03474 .21557 m
.03474 .21557 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.03474 .21557 .0027 0 365.73 arc
s
.126 .698 .667 r
.03857 .21332 m
.03857 .21332 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.03857 .21332 .00174 0 365.73 arc
s
.126 .698 .667 r
.04118 .21192 m
.04118 .21192 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.04118 .21192 .00122 0 365.73 arc
s
.126 .698 .667 r
.03636 .21277 m
.03636 .21277 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.03636 .21277 .00054 0 365.73 arc
s
.126 .698 .667 r
.03796 .2155 m
.03796 .2155 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.03796 .2155 .00052 0 365.73 arc
s
.126 .698 .667 r
.03124 .21479 m
.03124 .21479 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.03124 .21479 .00088 0 365.73 arc
s
.126 .698 .667 r
.02994 .21474 m
.02994 .21474 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.02994 .21474 .00043 0 365.73 arc
s
.126 .698 .667 r
.03215 .21395 m
.03215 .21395 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.03215 .21395 .00036 0 365.73 arc
s
.126 .698 .667 r
.03176 .21584 m
.03176 .21584 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.03176 .21584 .00029 0 365.73 arc
s
.126 .698 .667 r
.03409 .21905 m
.03409 .21905 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.03409 .21905 .00083 0 365.73 arc
s
.126 .698 .667 r
.03368 .22021 m
.03368 .22021 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.03368 .22021 .0004 0 365.73 arc
s
.126 .698 .667 r
.03516 .21859 m
.03516 .21859 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.03516 .21859 .00034 0 365.73 arc
s
.126 .698 .667 r
.03335 .21822 m
.03335 .21822 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.03335 .21822 .00028 0 365.73 arc
s
.126 .698 .667 r
.04942 .31683 m
.04942 .31683 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.04942 .31683 .02562 0 365.73 arc
s
.126 .698 .667 r
.04033 .35797 m
.04033 .35797 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.04033 .35797 .01652 0 365.73 arc
s
.126 .698 .667 r
.03534 .38557 m
.03534 .38557 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.03534 .38557 .01153 0 365.73 arc
s
.126 .698 .667 r
.03231 .40538 m
.03231 .40538 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.03231 .40538 .0085 0 365.73 arc
s
.126 .698 .667 r
.02723 .37301 m
.02723 .37301 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.02723 .37301 .00342 0 365.73 arc
s
.126 .698 .667 r
.0472 .3766 m
.0472 .3766 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.0472 .3766 .00334 0 365.73 arc
s
.126 .698 .667 r
.02889 .33965 m
.02889 .33965 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.02889 .33965 .00508 0 365.73 arc
s
.126 .698 .667 r
.02624 .33262 m
.02624 .33262 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.02624 .33262 .00243 0 365.73 arc
s
.126 .698 .667 r
.02591 .34618 m
.02591 .34618 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.02591 .34618 .0021 0 365.73 arc
s
.126 .698 .667 r
.03562 .34038 m
.03562 .34038 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.03562 .34038 .00169 0 365.73 arc
s
.126 .698 .667 r
.05815 .34608 m
.05815 .34608 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.05815 .34608 .00491 0 365.73 arc
s
.126 .698 .667 r
.06335 .34105 m
.06335 .34105 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.06335 .34105 .00233 0 365.73 arc
s
.126 .698 .667 r
.05819 .353 m
.05819 .353 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.05819 .353 .00202 0 365.73 arc
s
.126 .698 .667 r
.05193 .34398 m
.05193 .34398 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.05193 .34398 .00165 0 365.73 arc
s
.126 .698 .667 r
.03213 .28763 m
.03213 .28763 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.03213 .28763 .00832 0 365.73 arc
s
.126 .698 .667 r
.02788 .276 m
.02788 .276 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.02788 .276 .00407 0 365.73 arc
s
.126 .698 .667 r
.02621 .26975 m
.02621 .26975 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.02621 .26975 .0024 0 365.73 arc
s
.126 .698 .667 r
.02522 .28079 m
.02522 .28079 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.02522 .28079 .00141 0 365.73 arc
s
.126 .698 .667 r
.03282 .27805 m
.03282 .27805 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.03282 .27805 .00129 0 365.73 arc
s
.126 .698 .667 r
.02718 .29823 m
.02718 .29823 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.02718 .29823 .00338 0 365.73 arc
s
.126 .698 .667 r
.02563 .30318 m
.02563 .30318 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.02563 .30318 .00182 0 365.73 arc
s
.126 .698 .667 r
.02507 .29411 m
.02507 .29411 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.02507 .29411 .00126 0 365.73 arc
s
.126 .698 .667 r
.03149 .29703 m
.03149 .29703 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.03149 .29703 .0011 0 365.73 arc
s
.126 .698 .667 r
.04309 .28917 m
.04309 .28917 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.04309 .28917 .00276 0 365.73 arc
s
.126 .698 .667 r
.04715 .28994 m
.04715 .28994 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.04715 .28994 .00137 0 365.73 arc
s
.126 .698 .667 r
.0413 .28584 m
.0413 .28584 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.0413 .28584 .00103 0 365.73 arc
s
.126 .698 .667 r
.04044 .2918 m
.04044 .2918 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.04044 .2918 .00098 0 365.73 arc
s
.126 .698 .667 r
.07882 .30081 m
.07882 .30081 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.07882 .30081 .00786 0 365.73 arc
s
.126 .698 .667 r
.08805 .29372 m
.08805 .29372 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.08805 .29372 .00378 0 365.73 arc
s
.126 .698 .667 r
.09251 .28973 m
.09251 .28973 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.09251 .28973 .00222 0 365.73 arc
s
.126 .698 .667 r
.08776 .2988 m
.08776 .2988 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.08776 .2988 .00131 0 365.73 arc
s
.126 .698 .667 r
.08314 .29284 m
.08314 .29284 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.08314 .29284 .00121 0 365.73 arc
s
.126 .698 .667 r
.07777 .3118 m
.07777 .3118 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.07777 .3118 .00317 0 365.73 arc
s
.126 .698 .667 r
.07675 .31657 m
.07675 .31657 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.07675 .31657 .00171 0 365.73 arc
s
.126 .698 .667 r
.08144 .30946 m
.08144 .30946 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.08144 .30946 .00118 0 365.73 arc
s
.126 .698 .667 r
.07483 .30877 m
.07483 .30877 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.07483 .30877 .00104 0 365.73 arc
s
.126 .698 .667 r
.06918 .29658 m
.06918 .29658 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.06918 .29658 .00267 0 365.73 arc
s
.126 .698 .667 r
.06544 .29514 m
.06544 .29514 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.06544 .29514 .00134 0 365.73 arc
s
.126 .698 .667 r
.07235 .29477 m
.07235 .29477 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.07235 .29477 .00099 0 365.73 arc
s
.126 .698 .667 r
.07005 .30009 m
.07005 .30009 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.07005 .30009 .00094 0 365.73 arc
s
.126 .698 .667 r
.12735 .20957 m
.12735 .20957 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.12735 .20957 .02562 0 365.73 arc
s
.126 .698 .667 r
.16367 .18821 m
.16367 .18821 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.16367 .18821 .01652 0 365.73 arc
s
.126 .698 .667 r
.18838 .17494 m
.18838 .17494 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.18838 .17494 .01153 0 365.73 arc
s
.126 .698 .667 r
.20627 .16594 m
.20627 .16594 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.20627 .16594 .0085 0 365.73 arc
s
.126 .698 .667 r
.17392 .17111 m
.17392 .17111 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.17392 .17111 .00342 0 365.73 arc
s
.126 .698 .667 r
.18351 .18899 m
.18351 .18899 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.18351 .18899 .00334 0 365.73 arc
s
.126 .698 .667 r
.14271 .18299 m
.14271 .18299 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.14271 .18299 .00508 0 365.73 arc
s
.126 .698 .667 r
.1352 .18265 m
.1352 .18265 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.1352 .18265 .00243 0 365.73 arc
s
.126 .698 .667 r
.148 .17814 m
.148 .17814 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.148 .17814 .0021 0 365.73 arc
s
.126 .698 .667 r
.14549 .18917 m
.14549 .18917 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.14549 .18917 .00169 0 365.73 arc
s
.126 .698 .667 r
.15786 .20883 m
.15786 .20883 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.15786 .20883 .00491 0 365.73 arc
s
.126 .698 .667 r
.15469 .21533 m
.15469 .21533 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.15469 .21533 .00233 0 365.73 arc
s
.126 .698 .667 r
.16446 .20674 m
.16446 .20674 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.16446 .20674 .00202 0 365.73 arc
s
.126 .698 .667 r
.15395 .20357 m
.15395 .20357 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.15395 .20357 .00165 0 365.73 arc
s
.126 .698 .667 r
.09424 .20215 m
.09424 .20215 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.09424 .20215 .00832 0 365.73 arc
s
.126 .698 .667 r
.08186 .2017 m
.08186 .2017 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.08186 .2017 .00407 0 365.73 arc
s
.126 .698 .667 r
.0754 .20205 m
.0754 .20205 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.0754 .20205 .0024 0 365.73 arc
s
.126 .698 .667 r
.08559 .19769 m
.08559 .19769 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.08559 .19769 .00141 0 365.73 arc
s
.126 .698 .667 r
.08534 .20577 m
.08534 .20577 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.08534 .20577 .00129 0 365.73 arc
s
.126 .698 .667 r
.10279 .19417 m
.10279 .19417 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.10279 .19417 .00338 0 365.73 arc
s
.126 .698 .667 r
.10702 .19116 m
.10702 .19116 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.10702 .19116 .00182 0 365.73 arc
s
.126 .698 .667 r
.09821 .19343 m
.09821 .19343 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.09821 .19343 .00126 0 365.73 arc
s
.126 .698 .667 r
.10298 .19864 m
.10298 .19864 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.10298 .19864 .0011 0 365.73 arc
s
.126 .698 .667 r
.09909 .2121 m
.09909 .2121 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.09909 .2121 .00276 0 365.73 arc
s
.126 .698 .667 r
.10107 .21572 m
.10107 .21572 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.10107 .21572 .00137 0 365.73 arc
s
.126 .698 .667 r
.09537 .21143 m
.09537 .21143 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.09537 .21143 .00103 0 365.73 arc
s
.126 .698 .667 r
.10077 .20876 m
.10077 .20876 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.10077 .20876 .00098 0 365.73 arc
s
.126 .698 .667 r
.1212 .24248 m
.1212 .24248 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.1212 .24248 .00786 0 365.73 arc
s
.126 .698 .667 r
.11731 .25345 m
.11731 .25345 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.11731 .25345 .00378 0 365.73 arc
s
.126 .698 .667 r
.11489 .25893 m
.11489 .25893 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.11489 .25893 .00222 0 365.73 arc
s
.126 .698 .667 r
.12205 .2516 m
.12205 .2516 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.12205 .2516 .00131 0 365.73 arc
s
.126 .698 .667 r
.11495 .24905 m
.11495 .24905 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.11495 .24905 .00121 0 365.73 arc
s
.126 .698 .667 r
.13132 .23809 m
.13132 .23809 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.13132 .23809 .00317 0 365.73 arc
s
.126 .698 .667 r
.13555 .23564 m
.13555 .23564 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.13555 .23564 .00171 0 365.73 arc
s
.126 .698 .667 r
.13023 .2423 m
.13023 .2423 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.13023 .2423 .00118 0 365.73 arc
s
.126 .698 .667 r
.12754 .23623 m
.12754 .23623 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.12754 .23623 .00104 0 365.73 arc
s
.126 .698 .667 r
.1142 .23462 m
.1142 .23462 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.1142 .23462 .00267 0 365.73 arc
s
.126 .698 .667 r
.11167 .2315 m
.11167 .2315 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.11167 .2315 .00134 0 365.73 arc
s
.126 .698 .667 r
.11346 .2382 m
.11346 .2382 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.11346 .2382 .00099 0 365.73 arc
s
.126 .698 .667 r
.1178 .23436 m
.1178 .23436 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.1178 .23436 .00094 0 365.73 arc
s
.126 .698 .667 r
.59524 .07789 m
.59524 .07789 .04497 0 365.73 arc
F
.18 .18 .31 r
newpath
.59524 .07789 .04497 0 365.73 arc
s
.126 .698 .667 r
.6106 .03061 m
.6106 .03061 .00475 0 365.73 arc
F
.18 .18 .31 r
newpath
.6106 .03061 .00475 0 365.73 arc
s
.126 .698 .667 r
.61222 .02562 m
.61222 .02562 .0005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61222 .02562 .0005 0 365.73 arc
s
.126 .698 .667 r
.61239 .0251 m
.61239 .0251 5e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61239 .0251 5e-005 0 365.73 arc
s
.126 .698 .667 r
.61241 .02504 m
.61241 .02504 1e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61241 .02504 1e-005 0 365.73 arc
s
.126 .698 .667 r
.61231 .0251 m
.61231 .0251 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61231 .0251 3e-005 0 365.73 arc
s
.126 .698 .667 r
.61246 .02515 m
.61246 .02515 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61246 .02515 3e-005 0 365.73 arc
s
.126 .698 .667 r
.61144 .02565 m
.61144 .02565 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61144 .02565 .00029 0 365.73 arc
s
.126 .698 .667 r
.61097 .0257 m
.61097 .0257 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.61097 .0257 .00018 0 365.73 arc
s
.126 .698 .667 r
.61169 .02537 m
.61169 .02537 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61169 .02537 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61171 .02591 m
.61171 .02591 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61171 .02591 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61284 .02611 m
.61284 .02611 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61284 .02611 .00029 0 365.73 arc
s
.126 .698 .667 r
.61319 .02642 m
.61319 .02642 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.61319 .02642 .00018 0 365.73 arc
s
.126 .698 .667 r
.61281 .02573 m
.61281 .02573 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61281 .02573 9e-005 0 365.73 arc
s
.126 .698 .667 r
.61247 .02616 m
.61247 .02616 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.61247 .02616 9e-005 0 365.73 arc
s
.126 .698 .667 r
.60315 .03089 m
.60315 .03089 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.60315 .03089 .0027 0 365.73 arc
s
.126 .698 .667 r
.59873 .03131 m
.59873 .03131 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.59873 .03131 .00174 0 365.73 arc
s
.126 .698 .667 r
.59579 .03171 m
.59579 .03171 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.59579 .03171 .00122 0 365.73 arc
s
.126 .698 .667 r
.60019 .02957 m
.60019 .02957 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.60019 .02957 .00054 0 365.73 arc
s
.126 .698 .667 r
.6005 .03272 m
.6005 .03272 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.6005 .03272 .00052 0 365.73 arc
s
.126 .698 .667 r
.60552 .0282 m
.60552 .0282 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.60552 .0282 .00088 0 365.73 arc
s
.126 .698 .667 r
.60655 .02739 m
.60655 .02739 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.60655 .02739 .00043 0 365.73 arc
s
.126 .698 .667 r
.6043 .02805 m
.6043 .02805 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.6043 .02805 .00036 0 365.73 arc
s
.126 .698 .667 r
.60572 .02935 m
.60572 .02935 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.60572 .02935 .00029 0 365.73 arc
s
.126 .698 .667 r
.60572 .03331 m
.60572 .03331 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.60572 .03331 .00083 0 365.73 arc
s
.126 .698 .667 r
.60673 .03401 m
.60673 .03401 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.60673 .03401 .0004 0 365.73 arc
s
.126 .698 .667 r
.60458 .03357 m
.60458 .03357 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.60458 .03357 .00034 0 365.73 arc
s
.126 .698 .667 r
.60583 .03221 m
.60583 .03221 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.60583 .03221 .00028 0 365.73 arc
s
.126 .698 .667 r
.61647 .03521 m
.61647 .03521 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.61647 .03521 .0027 0 365.73 arc
s
.126 .698 .667 r
.6198 .03816 m
.6198 .03816 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.6198 .03816 .00174 0 365.73 arc
s
.126 .698 .667 r
.62193 .04021 m
.62193 .04021 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.62193 .04021 .00122 0 365.73 arc
s
.126 .698 .667 r
.61964 .03589 m
.61964 .03589 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.61964 .03589 .00054 0 365.73 arc
s
.126 .698 .667 r
.61754 .03825 m
.61754 .03825 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.61754 .03825 .00052 0 365.73 arc
s
.126 .698 .667 r
.61613 .03164 m
.61613 .03164 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.61613 .03164 .00088 0 365.73 arc
s
.126 .698 .667 r
.61577 .03039 m
.61577 .03039 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.61577 .03039 .00043 0 365.73 arc
s
.126 .698 .667 r
.61721 .03224 m
.61721 .03224 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.61721 .03224 .00036 0 365.73 arc
s
.126 .698 .667 r
.61529 .03246 m
.61529 .03246 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.61529 .03246 .00029 0 365.73 arc
s
.126 .698 .667 r
.61296 .03567 m
.61296 .03567 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.61296 .03567 .00083 0 365.73 arc
s
.126 .698 .667 r
.61173 .03563 m
.61173 .03563 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.61173 .03563 .0004 0 365.73 arc
s
.126 .698 .667 r
.61373 .03654 m
.61373 .03654 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.61373 .03654 .00034 0 365.73 arc
s
.126 .698 .667 r
.61352 .03471 m
.61352 .03471 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.61352 .03471 .00028 0 365.73 arc
s
.126 .698 .667 r
.52471 .08047 m
.52471 .08047 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.52471 .08047 .02562 0 365.73 arc
s
.126 .698 .667 r
.48277 .08453 m
.48277 .08453 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.48277 .08453 .01652 0 365.73 arc
s
.126 .698 .667 r
.45497 .08831 m
.45497 .08831 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.45497 .08831 .01153 0 365.73 arc
s
.126 .698 .667 r
.4352 .09155 m
.4352 .09155 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.4352 .09155 .0085 0 365.73 arc
s
.126 .698 .667 r
.46442 .07672 m
.46442 .07672 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.46442 .07672 .00342 0 365.73 arc
s
.126 .698 .667 r
.46717 .09682 m
.46717 .09682 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.46717 .09682 .00334 0 365.73 arc
s
.126 .698 .667 r
.49666 .06799 m
.49666 .06799 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.49666 .06799 .00508 0 365.73 arc
s
.126 .698 .667 r
.50253 .0633 m
.50253 .0633 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.50253 .0633 .00243 0 365.73 arc
s
.126 .698 .667 r
.48952 .06717 m
.48952 .06717 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.48952 .06717 .0021 0 365.73 arc
s
.126 .698 .667 r
.49804 .07461 m
.49804 .07461 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.49804 .07461 .00169 0 365.73 arc
s
.126 .698 .667 r
.49959 .0978 m
.49959 .0978 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.49959 .0978 .00491 0 365.73 arc
s
.126 .698 .667 r
.50597 .1012 m
.50597 .1012 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.50597 .1012 .00233 0 365.73 arc
s
.126 .698 .667 r
.49301 .09998 m
.49301 .09998 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.49301 .09998 .00202 0 365.73 arc
s
.126 .698 .667 r
.49965 .09124 m
.49965 .09124 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.49965 .09124 .00165 0 365.73 arc
s
.126 .698 .667 r
.54713 .05499 m
.54713 .05499 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.54713 .05499 .00832 0 365.73 arc
s
.126 .698 .667 r
.55688 .04736 m
.55688 .04736 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.55688 .04736 .00407 0 365.73 arc
s
.126 .698 .667 r
.56231 .04384 m
.56231 .04384 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.56231 .04384 .0024 0 365.73 arc
s
.126 .698 .667 r
.5515 .04631 m
.5515 .04631 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.5515 .04631 .00141 0 365.73 arc
s
.126 .698 .667 r
.55645 .05269 m
.55645 .05269 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.55645 .05269 .00129 0 365.73 arc
s
.126 .698 .667 r
.53552 .05357 m
.53552 .05357 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.53552 .05357 .00338 0 365.73 arc
s
.126 .698 .667 r
.53033 .05362 m
.53033 .05362 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.53033 .05362 .00182 0 365.73 arc
s
.126 .698 .667 r
.53879 .05028 m
.53879 .05028 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.53879 .05028 .00126 0 365.73 arc
s
.126 .698 .667 r
.53799 .05729 m
.53799 .05729 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.53799 .05729 .0011 0 365.73 arc
s
.126 .698 .667 r
.54905 .0659 m
.54905 .0659 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.54905 .0659 .00276 0 365.73 arc
s
.126 .698 .667 r
.54958 .06999 m
.54958 .06999 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.54958 .06999 .00137 0 365.73 arc
s
.126 .698 .667 r
.55167 .06317 m
.55167 .06317 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.55167 .06317 .00103 0 365.73 arc
s
.126 .698 .667 r
.54573 .06419 m
.54573 .06419 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.54573 .06419 .00098 0 365.73 arc
s
.126 .698 .667 r
.54902 .10347 m
.54902 .10347 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.54902 .10347 .00786 0 365.73 arc
s
.126 .698 .667 r
.55861 .11006 m
.55861 .11006 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.55861 .11006 .00378 0 365.73 arc
s
.126 .698 .667 r
.5638 .11307 m
.5638 .11307 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.5638 .11307 .00222 0 365.73 arc
s
.126 .698 .667 r
.5537 .11135 m
.5537 .11135 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.5537 .11135 .00131 0 365.73 arc
s
.126 .698 .667 r
.55794 .10511 m
.55794 .10511 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.55794 .10511 .00121 0 365.73 arc
s
.126 .698 .667 r
.53825 .10587 m
.53825 .10587 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.53825 .10587 .00317 0 365.73 arc
s
.126 .698 .667 r
.5334 .10637 m
.5334 .10637 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.5334 .10637 .00171 0 365.73 arc
s
.126 .698 .667 r
.54161 .10864 m
.54161 .10864 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.54161 .10864 .00118 0 365.73 arc
s
.126 .698 .667 r
.54022 .10214 m
.54022 .10214 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.54022 .10214 .00104 0 365.73 arc
s
.126 .698 .667 r
.55006 .093 m
.55006 .093 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.55006 .093 .00267 0 365.73 arc
s
.126 .698 .667 r
.55028 .08899 m
.55028 .08899 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.55028 .08899 .00134 0 365.73 arc
s
.126 .698 .667 r
.55277 .09546 m
.55277 .09546 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.55277 .09546 .00099 0 365.73 arc
s
.126 .698 .667 r
.547 .09491 m
.547 .09491 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.547 .09491 .00094 0 365.73 arc
s
.126 .698 .667 r
.65079 .12143 m
.65079 .12143 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.65079 .12143 .02562 0 365.73 arc
s
.126 .698 .667 r
.68233 .14937 m
.68233 .14937 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.68233 .14937 .01652 0 365.73 arc
s
.126 .698 .667 r
.70259 .16877 m
.70259 .16877 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.70259 .16877 .01153 0 365.73 arc
s
.126 .698 .667 r
.71668 .18301 m
.71668 .18301 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.71668 .18301 .0085 0 365.73 arc
s
.126 .698 .667 r
.70177 .15384 m
.70177 .15384 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.70177 .15384 .00342 0 365.73 arc
s
.126 .698 .667 r
.68772 .16849 m
.68772 .16849 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.68772 .16849 .00334 0 365.73 arc
s
.126 .698 .667 r
.68081 .12782 m
.68081 .12782 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.68081 .12782 .00508 0 365.73 arc
s
.126 .698 .667 r
.67882 .12058 m
.67882 .12058 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.67882 .12058 .00243 0 365.73 arc
s
.126 .698 .667 r
.68707 .13136 m
.68707 .13136 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.68707 .13136 .0021 0 365.73 arc
s
.126 .698 .667 r
.6758 .13237 m
.6758 .13237 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.6758 .13237 .00169 0 365.73 arc
s
.126 .698 .667 r
.66092 .15022 m
.66092 .15022 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.66092 .15022 .00491 0 365.73 arc
s
.126 .698 .667 r
.65376 .14922 m
.65376 .14922 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.65376 .14922 .00233 0 365.73 arc
s
.126 .698 .667 r
.66496 .15585 m
.66496 .15585 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.66496 .15585 .00202 0 365.73 arc
s
.126 .698 .667 r
.66472 .14488 m
.66472 .14488 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.66472 .14488 .00165 0 365.73 arc
s
.126 .698 .667 r
.64762 .08765 m
.64762 .08765 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.64762 .08765 .00832 0 365.73 arc
s
.126 .698 .667 r
.64422 .07574 m
.64422 .07574 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.64422 .07574 .00407 0 365.73 arc
s
.126 .698 .667 r
.64189 .0697 m
.64189 .0697 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.64189 .0697 .0024 0 365.73 arc
s
.126 .698 .667 r
.64919 .07805 m
.64919 .07805 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.64919 .07805 .00141 0 365.73 arc
s
.126 .698 .667 r
.64143 .0803 m
.64143 .0803 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.64143 .0803 .00129 0 365.73 arc
s
.126 .698 .667 r
.65785 .09332 m
.65785 .09332 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.65785 .09332 .00338 0 365.73 arc
s
.126 .698 .667 r
.66202 .09641 m
.66202 .09641 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.66202 .09641 .00182 0 365.73 arc
s
.126 .698 .667 r
.65714 .08874 m
.65714 .08874 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.65714 .08874 .00126 0 365.73 arc
s
.126 .698 .667 r
.65366 .09487 m
.65366 .09487 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.65366 .09487 .0011 0 365.73 arc
s
.126 .698 .667 r
.63966 .09534 m
.63966 .09534 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.63966 .09534 .00276 0 365.73 arc
s
.126 .698 .667 r
.63682 .09834 m
.63682 .09834 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.63682 .09834 .00137 0 365.73 arc
s
.126 .698 .667 r
.63915 .09159 m
.63915 .09159 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.63915 .09159 .00103 0 365.73 arc
s
.126 .698 .667 r
.64335 .0959 m
.64335 .0959 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.64335 .0959 .00098 0 365.73 arc
s
.126 .698 .667 r
.6176 .12575 m
.6176 .12575 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.6176 .12575 .00786 0 365.73 arc
s
.126 .698 .667 r
.60596 .12544 m
.60596 .12544 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.60596 .12544 .00378 0 365.73 arc
s
.126 .698 .667 r
.6 .12483 m
.6 .12483 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.6 .12483 .00222 0 365.73 arc
s
.126 .698 .667 r
.60918 .12938 m
.60918 .12938 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.60918 .12938 .00131 0 365.73 arc
s
.126 .698 .667 r
.60941 .12184 m
.60941 .12184 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.60941 .12184 .00121 0 365.73 arc
s
.126 .698 .667 r
.6249 .13402 m
.6249 .13402 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.6249 .13402 .00317 0 365.73 arc
s
.126 .698 .667 r
.62853 .13728 m
.62853 .13728 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.62853 .13728 .00171 0 365.73 arc
s
.126 .698 .667 r
.62056 .13429 m
.62056 .13429 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.62056 .13429 .00118 0 365.73 arc
s
.126 .698 .667 r
.6255 .12985 m
.6255 .12985 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.6255 .12985 .00104 0 365.73 arc
s
.126 .698 .667 r
.62291 .11667 m
.62291 .11667 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.62291 .11667 .00267 0 365.73 arc
s
.126 .698 .667 r
.62509 .1133 m
.62509 .1133 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.62509 .1133 .00134 0 365.73 arc
s
.126 .698 .667 r
.61927 .11706 m
.61927 .11706 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.61927 .11706 .00099 0 365.73 arc
s
.126 .698 .667 r
.62427 .12001 m
.62427 .12001 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.62427 .12001 .00094 0 365.73 arc
s
.126 .698 .667 r
.92061 .52573 m
.92061 .52573 .04497 0 365.73 arc
F
.18 .18 .31 r
newpath
.92061 .52573 .04497 0 365.73 arc
s
.126 .698 .667 r
.97032 .52573 m
.97032 .52573 .00475 0 365.73 arc
F
.18 .18 .31 r
newpath
.97032 .52573 .00475 0 365.73 arc
s
.126 .698 .667 r
.97557 .52573 m
.97557 .52573 .0005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97557 .52573 .0005 0 365.73 arc
s
.126 .698 .667 r
.97613 .52573 m
.97613 .52573 5e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97613 .52573 5e-005 0 365.73 arc
s
.126 .698 .667 r
.97618 .52573 m
.97618 .52573 1e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97618 .52573 1e-005 0 365.73 arc
s
.126 .698 .667 r
.9761 .52565 m
.9761 .52565 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.9761 .52565 3e-005 0 365.73 arc
s
.126 .698 .667 r
.9761 .52581 m
.9761 .52581 3e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.9761 .52581 3e-005 0 365.73 arc
s
.126 .698 .667 r
.9753 .52499 m
.9753 .52499 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.9753 .52499 .00029 0 365.73 arc
s
.126 .698 .667 r
.97511 .52456 m
.97511 .52456 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.97511 .52456 .00018 0 365.73 arc
s
.126 .698 .667 r
.97565 .52514 m
.97565 .52514 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97565 .52514 9e-005 0 365.73 arc
s
.126 .698 .667 r
.97514 .52533 m
.97514 .52533 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97514 .52533 9e-005 0 365.73 arc
s
.126 .698 .667 r
.9753 .52647 m
.9753 .52647 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.9753 .52647 .00029 0 365.73 arc
s
.126 .698 .667 r
.97511 .5269 m
.97511 .5269 .00018 0 365.73 arc
F
.18 .18 .31 r
newpath
.97511 .5269 .00018 0 365.73 arc
s
.126 .698 .667 r
.97565 .52632 m
.97565 .52632 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97565 .52632 9e-005 0 365.73 arc
s
.126 .698 .667 r
.97514 .52613 m
.97514 .52613 9e-005 0 365.73 arc
F
.18 .18 .31 r
newpath
.97514 .52613 9e-005 0 365.73 arc
s
.126 .698 .667 r
.96776 .51873 m
.96776 .51873 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.96776 .51873 .0027 0 365.73 arc
s
.126 .698 .667 r
.96599 .51465 m
.96599 .51465 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.96599 .51465 .00174 0 365.73 arc
s
.126 .698 .667 r
.9647 .51199 m
.9647 .51199 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.9647 .51199 .00122 0 365.73 arc
s
.126 .698 .667 r
.9681 .51551 m
.9681 .51551 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.9681 .51551 .00054 0 365.73 arc
s
.126 .698 .667 r
.9652 .51678 m
.9652 .51678 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.9652 .51678 .00052 0 365.73 arc
s
.126 .698 .667 r
.97105 .52015 m
.97105 .52015 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.97105 .52015 .00088 0 365.73 arc
s
.126 .698 .667 r
.97214 .52088 m
.97214 .52088 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.97214 .52088 .00043 0 365.73 arc
s
.126 .698 .667 r
.97082 .51894 m
.97082 .51894 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.97082 .51894 .00036 0 365.73 arc
s
.126 .698 .667 r
.97002 .5207 m
.97002 .5207 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.97002 .5207 .00029 0 365.73 arc
s
.126 .698 .667 r
.96625 .52192 m
.96625 .52192 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.96625 .52192 .00083 0 365.73 arc
s
.126 .698 .667 r
.9659 .5231 m
.9659 .5231 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.9659 .5231 .0004 0 365.73 arc
s
.126 .698 .667 r
.96566 .52092 m
.96566 .52092 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.96566 .52092 .00034 0 365.73 arc
s
.126 .698 .667 r
.96733 .52169 m
.96733 .52169 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.96733 .52169 .00028 0 365.73 arc
s
.126 .698 .667 r
.96776 .53273 m
.96776 .53273 .0027 0 365.73 arc
F
.18 .18 .31 r
newpath
.96776 .53273 .0027 0 365.73 arc
s
.126 .698 .667 r
.96599 .53681 m
.96599 .53681 .00174 0 365.73 arc
F
.18 .18 .31 r
newpath
.96599 .53681 .00174 0 365.73 arc
s
.126 .698 .667 r
.9647 .53947 m
.9647 .53947 .00122 0 365.73 arc
F
.18 .18 .31 r
newpath
.9647 .53947 .00122 0 365.73 arc
s
.126 .698 .667 r
.9681 .53595 m
.9681 .53595 .00054 0 365.73 arc
F
.18 .18 .31 r
newpath
.9681 .53595 .00054 0 365.73 arc
s
.126 .698 .667 r
.9652 .53469 m
.9652 .53469 .00052 0 365.73 arc
F
.18 .18 .31 r
newpath
.9652 .53469 .00052 0 365.73 arc
s
.126 .698 .667 r
.97105 .53131 m
.97105 .53131 .00088 0 365.73 arc
F
.18 .18 .31 r
newpath
.97105 .53131 .00088 0 365.73 arc
s
.126 .698 .667 r
.97214 .53058 m
.97214 .53058 .00043 0 365.73 arc
F
.18 .18 .31 r
newpath
.97214 .53058 .00043 0 365.73 arc
s
.126 .698 .667 r
.97082 .53252 m
.97082 .53252 .00036 0 365.73 arc
F
.18 .18 .31 r
newpath
.97082 .53252 .00036 0 365.73 arc
s
.126 .698 .667 r
.97002 .53076 m
.97002 .53076 .00029 0 365.73 arc
F
.18 .18 .31 r
newpath
.97002 .53076 .00029 0 365.73 arc
s
.126 .698 .667 r
.96625 .52954 m
.96625 .52954 .00083 0 365.73 arc
F
.18 .18 .31 r
newpath
.96625 .52954 .00083 0 365.73 arc
s
.126 .698 .667 r
.9659 .52836 m
.9659 .52836 .0004 0 365.73 arc
F
.18 .18 .31 r
newpath
.9659 .52836 .0004 0 365.73 arc
s
.126 .698 .667 r
.96566 .53054 m
.96566 .53054 .00034 0 365.73 arc
F
.18 .18 .31 r
newpath
.96566 .53054 .00034 0 365.73 arc
s
.126 .698 .667 r
.96733 .52977 m
.96733 .52977 .00028 0 365.73 arc
F
.18 .18 .31 r
newpath
.96733 .52977 .00028 0 365.73 arc
s
.126 .698 .667 r
.89637 .45944 m
.89637 .45944 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.89637 .45944 .02562 0 365.73 arc
s
.126 .698 .667 r
.87955 .42081 m
.87955 .42081 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.87955 .42081 .01652 0 365.73 arc
s
.126 .698 .667 r
.86736 .39555 m
.86736 .39555 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.86736 .39555 .01153 0 365.73 arc
s
.126 .698 .667 r
.85817 .37775 m
.85817 .37775 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.85817 .37775 .0085 0 365.73 arc
s
.126 .698 .667 r
.8813 .40095 m
.8813 .40095 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.8813 .40095 .00342 0 365.73 arc
s
.126 .698 .667 r
.86303 .40978 m
.86303 .40978 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.86303 .40978 .00334 0 365.73 arc
s
.126 .698 .667 r
.89957 .42891 m
.89957 .42891 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.89957 .42891 .00508 0 365.73 arc
s
.126 .698 .667 r
.90585 .43305 m
.90585 .43305 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.90585 .43305 .00243 0 365.73 arc
s
.126 .698 .667 r
.89814 .42188 m
.89814 .42188 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.89814 .42188 .0021 0 365.73 arc
s
.126 .698 .667 r
.89369 .43227 m
.89369 .43227 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.89369 .43227 .00169 0 365.73 arc
s
.126 .698 .667 r
.87212 .44091 m
.87212 .44091 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.87212 .44091 .00491 0 365.73 arc
s
.126 .698 .667 r
.87086 .44803 m
.87086 .44803 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.87086 .44803 .00233 0 365.73 arc
s
.126 .698 .667 r
.86801 .43533 m
.86801 .43533 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.86801 .43533 .00202 0 365.73 arc
s
.126 .698 .667 r
.87838 .43895 m
.87838 .43895 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.87838 .43895 .00165 0 365.73 arc
s
.126 .698 .667 r
.92752 .4729 m
.92752 .4729 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.92752 .4729 .00832 0 365.73 arc
s
.126 .698 .667 r
.9378 .47981 m
.9378 .47981 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.9378 .47981 .00407 0 365.73 arc
s
.126 .698 .667 r
.94282 .48389 m
.94282 .48389 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.94282 .48389 .0024 0 365.73 arc
s
.126 .698 .667 r
.93714 .47437 m
.93714 .47437 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.93714 .47437 .00141 0 365.73 arc
s
.126 .698 .667 r
.93259 .48106 m
.93259 .48106 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.93259 .48106 .00129 0 365.73 arc
s
.126 .698 .667 r
.92529 .46142 m
.92529 .46142 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.92529 .46142 .00338 0 365.73 arc
s
.126 .698 .667 r
.92364 .45649 m
.92364 .45649 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.92364 .45649 .00182 0 365.73 arc
s
.126 .698 .667 r
.92943 .46351 m
.92943 .46351 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.92943 .46351 .00126 0 365.73 arc
s
.126 .698 .667 r
.92251 .46492 m
.92251 .46492 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.92251 .46492 .0011 0 365.73 arc
s
.126 .698 .667 r
.91775 .4781 m
.91775 .4781 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.91775 .4781 .00276 0 365.73 arc
s
.126 .698 .667 r
.91402 .47986 m
.91402 .47986 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.91402 .47986 .00137 0 365.73 arc
s
.126 .698 .667 r
.92115 .47974 m
.92115 .47974 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.92115 .47974 .00103 0 365.73 arc
s
.126 .698 .667 r
.91835 .47441 m
.91835 .47441 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.91835 .47441 .00098 0 365.73 arc
s
.126 .698 .667 r
.882 .48968 m
.882 .48968 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.882 .48968 .00786 0 365.73 arc
s
.126 .698 .667 r
.8787 .50084 m
.8787 .50084 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.8787 .50084 .00378 0 365.73 arc
s
.126 .698 .667 r
.87744 .5067 m
.87744 .5067 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.87744 .5067 .00222 0 365.73 arc
s
.126 .698 .667 r
.87595 .49656 m
.87595 .49656 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.87595 .49656 .00131 0 365.73 arc
s
.126 .698 .667 r
.8832 .49867 m
.8832 .49867 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.8832 .49867 .00121 0 365.73 arc
s
.126 .698 .667 r
.8764 .48018 m
.8764 .48018 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.8764 .48018 .00317 0 365.73 arc
s
.126 .698 .667 r
.87442 .47571 m
.87442 .47571 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.87442 .47571 .00171 0 365.73 arc
s
.126 .698 .667 r
.8748 .48422 m
.8748 .48422 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.8748 .48422 .00118 0 365.73 arc
s
.126 .698 .667 r
.88055 .4809 m
.88055 .4809 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.88055 .4809 .00104 0 365.73 arc
s
.126 .698 .667 r
.89229 .48743 m
.89229 .48743 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.89229 .48743 .00267 0 365.73 arc
s
.126 .698 .667 r
.89617 .4864 m
.89617 .4864 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.89617 .4864 .00134 0 365.73 arc
s
.126 .698 .667 r
.89079 .49077 m
.89079 .49077 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.89079 .49077 .00099 0 365.73 arc
s
.126 .698 .667 r
.88952 .48511 m
.88952 .48511 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.88952 .48511 .00094 0 365.73 arc
s
.126 .698 .667 r
.89637 .59202 m
.89637 .59202 .02562 0 365.73 arc
F
.18 .18 .31 r
newpath
.89637 .59202 .02562 0 365.73 arc
s
.126 .698 .667 r
.87955 .63065 m
.87955 .63065 .01652 0 365.73 arc
F
.18 .18 .31 r
newpath
.87955 .63065 .01652 0 365.73 arc
s
.126 .698 .667 r
.86736 .65591 m
.86736 .65591 .01153 0 365.73 arc
F
.18 .18 .31 r
newpath
.86736 .65591 .01153 0 365.73 arc
s
.126 .698 .667 r
.85817 .67371 m
.85817 .67371 .0085 0 365.73 arc
F
.18 .18 .31 r
newpath
.85817 .67371 .0085 0 365.73 arc
s
.126 .698 .667 r
.8813 .65051 m
.8813 .65051 .00342 0 365.73 arc
F
.18 .18 .31 r
newpath
.8813 .65051 .00342 0 365.73 arc
s
.126 .698 .667 r
.86303 .64168 m
.86303 .64168 .00334 0 365.73 arc
F
.18 .18 .31 r
newpath
.86303 .64168 .00334 0 365.73 arc
s
.126 .698 .667 r
.89957 .62255 m
.89957 .62255 .00508 0 365.73 arc
F
.18 .18 .31 r
newpath
.89957 .62255 .00508 0 365.73 arc
s
.126 .698 .667 r
.90585 .61842 m
.90585 .61842 .00243 0 365.73 arc
F
.18 .18 .31 r
newpath
.90585 .61842 .00243 0 365.73 arc
s
.126 .698 .667 r
.89814 .62959 m
.89814 .62959 .0021 0 365.73 arc
F
.18 .18 .31 r
newpath
.89814 .62959 .0021 0 365.73 arc
s
.126 .698 .667 r
.89369 .61919 m
.89369 .61919 .00169 0 365.73 arc
F
.18 .18 .31 r
newpath
.89369 .61919 .00169 0 365.73 arc
s
.126 .698 .667 r
.87212 .61055 m
.87212 .61055 .00491 0 365.73 arc
F
.18 .18 .31 r
newpath
.87212 .61055 .00491 0 365.73 arc
s
.126 .698 .667 r
.87086 .60343 m
.87086 .60343 .00233 0 365.73 arc
F
.18 .18 .31 r
newpath
.87086 .60343 .00233 0 365.73 arc
s
.126 .698 .667 r
.86801 .61613 m
.86801 .61613 .00202 0 365.73 arc
F
.18 .18 .31 r
newpath
.86801 .61613 .00202 0 365.73 arc
s
.126 .698 .667 r
.87838 .61251 m
.87838 .61251 .00165 0 365.73 arc
F
.18 .18 .31 r
newpath
.87838 .61251 .00165 0 365.73 arc
s
.126 .698 .667 r
.92752 .57856 m
.92752 .57856 .00832 0 365.73 arc
F
.18 .18 .31 r
newpath
.92752 .57856 .00832 0 365.73 arc
s
.126 .698 .667 r
.9378 .57165 m
.9378 .57165 .00407 0 365.73 arc
F
.18 .18 .31 r
newpath
.9378 .57165 .00407 0 365.73 arc
s
.126 .698 .667 r
.94282 .56757 m
.94282 .56757 .0024 0 365.73 arc
F
.18 .18 .31 r
newpath
.94282 .56757 .0024 0 365.73 arc
s
.126 .698 .667 r
.93714 .57709 m
.93714 .57709 .00141 0 365.73 arc
F
.18 .18 .31 r
newpath
.93714 .57709 .00141 0 365.73 arc
s
.126 .698 .667 r
.93259 .57041 m
.93259 .57041 .00129 0 365.73 arc
F
.18 .18 .31 r
newpath
.93259 .57041 .00129 0 365.73 arc
s
.126 .698 .667 r
.92529 .59004 m
.92529 .59004 .00338 0 365.73 arc
F
.18 .18 .31 r
newpath
.92529 .59004 .00338 0 365.73 arc
s
.126 .698 .667 r
.92364 .59497 m
.92364 .59497 .00182 0 365.73 arc
F
.18 .18 .31 r
newpath
.92364 .59497 .00182 0 365.73 arc
s
.126 .698 .667 r
.92943 .58795 m
.92943 .58795 .00126 0 365.73 arc
F
.18 .18 .31 r
newpath
.92943 .58795 .00126 0 365.73 arc
s
.126 .698 .667 r
.92251 .58654 m
.92251 .58654 .0011 0 365.73 arc
F
.18 .18 .31 r
newpath
.92251 .58654 .0011 0 365.73 arc
s
.126 .698 .667 r
.91775 .57337 m
.91775 .57337 .00276 0 365.73 arc
F
.18 .18 .31 r
newpath
.91775 .57337 .00276 0 365.73 arc
s
.126 .698 .667 r
.91402 .5716 m
.91402 .5716 .00137 0 365.73 arc
F
.18 .18 .31 r
newpath
.91402 .5716 .00137 0 365.73 arc
s
.126 .698 .667 r
.92115 .57172 m
.92115 .57172 .00103 0 365.73 arc
F
.18 .18 .31 r
newpath
.92115 .57172 .00103 0 365.73 arc
s
.126 .698 .667 r
.91835 .57705 m
.91835 .57705 .00098 0 365.73 arc
F
.18 .18 .31 r
newpath
.91835 .57705 .00098 0 365.73 arc
s
.126 .698 .667 r
.882 .56178 m
.882 .56178 .00786 0 365.73 arc
F
.18 .18 .31 r
newpath
.882 .56178 .00786 0 365.73 arc
s
.126 .698 .667 r
.8787 .55062 m
.8787 .55062 .00378 0 365.73 arc
F
.18 .18 .31 r
newpath
.8787 .55062 .00378 0 365.73 arc
s
.126 .698 .667 r
.87744 .54476 m
.87744 .54476 .00222 0 365.73 arc
F
.18 .18 .31 r
newpath
.87744 .54476 .00222 0 365.73 arc
s
.126 .698 .667 r
.87595 .5549 m
.87595 .5549 .00131 0 365.73 arc
F
.18 .18 .31 r
newpath
.87595 .5549 .00131 0 365.73 arc
s
.126 .698 .667 r
.8832 .55279 m
.8832 .55279 .00121 0 365.73 arc
F
.18 .18 .31 r
newpath
.8832 .55279 .00121 0 365.73 arc
s
.126 .698 .667 r
.8764 .57128 m
.8764 .57128 .00317 0 365.73 arc
F
.18 .18 .31 r
newpath
.8764 .57128 .00317 0 365.73 arc
s
.126 .698 .667 r
.87442 .57575 m
.87442 .57575 .00171 0 365.73 arc
F
.18 .18 .31 r
newpath
.87442 .57575 .00171 0 365.73 arc
s
.126 .698 .667 r
.8748 .56724 m
.8748 .56724 .00118 0 365.73 arc
F
.18 .18 .31 r
newpath
.8748 .56724 .00118 0 365.73 arc
s
.126 .698 .667 r
.88055 .57056 m
.88055 .57056 .00104 0 365.73 arc
F
.18 .18 .31 r
newpath
.88055 .57056 .00104 0 365.73 arc
s
.126 .698 .667 r
.89229 .56403 m
.89229 .56403 .00267 0 365.73 arc
F
.18 .18 .31 r
newpath
.89229 .56403 .00267 0 365.73 arc
s
.126 .698 .667 r
.89617 .56506 m
.89617 .56506 .00134 0 365.73 arc
F
.18 .18 .31 r
newpath
.89617 .56506 .00134 0 365.73 arc
s
.126 .698 .667 r
.89079 .56069 m
.89079 .56069 .00099 0 365.73 arc
F
.18 .18 .31 r
newpath
.89079 .56069 .00099 0 365.73 arc
s
.126 .698 .667 r
.88952 .56636 m
.88952 .56636 .00094 0 365.73 arc
F
.18 .18 .31 r
newpath
.88952 .56636 .00094 0 365.73 arc
s
0 0 m
1 0 L
1 1.05146 L
0 1.05146 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[165]:=",
  ImageSize->{273.875, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00017b000`400?l00000o`00003oo`3ooolB
0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB
0?ooo`00YP3oool202h^CfT0oooo002S0?ooo`D0;Ri?J@3oool00:80oooo0P0^;Tl00`0P/ZX0;Ri?
022bZP0202h^CfP0oooo002N0?ooo``0;Ri?I`3oool009`0oooo0P0^;Tl9022bZP<0;Ri?I`3oool0
09P0oooo0P0^;Tl00`3oool0;Ri?022bZP0<022bZP80;Ri?IP3oool009D0oooo1P0^;Tl?022bZP03
02h^C`3oool0oooo06@0oooo002A0?ooo`@0;Ri?00<08;:Z02h^C`0^;Tl00P0^;TlA022bZP0302h^
C`3oool0oooo06<0oooo002@0?ooo`@0;Ri?0`0P/ZX202h^Ca<08;:Z00<0;Ri?0?ooo`3oool0HP3o
ool008`0oooo200^;Tl3022bZP0302h^C`0P/ZX08;:Z01<08;:Z00<0;Ri?0?ooo`3oool0H@3oool0
08P0oooo100^;Tl6022bZP80;Ri?0P0P/ZX202h^CaD08;:Z00<0;Ri?0?ooo`3oool0H@3oool008D0
oooo1@0^;Tl:022bZP<0;Ri?5`0P/ZX00`0^;Tl0oooo0?ooo`1P0?ooo`00PP3oool502h^C`03022b
ZP0^;Tl0;Ri?00X08;:Z0`0^;TlG022bZP80;Ri?H@3oool00800oooo0P0^;Tl3022bZP@0;Ri?300P
/ZX202h^CaL08;:Z0P0^;TmQ0?ooo`00O@3oool302h^C`H08;:Z0`0^;Tl<022bZP80;Ri?5`0P/ZX0
100^;Tl08;:Z02h^C`0^;TmO0?ooo`00NP3oool302h^C`030?ooo`0^;Tl0;Ri?00P08;:Z00<0;Ri?
022bZP0P/ZX02`0P/ZX00`0^;Tl08;:Z022bZP0E022bZP@0;Ri?G`3oool007H0oooo00D0;Ri?0?oo
o`3oool0oooo02h^C`02022bZP<0;Ri?200P/ZX00`0^;Tl08;:Z022bZP0;022bZP0302h^C`0P/ZX0
8;:Z01D08;:Z0P0^;Tl00`0P/ZX0;Ri?02h^C`1N0?ooo`00M@3oool00`0^;Tl08;:Z02h^C`0202h^
C`@08;:Z0P0^;Tl8022bZP0302h^C`0P/ZX08;:Z00X08;:Z0P0^;TlG022bZP0402h^C`0P/ZX08;:Z
022bZP80;Ri?G@3oool007@0oooo00@0;Ri?022bZP0P/ZX08;:Z0P0^;Tl5022bZP0302h^C`0P/ZX0
8;:Z00D08;:Z0P0^;Tl<022bZP80;Ri?5`0P/ZX0100^;Tl08;:Z022bZP0P/ZX302h^Ce`0oooo001d
0?ooo`0302h^C`0P/ZX08;:Z00808;:Z00<0;Ri?022bZP0P/ZX00P0P/ZX302h^C`D08;:Z100^;Tl;
022bZP<0;Ri?5@0P/ZX302h^C`808;:Z00<0;Ri?022bZP0^;Tl0G03oool007D0oooo00<0;Ri?022b
ZP0P/ZX00`0^;Tl3022bZP0302h^C`0P/ZX0;Ri?00D08;:Z00<0;Ri?022bZP0P/ZX00P0^;Tl9022b
ZP@0;Ri?5@0P/ZX902h^Ce/0oooo001^0?oooaX0;Ri?00@08;:Z02h^C`0^;Tl0;Ri?1`0P/ZX01@0^
;Tl08;:Z022bZP0P/ZX0;Ri?01@08;:Z0`0^;Tl6022bZP0302h^C`3oool0oooo05T0oooo001X0?oo
o`H0;Ri?6P0P/ZX602h^C`<08;:Z0`0^;Tl3022bZP80;Ri?4`0P/ZX00`0^;Tl08;:Z022bZP07022b
ZP0302h^C`3oool0oooo05P0oooo001R0?ooo`H0;Ri?9@0P/ZX802h^C`808;:Z0`0^;TlA022bZP03
02h^C`0P/ZX08;:Z00T08;:Z00<0;Ri?0?ooo`3oool0E`3oool005d0oooo1@0^;Tla022bZPD0;Ri?
00<08;:Z02h^C`0^;Tl03`0P/ZX202h^C`/08;:Z00<0;Ri?0?ooo`3oool0E`3oool005X0oooo0`0^
;Tlk022bZP@0;Ri?300P/ZX302h^C`d08;:Z00<0;Ri?0?ooo`3oool0EP3oool005L0oooo0`0^;Tm2
022bZP80;Ri?200P/ZX502h^C`d08;:Z0P0^;TmG0?ooo`00E03oool302h^CdL08;:Z2@0^;Tl2022b
ZP80;Ri?3@0P/ZX202h^CeL0oooo001B0?ooo`80;Ri?C@0P/ZX402h^C`03022bZP0^;Tl08;:Z0080
8;:Z0P0^;Tl<022bZP0402h^C`0P/ZX0;Ri?02h^CeD0oooo001?0?ooo`<0;Ri?DP0P/ZX302h^C`80
8;:Z0`0^;Tl<022bZP0302h^C`0P/ZX0;Ri?0080;Ri?E03oool004`0oooo0`0^;TmG022bZP@0;Ri?
00<08;:Z02h^C`0P/ZX02P0P/ZX602h^Ce@0oooo001:0?ooo`80;Ri?G@0P/ZX402h^C`X08;:Z00<0
;Ri?022bZP0P/ZX00`0P/ZX00`0^;Tl0oooo0?ooo`1A0?ooo`00B03oool202h^Cf808;:Z0P0^;Tl8
022bZP0302h^C`0P/ZX08;:Z00@08;:Z00<0;Ri?0?ooo`3oool0D@3oool004H0oooo0P0^;TmV022b
ZP80;Ri?0`0P/ZX302h^C`P08;:Z00<0;Ri?0?ooo`3oool0D03oool004D0oooo00<0;Ri?022bZP0P
/ZX0I`0P/ZX502h^C`03022bZP0^;Tl08;:Z00L08;:Z00<0;Ri?0?ooo`3oool0D03oool00480oooo
0`0^;Tm/022bZP<0;Ri?00<08;:Z02h^C`0P/ZX01`0P/ZX302h^Ce00oooo00100?ooo`80;Ri?L@0P
/ZX402h^C`L08;:Z0`0^;Tm@0?ooo`00=P3oool502h^C`@0oooo00<0;Ri?022bZP0P/ZX0L`0P/ZX2
02h^C`H08;:Z0P0^;Tl00`0P/ZX0;Ri?02h^C`1?0?ooo`00<`3oool00`0^;Tl0oooo02h^C`04022b
ZP0302h^C`3oool0oooo0080;Ri?N00P/ZX202h^C`<08;:Z00<0;Ri?022bZP0P/ZX00`0P/ZX00`0^
;Tl0oooo0?ooo`1<0?ooo`00;`3oool01@0^;Tl0oooo02h^C`0^;Tl08;:Z0080;Ri?100P/ZX302h^
Cg/08;:Z1@0^;Tl5022bZP0302h^C`3oool0oooo04`0oooo000]0?ooo`80;Ri?00<08;:Z02h^C`0P
/ZX00`0P/ZX202h^C`808;:Z0P0^;Tmo022bZP<0;Ri?1@0P/ZX00`0^;Tl0oooo0?ooo`1<0?ooo`00
:`3oool202h^C`04022bZP0^;Tl0;Ri?02h^C`D08;:Z100^;Tn2022bZP80;Ri?0`0P/ZX00`0^;Tl0
oooo02h^C`1=0?ooo`009P3oool502h^C`@08;:Z0P0^;Tl5022bZP<0;Ri?Q00P/ZX0100^;Tl08;:Z
022bZP0P/ZX202h^C`03022bZP0^;Tl0;Ri?04/0oooo000T0?ooo`80;Ri?00<08;:Z02h^C`0^;Tl0
1`0P/ZX202h^C`<08;:Z0P0^;Tn7022bZP@0;Ri?0`0P/ZX00`0^;Tl0oooo0?ooo`190?ooo`00803o
ool602h^C`03022bZP0^;Tl0;Ri?00L08;:Z1P0^;Tn9022bZP<0;Ri?0`0P/ZX00`0^;Tl0oooo0?oo
o`190?ooo`00703oool202h^C`030?ooo`0^;Tl08;:Z00<08;:Z1@0^;Tl8022bZP<0;Ri?S@0P/ZX0
1@0^;Tl08;:Z022bZP0P/ZX0;Ri?04/0oooo000I0?ooo`H0;Ri?200P/ZX202h^C`L08;:Z0`0^;Tn?
022bZP<0;Ri?C03oool001H0oooo0`0^;Tl00`0P/ZX0;Ri?02h^C`0202h^C`X08;:Z00<0;Ri?022b
ZP0P/ZX01@0P/ZX202h^Ci808;:Z00<0;Ri?0?ooo`3oool0BP3oool001@0oooo100^;Tl3022bZP80
;Ri?300P/ZX00`0^;Tl08;:Z022bZP03022bZP80;Ri?U00P/ZX00`0^;Tl0oooo0?ooo`190?ooo`00
403oool602h^C`03022bZP0^;Tl08;:Z00808;:Z00<0;Ri?022bZP0P/ZX02`0P/ZX702h^CiH08;:Z
00<0;Ri?0?ooo`3oool0B03oool000h0oooo0P0^;Tl5022bZP@0;Ri?0P0P/ZX00`0^;Tl08;:Z022b
ZP0;022bZP80;Ri?00<08;:Z02h^C`0^;Tl0V@0P/ZX00`0^;Tl0oooo0?ooo`170?ooo`002@3oool5
02h^C`T08;:Z1@0^;Tl=022bZP80;Ri?00<08;:Z02h^C`0P/ZX0VP0P/ZX00`0^;Tl0oooo0?ooo`16
0?ooo`001P3oool602h^C`d08;:Z100^;Tl<022bZP@0;Ri?W00P/ZX00`0^;Tl0oooo0?ooo`150?oo
o`001P3oool00`0^;Tl08;:Z02h^C`0202h^Ca008;:Z0P0^;Tl<022bZP80;Ri?W`0P/ZX00`0^;Tl0
oooo0?ooo`140?ooo`001P3oool0100^;Tl08;:Z02h^C`0^;TlB022bZP0302h^C`0P/ZX08;:Z00T0
8;:Z0P0^;TnQ022bZP0302h^C`3oool0oooo04<0oooo00060?ooo`<0;Ri?4`0P/ZX202h^C`X08;:Z
00<0;Ri?022bZP0P/ZX0X@0P/ZX00`0^;Tl0oooo0?ooo`120?ooo`001P3oool202h^CaD08;:Z0P0^
;Tl8022bZP0302h^C`0P/ZX08;:Z0:<08;:Z00<0;Ri?0?ooo`3oool0@@3oool000H0oooo0P0^;TlE
022bZP@0;Ri?0`0P/ZX302h^CjL08;:Z00<0;Ri?0?ooo`3oool0@03oool000H0oooo0P0^;TlF022b
ZPP0;Ri?Z@0P/ZX00`0^;Tl0oooo0?ooo`0o0?ooo`001P3oool00`0^;Tl08;:Z022bZP0E022bZP80
;Ri?0P0P/ZX302h^Cj/08;:Z00<0;Ri?0?ooo`3oool0?P3oool000H0oooo00<0;Ri?022bZP0P/ZX0
5@0P/ZX00`0^;Tl08;:Z022bZP02022bZP0302h^C`0P/ZX08;:Z0:/08;:Z00<0;Ri?0?ooo`3oool0
?@3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX202h^C`808;:Z00<0;Ri?022bZP0P/ZX0[@0P
/ZX00`0^;Tl0oooo0?ooo`0l0?ooo`001P3oool00`0^;Tl08;:Z022bZP0E022bZP@0;Ri?/@0P/ZX0
0`0^;Tl0oooo0?ooo`0k0?ooo`001P3oool00`0^;Tl08;:Z022bZP0E022bZP@0;Ri?/P0P/ZX00`0^
;Tl0oooo0?ooo`0j0?ooo`001P3oool00`0^;Tl08;:Z022bZP0E022bZP<0;Ri?/`0P/ZX00`0^;Tl0
oooo0?ooo`0j0?ooo`001`3oool00`0^;Tl08;:Z022bZP0D022bZP80;Ri?]@0P/ZX00`0^;Tl0oooo
0?ooo`0i0?ooo`001`3oool00`0^;Tl08;:Z022bZP0D022bZP0302h^C`0P/ZX08;:Z0;D08;:Z00<0
;Ri?0?ooo`3oool0>03oool000H0oooo0P0^;TlE022bZP80;Ri?^00P/ZX00`0^;Tl0oooo0?ooo`0g
0?ooo`001P3oool302h^Ca<08;:Z0P0^;Tnj022bZP0302h^C`3oool0oooo03H0oooo00060?ooo`04
02h^C`0P/ZX0;Ri?02h^Ca408;:Z0P0^;Tnl022bZP0302h^C`3oool0oooo03D0oooo00060?ooo`@0
;Ri?4@0P/ZX00`0^;Tl08;:Z022bZP2k022bZP0302h^C`3oool0oooo03D0oooo00060?ooo`0302h^
C`0P/ZX08;:Z00<0;Ri?3P0P/ZX202h^Ckh08;:Z00<0;Ri?0?ooo`3oool0=03oool000H0oooo00@0
;Ri?022bZP0P/ZX08;:Z100^;Tl:022bZP<0;Ri?_`0P/ZX00`0^;Tl0oooo0?ooo`0d0?ooo`001P3o
ool0100^;Tl08;:Z022bZP0P/ZX702h^C`D08;:Z100^;To1022bZP0302h^C`3oool0oooo03<0oooo
00060?ooo`D0;Ri?100P/ZX;02h^Cl808;:Z00<0;Ri?0?ooo`3oool0<P3oool000H0oooo00<0;Ri?
022bZP0^;Tl0200P/ZX302h^C`<08;:Z0P0^;To3022bZP0302h^C`3oool0oooo0380oooo00060?oo
o`<0;Ri?2@0P/ZX202h^C`<08;:Z00<0;Ri?022bZP0P/ZX0``0P/ZX00`0^;Tl0oooo0?ooo`0a0?oo
o`001P3oool202h^C`/08;:Z00D0;Ri?022bZP0P/ZX08;:Z02h^C`36022bZP0302h^C`3oool0oooo
0300oooo00070?ooo`0302h^C`0P/ZX08;:Z00X08;:Z0`0^;To7022bZP0302h^C`3oool0oooo0300
oooo00060?ooo`0302h^C`0P/ZX08;:Z00/08;:Z0`0^;To8022bZP0302h^C`3oool0oooo02l0oooo
00060?ooo`0302h^C`0P/ZX08;:Z00/08;:Z0P0^;To9022bZP0302h^C`3oool0oooo02l0oooo0006
0?ooo`0302h^C`0P/ZX08;:Z00/08;:Z00<0;Ri?022bZP0P/ZX0b@0P/ZX00`0^;Tl0oooo0?ooo`0^
0?ooo`001P3oool00`0^;Tl08;:Z022bZP0:022bZP80;Ri?c00P/ZX00`0^;Tl0oooo0?ooo`0]0?oo
o`001`3oool00`0^;Tl08;:Z022bZP09022bZP0302h^C`0P/ZX08;:Z0</08;:Z00<0;Ri?0?ooo`3o
ool0;@3oool000H0oooo0P0^;Tl:022bZP80;Ri?cP0P/ZX00`0^;Tl0oooo0?ooo`0/0?ooo`001P3o
ool302h^C`T08;:Z0P0^;To>022bZP0302h^C`3oool0oooo02`0oooo00060?ooo`0302h^C`0P/ZX0
8;:Z00<0;Ri?100P/ZX302h^Cm008;:Z00<0;Ri?0?ooo`3oool0:`3oool000H0oooo3@0^;To@022b
ZP0302h^C`3oool0oooo02/0oooo00060?ooo`<0;Ri?100P/ZX202h^C`808;:Z00<0;Ri?022bZP0P
/ZX0c`0P/ZX00`0^;Tl0oooo0?ooo`0[0?ooo`001P3oool202h^C`H08;:Z0`0^;ToC022bZP0302h^
C`3oool0oooo02X0oooo00060?ooo`0302h^C`0P/ZX08;:Z00H08;:Z0P0^;ToC022bZP0302h^C`3o
ool0oooo02X0oooo00060?ooo`0302h^C`0P/ZX08;:Z00H08;:Z00<0;Ri?022bZP0P/ZX0d`0P/ZX0
0`0^;Tl0oooo0?ooo`0Y0?ooo`001P3oool00`0^;Tl08;:Z022bZP06022bZP0302h^C`0P/ZX08;:Z
0=<08;:Z00<0;Ri?0?ooo`3oool0:@3oool000H0oooo00<0;Ri?022bZP0P/ZX01P0P/ZX00`0^;Tl0
8;:Z022bZP3C022bZP0302h^C`3oool0oooo02T0oooo00070?ooo`0302h^C`0P/ZX08;:Z00@08;:Z
00<0;Ri?022bZP0P/ZX0e@0P/ZX01@0^;Tl0oooo0?ooo`3oool0;Ri?02H0oooo00060?ooo`0402h^
C`0P/ZX0;Ri?02h^C`808;:Z0`0^;ToG022bZP0602h^C`3oool0;Ri?02h^C`0P/ZX0;Ri?9@3oool0
00H0oooo200^;ToH022bZP80;Ri?0`0P/ZX00`0^;Tl0oooo0?ooo`0S0?ooo`001`3oool0100^;Tl0
8;:Z022bZP0P/ZX302h^CmT08;:Z00<0;Ri?022bZP0P/ZX00P0P/ZX00`0^;Tl0oooo0?ooo`0R0?oo
o`001P3oool00`0^;Tl08;:Z022bZP03022bZP80;Ri?f@0P/ZX202h^C`808;:Z0`0^;TlS0?ooo`00
1P3oool00`0^;Tl08;:Z022bZP03022bZP0302h^C`0P/ZX08;:Z0=T08;:Z100^;Tl2022bZP80;Ri?
8@3oool000H0oooo00<0;Ri?022bZP0P/ZX00P0P/ZX202h^Cm/08;:Z0P0^;Tl5022bZP0302h^C`3o
ool0oooo01l0oooo00070?ooo`0402h^C`0P/ZX08;:Z022bZP80;Ri?f`0P/ZX202h^C`D08;:Z00<0
;Ri?0?ooo`3oool07`3oool000L0oooo1@0^;ToM022bZP0302h^C`0P/ZX08;:Z00<08;:Z0`0^;TlO
0?ooo`001P3oool00`0^;Tl08;:Z022bZP0302h^Cmd08;:Z0P0^;Tl3022bZP80;Ri?00<08;:Z02h^
C`3oool07P3oool000H0oooo00<0;Ri?022bZP0P/ZX00P0P/ZX00`0^;Tl08;:Z022bZP3K022bZP<0
;Ri?0P0P/ZX502h^Cah0oooo00060?ooo`0502h^C`0P/ZX08;:Z022bZP0^;Tl0g`0P/ZX0100^;Tl0
8;:Z02h^C`0^;Tl4022bZP0302h^C`3oool0oooo01`0oooo00070?ooo`0402h^C`0P/ZX08;:Z02h^
Cml08;:Z0`0^;Tl6022bZP0302h^C`3oool0oooo01/0oooo00080?ooo`<0;Ri?g`0P/ZX202h^C`P0
8;:Z00<0;Ri?0?ooo`3oool06P3oool000X0oooo00<0;Ri?022bZP0P/ZX0gP0P/ZX00`0^;Tl08;:Z
022bZP06022bZP80;Ri?6`3oool000X0oooo00<0;Ri?022bZP0P/ZX0gP0P/ZX00`0^;Tl08;:Z022b
ZP06022bZP80;Ri?6`3oool000T0oooo00<0;Ri?022bZP0P/ZX0g`0P/ZX00`0^;Tl08;:Z022bZP06
022bZP0302h^C`0P/ZX0;Ri?01X0oooo00090?ooo`0302h^C`0P/ZX08;:Z0>008;:Z00<0;Ri?022b
ZP0P/ZX0100P/ZX202h^C`03022bZP0^;Tl0;Ri?01T0oooo00090?ooo`0302h^C`0P/ZX08;:Z0>00
8;:Z0P0^;Tl5022bZPD0;Ri?6@3oool000P0oooo00<0;Ri?022bZP0P/ZX0h@0P/ZX702h^C`<08;:Z
0P0^;TlI0?ooo`00203oool00`0^;Tl08;:Z022bZP3Q022bZP0302h^C`0P/ZX08;:Z0080;Ri?1`0P
/ZX202h^CaL0oooo00080?ooo`0302h^C`0P/ZX08;:Z0>408;:Z0`0^;Tl;022bZP0302h^C`3oool0
oooo01@0oooo00080?ooo`0302h^C`0P/ZX08;:Z0>808;:Z0P0^;Tl;022bZP0302h^C`3oool0oooo
01@0oooo00080?ooo`0302h^C`0P/ZX08;:Z0>808;:Z0P0^;Tl<022bZP0302h^C`3oool0oooo01<0
oooo00080?ooo`0302h^C`0P/ZX08;:Z0>808;:Z00<0;Ri?022bZP0P/ZX02`0P/ZX202h^Ca@0oooo
00070?ooo`0302h^C`0P/ZX08;:Z0><08;:Z00<0;Ri?022bZP0P/ZX02`0P/ZX302h^Ca<0oooo0007
0?ooo`0302h^C`0P/ZX08;:Z0><08;:Z00<0;Ri?022bZP0P/ZX02`0P/ZX302h^Ca<0oooo00070?oo
o`0302h^C`0P/ZX08;:Z0><08;:Z0P0^;Tl<022bZP80;Ri?00<08;:Z02h^C`3oool04@3oool000L0
oooo00<0;Ri?022bZP0P/ZX0i00P/ZX00`0^;Tl08;:Z022bZP09022bZP0502h^C`0P/ZX08;:Z022b
ZP0^;Tl04P3oool000L0oooo00<0;Ri?022bZP0P/ZX0i00P/ZX202h^C`T08;:Z0P0^;Tl4022bZP80
;Ri?403oool000L0oooo00<0;Ri?022bZP0P/ZX0i00P/ZX202h^C`T08;:Z00<0;Ri?022bZP0^;Tl0
0P0P/ZX402h^C`l0oooo00070?ooo`0302h^C`0P/ZX08;:Z0>@08;:Z1@0^;Tl3022bZP`0;Ri?3`3o
ool000L0oooo00<0;Ri?022bZP0P/ZX0i00P/ZX202h^C`03022bZP0^;Tl0;Ri?00@0;Ri?200P/ZX3
02h^C`l0oooo00060?ooo`0302h^C`0P/ZX08;:Z0>D08;:Z00@0;Ri?022bZP0P/ZX08;:Z0`0^;Tl<
022bZP80;Ri?3P3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX0100^;Tl08;:Z022bZP0P/ZX2
02h^C`l08;:Z00<0;Ri?0?ooo`3oool02`3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX502h^
Ca408;:Z00<0;Ri?0?ooo`3oool02P3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX0100^;Tl0
8;:Z02h^C`0^;TlB022bZP0302h^C`3oool0oooo00X0oooo00060?ooo`0302h^C`0P/ZX08;:Z0>D0
8;:Z0`0^;TlD022bZP0302h^C`3oool0oooo00T0oooo00060?ooo`0302h^C`0P/ZX08;:Z0>D08;:Z
0`0^;TlD022bZP0302h^C`3oool0oooo00T0oooo00060?ooo`0302h^C`0P/ZX08;:Z0>D08;:Z0P0^
;TlF022bZP80;Ri?2@3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX202h^CaH08;:Z0`0^;Tl8
0?ooo`001P3oool00`0^;Tl08;:Z022bZP3U022bZP0302h^C`0P/ZX08;:Z01H08;:Z0`0^;Tl70?oo
o`001P3oool00`0^;Tl08;:Z022bZP3U022bZP0302h^C`0P/ZX08;:Z01H08;:Z100^;Tl60?ooo`00
1P3oool00`0^;Tl08;:Z022bZP3U022bZP0302h^C`0P/ZX08;:Z01H08;:Z00@0;Ri?022bZP0P/ZX0
;Ri?1P3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX202h^CaL08;:Z0`0^;Tl70?ooo`001P3o
ool00`0^;Tl08;:Z022bZP3U022bZP80;Ri?5`0P/ZX302h^C`L0oooo00060?ooo`0302h^C`0P/ZX0
8;:Z0>D08;:Z0P0^;TlG022bZP80;Ri?203oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX202h^
CaH08;:Z0P0^;Tl90?ooo`001P3oool00`0^;Tl08;:Z022bZP3U022bZP<0;Ri?5@0P/ZX00`0^;Tl0
oooo0?ooo`080?ooo`001P3oool00`0^;Tl08;:Z022bZP3U022bZP<0;Ri?500P/ZX00`0^;Tl0oooo
0?ooo`090?ooo`001P3oool00`0^;Tl08;:Z022bZP3U022bZP0402h^C`0P/ZX0;Ri?02h^Ca<08;:Z
00<0;Ri?0?ooo`3oool02@3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX502h^Ca408;:Z00<0
;Ri?0?ooo`3oool02P3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX0100^;Tl08;:Z022bZP0P
/ZX202h^C`l08;:Z00<0;Ri?0?ooo`3oool02`3oool000H0oooo00<0;Ri?022bZP0P/ZX0i@0P/ZX0
100^;Tl08;:Z022bZP0P/ZX302h^C``08;:Z0P0^;Tl>0?ooo`001`3oool00`0^;Tl08;:Z022bZP3T
022bZP80;Ri?0P0P/ZX502h^C`P08;:Z0`0^;Tl?0?ooo`001`3oool00`0^;Tl08;:Z022bZP3T022b
ZP@0;Ri?100P/ZX<02h^C`l0oooo00070?ooo`0302h^C`0P/ZX08;:Z0>@08;:Z0`0^;Tl7022bZP80
;Ri?00@08;:Z02h^C`0^;Tl08;:Z100^;Tl?0?ooo`001`3oool00`0^;Tl08;:Z022bZP3T022bZP80
;Ri?2@0P/ZX202h^C`<08;:Z0`0^;Tl@0?ooo`001`3oool00`0^;Tl08;:Z022bZP3T022bZP0302h^
C`0P/ZX08;:Z00T08;:Z00@0;Ri?022bZP0P/ZX08;:Z0P0^;TlA0?ooo`001`3oool00`0^;Tl08;:Z
022bZP3S022bZP80;Ri?300P/ZX0100^;Tl08;:Z022bZP0^;TlB0?ooo`001`3oool00`0^;Tl08;:Z
022bZP3S022bZP0302h^C`0P/ZX08;:Z00/08;:Z0`0^;TlC0?ooo`001`3oool00`0^;Tl08;:Z022b
ZP3S022bZP0302h^C`0P/ZX08;:Z00/08;:Z0`0^;TlC0?ooo`00203oool00`0^;Tl08;:Z022bZP3R
022bZP0302h^C`0P/ZX08;:Z00/08;:Z0P0^;TlD0?ooo`00203oool00`0^;Tl08;:Z022bZP3R022b
ZP80;Ri?300P/ZX00`0^;Tl0oooo0?ooo`0C0?ooo`00203oool00`0^;Tl08;:Z022bZP3R022bZP80
;Ri?300P/ZX00`0^;Tl0oooo0?ooo`0C0?ooo`00203oool00`0^;Tl08;:Z022bZP3Q022bZP@0;Ri?
2P0P/ZX00`0^;Tl0oooo0?ooo`0D0?ooo`00203oool00`0^;Tl08;:Z022bZP3Q022bZP0302h^C`0P
/ZX08;:Z0080;Ri?200P/ZX00`0^;Tl0oooo0?ooo`0E0?ooo`00203oool00`0^;Tl08;:Z022bZP3Q
022bZPL0;Ri?1@0P/ZX00`0^;Tl0oooo0?ooo`0F0?ooo`002@3oool00`0^;Tl08;:Z022bZP3P022b
ZP80;Ri?0`0P/ZX702h^CaT0oooo00090?ooo`0302h^C`0P/ZX08;:Z0>008;:Z00<0;Ri?022bZP0P
/ZX0100P/ZX202h^C`03022bZP0^;Tl0;Ri?01T0oooo00090?ooo`0302h^C`0P/ZX08;:Z0=l08;:Z
00<0;Ri?022bZP0P/ZX01P0P/ZX00`0^;Tl08;:Z02h^C`0J0?ooo`002P3oool00`0^;Tl08;:Z022b
ZP3N022bZP0302h^C`0P/ZX08;:Z00H08;:Z0P0^;TlK0?ooo`002P3oool00`0^;Tl08;:Z022bZP3N
022bZP0302h^C`0P/ZX08;:Z00H08;:Z0P0^;TlK0?ooo`002P3oool00`0^;Tl08;:Z022bZP3N022b
ZP0302h^C`0P/ZX08;:Z00H08;:Z00<0;Ri?0?ooo`3oool06P3oool000L0oooo100^;ToO022bZP<0
;Ri?1P0P/ZX00`0^;Tl0oooo0?ooo`0K0?ooo`001P3oool01@0^;Tl08;:Z022bZP0P/ZX0;Ri?0=l0
8;:Z00<0;Ri?022bZP0^;Tl01P0P/ZX00`0^;Tl0oooo0?ooo`0K0?ooo`001P3oool00`0^;Tl08;:Z
022bZP02022bZP0302h^C`0P/ZX08;:Z0=/08;:Z0`0^;Tl00`0P/ZX0;Ri?02h^C`0402h^Cah0oooo
00070?ooo`0302h^C`0P/ZX08;:Z0080;Ri?g@0P/ZX00`0^;Tl08;:Z022bZP03022bZP0302h^C`0P
/ZX0;Ri?01l0oooo00080?ooo`@0;Ri?g@0P/ZX00`0^;Tl08;:Z022bZP03022bZP<0;Ri?7`3oool0
00L0oooo0P0^;Tl2022bZP80;Ri?f`0P/ZX202h^C`D08;:Z00<0;Ri?0?ooo`3oool07`3oool000H0
oooo00<0;Ri?022bZP0P/ZX00`0P/ZX00`0^;Tl08;:Z022bZP3I022bZP0302h^C`3oool0;Ri?00<0
8;:Z00<0;Ri?0?ooo`3oool0803oool000H0oooo00<0;Ri?022bZP0P/ZX00`0P/ZX00`0^;Tl08;:Z
022bZP3I022bZP0302h^C`3oool0;Ri?00<08;:Z00<0;Ri?0?ooo`3oool0803oool000H0oooo00<0
;Ri?022bZP0P/ZX00`0P/ZX202h^CmT08;:Z0`0^;Tl0100P/ZX0;Ri?02h^C`0^;TlS0?ooo`001`3o
ool0100^;Tl08;:Z022bZP0P/ZX302h^CmT08;:Z00@0;Ri?022bZP0P/ZX08;:Z0P0^;TlT0?ooo`00
1P3oool802h^CmP08;:Z0P0^;Tl3022bZP80;Ri?903oool000H0oooo00<0;Ri?022bZP0^;Tl00P0^
;Tl0100P/ZX0;Ri?02h^C`0^;ToG022bZP0302h^C`3oool0;Ri?00808;:Z00<0;Ri?0?ooo`3oool0
8`3oool000L0oooo00<0;Ri?022bZP0P/ZX0100P/ZX00`0^;Tl08;:Z022bZP3E022bZP0302h^C`3o
ool0oooo0080;Ri?9P3oool000H0oooo00<0;Ri?022bZP0P/ZX01P0P/ZX00`0^;Tl08;:Z022bZP3C
022bZP0302h^C`3oool0oooo02T0oooo00060?ooo`0302h^C`0P/ZX08;:Z00H08;:Z00<0;Ri?022b
ZP0P/ZX0d`0P/ZX00`0^;Tl0oooo0?ooo`0Y0?ooo`001P3oool00`0^;Tl08;:Z022bZP06022bZP03
02h^C`0P/ZX08;:Z0=<08;:Z00<0;Ri?0?ooo`3oool0:@3oool000H0oooo00<0;Ri?022bZP0P/ZX0
1P0P/ZX202h^Cm<08;:Z00<0;Ri?0?ooo`3oool0:P3oool000H0oooo0P0^;Tl6022bZP<0;Ri?d`0P
/ZX00`0^;Tl0oooo0?ooo`0Z0?ooo`001P3oool202h^C`D08;:Z0P0^;Tl2022bZP0302h^C`0P/ZX0
8;:Z0<l08;:Z00<0;Ri?0?ooo`3oool0:`3oool000H0oooo3@0^;To@022bZP0302h^C`3oool0oooo
02/0oooo00060?ooo`0302h^C`0P/ZX08;:Z0080;Ri?100P/ZX402h^Cm008;:Z00<0;Ri?0?ooo`3o
ool0:`3oool000H0oooo0`0^;Tl8022bZP0302h^C`3oool0;Ri?0<h08;:Z00<0;Ri?0?ooo`3oool0
;03oool000H0oooo0P0^;Tl:022bZP80;Ri?cP0P/ZX00`0^;Tl0oooo0?ooo`0/0?ooo`001`3oool0
0`0^;Tl08;:Z022bZP09022bZP0302h^C`0P/ZX08;:Z0</08;:Z00<0;Ri?0?ooo`3oool0;@3oool0
00L0oooo00<0;Ri?022bZP0P/ZX02P0P/ZX00`0^;Tl08;:Z022bZP3:022bZP0302h^C`3oool0oooo
02d0oooo00060?ooo`0302h^C`0P/ZX08;:Z00/08;:Z00<0;Ri?022bZP0P/ZX0b@0P/ZX00`0^;Tl0
oooo0?ooo`0^0?ooo`001P3oool00`0^;Tl08;:Z022bZP0;022bZP80;Ri?b@0P/ZX00`0^;Tl0oooo
0?ooo`0_0?ooo`001P3oool00`0^;Tl08;:Z022bZP0;022bZP<0;Ri?b00P/ZX00`0^;Tl0oooo0?oo
o`0_0?ooo`001P3oool00`0^;Tl08;:Z022bZP0:022bZP@0;Ri?a`0P/ZX00`0^;Tl0oooo0?ooo`0`
0?ooo`001P3oool202h^C`/08;:Z0P0^;Tl00`0P/ZX0;Ri?02h^C`36022bZP0302h^C`3oool0oooo
0300oooo00060?ooo`80;Ri?2P0P/ZX202h^C`<08;:Z00<0;Ri?022bZP0P/ZX0``0P/ZX00`0^;Tl0
oooo0?ooo`0a0?ooo`001P3oool00`0^;Tl08;:Z02h^C`09022bZP80;Ri?0`0P/ZX202h^Cl<08;:Z
00<0;Ri?0?ooo`3oool0<P3oool000H0oooo1P0^;Tl5022bZP@0;Ri?00<08;:Z02h^C`0^;Tl00P0^
;To2022bZP0302h^C`3oool0oooo0380oooo00060?ooo`0302h^C`0P/ZX08;:Z00P0;Ri?0`0P/ZX6
02h^Cl408;:Z00<0;Ri?0?ooo`3oool0<`3oool000H0oooo00@0;Ri?022bZP0P/ZX08;:Z100^;Tl9
022bZP@0;Ri?`00P/ZX00`0^;Tl0oooo0?ooo`0c0?ooo`001P3oool0100^;Tl08;:Z022bZP0P/ZX2
02h^C`d08;:Z0`0^;Tnn022bZP0302h^C`3oool0oooo03@0oooo00060?ooo`D0;Ri?400P/ZX00`0^
;Tl08;:Z022bZP2k022bZP0302h^C`3oool0oooo03D0oooo00060?ooo`0402h^C`0P/ZX0;Ri?02h^
Ca808;:Z00<0;Ri?022bZP0P/ZX0^P0P/ZX00`0^;Tl0oooo0?ooo`0e0?ooo`001P3oool302h^Ca<0
8;:Z0P0^;Tnj022bZP0302h^C`3oool0oooo03H0oooo00060?ooo`80;Ri?5@0P/ZX202h^CkP08;:Z
00<0;Ri?0?ooo`3oool0=`3oool000L0oooo00<0;Ri?022bZP0P/ZX04`0P/ZX202h^CkL08;:Z00<0
;Ri?0?ooo`3oool0>03oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX202h^CkD08;:Z00<0;Ri?
0?ooo`3oool0>@3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX302h^Ck<08;:Z00<0;Ri?0?oo
o`3oool0>P3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX402h^Ck808;:Z00<0;Ri?0?ooo`3o
ool0>P3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX402h^Ck408;:Z00<0;Ri?0?ooo`3oool0
>`3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX302h^C`03022bZP0^;Tl08;:Z0:h08;:Z00<0
;Ri?0?ooo`3oool0?03oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX0100^;Tl08;:Z022bZP0P
/ZX202h^Cjd08;:Z00<0;Ri?0?ooo`3oool0?@3oool000H0oooo00<0;Ri?022bZP0P/ZX05@0P/ZX2
02h^C`808;:Z0`0^;Tn[022bZP0302h^C`3oool0oooo03h0oooo00060?ooo`80;Ri?5P0P/ZX802h^
CjT08;:Z00<0;Ri?0?ooo`3oool0?`3oool000H0oooo0P0^;TlF022bZP@0;Ri?0P0P/ZX302h^CjL0
8;:Z00<0;Ri?0?ooo`3oool0@03oool000H0oooo0P0^;TlE022bZP<0;Ri?1P0P/ZX202h^CjD08;:Z
00<0;Ri?0?ooo`3oool0@@3oool000H0oooo0`0^;TlC022bZP80;Ri?2P0P/ZX00`0^;Tl08;:Z022b
ZP2Q022bZP0302h^C`3oool0oooo0480oooo00060?ooo`0402h^C`0P/ZX0;Ri?02h^Ca408;:Z0P0^
;Tl;022bZP80;Ri?X@0P/ZX00`0^;Tl0oooo0?ooo`130?ooo`001P3oool502h^Ca008;:Z0P0^;Tl<
022bZP80;Ri?W`0P/ZX00`0^;Tl0oooo0?ooo`140?ooo`001P3oool602h^C`h08;:Z0P0^;Tl=022b
ZP<0;Ri?W@0P/ZX00`0^;Tl0oooo0?ooo`150?ooo`002@3oool302h^C`d08;:Z0`0^;Tl=022bZP04
02h^C`0P/ZX08;:Z02h^Ci/08;:Z00<0;Ri?0?ooo`3oool0AP3oool000`0oooo0`0^;Tl7022bZP<0
;Ri?00<08;:Z02h^C`0^;Tl03@0P/ZX202h^C`03022bZP0^;Tl0;Ri?09T08;:Z00<0;Ri?0?ooo`3o
ool0A`3oool000l0oooo1`0^;Tl00`0P/ZX0;Ri?022bZP02022bZP80;Ri?300P/ZX702h^CiH08;:Z
00<0;Ri?0?ooo`3oool0B03oool001@0oooo0P0^;Tl00`0P/ZX0;Ri?022bZP02022bZP80;Ri?300P
/ZX202h^C`@08;:Z0P0^;TnD022bZP0302h^C`3oool0oooo04T0oooo000F0?ooo`<0;Ri?00@08;:Z
02h^C`0^;Tl0;Ri?2`0P/ZX00`0^;Tl08;:Z022bZP05022bZP80;Ri?TP0P/ZX00`0^;Tl0oooo0?oo
o`1:0?ooo`006@3oool502h^C`T08;:Z0P0^;Tl7022bZP<0;Ri?T00P/ZX00`0^;Tl0oooo0?ooo`1;
0?ooo`00703oool302h^C`L08;:Z0`0^;Tl7022bZP@0;Ri?S@0P/ZX202h^C`03022bZP0^;Tl0;Ri?
04/0oooo000O0?ooo`P0;Ri?00<08;:Z02h^C`0P/ZX01P0P/ZX502h^Ch/08;:Z0P0^;Tl3022bZP03
02h^C`3oool0oooo04T0oooo000T0?ooo`80;Ri?0P0P/ZX00`0^;Tl08;:Z022bZP05022bZP80;Ri?
0P0P/ZX302h^ChL08;:Z100^;Tl3022bZP0302h^C`3oool0oooo04T0oooo000V0?ooo`@0;Ri?1@0P
/ZX202h^C`@08;:Z00@0;Ri?0?ooo`0^;Tl0;Ri?Q00P/ZX202h^C`808;:Z00D0;Ri?022bZP0P/ZX0
8;:Z02h^C`1;0?ooo`00:P3oool0100^;Tl08;:Z022bZP0P/ZX302h^C`D08;:Z100^;Tn2022bZP03
02h^C`0P/ZX08;:Z00<08;:Z0`0^;Tm<0?ooo`00:`3oool402h^C`03022bZP0^;Tl08;:Z00<08;:Z
00@0;Ri?022bZP0P/ZX08;:Z0P0^;Tmo022bZP<0;Ri?1@0P/ZX00`0^;Tl0oooo0?ooo`1<0?ooo`00
;`3oool00`0^;Tl0oooo02h^C`03022bZP0302h^C`0P/ZX08;:Z00808;:Z0`0^;Tmk022bZPD0;Ri?
1@0P/ZX00`0^;Tl0oooo0?ooo`1<0?ooo`00<P3oool402h^C`<08;:Z00@0;Ri?0?ooo`3oool0oooo
0P0^;Tmh022bZP0402h^C`0P/ZX08;:Z022bZP<0;Ri?0`0P/ZX00`0^;Tl0oooo0?ooo`1=0?ooo`00
=P3oool0100^;Tl08;:Z022bZP0^;Tl50?ooo`0302h^C`0P/ZX08;:Z07<08;:Z0P0^;Tl6022bZP05
02h^C`0P/ZX08;:Z022bZP0^;Tl0C`3oool003L0oooo0P0^;Tl70?ooo`80;Ri?L@0P/ZX402h^C`L0
8;:Z0`0^;Tm@0?ooo`00@P3oool202h^Cfd08;:Z0`0^;Tl00`0P/ZX0;Ri?022bZP07022bZP<0;Ri?
D03oool004@0oooo0P0^;TmY022bZPD0;Ri?00<08;:Z02h^C`0P/ZX01`0P/ZX00`0^;Tl0oooo0?oo
o`1@0?ooo`00AP3oool202h^CfH08;:Z0`0^;Tl2022bZP<0;Ri?200P/ZX00`0^;Tl0oooo0?ooo`1@
0?ooo`00B03oool00`0^;Tl08;:Z022bZP1Q022bZP80;Ri?1`0P/ZX00`0^;Tl08;:Z022bZP05022b
ZP0302h^C`3oool0oooo0540oooo00190?ooo`<0;Ri?G@0P/ZX302h^C`X08;:Z00<0;Ri?022bZP0P
/ZX0100P/ZX00`0^;Tl0oooo0?ooo`1A0?ooo`00C03oool302h^CeP08;:Z0`0^;Tl00`0P/ZX0;Ri?
022bZP0:022bZPH0;Ri?E03oool004l0oooo0P0^;TmC022bZP@0;Ri?00@08;:Z02h^C`0^;Tl0;Ri?
300P/ZX00`0^;Tl08;:Z02h^C`0202h^Ce@0oooo001A0?ooo`<0;Ri?C@0P/ZX402h^C`03022bZP0^
;Tl08;:Z00808;:Z00<0;Ri?022bZP0P/ZX02`0P/ZX0100^;Tl08;:Z022bZP0^;TmE0?ooo`00E03o
ool302h^CdL08;:Z2@0^;Tl3022bZP0302h^C`0P/ZX08;:Z00/08;:Z0`0^;TmF0?ooo`00E`3oool3
02h^Cd808;:Z100^;Tl6022bZPD0;Ri?3@0P/ZX202h^CeL0oooo001J0?ooo`<0;Ri?>`0P/ZX602h^
C`X08;:Z100^;Tl<022bZP0302h^C`3oool0oooo05H0oooo001M0?ooo`D0;Ri?<@0P/ZX502h^C`04
022bZP0^;Tl0;Ri?02h^C`h08;:Z0P0^;Tl<022bZP0302h^C`3oool0oooo05H0oooo001R0?ooo`H0
;Ri?9P0P/ZX702h^C`03022bZP0^;Tl0;Ri?0080;Ri?4@0P/ZX00`0^;Tl08;:Z022bZP09022bZP03
02h^C`3oool0oooo05L0oooo001X0?ooo`H0;Ri?6P0P/ZX<02h^C`<08;:Z0P0^;TlC022bZP0302h^
C`0P/ZX08;:Z00L08;:Z00<0;Ri?0?ooo`3oool0F03oool006h0oooo6P0^;Tl0100P/ZX0;Ri?02h^
C`0^;Tl7022bZP0502h^C`0P/ZX08;:Z022bZP0^;Tl05@0P/ZX202h^C`H08;:Z00<0;Ri?0?ooo`3o
ool0F@3oool007D0oooo00D0;Ri?022bZP0^;Tl0;Ri?0?ooo`0202h^C`04022bZP0^;Tl0;Ri?022b
ZP80;Ri?100P/ZX00`0^;Tl08;:Z022bZP0202h^C`T08;:Z100^;TlE022bZPT0;Ri?F`3oool007@0
oooo00@0;Ri?022bZP0P/ZX08;:Z0P0^;Tl4022bZP<0;Ri?1P0P/ZX302h^C`X08;:Z100^;TlE022b
ZP<0;Ri?00D08;:Z02h^C`0^;Tl08;:Z02h^C`1L0?ooo`00M03oool00`0^;Tl08;:Z022bZP02022b
ZP0302h^C`0P/ZX08;:Z00<08;:Z00<0;Ri?022bZP0P/ZX01@0P/ZX202h^C``08;:Z0P0^;TlG022b
ZP0402h^C`0P/ZX08;:Z022bZP<0;Ri?G03oool007D0oooo00<0;Ri?022bZP0P/ZX00P0^;Tl5022b
ZP0302h^C`0P/ZX08;:Z00H08;:Z00<0;Ri?022bZP0P/ZX02P0P/ZX202h^CaL08;:Z00@0;Ri?022b
ZP0P/ZX08;:Z0P0^;TmM0?ooo`00MP3oool202h^C`030?ooo`0^;Tl08;:Z00<08;:Z0P0^;Tl7022b
ZP80;Ri?3@0P/ZX00`0^;Tl08;:Z022bZP0E022bZP80;Ri?0P0P/ZX00`0^;Tl0oooo0?ooo`1L0?oo
o`00N@3oool202h^C`<08;:Z0P0^;Tl7022bZP80;Ri?3@0P/ZX00`0^;Tl08;:Z022bZP0E022bZP@0
;Ri?G`3oool007/0oooo1P0^;Tl5022bZP<0;Ri?300P/ZX202h^CaL08;:Z00@0;Ri?022bZP0^;Tl0
;Ri?G`3oool00800oooo00<0;Ri?022bZP0P/ZX00`0P/ZX302h^C``08;:Z0P0^;TlG022bZP<0;Ri?
H03oool00840oooo1P0^;Tl00`0P/ZX0;Ri?02h^C`0;022bZP80;Ri?5`0P/ZX202h^Cf40oooo0025
0?ooo`H0;Ri?2@0P/ZX302h^CaH08;:Z00<0;Ri?0?ooo`3oool0H@3oool008P0oooo0P0^;Tl00`3o
ool0;Ri?022bZP06022bZP80;Ri?00<08;:Z02h^C`0^;Tl05@0P/ZX00`0^;Tl0oooo0?ooo`1Q0?oo
o`00S03oool202h^C`808;:Z100^;Tl3022bZP0302h^C`0P/ZX08;:Z01808;:Z00<0;Ri?0?ooo`3o
ool0HP3oool008h0oooo100^;Tl0100P/ZX0;Ri?022bZP0P/ZX302h^Ca<08;:Z00<0;Ri?0?ooo`3o
ool0HP3oool00980oooo0P0^;Tl2022bZP<0;Ri?4P0P/ZX00`0^;Tl0oooo0?ooo`1S0?ooo`00U03o
ool602h^Ca008;:Z00<0;Ri?0?ooo`3oool0I03oool009L0oooo1@0^;Tl=022bZP0302h^C`3oool0
oooo06D0oooo002L0?ooo`80;Ri?2@0P/ZX402h^CfH0oooo002N0?ooo``0;Ri?I`3oool00:80oooo
100^;Tl00`0P/ZX0;Ri?02h^C`1X0?ooo`00X`3oool502h^CfT0oooo002V0?ooo`0302h^C`0P/ZX0
oooo06P0oooo003o0?oooa80oooo003o0?oooa80oooo003o0?oooa80oooo003o0?oooa80oooo003o
0?oooa80oooo003o0?oooa80oooo0000\
\>"],
  ImageRangeCache->{{{0, 272.875}, {286.938, 0}} -> {-0.854252, -0.998689, \
0.006961, 0.006961}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D examples", "Section"],

Cell[BoxData[{
    \(<< RealTime3D`\), "\[IndentingNewLine]", 
    \(<< Graphics`Polyhedra`\)}], "Input",
  CellLabel->"In[336]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sphere[{x_, y_}, r_] := 
      Polyhedron[Dodecahedron, {x, y, 0}, r]\), "\[IndentingNewLine]", 
    \(\(cir = 
        type[0, {0, 0}, {2, 0}, {1. , \@3}, 5];\)\), "\[IndentingNewLine]", 
    \(\(Show[\(sphere[First[#], Last[#]] &\) /@ cir];\)\)}], "Input",
  CellLabel->"In[342]:="],

Cell[BoxData[
  Graphics3D[{
    Polygon[{{1.303531, 0.797878, 0.491123},{0.884061, 0.934172, 0.491123},{
      0.624815, 0.577350, 0.491123},{0.884061, 0.220528, 0.491123},{
      1.303531, 0.356822, 0.491123}}],
    Polygon[{{1.303531, 0.797878, 0.491123},{1.303531, 0.356822, 0.491123},{
      1.491123, 0.220528, 0.115939},{1.607062, 0.577350, -0.115939},{
      1.491123, 0.934172, 0.115939}}],
    Polygon[{{1.303531, 0.797878, 0.491123},{1.491123, 0.934172, 0.115939},{
      1.187593, 1.154701, -0.115939},{0.812408, 1.154701, 0.115939},{
      0.884061, 0.934172, 0.491123}}],
    Polygon[{{0.884061, 0.934172, 0.491123},{0.812408, 1.154701, 0.115939},{
      0.508877, 0.934172, -0.115939},{0.392938, 0.577350, 0.115939},{
      0.624815, 0.577350, 0.491123}}],
    Polygon[{{0.624815, 0.577350, 0.491123},{0.392938, 0.577350, 0.115939},{
      0.508877, 0.220528, -0.115939},{0.812408, 0.000000, 0.115939},{
      0.884061, 0.220528, 0.491123}}],
    Polygon[{{0.884061, 0.220528, 0.491123},{1.303531, 0.356822, 0.491123},{
      1.491123, 0.220528, 0.115939},{1.187593, 0.000000, -0.115939},{
      0.812408, 0.000000, 0.115939}}],
    Polygon[{{1.491123, 0.934172, 0.115939},{1.607062, 0.577350, -0.115939},{
      1.375185, 0.577350, -0.491123},{1.115939, 0.934172, -0.491123},{
      1.187593, 1.154701, -0.115939}}],
    Polygon[{{0.812408, 1.154701, 0.115939},{1.187593, 1.154701, -0.115939},{
      1.115939, 0.934172, -0.491123},{0.696469, 0.797878, -0.491123},{
      0.508877, 0.934172, -0.115939}}],
    Polygon[{{0.392938, 0.577350, 0.115939},{0.508877, 0.934172, -0.115939},{
      0.696469, 0.797878, -0.491123},{0.696469, 0.356822, -0.491123},{
      0.508877, 0.220528, -0.115939}}],
    Polygon[{{0.812408, 0.000000, 0.115939},{0.508877, 0.220528, -0.115939},{
      0.696469, 0.356822, -0.491123},{1.115939, 0.220528, -0.491123},{
      1.187593, 0.000000, -0.115939}}],
    Polygon[{{1.491123, 0.220528, 0.115939},{1.187593, 0.000000, -0.115939},{
      1.115939, 0.220528, -0.491123},{1.375185, 0.577350, -0.491123},{
      1.607062, 0.577350, -0.115939}}],
    Polygon[{{1.115939, 0.934172, -0.491123},{1.375185, 0.577350, -0.491123},{
      1.115939, 0.220528, -0.491123},{0.696469, 0.356822, -0.491123},{
      0.696469, 0.797878, -0.491123}}],
    Polygon[{{0.434510, 0.265959, 0.163708},{0.294687, 0.311391, 0.163708},{
      0.208272, 0.192450, 0.163708},{0.294687, 0.073509, 0.163708},{
      0.434510, 0.118941, 0.163708}}],
    Polygon[{{0.434510, 0.265959, 0.163708},{0.434510, 0.118941, 0.163708},{
      0.497041, 0.073509, 0.038646},{0.535687, 0.192450, -0.038646},{
      0.497041, 0.311391, 0.038646}}],
    Polygon[{{0.434510, 0.265959, 0.163708},{0.497041, 0.311391, 0.038646},{
      0.395864, 0.384900, -0.038646},{0.270802, 0.384900, 0.038646},{
      0.294687, 0.311391, 0.163708}}],
    Polygon[{{0.294687, 0.311391, 0.163708},{0.270802, 0.384900, 0.038646},{
      0.169626, 0.311391, -0.038646},{0.130979, 0.192450, 0.038646},{
      0.208272, 0.192450, 0.163708}}],
    Polygon[{{0.208272, 0.192450, 0.163708},{0.130979, 0.192450, 0.038646},{
      0.169626, 0.073509, -0.038646},{0.270802, 0.000000, 0.038646},{
      0.294687, 0.073509, 0.163708}}],
    Polygon[{{0.294687, 0.073509, 0.163708},{0.434510, 0.118941, 0.163708},{
      0.497041, 0.073509, 0.038646},{0.395864, 0.000000, -0.038646},{
      0.270802, 0.000000, 0.038646}}],
    Polygon[{{0.497041, 0.311391, 0.038646},{0.535687, 0.192450, -0.038646},{
      0.458395, 0.192450, -0.163708},{0.371980, 0.311391, -0.163708},{
      0.395864, 0.384900, -0.038646}}],
    Polygon[{{0.270802, 0.384900, 0.038646},{0.395864, 0.384900, -0.038646},{
      0.371980, 0.311391, -0.163708},{0.232156, 0.265959, -0.163708},{
      0.169626, 0.311391, -0.038646}}],
    Polygon[{{0.130979, 0.192450, 0.038646},{0.169626, 0.311391, -0.038646},{
      0.232156, 0.265959, -0.163708},{0.232156, 0.118941, -0.163708},{
      0.169626, 0.073509, -0.038646}}],
    Polygon[{{0.270802, 0.000000, 0.038646},{0.169626, 0.073509, -0.038646},{
      0.232156, 0.118941, -0.163708},{0.371980, 0.073509, -0.163708},{
      0.395864, 0.000000, -0.038646}}],
    Polygon[{{0.497041, 0.073509, 0.038646},{0.395864, 0.000000, -0.038646},{
      0.371980, 0.073509, -0.163708},{0.458395, 0.192450, -0.163708},{
      0.535687, 0.192450, -0.038646}}],
    Polygon[{{0.371980, 0.311391, -0.163708},{0.458395, 0.192450, -0.163708},{
      0.371980, 0.073509, -0.163708},{0.232156, 0.118941, -0.163708},{
      0.232156, 0.265959, -0.163708}}],
    Polygon[{{0.144837, 0.088653, 0.054569},{0.098229, 0.103797, 0.054569},{
      0.069424, 0.064150, 0.054569},{0.098229, 0.024503, 0.054569},{
      0.144837, 0.039647, 0.054569}}],
    Polygon[{{0.144837, 0.088653, 0.054569},{0.144837, 0.039647, 0.054569},{
      0.165680, 0.024503, 0.012882},{0.178562, 0.064150, -0.012882},{
      0.165680, 0.103797, 0.012882}}],
    Polygon[{{0.144837, 0.088653, 0.054569},{0.165680, 0.103797, 0.012882},{
      0.131955, 0.128300, -0.012882},{0.090268, 0.128300, 0.012882},{
      0.098229, 0.103797, 0.054569}}],
    Polygon[{{0.098229, 0.103797, 0.054569},{0.090268, 0.128300, 0.012882},{
      0.056542, 0.103797, -0.012882},{0.043660, 0.064150, 0.012882},{
      0.069424, 0.064150, 0.054569}}],
    Polygon[{{0.069424, 0.064150, 0.054569},{0.043660, 0.064150, 0.012882},{
      0.056542, 0.024503, -0.012882},{0.090268, 0.000000, 0.012882},{
      0.098229, 0.024503, 0.054569}}],
    Polygon[{{0.098229, 0.024503, 0.054569},{0.144837, 0.039647, 0.054569},{
      0.165680, 0.024503, 0.012882},{0.131955, 0.000000, -0.012882},{
      0.090268, 0.000000, 0.012882}}],
    Polygon[{{0.165680, 0.103797, 0.012882},{0.178562, 0.064150, -0.012882},{
      0.152798, 0.064150, -0.054569},{0.123993, 0.103797, -0.054569},{
      0.131955, 0.128300, -0.012882}}],
    Polygon[{{0.090268, 0.128300, 0.012882},{0.131955, 0.128300, -0.012882},{
      0.123993, 0.103797, -0.054569},{0.077385, 0.088653, -0.054569},{
      0.056542, 0.103797, -0.012882}}],
    Polygon[{{0.043660, 0.064150, 0.012882},{0.056542, 0.103797, -0.012882},{
      0.077385, 0.088653, -0.054569},{0.077385, 0.039647, -0.054569},{
      0.056542, 0.024503, -0.012882}}],
    Polygon[{{0.090268, 0.000000, 0.012882},{0.056542, 0.024503, -0.012882},{
      0.077385, 0.039647, -0.054569},{0.123993, 0.024503, -0.054569},{
      0.131955, 0.000000, -0.012882}}],
    Polygon[{{0.165680, 0.024503, 0.012882},{0.131955, 0.000000, -0.012882},{
      0.123993, 0.024503, -0.054569},{0.152798, 0.064150, -0.054569},{
      0.178562, 0.064150, -0.012882}}],
    Polygon[{{0.123993, 0.103797, -0.054569},{0.152798, 0.064150, -0.054569},{
      0.123993, 0.024503, -0.054569},{0.077385, 0.039647, -0.054569},{
      0.077385, 0.088653, -0.054569}}],
    Polygon[{{0.048279, 0.029551, 0.018190},{0.032743, 0.034599, 0.018190},{
      0.023141, 0.021383, 0.018190},{0.032743, 0.008168, 0.018190},{
      0.048279, 0.013216, 0.018190}}],
    Polygon[{{0.048279, 0.029551, 0.018190},{0.048279, 0.013216, 0.018190},{
      0.055227, 0.008168, 0.004294},{0.059521, 0.021383, -0.004294},{
      0.055227, 0.034599, 0.004294}}],
    Polygon[{{0.048279, 0.029551, 0.018190},{0.055227, 0.034599, 0.004294},{
      0.043985, 0.042767, -0.004294},{0.030089, 0.042767, 0.004294},{
      0.032743, 0.034599, 0.018190}}],
    Polygon[{{0.032743, 0.034599, 0.018190},{0.030089, 0.042767, 0.004294},{
      0.018847, 0.034599, -0.004294},{0.014553, 0.021383, 0.004294},{
      0.023141, 0.021383, 0.018190}}],
    Polygon[{{0.023141, 0.021383, 0.018190},{0.014553, 0.021383, 0.004294},{
      0.018847, 0.008168, -0.004294},{0.030089, 0.000000, 0.004294},{
      0.032743, 0.008168, 0.018190}}],
    Polygon[{{0.032743, 0.008168, 0.018190},{0.048279, 0.013216, 0.018190},{
      0.055227, 0.008168, 0.004294},{0.043985, 0.000000, -0.004294},{
      0.030089, 0.000000, 0.004294}}],
    Polygon[{{0.055227, 0.034599, 0.004294},{0.059521, 0.021383, -0.004294},{
      0.050933, 0.021383, -0.018190},{0.041331, 0.034599, -0.018190},{
      0.043985, 0.042767, -0.004294}}],
    Polygon[{{0.030089, 0.042767, 0.004294},{0.043985, 0.042767, -0.004294},{
      0.041331, 0.034599, -0.018190},{0.025795, 0.029551, -0.018190},{
      0.018847, 0.034599, -0.004294}}],
    Polygon[{{0.014553, 0.021383, 0.004294},{0.018847, 0.034599, -0.004294},{
      0.025795, 0.029551, -0.018190},{0.025795, 0.013216, -0.018190},{
      0.018847, 0.008168, -0.004294}}],
    Polygon[{{0.030089, 0.000000, 0.004294},{0.018847, 0.008168, -0.004294},{
      0.025795, 0.013216, -0.018190},{0.041331, 0.008168, -0.018190},{
      0.043985, 0.000000, -0.004294}}],
    Polygon[{{0.055227, 0.008168, 0.004294},{0.043985, 0.000000, -0.004294},{
      0.041331, 0.008168, -0.018190},{0.050933, 0.021383, -0.018190},{
      0.059521, 0.021383, -0.004294}}],
    Polygon[{{0.041331, 0.034599, -0.018190},{0.050933, 0.021383, -0.018190},{
      0.041331, 0.008168, -0.018190},{0.025795, 0.013216, -0.018190},{
      0.025795, 0.029551, -0.018190}}],
    Polygon[{{0.016093, 0.009850, 0.006063},{0.010914, 0.011533, 0.006063},{
      0.007714, 0.007128, 0.006063},{0.010914, 0.002723, 0.006063},{
      0.016093, 0.004405, 0.006063}}],
    Polygon[{{0.016093, 0.009850, 0.006063},{0.016093, 0.004405, 0.006063},{
      0.018409, 0.002723, 0.001431},{0.019840, 0.007128, -0.001431},{
      0.018409, 0.011533, 0.001431}}],
    Polygon[{{0.016093, 0.009850, 0.006063},{0.018409, 0.011533, 0.001431},{
      0.014662, 0.014256, -0.001431},{0.010030, 0.014256, 0.001431},{
      0.010914, 0.011533, 0.006063}}],
    Polygon[{{0.010914, 0.011533, 0.006063},{0.010030, 0.014256, 0.001431},{
      0.006282, 0.011533, -0.001431},{0.004851, 0.007128, 0.001431},{
      0.007714, 0.007128, 0.006063}}],
    Polygon[{{0.007714, 0.007128, 0.006063},{0.004851, 0.007128, 0.001431},{
      0.006282, 0.002723, -0.001431},{0.010030, 0.000000, 0.001431},{
      0.010914, 0.002723, 0.006063}}],
    Polygon[{{0.010914, 0.002723, 0.006063},{0.016093, 0.004405, 0.006063},{
      0.018409, 0.002723, 0.001431},{0.014662, 0.000000, -0.001431},{
      0.010030, 0.000000, 0.001431}}],
    Polygon[{{0.018409, 0.011533, 0.001431},{0.019840, 0.007128, -0.001431},{
      0.016978, 0.007128, -0.006063},{0.013777, 0.011533, -0.006063},{
      0.014662, 0.014256, -0.001431}}],
    Polygon[{{0.010030, 0.014256, 0.001431},{0.014662, 0.014256, -0.001431},{
      0.013777, 0.011533, -0.006063},{0.008598, 0.009850, -0.006063},{
      0.006282, 0.011533, -0.001431}}],
    Polygon[{{0.004851, 0.007128, 0.001431},{0.006282, 0.011533, -0.001431},{
      0.008598, 0.009850, -0.006063},{0.008598, 0.004405, -0.006063},{
      0.006282, 0.002723, -0.001431}}],
    Polygon[{{0.010030, 0.000000, 0.001431},{0.006282, 0.002723, -0.001431},{
      0.008598, 0.004405, -0.006063},{0.013777, 0.002723, -0.006063},{
      0.014662, 0.000000, -0.001431}}],
    Polygon[{{0.018409, 0.002723, 0.001431},{0.014662, 0.000000, -0.001431},{
      0.013777, 0.002723, -0.006063},{0.016978, 0.007128, -0.006063},{
      0.019840, 0.007128, -0.001431}}],
    Polygon[{{0.013777, 0.011533, -0.006063},{0.016978, 0.007128, -0.006063},{
      0.013777, 0.002723, -0.006063},{0.008598, 0.004405, -0.006063},{
      0.008598, 0.009850, -0.006063}}],
    Polygon[{{0.068668, 0.011877, 0.007311},{0.062424, 0.013906, 0.007311},{
      0.058565, 0.008594, 0.007311},{0.062424, 0.003283, 0.007311},{
      0.068668, 0.005312, 0.007311}}],
    Polygon[{{0.068668, 0.011877, 0.007311},{0.068668, 0.005312, 0.007311},{
      0.071461, 0.003283, 0.001726},{0.073187, 0.008594, -0.001726},{
      0.071461, 0.013906, 0.001726}}],
    Polygon[{{0.068668, 0.011877, 0.007311},{0.071461, 0.013906, 0.001726},{
      0.066943, 0.017189, -0.001726},{0.061358, 0.017189, 0.001726},{
      0.062424, 0.013906, 0.007311}}],
    Polygon[{{0.062424, 0.013906, 0.007311},{0.061358, 0.017189, 0.001726},{
      0.056839, 0.013906, -0.001726},{0.055113, 0.008594, 0.001726},{
      0.058565, 0.008594, 0.007311}}],
    Polygon[{{0.058565, 0.008594, 0.007311},{0.055113, 0.008594, 0.001726},{
      0.056839, 0.003283, -0.001726},{0.061358, 0.000000, 0.001726},{
      0.062424, 0.003283, 0.007311}}],
    Polygon[{{0.062424, 0.003283, 0.007311},{0.068668, 0.005312, 0.007311},{
      0.071461, 0.003283, 0.001726},{0.066943, 0.000000, -0.001726},{
      0.061358, 0.000000, 0.001726}}],
    Polygon[{{0.071461, 0.013906, 0.001726},{0.073187, 0.008594, -0.001726},{
      0.069735, 0.008594, -0.007311},{0.065876, 0.013906, -0.007311},{
      0.066943, 0.017189, -0.001726}}],
    Polygon[{{0.061358, 0.017189, 0.001726},{0.066943, 0.017189, -0.001726},{
      0.065876, 0.013906, -0.007311},{0.059632, 0.011877, -0.007311},{
      0.056839, 0.013906, -0.001726}}],
    Polygon[{{0.055113, 0.008594, 0.001726},{0.056839, 0.013906, -0.001726},{
      0.059632, 0.011877, -0.007311},{0.059632, 0.005312, -0.007311},{
      0.056839, 0.003283, -0.001726}}],
    Polygon[{{0.061358, 0.000000, 0.001726},{0.056839, 0.003283, -0.001726},{
      0.059632, 0.005312, -0.007311},{0.065876, 0.003283, -0.007311},{
      0.066943, 0.000000, -0.001726}}],
    Polygon[{{0.071461, 0.003283, 0.001726},{0.066943, 0.000000, -0.001726},{
      0.065876, 0.003283, -0.007311},{0.069735, 0.008594, -0.007311},{
      0.073187, 0.008594, -0.001726}}],
    Polygon[{{0.065876, 0.013906, -0.007311},{0.069735, 0.008594, -0.007311},{
      0.065876, 0.003283, -0.007311},{0.059632, 0.005312, -0.007311},{
      0.059632, 0.011877, -0.007311}}],
    Polygon[{{0.044036, 0.054541, 0.007311},{0.037792, 0.056570, 0.007311},{
      0.033933, 0.051258, 0.007311},{0.037792, 0.045947, 0.007311},{
      0.044036, 0.047976, 0.007311}}],
    Polygon[{{0.044036, 0.054541, 0.007311},{0.044036, 0.047976, 0.007311},{
      0.046829, 0.045947, 0.001726},{0.048555, 0.051258, -0.001726},{
      0.046829, 0.056570, 0.001726}}],
    Polygon[{{0.044036, 0.054541, 0.007311},{0.046829, 0.056570, 0.001726},{
      0.042311, 0.059853, -0.001726},{0.036726, 0.059853, 0.001726},{
      0.037792, 0.056570, 0.007311}}],
    Polygon[{{0.037792, 0.056570, 0.007311},{0.036726, 0.059853, 0.001726},{
      0.032207, 0.056570, -0.001726},{0.030481, 0.051258, 0.001726},{
      0.033933, 0.051258, 0.007311}}],
    Polygon[{{0.033933, 0.051258, 0.007311},{0.030481, 0.051258, 0.001726},{
      0.032207, 0.045947, -0.001726},{0.036726, 0.042664, 0.001726},{
      0.037792, 0.045947, 0.007311}}],
    Polygon[{{0.037792, 0.045947, 0.007311},{0.044036, 0.047976, 0.007311},{
      0.046829, 0.045947, 0.001726},{0.042311, 0.042664, -0.001726},{
      0.036726, 0.042664, 0.001726}}],
    Polygon[{{0.046829, 0.056570, 0.001726},{0.048555, 0.051258, -0.001726},{
      0.045103, 0.051258, -0.007311},{0.041244, 0.056570, -0.007311},{
      0.042311, 0.059853, -0.001726}}],
    Polygon[{{0.036726, 0.059853, 0.001726},{0.042311, 0.059853, -0.001726},{
      0.041244, 0.056570, -0.007311},{0.035000, 0.054541, -0.007311},{
      0.032207, 0.056570, -0.001726}}],
    Polygon[{{0.030481, 0.051258, 0.001726},{0.032207, 0.056570, -0.001726},{
      0.035000, 0.054541, -0.007311},{0.035000, 0.047976, -0.007311},{
      0.032207, 0.045947, -0.001726}}],
    Polygon[{{0.036726, 0.042664, 0.001726},{0.032207, 0.045947, -0.001726},{
      0.035000, 0.047976, -0.007311},{0.041244, 0.045947, -0.007311},{
      0.042311, 0.042664, -0.001726}}],
    Polygon[{{0.046829, 0.045947, 0.001726},{0.042311, 0.042664, -0.001726},{
      0.041244, 0.045947, -0.007311},{0.045103, 0.051258, -0.007311},{
      0.048555, 0.051258, -0.001726}}],
    Polygon[{{0.041244, 0.056570, -0.007311},{0.045103, 0.051258, -0.007311},{
      0.041244, 0.045947, -0.007311},{0.035000, 0.047976, -0.007311},{
      0.035000, 0.054541, -0.007311}}],
    Polygon[{{0.206005, 0.035632, 0.021933},{0.187272, 0.041718, 0.021933},{
      0.175695, 0.025783, 0.021933},{0.187272, 0.009848, 0.021933},{
      0.206005, 0.015935, 0.021933}}],
    Polygon[{{0.206005, 0.035632, 0.021933},{0.206005, 0.015935, 0.021933},{
      0.214383, 0.009848, 0.005178},{0.219560, 0.025783, -0.005178},{
      0.214383, 0.041718, 0.005178}}],
    Polygon[{{0.206005, 0.035632, 0.021933},{0.214383, 0.041718, 0.005178},{
      0.200828, 0.051567, -0.005178},{0.184073, 0.051567, 0.005178},{
      0.187272, 0.041718, 0.021933}}],
    Polygon[{{0.187272, 0.041718, 0.021933},{0.184073, 0.051567, 0.005178},{
      0.170517, 0.041718, -0.005178},{0.165340, 0.025783, 0.005178},{
      0.175695, 0.025783, 0.021933}}],
    Polygon[{{0.175695, 0.025783, 0.021933},{0.165340, 0.025783, 0.005178},{
      0.170517, 0.009848, -0.005178},{0.184073, 0.000000, 0.005178},{
      0.187272, 0.009848, 0.021933}}],
    Polygon[{{0.187272, 0.009848, 0.021933},{0.206005, 0.015935, 0.021933},{
      0.214383, 0.009848, 0.005178},{0.200828, 0.000000, -0.005178},{
      0.184073, 0.000000, 0.005178}}],
    Polygon[{{0.214383, 0.041718, 0.005178},{0.219560, 0.025783, -0.005178},{
      0.209205, 0.025783, -0.021933},{0.197628, 0.041718, -0.021933},{
      0.200828, 0.051567, -0.005178}}],
    Polygon[{{0.184073, 0.051567, 0.005178},{0.200828, 0.051567, -0.005178},{
      0.197628, 0.041718, -0.021933},{0.178895, 0.035632, -0.021933},{
      0.170517, 0.041718, -0.005178}}],
    Polygon[{{0.165340, 0.025783, 0.005178},{0.170517, 0.041718, -0.005178},{
      0.178895, 0.035632, -0.021933},{0.178895, 0.015935, -0.021933},{
      0.170517, 0.009848, -0.005178}}],
    Polygon[{{0.184073, 0.000000, 0.005178},{0.170517, 0.009848, -0.005178},{
      0.178895, 0.015935, -0.021933},{0.197628, 0.009848, -0.021933},{
      0.200828, 0.000000, -0.005178}}],
    Polygon[{{0.214383, 0.009848, 0.005178},{0.200828, 0.000000, -0.005178},{
      0.197628, 0.009848, -0.021933},{0.209205, 0.025783, -0.021933},{
      0.219560, 0.025783, -0.005178}}],
    Polygon[{{0.197628, 0.041718, -0.021933},{0.209205, 0.025783, -0.021933},{
      0.197628, 0.009848, -0.021933},{0.178895, 0.015935, -0.021933},{
      0.178895, 0.035632, -0.021933}}],
    Polygon[{{0.237464, 0.019095, 0.011754},{0.227425, 0.022357, 0.011754},{
      0.221221, 0.013817, 0.011754},{0.227425, 0.005278, 0.011754},{
      0.237464, 0.008540, 0.011754}}],
    Polygon[{{0.237464, 0.019095, 0.011754},{0.237464, 0.008540, 0.011754},{
      0.241953, 0.005278, 0.002775},{0.244728, 0.013817, -0.002775},{
      0.241953, 0.022357, 0.002775}}],
    Polygon[{{0.237464, 0.019095, 0.011754},{0.241953, 0.022357, 0.002775},{
      0.234689, 0.027635, -0.002775},{0.225710, 0.027635, 0.002775},{
      0.227425, 0.022357, 0.011754}}],
    Polygon[{{0.227425, 0.022357, 0.011754},{0.225710, 0.027635, 0.002775},{
      0.218446, 0.022357, -0.002775},{0.215671, 0.013817, 0.002775},{
      0.221221, 0.013817, 0.011754}}],
    Polygon[{{0.221221, 0.013817, 0.011754},{0.215671, 0.013817, 0.002775},{
      0.218446, 0.005278, -0.002775},{0.225710, 0.000000, 0.002775},{
      0.227425, 0.005278, 0.011754}}],
    Polygon[{{0.227425, 0.005278, 0.011754},{0.237464, 0.008540, 0.011754},{
      0.241953, 0.005278, 0.002775},{0.234689, 0.000000, -0.002775},{
      0.225710, 0.000000, 0.002775}}],
    Polygon[{{0.241953, 0.022357, 0.002775},{0.244728, 0.013817, -0.002775},{
      0.239179, 0.013817, -0.011754},{0.232974, 0.022357, -0.011754},{
      0.234689, 0.027635, -0.002775}}],
    Polygon[{{0.225710, 0.027635, 0.002775},{0.234689, 0.027635, -0.002775},{
      0.232974, 0.022357, -0.011754},{0.222935, 0.019095, -0.011754},{
      0.218446, 0.022357, -0.002775}}],
    Polygon[{{0.215671, 0.013817, 0.002775},{0.218446, 0.022357, -0.002775},{
      0.222935, 0.019095, -0.011754},{0.222935, 0.008540, -0.011754},{
      0.218446, 0.005278, -0.002775}}],
    Polygon[{{0.225710, 0.000000, 0.002775},{0.218446, 0.005278, -0.002775},{
      0.222935, 0.008540, -0.011754},{0.232974, 0.005278, -0.011754},{
      0.234689, 0.000000, -0.002775}}],
    Polygon[{{0.241953, 0.005278, 0.002775},{0.234689, 0.000000, -0.002775},{
      0.232974, 0.005278, -0.011754},{0.239179, 0.013817, -0.011754},{
      0.244728, 0.013817, -0.002775}}],
    Polygon[{{0.232974, 0.022357, -0.011754},{0.239179, 0.013817, -0.011754},{
      0.232974, 0.005278, -0.011754},{0.222935, 0.008540, -0.011754},{
      0.222935, 0.019095, -0.011754}}],
    Polygon[{{0.165968, 0.013346, 0.008215},{0.158952, 0.015626, 0.008215},{
      0.154615, 0.009657, 0.008215},{0.158952, 0.003689, 0.008215},{
      0.165968, 0.005968, 0.008215}}],
    Polygon[{{0.165968, 0.013346, 0.008215},{0.165968, 0.005968, 0.008215},{
      0.169106, 0.003689, 0.001939},{0.171045, 0.009657, -0.001939},{
      0.169106, 0.015626, 0.001939}}],
    Polygon[{{0.165968, 0.013346, 0.008215},{0.169106, 0.015626, 0.001939},{
      0.164029, 0.019314, -0.001939},{0.157753, 0.019314, 0.001939},{
      0.158952, 0.015626, 0.008215}}],
    Polygon[{{0.158952, 0.015626, 0.008215},{0.157753, 0.019314, 0.001939},{
      0.152676, 0.015626, -0.001939},{0.150737, 0.009657, 0.001939},{
      0.154615, 0.009657, 0.008215}}],
    Polygon[{{0.154615, 0.009657, 0.008215},{0.150737, 0.009657, 0.001939},{
      0.152676, 0.003689, -0.001939},{0.157753, 0.000000, 0.001939},{
      0.158952, 0.003689, 0.008215}}],
    Polygon[{{0.158952, 0.003689, 0.008215},{0.165968, 0.005968, 0.008215},{
      0.169106, 0.003689, 0.001939},{0.164029, 0.000000, -0.001939},{
      0.157753, 0.000000, 0.001939}}],
    Polygon[{{0.169106, 0.015626, 0.001939},{0.171045, 0.009657, -0.001939},{
      0.167167, 0.009657, -0.008215},{0.162830, 0.015626, -0.008215},{
      0.164029, 0.019314, -0.001939}}],
    Polygon[{{0.157753, 0.019314, 0.001939},{0.164029, 0.019314, -0.001939},{
      0.162830, 0.015626, -0.008215},{0.155814, 0.013346, -0.008215},{
      0.152676, 0.015626, -0.001939}}],
    Polygon[{{0.150737, 0.009657, 0.001939},{0.152676, 0.015626, -0.001939},{
      0.155814, 0.013346, -0.008215},{0.155814, 0.005968, -0.008215},{
      0.152676, 0.003689, -0.001939}}],
    Polygon[{{0.157753, 0.000000, 0.001939},{0.152676, 0.003689, -0.001939},{
      0.155814, 0.005968, -0.008215},{0.162830, 0.003689, -0.008215},{
      0.164029, 0.000000, -0.001939}}],
    Polygon[{{0.169106, 0.003689, 0.001939},{0.164029, 0.000000, -0.001939},{
      0.162830, 0.003689, -0.008215},{0.167167, 0.009657, -0.008215},{
      0.171045, 0.009657, -0.001939}}],
    Polygon[{{0.162830, 0.015626, -0.008215},{0.167167, 0.009657, -0.008215},{
      0.162830, 0.003689, -0.008215},{0.155814, 0.005968, -0.008215},{
      0.155814, 0.013346, -0.008215}}],
    Polygon[{{0.187867, 0.061961, 0.007140},{0.181768, 0.063943, 0.007140},{
      0.177999, 0.058755, 0.007140},{0.181768, 0.053568, 0.007140},{
      0.187867, 0.055549, 0.007140}}],
    Polygon[{{0.187867, 0.061961, 0.007140},{0.187867, 0.055549, 0.007140},{
      0.190594, 0.053568, 0.001686},{0.192279, 0.058755, -0.001686},{
      0.190594, 0.063943, 0.001686}}],
    Polygon[{{0.187867, 0.061961, 0.007140},{0.190594, 0.063943, 0.001686},{
      0.186181, 0.067149, -0.001686},{0.180727, 0.067149, 0.001686},{
      0.181768, 0.063943, 0.007140}}],
    Polygon[{{0.181768, 0.063943, 0.007140},{0.180727, 0.067149, 0.001686},{
      0.176314, 0.063943, -0.001686},{0.174628, 0.058755, 0.001686},{
      0.177999, 0.058755, 0.007140}}],
    Polygon[{{0.177999, 0.058755, 0.007140},{0.174628, 0.058755, 0.001686},{
      0.176314, 0.053568, -0.001686},{0.180727, 0.050362, 0.001686},{
      0.181768, 0.053568, 0.007140}}],
    Polygon[{{0.181768, 0.053568, 0.007140},{0.187867, 0.055549, 0.007140},{
      0.190594, 0.053568, 0.001686},{0.186181, 0.050362, -0.001686},{
      0.180727, 0.050362, 0.001686}}],
    Polygon[{{0.190594, 0.063943, 0.001686},{0.192279, 0.058755, -0.001686},{
      0.188908, 0.058755, -0.007140},{0.185139, 0.063943, -0.007140},{
      0.186181, 0.067149, -0.001686}}],
    Polygon[{{0.180727, 0.067149, 0.001686},{0.186181, 0.067149, -0.001686},{
      0.185139, 0.063943, -0.007140},{0.179041, 0.061961, -0.007140},{
      0.176314, 0.063943, -0.001686}}],
    Polygon[{{0.174628, 0.058755, 0.001686},{0.176314, 0.063943, -0.001686},{
      0.179041, 0.061961, -0.007140},{0.179041, 0.055549, -0.007140},{
      0.176314, 0.053568, -0.001686}}],
    Polygon[{{0.180727, 0.050362, 0.001686},{0.176314, 0.053568, -0.001686},{
      0.179041, 0.055549, -0.007140},{0.185139, 0.053568, -0.007140},{
      0.186181, 0.050362, -0.001686}}],
    Polygon[{{0.190594, 0.053568, 0.001686},{0.186181, 0.050362, -0.001686},{
      0.185139, 0.053568, -0.007140},{0.188908, 0.058755, -0.007140},{
      0.192279, 0.058755, -0.001686}}],
    Polygon[{{0.185139, 0.063943, -0.007140},{0.188908, 0.058755, -0.007140},{
      0.185139, 0.053568, -0.007140},{0.179041, 0.055549, -0.007140},{
      0.179041, 0.061961, -0.007140}}],
    Polygon[{{0.132109, 0.163623, 0.021933},{0.113377, 0.169710, 0.021933},{
      0.101799, 0.153775, 0.021933},{0.113377, 0.137840, 0.021933},{
      0.132109, 0.143927, 0.021933}}],
    Polygon[{{0.132109, 0.163623, 0.021933},{0.132109, 0.143927, 0.021933},{
      0.140487, 0.137840, 0.005178},{0.145664, 0.153775, -0.005178},{
      0.140487, 0.169710, 0.005178}}],
    Polygon[{{0.132109, 0.163623, 0.021933},{0.140487, 0.169710, 0.005178},{
      0.126932, 0.179558, -0.005178},{0.110177, 0.179558, 0.005178},{
      0.113377, 0.169710, 0.021933}}],
    Polygon[{{0.113377, 0.169710, 0.021933},{0.110177, 0.179558, 0.005178},{
      0.096621, 0.169710, -0.005178},{0.091444, 0.153775, 0.005178},{
      0.101799, 0.153775, 0.021933}}],
    Polygon[{{0.101799, 0.153775, 0.021933},{0.091444, 0.153775, 0.005178},{
      0.096621, 0.137840, -0.005178},{0.110177, 0.127992, 0.005178},{
      0.113377, 0.137840, 0.021933}}],
    Polygon[{{0.113377, 0.137840, 0.021933},{0.132109, 0.143927, 0.021933},{
      0.140487, 0.137840, 0.005178},{0.126932, 0.127992, -0.005178},{
      0.110177, 0.127992, 0.005178}}],
    Polygon[{{0.140487, 0.169710, 0.005178},{0.145664, 0.153775, -0.005178},{
      0.135309, 0.153775, -0.021933},{0.123732, 0.169710, -0.021933},{
      0.126932, 0.179558, -0.005178}}],
    Polygon[{{0.110177, 0.179558, 0.005178},{0.126932, 0.179558, -0.005178},{
      0.123732, 0.169710, -0.021933},{0.104999, 0.163623, -0.021933},{
      0.096621, 0.169710, -0.005178}}],
    Polygon[{{0.091444, 0.153775, 0.005178},{0.096621, 0.169710, -0.005178},{
      0.104999, 0.163623, -0.021933},{0.104999, 0.143927, -0.021933},{
      0.096621, 0.137840, -0.005178}}],
    Polygon[{{0.110177, 0.127992, 0.005178},{0.096621, 0.137840, -0.005178},{
      0.104999, 0.143927, -0.021933},{0.123732, 0.137840, -0.021933},{
      0.126932, 0.127992, -0.005178}}],
    Polygon[{{0.140487, 0.137840, 0.005178},{0.126932, 0.127992, -0.005178},{
      0.123732, 0.137840, -0.021933},{0.135309, 0.153775, -0.021933},{
      0.145664, 0.153775, -0.005178}}],
    Polygon[{{0.123732, 0.169710, -0.021933},{0.135309, 0.153775, -0.021933},{
      0.123732, 0.137840, -0.021933},{0.104999, 0.143927, -0.021933},{
      0.104999, 0.163623, -0.021933}}],
    Polygon[{{0.134330, 0.197728, 0.011754},{0.124291, 0.200990, 0.011754},{
      0.118087, 0.192450, 0.011754},{0.124291, 0.183911, 0.011754},{
      0.134330, 0.187172, 0.011754}}],
    Polygon[{{0.134330, 0.197728, 0.011754},{0.134330, 0.187172, 0.011754},{
      0.138820, 0.183911, 0.002775},{0.141594, 0.192450, -0.002775},{
      0.138820, 0.200990, 0.002775}}],
    Polygon[{{0.134330, 0.197728, 0.011754},{0.138820, 0.200990, 0.002775},{
      0.131555, 0.206267, -0.002775},{0.122576, 0.206267, 0.002775},{
      0.124291, 0.200990, 0.011754}}],
    Polygon[{{0.124291, 0.200990, 0.011754},{0.122576, 0.206267, 0.002775},{
      0.115312, 0.200990, -0.002775},{0.112538, 0.192450, 0.002775},{
      0.118087, 0.192450, 0.011754}}],
    Polygon[{{0.118087, 0.192450, 0.011754},{0.112538, 0.192450, 0.002775},{
      0.115312, 0.183911, -0.002775},{0.122576, 0.178633, 0.002775},{
      0.124291, 0.183911, 0.011754}}],
    Polygon[{{0.124291, 0.183911, 0.011754},{0.134330, 0.187172, 0.011754},{
      0.138820, 0.183911, 0.002775},{0.131555, 0.178633, -0.002775},{
      0.122576, 0.178633, 0.002775}}],
    Polygon[{{0.138820, 0.200990, 0.002775},{0.141594, 0.192450, -0.002775},{
      0.136045, 0.192450, -0.011754},{0.129841, 0.200990, -0.011754},{
      0.131555, 0.206267, -0.002775}}],
    Polygon[{{0.122576, 0.206267, 0.002775},{0.131555, 0.206267, -0.002775},{
      0.129841, 0.200990, -0.011754},{0.119802, 0.197728, -0.011754},{
      0.115312, 0.200990, -0.002775}}],
    Polygon[{{0.112538, 0.192450, 0.002775},{0.115312, 0.200990, -0.002775},{
      0.119802, 0.197728, -0.011754},{0.119802, 0.187172, -0.011754},{
      0.115312, 0.183911, -0.002775}}],
    Polygon[{{0.122576, 0.178633, 0.002775},{0.115312, 0.183911, -0.002775},{
      0.119802, 0.187172, -0.011754},{0.129841, 0.183911, -0.011754},{
      0.131555, 0.178633, -0.002775}}],
    Polygon[{{0.138820, 0.183911, 0.002775},{0.131555, 0.178633, -0.002775},{
      0.129841, 0.183911, -0.011754},{0.136045, 0.192450, -0.011754},{
      0.141594, 0.192450, -0.002775}}],
    Polygon[{{0.129841, 0.200990, -0.011754},{0.136045, 0.192450, -0.011754},{
      0.129841, 0.183911, -0.011754},{0.119802, 0.187172, -0.011754},{
      0.119802, 0.197728, -0.011754}}],
    Polygon[{{0.093886, 0.138196, 0.008215},{0.086870, 0.140476, 0.008215},{
      0.082533, 0.134507, 0.008215},{0.086870, 0.128539, 0.008215},{
      0.093886, 0.130818, 0.008215}}],
    Polygon[{{0.093886, 0.138196, 0.008215},{0.093886, 0.130818, 0.008215},{
      0.097024, 0.128539, 0.001939},{0.098963, 0.134507, -0.001939},{
      0.097024, 0.140476, 0.001939}}],
    Polygon[{{0.093886, 0.138196, 0.008215},{0.097024, 0.140476, 0.001939},{
      0.091947, 0.144164, -0.001939},{0.085671, 0.144164, 0.001939},{
      0.086870, 0.140476, 0.008215}}],
    Polygon[{{0.086870, 0.140476, 0.008215},{0.085671, 0.144164, 0.001939},{
      0.080594, 0.140476, -0.001939},{0.078655, 0.134507, 0.001939},{
      0.082533, 0.134507, 0.008215}}],
    Polygon[{{0.082533, 0.134507, 0.008215},{0.078655, 0.134507, 0.001939},{
      0.080594, 0.128539, -0.001939},{0.085671, 0.124850, 0.001939},{
      0.086870, 0.128539, 0.008215}}],
    Polygon[{{0.086870, 0.128539, 0.008215},{0.093886, 0.130818, 0.008215},{
      0.097024, 0.128539, 0.001939},{0.091947, 0.124850, -0.001939},{
      0.085671, 0.124850, 0.001939}}],
    Polygon[{{0.097024, 0.140476, 0.001939},{0.098963, 0.134507, -0.001939},{
      0.095084, 0.134507, -0.008215},{0.090748, 0.140476, -0.008215},{
      0.091947, 0.144164, -0.001939}}],
    Polygon[{{0.085671, 0.144164, 0.001939},{0.091947, 0.144164, -0.001939},{
      0.090748, 0.140476, -0.008215},{0.083732, 0.138196, -0.008215},{
      0.080594, 0.140476, -0.001939}}],
    Polygon[{{0.078655, 0.134507, 0.001939},{0.080594, 0.140476, -0.001939},{
      0.083732, 0.138196, -0.008215},{0.083732, 0.130818, -0.008215},{
      0.080594, 0.128539, -0.001939}}],
    Polygon[{{0.085671, 0.124850, 0.001939},{0.080594, 0.128539, -0.001939},{
      0.083732, 0.130818, -0.008215},{0.090748, 0.128539, -0.008215},{
      0.091947, 0.124850, -0.001939}}],
    Polygon[{{0.097024, 0.128539, 0.001939},{0.091947, 0.124850, -0.001939},{
      0.090748, 0.128539, -0.008215},{0.095084, 0.134507, -0.008215},{
      0.098963, 0.134507, -0.001939}}],
    Polygon[{{0.090748, 0.140476, -0.008215},{0.095084, 0.134507, -0.008215},{
      0.090748, 0.128539, -0.008215},{0.083732, 0.130818, -0.008215},{
      0.083732, 0.138196, -0.008215}}],
    Polygon[{{0.147023, 0.132704, 0.007140},{0.140925, 0.134686, 0.007140},{
      0.137156, 0.129498, 0.007140},{0.140925, 0.124311, 0.007140},{
      0.147023, 0.126292, 0.007140}}],
    Polygon[{{0.147023, 0.132704, 0.007140},{0.147023, 0.126292, 0.007140},{
      0.149750, 0.124311, 0.001686},{0.151436, 0.129498, -0.001686},{
      0.149750, 0.134686, 0.001686}}],
    Polygon[{{0.147023, 0.132704, 0.007140},{0.149750, 0.134686, 0.001686},{
      0.145338, 0.137892, -0.001686},{0.139883, 0.137892, 0.001686},{
      0.140925, 0.134686, 0.007140}}],
    Polygon[{{0.140925, 0.134686, 0.007140},{0.139883, 0.137892, 0.001686},{
      0.135470, 0.134686, -0.001686},{0.133785, 0.129498, 0.001686},{
      0.137156, 0.129498, 0.007140}}],
    Polygon[{{0.137156, 0.129498, 0.007140},{0.133785, 0.129498, 0.001686},{
      0.135470, 0.124311, -0.001686},{0.139883, 0.121105, 0.001686},{
      0.140925, 0.124311, 0.007140}}],
    Polygon[{{0.140925, 0.124311, 0.007140},{0.147023, 0.126292, 0.007140},{
      0.149750, 0.124311, 0.001686},{0.145338, 0.121105, -0.001686},{
      0.139883, 0.121105, 0.001686}}],
    Polygon[{{0.149750, 0.134686, 0.001686},{0.151436, 0.129498, -0.001686},{
      0.148065, 0.129498, -0.007140},{0.144296, 0.134686, -0.007140},{
      0.145338, 0.137892, -0.001686}}],
    Polygon[{{0.139883, 0.137892, 0.001686},{0.145338, 0.137892, -0.001686},{
      0.144296, 0.134686, -0.007140},{0.138198, 0.132704, -0.007140},{
      0.135470, 0.134686, -0.001686}}],
    Polygon[{{0.133785, 0.129498, 0.001686},{0.135470, 0.134686, -0.001686},{
      0.138198, 0.132704, -0.007140},{0.138198, 0.126292, -0.007140},{
      0.135470, 0.124311, -0.001686}}],
    Polygon[{{0.139883, 0.121105, 0.001686},{0.135470, 0.124311, -0.001686},{
      0.138198, 0.126292, -0.007140},{0.144296, 0.124311, -0.007140},{
      0.145338, 0.121105, -0.001686}}],
    Polygon[{{0.149750, 0.124311, 0.001686},{0.145338, 0.121105, -0.001686},{
      0.144296, 0.124311, -0.007140},{0.148065, 0.129498, -0.007140},{
      0.151436, 0.129498, -0.001686}}],
    Polygon[{{0.144296, 0.134686, -0.007140},{0.148065, 0.129498, -0.007140},{
      0.144296, 0.124311, -0.007140},{0.138198, 0.126292, -0.007140},{
      0.138198, 0.132704, -0.007140}}],
    Polygon[{{0.618016, 0.106895, 0.065798},{0.561817, 0.125155, 0.065798},{
      0.527085, 0.077350, 0.065798},{0.561817, 0.029545, 0.065798},{
      0.618016, 0.047805, 0.065798}}],
    Polygon[{{0.618016, 0.106895, 0.065798},{0.618016, 0.047805, 0.065798},{
      0.643148, 0.029545, 0.015533},{0.658681, 0.077350, -0.015533},{
      0.643148, 0.125155, 0.015533}}],
    Polygon[{{0.618016, 0.106895, 0.065798},{0.643148, 0.125155, 0.015533},{
      0.602483, 0.154701, -0.015533},{0.552218, 0.154701, 0.015533},{
      0.561817, 0.125155, 0.065798}}],
    Polygon[{{0.561817, 0.125155, 0.065798},{0.552218, 0.154701, 0.015533},{
      0.511552, 0.125155, -0.015533},{0.496019, 0.077350, 0.015533},{
      0.527085, 0.077350, 0.065798}}],
    Polygon[{{0.527085, 0.077350, 0.065798},{0.496019, 0.077350, 0.015533},{
      0.511552, 0.029545, -0.015533},{0.552218, 0.000000, 0.015533},{
      0.561817, 0.029545, 0.065798}}],
    Polygon[{{0.561817, 0.029545, 0.065798},{0.618016, 0.047805, 0.065798},{
      0.643148, 0.029545, 0.015533},{0.602483, 0.000000, -0.015533},{
      0.552218, 0.000000, 0.015533}}],
    Polygon[{{0.643148, 0.125155, 0.015533},{0.658681, 0.077350, -0.015533},{
      0.627616, 0.077350, -0.065798},{0.592883, 0.125155, -0.065798},{
      0.602483, 0.154701, -0.015533}}],
    Polygon[{{0.552218, 0.154701, 0.015533},{0.602483, 0.154701, -0.015533},{
      0.592883, 0.125155, -0.065798},{0.536685, 0.106895, -0.065798},{
      0.511552, 0.125155, -0.015533}}],
    Polygon[{{0.496019, 0.077350, 0.015533},{0.511552, 0.125155, -0.015533},{
      0.536685, 0.106895, -0.065798},{0.536685, 0.047805, -0.065798},{
      0.511552, 0.029545, -0.015533}}],
    Polygon[{{0.552218, 0.000000, 0.015533},{0.511552, 0.029545, -0.015533},{
      0.536685, 0.047805, -0.065798},{0.592883, 0.029545, -0.065798},{
      0.602483, 0.000000, -0.015533}}],
    Polygon[{{0.643148, 0.029545, 0.015533},{0.602483, 0.000000, -0.015533},{
      0.592883, 0.029545, -0.065798},{0.627616, 0.077350, -0.065798},{
      0.658681, 0.077350, -0.015533}}],
    Polygon[{{0.592883, 0.125155, -0.065798},{0.627616, 0.077350, -0.065798},{
      0.592883, 0.029545, -0.065798},{0.536685, 0.047805, -0.065798},{
      0.536685, 0.106895, -0.065798}}],
    Polygon[{{0.712391, 0.057285, 0.035261},{0.682275, 0.067071, 0.035261},{
      0.663662, 0.041452, 0.035261},{0.682275, 0.015833, 0.035261},{
      0.712391, 0.025619, 0.035261}}],
    Polygon[{{0.712391, 0.057285, 0.035261},{0.712391, 0.025619, 0.035261},{
      0.725860, 0.015833, 0.008324},{0.734184, 0.041452, -0.008324},{
      0.725860, 0.067071, 0.008324}}],
    Polygon[{{0.712391, 0.057285, 0.035261},{0.725860, 0.067071, 0.008324},{
      0.704067, 0.082904, -0.008324},{0.677130, 0.082904, 0.008324},{
      0.682275, 0.067071, 0.035261}}],
    Polygon[{{0.682275, 0.067071, 0.035261},{0.677130, 0.082904, 0.008324},{
      0.655338, 0.067071, -0.008324},{0.647014, 0.041452, 0.008324},{
      0.663662, 0.041452, 0.035261}}],
    Polygon[{{0.663662, 0.041452, 0.035261},{0.647014, 0.041452, 0.008324},{
      0.655338, 0.015833, -0.008324},{0.677130, 0.000000, 0.008324},{
      0.682275, 0.015833, 0.035261}}],
    Polygon[{{0.682275, 0.015833, 0.035261},{0.712391, 0.025619, 0.035261},{
      0.725860, 0.015833, 0.008324},{0.704067, 0.000000, -0.008324},{
      0.677130, 0.000000, 0.008324}}],
    Polygon[{{0.725860, 0.067071, 0.008324},{0.734184, 0.041452, -0.008324},{
      0.717536, 0.041452, -0.035261},{0.698923, 0.067071, -0.035261},{
      0.704067, 0.082904, -0.008324}}],
    Polygon[{{0.677130, 0.082904, 0.008324},{0.704067, 0.082904, -0.008324},{
      0.698923, 0.067071, -0.035261},{0.668806, 0.057285, -0.035261},{
      0.655338, 0.067071, -0.008324}}],
    Polygon[{{0.647014, 0.041452, 0.008324},{0.655338, 0.067071, -0.008324},{
      0.668806, 0.057285, -0.035261},{0.668806, 0.025619, -0.035261},{
      0.655338, 0.015833, -0.008324}}],
    Polygon[{{0.677130, 0.000000, 0.008324},{0.655338, 0.015833, -0.008324},{
      0.668806, 0.025619, -0.035261},{0.698923, 0.015833, -0.035261},{
      0.704067, 0.000000, -0.008324}}],
    Polygon[{{0.725860, 0.015833, 0.008324},{0.704067, 0.000000, -0.008324},{
      0.698923, 0.015833, -0.035261},{0.717536, 0.041452, -0.035261},{
      0.734184, 0.041452, -0.008324}}],
    Polygon[{{0.698923, 0.067071, -0.035261},{0.717536, 0.041452, -0.035261},{
      0.698923, 0.015833, -0.035261},{0.668806, 0.025619, -0.035261},{
      0.668806, 0.057285, -0.035261}}],
    Polygon[{{0.769538, 0.035632, 0.021933},{0.750805, 0.041718, 0.021933},{
      0.739228, 0.025783, 0.021933},{0.750805, 0.009848, 0.021933},{
      0.769538, 0.015935, 0.021933}}],
    Polygon[{{0.769538, 0.035632, 0.021933},{0.769538, 0.015935, 0.021933},{
      0.777916, 0.009848, 0.005178},{0.783093, 0.025783, -0.005178},{
      0.777916, 0.041718, 0.005178}}],
    Polygon[{{0.769538, 0.035632, 0.021933},{0.777916, 0.041718, 0.005178},{
      0.764361, 0.051567, -0.005178},{0.747606, 0.051567, 0.005178},{
      0.750805, 0.041718, 0.021933}}],
    Polygon[{{0.750805, 0.041718, 0.021933},{0.747606, 0.051567, 0.005178},{
      0.734050, 0.041718, -0.005178},{0.728873, 0.025783, 0.005178},{
      0.739228, 0.025783, 0.021933}}],
    Polygon[{{0.739228, 0.025783, 0.021933},{0.728873, 0.025783, 0.005178},{
      0.734050, 0.009848, -0.005178},{0.747606, 0.000000, 0.005178},{
      0.750805, 0.009848, 0.021933}}],
    Polygon[{{0.750805, 0.009848, 0.021933},{0.769538, 0.015935, 0.021933},{
      0.777916, 0.009848, 0.005178},{0.764361, 0.000000, -0.005178},{
      0.747606, 0.000000, 0.005178}}],
    Polygon[{{0.777916, 0.041718, 0.005178},{0.783093, 0.025783, -0.005178},{
      0.772738, 0.025783, -0.021933},{0.761161, 0.041718, -0.021933},{
      0.764361, 0.051567, -0.005178}}],
    Polygon[{{0.747606, 0.051567, 0.005178},{0.764361, 0.051567, -0.005178},{
      0.761161, 0.041718, -0.021933},{0.742428, 0.035632, -0.021933},{
      0.734050, 0.041718, -0.005178}}],
    Polygon[{{0.728873, 0.025783, 0.005178},{0.734050, 0.041718, -0.005178},{
      0.742428, 0.035632, -0.021933},{0.742428, 0.015935, -0.021933},{
      0.734050, 0.009848, -0.005178}}],
    Polygon[{{0.747606, 0.000000, 0.005178},{0.734050, 0.009848, -0.005178},{
      0.742428, 0.015935, -0.021933},{0.761161, 0.009848, -0.021933},{
      0.764361, 0.000000, -0.005178}}],
    Polygon[{{0.777916, 0.009848, 0.005178},{0.764361, 0.000000, -0.005178},{
      0.761161, 0.009848, -0.021933},{0.772738, 0.025783, -0.021933},{
      0.783093, 0.025783, -0.005178}}],
    Polygon[{{0.761161, 0.041718, -0.021933},{0.772738, 0.025783, -0.021933},{
      0.761161, 0.009848, -0.021933},{0.742428, 0.015935, -0.021933},{
      0.742428, 0.035632, -0.021933}}],
    Polygon[{{0.649999, 0.019095, 0.011754},{0.639960, 0.022357, 0.011754},{
      0.633755, 0.013817, 0.011754},{0.639960, 0.005278, 0.011754},{
      0.649999, 0.008540, 0.011754}}],
    Polygon[{{0.649999, 0.019095, 0.011754},{0.649999, 0.008540, 0.011754},{
      0.654488, 0.005278, 0.002775},{0.657263, 0.013817, -0.002775},{
      0.654488, 0.022357, 0.002775}}],
    Polygon[{{0.649999, 0.019095, 0.011754},{0.654488, 0.022357, 0.002775},{
      0.647224, 0.027635, -0.002775},{0.638245, 0.027635, 0.002775},{
      0.639960, 0.022357, 0.011754}}],
    Polygon[{{0.639960, 0.022357, 0.011754},{0.638245, 0.027635, 0.002775},{
      0.630981, 0.022357, -0.002775},{0.628206, 0.013817, 0.002775},{
      0.633755, 0.013817, 0.011754}}],
    Polygon[{{0.633755, 0.013817, 0.011754},{0.628206, 0.013817, 0.002775},{
      0.630981, 0.005278, -0.002775},{0.638245, 0.000000, 0.002775},{
      0.639960, 0.005278, 0.011754}}],
    Polygon[{{0.639960, 0.005278, 0.011754},{0.649999, 0.008540, 0.011754},{
      0.654488, 0.005278, 0.002775},{0.647224, 0.000000, -0.002775},{
      0.638245, 0.000000, 0.002775}}],
    Polygon[{{0.654488, 0.022357, 0.002775},{0.657263, 0.013817, -0.002775},{
      0.651713, 0.013817, -0.011754},{0.645509, 0.022357, -0.011754},{
      0.647224, 0.027635, -0.002775}}],
    Polygon[{{0.638245, 0.027635, 0.002775},{0.647224, 0.027635, -0.002775},{
      0.645509, 0.022357, -0.011754},{0.635470, 0.019095, -0.011754},{
      0.630981, 0.022357, -0.002775}}],
    Polygon[{{0.628206, 0.013817, 0.002775},{0.630981, 0.022357, -0.002775},{
      0.635470, 0.019095, -0.011754},{0.635470, 0.008540, -0.011754},{
      0.630981, 0.005278, -0.002775}}],
    Polygon[{{0.638245, 0.000000, 0.002775},{0.630981, 0.005278, -0.002775},{
      0.635470, 0.008540, -0.011754},{0.645509, 0.005278, -0.011754},{
      0.647224, 0.000000, -0.002775}}],
    Polygon[{{0.654488, 0.005278, 0.002775},{0.647224, 0.000000, -0.002775},{
      0.645509, 0.005278, -0.011754},{0.651713, 0.013817, -0.011754},{
      0.657263, 0.013817, -0.002775}}],
    Polygon[{{0.645509, 0.022357, -0.011754},{0.651713, 0.013817, -0.011754},{
      0.645509, 0.005278, -0.011754},{0.635470, 0.008540, -0.011754},{
      0.635470, 0.019095, -0.011754}}],
    Polygon[{{0.673444, 0.095166, 0.010966},{0.664078, 0.098210, 0.010966},{
      0.658289, 0.090242, 0.010966},{0.664078, 0.082274, 0.010966},{
      0.673444, 0.085318, 0.010966}}],
    Polygon[{{0.673444, 0.095166, 0.010966},{0.673444, 0.085318, 0.010966},{
      0.677633, 0.082274, 0.002589},{0.680222, 0.090242, -0.002589},{
      0.677633, 0.098210, 0.002589}}],
    Polygon[{{0.673444, 0.095166, 0.010966},{0.677633, 0.098210, 0.002589},{
      0.670855, 0.103134, -0.002589},{0.662478, 0.103134, 0.002589},{
      0.664078, 0.098210, 0.010966}}],
    Polygon[{{0.664078, 0.098210, 0.010966},{0.662478, 0.103134, 0.002589},{
      0.655700, 0.098210, -0.002589},{0.653112, 0.090242, 0.002589},{
      0.658289, 0.090242, 0.010966}}],
    Polygon[{{0.658289, 0.090242, 0.010966},{0.653112, 0.090242, 0.002589},{
      0.655700, 0.082274, -0.002589},{0.662478, 0.077350, 0.002589},{
      0.664078, 0.082274, 0.010966}}],
    Polygon[{{0.664078, 0.082274, 0.010966},{0.673444, 0.085318, 0.010966},{
      0.677633, 0.082274, 0.002589},{0.670855, 0.077350, -0.002589},{
      0.662478, 0.077350, 0.002589}}],
    Polygon[{{0.677633, 0.098210, 0.002589},{0.680222, 0.090242, -0.002589},{
      0.675044, 0.090242, -0.010966},{0.669255, 0.098210, -0.010966},{
      0.670855, 0.103134, -0.002589}}],
    Polygon[{{0.662478, 0.103134, 0.002589},{0.670855, 0.103134, -0.002589},{
      0.669255, 0.098210, -0.010966},{0.659889, 0.095166, -0.010966},{
      0.655700, 0.098210, -0.002589}}],
    Polygon[{{0.653112, 0.090242, 0.002589},{0.655700, 0.098210, -0.002589},{
      0.659889, 0.095166, -0.010966},{0.659889, 0.085318, -0.010966},{
      0.655700, 0.082274, -0.002589}}],
    Polygon[{{0.662478, 0.077350, 0.002589},{0.655700, 0.082274, -0.002589},{
      0.659889, 0.085318, -0.010966},{0.669255, 0.082274, -0.010966},{
      0.670855, 0.077350, -0.002589}}],
    Polygon[{{0.677633, 0.082274, 0.002589},{0.670855, 0.077350, -0.002589},{
      0.669255, 0.082274, -0.010966},{0.675044, 0.090242, -0.010966},{
      0.680222, 0.090242, -0.002589}}],
    Polygon[{{0.669255, 0.098210, -0.010966},{0.675044, 0.090242, -0.010966},{
      0.669255, 0.082274, -0.010966},{0.659889, 0.085318, -0.010966},{
      0.659889, 0.095166, -0.010966}}],
    Polygon[{{0.497904, 0.040038, 0.024645},{0.476855, 0.046877, 0.024645},{
      0.463846, 0.028972, 0.024645},{0.476855, 0.011066, 0.024645},{
      0.497904, 0.017905, 0.024645}}],
    Polygon[{{0.497904, 0.040038, 0.024645},{0.497904, 0.017905, 0.024645},{
      0.507317, 0.011066, 0.005818},{0.513135, 0.028972, -0.005818},{
      0.507317, 0.046877, 0.005818}}],
    Polygon[{{0.497904, 0.040038, 0.024645},{0.507317, 0.046877, 0.005818},{
      0.492086, 0.057943, -0.005818},{0.473259, 0.057943, 0.005818},{
      0.476855, 0.046877, 0.024645}}],
    Polygon[{{0.476855, 0.046877, 0.024645},{0.473259, 0.057943, 0.005818},{
      0.458028, 0.046877, -0.005818},{0.452210, 0.028972, 0.005818},{
      0.463846, 0.028972, 0.024645}}],
    Polygon[{{0.463846, 0.028972, 0.024645},{0.452210, 0.028972, 0.005818},{
      0.458028, 0.011066, -0.005818},{0.473259, 0.000000, 0.005818},{
      0.476855, 0.011066, 0.024645}}],
    Polygon[{{0.476855, 0.011066, 0.024645},{0.497904, 0.017905, 0.024645},{
      0.507317, 0.011066, 0.005818},{0.492086, 0.000000, -0.005818},{
      0.473259, 0.000000, 0.005818}}],
    Polygon[{{0.507317, 0.046877, 0.005818},{0.513135, 0.028972, -0.005818},{
      0.501500, 0.028972, -0.024645},{0.488491, 0.046877, -0.024645},{
      0.492086, 0.057943, -0.005818}}],
    Polygon[{{0.473259, 0.057943, 0.005818},{0.492086, 0.057943, -0.005818},{
      0.488491, 0.046877, -0.024645},{0.467442, 0.040038, -0.024645},{
      0.458028, 0.046877, -0.005818}}],
    Polygon[{{0.452210, 0.028972, 0.005818},{0.458028, 0.046877, -0.005818},{
      0.467442, 0.040038, -0.024645},{0.467442, 0.017905, -0.024645},{
      0.458028, 0.011066, -0.005818}}],
    Polygon[{{0.473259, 0.000000, 0.005818},{0.458028, 0.011066, -0.005818},{
      0.467442, 0.017905, -0.024645},{0.488491, 0.011066, -0.024645},{
      0.492086, 0.000000, -0.005818}}],
    Polygon[{{0.507317, 0.011066, 0.005818},{0.492086, 0.000000, -0.005818},{
      0.488491, 0.011066, -0.024645},{0.501500, 0.028972, -0.024645},{
      0.513135, 0.028972, -0.005818}}],
    Polygon[{{0.488491, 0.046877, -0.024645},{0.501500, 0.028972, -0.024645},{
      0.488491, 0.011066, -0.024645},{0.467442, 0.017905, -0.024645},{
      0.467442, 0.040038, -0.024645}}],
    Polygon[{{0.448833, 0.020782, 0.012792},{0.437907, 0.024332, 0.012792},{
      0.431155, 0.015038, 0.012792},{0.437907, 0.005744, 0.012792},{
      0.448833, 0.009294, 0.012792}}],
    Polygon[{{0.448833, 0.020782, 0.012792},{0.448833, 0.009294, 0.012792},{
      0.453719, 0.005744, 0.003020},{0.456739, 0.015038, -0.003020},{
      0.453719, 0.024332, 0.003020}}],
    Polygon[{{0.448833, 0.020782, 0.012792},{0.453719, 0.024332, 0.003020},{
      0.445813, 0.030076, -0.003020},{0.436041, 0.030076, 0.003020},{
      0.437907, 0.024332, 0.012792}}],
    Polygon[{{0.437907, 0.024332, 0.012792},{0.436041, 0.030076, 0.003020},{
      0.428135, 0.024332, -0.003020},{0.425115, 0.015038, 0.003020},{
      0.431155, 0.015038, 0.012792}}],
    Polygon[{{0.431155, 0.015038, 0.012792},{0.425115, 0.015038, 0.003020},{
      0.428135, 0.005744, -0.003020},{0.436041, 0.000000, 0.003020},{
      0.437907, 0.005744, 0.012792}}],
    Polygon[{{0.437907, 0.005744, 0.012792},{0.448833, 0.009294, 0.012792},{
      0.453719, 0.005744, 0.003020},{0.445813, 0.000000, -0.003020},{
      0.436041, 0.000000, 0.003020}}],
    Polygon[{{0.453719, 0.024332, 0.003020},{0.456739, 0.015038, -0.003020},{
      0.450699, 0.015038, -0.012792},{0.443947, 0.024332, -0.012792},{
      0.445813, 0.030076, -0.003020}}],
    Polygon[{{0.436041, 0.030076, 0.003020},{0.445813, 0.030076, -0.003020},{
      0.443947, 0.024332, -0.012792},{0.433021, 0.020782, -0.012792},{
      0.428135, 0.024332, -0.003020}}],
    Polygon[{{0.425115, 0.015038, 0.003020},{0.428135, 0.024332, -0.003020},{
      0.433021, 0.020782, -0.012792},{0.433021, 0.009294, -0.012792},{
      0.428135, 0.005744, -0.003020}}],
    Polygon[{{0.436041, 0.000000, 0.003020},{0.428135, 0.005744, -0.003020},{
      0.433021, 0.009294, -0.012792},{0.443947, 0.005744, -0.012792},{
      0.445813, 0.000000, -0.003020}}],
    Polygon[{{0.453719, 0.005744, 0.003020},{0.445813, 0.000000, -0.003020},{
      0.443947, 0.005744, -0.012792},{0.450699, 0.015038, -0.012792},{
      0.456739, 0.015038, -0.003020}}],
    Polygon[{{0.443947, 0.024332, -0.012792},{0.450699, 0.015038, -0.012792},{
      0.443947, 0.005744, -0.012792},{0.433021, 0.009294, -0.012792},{
      0.433021, 0.020782, -0.012792}}],
    Polygon[{{0.524479, 0.015408, 0.009484},{0.516379, 0.018040, 0.009484},{
      0.511372, 0.011149, 0.009484},{0.516379, 0.004259, 0.009484},{
      0.524479, 0.006891, 0.009484}}],
    Polygon[{{0.524479, 0.015408, 0.009484},{0.524479, 0.006891, 0.009484},{
      0.528102, 0.004259, 0.002239},{0.530340, 0.011149, -0.002239},{
      0.528102, 0.018040, 0.002239}}],
    Polygon[{{0.524479, 0.015408, 0.009484},{0.528102, 0.018040, 0.002239},{
      0.522240, 0.022298, -0.002239},{0.514995, 0.022298, 0.002239},{
      0.516379, 0.018040, 0.009484}}],
    Polygon[{{0.516379, 0.018040, 0.009484},{0.514995, 0.022298, 0.002239},{
      0.509134, 0.018040, -0.002239},{0.506895, 0.011149, 0.002239},{
      0.511372, 0.011149, 0.009484}}],
    Polygon[{{0.511372, 0.011149, 0.009484},{0.506895, 0.011149, 0.002239},{
      0.509134, 0.004259, -0.002239},{0.514995, 0.000000, 0.002239},{
      0.516379, 0.004259, 0.009484}}],
    Polygon[{{0.516379, 0.004259, 0.009484},{0.524479, 0.006891, 0.009484},{
      0.528102, 0.004259, 0.002239},{0.522240, 0.000000, -0.002239},{
      0.514995, 0.000000, 0.002239}}],
    Polygon[{{0.528102, 0.018040, 0.002239},{0.530340, 0.011149, -0.002239},{
      0.525863, 0.011149, -0.009484},{0.520856, 0.018040, -0.009484},{
      0.522240, 0.022298, -0.002239}}],
    Polygon[{{0.514995, 0.022298, 0.002239},{0.522240, 0.022298, -0.002239},{
      0.520856, 0.018040, -0.009484},{0.512756, 0.015408, -0.009484},{
      0.509134, 0.018040, -0.002239}}],
    Polygon[{{0.506895, 0.011149, 0.002239},{0.509134, 0.018040, -0.002239},{
      0.512756, 0.015408, -0.009484},{0.512756, 0.006891, -0.009484},{
      0.509134, 0.004259, -0.002239}}],
    Polygon[{{0.514995, 0.000000, 0.002239},{0.509134, 0.004259, -0.002239},{
      0.512756, 0.006891, -0.009484},{0.520856, 0.004259, -0.009484},{
      0.522240, 0.000000, -0.002239}}],
    Polygon[{{0.528102, 0.004259, 0.002239},{0.522240, 0.000000, -0.002239},{
      0.520856, 0.004259, -0.009484},{0.525863, 0.011149, -0.009484},{
      0.530340, 0.011149, -0.002239}}],
    Polygon[{{0.520856, 0.018040, -0.009484},{0.525863, 0.011149, -0.009484},{
      0.520856, 0.004259, -0.009484},{0.512756, 0.006891, -0.009484},{
      0.512756, 0.015408, -0.009484}}],
    Polygon[{{0.496177, 0.070116, 0.008080},{0.489276, 0.072358, 0.008080},{
      0.485011, 0.066488, 0.008080},{0.489276, 0.060618, 0.008080},{
      0.496177, 0.062860, 0.008080}}],
    Polygon[{{0.496177, 0.070116, 0.008080},{0.496177, 0.062860, 0.008080},{
      0.499263, 0.060618, 0.001907},{0.501171, 0.066488, -0.001907},{
      0.499263, 0.072358, 0.001907}}],
    Polygon[{{0.496177, 0.070116, 0.008080},{0.499263, 0.072358, 0.001907},{
      0.494270, 0.075986, -0.001907},{0.488097, 0.075986, 0.001907},{
      0.489276, 0.072358, 0.008080}}],
    Polygon[{{0.489276, 0.072358, 0.008080},{0.488097, 0.075986, 0.001907},{
      0.483104, 0.072358, -0.001907},{0.481197, 0.066488, 0.001907},{
      0.485011, 0.066488, 0.008080}}],
    Polygon[{{0.485011, 0.066488, 0.008080},{0.481197, 0.066488, 0.001907},{
      0.483104, 0.060618, -0.001907},{0.488097, 0.056990, 0.001907},{
      0.489276, 0.060618, 0.008080}}],
    Polygon[{{0.489276, 0.060618, 0.008080},{0.496177, 0.062860, 0.008080},{
      0.499263, 0.060618, 0.001907},{0.494270, 0.056990, -0.001907},{
      0.488097, 0.056990, 0.001907}}],
    Polygon[{{0.499263, 0.072358, 0.001907},{0.501171, 0.066488, -0.001907},{
      0.497356, 0.066488, -0.008080},{0.493091, 0.072358, -0.008080},{
      0.494270, 0.075986, -0.001907}}],
    Polygon[{{0.488097, 0.075986, 0.001907},{0.494270, 0.075986, -0.001907},{
      0.493091, 0.072358, -0.008080},{0.486190, 0.070116, -0.008080},{
      0.483104, 0.072358, -0.001907}}],
    Polygon[{{0.481197, 0.066488, 0.001907},{0.483104, 0.072358, -0.001907},{
      0.486190, 0.070116, -0.008080},{0.486190, 0.062860, -0.008080},{
      0.483104, 0.060618, -0.001907}}],
    Polygon[{{0.488097, 0.056990, 0.001907},{0.483104, 0.060618, -0.001907},{
      0.486190, 0.062860, -0.008080},{0.493091, 0.060618, -0.008080},{
      0.494270, 0.056990, -0.001907}}],
    Polygon[{{0.499263, 0.060618, 0.001907},{0.494270, 0.056990, -0.001907},{
      0.493091, 0.060618, -0.008080},{0.497356, 0.066488, -0.008080},{
      0.501171, 0.066488, -0.001907}}],
    Polygon[{{0.493091, 0.072358, -0.008080},{0.497356, 0.066488, -0.008080},{
      0.493091, 0.060618, -0.008080},{0.486190, 0.062860, -0.008080},{
      0.486190, 0.070116, -0.008080}}],
    Polygon[{{0.563600, 0.185884, 0.021420},{0.545305, 0.191828, 0.021420},{
      0.533998, 0.176266, 0.021420},{0.545305, 0.160703, 0.021420},{
      0.563600, 0.166647, 0.021420}}],
    Polygon[{{0.563600, 0.185884, 0.021420},{0.563600, 0.166647, 0.021420},{
      0.571782, 0.160703, 0.005057},{0.576838, 0.176266, -0.005057},{
      0.571782, 0.191828, 0.005057}}],
    Polygon[{{0.563600, 0.185884, 0.021420},{0.571782, 0.191828, 0.005057},{
      0.558543, 0.201446, -0.005057},{0.542180, 0.201446, 0.005057},{
      0.545305, 0.191828, 0.021420}}],
    Polygon[{{0.545305, 0.191828, 0.021420},{0.542180, 0.201446, 0.005057},{
      0.528942, 0.191828, -0.005057},{0.523885, 0.176266, 0.005057},{
      0.533998, 0.176266, 0.021420}}],
    Polygon[{{0.533998, 0.176266, 0.021420},{0.523885, 0.176266, 0.005057},{
      0.528942, 0.160703, -0.005057},{0.542180, 0.151085, 0.005057},{
      0.545305, 0.160703, 0.021420}}],
    Polygon[{{0.545305, 0.160703, 0.021420},{0.563600, 0.166647, 0.021420},{
      0.571782, 0.160703, 0.005057},{0.558543, 0.151085, -0.005057},{
      0.542180, 0.151085, 0.005057}}],
    Polygon[{{0.571782, 0.191828, 0.005057},{0.576838, 0.176266, -0.005057},{
      0.566725, 0.176266, -0.021420},{0.555418, 0.191828, -0.021420},{
      0.558543, 0.201446, -0.005057}}],
    Polygon[{{0.542180, 0.201446, 0.005057},{0.558543, 0.201446, -0.005057},{
      0.555418, 0.191828, -0.021420},{0.537123, 0.185884, -0.021420},{
      0.528942, 0.191828, -0.005057}}],
    Polygon[{{0.523885, 0.176266, 0.005057},{0.528942, 0.191828, -0.005057},{
      0.537123, 0.185884, -0.021420},{0.537123, 0.166647, -0.021420},{
      0.528942, 0.160703, -0.005057}}],
    Polygon[{{0.542180, 0.151085, 0.005057},{0.528942, 0.160703, -0.005057},{
      0.537123, 0.166647, -0.021420},{0.555418, 0.160703, -0.021420},{
      0.558543, 0.151085, -0.005057}}],
    Polygon[{{0.571782, 0.160703, 0.005057},{0.558543, 0.151085, -0.005057},{
      0.555418, 0.160703, -0.021420},{0.566725, 0.176266, -0.021420},{
      0.576838, 0.176266, -0.005057}}],
    Polygon[{{0.555418, 0.191828, -0.021420},{0.566725, 0.176266, -0.021420},{
      0.555418, 0.160703, -0.021420},{0.537123, 0.166647, -0.021420},{
      0.537123, 0.185884, -0.021420}}],
    Polygon[{{0.543878, 0.216318, 0.010586},{0.534836, 0.219256, 0.010586},{
      0.529248, 0.211564, 0.010586},{0.534836, 0.203873, 0.010586},{
      0.543878, 0.206811, 0.010586}}],
    Polygon[{{0.543878, 0.216318, 0.010586},{0.543878, 0.206811, 0.010586},{
      0.547921, 0.203873, 0.002499},{0.550420, 0.211564, -0.002499},{
      0.547921, 0.219256, 0.002499}}],
    Polygon[{{0.543878, 0.216318, 0.010586},{0.547921, 0.219256, 0.002499},{
      0.541378, 0.224009, -0.002499},{0.533291, 0.224009, 0.002499},{
      0.534836, 0.219256, 0.010586}}],
    Polygon[{{0.534836, 0.219256, 0.010586},{0.533291, 0.224009, 0.002499},{
      0.526749, 0.219256, -0.002499},{0.524249, 0.211564, 0.002499},{
      0.529248, 0.211564, 0.010586}}],
    Polygon[{{0.529248, 0.211564, 0.010586},{0.524249, 0.211564, 0.002499},{
      0.526749, 0.203873, -0.002499},{0.533291, 0.199119, 0.002499},{
      0.534836, 0.203873, 0.010586}}],
    Polygon[{{0.534836, 0.203873, 0.010586},{0.543878, 0.206811, 0.010586},{
      0.547921, 0.203873, 0.002499},{0.541378, 0.199119, -0.002499},{
      0.533291, 0.199119, 0.002499}}],
    Polygon[{{0.547921, 0.219256, 0.002499},{0.550420, 0.211564, -0.002499},{
      0.545422, 0.211564, -0.010586},{0.539834, 0.219256, -0.010586},{
      0.541378, 0.224009, -0.002499}}],
    Polygon[{{0.533291, 0.224009, 0.002499},{0.541378, 0.224009, -0.002499},{
      0.539834, 0.219256, -0.010586},{0.530792, 0.216318, -0.010586},{
      0.526749, 0.219256, -0.002499}}],
    Polygon[{{0.524249, 0.211564, 0.002499},{0.526749, 0.219256, -0.002499},{
      0.530792, 0.216318, -0.010586},{0.530792, 0.206811, -0.010586},{
      0.526749, 0.203873, -0.002499}}],
    Polygon[{{0.533291, 0.199119, 0.002499},{0.526749, 0.203873, -0.002499},{
      0.530792, 0.206811, -0.010586},{0.539834, 0.203873, -0.010586},{
      0.541378, 0.199119, -0.002499}}],
    Polygon[{{0.547921, 0.203873, 0.002499},{0.541378, 0.199119, -0.002499},{
      0.539834, 0.203873, -0.010586},{0.545422, 0.211564, -0.010586},{
      0.550420, 0.211564, -0.002499}}],
    Polygon[{{0.539834, 0.219256, -0.010586},{0.545422, 0.211564, -0.010586},{
      0.539834, 0.203873, -0.010586},{0.530792, 0.206811, -0.010586},{
      0.530792, 0.216318, -0.010586}}],
    Polygon[{{0.588110, 0.167861, 0.008215},{0.581094, 0.170140, 0.008215},{
      0.576757, 0.164172, 0.008215},{0.581094, 0.158203, 0.008215},{
      0.588110, 0.160483, 0.008215}}],
    Polygon[{{0.588110, 0.167861, 0.008215},{0.588110, 0.160483, 0.008215},{
      0.591248, 0.158203, 0.001939},{0.593187, 0.164172, -0.001939},{
      0.591248, 0.170140, 0.001939}}],
    Polygon[{{0.588110, 0.167861, 0.008215},{0.591248, 0.170140, 0.001939},{
      0.586171, 0.173829, -0.001939},{0.579895, 0.173829, 0.001939},{
      0.581094, 0.170140, 0.008215}}],
    Polygon[{{0.581094, 0.170140, 0.008215},{0.579895, 0.173829, 0.001939},{
      0.574818, 0.170140, -0.001939},{0.572879, 0.164172, 0.001939},{
      0.576757, 0.164172, 0.008215}}],
    Polygon[{{0.576757, 0.164172, 0.008215},{0.572879, 0.164172, 0.001939},{
      0.574818, 0.158203, -0.001939},{0.579895, 0.154515, 0.001939},{
      0.581094, 0.158203, 0.008215}}],
    Polygon[{{0.581094, 0.158203, 0.008215},{0.588110, 0.160483, 0.008215},{
      0.591248, 0.158203, 0.001939},{0.586171, 0.154515, -0.001939},{
      0.579895, 0.154515, 0.001939}}],
    Polygon[{{0.591248, 0.170140, 0.001939},{0.593187, 0.164172, -0.001939},{
      0.589309, 0.164172, -0.008215},{0.584972, 0.170140, -0.008215},{
      0.586171, 0.173829, -0.001939}}],
    Polygon[{{0.579895, 0.173829, 0.001939},{0.586171, 0.173829, -0.001939},{
      0.584972, 0.170140, -0.008215},{0.577956, 0.167861, -0.008215},{
      0.574818, 0.170140, -0.001939}}],
    Polygon[{{0.572879, 0.164172, 0.001939},{0.574818, 0.170140, -0.001939},{
      0.577956, 0.167861, -0.008215},{0.577956, 0.160483, -0.008215},{
      0.574818, 0.158203, -0.001939}}],
    Polygon[{{0.579895, 0.154515, 0.001939},{0.574818, 0.158203, -0.001939},{
      0.577956, 0.160483, -0.008215},{0.584972, 0.158203, -0.008215},{
      0.586171, 0.154515, -0.001939}}],
    Polygon[{{0.591248, 0.158203, 0.001939},{0.586171, 0.154515, -0.001939},{
      0.584972, 0.158203, -0.008215},{0.589309, 0.164172, -0.008215},{
      0.593187, 0.164172, -0.001939}}],
    Polygon[{{0.584972, 0.170140, -0.008215},{0.589309, 0.164172, -0.008215},{
      0.584972, 0.158203, -0.008215},{0.577956, 0.160483, -0.008215},{
      0.577956, 0.167861, -0.008215}}],
    Polygon[{{0.534471, 0.152551, 0.007466},{0.528094, 0.154622, 0.007466},{
      0.524153, 0.149198, 0.007466},{0.528094, 0.143774, 0.007466},{
      0.534471, 0.145846, 0.007466}}],
    Polygon[{{0.534471, 0.152551, 0.007466},{0.534471, 0.145846, 0.007466},{
      0.537322, 0.143774, 0.001762},{0.539085, 0.149198, -0.001762},{
      0.537322, 0.154622, 0.001762}}],
    Polygon[{{0.534471, 0.152551, 0.007466},{0.537322, 0.154622, 0.001762},{
      0.532708, 0.157975, -0.001762},{0.527005, 0.157975, 0.001762},{
      0.528094, 0.154622, 0.007466}}],
    Polygon[{{0.528094, 0.154622, 0.007466},{0.527005, 0.157975, 0.001762},{
      0.522391, 0.154622, -0.001762},{0.520629, 0.149198, 0.001762},{
      0.524153, 0.149198, 0.007466}}],
    Polygon[{{0.524153, 0.149198, 0.007466},{0.520629, 0.149198, 0.001762},{
      0.522391, 0.143774, -0.001762},{0.527005, 0.140422, 0.001762},{
      0.528094, 0.143774, 0.007466}}],
    Polygon[{{0.528094, 0.143774, 0.007466},{0.534471, 0.145846, 0.007466},{
      0.537322, 0.143774, 0.001762},{0.532708, 0.140422, -0.001762},{
      0.527005, 0.140422, 0.001762}}],
    Polygon[{{0.537322, 0.154622, 0.001762},{0.539085, 0.149198, -0.001762},{
      0.535560, 0.149198, -0.007466},{0.531619, 0.154622, -0.007466},{
      0.532708, 0.157975, -0.001762}}],
    Polygon[{{0.527005, 0.157975, 0.001762},{0.532708, 0.157975, -0.001762},{
      0.531619, 0.154622, -0.007466},{0.525243, 0.152551, -0.007466},{
      0.522391, 0.154622, -0.001762}}],
    Polygon[{{0.520629, 0.149198, 0.001762},{0.522391, 0.154622, -0.001762},{
      0.525243, 0.152551, -0.007466},{0.525243, 0.145846, -0.007466},{
      0.522391, 0.143774, -0.001762}}],
    Polygon[{{0.527005, 0.140422, 0.001762},{0.522391, 0.143774, -0.001762},{
      0.525243, 0.145846, -0.007466},{0.531619, 0.143774, -0.007466},{
      0.532708, 0.140422, -0.001762}}],
    Polygon[{{0.537322, 0.143774, 0.001762},{0.532708, 0.140422, -0.001762},{
      0.531619, 0.143774, -0.007466},{0.535560, 0.149198, -0.007466},{
      0.539085, 0.149198, -0.001762}}],
    Polygon[{{0.531619, 0.154622, -0.007466},{0.535560, 0.149198, -0.007466},{
      0.531619, 0.143774, -0.007466},{0.525243, 0.145846, -0.007466},{
      0.525243, 0.152551, -0.007466}}],
    Polygon[{{0.396328, 0.490870, 0.065798},{0.340130, 0.509130, 0.065798},{
      0.305397, 0.461325, 0.065798},{0.340130, 0.413520, 0.065798},{
      0.396328, 0.431780, 0.065798}}],
    Polygon[{{0.396328, 0.490870, 0.065798},{0.396328, 0.431780, 0.065798},{
      0.421461, 0.413520, 0.015533},{0.436993, 0.461325, -0.015533},{
      0.421461, 0.509130, 0.015533}}],
    Polygon[{{0.396328, 0.490870, 0.065798},{0.421461, 0.509130, 0.015533},{
      0.380795, 0.538675, -0.015533},{0.330530, 0.538675, 0.015533},{
      0.340130, 0.509130, 0.065798}}],
    Polygon[{{0.340130, 0.509130, 0.065798},{0.330530, 0.538675, 0.015533},{
      0.289864, 0.509130, -0.015533},{0.274332, 0.461325, 0.015533},{
      0.305397, 0.461325, 0.065798}}],
    Polygon[{{0.305397, 0.461325, 0.065798},{0.274332, 0.461325, 0.015533},{
      0.289864, 0.413520, -0.015533},{0.330530, 0.383975, 0.015533},{
      0.340130, 0.413520, 0.065798}}],
    Polygon[{{0.340130, 0.413520, 0.065798},{0.396328, 0.431780, 0.065798},{
      0.421461, 0.413520, 0.015533},{0.380795, 0.383975, -0.015533},{
      0.330530, 0.383975, 0.015533}}],
    Polygon[{{0.421461, 0.509130, 0.015533},{0.436993, 0.461325, -0.015533},{
      0.405928, 0.461325, -0.065798},{0.371195, 0.509130, -0.065798},{
      0.380795, 0.538675, -0.015533}}],
    Polygon[{{0.330530, 0.538675, 0.015533},{0.380795, 0.538675, -0.015533},{
      0.371195, 0.509130, -0.065798},{0.314997, 0.490870, -0.065798},{
      0.289864, 0.509130, -0.015533}}],
    Polygon[{{0.274332, 0.461325, 0.015533},{0.289864, 0.509130, -0.015533},{
      0.314997, 0.490870, -0.065798},{0.314997, 0.431780, -0.065798},{
      0.289864, 0.413520, -0.015533}}],
    Polygon[{{0.330530, 0.383975, 0.015533},{0.289864, 0.413520, -0.015533},{
      0.314997, 0.431780, -0.065798},{0.371195, 0.413520, -0.065798},{
      0.380795, 0.383975, -0.015533}}],
    Polygon[{{0.421461, 0.413520, 0.015533},{0.380795, 0.383975, -0.015533},{
      0.371195, 0.413520, -0.065798},{0.405928, 0.461325, -0.065798},{
      0.436993, 0.461325, -0.015533}}],
    Polygon[{{0.371195, 0.509130, -0.065798},{0.405928, 0.461325, -0.065798},{
      0.371195, 0.413520, -0.065798},{0.314997, 0.431780, -0.065798},{
      0.314997, 0.490870, -0.065798}}],
    Polygon[{{0.402990, 0.593183, 0.035261},{0.372874, 0.602969, 0.035261},{
      0.354261, 0.577350, 0.035261},{0.372874, 0.551732, 0.035261},{
      0.402990, 0.561517, 0.035261}}],
    Polygon[{{0.402990, 0.593183, 0.035261},{0.402990, 0.561517, 0.035261},{
      0.416459, 0.551732, 0.008324},{0.424783, 0.577350, -0.008324},{
      0.416459, 0.602969, 0.008324}}],
    Polygon[{{0.402990, 0.593183, 0.035261},{0.416459, 0.602969, 0.008324},{
      0.394666, 0.618802, -0.008324},{0.367729, 0.618802, 0.008324},{
      0.372874, 0.602969, 0.035261}}],
    Polygon[{{0.372874, 0.602969, 0.035261},{0.367729, 0.618802, 0.008324},{
      0.345937, 0.602969, -0.008324},{0.337613, 0.577350, 0.008324},{
      0.354261, 0.577350, 0.035261}}],
    Polygon[{{0.354261, 0.577350, 0.035261},{0.337613, 0.577350, 0.008324},{
      0.345937, 0.551732, -0.008324},{0.367729, 0.535898, 0.008324},{
      0.372874, 0.551732, 0.035261}}],
    Polygon[{{0.372874, 0.551732, 0.035261},{0.402990, 0.561517, 0.035261},{
      0.416459, 0.551732, 0.008324},{0.394666, 0.535898, -0.008324},{
      0.367729, 0.535898, 0.008324}}],
    Polygon[{{0.416459, 0.602969, 0.008324},{0.424783, 0.577350, -0.008324},{
      0.408135, 0.577350, -0.035261},{0.389522, 0.602969, -0.035261},{
      0.394666, 0.618802, -0.008324}}],
    Polygon[{{0.367729, 0.618802, 0.008324},{0.394666, 0.618802, -0.008324},{
      0.389522, 0.602969, -0.035261},{0.359405, 0.593183, -0.035261},{
      0.345937, 0.602969, -0.008324}}],
    Polygon[{{0.337613, 0.577350, 0.008324},{0.345937, 0.602969, -0.008324},{
      0.359405, 0.593183, -0.035261},{0.359405, 0.561517, -0.035261},{
      0.345937, 0.551732, -0.008324}}],
    Polygon[{{0.367729, 0.535898, 0.008324},{0.345937, 0.551732, -0.008324},{
      0.359405, 0.561517, -0.035261},{0.389522, 0.551732, -0.035261},{
      0.394666, 0.535898, -0.008324}}],
    Polygon[{{0.416459, 0.551732, 0.008324},{0.394666, 0.535898, -0.008324},{
      0.389522, 0.551732, -0.035261},{0.408135, 0.577350, -0.035261},{
      0.424783, 0.577350, -0.008324}}],
    Polygon[{{0.389522, 0.602969, -0.035261},{0.408135, 0.577350, -0.035261},{
      0.389522, 0.551732, -0.035261},{0.359405, 0.561517, -0.035261},{
      0.359405, 0.593183, -0.035261}}],
    Polygon[{{0.413876, 0.651657, 0.021933},{0.395143, 0.657744, 0.021933},{
      0.383566, 0.641809, 0.021933},{0.395143, 0.625874, 0.021933},{
      0.413876, 0.631960, 0.021933}}],
    Polygon[{{0.413876, 0.651657, 0.021933},{0.413876, 0.631960, 0.021933},{
      0.422253, 0.625874, 0.005178},{0.427431, 0.641809, -0.005178},{
      0.422253, 0.657744, 0.005178}}],
    Polygon[{{0.413876, 0.651657, 0.021933},{0.422253, 0.657744, 0.005178},{
      0.408698, 0.667592, -0.005178},{0.391943, 0.667592, 0.005178},{
      0.395143, 0.657744, 0.021933}}],
    Polygon[{{0.395143, 0.657744, 0.021933},{0.391943, 0.667592, 0.005178},{
      0.378388, 0.657744, -0.005178},{0.373210, 0.641809, 0.005178},{
      0.383566, 0.641809, 0.021933}}],
    Polygon[{{0.383566, 0.641809, 0.021933},{0.373210, 0.641809, 0.005178},{
      0.378388, 0.625874, -0.005178},{0.391943, 0.616025, 0.005178},{
      0.395143, 0.625874, 0.021933}}],
    Polygon[{{0.395143, 0.625874, 0.021933},{0.413876, 0.631960, 0.021933},{
      0.422253, 0.625874, 0.005178},{0.408698, 0.616025, -0.005178},{
      0.391943, 0.616025, 0.005178}}],
    Polygon[{{0.422253, 0.657744, 0.005178},{0.427431, 0.641809, -0.005178},{
      0.417076, 0.641809, -0.021933},{0.405498, 0.657744, -0.021933},{
      0.408698, 0.667592, -0.005178}}],
    Polygon[{{0.391943, 0.667592, 0.005178},{0.408698, 0.667592, -0.005178},{
      0.405498, 0.657744, -0.021933},{0.386765, 0.651657, -0.021933},{
      0.378388, 0.657744, -0.005178}}],
    Polygon[{{0.373210, 0.641809, 0.005178},{0.378388, 0.657744, -0.005178},{
      0.386765, 0.651657, -0.021933},{0.386765, 0.631960, -0.021933},{
      0.378388, 0.625874, -0.005178}}],
    Polygon[{{0.391943, 0.616025, 0.005178},{0.378388, 0.625874, -0.005178},{
      0.386765, 0.631960, -0.021933},{0.405498, 0.625874, -0.021933},{
      0.408698, 0.616025, -0.005178}}],
    Polygon[{{0.422253, 0.625874, 0.005178},{0.408698, 0.616025, -0.005178},{
      0.405498, 0.625874, -0.021933},{0.417076, 0.641809, -0.021933},{
      0.427431, 0.641809, -0.005178}}],
    Polygon[{{0.405498, 0.657744, -0.021933},{0.417076, 0.641809, -0.021933},{
      0.405498, 0.625874, -0.021933},{0.386765, 0.631960, -0.021933},{
      0.386765, 0.651657, -0.021933}}],
    Polygon[{{0.340598, 0.554993, 0.011754},{0.330559, 0.558255, 0.011754},{
      0.324354, 0.549716, 0.011754},{0.330559, 0.541176, 0.011754},{
      0.340598, 0.544438, 0.011754}}],
    Polygon[{{0.340598, 0.554993, 0.011754},{0.340598, 0.544438, 0.011754},{
      0.345087, 0.541176, 0.002775},{0.347862, 0.549716, -0.002775},{
      0.345087, 0.558255, 0.002775}}],
    Polygon[{{0.340598, 0.554993, 0.011754},{0.345087, 0.558255, 0.002775},{
      0.337823, 0.563533, -0.002775},{0.328844, 0.563533, 0.002775},{
      0.330559, 0.558255, 0.011754}}],
    Polygon[{{0.330559, 0.558255, 0.011754},{0.328844, 0.563533, 0.002775},{
      0.321580, 0.558255, -0.002775},{0.318805, 0.549716, 0.002775},{
      0.324354, 0.549716, 0.011754}}],
    Polygon[{{0.324354, 0.549716, 0.011754},{0.318805, 0.549716, 0.002775},{
      0.321580, 0.541176, -0.002775},{0.328844, 0.535898, 0.002775},{
      0.330559, 0.541176, 0.011754}}],
    Polygon[{{0.330559, 0.541176, 0.011754},{0.340598, 0.544438, 0.011754},{
      0.345087, 0.541176, 0.002775},{0.337823, 0.535898, -0.002775},{
      0.328844, 0.535898, 0.002775}}],
    Polygon[{{0.345087, 0.558255, 0.002775},{0.347862, 0.549716, -0.002775},{
      0.342312, 0.549716, -0.011754},{0.336108, 0.558255, -0.011754},{
      0.337823, 0.563533, -0.002775}}],
    Polygon[{{0.328844, 0.563533, 0.002775},{0.337823, 0.563533, -0.002775},{
      0.336108, 0.558255, -0.011754},{0.326069, 0.554993, -0.011754},{
      0.321580, 0.558255, -0.002775}}],
    Polygon[{{0.318805, 0.549716, 0.002775},{0.321580, 0.558255, -0.002775},{
      0.326069, 0.554993, -0.011754},{0.326069, 0.544438, -0.011754},{
      0.321580, 0.541176, -0.002775}}],
    Polygon[{{0.328844, 0.535898, 0.002775},{0.321580, 0.541176, -0.002775},{
      0.326069, 0.544438, -0.011754},{0.336108, 0.541176, -0.011754},{
      0.337823, 0.535898, -0.002775}}],
    Polygon[{{0.345087, 0.541176, 0.002775},{0.337823, 0.535898, -0.002775},{
      0.336108, 0.541176, -0.011754},{0.342312, 0.549716, -0.011754},{
      0.347862, 0.549716, -0.002775}}],
    Polygon[{{0.336108, 0.558255, -0.011754},{0.342312, 0.549716, -0.011754},{
      0.336108, 0.541176, -0.011754},{0.326069, 0.544438, -0.011754},{
      0.326069, 0.554993, -0.011754}}],
    Polygon[{{0.418263, 0.537153, 0.010966},{0.408896, 0.540197, 0.010966},{
      0.403108, 0.532229, 0.010966},{0.408896, 0.524262, 0.010966},{
      0.418263, 0.527305, 0.010966}}],
    Polygon[{{0.418263, 0.537153, 0.010966},{0.418263, 0.527305, 0.010966},{
      0.422452, 0.524262, 0.002589},{0.425040, 0.532229, -0.002589},{
      0.422452, 0.540197, 0.002589}}],
    Polygon[{{0.418263, 0.537153, 0.010966},{0.422452, 0.540197, 0.002589},{
      0.415674, 0.545121, -0.002589},{0.407296, 0.545121, 0.002589},{
      0.408896, 0.540197, 0.010966}}],
    Polygon[{{0.408896, 0.540197, 0.010966},{0.407296, 0.545121, 0.002589},{
      0.400519, 0.540197, -0.002589},{0.397930, 0.532229, 0.002589},{
      0.403108, 0.532229, 0.010966}}],
    Polygon[{{0.403108, 0.532229, 0.010966},{0.397930, 0.532229, 0.002589},{
      0.400519, 0.524262, -0.002589},{0.407296, 0.519338, 0.002589},{
      0.408896, 0.524262, 0.010966}}],
    Polygon[{{0.408896, 0.524262, 0.010966},{0.418263, 0.527305, 0.010966},{
      0.422452, 0.524262, 0.002589},{0.415674, 0.519338, -0.002589},{
      0.407296, 0.519338, 0.002589}}],
    Polygon[{{0.422452, 0.540197, 0.002589},{0.425040, 0.532229, -0.002589},{
      0.419863, 0.532229, -0.010966},{0.414074, 0.540197, -0.010966},{
      0.415674, 0.545121, -0.002589}}],
    Polygon[{{0.407296, 0.545121, 0.002589},{0.415674, 0.545121, -0.002589},{
      0.414074, 0.540197, -0.010966},{0.404708, 0.537153, -0.010966},{
      0.400519, 0.540197, -0.002589}}],
    Polygon[{{0.397930, 0.532229, 0.002589},{0.400519, 0.540197, -0.002589},{
      0.404708, 0.537153, -0.010966},{0.404708, 0.527305, -0.010966},{
      0.400519, 0.524262, -0.002589}}],
    Polygon[{{0.407296, 0.519338, 0.002589},{0.400519, 0.524262, -0.002589},{
      0.404708, 0.527305, -0.010966},{0.414074, 0.524262, -0.010966},{
      0.415674, 0.519338, -0.002589}}],
    Polygon[{{0.422452, 0.524262, 0.002589},{0.415674, 0.519338, -0.002589},{
      0.414074, 0.524262, -0.010966},{0.419863, 0.532229, -0.010966},{
      0.425040, 0.532229, -0.002589}}],
    Polygon[{{0.414074, 0.540197, -0.010966},{0.419863, 0.532229, -0.010966},{
      0.414074, 0.524262, -0.010966},{0.404708, 0.527305, -0.010966},{
      0.404708, 0.537153, -0.010966}}],
    Polygon[{{0.281658, 0.414587, 0.024645},{0.260609, 0.421427, 0.024645},{
      0.247600, 0.403521, 0.024645},{0.260609, 0.385616, 0.024645},{
      0.281658, 0.392455, 0.024645}}],
    Polygon[{{0.281658, 0.414587, 0.024645},{0.281658, 0.392455, 0.024645},{
      0.291071, 0.385616, 0.005818},{0.296889, 0.403521, -0.005818},{
      0.291071, 0.421427, 0.005818}}],
    Polygon[{{0.281658, 0.414587, 0.024645},{0.291071, 0.421427, 0.005818},{
      0.275840, 0.432493, -0.005818},{0.257013, 0.432493, 0.005818},{
      0.260609, 0.421427, 0.024645}}],
    Polygon[{{0.260609, 0.421427, 0.024645},{0.257013, 0.432493, 0.005818},{
      0.241782, 0.421427, -0.005818},{0.235964, 0.403521, 0.005818},{
      0.247600, 0.403521, 0.024645}}],
    Polygon[{{0.247600, 0.403521, 0.024645},{0.235964, 0.403521, 0.005818},{
      0.241782, 0.385616, -0.005818},{0.257013, 0.374550, 0.005818},{
      0.260609, 0.385616, 0.024645}}],
    Polygon[{{0.260609, 0.385616, 0.024645},{0.281658, 0.392455, 0.024645},{
      0.291071, 0.385616, 0.005818},{0.275840, 0.374550, -0.005818},{
      0.257013, 0.374550, 0.005818}}],
    Polygon[{{0.291071, 0.421427, 0.005818},{0.296889, 0.403521, -0.005818},{
      0.285253, 0.403521, -0.024645},{0.272244, 0.421427, -0.024645},{
      0.275840, 0.432493, -0.005818}}],
    Polygon[{{0.257013, 0.432493, 0.005818},{0.275840, 0.432493, -0.005818},{
      0.272244, 0.421427, -0.024645},{0.251195, 0.414587, -0.024645},{
      0.241782, 0.421427, -0.005818}}],
    Polygon[{{0.235964, 0.403521, 0.005818},{0.241782, 0.421427, -0.005818},{
      0.251195, 0.414587, -0.024645},{0.251195, 0.392455, -0.024645},{
      0.241782, 0.385616, -0.005818}}],
    Polygon[{{0.257013, 0.374550, 0.005818},{0.241782, 0.385616, -0.005818},{
      0.251195, 0.392455, -0.024645},{0.272244, 0.385616, -0.024645},{
      0.275840, 0.374550, -0.005818}}],
    Polygon[{{0.291071, 0.385616, 0.005818},{0.275840, 0.374550, -0.005818},{
      0.272244, 0.385616, -0.024645},{0.285253, 0.403521, -0.024645},{
      0.296889, 0.403521, -0.005818}}],
    Polygon[{{0.272244, 0.421427, -0.024645},{0.285253, 0.403521, -0.024645},{
      0.272244, 0.385616, -0.024645},{0.251195, 0.392455, -0.024645},{
      0.251195, 0.414587, -0.024645}}],
    Polygon[{{0.241393, 0.380079, 0.012792},{0.230467, 0.383629, 0.012792},{
      0.223715, 0.374335, 0.012792},{0.230467, 0.365041, 0.012792},{
      0.241393, 0.368591, 0.012792}}],
    Polygon[{{0.241393, 0.380079, 0.012792},{0.241393, 0.368591, 0.012792},{
      0.246279, 0.365041, 0.003020},{0.249299, 0.374335, -0.003020},{
      0.246279, 0.383629, 0.003020}}],
    Polygon[{{0.241393, 0.380079, 0.012792},{0.246279, 0.383629, 0.003020},{
      0.238373, 0.389373, -0.003020},{0.228601, 0.389373, 0.003020},{
      0.230467, 0.383629, 0.012792}}],
    Polygon[{{0.230467, 0.383629, 0.012792},{0.228601, 0.389373, 0.003020},{
      0.220695, 0.383629, -0.003020},{0.217675, 0.374335, 0.003020},{
      0.223715, 0.374335, 0.012792}}],
    Polygon[{{0.223715, 0.374335, 0.012792},{0.217675, 0.374335, 0.003020},{
      0.220695, 0.365041, -0.003020},{0.228601, 0.359297, 0.003020},{
      0.230467, 0.365041, 0.012792}}],
    Polygon[{{0.230467, 0.365041, 0.012792},{0.241393, 0.368591, 0.012792},{
      0.246279, 0.365041, 0.003020},{0.238373, 0.359297, -0.003020},{
      0.228601, 0.359297, 0.003020}}],
    Polygon[{{0.246279, 0.383629, 0.003020},{0.249299, 0.374335, -0.003020},{
      0.243259, 0.374335, -0.012792},{0.236507, 0.383629, -0.012792},{
      0.238373, 0.389373, -0.003020}}],
    Polygon[{{0.228601, 0.389373, 0.003020},{0.238373, 0.389373, -0.003020},{
      0.236507, 0.383629, -0.012792},{0.225581, 0.380079, -0.012792},{
      0.220695, 0.383629, -0.003020}}],
    Polygon[{{0.217675, 0.374335, 0.003020},{0.220695, 0.383629, -0.003020},{
      0.225581, 0.380079, -0.012792},{0.225581, 0.368591, -0.012792},{
      0.220695, 0.365041, -0.003020}}],
    Polygon[{{0.228601, 0.359297, 0.003020},{0.220695, 0.365041, -0.003020},{
      0.225581, 0.368591, -0.012792},{0.236507, 0.365041, -0.012792},{
      0.238373, 0.359297, -0.003020}}],
    Polygon[{{0.246279, 0.365041, 0.003020},{0.238373, 0.359297, -0.003020},{
      0.236507, 0.365041, -0.012792},{0.243259, 0.374335, -0.012792},{
      0.249299, 0.374335, -0.003020}}],
    Polygon[{{0.236507, 0.383629, -0.012792},{0.243259, 0.374335, -0.012792},{
      0.236507, 0.365041, -0.012792},{0.225581, 0.368591, -0.012792},{
      0.225581, 0.380079, -0.012792}}],
    Polygon[{{0.274826, 0.447820, 0.009484},{0.266725, 0.450452, 0.009484},{
      0.261719, 0.443561, 0.009484},{0.266725, 0.436671, 0.009484},{
      0.274826, 0.439303, 0.009484}}],
    Polygon[{{0.274826, 0.447820, 0.009484},{0.274826, 0.439303, 0.009484},{
      0.278448, 0.436671, 0.002239},{0.280687, 0.443561, -0.002239},{
      0.278448, 0.450452, 0.002239}}],
    Polygon[{{0.274826, 0.447820, 0.009484},{0.278448, 0.450452, 0.002239},{
      0.272587, 0.454710, -0.002239},{0.265342, 0.454710, 0.002239},{
      0.266725, 0.450452, 0.009484}}],
    Polygon[{{0.266725, 0.450452, 0.009484},{0.265342, 0.454710, 0.002239},{
      0.259480, 0.450452, -0.002239},{0.257241, 0.443561, 0.002239},{
      0.261719, 0.443561, 0.009484}}],
    Polygon[{{0.261719, 0.443561, 0.009484},{0.257241, 0.443561, 0.002239},{
      0.259480, 0.436671, -0.002239},{0.265342, 0.432412, 0.002239},{
      0.266725, 0.436671, 0.009484}}],
    Polygon[{{0.266725, 0.436671, 0.009484},{0.274826, 0.439303, 0.009484},{
      0.278448, 0.436671, 0.002239},{0.272587, 0.432412, -0.002239},{
      0.265342, 0.432412, 0.002239}}],
    Polygon[{{0.278448, 0.450452, 0.002239},{0.280687, 0.443561, -0.002239},{
      0.276209, 0.443561, -0.009484},{0.271203, 0.450452, -0.009484},{
      0.272587, 0.454710, -0.002239}}],
    Polygon[{{0.265342, 0.454710, 0.002239},{0.272587, 0.454710, -0.002239},{
      0.271203, 0.450452, -0.009484},{0.263103, 0.447820, -0.009484},{
      0.259480, 0.450452, -0.002239}}],
    Polygon[{{0.257241, 0.443561, 0.002239},{0.259480, 0.450452, -0.002239},{
      0.263103, 0.447820, -0.009484},{0.263103, 0.439303, -0.009484},{
      0.259480, 0.436671, -0.002239}}],
    Polygon[{{0.265342, 0.432412, 0.002239},{0.259480, 0.436671, -0.002239},{
      0.263103, 0.439303, -0.009484},{0.271203, 0.436671, -0.009484},{
      0.272587, 0.432412, -0.002239}}],
    Polygon[{{0.278448, 0.436671, 0.002239},{0.272587, 0.432412, -0.002239},{
      0.271203, 0.436671, -0.009484},{0.276209, 0.443561, -0.009484},{
      0.280687, 0.443561, -0.002239}}],
    Polygon[{{0.271203, 0.450452, -0.009484},{0.276209, 0.443561, -0.009484},{
      0.271203, 0.436671, -0.009484},{0.263103, 0.439303, -0.009484},{
      0.263103, 0.447820, -0.009484}}],
    Polygon[{{0.308166, 0.395762, 0.008080},{0.301265, 0.398004, 0.008080},{
      0.297000, 0.392133, 0.008080},{0.301265, 0.386263, 0.008080},{
      0.308166, 0.388505, 0.008080}}],
    Polygon[{{0.308166, 0.395762, 0.008080},{0.308166, 0.388505, 0.008080},{
      0.311252, 0.386263, 0.001907},{0.313159, 0.392133, -0.001907},{
      0.311252, 0.398004, 0.001907}}],
    Polygon[{{0.308166, 0.395762, 0.008080},{0.311252, 0.398004, 0.001907},{
      0.306258, 0.401632, -0.001907},{0.300086, 0.401632, 0.001907},{
      0.301265, 0.398004, 0.008080}}],
    Polygon[{{0.301265, 0.398004, 0.008080},{0.300086, 0.401632, 0.001907},{
      0.295092, 0.398004, -0.001907},{0.293185, 0.392133, 0.001907},{
      0.297000, 0.392133, 0.008080}}],
    Polygon[{{0.297000, 0.392133, 0.008080},{0.293185, 0.392133, 0.001907},{
      0.295092, 0.386263, -0.001907},{0.300086, 0.382635, 0.001907},{
      0.301265, 0.386263, 0.008080}}],
    Polygon[{{0.301265, 0.386263, 0.008080},{0.308166, 0.388505, 0.008080},{
      0.311252, 0.386263, 0.001907},{0.306258, 0.382635, -0.001907},{
      0.300086, 0.382635, 0.001907}}],
    Polygon[{{0.311252, 0.398004, 0.001907},{0.313159, 0.392133, -0.001907},{
      0.309345, 0.392133, -0.008080},{0.305080, 0.398004, -0.008080},{
      0.306258, 0.401632, -0.001907}}],
    Polygon[{{0.300086, 0.401632, 0.001907},{0.306258, 0.401632, -0.001907},{
      0.305080, 0.398004, -0.008080},{0.298179, 0.395762, -0.008080},{
      0.295092, 0.398004, -0.001907}}],
    Polygon[{{0.293185, 0.392133, 0.001907},{0.295092, 0.398004, -0.001907},{
      0.298179, 0.395762, -0.008080},{0.298179, 0.388505, -0.008080},{
      0.295092, 0.386263, -0.001907}}],
    Polygon[{{0.300086, 0.382635, 0.001907},{0.295092, 0.386263, -0.001907},{
      0.298179, 0.388505, -0.008080},{0.305080, 0.386263, -0.008080},{
      0.306258, 0.382635, -0.001907}}],
    Polygon[{{0.311252, 0.386263, 0.001907},{0.306258, 0.382635, -0.001907},{
      0.305080, 0.386263, -0.008080},{0.309345, 0.392133, -0.008080},{
      0.313159, 0.392133, -0.001907}}],
    Polygon[{{0.305080, 0.398004, -0.008080},{0.309345, 0.392133, -0.008080},{
      0.305080, 0.386263, -0.008080},{0.298179, 0.388505, -0.008080},{
      0.298179, 0.395762, -0.008080}}],
    Polygon[{{0.441070, 0.398113, 0.021420},{0.422775, 0.404057, 0.021420},{
      0.411468, 0.388494, 0.021420},{0.422775, 0.372932, 0.021420},{
      0.441070, 0.378876, 0.021420}}],
    Polygon[{{0.441070, 0.398113, 0.021420},{0.441070, 0.378876, 0.021420},{
      0.449251, 0.372932, 0.005057},{0.454308, 0.388494, -0.005057},{
      0.449251, 0.404057, 0.005057}}],
    Polygon[{{0.441070, 0.398113, 0.021420},{0.449251, 0.404057, 0.005057},{
      0.436013, 0.413675, -0.005057},{0.419649, 0.413675, 0.005057},{
      0.422775, 0.404057, 0.021420}}],
    Polygon[{{0.422775, 0.404057, 0.021420},{0.419649, 0.413675, 0.005057},{
      0.406411, 0.404057, -0.005057},{0.401355, 0.388494, 0.005057},{
      0.411468, 0.388494, 0.021420}}],
    Polygon[{{0.411468, 0.388494, 0.021420},{0.401355, 0.388494, 0.005057},{
      0.406411, 0.372932, -0.005057},{0.419649, 0.363314, 0.005057},{
      0.422775, 0.372932, 0.021420}}],
    Polygon[{{0.422775, 0.372932, 0.021420},{0.441070, 0.378876, 0.021420},{
      0.449251, 0.372932, 0.005057},{0.436013, 0.363314, -0.005057},{
      0.419649, 0.363314, 0.005057}}],
    Polygon[{{0.449251, 0.404057, 0.005057},{0.454308, 0.388494, -0.005057},{
      0.444195, 0.388494, -0.021420},{0.432888, 0.404057, -0.021420},{
      0.436013, 0.413675, -0.005057}}],
    Polygon[{{0.419649, 0.413675, 0.005057},{0.436013, 0.413675, -0.005057},{
      0.432888, 0.404057, -0.021420},{0.414593, 0.398113, -0.021420},{
      0.406411, 0.404057, -0.005057}}],
    Polygon[{{0.401355, 0.388494, 0.005057},{0.406411, 0.404057, -0.005057},{
      0.414593, 0.398113, -0.021420},{0.414593, 0.378876, -0.021420},{
      0.406411, 0.372932, -0.005057}}],
    Polygon[{{0.419649, 0.363314, 0.005057},{0.406411, 0.372932, -0.005057},{
      0.414593, 0.378876, -0.021420},{0.432888, 0.372932, -0.021420},{
      0.436013, 0.363314, -0.005057}}],
    Polygon[{{0.449251, 0.372932, 0.005057},{0.436013, 0.363314, -0.005057},{
      0.432888, 0.372932, -0.021420},{0.444195, 0.388494, -0.021420},{
      0.454308, 0.388494, -0.005057}}],
    Polygon[{{0.432888, 0.404057, -0.021420},{0.444195, 0.388494, -0.021420},{
      0.432888, 0.372932, -0.021420},{0.414593, 0.378876, -0.021420},{
      0.414593, 0.398113, -0.021420}}],
    Polygon[{{0.458430, 0.364317, 0.010586},{0.449388, 0.367255, 0.010586},{
      0.443800, 0.359563, 0.010586},{0.449388, 0.351872, 0.010586},{
      0.458430, 0.354810, 0.010586}}],
    Polygon[{{0.458430, 0.364317, 0.010586},{0.458430, 0.354810, 0.010586},{
      0.462474, 0.351872, 0.002499},{0.464973, 0.359563, -0.002499},{
      0.462474, 0.367255, 0.002499}}],
    Polygon[{{0.458430, 0.364317, 0.010586},{0.462474, 0.367255, 0.002499},{
      0.455931, 0.372008, -0.002499},{0.447844, 0.372008, 0.002499},{
      0.449388, 0.367255, 0.010586}}],
    Polygon[{{0.449388, 0.367255, 0.010586},{0.447844, 0.372008, 0.002499},{
      0.441301, 0.367255, -0.002499},{0.438802, 0.359563, 0.002499},{
      0.443800, 0.359563, 0.010586}}],
    Polygon[{{0.443800, 0.359563, 0.010586},{0.438802, 0.359563, 0.002499},{
      0.441301, 0.351872, -0.002499},{0.447844, 0.347119, 0.002499},{
      0.449388, 0.351872, 0.010586}}],
    Polygon[{{0.449388, 0.351872, 0.010586},{0.458430, 0.354810, 0.010586},{
      0.462474, 0.351872, 0.002499},{0.455931, 0.347119, -0.002499},{
      0.447844, 0.347119, 0.002499}}],
    Polygon[{{0.462474, 0.367255, 0.002499},{0.464973, 0.359563, -0.002499},{
      0.459975, 0.359563, -0.010586},{0.454387, 0.367255, -0.010586},{
      0.455931, 0.372008, -0.002499}}],
    Polygon[{{0.447844, 0.372008, 0.002499},{0.455931, 0.372008, -0.002499},{
      0.454387, 0.367255, -0.010586},{0.445345, 0.364317, -0.010586},{
      0.441301, 0.367255, -0.002499}}],
    Polygon[{{0.438802, 0.359563, 0.002499},{0.441301, 0.367255, -0.002499},{
      0.445345, 0.364317, -0.010586},{0.445345, 0.354810, -0.010586},{
      0.441301, 0.351872, -0.002499}}],
    Polygon[{{0.447844, 0.347119, 0.002499},{0.441301, 0.351872, -0.002499},{
      0.445345, 0.354810, -0.010586},{0.454387, 0.351872, -0.010586},{
      0.455931, 0.347119, -0.002499}}],
    Polygon[{{0.462474, 0.351872, 0.002499},{0.455931, 0.347119, -0.002499},{
      0.454387, 0.351872, -0.010586},{0.459975, 0.359563, -0.010586},{
      0.464973, 0.359563, -0.002499}}],
    Polygon[{{0.454387, 0.367255, -0.010586},{0.459975, 0.359563, -0.010586},{
      0.454387, 0.351872, -0.010586},{0.445345, 0.354810, -0.010586},{
      0.445345, 0.364317, -0.010586}}],
    Polygon[{{0.438771, 0.426524, 0.008215},{0.431754, 0.428804, 0.008215},{
      0.427418, 0.422836, 0.008215},{0.431754, 0.416867, 0.008215},{
      0.438771, 0.419147, 0.008215}}],
    Polygon[{{0.438771, 0.426524, 0.008215},{0.438771, 0.419147, 0.008215},{
      0.441908, 0.416867, 0.001939},{0.443848, 0.422836, -0.001939},{
      0.441908, 0.428804, 0.001939}}],
    Polygon[{{0.438771, 0.426524, 0.008215},{0.441908, 0.428804, 0.001939},{
      0.436831, 0.432493, -0.001939},{0.430556, 0.432493, 0.001939},{
      0.431754, 0.428804, 0.008215}}],
    Polygon[{{0.431754, 0.428804, 0.008215},{0.430556, 0.432493, 0.001939},{
      0.425479, 0.428804, -0.001939},{0.423539, 0.422836, 0.001939},{
      0.427418, 0.422836, 0.008215}}],
    Polygon[{{0.427418, 0.422836, 0.008215},{0.423539, 0.422836, 0.001939},{
      0.425479, 0.416867, -0.001939},{0.430556, 0.413178, 0.001939},{
      0.431754, 0.416867, 0.008215}}],
    Polygon[{{0.431754, 0.416867, 0.008215},{0.438771, 0.419147, 0.008215},{
      0.441908, 0.416867, 0.001939},{0.436831, 0.413178, -0.001939},{
      0.430556, 0.413178, 0.001939}}],
    Polygon[{{0.441908, 0.428804, 0.001939},{0.443848, 0.422836, -0.001939},{
      0.439969, 0.422836, -0.008215},{0.435633, 0.428804, -0.008215},{
      0.436831, 0.432493, -0.001939}}],
    Polygon[{{0.430556, 0.432493, 0.001939},{0.436831, 0.432493, -0.001939},{
      0.435633, 0.428804, -0.008215},{0.428617, 0.426524, -0.008215},{
      0.425479, 0.428804, -0.001939}}],
    Polygon[{{0.423539, 0.422836, 0.001939},{0.425479, 0.428804, -0.001939},{
      0.428617, 0.426524, -0.008215},{0.428617, 0.419147, -0.008215},{
      0.425479, 0.416867, -0.001939}}],
    Polygon[{{0.430556, 0.413178, 0.001939},{0.425479, 0.416867, -0.001939},{
      0.428617, 0.419147, -0.008215},{0.435633, 0.416867, -0.008215},{
      0.436831, 0.413178, -0.001939}}],
    Polygon[{{0.441908, 0.416867, 0.001939},{0.436831, 0.413178, -0.001939},{
      0.435633, 0.416867, -0.008215},{0.439969, 0.422836, -0.008215},{
      0.443848, 0.422836, -0.001939}}],
    Polygon[{{0.435633, 0.428804, -0.008215},{0.439969, 0.422836, -0.008215},{
      0.435633, 0.416867, -0.008215},{0.428617, 0.419147, -0.008215},{
      0.428617, 0.426524, -0.008215}}],
    Polygon[{{0.398752, 0.387622, 0.007466},{0.392375, 0.389694, 0.007466},{
      0.388435, 0.384270, 0.007466},{0.392375, 0.378846, 0.007466},{
      0.398752, 0.380918, 0.007466}}],
    Polygon[{{0.398752, 0.387622, 0.007466},{0.398752, 0.380918, 0.007466},{
      0.401603, 0.378846, 0.001762},{0.403366, 0.384270, -0.001762},{
      0.401603, 0.389694, 0.001762}}],
    Polygon[{{0.398752, 0.387622, 0.007466},{0.401603, 0.389694, 0.001762},{
      0.396989, 0.393046, -0.001762},{0.391286, 0.393046, 0.001762},{
      0.392375, 0.389694, 0.007466}}],
    Polygon[{{0.392375, 0.389694, 0.007466},{0.391286, 0.393046, 0.001762},{
      0.386672, 0.389694, -0.001762},{0.384910, 0.384270, 0.001762},{
      0.388435, 0.384270, 0.007466}}],
    Polygon[{{0.388435, 0.384270, 0.007466},{0.384910, 0.384270, 0.001762},{
      0.386672, 0.378846, -0.001762},{0.391286, 0.375494, 0.001762},{
      0.392375, 0.378846, 0.007466}}],
    Polygon[{{0.392375, 0.378846, 0.007466},{0.398752, 0.380918, 0.007466},{
      0.401603, 0.378846, 0.001762},{0.396989, 0.375494, -0.001762},{
      0.391286, 0.375494, 0.001762}}],
    Polygon[{{0.401603, 0.389694, 0.001762},{0.403366, 0.384270, -0.001762},{
      0.399841, 0.384270, -0.007466},{0.395900, 0.389694, -0.007466},{
      0.396989, 0.393046, -0.001762}}],
    Polygon[{{0.391286, 0.393046, 0.001762},{0.396989, 0.393046, -0.001762},{
      0.395900, 0.389694, -0.007466},{0.389524, 0.387622, -0.007466},{
      0.386672, 0.389694, -0.001762}}],
    Polygon[{{0.384910, 0.384270, 0.001762},{0.386672, 0.389694, -0.001762},{
      0.389524, 0.387622, -0.007466},{0.389524, 0.380918, -0.007466},{
      0.386672, 0.378846, -0.001762}}],
    Polygon[{{0.391286, 0.375494, 0.001762},{0.386672, 0.378846, -0.001762},{
      0.389524, 0.380918, -0.007466},{0.395900, 0.378846, -0.007466},{
      0.396989, 0.375494, -0.001762}}],
    Polygon[{{0.401603, 0.378846, 0.001762},{0.396989, 0.375494, -0.001762},{
      0.395900, 0.378846, -0.007466},{0.399841, 0.384270, -0.007466},{
      0.403366, 0.384270, -0.001762}}],
    Polygon[{{0.395900, 0.389694, -0.007466},{0.399841, 0.384270, -0.007466},{
      0.395900, 0.378846, -0.007466},{0.389524, 0.380918, -0.007466},{
      0.389524, 0.387622, -0.007466}}],
    Polygon[{{1.767844, 0.265959, 0.163708},{1.628021, 0.311391, 0.163708},{
      1.541605, 0.192450, 0.163708},{1.628021, 0.073509, 0.163708},{
      1.767844, 0.118941, 0.163708}}],
    Polygon[{{1.767844, 0.265959, 0.163708},{1.767844, 0.118941, 0.163708},{
      1.830374, 0.073509, 0.038646},{1.869021, 0.192450, -0.038646},{
      1.830374, 0.311391, 0.038646}}],
    Polygon[{{1.767844, 0.265959, 0.163708},{1.830374, 0.311391, 0.038646},{
      1.729198, 0.384900, -0.038646},{1.604136, 0.384900, 0.038646},{
      1.628021, 0.311391, 0.163708}}],
    Polygon[{{1.628021, 0.311391, 0.163708},{1.604136, 0.384900, 0.038646},{
      1.502959, 0.311391, -0.038646},{1.464313, 0.192450, 0.038646},{
      1.541605, 0.192450, 0.163708}}],
    Polygon[{{1.541605, 0.192450, 0.163708},{1.464313, 0.192450, 0.038646},{
      1.502959, 0.073509, -0.038646},{1.604136, 0.000000, 0.038646},{
      1.628021, 0.073509, 0.163708}}],
    Polygon[{{1.628021, 0.073509, 0.163708},{1.767844, 0.118941, 0.163708},{
      1.830374, 0.073509, 0.038646},{1.729198, 0.000000, -0.038646},{
      1.604136, 0.000000, 0.038646}}],
    Polygon[{{1.830374, 0.311391, 0.038646},{1.869021, 0.192450, -0.038646},{
      1.791728, 0.192450, -0.163708},{1.705313, 0.311391, -0.163708},{
      1.729198, 0.384900, -0.038646}}],
    Polygon[{{1.604136, 0.384900, 0.038646},{1.729198, 0.384900, -0.038646},{
      1.705313, 0.311391, -0.163708},{1.565490, 0.265959, -0.163708},{
      1.502959, 0.311391, -0.038646}}],
    Polygon[{{1.464313, 0.192450, 0.038646},{1.502959, 0.311391, -0.038646},{
      1.565490, 0.265959, -0.163708},{1.565490, 0.118941, -0.163708},{
      1.502959, 0.073509, -0.038646}}],
    Polygon[{{1.604136, 0.000000, 0.038646},{1.502959, 0.073509, -0.038646},{
      1.565490, 0.118941, -0.163708},{1.705313, 0.073509, -0.163708},{
      1.729198, 0.000000, -0.038646}}],
    Polygon[{{1.830374, 0.073509, 0.038646},{1.729198, 0.000000, -0.038646},{
      1.705313, 0.073509, -0.163708},{1.791728, 0.192450, -0.163708},{
      1.869021, 0.192450, -0.038646}}],
    Polygon[{{1.705313, 0.311391, -0.163708},{1.791728, 0.192450, -0.163708},{
      1.705313, 0.073509, -0.163708},{1.565490, 0.118941, -0.163708},{
      1.565490, 0.265959, -0.163708}}],
    Polygon[{{1.922615, 0.088653, 0.054569},{1.876007, 0.103797, 0.054569},{
      1.847202, 0.064150, 0.054569},{1.876007, 0.024503, 0.054569},{
      1.922615, 0.039647, 0.054569}}],
    Polygon[{{1.922615, 0.088653, 0.054569},{1.922615, 0.039647, 0.054569},{
      1.943458, 0.024503, 0.012882},{1.956340, 0.064150, -0.012882},{
      1.943458, 0.103797, 0.012882}}],
    Polygon[{{1.922615, 0.088653, 0.054569},{1.943458, 0.103797, 0.012882},{
      1.909732, 0.128300, -0.012882},{1.868045, 0.128300, 0.012882},{
      1.876007, 0.103797, 0.054569}}],
    Polygon[{{1.876007, 0.103797, 0.054569},{1.868045, 0.128300, 0.012882},{
      1.834320, 0.103797, -0.012882},{1.821438, 0.064150, 0.012882},{
      1.847202, 0.064150, 0.054569}}],
    Polygon[{{1.847202, 0.064150, 0.054569},{1.821438, 0.064150, 0.012882},{
      1.834320, 0.024503, -0.012882},{1.868045, 0.000000, 0.012882},{
      1.876007, 0.024503, 0.054569}}],
    Polygon[{{1.876007, 0.024503, 0.054569},{1.922615, 0.039647, 0.054569},{
      1.943458, 0.024503, 0.012882},{1.909732, 0.000000, -0.012882},{
      1.868045, 0.000000, 0.012882}}],
    Polygon[{{1.943458, 0.103797, 0.012882},{1.956340, 0.064150, -0.012882},{
      1.930576, 0.064150, -0.054569},{1.901771, 0.103797, -0.054569},{
      1.909732, 0.128300, -0.012882}}],
    Polygon[{{1.868045, 0.128300, 0.012882},{1.909732, 0.128300, -0.012882},{
      1.901771, 0.103797, -0.054569},{1.855163, 0.088653, -0.054569},{
      1.834320, 0.103797, -0.012882}}],
    Polygon[{{1.821438, 0.064150, 0.012882},{1.834320, 0.103797, -0.012882},{
      1.855163, 0.088653, -0.054569},{1.855163, 0.039647, -0.054569},{
      1.834320, 0.024503, -0.012882}}],
    Polygon[{{1.868045, 0.000000, 0.012882},{1.834320, 0.024503, -0.012882},{
      1.855163, 0.039647, -0.054569},{1.901771, 0.024503, -0.054569},{
      1.909732, 0.000000, -0.012882}}],
    Polygon[{{1.943458, 0.024503, 0.012882},{1.909732, 0.000000, -0.012882},{
      1.901771, 0.024503, -0.054569},{1.930576, 0.064150, -0.054569},{
      1.956340, 0.064150, -0.012882}}],
    Polygon[{{1.901771, 0.103797, -0.054569},{1.930576, 0.064150, -0.054569},{
      1.901771, 0.024503, -0.054569},{1.855163, 0.039647, -0.054569},{
      1.855163, 0.088653, -0.054569}}],
    Polygon[{{1.974205, 0.029551, 0.018190},{1.958669, 0.034599, 0.018190},{
      1.949067, 0.021383, 0.018190},{1.958669, 0.008168, 0.018190},{
      1.974205, 0.013216, 0.018190}}],
    Polygon[{{1.974205, 0.029551, 0.018190},{1.974205, 0.013216, 0.018190},{
      1.981153, 0.008168, 0.004294},{1.985447, 0.021383, -0.004294},{
      1.981153, 0.034599, 0.004294}}],
    Polygon[{{1.974205, 0.029551, 0.018190},{1.981153, 0.034599, 0.004294},{
      1.969911, 0.042767, -0.004294},{1.956015, 0.042767, 0.004294},{
      1.958669, 0.034599, 0.018190}}],
    Polygon[{{1.958669, 0.034599, 0.018190},{1.956015, 0.042767, 0.004294},{
      1.944773, 0.034599, -0.004294},{1.940479, 0.021383, 0.004294},{
      1.949067, 0.021383, 0.018190}}],
    Polygon[{{1.949067, 0.021383, 0.018190},{1.940479, 0.021383, 0.004294},{
      1.944773, 0.008168, -0.004294},{1.956015, 0.000000, 0.004294},{
      1.958669, 0.008168, 0.018190}}],
    Polygon[{{1.958669, 0.008168, 0.018190},{1.974205, 0.013216, 0.018190},{
      1.981153, 0.008168, 0.004294},{1.969911, 0.000000, -0.004294},{
      1.956015, 0.000000, 0.004294}}],
    Polygon[{{1.981153, 0.034599, 0.004294},{1.985447, 0.021383, -0.004294},{
      1.976859, 0.021383, -0.018190},{1.967257, 0.034599, -0.018190},{
      1.969911, 0.042767, -0.004294}}],
    Polygon[{{1.956015, 0.042767, 0.004294},{1.969911, 0.042767, -0.004294},{
      1.967257, 0.034599, -0.018190},{1.951721, 0.029551, -0.018190},{
      1.944773, 0.034599, -0.004294}}],
    Polygon[{{1.940479, 0.021383, 0.004294},{1.944773, 0.034599, -0.004294},{
      1.951721, 0.029551, -0.018190},{1.951721, 0.013216, -0.018190},{
      1.944773, 0.008168, -0.004294}}],
    Polygon[{{1.956015, 0.000000, 0.004294},{1.944773, 0.008168, -0.004294},{
      1.951721, 0.013216, -0.018190},{1.967257, 0.008168, -0.018190},{
      1.969911, 0.000000, -0.004294}}],
    Polygon[{{1.981153, 0.008168, 0.004294},{1.969911, 0.000000, -0.004294},{
      1.967257, 0.008168, -0.018190},{1.976859, 0.021383, -0.018190},{
      1.985447, 0.021383, -0.004294}}],
    Polygon[{{1.967257, 0.034599, -0.018190},{1.976859, 0.021383, -0.018190},{
      1.967257, 0.008168, -0.018190},{1.951721, 0.013216, -0.018190},{
      1.951721, 0.029551, -0.018190}}],
    Polygon[{{1.991402, 0.009850, 0.006063},{1.986223, 0.011533, 0.006063},{
      1.983022, 0.007128, 0.006063},{1.986223, 0.002723, 0.006063},{
      1.991402, 0.004405, 0.006063}}],
    Polygon[{{1.991402, 0.009850, 0.006063},{1.991402, 0.004405, 0.006063},{
      1.993718, 0.002723, 0.001431},{1.995149, 0.007128, -0.001431},{
      1.993718, 0.011533, 0.001431}}],
    Polygon[{{1.991402, 0.009850, 0.006063},{1.993718, 0.011533, 0.001431},{
      1.989970, 0.014256, -0.001431},{1.985338, 0.014256, 0.001431},{
      1.986223, 0.011533, 0.006063}}],
    Polygon[{{1.986223, 0.011533, 0.006063},{1.985338, 0.014256, 0.001431},{
      1.981591, 0.011533, -0.001431},{1.980160, 0.007128, 0.001431},{
      1.983022, 0.007128, 0.006063}}],
    Polygon[{{1.983022, 0.007128, 0.006063},{1.980160, 0.007128, 0.001431},{
      1.981591, 0.002723, -0.001431},{1.985338, 0.000000, 0.001431},{
      1.986223, 0.002723, 0.006063}}],
    Polygon[{{1.986223, 0.002723, 0.006063},{1.991402, 0.004405, 0.006063},{
      1.993718, 0.002723, 0.001431},{1.989970, 0.000000, -0.001431},{
      1.985338, 0.000000, 0.001431}}],
    Polygon[{{1.993718, 0.011533, 0.001431},{1.995149, 0.007128, -0.001431},{
      1.992286, 0.007128, -0.006063},{1.989086, 0.011533, -0.006063},{
      1.989970, 0.014256, -0.001431}}],
    Polygon[{{1.985338, 0.014256, 0.001431},{1.989970, 0.014256, -0.001431},{
      1.989086, 0.011533, -0.006063},{1.983907, 0.009850, -0.006063},{
      1.981591, 0.011533, -0.001431}}],
    Polygon[{{1.980160, 0.007128, 0.001431},{1.981591, 0.011533, -0.001431},{
      1.983907, 0.009850, -0.006063},{1.983907, 0.004405, -0.006063},{
      1.981591, 0.002723, -0.001431}}],
    Polygon[{{1.985338, 0.000000, 0.001431},{1.981591, 0.002723, -0.001431},{
      1.983907, 0.004405, -0.006063},{1.989086, 0.002723, -0.006063},{
      1.989970, 0.000000, -0.001431}}],
    Polygon[{{1.993718, 0.002723, 0.001431},{1.989970, 0.000000, -0.001431},{
      1.989086, 0.002723, -0.006063},{1.992286, 0.007128, -0.006063},{
      1.995149, 0.007128, -0.001431}}],
    Polygon[{{1.989086, 0.011533, -0.006063},{1.992286, 0.007128, -0.006063},{
      1.989086, 0.002723, -0.006063},{1.983907, 0.004405, -0.006063},{
      1.983907, 0.009850, -0.006063}}],
    Polygon[{{1.940368, 0.011877, 0.007311},{1.934124, 0.013906, 0.007311},{
      1.930265, 0.008594, 0.007311},{1.934124, 0.003283, 0.007311},{
      1.940368, 0.005312, 0.007311}}],
    Polygon[{{1.940368, 0.011877, 0.007311},{1.940368, 0.005312, 0.007311},{
      1.943161, 0.003283, 0.001726},{1.944887, 0.008594, -0.001726},{
      1.943161, 0.013906, 0.001726}}],
    Polygon[{{1.940368, 0.011877, 0.007311},{1.943161, 0.013906, 0.001726},{
      1.938643, 0.017189, -0.001726},{1.933057, 0.017189, 0.001726},{
      1.934124, 0.013906, 0.007311}}],
    Polygon[{{1.934124, 0.013906, 0.007311},{1.933057, 0.017189, 0.001726},{
      1.928539, 0.013906, -0.001726},{1.926813, 0.008594, 0.001726},{
      1.930265, 0.008594, 0.007311}}],
    Polygon[{{1.930265, 0.008594, 0.007311},{1.926813, 0.008594, 0.001726},{
      1.928539, 0.003283, -0.001726},{1.933057, 0.000000, 0.001726},{
      1.934124, 0.003283, 0.007311}}],
    Polygon[{{1.934124, 0.003283, 0.007311},{1.940368, 0.005312, 0.007311},{
      1.943161, 0.003283, 0.001726},{1.938643, 0.000000, -0.001726},{
      1.933057, 0.000000, 0.001726}}],
    Polygon[{{1.943161, 0.013906, 0.001726},{1.944887, 0.008594, -0.001726},{
      1.941435, 0.008594, -0.007311},{1.937576, 0.013906, -0.007311},{
      1.938643, 0.017189, -0.001726}}],
    Polygon[{{1.933057, 0.017189, 0.001726},{1.938643, 0.017189, -0.001726},{
      1.937576, 0.013906, -0.007311},{1.931332, 0.011877, -0.007311},{
      1.928539, 0.013906, -0.001726}}],
    Polygon[{{1.926813, 0.008594, 0.001726},{1.928539, 0.013906, -0.001726},{
      1.931332, 0.011877, -0.007311},{1.931332, 0.005312, -0.007311},{
      1.928539, 0.003283, -0.001726}}],
    Polygon[{{1.933057, 0.000000, 0.001726},{1.928539, 0.003283, -0.001726},{
      1.931332, 0.005312, -0.007311},{1.937576, 0.003283, -0.007311},{
      1.938643, 0.000000, -0.001726}}],
    Polygon[{{1.943161, 0.003283, 0.001726},{1.938643, 0.000000, -0.001726},{
      1.937576, 0.003283, -0.007311},{1.941435, 0.008594, -0.007311},{
      1.944887, 0.008594, -0.001726}}],
    Polygon[{{1.937576, 0.013906, -0.007311},{1.941435, 0.008594, -0.007311},{
      1.937576, 0.003283, -0.007311},{1.931332, 0.005312, -0.007311},{
      1.931332, 0.011877, -0.007311}}],
    Polygon[{{1.965000, 0.054541, 0.007311},{1.958756, 0.056570, 0.007311},{
      1.954897, 0.051258, 0.007311},{1.958756, 0.045947, 0.007311},{
      1.965000, 0.047976, 0.007311}}],
    Polygon[{{1.965000, 0.054541, 0.007311},{1.965000, 0.047976, 0.007311},{
      1.967793, 0.045947, 0.001726},{1.969519, 0.051258, -0.001726},{
      1.967793, 0.056570, 0.001726}}],
    Polygon[{{1.965000, 0.054541, 0.007311},{1.967793, 0.056570, 0.001726},{
      1.963274, 0.059853, -0.001726},{1.957689, 0.059853, 0.001726},{
      1.958756, 0.056570, 0.007311}}],
    Polygon[{{1.958756, 0.056570, 0.007311},{1.957689, 0.059853, 0.001726},{
      1.953171, 0.056570, -0.001726},{1.951445, 0.051258, 0.001726},{
      1.954897, 0.051258, 0.007311}}],
    Polygon[{{1.954897, 0.051258, 0.007311},{1.951445, 0.051258, 0.001726},{
      1.953171, 0.045947, -0.001726},{1.957689, 0.042664, 0.001726},{
      1.958756, 0.045947, 0.007311}}],
    Polygon[{{1.958756, 0.045947, 0.007311},{1.965000, 0.047976, 0.007311},{
      1.967793, 0.045947, 0.001726},{1.963274, 0.042664, -0.001726},{
      1.957689, 0.042664, 0.001726}}],
    Polygon[{{1.967793, 0.056570, 0.001726},{1.969519, 0.051258, -0.001726},{
      1.966067, 0.051258, -0.007311},{1.962208, 0.056570, -0.007311},{
      1.963274, 0.059853, -0.001726}}],
    Polygon[{{1.957689, 0.059853, 0.001726},{1.963274, 0.059853, -0.001726},{
      1.962208, 0.056570, -0.007311},{1.955964, 0.054541, -0.007311},{
      1.953171, 0.056570, -0.001726}}],
    Polygon[{{1.951445, 0.051258, 0.001726},{1.953171, 0.056570, -0.001726},{
      1.955964, 0.054541, -0.007311},{1.955964, 0.047976, -0.007311},{
      1.953171, 0.045947, -0.001726}}],
    Polygon[{{1.957689, 0.042664, 0.001726},{1.953171, 0.045947, -0.001726},{
      1.955964, 0.047976, -0.007311},{1.962208, 0.045947, -0.007311},{
      1.963274, 0.042664, -0.001726}}],
    Polygon[{{1.967793, 0.045947, 0.001726},{1.963274, 0.042664, -0.001726},{
      1.962208, 0.045947, -0.007311},{1.966067, 0.051258, -0.007311},{
      1.969519, 0.051258, -0.001726}}],
    Polygon[{{1.962208, 0.056570, -0.007311},{1.966067, 0.051258, -0.007311},{
      1.962208, 0.045947, -0.007311},{1.955964, 0.047976, -0.007311},{
      1.955964, 0.054541, -0.007311}}],
    Polygon[{{1.821105, 0.035632, 0.021933},{1.802372, 0.041718, 0.021933},{
      1.790795, 0.025783, 0.021933},{1.802372, 0.009848, 0.021933},{
      1.821105, 0.015935, 0.021933}}],
    Polygon[{{1.821105, 0.035632, 0.021933},{1.821105, 0.015935, 0.021933},{
      1.829483, 0.009848, 0.005178},{1.834660, 0.025783, -0.005178},{
      1.829483, 0.041718, 0.005178}}],
    Polygon[{{1.821105, 0.035632, 0.021933},{1.829483, 0.041718, 0.005178},{
      1.815928, 0.051567, -0.005178},{1.799172, 0.051567, 0.005178},{
      1.802372, 0.041718, 0.021933}}],
    Polygon[{{1.802372, 0.041718, 0.021933},{1.799172, 0.051567, 0.005178},{
      1.785617, 0.041718, -0.005178},{1.780440, 0.025783, 0.005178},{
      1.790795, 0.025783, 0.021933}}],
    Polygon[{{1.790795, 0.025783, 0.021933},{1.780440, 0.025783, 0.005178},{
      1.785617, 0.009848, -0.005178},{1.799172, 0.000000, 0.005178},{
      1.802372, 0.009848, 0.021933}}],
    Polygon[{{1.802372, 0.009848, 0.021933},{1.821105, 0.015935, 0.021933},{
      1.829483, 0.009848, 0.005178},{1.815928, 0.000000, -0.005178},{
      1.799172, 0.000000, 0.005178}}],
    Polygon[{{1.829483, 0.041718, 0.005178},{1.834660, 0.025783, -0.005178},{
      1.824305, 0.025783, -0.021933},{1.812728, 0.041718, -0.021933},{
      1.815928, 0.051567, -0.005178}}],
    Polygon[{{1.799172, 0.051567, 0.005178},{1.815928, 0.051567, -0.005178},{
      1.812728, 0.041718, -0.021933},{1.793995, 0.035632, -0.021933},{
      1.785617, 0.041718, -0.005178}}],
    Polygon[{{1.780440, 0.025783, 0.005178},{1.785617, 0.041718, -0.005178},{
      1.793995, 0.035632, -0.021933},{1.793995, 0.015935, -0.021933},{
      1.785617, 0.009848, -0.005178}}],
    Polygon[{{1.799172, 0.000000, 0.005178},{1.785617, 0.009848, -0.005178},{
      1.793995, 0.015935, -0.021933},{1.812728, 0.009848, -0.021933},{
      1.815928, 0.000000, -0.005178}}],
    Polygon[{{1.829483, 0.009848, 0.005178},{1.815928, 0.000000, -0.005178},{
      1.812728, 0.009848, -0.021933},{1.824305, 0.025783, -0.021933},{
      1.834660, 0.025783, -0.005178}}],
    Polygon[{{1.812728, 0.041718, -0.021933},{1.824305, 0.025783, -0.021933},{
      1.812728, 0.009848, -0.021933},{1.793995, 0.015935, -0.021933},{
      1.793995, 0.035632, -0.021933}}],
    Polygon[{{1.777065, 0.019095, 0.011754},{1.767026, 0.022357, 0.011754},{
      1.760821, 0.013817, 0.011754},{1.767026, 0.005278, 0.011754},{
      1.777065, 0.008540, 0.011754}}],
    Polygon[{{1.777065, 0.019095, 0.011754},{1.777065, 0.008540, 0.011754},{
      1.781554, 0.005278, 0.002775},{1.784329, 0.013817, -0.002775},{
      1.781554, 0.022357, 0.002775}}],
    Polygon[{{1.777065, 0.019095, 0.011754},{1.781554, 0.022357, 0.002775},{
      1.774290, 0.027635, -0.002775},{1.765311, 0.027635, 0.002775},{
      1.767026, 0.022357, 0.011754}}],
    Polygon[{{1.767026, 0.022357, 0.011754},{1.765311, 0.027635, 0.002775},{
      1.758047, 0.022357, -0.002775},{1.755272, 0.013817, 0.002775},{
      1.760821, 0.013817, 0.011754}}],
    Polygon[{{1.760821, 0.013817, 0.011754},{1.755272, 0.013817, 0.002775},{
      1.758047, 0.005278, -0.002775},{1.765311, 0.000000, 0.002775},{
      1.767026, 0.005278, 0.011754}}],
    Polygon[{{1.767026, 0.005278, 0.011754},{1.777065, 0.008540, 0.011754},{
      1.781554, 0.005278, 0.002775},{1.774290, 0.000000, -0.002775},{
      1.765311, 0.000000, 0.002775}}],
    Polygon[{{1.781554, 0.022357, 0.002775},{1.784329, 0.013817, -0.002775},{
      1.778779, 0.013817, -0.011754},{1.772575, 0.022357, -0.011754},{
      1.774290, 0.027635, -0.002775}}],
    Polygon[{{1.765311, 0.027635, 0.002775},{1.774290, 0.027635, -0.002775},{
      1.772575, 0.022357, -0.011754},{1.762536, 0.019095, -0.011754},{
      1.758047, 0.022357, -0.002775}}],
    Polygon[{{1.755272, 0.013817, 0.002775},{1.758047, 0.022357, -0.002775},{
      1.762536, 0.019095, -0.011754},{1.762536, 0.008540, -0.011754},{
      1.758047, 0.005278, -0.002775}}],
    Polygon[{{1.765311, 0.000000, 0.002775},{1.758047, 0.005278, -0.002775},{
      1.762536, 0.008540, -0.011754},{1.772575, 0.005278, -0.011754},{
      1.774290, 0.000000, -0.002775}}],
    Polygon[{{1.781554, 0.005278, 0.002775},{1.774290, 0.000000, -0.002775},{
      1.772575, 0.005278, -0.011754},{1.778779, 0.013817, -0.011754},{
      1.784329, 0.013817, -0.002775}}],
    Polygon[{{1.772575, 0.022357, -0.011754},{1.778779, 0.013817, -0.011754},{
      1.772575, 0.005278, -0.011754},{1.762536, 0.008540, -0.011754},{
      1.762536, 0.019095, -0.011754}}],
    Polygon[{{1.844186, 0.013346, 0.008215},{1.837170, 0.015626, 0.008215},{
      1.832833, 0.009657, 0.008215},{1.837170, 0.003689, 0.008215},{
      1.844186, 0.005968, 0.008215}}],
    Polygon[{{1.844186, 0.013346, 0.008215},{1.844186, 0.005968, 0.008215},{
      1.847324, 0.003689, 0.001939},{1.849263, 0.009657, -0.001939},{
      1.847324, 0.015626, 0.001939}}],
    Polygon[{{1.844186, 0.013346, 0.008215},{1.847324, 0.015626, 0.001939},{
      1.842247, 0.019314, -0.001939},{1.835971, 0.019314, 0.001939},{
      1.837170, 0.015626, 0.008215}}],
    Polygon[{{1.837170, 0.015626, 0.008215},{1.835971, 0.019314, 0.001939},{
      1.830894, 0.015626, -0.001939},{1.828955, 0.009657, 0.001939},{
      1.832833, 0.009657, 0.008215}}],
    Polygon[{{1.832833, 0.009657, 0.008215},{1.828955, 0.009657, 0.001939},{
      1.830894, 0.003689, -0.001939},{1.835971, 0.000000, 0.001939},{
      1.837170, 0.003689, 0.008215}}],
    Polygon[{{1.837170, 0.003689, 0.008215},{1.844186, 0.005968, 0.008215},{
      1.847324, 0.003689, 0.001939},{1.842247, 0.000000, -0.001939},{
      1.835971, 0.000000, 0.001939}}],
    Polygon[{{1.847324, 0.015626, 0.001939},{1.849263, 0.009657, -0.001939},{
      1.845385, 0.009657, -0.008215},{1.841048, 0.015626, -0.008215},{
      1.842247, 0.019314, -0.001939}}],
    Polygon[{{1.835971, 0.019314, 0.001939},{1.842247, 0.019314, -0.001939},{
      1.841048, 0.015626, -0.008215},{1.834032, 0.013346, -0.008215},{
      1.830894, 0.015626, -0.001939}}],
    Polygon[{{1.828955, 0.009657, 0.001939},{1.830894, 0.015626, -0.001939},{
      1.834032, 0.013346, -0.008215},{1.834032, 0.005968, -0.008215},{
      1.830894, 0.003689, -0.001939}}],
    Polygon[{{1.835971, 0.000000, 0.001939},{1.830894, 0.003689, -0.001939},{
      1.834032, 0.005968, -0.008215},{1.841048, 0.003689, -0.008215},{
      1.842247, 0.000000, -0.001939}}],
    Polygon[{{1.847324, 0.003689, 0.001939},{1.842247, 0.000000, -0.001939},{
      1.841048, 0.003689, -0.008215},{1.845385, 0.009657, -0.008215},{
      1.849263, 0.009657, -0.001939}}],
    Polygon[{{1.841048, 0.015626, -0.008215},{1.845385, 0.009657, -0.008215},{
      1.841048, 0.003689, -0.008215},{1.834032, 0.005968, -0.008215},{
      1.834032, 0.013346, -0.008215}}],
    Polygon[{{1.820959, 0.061961, 0.007140},{1.814861, 0.063943, 0.007140},{
      1.811092, 0.058755, 0.007140},{1.814861, 0.053568, 0.007140},{
      1.820959, 0.055549, 0.007140}}],
    Polygon[{{1.820959, 0.061961, 0.007140},{1.820959, 0.055549, 0.007140},{
      1.823686, 0.053568, 0.001686},{1.825372, 0.058755, -0.001686},{
      1.823686, 0.063943, 0.001686}}],
    Polygon[{{1.820959, 0.061961, 0.007140},{1.823686, 0.063943, 0.001686},{
      1.819273, 0.067149, -0.001686},{1.813819, 0.067149, 0.001686},{
      1.814861, 0.063943, 0.007140}}],
    Polygon[{{1.814861, 0.063943, 0.007140},{1.813819, 0.067149, 0.001686},{
      1.809406, 0.063943, -0.001686},{1.807721, 0.058755, 0.001686},{
      1.811092, 0.058755, 0.007140}}],
    Polygon[{{1.811092, 0.058755, 0.007140},{1.807721, 0.058755, 0.001686},{
      1.809406, 0.053568, -0.001686},{1.813819, 0.050362, 0.001686},{
      1.814861, 0.053568, 0.007140}}],
    Polygon[{{1.814861, 0.053568, 0.007140},{1.820959, 0.055549, 0.007140},{
      1.823686, 0.053568, 0.001686},{1.819273, 0.050362, -0.001686},{
      1.813819, 0.050362, 0.001686}}],
    Polygon[{{1.823686, 0.063943, 0.001686},{1.825372, 0.058755, -0.001686},{
      1.822001, 0.058755, -0.007140},{1.818232, 0.063943, -0.007140},{
      1.819273, 0.067149, -0.001686}}],
    Polygon[{{1.813819, 0.067149, 0.001686},{1.819273, 0.067149, -0.001686},{
      1.818232, 0.063943, -0.007140},{1.812133, 0.061961, -0.007140},{
      1.809406, 0.063943, -0.001686}}],
    Polygon[{{1.807721, 0.058755, 0.001686},{1.809406, 0.063943, -0.001686},{
      1.812133, 0.061961, -0.007140},{1.812133, 0.055549, -0.007140},{
      1.809406, 0.053568, -0.001686}}],
    Polygon[{{1.813819, 0.050362, 0.001686},{1.809406, 0.053568, -0.001686},{
      1.812133, 0.055549, -0.007140},{1.818232, 0.053568, -0.007140},{
      1.819273, 0.050362, -0.001686}}],
    Polygon[{{1.823686, 0.053568, 0.001686},{1.819273, 0.050362, -0.001686},{
      1.818232, 0.053568, -0.007140},{1.822001, 0.058755, -0.007140},{
      1.825372, 0.058755, -0.001686}}],
    Polygon[{{1.818232, 0.063943, -0.007140},{1.822001, 0.058755, -0.007140},{
      1.818232, 0.053568, -0.007140},{1.812133, 0.055549, -0.007140},{
      1.812133, 0.061961, -0.007140}}],
    Polygon[{{1.895001, 0.163623, 0.021933},{1.876268, 0.169710, 0.021933},{
      1.864691, 0.153775, 0.021933},{1.876268, 0.137840, 0.021933},{
      1.895001, 0.143927, 0.021933}}],
    Polygon[{{1.895001, 0.163623, 0.021933},{1.895001, 0.143927, 0.021933},{
      1.903378, 0.137840, 0.005178},{1.908556, 0.153775, -0.005178},{
      1.903378, 0.169710, 0.005178}}],
    Polygon[{{1.895001, 0.163623, 0.021933},{1.903378, 0.169710, 0.005178},{
      1.889823, 0.179558, -0.005178},{1.873068, 0.179558, 0.005178},{
      1.876268, 0.169710, 0.021933}}],
    Polygon[{{1.876268, 0.169710, 0.021933},{1.873068, 0.179558, 0.005178},{
      1.859513, 0.169710, -0.005178},{1.854336, 0.153775, 0.005178},{
      1.864691, 0.153775, 0.021933}}],
    Polygon[{{1.864691, 0.153775, 0.021933},{1.854336, 0.153775, 0.005178},{
      1.859513, 0.137840, -0.005178},{1.873068, 0.127992, 0.005178},{
      1.876268, 0.137840, 0.021933}}],
    Polygon[{{1.876268, 0.137840, 0.021933},{1.895001, 0.143927, 0.021933},{
      1.903378, 0.137840, 0.005178},{1.889823, 0.127992, -0.005178},{
      1.873068, 0.127992, 0.005178}}],
    Polygon[{{1.903378, 0.169710, 0.005178},{1.908556, 0.153775, -0.005178},{
      1.898201, 0.153775, -0.021933},{1.886624, 0.169710, -0.021933},{
      1.889823, 0.179558, -0.005178}}],
    Polygon[{{1.873068, 0.179558, 0.005178},{1.889823, 0.179558, -0.005178},{
      1.886624, 0.169710, -0.021933},{1.867891, 0.163623, -0.021933},{
      1.859513, 0.169710, -0.005178}}],
    Polygon[{{1.854336, 0.153775, 0.005178},{1.859513, 0.169710, -0.005178},{
      1.867891, 0.163623, -0.021933},{1.867891, 0.143927, -0.021933},{
      1.859513, 0.137840, -0.005178}}],
    Polygon[{{1.873068, 0.127992, 0.005178},{1.859513, 0.137840, -0.005178},{
      1.867891, 0.143927, -0.021933},{1.886624, 0.137840, -0.021933},{
      1.889823, 0.127992, -0.005178}}],
    Polygon[{{1.903378, 0.137840, 0.005178},{1.889823, 0.127992, -0.005178},{
      1.886624, 0.137840, -0.021933},{1.898201, 0.153775, -0.021933},{
      1.908556, 0.153775, -0.005178}}],
    Polygon[{{1.886624, 0.169710, -0.021933},{1.898201, 0.153775, -0.021933},{
      1.886624, 0.137840, -0.021933},{1.867891, 0.143927, -0.021933},{
      1.867891, 0.163623, -0.021933}}],
    Polygon[{{1.880198, 0.197728, 0.011754},{1.870159, 0.200990, 0.011754},{
      1.863955, 0.192450, 0.011754},{1.870159, 0.183911, 0.011754},{
      1.880198, 0.187172, 0.011754}}],
    Polygon[{{1.880198, 0.197728, 0.011754},{1.880198, 0.187172, 0.011754},{
      1.884688, 0.183911, 0.002775},{1.887462, 0.192450, -0.002775},{
      1.884688, 0.200990, 0.002775}}],
    Polygon[{{1.880198, 0.197728, 0.011754},{1.884688, 0.200990, 0.002775},{
      1.877424, 0.206267, -0.002775},{1.868445, 0.206267, 0.002775},{
      1.870159, 0.200990, 0.011754}}],
    Polygon[{{1.870159, 0.200990, 0.011754},{1.868445, 0.206267, 0.002775},{
      1.861180, 0.200990, -0.002775},{1.858406, 0.192450, 0.002775},{
      1.863955, 0.192450, 0.011754}}],
    Polygon[{{1.863955, 0.192450, 0.011754},{1.858406, 0.192450, 0.002775},{
      1.861180, 0.183911, -0.002775},{1.868445, 0.178633, 0.002775},{
      1.870159, 0.183911, 0.011754}}],
    Polygon[{{1.870159, 0.183911, 0.011754},{1.880198, 0.187172, 0.011754},{
      1.884688, 0.183911, 0.002775},{1.877424, 0.178633, -0.002775},{
      1.868445, 0.178633, 0.002775}}],
    Polygon[{{1.884688, 0.200990, 0.002775},{1.887462, 0.192450, -0.002775},{
      1.881913, 0.192450, -0.011754},{1.875709, 0.200990, -0.011754},{
      1.877424, 0.206267, -0.002775}}],
    Polygon[{{1.868445, 0.206267, 0.002775},{1.877424, 0.206267, -0.002775},{
      1.875709, 0.200990, -0.011754},{1.865670, 0.197728, -0.011754},{
      1.861180, 0.200990, -0.002775}}],
    Polygon[{{1.858406, 0.192450, 0.002775},{1.861180, 0.200990, -0.002775},{
      1.865670, 0.197728, -0.011754},{1.865670, 0.187172, -0.011754},{
      1.861180, 0.183911, -0.002775}}],
    Polygon[{{1.868445, 0.178633, 0.002775},{1.861180, 0.183911, -0.002775},{
      1.865670, 0.187172, -0.011754},{1.875709, 0.183911, -0.011754},{
      1.877424, 0.178633, -0.002775}}],
    Polygon[{{1.884688, 0.183911, 0.002775},{1.877424, 0.178633, -0.002775},{
      1.875709, 0.183911, -0.011754},{1.881913, 0.192450, -0.011754},{
      1.887462, 0.192450, -0.002775}}],
    Polygon[{{1.875709, 0.200990, -0.011754},{1.881913, 0.192450, -0.011754},{
      1.875709, 0.183911, -0.011754},{1.865670, 0.187172, -0.011754},{
      1.865670, 0.197728, -0.011754}}],
    Polygon[{{1.916268, 0.138196, 0.008215},{1.909252, 0.140476, 0.008215},{
      1.904916, 0.134507, 0.008215},{1.909252, 0.128539, 0.008215},{
      1.916268, 0.130818, 0.008215}}],
    Polygon[{{1.916268, 0.138196, 0.008215},{1.916268, 0.130818, 0.008215},{
      1.919406, 0.128539, 0.001939},{1.921345, 0.134507, -0.001939},{
      1.919406, 0.140476, 0.001939}}],
    Polygon[{{1.916268, 0.138196, 0.008215},{1.919406, 0.140476, 0.001939},{
      1.914329, 0.144164, -0.001939},{1.908053, 0.144164, 0.001939},{
      1.909252, 0.140476, 0.008215}}],
    Polygon[{{1.909252, 0.140476, 0.008215},{1.908053, 0.144164, 0.001939},{
      1.902976, 0.140476, -0.001939},{1.901037, 0.134507, 0.001939},{
      1.904916, 0.134507, 0.008215}}],
    Polygon[{{1.904916, 0.134507, 0.008215},{1.901037, 0.134507, 0.001939},{
      1.902976, 0.128539, -0.001939},{1.908053, 0.124850, 0.001939},{
      1.909252, 0.128539, 0.008215}}],
    Polygon[{{1.909252, 0.128539, 0.008215},{1.916268, 0.130818, 0.008215},{
      1.919406, 0.128539, 0.001939},{1.914329, 0.124850, -0.001939},{
      1.908053, 0.124850, 0.001939}}],
    Polygon[{{1.919406, 0.140476, 0.001939},{1.921345, 0.134507, -0.001939},{
      1.917467, 0.134507, -0.008215},{1.913130, 0.140476, -0.008215},{
      1.914329, 0.144164, -0.001939}}],
    Polygon[{{1.908053, 0.144164, 0.001939},{1.914329, 0.144164, -0.001939},{
      1.913130, 0.140476, -0.008215},{1.906114, 0.138196, -0.008215},{
      1.902976, 0.140476, -0.001939}}],
    Polygon[{{1.901037, 0.134507, 0.001939},{1.902976, 0.140476, -0.001939},{
      1.906114, 0.138196, -0.008215},{1.906114, 0.130818, -0.008215},{
      1.902976, 0.128539, -0.001939}}],
    Polygon[{{1.908053, 0.124850, 0.001939},{1.902976, 0.128539, -0.001939},{
      1.906114, 0.130818, -0.008215},{1.913130, 0.128539, -0.008215},{
      1.914329, 0.124850, -0.001939}}],
    Polygon[{{1.919406, 0.128539, 0.001939},{1.914329, 0.124850, -0.001939},{
      1.913130, 0.128539, -0.008215},{1.917467, 0.134507, -0.008215},{
      1.921345, 0.134507, -0.001939}}],
    Polygon[{{1.913130, 0.140476, -0.008215},{1.917467, 0.134507, -0.008215},{
      1.913130, 0.128539, -0.008215},{1.906114, 0.130818, -0.008215},{
      1.906114, 0.138196, -0.008215}}],
    Polygon[{{1.861802, 0.132704, 0.007140},{1.855704, 0.134686, 0.007140},{
      1.851935, 0.129498, 0.007140},{1.855704, 0.124311, 0.007140},{
      1.861802, 0.126292, 0.007140}}],
    Polygon[{{1.861802, 0.132704, 0.007140},{1.861802, 0.126292, 0.007140},{
      1.864530, 0.124311, 0.001686},{1.866215, 0.129498, -0.001686},{
      1.864530, 0.134686, 0.001686}}],
    Polygon[{{1.861802, 0.132704, 0.007140},{1.864530, 0.134686, 0.001686},{
      1.860117, 0.137892, -0.001686},{1.854662, 0.137892, 0.001686},{
      1.855704, 0.134686, 0.007140}}],
    Polygon[{{1.855704, 0.134686, 0.007140},{1.854662, 0.137892, 0.001686},{
      1.850250, 0.134686, -0.001686},{1.848564, 0.129498, 0.001686},{
      1.851935, 0.129498, 0.007140}}],
    Polygon[{{1.851935, 0.129498, 0.007140},{1.848564, 0.129498, 0.001686},{
      1.850250, 0.124311, -0.001686},{1.854662, 0.121105, 0.001686},{
      1.855704, 0.124311, 0.007140}}],
    Polygon[{{1.855704, 0.124311, 0.007140},{1.861802, 0.126292, 0.007140},{
      1.864530, 0.124311, 0.001686},{1.860117, 0.121105, -0.001686},{
      1.854662, 0.121105, 0.001686}}],
    Polygon[{{1.864530, 0.134686, 0.001686},{1.866215, 0.129498, -0.001686},{
      1.862844, 0.129498, -0.007140},{1.859075, 0.134686, -0.007140},{
      1.860117, 0.137892, -0.001686}}],
    Polygon[{{1.854662, 0.137892, 0.001686},{1.860117, 0.137892, -0.001686},{
      1.859075, 0.134686, -0.007140},{1.852977, 0.132704, -0.007140},{
      1.850250, 0.134686, -0.001686}}],
    Polygon[{{1.848564, 0.129498, 0.001686},{1.850250, 0.134686, -0.001686},{
      1.852977, 0.132704, -0.007140},{1.852977, 0.126292, -0.007140},{
      1.850250, 0.124311, -0.001686}}],
    Polygon[{{1.854662, 0.121105, 0.001686},{1.850250, 0.124311, -0.001686},{
      1.852977, 0.126292, -0.007140},{1.859075, 0.124311, -0.007140},{
      1.860117, 0.121105, -0.001686}}],
    Polygon[{{1.864530, 0.124311, 0.001686},{1.860117, 0.121105, -0.001686},{
      1.859075, 0.124311, -0.007140},{1.862844, 0.129498, -0.007140},{
      1.866215, 0.129498, -0.001686}}],
    Polygon[{{1.859075, 0.134686, -0.007140},{1.862844, 0.129498, -0.007140},{
      1.859075, 0.124311, -0.007140},{1.852977, 0.126292, -0.007140},{
      1.852977, 0.132704, -0.007140}}],
    Polygon[{{1.463315, 0.106895, 0.065798},{1.407117, 0.125155, 0.065798},{
      1.372384, 0.077350, 0.065798},{1.407117, 0.029545, 0.065798},{
      1.463315, 0.047805, 0.065798}}],
    Polygon[{{1.463315, 0.106895, 0.065798},{1.463315, 0.047805, 0.065798},{
      1.488448, 0.029545, 0.015533},{1.503981, 0.077350, -0.015533},{
      1.488448, 0.125155, 0.015533}}],
    Polygon[{{1.463315, 0.106895, 0.065798},{1.488448, 0.125155, 0.015533},{
      1.447782, 0.154701, -0.015533},{1.397517, 0.154701, 0.015533},{
      1.407117, 0.125155, 0.065798}}],
    Polygon[{{1.407117, 0.125155, 0.065798},{1.397517, 0.154701, 0.015533},{
      1.356852, 0.125155, -0.015533},{1.341319, 0.077350, 0.015533},{
      1.372384, 0.077350, 0.065798}}],
    Polygon[{{1.372384, 0.077350, 0.065798},{1.341319, 0.077350, 0.015533},{
      1.356852, 0.029545, -0.015533},{1.397517, 0.000000, 0.015533},{
      1.407117, 0.029545, 0.065798}}],
    Polygon[{{1.407117, 0.029545, 0.065798},{1.463315, 0.047805, 0.065798},{
      1.488448, 0.029545, 0.015533},{1.447782, 0.000000, -0.015533},{
      1.397517, 0.000000, 0.015533}}],
    Polygon[{{1.488448, 0.125155, 0.015533},{1.503981, 0.077350, -0.015533},{
      1.472915, 0.077350, -0.065798},{1.438183, 0.125155, -0.065798},{
      1.447782, 0.154701, -0.015533}}],
    Polygon[{{1.397517, 0.154701, 0.015533},{1.447782, 0.154701, -0.015533},{
      1.438183, 0.125155, -0.065798},{1.381984, 0.106895, -0.065798},{
      1.356852, 0.125155, -0.015533}}],
    Polygon[{{1.341319, 0.077350, 0.015533},{1.356852, 0.125155, -0.015533},{
      1.381984, 0.106895, -0.065798},{1.381984, 0.047805, -0.065798},{
      1.356852, 0.029545, -0.015533}}],
    Polygon[{{1.397517, 0.000000, 0.015533},{1.356852, 0.029545, -0.015533},{
      1.381984, 0.047805, -0.065798},{1.438183, 0.029545, -0.065798},{
      1.447782, 0.000000, -0.015533}}],
    Polygon[{{1.488448, 0.029545, 0.015533},{1.447782, 0.000000, -0.015533},{
      1.438183, 0.029545, -0.065798},{1.472915, 0.077350, -0.065798},{
      1.503981, 0.077350, -0.015533}}],
    Polygon[{{1.438183, 0.125155, -0.065798},{1.472915, 0.077350, -0.065798},{
      1.438183, 0.029545, -0.065798},{1.381984, 0.047805, -0.065798},{
      1.381984, 0.106895, -0.065798}}],
    Polygon[{{1.331194, 0.057285, 0.035261},{1.301077, 0.067071, 0.035261},{
      1.282464, 0.041452, 0.035261},{1.301077, 0.015833, 0.035261},{
      1.331194, 0.025619, 0.035261}}],
    Polygon[{{1.331194, 0.057285, 0.035261},{1.331194, 0.025619, 0.035261},{
      1.344662, 0.015833, 0.008324},{1.352986, 0.041452, -0.008324},{
      1.344662, 0.067071, 0.008324}}],
    Polygon[{{1.331194, 0.057285, 0.035261},{1.344662, 0.067071, 0.008324},{
      1.322870, 0.082904, -0.008324},{1.295933, 0.082904, 0.008324},{
      1.301077, 0.067071, 0.035261}}],
    Polygon[{{1.301077, 0.067071, 0.035261},{1.295933, 0.082904, 0.008324},{
      1.274140, 0.067071, -0.008324},{1.265816, 0.041452, 0.008324},{
      1.282464, 0.041452, 0.035261}}],
    Polygon[{{1.282464, 0.041452, 0.035261},{1.265816, 0.041452, 0.008324},{
      1.274140, 0.015833, -0.008324},{1.295933, 0.000000, 0.008324},{
      1.301077, 0.015833, 0.035261}}],
    Polygon[{{1.301077, 0.015833, 0.035261},{1.331194, 0.025619, 0.035261},{
      1.344662, 0.015833, 0.008324},{1.322870, 0.000000, -0.008324},{
      1.295933, 0.000000, 0.008324}}],
    Polygon[{{1.344662, 0.067071, 0.008324},{1.352986, 0.041452, -0.008324},{
      1.336338, 0.041452, -0.035261},{1.317725, 0.067071, -0.035261},{
      1.322870, 0.082904, -0.008324}}],
    Polygon[{{1.295933, 0.082904, 0.008324},{1.322870, 0.082904, -0.008324},{
      1.317725, 0.067071, -0.035261},{1.287609, 0.057285, -0.035261},{
      1.274140, 0.067071, -0.008324}}],
    Polygon[{{1.265816, 0.041452, 0.008324},{1.274140, 0.067071, -0.008324},{
      1.287609, 0.057285, -0.035261},{1.287609, 0.025619, -0.035261},{
      1.274140, 0.015833, -0.008324}}],
    Polygon[{{1.295933, 0.000000, 0.008324},{1.274140, 0.015833, -0.008324},{
      1.287609, 0.025619, -0.035261},{1.317725, 0.015833, -0.035261},{
      1.322870, 0.000000, -0.008324}}],
    Polygon[{{1.344662, 0.015833, 0.008324},{1.322870, 0.000000, -0.008324},{
      1.317725, 0.015833, -0.035261},{1.336338, 0.041452, -0.035261},{
      1.352986, 0.041452, -0.008324}}],
    Polygon[{{1.317725, 0.067071, -0.035261},{1.336338, 0.041452, -0.035261},{
      1.317725, 0.015833, -0.035261},{1.287609, 0.025619, -0.035261},{
      1.287609, 0.057285, -0.035261}}],
    Polygon[{{1.257572, 0.035632, 0.021933},{1.238839, 0.041718, 0.021933},{
      1.227262, 0.025783, 0.021933},{1.238839, 0.009848, 0.021933},{
      1.257572, 0.015935, 0.021933}}],
    Polygon[{{1.257572, 0.035632, 0.021933},{1.257572, 0.015935, 0.021933},{
      1.265950, 0.009848, 0.005178},{1.271127, 0.025783, -0.005178},{
      1.265950, 0.041718, 0.005178}}],
    Polygon[{{1.257572, 0.035632, 0.021933},{1.265950, 0.041718, 0.005178},{
      1.252394, 0.051567, -0.005178},{1.235639, 0.051567, 0.005178},{
      1.238839, 0.041718, 0.021933}}],
    Polygon[{{1.238839, 0.041718, 0.021933},{1.235639, 0.051567, 0.005178},{
      1.222084, 0.041718, -0.005178},{1.216907, 0.025783, 0.005178},{
      1.227262, 0.025783, 0.021933}}],
    Polygon[{{1.227262, 0.025783, 0.021933},{1.216907, 0.025783, 0.005178},{
      1.222084, 0.009848, -0.005178},{1.235639, 0.000000, 0.005178},{
      1.238839, 0.009848, 0.021933}}],
    Polygon[{{1.238839, 0.009848, 0.021933},{1.257572, 0.015935, 0.021933},{
      1.265950, 0.009848, 0.005178},{1.252394, 0.000000, -0.005178},{
      1.235639, 0.000000, 0.005178}}],
    Polygon[{{1.265950, 0.041718, 0.005178},{1.271127, 0.025783, -0.005178},{
      1.260772, 0.025783, -0.021933},{1.249195, 0.041718, -0.021933},{
      1.252394, 0.051567, -0.005178}}],
    Polygon[{{1.235639, 0.051567, 0.005178},{1.252394, 0.051567, -0.005178},{
      1.249195, 0.041718, -0.021933},{1.230462, 0.035632, -0.021933},{
      1.222084, 0.041718, -0.005178}}],
    Polygon[{{1.216907, 0.025783, 0.005178},{1.222084, 0.041718, -0.005178},{
      1.230462, 0.035632, -0.021933},{1.230462, 0.015935, -0.021933},{
      1.222084, 0.009848, -0.005178}}],
    Polygon[{{1.235639, 0.000000, 0.005178},{1.222084, 0.009848, -0.005178},{
      1.230462, 0.015935, -0.021933},{1.249195, 0.009848, -0.021933},{
      1.252394, 0.000000, -0.005178}}],
    Polygon[{{1.265950, 0.009848, 0.005178},{1.252394, 0.000000, -0.005178},{
      1.249195, 0.009848, -0.021933},{1.260772, 0.025783, -0.021933},{
      1.271127, 0.025783, -0.005178}}],
    Polygon[{{1.249195, 0.041718, -0.021933},{1.260772, 0.025783, -0.021933},{
      1.249195, 0.009848, -0.021933},{1.230462, 0.015935, -0.021933},{
      1.230462, 0.035632, -0.021933}}],
    Polygon[{{1.364530, 0.019095, 0.011754},{1.354491, 0.022357, 0.011754},{
      1.348287, 0.013817, 0.011754},{1.354491, 0.005278, 0.011754},{
      1.364530, 0.008540, 0.011754}}],
    Polygon[{{1.364530, 0.019095, 0.011754},{1.364530, 0.008540, 0.011754},{
      1.369019, 0.005278, 0.002775},{1.371794, 0.013817, -0.002775},{
      1.369019, 0.022357, 0.002775}}],
    Polygon[{{1.364530, 0.019095, 0.011754},{1.369019, 0.022357, 0.002775},{
      1.361755, 0.027635, -0.002775},{1.352776, 0.027635, 0.002775},{
      1.354491, 0.022357, 0.011754}}],
    Polygon[{{1.354491, 0.022357, 0.011754},{1.352776, 0.027635, 0.002775},{
      1.345512, 0.022357, -0.002775},{1.342737, 0.013817, 0.002775},{
      1.348287, 0.013817, 0.011754}}],
    Polygon[{{1.348287, 0.013817, 0.011754},{1.342737, 0.013817, 0.002775},{
      1.345512, 0.005278, -0.002775},{1.352776, 0.000000, 0.002775},{
      1.354491, 0.005278, 0.011754}}],
    Polygon[{{1.354491, 0.005278, 0.011754},{1.364530, 0.008540, 0.011754},{
      1.369019, 0.005278, 0.002775},{1.361755, 0.000000, -0.002775},{
      1.352776, 0.000000, 0.002775}}],
    Polygon[{{1.369019, 0.022357, 0.002775},{1.371794, 0.013817, -0.002775},{
      1.366245, 0.013817, -0.011754},{1.360040, 0.022357, -0.011754},{
      1.361755, 0.027635, -0.002775}}],
    Polygon[{{1.352776, 0.027635, 0.002775},{1.361755, 0.027635, -0.002775},{
      1.360040, 0.022357, -0.011754},{1.350001, 0.019095, -0.011754},{
      1.345512, 0.022357, -0.002775}}],
    Polygon[{{1.342737, 0.013817, 0.002775},{1.345512, 0.022357, -0.002775},{
      1.350001, 0.019095, -0.011754},{1.350001, 0.008540, -0.011754},{
      1.345512, 0.005278, -0.002775}}],
    Polygon[{{1.352776, 0.000000, 0.002775},{1.345512, 0.005278, -0.002775},{
      1.350001, 0.008540, -0.011754},{1.360040, 0.005278, -0.011754},{
      1.361755, 0.000000, -0.002775}}],
    Polygon[{{1.369019, 0.005278, 0.002775},{1.361755, 0.000000, -0.002775},{
      1.360040, 0.005278, -0.011754},{1.366245, 0.013817, -0.011754},{
      1.371794, 0.013817, -0.002775}}],
    Polygon[{{1.360040, 0.022357, -0.011754},{1.366245, 0.013817, -0.011754},{
      1.360040, 0.005278, -0.011754},{1.350001, 0.008540, -0.011754},{
      1.350001, 0.019095, -0.011754}}],
    Polygon[{{1.340111, 0.095166, 0.010966},{1.330745, 0.098210, 0.010966},{
      1.324956, 0.090242, 0.010966},{1.330745, 0.082274, 0.010966},{
      1.340111, 0.085318, 0.010966}}],
    Polygon[{{1.340111, 0.095166, 0.010966},{1.340111, 0.085318, 0.010966},{
      1.344300, 0.082274, 0.002589},{1.346888, 0.090242, -0.002589},{
      1.344300, 0.098210, 0.002589}}],
    Polygon[{{1.340111, 0.095166, 0.010966},{1.344300, 0.098210, 0.002589},{
      1.337522, 0.103134, -0.002589},{1.329145, 0.103134, 0.002589},{
      1.330745, 0.098210, 0.010966}}],
    Polygon[{{1.330745, 0.098210, 0.010966},{1.329145, 0.103134, 0.002589},{
      1.322367, 0.098210, -0.002589},{1.319778, 0.090242, 0.002589},{
      1.324956, 0.090242, 0.010966}}],
    Polygon[{{1.324956, 0.090242, 0.010966},{1.319778, 0.090242, 0.002589},{
      1.322367, 0.082274, -0.002589},{1.329145, 0.077350, 0.002589},{
      1.330745, 0.082274, 0.010966}}],
    Polygon[{{1.330745, 0.082274, 0.010966},{1.340111, 0.085318, 0.010966},{
      1.344300, 0.082274, 0.002589},{1.337522, 0.077350, -0.002589},{
      1.329145, 0.077350, 0.002589}}],
    Polygon[{{1.344300, 0.098210, 0.002589},{1.346888, 0.090242, -0.002589},{
      1.341711, 0.090242, -0.010966},{1.335922, 0.098210, -0.010966},{
      1.337522, 0.103134, -0.002589}}],
    Polygon[{{1.329145, 0.103134, 0.002589},{1.337522, 0.103134, -0.002589},{
      1.335922, 0.098210, -0.010966},{1.326556, 0.095166, -0.010966},{
      1.322367, 0.098210, -0.002589}}],
    Polygon[{{1.319778, 0.090242, 0.002589},{1.322367, 0.098210, -0.002589},{
      1.326556, 0.095166, -0.010966},{1.326556, 0.085318, -0.010966},{
      1.322367, 0.082274, -0.002589}}],
    Polygon[{{1.329145, 0.077350, 0.002589},{1.322367, 0.082274, -0.002589},{
      1.326556, 0.085318, -0.010966},{1.335922, 0.082274, -0.010966},{
      1.337522, 0.077350, -0.002589}}],
    Polygon[{{1.344300, 0.082274, 0.002589},{1.337522, 0.077350, -0.002589},{
      1.335922, 0.082274, -0.010966},{1.341711, 0.090242, -0.010966},{
      1.346888, 0.090242, -0.002589}}],
    Polygon[{{1.335922, 0.098210, -0.010966},{1.341711, 0.090242, -0.010966},{
      1.335922, 0.082274, -0.010966},{1.326556, 0.085318, -0.010966},{
      1.326556, 0.095166, -0.010966}}],
    Polygon[{{1.532558, 0.040038, 0.024645},{1.511509, 0.046877, 0.024645},{
      1.498500, 0.028972, 0.024645},{1.511509, 0.011066, 0.024645},{
      1.532558, 0.017905, 0.024645}}],
    Polygon[{{1.532558, 0.040038, 0.024645},{1.532558, 0.017905, 0.024645},{
      1.541972, 0.011066, 0.005818},{1.547790, 0.028972, -0.005818},{
      1.541972, 0.046877, 0.005818}}],
    Polygon[{{1.532558, 0.040038, 0.024645},{1.541972, 0.046877, 0.005818},{
      1.526741, 0.057943, -0.005818},{1.507914, 0.057943, 0.005818},{
      1.511509, 0.046877, 0.024645}}],
    Polygon[{{1.511509, 0.046877, 0.024645},{1.507914, 0.057943, 0.005818},{
      1.492683, 0.046877, -0.005818},{1.486865, 0.028972, 0.005818},{
      1.498500, 0.028972, 0.024645}}],
    Polygon[{{1.498500, 0.028972, 0.024645},{1.486865, 0.028972, 0.005818},{
      1.492683, 0.011066, -0.005818},{1.507914, 0.000000, 0.005818},{
      1.511509, 0.011066, 0.024645}}],
    Polygon[{{1.511509, 0.011066, 0.024645},{1.532558, 0.017905, 0.024645},{
      1.541972, 0.011066, 0.005818},{1.526741, 0.000000, -0.005818},{
      1.507914, 0.000000, 0.005818}}],
    Polygon[{{1.541972, 0.046877, 0.005818},{1.547790, 0.028972, -0.005818},{
      1.536154, 0.028972, -0.024645},{1.523145, 0.046877, -0.024645},{
      1.526741, 0.057943, -0.005818}}],
    Polygon[{{1.507914, 0.057943, 0.005818},{1.526741, 0.057943, -0.005818},{
      1.523145, 0.046877, -0.024645},{1.502096, 0.040038, -0.024645},{
      1.492683, 0.046877, -0.005818}}],
    Polygon[{{1.486865, 0.028972, 0.005818},{1.492683, 0.046877, -0.005818},{
      1.502096, 0.040038, -0.024645},{1.502096, 0.017905, -0.024645},{
      1.492683, 0.011066, -0.005818}}],
    Polygon[{{1.507914, 0.000000, 0.005818},{1.492683, 0.011066, -0.005818},{
      1.502096, 0.017905, -0.024645},{1.523145, 0.011066, -0.024645},{
      1.526741, 0.000000, -0.005818}}],
    Polygon[{{1.541972, 0.011066, 0.005818},{1.526741, 0.000000, -0.005818},{
      1.523145, 0.011066, -0.024645},{1.536154, 0.028972, -0.024645},{
      1.547790, 0.028972, -0.005818}}],
    Polygon[{{1.523145, 0.046877, -0.024645},{1.536154, 0.028972, -0.024645},{
      1.523145, 0.011066, -0.024645},{1.502096, 0.017905, -0.024645},{
      1.502096, 0.040038, -0.024645}}],
    Polygon[{{1.566979, 0.020782, 0.012792},{1.556053, 0.024332, 0.012792},{
      1.549301, 0.015038, 0.012792},{1.556053, 0.005744, 0.012792},{
      1.566979, 0.009294, 0.012792}}],
    Polygon[{{1.566979, 0.020782, 0.012792},{1.566979, 0.009294, 0.012792},{
      1.571865, 0.005744, 0.003020},{1.574885, 0.015038, -0.003020},{
      1.571865, 0.024332, 0.003020}}],
    Polygon[{{1.566979, 0.020782, 0.012792},{1.571865, 0.024332, 0.003020},{
      1.563959, 0.030076, -0.003020},{1.554187, 0.030076, 0.003020},{
      1.556053, 0.024332, 0.012792}}],
    Polygon[{{1.556053, 0.024332, 0.012792},{1.554187, 0.030076, 0.003020},{
      1.546281, 0.024332, -0.003020},{1.543261, 0.015038, 0.003020},{
      1.549301, 0.015038, 0.012792}}],
    Polygon[{{1.549301, 0.015038, 0.012792},{1.543261, 0.015038, 0.003020},{
      1.546281, 0.005744, -0.003020},{1.554187, 0.000000, 0.003020},{
      1.556053, 0.005744, 0.012792}}],
    Polygon[{{1.556053, 0.005744, 0.012792},{1.566979, 0.009294, 0.012792},{
      1.571865, 0.005744, 0.003020},{1.563959, 0.000000, -0.003020},{
      1.554187, 0.000000, 0.003020}}],
    Polygon[{{1.571865, 0.024332, 0.003020},{1.574885, 0.015038, -0.003020},{
      1.568845, 0.015038, -0.012792},{1.562093, 0.024332, -0.012792},{
      1.563959, 0.030076, -0.003020}}],
    Polygon[{{1.554187, 0.030076, 0.003020},{1.563959, 0.030076, -0.003020},{
      1.562093, 0.024332, -0.012792},{1.551167, 0.020782, -0.012792},{
      1.546281, 0.024332, -0.003020}}],
    Polygon[{{1.543261, 0.015038, 0.003020},{1.546281, 0.024332, -0.003020},{
      1.551167, 0.020782, -0.012792},{1.551167, 0.009294, -0.012792},{
      1.546281, 0.005744, -0.003020}}],
    Polygon[{{1.554187, 0.000000, 0.003020},{1.546281, 0.005744, -0.003020},{
      1.551167, 0.009294, -0.012792},{1.562093, 0.005744, -0.012792},{
      1.563959, 0.000000, -0.003020}}],
    Polygon[{{1.571865, 0.005744, 0.003020},{1.563959, 0.000000, -0.003020},{
      1.562093, 0.005744, -0.012792},{1.568845, 0.015038, -0.012792},{
      1.574885, 0.015038, -0.003020}}],
    Polygon[{{1.562093, 0.024332, -0.012792},{1.568845, 0.015038, -0.012792},{
      1.562093, 0.005744, -0.012792},{1.551167, 0.009294, -0.012792},{
      1.551167, 0.020782, -0.012792}}],
    Polygon[{{1.487244, 0.015408, 0.009484},{1.479144, 0.018040, 0.009484},{
      1.474137, 0.011149, 0.009484},{1.479144, 0.004259, 0.009484},{
      1.487244, 0.006891, 0.009484}}],
    Polygon[{{1.487244, 0.015408, 0.009484},{1.487244, 0.006891, 0.009484},{
      1.490866, 0.004259, 0.002239},{1.493105, 0.011149, -0.002239},{
      1.490866, 0.018040, 0.002239}}],
    Polygon[{{1.487244, 0.015408, 0.009484},{1.490866, 0.018040, 0.002239},{
      1.485005, 0.022298, -0.002239},{1.477760, 0.022298, 0.002239},{
      1.479144, 0.018040, 0.009484}}],
    Polygon[{{1.479144, 0.018040, 0.009484},{1.477760, 0.022298, 0.002239},{
      1.471899, 0.018040, -0.002239},{1.469660, 0.011149, 0.002239},{
      1.474137, 0.011149, 0.009484}}],
    Polygon[{{1.474137, 0.011149, 0.009484},{1.469660, 0.011149, 0.002239},{
      1.471899, 0.004259, -0.002239},{1.477760, 0.000000, 0.002239},{
      1.479144, 0.004259, 0.009484}}],
    Polygon[{{1.479144, 0.004259, 0.009484},{1.487244, 0.006891, 0.009484},{
      1.490866, 0.004259, 0.002239},{1.485005, 0.000000, -0.002239},{
      1.477760, 0.000000, 0.002239}}],
    Polygon[{{1.490866, 0.018040, 0.002239},{1.493105, 0.011149, -0.002239},{
      1.488628, 0.011149, -0.009484},{1.483621, 0.018040, -0.009484},{
      1.485005, 0.022298, -0.002239}}],
    Polygon[{{1.477760, 0.022298, 0.002239},{1.485005, 0.022298, -0.002239},{
      1.483621, 0.018040, -0.009484},{1.475521, 0.015408, -0.009484},{
      1.471899, 0.018040, -0.002239}}],
    Polygon[{{1.469660, 0.011149, 0.002239},{1.471899, 0.018040, -0.002239},{
      1.475521, 0.015408, -0.009484},{1.475521, 0.006891, -0.009484},{
      1.471899, 0.004259, -0.002239}}],
    Polygon[{{1.477760, 0.000000, 0.002239},{1.471899, 0.004259, -0.002239},{
      1.475521, 0.006891, -0.009484},{1.483621, 0.004259, -0.009484},{
      1.485005, 0.000000, -0.002239}}],
    Polygon[{{1.490866, 0.004259, 0.002239},{1.485005, 0.000000, -0.002239},{
      1.483621, 0.004259, -0.009484},{1.488628, 0.011149, -0.009484},{
      1.493105, 0.011149, -0.002239}}],
    Polygon[{{1.483621, 0.018040, -0.009484},{1.488628, 0.011149, -0.009484},{
      1.483621, 0.004259, -0.009484},{1.475521, 0.006891, -0.009484},{
      1.475521, 0.015408, -0.009484}}],
    Polygon[{{1.513810, 0.070116, 0.008080},{1.506909, 0.072358, 0.008080},{
      1.502644, 0.066488, 0.008080},{1.506909, 0.060618, 0.008080},{
      1.513810, 0.062860, 0.008080}}],
    Polygon[{{1.513810, 0.070116, 0.008080},{1.513810, 0.062860, 0.008080},{
      1.516896, 0.060618, 0.001907},{1.518803, 0.066488, -0.001907},{
      1.516896, 0.072358, 0.001907}}],
    Polygon[{{1.513810, 0.070116, 0.008080},{1.516896, 0.072358, 0.001907},{
      1.511903, 0.075986, -0.001907},{1.505730, 0.075986, 0.001907},{
      1.506909, 0.072358, 0.008080}}],
    Polygon[{{1.506909, 0.072358, 0.008080},{1.505730, 0.075986, 0.001907},{
      1.500737, 0.072358, -0.001907},{1.498829, 0.066488, 0.001907},{
      1.502644, 0.066488, 0.008080}}],
    Polygon[{{1.502644, 0.066488, 0.008080},{1.498829, 0.066488, 0.001907},{
      1.500737, 0.060618, -0.001907},{1.505730, 0.056990, 0.001907},{
      1.506909, 0.060618, 0.008080}}],
    Polygon[{{1.506909, 0.060618, 0.008080},{1.513810, 0.062860, 0.008080},{
      1.516896, 0.060618, 0.001907},{1.511903, 0.056990, -0.001907},{
      1.505730, 0.056990, 0.001907}}],
    Polygon[{{1.516896, 0.072358, 0.001907},{1.518803, 0.066488, -0.001907},{
      1.514989, 0.066488, -0.008080},{1.510724, 0.072358, -0.008080},{
      1.511903, 0.075986, -0.001907}}],
    Polygon[{{1.505730, 0.075986, 0.001907},{1.511903, 0.075986, -0.001907},{
      1.510724, 0.072358, -0.008080},{1.503823, 0.070116, -0.008080},{
      1.500737, 0.072358, -0.001907}}],
    Polygon[{{1.498829, 0.066488, 0.001907},{1.500737, 0.072358, -0.001907},{
      1.503823, 0.070116, -0.008080},{1.503823, 0.062860, -0.008080},{
      1.500737, 0.060618, -0.001907}}],
    Polygon[{{1.505730, 0.056990, 0.001907},{1.500737, 0.060618, -0.001907},{
      1.503823, 0.062860, -0.008080},{1.510724, 0.060618, -0.008080},{
      1.511903, 0.056990, -0.001907}}],
    Polygon[{{1.516896, 0.060618, 0.001907},{1.511903, 0.056990, -0.001907},{
      1.510724, 0.060618, -0.008080},{1.514989, 0.066488, -0.008080},{
      1.518803, 0.066488, -0.001907}}],
    Polygon[{{1.510724, 0.072358, -0.008080},{1.514989, 0.066488, -0.008080},{
      1.510724, 0.060618, -0.008080},{1.503823, 0.062860, -0.008080},{
      1.503823, 0.070116, -0.008080}}],
    Polygon[{{1.462877, 0.185884, 0.021420},{1.444582, 0.191828, 0.021420},{
      1.433275, 0.176266, 0.021420},{1.444582, 0.160703, 0.021420},{
      1.462877, 0.166647, 0.021420}}],
    Polygon[{{1.462877, 0.185884, 0.021420},{1.462877, 0.166647, 0.021420},{
      1.471058, 0.160703, 0.005057},{1.476115, 0.176266, -0.005057},{
      1.471058, 0.191828, 0.005057}}],
    Polygon[{{1.462877, 0.185884, 0.021420},{1.471058, 0.191828, 0.005057},{
      1.457820, 0.201446, -0.005057},{1.441457, 0.201446, 0.005057},{
      1.444582, 0.191828, 0.021420}}],
    Polygon[{{1.444582, 0.191828, 0.021420},{1.441457, 0.201446, 0.005057},{
      1.428218, 0.191828, -0.005057},{1.423162, 0.176266, 0.005057},{
      1.433275, 0.176266, 0.021420}}],
    Polygon[{{1.433275, 0.176266, 0.021420},{1.423162, 0.176266, 0.005057},{
      1.428218, 0.160703, -0.005057},{1.441457, 0.151085, 0.005057},{
      1.444582, 0.160703, 0.021420}}],
    Polygon[{{1.444582, 0.160703, 0.021420},{1.462877, 0.166647, 0.021420},{
      1.471058, 0.160703, 0.005057},{1.457820, 0.151085, -0.005057},{
      1.441457, 0.151085, 0.005057}}],
    Polygon[{{1.471058, 0.191828, 0.005057},{1.476115, 0.176266, -0.005057},{
      1.466002, 0.176266, -0.021420},{1.454695, 0.191828, -0.021420},{
      1.457820, 0.201446, -0.005057}}],
    Polygon[{{1.441457, 0.201446, 0.005057},{1.457820, 0.201446, -0.005057},{
      1.454695, 0.191828, -0.021420},{1.436400, 0.185884, -0.021420},{
      1.428218, 0.191828, -0.005057}}],
    Polygon[{{1.423162, 0.176266, 0.005057},{1.428218, 0.191828, -0.005057},{
      1.436400, 0.185884, -0.021420},{1.436400, 0.166647, -0.021420},{
      1.428218, 0.160703, -0.005057}}],
    Polygon[{{1.441457, 0.151085, 0.005057},{1.428218, 0.160703, -0.005057},{
      1.436400, 0.166647, -0.021420},{1.454695, 0.160703, -0.021420},{
      1.457820, 0.151085, -0.005057}}],
    Polygon[{{1.471058, 0.160703, 0.005057},{1.457820, 0.151085, -0.005057},{
      1.454695, 0.160703, -0.021420},{1.466002, 0.176266, -0.021420},{
      1.476115, 0.176266, -0.005057}}],
    Polygon[{{1.454695, 0.191828, -0.021420},{1.466002, 0.176266, -0.021420},{
      1.454695, 0.160703, -0.021420},{1.436400, 0.166647, -0.021420},{
      1.436400, 0.185884, -0.021420}}],
    Polygon[{{1.469208, 0.216318, 0.010586},{1.460166, 0.219256, 0.010586},{
      1.454578, 0.211564, 0.010586},{1.460166, 0.203873, 0.010586},{
      1.469208, 0.206811, 0.010586}}],
    Polygon[{{1.469208, 0.216318, 0.010586},{1.469208, 0.206811, 0.010586},{
      1.473251, 0.203873, 0.002499},{1.475751, 0.211564, -0.002499},{
      1.473251, 0.219256, 0.002499}}],
    Polygon[{{1.469208, 0.216318, 0.010586},{1.473251, 0.219256, 0.002499},{
      1.466709, 0.224009, -0.002499},{1.458622, 0.224009, 0.002499},{
      1.460166, 0.219256, 0.010586}}],
    Polygon[{{1.460166, 0.219256, 0.010586},{1.458622, 0.224009, 0.002499},{
      1.452079, 0.219256, -0.002499},{1.449580, 0.211564, 0.002499},{
      1.454578, 0.211564, 0.010586}}],
    Polygon[{{1.454578, 0.211564, 0.010586},{1.449580, 0.211564, 0.002499},{
      1.452079, 0.203873, -0.002499},{1.458622, 0.199119, 0.002499},{
      1.460166, 0.203873, 0.010586}}],
    Polygon[{{1.460166, 0.203873, 0.010586},{1.469208, 0.206811, 0.010586},{
      1.473251, 0.203873, 0.002499},{1.466709, 0.199119, -0.002499},{
      1.458622, 0.199119, 0.002499}}],
    Polygon[{{1.473251, 0.219256, 0.002499},{1.475751, 0.211564, -0.002499},{
      1.470752, 0.211564, -0.010586},{1.465164, 0.219256, -0.010586},{
      1.466709, 0.224009, -0.002499}}],
    Polygon[{{1.458622, 0.224009, 0.002499},{1.466709, 0.224009, -0.002499},{
      1.465164, 0.219256, -0.010586},{1.456122, 0.216318, -0.010586},{
      1.452079, 0.219256, -0.002499}}],
    Polygon[{{1.449580, 0.211564, 0.002499},{1.452079, 0.219256, -0.002499},{
      1.456122, 0.216318, -0.010586},{1.456122, 0.206811, -0.010586},{
      1.452079, 0.203873, -0.002499}}],
    Polygon[{{1.458622, 0.199119, 0.002499},{1.452079, 0.203873, -0.002499},{
      1.456122, 0.206811, -0.010586},{1.465164, 0.203873, -0.010586},{
      1.466709, 0.199119, -0.002499}}],
    Polygon[{{1.473251, 0.203873, 0.002499},{1.466709, 0.199119, -0.002499},{
      1.465164, 0.203873, -0.010586},{1.470752, 0.211564, -0.010586},{
      1.475751, 0.211564, -0.002499}}],
    Polygon[{{1.465164, 0.219256, -0.010586},{1.470752, 0.211564, -0.010586},{
      1.465164, 0.203873, -0.010586},{1.456122, 0.206811, -0.010586},{
      1.456122, 0.216318, -0.010586}}],
    Polygon[{{1.422044, 0.167861, 0.008215},{1.415028, 0.170140, 0.008215},{
      1.410691, 0.164172, 0.008215},{1.415028, 0.158203, 0.008215},{
      1.422044, 0.160483, 0.008215}}],
    Polygon[{{1.422044, 0.167861, 0.008215},{1.422044, 0.160483, 0.008215},{
      1.425182, 0.158203, 0.001939},{1.427121, 0.164172, -0.001939},{
      1.425182, 0.170140, 0.001939}}],
    Polygon[{{1.422044, 0.167861, 0.008215},{1.425182, 0.170140, 0.001939},{
      1.420105, 0.173829, -0.001939},{1.413829, 0.173829, 0.001939},{
      1.415028, 0.170140, 0.008215}}],
    Polygon[{{1.415028, 0.170140, 0.008215},{1.413829, 0.173829, 0.001939},{
      1.408752, 0.170140, -0.001939},{1.406813, 0.164172, 0.001939},{
      1.410691, 0.164172, 0.008215}}],
    Polygon[{{1.410691, 0.164172, 0.008215},{1.406813, 0.164172, 0.001939},{
      1.408752, 0.158203, -0.001939},{1.413829, 0.154515, 0.001939},{
      1.415028, 0.158203, 0.008215}}],
    Polygon[{{1.415028, 0.158203, 0.008215},{1.422044, 0.160483, 0.008215},{
      1.425182, 0.158203, 0.001939},{1.420105, 0.154515, -0.001939},{
      1.413829, 0.154515, 0.001939}}],
    Polygon[{{1.425182, 0.170140, 0.001939},{1.427121, 0.164172, -0.001939},{
      1.423242, 0.164172, -0.008215},{1.418906, 0.170140, -0.008215},{
      1.420105, 0.173829, -0.001939}}],
    Polygon[{{1.413829, 0.173829, 0.001939},{1.420105, 0.173829, -0.001939},{
      1.418906, 0.170140, -0.008215},{1.411890, 0.167861, -0.008215},{
      1.408752, 0.170140, -0.001939}}],
    Polygon[{{1.406813, 0.164172, 0.001939},{1.408752, 0.170140, -0.001939},{
      1.411890, 0.167861, -0.008215},{1.411890, 0.160483, -0.008215},{
      1.408752, 0.158203, -0.001939}}],
    Polygon[{{1.413829, 0.154515, 0.001939},{1.408752, 0.158203, -0.001939},{
      1.411890, 0.160483, -0.008215},{1.418906, 0.158203, -0.008215},{
      1.420105, 0.154515, -0.001939}}],
    Polygon[{{1.425182, 0.158203, 0.001939},{1.420105, 0.154515, -0.001939},{
      1.418906, 0.158203, -0.008215},{1.423242, 0.164172, -0.008215},{
      1.427121, 0.164172, -0.001939}}],
    Polygon[{{1.418906, 0.170140, -0.008215},{1.423242, 0.164172, -0.008215},{
      1.418906, 0.158203, -0.008215},{1.411890, 0.160483, -0.008215},{
      1.411890, 0.167861, -0.008215}}],
    Polygon[{{1.474757, 0.152551, 0.007466},{1.468381, 0.154622, 0.007466},{
      1.464440, 0.149198, 0.007466},{1.468381, 0.143774, 0.007466},{
      1.474757, 0.145846, 0.007466}}],
    Polygon[{{1.474757, 0.152551, 0.007466},{1.474757, 0.145846, 0.007466},{
      1.477609, 0.143774, 0.001762},{1.479371, 0.149198, -0.001762},{
      1.477609, 0.154622, 0.001762}}],
    Polygon[{{1.474757, 0.152551, 0.007466},{1.477609, 0.154622, 0.001762},{
      1.472995, 0.157975, -0.001762},{1.467292, 0.157975, 0.001762},{
      1.468381, 0.154622, 0.007466}}],
    Polygon[{{1.468381, 0.154622, 0.007466},{1.467292, 0.157975, 0.001762},{
      1.462678, 0.154622, -0.001762},{1.460915, 0.149198, 0.001762},{
      1.464440, 0.149198, 0.007466}}],
    Polygon[{{1.464440, 0.149198, 0.007466},{1.460915, 0.149198, 0.001762},{
      1.462678, 0.143774, -0.001762},{1.467292, 0.140422, 0.001762},{
      1.468381, 0.143774, 0.007466}}],
    Polygon[{{1.468381, 0.143774, 0.007466},{1.474757, 0.145846, 0.007466},{
      1.477609, 0.143774, 0.001762},{1.472995, 0.140422, -0.001762},{
      1.467292, 0.140422, 0.001762}}],
    Polygon[{{1.477609, 0.154622, 0.001762},{1.479371, 0.149198, -0.001762},{
      1.475847, 0.149198, -0.007466},{1.471906, 0.154622, -0.007466},{
      1.472995, 0.157975, -0.001762}}],
    Polygon[{{1.467292, 0.157975, 0.001762},{1.472995, 0.157975, -0.001762},{
      1.471906, 0.154622, -0.007466},{1.465529, 0.152551, -0.007466},{
      1.462678, 0.154622, -0.001762}}],
    Polygon[{{1.460915, 0.149198, 0.001762},{1.462678, 0.154622, -0.001762},{
      1.465529, 0.152551, -0.007466},{1.465529, 0.145846, -0.007466},{
      1.462678, 0.143774, -0.001762}}],
    Polygon[{{1.467292, 0.140422, 0.001762},{1.462678, 0.143774, -0.001762},{
      1.465529, 0.145846, -0.007466},{1.471906, 0.143774, -0.007466},{
      1.472995, 0.140422, -0.001762}}],
    Polygon[{{1.477609, 0.143774, 0.001762},{1.472995, 0.140422, -0.001762},{
      1.471906, 0.143774, -0.007466},{1.475847, 0.149198, -0.007466},{
      1.479371, 0.149198, -0.001762}}],
    Polygon[{{1.471906, 0.154622, -0.007466},{1.475847, 0.149198, -0.007466},{
      1.471906, 0.143774, -0.007466},{1.465529, 0.145846, -0.007466},{
      1.465529, 0.152551, -0.007466}}],
    Polygon[{{1.685003, 0.490870, 0.065798},{1.628805, 0.509130, 0.065798},{
      1.594072, 0.461325, 0.065798},{1.628805, 0.413520, 0.065798},{
      1.685003, 0.431780, 0.065798}}],
    Polygon[{{1.685003, 0.490870, 0.065798},{1.685003, 0.431780, 0.065798},{
      1.710136, 0.413520, 0.015533},{1.725668, 0.461325, -0.015533},{
      1.710136, 0.509130, 0.015533}}],
    Polygon[{{1.685003, 0.490870, 0.065798},{1.710136, 0.509130, 0.015533},{
      1.669470, 0.538675, -0.015533},{1.619205, 0.538675, 0.015533},{
      1.628805, 0.509130, 0.065798}}],
    Polygon[{{1.628805, 0.509130, 0.065798},{1.619205, 0.538675, 0.015533},{
      1.578539, 0.509130, -0.015533},{1.563007, 0.461325, 0.015533},{
      1.594072, 0.461325, 0.065798}}],
    Polygon[{{1.594072, 0.461325, 0.065798},{1.563007, 0.461325, 0.015533},{
      1.578539, 0.413520, -0.015533},{1.619205, 0.383975, 0.015533},{
      1.628805, 0.413520, 0.065798}}],
    Polygon[{{1.628805, 0.413520, 0.065798},{1.685003, 0.431780, 0.065798},{
      1.710136, 0.413520, 0.015533},{1.669470, 0.383975, -0.015533},{
      1.619205, 0.383975, 0.015533}}],
    Polygon[{{1.710136, 0.509130, 0.015533},{1.725668, 0.461325, -0.015533},{
      1.694603, 0.461325, -0.065798},{1.659870, 0.509130, -0.065798},{
      1.669470, 0.538675, -0.015533}}],
    Polygon[{{1.619205, 0.538675, 0.015533},{1.669470, 0.538675, -0.015533},{
      1.659870, 0.509130, -0.065798},{1.603672, 0.490870, -0.065798},{
      1.578539, 0.509130, -0.015533}}],
    Polygon[{{1.563007, 0.461325, 0.015533},{1.578539, 0.509130, -0.015533},{
      1.603672, 0.490870, -0.065798},{1.603672, 0.431780, -0.065798},{
      1.578539, 0.413520, -0.015533}}],
    Polygon[{{1.619205, 0.383975, 0.015533},{1.578539, 0.413520, -0.015533},{
      1.603672, 0.431780, -0.065798},{1.659870, 0.413520, -0.065798},{
      1.669470, 0.383975, -0.015533}}],
    Polygon[{{1.710136, 0.413520, 0.015533},{1.669470, 0.383975, -0.015533},{
      1.659870, 0.413520, -0.065798},{1.694603, 0.461325, -0.065798},{
      1.725668, 0.461325, -0.015533}}],
    Polygon[{{1.659870, 0.509130, -0.065798},{1.694603, 0.461325, -0.065798},{
      1.659870, 0.413520, -0.065798},{1.603672, 0.431780, -0.065798},{
      1.603672, 0.490870, -0.065798}}],
    Polygon[{{1.640595, 0.593183, 0.035261},{1.610478, 0.602969, 0.035261},{
      1.591865, 0.577350, 0.035261},{1.610478, 0.551732, 0.035261},{
      1.640595, 0.561517, 0.035261}}],
    Polygon[{{1.640595, 0.593183, 0.035261},{1.640595, 0.561517, 0.035261},{
      1.654063, 0.551732, 0.008324},{1.662387, 0.577350, -0.008324},{
      1.654063, 0.602969, 0.008324}}],
    Polygon[{{1.640595, 0.593183, 0.035261},{1.654063, 0.602969, 0.008324},{
      1.632271, 0.618802, -0.008324},{1.605334, 0.618802, 0.008324},{
      1.610478, 0.602969, 0.035261}}],
    Polygon[{{1.610478, 0.602969, 0.035261},{1.605334, 0.618802, 0.008324},{
      1.583541, 0.602969, -0.008324},{1.575217, 0.577350, 0.008324},{
      1.591865, 0.577350, 0.035261}}],
    Polygon[{{1.591865, 0.577350, 0.035261},{1.575217, 0.577350, 0.008324},{
      1.583541, 0.551732, -0.008324},{1.605334, 0.535898, 0.008324},{
      1.610478, 0.551732, 0.035261}}],
    Polygon[{{1.610478, 0.551732, 0.035261},{1.640595, 0.561517, 0.035261},{
      1.654063, 0.551732, 0.008324},{1.632271, 0.535898, -0.008324},{
      1.605334, 0.535898, 0.008324}}],
    Polygon[{{1.654063, 0.602969, 0.008324},{1.662387, 0.577350, -0.008324},{
      1.645739, 0.577350, -0.035261},{1.627126, 0.602969, -0.035261},{
      1.632271, 0.618802, -0.008324}}],
    Polygon[{{1.605334, 0.618802, 0.008324},{1.632271, 0.618802, -0.008324},{
      1.627126, 0.602969, -0.035261},{1.597010, 0.593183, -0.035261},{
      1.583541, 0.602969, -0.008324}}],
    Polygon[{{1.575217, 0.577350, 0.008324},{1.583541, 0.602969, -0.008324},{
      1.597010, 0.593183, -0.035261},{1.597010, 0.561517, -0.035261},{
      1.583541, 0.551732, -0.008324}}],
    Polygon[{{1.605334, 0.535898, 0.008324},{1.583541, 0.551732, -0.008324},{
      1.597010, 0.561517, -0.035261},{1.627126, 0.551732, -0.035261},{
      1.632271, 0.535898, -0.008324}}],
    Polygon[{{1.654063, 0.551732, 0.008324},{1.632271, 0.535898, -0.008324},{
      1.627126, 0.551732, -0.035261},{1.645739, 0.577350, -0.035261},{
      1.662387, 0.577350, -0.008324}}],
    Polygon[{{1.627126, 0.602969, -0.035261},{1.645739, 0.577350, -0.035261},{
      1.627126, 0.551732, -0.035261},{1.597010, 0.561517, -0.035261},{
      1.597010, 0.593183, -0.035261}}],
    Polygon[{{1.613235, 0.651657, 0.021933},{1.594502, 0.657744, 0.021933},{
      1.582924, 0.641809, 0.021933},{1.594502, 0.625874, 0.021933},{
      1.613235, 0.631960, 0.021933}}],
    Polygon[{{1.613235, 0.651657, 0.021933},{1.613235, 0.631960, 0.021933},{
      1.621612, 0.625874, 0.005178},{1.626790, 0.641809, -0.005178},{
      1.621612, 0.657744, 0.005178}}],
    Polygon[{{1.613235, 0.651657, 0.021933},{1.621612, 0.657744, 0.005178},{
      1.608057, 0.667592, -0.005178},{1.591302, 0.667592, 0.005178},{
      1.594502, 0.657744, 0.021933}}],
    Polygon[{{1.594502, 0.657744, 0.021933},{1.591302, 0.667592, 0.005178},{
      1.577747, 0.657744, -0.005178},{1.572569, 0.641809, 0.005178},{
      1.582924, 0.641809, 0.021933}}],
    Polygon[{{1.582924, 0.641809, 0.021933},{1.572569, 0.641809, 0.005178},{
      1.577747, 0.625874, -0.005178},{1.591302, 0.616025, 0.005178},{
      1.594502, 0.625874, 0.021933}}],
    Polygon[{{1.594502, 0.625874, 0.021933},{1.613235, 0.631960, 0.021933},{
      1.621612, 0.625874, 0.005178},{1.608057, 0.616025, -0.005178},{
      1.591302, 0.616025, 0.005178}}],
    Polygon[{{1.621612, 0.657744, 0.005178},{1.626790, 0.641809, -0.005178},{
      1.616434, 0.641809, -0.021933},{1.604857, 0.657744, -0.021933},{
      1.608057, 0.667592, -0.005178}}],
    Polygon[{{1.591302, 0.667592, 0.005178},{1.608057, 0.667592, -0.005178},{
      1.604857, 0.657744, -0.021933},{1.586124, 0.651657, -0.021933},{
      1.577747, 0.657744, -0.005178}}],
    Polygon[{{1.572569, 0.641809, 0.005178},{1.577747, 0.657744, -0.005178},{
      1.586124, 0.651657, -0.021933},{1.586124, 0.631960, -0.021933},{
      1.577747, 0.625874, -0.005178}}],
    Polygon[{{1.591302, 0.616025, 0.005178},{1.577747, 0.625874, -0.005178},{
      1.586124, 0.631960, -0.021933},{1.604857, 0.625874, -0.021933},{
      1.608057, 0.616025, -0.005178}}],
    Polygon[{{1.621612, 0.625874, 0.005178},{1.608057, 0.616025, -0.005178},{
      1.604857, 0.625874, -0.021933},{1.616434, 0.641809, -0.021933},{
      1.626790, 0.641809, -0.005178}}],
    Polygon[{{1.604857, 0.657744, -0.021933},{1.616434, 0.641809, -0.021933},{
      1.604857, 0.625874, -0.021933},{1.586124, 0.631960, -0.021933},{
      1.586124, 0.651657, -0.021933}}],
    Polygon[{{1.673931, 0.554993, 0.011754},{1.663892, 0.558255, 0.011754},{
      1.657688, 0.549716, 0.011754},{1.663892, 0.541176, 0.011754},{
      1.673931, 0.544438, 0.011754}}],
    Polygon[{{1.673931, 0.554993, 0.011754},{1.673931, 0.544438, 0.011754},{
      1.678420, 0.541176, 0.002775},{1.681195, 0.549716, -0.002775},{
      1.678420, 0.558255, 0.002775}}],
    Polygon[{{1.673931, 0.554993, 0.011754},{1.678420, 0.558255, 0.002775},{
      1.671156, 0.563533, -0.002775},{1.662177, 0.563533, 0.002775},{
      1.663892, 0.558255, 0.011754}}],
    Polygon[{{1.663892, 0.558255, 0.011754},{1.662177, 0.563533, 0.002775},{
      1.654913, 0.558255, -0.002775},{1.652138, 0.549716, 0.002775},{
      1.657688, 0.549716, 0.011754}}],
    Polygon[{{1.657688, 0.549716, 0.011754},{1.652138, 0.549716, 0.002775},{
      1.654913, 0.541176, -0.002775},{1.662177, 0.535898, 0.002775},{
      1.663892, 0.541176, 0.011754}}],
    Polygon[{{1.663892, 0.541176, 0.011754},{1.673931, 0.544438, 0.011754},{
      1.678420, 0.541176, 0.002775},{1.671156, 0.535898, -0.002775},{
      1.662177, 0.535898, 0.002775}}],
    Polygon[{{1.678420, 0.558255, 0.002775},{1.681195, 0.549716, -0.002775},{
      1.675646, 0.549716, -0.011754},{1.669441, 0.558255, -0.011754},{
      1.671156, 0.563533, -0.002775}}],
    Polygon[{{1.662177, 0.563533, 0.002775},{1.671156, 0.563533, -0.002775},{
      1.669441, 0.558255, -0.011754},{1.659402, 0.554993, -0.011754},{
      1.654913, 0.558255, -0.002775}}],
    Polygon[{{1.652138, 0.549716, 0.002775},{1.654913, 0.558255, -0.002775},{
      1.659402, 0.554993, -0.011754},{1.659402, 0.544438, -0.011754},{
      1.654913, 0.541176, -0.002775}}],
    Polygon[{{1.662177, 0.535898, 0.002775},{1.654913, 0.541176, -0.002775},{
      1.659402, 0.544438, -0.011754},{1.669441, 0.541176, -0.011754},{
      1.671156, 0.535898, -0.002775}}],
    Polygon[{{1.678420, 0.541176, 0.002775},{1.671156, 0.535898, -0.002775},{
      1.669441, 0.541176, -0.011754},{1.675646, 0.549716, -0.011754},{
      1.681195, 0.549716, -0.002775}}],
    Polygon[{{1.669441, 0.558255, -0.011754},{1.675646, 0.549716, -0.011754},{
      1.669441, 0.541176, -0.011754},{1.659402, 0.544438, -0.011754},{
      1.659402, 0.554993, -0.011754}}],
    Polygon[{{1.595292, 0.537153, 0.010966},{1.585926, 0.540197, 0.010966},{
      1.580137, 0.532229, 0.010966},{1.585926, 0.524262, 0.010966},{
      1.595292, 0.527305, 0.010966}}],
    Polygon[{{1.595292, 0.537153, 0.010966},{1.595292, 0.527305, 0.010966},{
      1.599481, 0.524262, 0.002589},{1.602070, 0.532229, -0.002589},{
      1.599481, 0.540197, 0.002589}}],
    Polygon[{{1.595292, 0.537153, 0.010966},{1.599481, 0.540197, 0.002589},{
      1.592704, 0.545121, -0.002589},{1.584326, 0.545121, 0.002589},{
      1.585926, 0.540197, 0.010966}}],
    Polygon[{{1.585926, 0.540197, 0.010966},{1.584326, 0.545121, 0.002589},{
      1.577549, 0.540197, -0.002589},{1.574960, 0.532229, 0.002589},{
      1.580137, 0.532229, 0.010966}}],
    Polygon[{{1.580137, 0.532229, 0.010966},{1.574960, 0.532229, 0.002589},{
      1.577549, 0.524262, -0.002589},{1.584326, 0.519338, 0.002589},{
      1.585926, 0.524262, 0.010966}}],
    Polygon[{{1.585926, 0.524262, 0.010966},{1.595292, 0.527305, 0.010966},{
      1.599481, 0.524262, 0.002589},{1.592704, 0.519338, -0.002589},{
      1.584326, 0.519338, 0.002589}}],
    Polygon[{{1.599481, 0.540197, 0.002589},{1.602070, 0.532229, -0.002589},{
      1.596892, 0.532229, -0.010966},{1.591104, 0.540197, -0.010966},{
      1.592704, 0.545121, -0.002589}}],
    Polygon[{{1.584326, 0.545121, 0.002589},{1.592704, 0.545121, -0.002589},{
      1.591104, 0.540197, -0.010966},{1.581737, 0.537153, -0.010966},{
      1.577549, 0.540197, -0.002589}}],
    Polygon[{{1.574960, 0.532229, 0.002589},{1.577549, 0.540197, -0.002589},{
      1.581737, 0.537153, -0.010966},{1.581737, 0.527305, -0.010966},{
      1.577549, 0.524262, -0.002589}}],
    Polygon[{{1.584326, 0.519338, 0.002589},{1.577549, 0.524262, -0.002589},{
      1.581737, 0.527305, -0.010966},{1.591104, 0.524262, -0.010966},{
      1.592704, 0.519338, -0.002589}}],
    Polygon[{{1.599481, 0.524262, 0.002589},{1.592704, 0.519338, -0.002589},{
      1.591104, 0.524262, -0.010966},{1.596892, 0.532229, -0.010966},{
      1.602070, 0.532229, -0.002589}}],
    Polygon[{{1.591104, 0.540197, -0.010966},{1.596892, 0.532229, -0.010966},{
      1.591104, 0.524262, -0.010966},{1.581737, 0.527305, -0.010966},{
      1.581737, 0.537153, -0.010966}}],
    Polygon[{{1.748805, 0.414587, 0.024645},{1.727756, 0.421427, 0.024645},{
      1.714747, 0.403521, 0.024645},{1.727756, 0.385616, 0.024645},{
      1.748805, 0.392455, 0.024645}}],
    Polygon[{{1.748805, 0.414587, 0.024645},{1.748805, 0.392455, 0.024645},{
      1.758218, 0.385616, 0.005818},{1.764036, 0.403521, -0.005818},{
      1.758218, 0.421427, 0.005818}}],
    Polygon[{{1.748805, 0.414587, 0.024645},{1.758218, 0.421427, 0.005818},{
      1.742987, 0.432493, -0.005818},{1.724160, 0.432493, 0.005818},{
      1.727756, 0.421427, 0.024645}}],
    Polygon[{{1.727756, 0.421427, 0.024645},{1.724160, 0.432493, 0.005818},{
      1.708929, 0.421427, -0.005818},{1.703111, 0.403521, 0.005818},{
      1.714747, 0.403521, 0.024645}}],
    Polygon[{{1.714747, 0.403521, 0.024645},{1.703111, 0.403521, 0.005818},{
      1.708929, 0.385616, -0.005818},{1.724160, 0.374550, 0.005818},{
      1.727756, 0.385616, 0.024645}}],
    Polygon[{{1.727756, 0.385616, 0.024645},{1.748805, 0.392455, 0.024645},{
      1.758218, 0.385616, 0.005818},{1.742987, 0.374550, -0.005818},{
      1.724160, 0.374550, 0.005818}}],
    Polygon[{{1.758218, 0.421427, 0.005818},{1.764036, 0.403521, -0.005818},{
      1.752400, 0.403521, -0.024645},{1.739391, 0.421427, -0.024645},{
      1.742987, 0.432493, -0.005818}}],
    Polygon[{{1.724160, 0.432493, 0.005818},{1.742987, 0.432493, -0.005818},{
      1.739391, 0.421427, -0.024645},{1.718342, 0.414587, -0.024645},{
      1.708929, 0.421427, -0.005818}}],
    Polygon[{{1.703111, 0.403521, 0.005818},{1.708929, 0.421427, -0.005818},{
      1.718342, 0.414587, -0.024645},{1.718342, 0.392455, -0.024645},{
      1.708929, 0.385616, -0.005818}}],
    Polygon[{{1.724160, 0.374550, 0.005818},{1.708929, 0.385616, -0.005818},{
      1.718342, 0.392455, -0.024645},{1.739391, 0.385616, -0.024645},{
      1.742987, 0.374550, -0.005818}}],
    Polygon[{{1.758218, 0.385616, 0.005818},{1.742987, 0.374550, -0.005818},{
      1.739391, 0.385616, -0.024645},{1.752400, 0.403521, -0.024645},{
      1.764036, 0.403521, -0.005818}}],
    Polygon[{{1.739391, 0.421427, -0.024645},{1.752400, 0.403521, -0.024645},{
      1.739391, 0.385616, -0.024645},{1.718342, 0.392455, -0.024645},{
      1.718342, 0.414587, -0.024645}}],
    Polygon[{{1.774419, 0.380079, 0.012792},{1.763493, 0.383629, 0.012792},{
      1.756741, 0.374335, 0.012792},{1.763493, 0.365041, 0.012792},{
      1.774419, 0.368591, 0.012792}}],
    Polygon[{{1.774419, 0.380079, 0.012792},{1.774419, 0.368591, 0.012792},{
      1.779305, 0.365041, 0.003020},{1.782325, 0.374335, -0.003020},{
      1.779305, 0.383629, 0.003020}}],
    Polygon[{{1.774419, 0.380079, 0.012792},{1.779305, 0.383629, 0.003020},{
      1.771399, 0.389373, -0.003020},{1.761627, 0.389373, 0.003020},{
      1.763493, 0.383629, 0.012792}}],
    Polygon[{{1.763493, 0.383629, 0.012792},{1.761627, 0.389373, 0.003020},{
      1.753721, 0.383629, -0.003020},{1.750701, 0.374335, 0.003020},{
      1.756741, 0.374335, 0.012792}}],
    Polygon[{{1.756741, 0.374335, 0.012792},{1.750701, 0.374335, 0.003020},{
      1.753721, 0.365041, -0.003020},{1.761627, 0.359297, 0.003020},{
      1.763493, 0.365041, 0.012792}}],
    Polygon[{{1.763493, 0.365041, 0.012792},{1.774419, 0.368591, 0.012792},{
      1.779305, 0.365041, 0.003020},{1.771399, 0.359297, -0.003020},{
      1.761627, 0.359297, 0.003020}}],
    Polygon[{{1.779305, 0.383629, 0.003020},{1.782325, 0.374335, -0.003020},{
      1.776285, 0.374335, -0.012792},{1.769533, 0.383629, -0.012792},{
      1.771399, 0.389373, -0.003020}}],
    Polygon[{{1.761627, 0.389373, 0.003020},{1.771399, 0.389373, -0.003020},{
      1.769533, 0.383629, -0.012792},{1.758607, 0.380079, -0.012792},{
      1.753721, 0.383629, -0.003020}}],
    Polygon[{{1.750701, 0.374335, 0.003020},{1.753721, 0.383629, -0.003020},{
      1.758607, 0.380079, -0.012792},{1.758607, 0.368591, -0.012792},{
      1.753721, 0.365041, -0.003020}}],
    Polygon[{{1.761627, 0.359297, 0.003020},{1.753721, 0.365041, -0.003020},{
      1.758607, 0.368591, -0.012792},{1.769533, 0.365041, -0.012792},{
      1.771399, 0.359297, -0.003020}}],
    Polygon[{{1.779305, 0.365041, 0.003020},{1.771399, 0.359297, -0.003020},{
      1.769533, 0.365041, -0.012792},{1.776285, 0.374335, -0.012792},{
      1.782325, 0.374335, -0.003020}}],
    Polygon[{{1.769533, 0.383629, -0.012792},{1.776285, 0.374335, -0.012792},{
      1.769533, 0.365041, -0.012792},{1.758607, 0.368591, -0.012792},{
      1.758607, 0.380079, -0.012792}}],
    Polygon[{{1.736897, 0.447820, 0.009484},{1.728797, 0.450452, 0.009484},{
      1.723791, 0.443561, 0.009484},{1.728797, 0.436671, 0.009484},{
      1.736897, 0.439303, 0.009484}}],
    Polygon[{{1.736897, 0.447820, 0.009484},{1.736897, 0.439303, 0.009484},{
      1.740520, 0.436671, 0.002239},{1.742759, 0.443561, -0.002239},{
      1.740520, 0.450452, 0.002239}}],
    Polygon[{{1.736897, 0.447820, 0.009484},{1.740520, 0.450452, 0.002239},{
      1.734658, 0.454710, -0.002239},{1.727413, 0.454710, 0.002239},{
      1.728797, 0.450452, 0.009484}}],
    Polygon[{{1.728797, 0.450452, 0.009484},{1.727413, 0.454710, 0.002239},{
      1.721552, 0.450452, -0.002239},{1.719313, 0.443561, 0.002239},{
      1.723791, 0.443561, 0.009484}}],
    Polygon[{{1.723791, 0.443561, 0.009484},{1.719313, 0.443561, 0.002239},{
      1.721552, 0.436671, -0.002239},{1.727413, 0.432412, 0.002239},{
      1.728797, 0.436671, 0.009484}}],
    Polygon[{{1.728797, 0.436671, 0.009484},{1.736897, 0.439303, 0.009484},{
      1.740520, 0.436671, 0.002239},{1.734658, 0.432412, -0.002239},{
      1.727413, 0.432412, 0.002239}}],
    Polygon[{{1.740520, 0.450452, 0.002239},{1.742759, 0.443561, -0.002239},{
      1.738281, 0.443561, -0.009484},{1.733275, 0.450452, -0.009484},{
      1.734658, 0.454710, -0.002239}}],
    Polygon[{{1.727413, 0.454710, 0.002239},{1.734658, 0.454710, -0.002239},{
      1.733275, 0.450452, -0.009484},{1.725174, 0.447820, -0.009484},{
      1.721552, 0.450452, -0.002239}}],
    Polygon[{{1.719313, 0.443561, 0.002239},{1.721552, 0.450452, -0.002239},{
      1.725174, 0.447820, -0.009484},{1.725174, 0.439303, -0.009484},{
      1.721552, 0.436671, -0.002239}}],
    Polygon[{{1.727413, 0.432412, 0.002239},{1.721552, 0.436671, -0.002239},{
      1.725174, 0.439303, -0.009484},{1.733275, 0.436671, -0.009484},{
      1.734658, 0.432412, -0.002239}}],
    Polygon[{{1.740520, 0.436671, 0.002239},{1.734658, 0.432412, -0.002239},{
      1.733275, 0.436671, -0.009484},{1.738281, 0.443561, -0.009484},{
      1.742759, 0.443561, -0.002239}}],
    Polygon[{{1.733275, 0.450452, -0.009484},{1.738281, 0.443561, -0.009484},{
      1.733275, 0.436671, -0.009484},{1.725174, 0.439303, -0.009484},{
      1.725174, 0.447820, -0.009484}}],
    Polygon[{{1.701821, 0.395762, 0.008080},{1.694920, 0.398004, 0.008080},{
      1.690655, 0.392133, 0.008080},{1.694920, 0.386263, 0.008080},{
      1.701821, 0.388505, 0.008080}}],
    Polygon[{{1.701821, 0.395762, 0.008080},{1.701821, 0.388505, 0.008080},{
      1.704908, 0.386263, 0.001907},{1.706815, 0.392133, -0.001907},{
      1.704908, 0.398004, 0.001907}}],
    Polygon[{{1.701821, 0.395762, 0.008080},{1.704908, 0.398004, 0.001907},{
      1.699914, 0.401632, -0.001907},{1.693742, 0.401632, 0.001907},{
      1.694920, 0.398004, 0.008080}}],
    Polygon[{{1.694920, 0.398004, 0.008080},{1.693742, 0.401632, 0.001907},{
      1.688748, 0.398004, -0.001907},{1.686841, 0.392133, 0.001907},{
      1.690655, 0.392133, 0.008080}}],
    Polygon[{{1.690655, 0.392133, 0.008080},{1.686841, 0.392133, 0.001907},{
      1.688748, 0.386263, -0.001907},{1.693742, 0.382635, 0.001907},{
      1.694920, 0.386263, 0.008080}}],
    Polygon[{{1.694920, 0.386263, 0.008080},{1.701821, 0.388505, 0.008080},{
      1.704908, 0.386263, 0.001907},{1.699914, 0.382635, -0.001907},{
      1.693742, 0.382635, 0.001907}}],
    Polygon[{{1.704908, 0.398004, 0.001907},{1.706815, 0.392133, -0.001907},{
      1.703000, 0.392133, -0.008080},{1.698735, 0.398004, -0.008080},{
      1.699914, 0.401632, -0.001907}}],
    Polygon[{{1.693742, 0.401632, 0.001907},{1.699914, 0.401632, -0.001907},{
      1.698735, 0.398004, -0.008080},{1.691834, 0.395762, -0.008080},{
      1.688748, 0.398004, -0.001907}}],
    Polygon[{{1.686841, 0.392133, 0.001907},{1.688748, 0.398004, -0.001907},{
      1.691834, 0.395762, -0.008080},{1.691834, 0.388505, -0.008080},{
      1.688748, 0.386263, -0.001907}}],
    Polygon[{{1.693742, 0.382635, 0.001907},{1.688748, 0.386263, -0.001907},{
      1.691834, 0.388505, -0.008080},{1.698735, 0.386263, -0.008080},{
      1.699914, 0.382635, -0.001907}}],
    Polygon[{{1.704908, 0.386263, 0.001907},{1.699914, 0.382635, -0.001907},{
      1.698735, 0.386263, -0.008080},{1.703000, 0.392133, -0.008080},{
      1.706815, 0.392133, -0.001907}}],
    Polygon[{{1.698735, 0.398004, -0.008080},{1.703000, 0.392133, -0.008080},{
      1.698735, 0.386263, -0.008080},{1.691834, 0.388505, -0.008080},{
      1.691834, 0.395762, -0.008080}}],
    Polygon[{{1.585407, 0.398113, 0.021420},{1.567112, 0.404057, 0.021420},{
      1.555805, 0.388494, 0.021420},{1.567112, 0.372932, 0.021420},{
      1.585407, 0.378876, 0.021420}}],
    Polygon[{{1.585407, 0.398113, 0.021420},{1.585407, 0.378876, 0.021420},{
      1.593589, 0.372932, 0.005057},{1.598645, 0.388494, -0.005057},{
      1.593589, 0.404057, 0.005057}}],
    Polygon[{{1.585407, 0.398113, 0.021420},{1.593589, 0.404057, 0.005057},{
      1.580351, 0.413675, -0.005057},{1.563987, 0.413675, 0.005057},{
      1.567112, 0.404057, 0.021420}}],
    Polygon[{{1.567112, 0.404057, 0.021420},{1.563987, 0.413675, 0.005057},{
      1.550749, 0.404057, -0.005057},{1.545692, 0.388494, 0.005057},{
      1.555805, 0.388494, 0.021420}}],
    Polygon[{{1.555805, 0.388494, 0.021420},{1.545692, 0.388494, 0.005057},{
      1.550749, 0.372932, -0.005057},{1.563987, 0.363314, 0.005057},{
      1.567112, 0.372932, 0.021420}}],
    Polygon[{{1.567112, 0.372932, 0.021420},{1.585407, 0.378876, 0.021420},{
      1.593589, 0.372932, 0.005057},{1.580351, 0.363314, -0.005057},{
      1.563987, 0.363314, 0.005057}}],
    Polygon[{{1.593589, 0.404057, 0.005057},{1.598645, 0.388494, -0.005057},{
      1.588532, 0.388494, -0.021420},{1.577225, 0.404057, -0.021420},{
      1.580351, 0.413675, -0.005057}}],
    Polygon[{{1.563987, 0.413675, 0.005057},{1.580351, 0.413675, -0.005057},{
      1.577225, 0.404057, -0.021420},{1.558931, 0.398113, -0.021420},{
      1.550749, 0.404057, -0.005057}}],
    Polygon[{{1.545692, 0.388494, 0.005057},{1.550749, 0.404057, -0.005057},{
      1.558931, 0.398113, -0.021420},{1.558931, 0.378876, -0.021420},{
      1.550749, 0.372932, -0.005057}}],
    Polygon[{{1.563987, 0.363314, 0.005057},{1.550749, 0.372932, -0.005057},{
      1.558931, 0.378876, -0.021420},{1.577225, 0.372932, -0.021420},{
      1.580351, 0.363314, -0.005057}}],
    Polygon[{{1.593589, 0.372932, 0.005057},{1.580351, 0.363314, -0.005057},{
      1.577225, 0.372932, -0.021420},{1.588532, 0.388494, -0.021420},{
      1.598645, 0.388494, -0.005057}}],
    Polygon[{{1.577225, 0.404057, -0.021420},{1.588532, 0.388494, -0.021420},{
      1.577225, 0.372932, -0.021420},{1.558931, 0.378876, -0.021420},{
      1.558931, 0.398113, -0.021420}}],
    Polygon[{{1.554655, 0.364317, 0.010586},{1.545613, 0.367255, 0.010586},{
      1.540025, 0.359563, 0.010586},{1.545613, 0.351872, 0.010586},{
      1.554655, 0.354810, 0.010586}}],
    Polygon[{{1.554655, 0.364317, 0.010586},{1.554655, 0.354810, 0.010586},{
      1.558699, 0.351872, 0.002499},{1.561198, 0.359563, -0.002499},{
      1.558699, 0.367255, 0.002499}}],
    Polygon[{{1.554655, 0.364317, 0.010586},{1.558699, 0.367255, 0.002499},{
      1.552156, 0.372008, -0.002499},{1.544069, 0.372008, 0.002499},{
      1.545613, 0.367255, 0.010586}}],
    Polygon[{{1.545613, 0.367255, 0.010586},{1.544069, 0.372008, 0.002499},{
      1.537526, 0.367255, -0.002499},{1.535027, 0.359563, 0.002499},{
      1.540025, 0.359563, 0.010586}}],
    Polygon[{{1.540025, 0.359563, 0.010586},{1.535027, 0.359563, 0.002499},{
      1.537526, 0.351872, -0.002499},{1.544069, 0.347119, 0.002499},{
      1.545613, 0.351872, 0.010586}}],
    Polygon[{{1.545613, 0.351872, 0.010586},{1.554655, 0.354810, 0.010586},{
      1.558699, 0.351872, 0.002499},{1.552156, 0.347119, -0.002499},{
      1.544069, 0.347119, 0.002499}}],
    Polygon[{{1.558699, 0.367255, 0.002499},{1.561198, 0.359563, -0.002499},{
      1.556200, 0.359563, -0.010586},{1.550612, 0.367255, -0.010586},{
      1.552156, 0.372008, -0.002499}}],
    Polygon[{{1.544069, 0.372008, 0.002499},{1.552156, 0.372008, -0.002499},{
      1.550612, 0.367255, -0.010586},{1.541570, 0.364317, -0.010586},{
      1.537526, 0.367255, -0.002499}}],
    Polygon[{{1.535027, 0.359563, 0.002499},{1.537526, 0.367255, -0.002499},{
      1.541570, 0.364317, -0.010586},{1.541570, 0.354810, -0.010586},{
      1.537526, 0.351872, -0.002499}}],
    Polygon[{{1.544069, 0.347119, 0.002499},{1.537526, 0.351872, -0.002499},{
      1.541570, 0.354810, -0.010586},{1.550612, 0.351872, -0.010586},{
      1.552156, 0.347119, -0.002499}}],
    Polygon[{{1.558699, 0.351872, 0.002499},{1.552156, 0.347119, -0.002499},{
      1.550612, 0.351872, -0.010586},{1.556200, 0.359563, -0.010586},{
      1.561198, 0.359563, -0.002499}}],
    Polygon[{{1.550612, 0.367255, -0.010586},{1.556200, 0.359563, -0.010586},{
      1.550612, 0.351872, -0.010586},{1.541570, 0.354810, -0.010586},{
      1.541570, 0.364317, -0.010586}}],
    Polygon[{{1.571383, 0.426524, 0.008215},{1.564367, 0.428804, 0.008215},{
      1.560031, 0.422836, 0.008215},{1.564367, 0.416867, 0.008215},{
      1.571383, 0.419147, 0.008215}}],
    Polygon[{{1.571383, 0.426524, 0.008215},{1.571383, 0.419147, 0.008215},{
      1.574521, 0.416867, 0.001939},{1.576461, 0.422836, -0.001939},{
      1.574521, 0.428804, 0.001939}}],
    Polygon[{{1.571383, 0.426524, 0.008215},{1.574521, 0.428804, 0.001939},{
      1.569444, 0.432493, -0.001939},{1.563169, 0.432493, 0.001939},{
      1.564367, 0.428804, 0.008215}}],
    Polygon[{{1.564367, 0.428804, 0.008215},{1.563169, 0.432493, 0.001939},{
      1.558092, 0.428804, -0.001939},{1.556152, 0.422836, 0.001939},{
      1.560031, 0.422836, 0.008215}}],
    Polygon[{{1.560031, 0.422836, 0.008215},{1.556152, 0.422836, 0.001939},{
      1.558092, 0.416867, -0.001939},{1.563169, 0.413178, 0.001939},{
      1.564367, 0.416867, 0.008215}}],
    Polygon[{{1.564367, 0.416867, 0.008215},{1.571383, 0.419147, 0.008215},{
      1.574521, 0.416867, 0.001939},{1.569444, 0.413178, -0.001939},{
      1.563169, 0.413178, 0.001939}}],
    Polygon[{{1.574521, 0.428804, 0.001939},{1.576461, 0.422836, -0.001939},{
      1.572582, 0.422836, -0.008215},{1.568246, 0.428804, -0.008215},{
      1.569444, 0.432493, -0.001939}}],
    Polygon[{{1.563169, 0.432493, 0.001939},{1.569444, 0.432493, -0.001939},{
      1.568246, 0.428804, -0.008215},{1.561229, 0.426524, -0.008215},{
      1.558092, 0.428804, -0.001939}}],
    Polygon[{{1.556152, 0.422836, 0.001939},{1.558092, 0.428804, -0.001939},{
      1.561229, 0.426524, -0.008215},{1.561229, 0.419147, -0.008215},{
      1.558092, 0.416867, -0.001939}}],
    Polygon[{{1.563169, 0.413178, 0.001939},{1.558092, 0.416867, -0.001939},{
      1.561229, 0.419147, -0.008215},{1.568246, 0.416867, -0.008215},{
      1.569444, 0.413178, -0.001939}}],
    Polygon[{{1.574521, 0.416867, 0.001939},{1.569444, 0.413178, -0.001939},{
      1.568246, 0.416867, -0.008215},{1.572582, 0.422836, -0.008215},{
      1.576461, 0.422836, -0.001939}}],
    Polygon[{{1.568246, 0.428804, -0.008215},{1.572582, 0.422836, -0.008215},{
      1.568246, 0.416867, -0.008215},{1.561229, 0.419147, -0.008215},{
      1.561229, 0.426524, -0.008215}}],
    Polygon[{{1.610476, 0.387622, 0.007466},{1.604100, 0.389694, 0.007466},{
      1.600159, 0.384270, 0.007466},{1.604100, 0.378846, 0.007466},{
      1.610476, 0.380918, 0.007466}}],
    Polygon[{{1.610476, 0.387622, 0.007466},{1.610476, 0.380918, 0.007466},{
      1.613328, 0.378846, 0.001762},{1.615090, 0.384270, -0.001762},{
      1.613328, 0.389694, 0.001762}}],
    Polygon[{{1.610476, 0.387622, 0.007466},{1.613328, 0.389694, 0.001762},{
      1.608714, 0.393046, -0.001762},{1.603011, 0.393046, 0.001762},{
      1.604100, 0.389694, 0.007466}}],
    Polygon[{{1.604100, 0.389694, 0.007466},{1.603011, 0.393046, 0.001762},{
      1.598397, 0.389694, -0.001762},{1.596634, 0.384270, 0.001762},{
      1.600159, 0.384270, 0.007466}}],
    Polygon[{{1.600159, 0.384270, 0.007466},{1.596634, 0.384270, 0.001762},{
      1.598397, 0.378846, -0.001762},{1.603011, 0.375494, 0.001762},{
      1.604100, 0.378846, 0.007466}}],
    Polygon[{{1.604100, 0.378846, 0.007466},{1.610476, 0.380918, 0.007466},{
      1.613328, 0.378846, 0.001762},{1.608714, 0.375494, -0.001762},{
      1.603011, 0.375494, 0.001762}}],
    Polygon[{{1.613328, 0.389694, 0.001762},{1.615090, 0.384270, -0.001762},{
      1.611565, 0.384270, -0.007466},{1.607625, 0.389694, -0.007466},{
      1.608714, 0.393046, -0.001762}}],
    Polygon[{{1.603011, 0.393046, 0.001762},{1.608714, 0.393046, -0.001762},{
      1.607625, 0.389694, -0.007466},{1.601248, 0.387622, -0.007466},{
      1.598397, 0.389694, -0.001762}}],
    Polygon[{{1.596634, 0.384270, 0.001762},{1.598397, 0.389694, -0.001762},{
      1.601248, 0.387622, -0.007466},{1.601248, 0.380918, -0.007466},{
      1.598397, 0.378846, -0.001762}}],
    Polygon[{{1.603011, 0.375494, 0.001762},{1.598397, 0.378846, -0.001762},{
      1.601248, 0.380918, -0.007466},{1.607625, 0.378846, -0.007466},{
      1.608714, 0.375494, -0.001762}}],
    Polygon[{{1.613328, 0.378846, 0.001762},{1.608714, 0.375494, -0.001762},{
      1.607625, 0.378846, -0.007466},{1.611565, 0.384270, -0.007466},{
      1.615090, 0.384270, -0.001762}}],
    Polygon[{{1.607625, 0.389694, -0.007466},{1.611565, 0.384270, -0.007466},{
      1.607625, 0.378846, -0.007466},{1.601248, 0.380918, -0.007466},{
      1.601248, 0.387622, -0.007466}}],
    Polygon[{{1.101177, 1.420660, 0.163708},{0.961354, 1.466091, 0.163708},{
      0.874938, 1.347151, 0.163708},{0.961354, 1.228210, 0.163708},{
      1.101177, 1.273641, 0.163708}}],
    Polygon[{{1.101177, 1.420660, 0.163708},{1.101177, 1.273641, 0.163708},{
      1.163708, 1.228210, 0.038646},{1.202354, 1.347151, -0.038646},{
      1.163708, 1.466091, 0.038646}}],
    Polygon[{{1.101177, 1.420660, 0.163708},{1.163708, 1.466091, 0.038646},{
      1.062531, 1.539601, -0.038646},{0.937469, 1.539601, 0.038646},{
      0.961354, 1.466091, 0.163708}}],
    Polygon[{{0.961354, 1.466091, 0.163708},{0.937469, 1.539601, 0.038646},{
      0.836292, 1.466091, -0.038646},{0.797646, 1.347151, 0.038646},{
      0.874938, 1.347151, 0.163708}}],
    Polygon[{{0.874938, 1.347151, 0.163708},{0.797646, 1.347151, 0.038646},{
      0.836292, 1.228210, -0.038646},{0.937469, 1.154701, 0.038646},{
      0.961354, 1.228210, 0.163708}}],
    Polygon[{{0.961354, 1.228210, 0.163708},{1.101177, 1.273641, 0.163708},{
      1.163708, 1.228210, 0.038646},{1.062531, 1.154701, -0.038646},{
      0.937469, 1.154701, 0.038646}}],
    Polygon[{{1.163708, 1.466091, 0.038646},{1.202354, 1.347151, -0.038646},{
      1.125062, 1.347151, -0.163708},{1.038646, 1.466091, -0.163708},{
      1.062531, 1.539601, -0.038646}}],
    Polygon[{{0.937469, 1.539601, 0.038646},{1.062531, 1.539601, -0.038646},{
      1.038646, 1.466091, -0.163708},{0.898823, 1.420660, -0.163708},{
      0.836292, 1.466091, -0.038646}}],
    Polygon[{{0.797646, 1.347151, 0.038646},{0.836292, 1.466091, -0.038646},{
      0.898823, 1.420660, -0.163708},{0.898823, 1.273641, -0.163708},{
      0.836292, 1.228210, -0.038646}}],
    Polygon[{{0.937469, 1.154701, 0.038646},{0.836292, 1.228210, -0.038646},{
      0.898823, 1.273641, -0.163708},{1.038646, 1.228210, -0.163708},{
      1.062531, 1.154701, -0.038646}}],
    Polygon[{{1.163708, 1.228210, 0.038646},{1.062531, 1.154701, -0.038646},{
      1.038646, 1.228210, -0.163708},{1.125062, 1.347151, -0.163708},{
      1.202354, 1.347151, -0.038646}}],
    Polygon[{{1.038646, 1.466091, -0.163708},{1.125062, 1.347151, -0.163708},{
      1.038646, 1.228210, -0.163708},{0.898823, 1.273641, -0.163708},{
      0.898823, 1.420660, -0.163708}}],
    Polygon[{{1.033726, 1.628254, 0.054569},{0.987118, 1.643398, 0.054569},{
      0.958313, 1.603751, 0.054569},{0.987118, 1.564104, 0.054569},{
      1.033726, 1.579248, 0.054569}}],
    Polygon[{{1.033726, 1.628254, 0.054569},{1.033726, 1.579248, 0.054569},{
      1.054569, 1.564104, 0.012882},{1.067451, 1.603751, -0.012882},{
      1.054569, 1.643398, 0.012882}}],
    Polygon[{{1.033726, 1.628254, 0.054569},{1.054569, 1.643398, 0.012882},{
      1.020844, 1.667901, -0.012882},{0.979156, 1.667901, 0.012882},{
      0.987118, 1.643398, 0.054569}}],
    Polygon[{{0.987118, 1.643398, 0.054569},{0.979156, 1.667901, 0.012882},{
      0.945431, 1.643398, -0.012882},{0.932549, 1.603751, 0.012882},{
      0.958313, 1.603751, 0.054569}}],
    Polygon[{{0.958313, 1.603751, 0.054569},{0.932549, 1.603751, 0.012882},{
      0.945431, 1.564104, -0.012882},{0.979156, 1.539601, 0.012882},{
      0.987118, 1.564104, 0.054569}}],
    Polygon[{{0.987118, 1.564104, 0.054569},{1.033726, 1.579248, 0.054569},{
      1.054569, 1.564104, 0.012882},{1.020844, 1.539601, -0.012882},{
      0.979156, 1.539601, 0.012882}}],
    Polygon[{{1.054569, 1.643398, 0.012882},{1.067451, 1.603751, -0.012882},{
      1.041687, 1.603751, -0.054569},{1.012882, 1.643398, -0.054569},{
      1.020844, 1.667901, -0.012882}}],
    Polygon[{{0.979156, 1.667901, 0.012882},{1.020844, 1.667901, -0.012882},{
      1.012882, 1.643398, -0.054569},{0.966274, 1.628254, -0.054569},{
      0.945431, 1.643398, -0.012882}}],
    Polygon[{{0.932549, 1.603751, 0.012882},{0.945431, 1.643398, -0.012882},{
      0.966274, 1.628254, -0.054569},{0.966274, 1.579248, -0.054569},{
      0.945431, 1.564104, -0.012882}}],
    Polygon[{{0.979156, 1.539601, 0.012882},{0.945431, 1.564104, -0.012882},{
      0.966274, 1.579248, -0.054569},{1.012882, 1.564104, -0.054569},{
      1.020844, 1.539601, -0.012882}}],
    Polygon[{{1.054569, 1.564104, 0.012882},{1.020844, 1.539601, -0.012882},{
      1.012882, 1.564104, -0.054569},{1.041687, 1.603751, -0.054569},{
      1.067451, 1.603751, -0.012882}}],
    Polygon[{{1.012882, 1.643398, -0.054569},{1.041687, 1.603751, -0.054569},{
      1.012882, 1.564104, -0.054569},{0.966274, 1.579248, -0.054569},{
      0.966274, 1.628254, -0.054569}}],
    Polygon[{{1.011242, 1.697452, 0.018190},{0.995706, 1.702500, 0.018190},{
      0.986104, 1.689284, 0.018190},{0.995706, 1.676069, 0.018190},{
      1.011242, 1.681116, 0.018190}}],
    Polygon[{{1.011242, 1.697452, 0.018190},{1.011242, 1.681116, 0.018190},{
      1.018190, 1.676069, 0.004294},{1.022484, 1.689284, -0.004294},{
      1.018190, 1.702500, 0.004294}}],
    Polygon[{{1.011242, 1.697452, 0.018190},{1.018190, 1.702500, 0.004294},{
      1.006948, 1.710667, -0.004294},{0.993052, 1.710667, 0.004294},{
      0.995706, 1.702500, 0.018190}}],
    Polygon[{{0.995706, 1.702500, 0.018190},{0.993052, 1.710667, 0.004294},{
      0.981810, 1.702500, -0.004294},{0.977516, 1.689284, 0.004294},{
      0.986104, 1.689284, 0.018190}}],
    Polygon[{{0.986104, 1.689284, 0.018190},{0.977516, 1.689284, 0.004294},{
      0.981810, 1.676069, -0.004294},{0.993052, 1.667901, 0.004294},{
      0.995706, 1.676069, 0.018190}}],
    Polygon[{{0.995706, 1.676069, 0.018190},{1.011242, 1.681116, 0.018190},{
      1.018190, 1.676069, 0.004294},{1.006948, 1.667901, -0.004294},{
      0.993052, 1.667901, 0.004294}}],
    Polygon[{{1.018190, 1.702500, 0.004294},{1.022484, 1.689284, -0.004294},{
      1.013896, 1.689284, -0.018190},{1.004294, 1.702500, -0.018190},{
      1.006948, 1.710667, -0.004294}}],
    Polygon[{{0.993052, 1.710667, 0.004294},{1.006948, 1.710667, -0.004294},{
      1.004294, 1.702500, -0.018190},{0.988758, 1.697452, -0.018190},{
      0.981810, 1.702500, -0.004294}}],
    Polygon[{{0.977516, 1.689284, 0.004294},{0.981810, 1.702500, -0.004294},{
      0.988758, 1.697452, -0.018190},{0.988758, 1.681116, -0.018190},{
      0.981810, 1.676069, -0.004294}}],
    Polygon[{{0.993052, 1.667901, 0.004294},{0.981810, 1.676069, -0.004294},{
      0.988758, 1.681116, -0.018190},{1.004294, 1.676069, -0.018190},{
      1.006948, 1.667901, -0.004294}}],
    Polygon[{{1.018190, 1.676069, 0.004294},{1.006948, 1.667901, -0.004294},{
      1.004294, 1.676069, -0.018190},{1.013896, 1.689284, -0.018190},{
      1.022484, 1.689284, -0.004294}}],
    Polygon[{{1.004294, 1.702500, -0.018190},{1.013896, 1.689284, -0.018190},{
      1.004294, 1.676069, -0.018190},{0.988758, 1.681116, -0.018190},{
      0.988758, 1.697452, -0.018190}}],
    Polygon[{{1.003747, 1.720518, 0.006063},{0.998569, 1.722201, 0.006063},{
      0.995368, 1.717795, 0.006063},{0.998569, 1.713390, 0.006063},{
      1.003747, 1.715073, 0.006063}}],
    Polygon[{{1.003747, 1.720518, 0.006063},{1.003747, 1.715073, 0.006063},{
      1.006063, 1.713390, 0.001431},{1.007495, 1.717795, -0.001431},{
      1.006063, 1.722201, 0.001431}}],
    Polygon[{{1.003747, 1.720518, 0.006063},{1.006063, 1.722201, 0.001431},{
      1.002316, 1.724923, -0.001431},{0.997684, 1.724923, 0.001431},{
      0.998569, 1.722201, 0.006063}}],
    Polygon[{{0.998569, 1.722201, 0.006063},{0.997684, 1.724923, 0.001431},{
      0.993937, 1.722201, -0.001431},{0.992505, 1.717795, 0.001431},{
      0.995368, 1.717795, 0.006063}}],
    Polygon[{{0.995368, 1.717795, 0.006063},{0.992505, 1.717795, 0.001431},{
      0.993937, 1.713390, -0.001431},{0.997684, 1.710667, 0.001431},{
      0.998569, 1.713390, 0.006063}}],
    Polygon[{{0.998569, 1.713390, 0.006063},{1.003747, 1.715073, 0.006063},{
      1.006063, 1.713390, 0.001431},{1.002316, 1.710667, -0.001431},{
      0.997684, 1.710667, 0.001431}}],
    Polygon[{{1.006063, 1.722201, 0.001431},{1.007495, 1.717795, -0.001431},{
      1.004632, 1.717795, -0.006063},{1.001431, 1.722201, -0.006063},{
      1.002316, 1.724923, -0.001431}}],
    Polygon[{{0.997684, 1.724923, 0.001431},{1.002316, 1.724923, -0.001431},{
      1.001431, 1.722201, -0.006063},{0.996253, 1.720518, -0.006063},{
      0.993937, 1.722201, -0.001431}}],
    Polygon[{{0.992505, 1.717795, 0.001431},{0.993937, 1.722201, -0.001431},{
      0.996253, 1.720518, -0.006063},{0.996253, 1.715073, -0.006063},{
      0.993937, 1.713390, -0.001431}}],
    Polygon[{{0.997684, 1.710667, 0.001431},{0.993937, 1.713390, -0.001431},{
      0.996253, 1.715073, -0.006063},{1.001431, 1.713390, -0.006063},{
      1.002316, 1.710667, -0.001431}}],
    Polygon[{{1.006063, 1.713390, 0.001431},{1.002316, 1.710667, -0.001431},{
      1.001431, 1.713390, -0.006063},{1.004632, 1.717795, -0.006063},{
      1.007495, 1.717795, -0.001431}}],
    Polygon[{{1.001431, 1.722201, -0.006063},{1.004632, 1.717795, -0.006063},{
      1.001431, 1.713390, -0.006063},{0.996253, 1.715073, -0.006063},{
      0.996253, 1.720518, -0.006063}}],
    Polygon[{{0.979886, 1.675481, 0.007311},{0.973642, 1.677510, 0.007311},{
      0.969783, 1.672198, 0.007311},{0.973642, 1.666886, 0.007311},{
      0.979886, 1.668915, 0.007311}}],
    Polygon[{{0.979886, 1.675481, 0.007311},{0.979886, 1.668915, 0.007311},{
      0.982679, 1.666886, 0.001726},{0.984405, 1.672198, -0.001726},{
      0.982679, 1.677510, 0.001726}}],
    Polygon[{{0.979886, 1.675481, 0.007311},{0.982679, 1.677510, 0.001726},{
      0.978161, 1.680792, -0.001726},{0.972575, 1.680792, 0.001726},{
      0.973642, 1.677510, 0.007311}}],
    Polygon[{{0.973642, 1.677510, 0.007311},{0.972575, 1.680792, 0.001726},{
      0.968057, 1.677510, -0.001726},{0.966331, 1.672198, 0.001726},{
      0.969783, 1.672198, 0.007311}}],
    Polygon[{{0.969783, 1.672198, 0.007311},{0.966331, 1.672198, 0.001726},{
      0.968057, 1.666886, -0.001726},{0.972575, 1.663604, 0.001726},{
      0.973642, 1.666886, 0.007311}}],
    Polygon[{{0.973642, 1.666886, 0.007311},{0.979886, 1.668915, 0.007311},{
      0.982679, 1.666886, 0.001726},{0.978161, 1.663604, -0.001726},{
      0.972575, 1.663604, 0.001726}}],
    Polygon[{{0.982679, 1.677510, 0.001726},{0.984405, 1.672198, -0.001726},{
      0.980953, 1.672198, -0.007311},{0.977094, 1.677510, -0.007311},{
      0.978161, 1.680792, -0.001726}}],
    Polygon[{{0.972575, 1.680792, 0.001726},{0.978161, 1.680792, -0.001726},{
      0.977094, 1.677510, -0.007311},{0.970850, 1.675481, -0.007311},{
      0.968057, 1.677510, -0.001726}}],
    Polygon[{{0.966331, 1.672198, 0.001726},{0.968057, 1.677510, -0.001726},{
      0.970850, 1.675481, -0.007311},{0.970850, 1.668915, -0.007311},{
      0.968057, 1.666886, -0.001726}}],
    Polygon[{{0.972575, 1.663604, 0.001726},{0.968057, 1.666886, -0.001726},{
      0.970850, 1.668915, -0.007311},{0.977094, 1.666886, -0.007311},{
      0.978161, 1.663604, -0.001726}}],
    Polygon[{{0.982679, 1.666886, 0.001726},{0.978161, 1.663604, -0.001726},{
      0.977094, 1.666886, -0.007311},{0.980953, 1.672198, -0.007311},{
      0.984405, 1.672198, -0.001726}}],
    Polygon[{{0.977094, 1.677510, -0.007311},{0.980953, 1.672198, -0.007311},{
      0.977094, 1.666886, -0.007311},{0.970850, 1.668915, -0.007311},{
      0.970850, 1.675481, -0.007311}}],
    Polygon[{{1.029150, 1.675481, 0.007311},{1.022906, 1.677510, 0.007311},{
      1.019047, 1.672198, 0.007311},{1.022906, 1.666886, 0.007311},{
      1.029150, 1.668915, 0.007311}}],
    Polygon[{{1.029150, 1.675481, 0.007311},{1.029150, 1.668915, 0.007311},{
      1.031943, 1.666886, 0.001726},{1.033669, 1.672198, -0.001726},{
      1.031943, 1.677510, 0.001726}}],
    Polygon[{{1.029150, 1.675481, 0.007311},{1.031943, 1.677510, 0.001726},{
      1.027424, 1.680792, -0.001726},{1.021839, 1.680792, 0.001726},{
      1.022906, 1.677510, 0.007311}}],
    Polygon[{{1.022906, 1.677510, 0.007311},{1.021839, 1.680792, 0.001726},{
      1.017321, 1.677510, -0.001726},{1.015595, 1.672198, 0.001726},{
      1.019047, 1.672198, 0.007311}}],
    Polygon[{{1.019047, 1.672198, 0.007311},{1.015595, 1.672198, 0.001726},{
      1.017321, 1.666886, -0.001726},{1.021839, 1.663604, 0.001726},{
      1.022906, 1.666886, 0.007311}}],
    Polygon[{{1.022906, 1.666886, 0.007311},{1.029150, 1.668915, 0.007311},{
      1.031943, 1.666886, 0.001726},{1.027424, 1.663604, -0.001726},{
      1.021839, 1.663604, 0.001726}}],
    Polygon[{{1.031943, 1.677510, 0.001726},{1.033669, 1.672198, -0.001726},{
      1.030217, 1.672198, -0.007311},{1.026358, 1.677510, -0.007311},{
      1.027424, 1.680792, -0.001726}}],
    Polygon[{{1.021839, 1.680792, 0.001726},{1.027424, 1.680792, -0.001726},{
      1.026358, 1.677510, -0.007311},{1.020114, 1.675481, -0.007311},{
      1.017321, 1.677510, -0.001726}}],
    Polygon[{{1.015595, 1.672198, 0.001726},{1.017321, 1.677510, -0.001726},{
      1.020114, 1.675481, -0.007311},{1.020114, 1.668915, -0.007311},{
      1.017321, 1.666886, -0.001726}}],
    Polygon[{{1.021839, 1.663604, 0.001726},{1.017321, 1.666886, -0.001726},{
      1.020114, 1.668915, -0.007311},{1.026358, 1.666886, -0.007311},{
      1.027424, 1.663604, -0.001726}}],
    Polygon[{{1.031943, 1.666886, 0.001726},{1.027424, 1.663604, -0.001726},{
      1.026358, 1.666886, -0.007311},{1.030217, 1.672198, -0.007311},{
      1.033669, 1.672198, -0.001726}}],
    Polygon[{{1.026358, 1.677510, -0.007311},{1.030217, 1.672198, -0.007311},{
      1.026358, 1.666886, -0.007311},{1.020114, 1.668915, -0.007311},{
      1.020114, 1.675481, -0.007311}}],
    Polygon[{{0.939659, 1.562341, 0.021933},{0.920926, 1.568427, 0.021933},{
      0.909349, 1.552492, 0.021933},{0.920926, 1.536557, 0.021933},{
      0.939659, 1.542644, 0.021933}}],
    Polygon[{{0.939659, 1.562341, 0.021933},{0.939659, 1.542644, 0.021933},{
      0.948037, 1.536557, 0.005178},{0.953214, 1.552492, -0.005178},{
      0.948037, 1.568427, 0.005178}}],
    Polygon[{{0.939659, 1.562341, 0.021933},{0.948037, 1.568427, 0.005178},{
      0.934482, 1.578276, -0.005178},{0.917727, 1.578276, 0.005178},{
      0.920926, 1.568427, 0.021933}}],
    Polygon[{{0.920926, 1.568427, 0.021933},{0.917727, 1.578276, 0.005178},{
      0.904171, 1.568427, -0.005178},{0.898994, 1.552492, 0.005178},{
      0.909349, 1.552492, 0.021933}}],
    Polygon[{{0.909349, 1.552492, 0.021933},{0.898994, 1.552492, 0.005178},{
      0.904171, 1.536557, -0.005178},{0.917727, 1.526709, 0.005178},{
      0.920926, 1.536557, 0.021933}}],
    Polygon[{{0.920926, 1.536557, 0.021933},{0.939659, 1.542644, 0.021933},{
      0.948037, 1.536557, 0.005178},{0.934482, 1.526709, -0.005178},{
      0.917727, 1.526709, 0.005178}}],
    Polygon[{{0.948037, 1.568427, 0.005178},{0.953214, 1.552492, -0.005178},{
      0.942859, 1.552492, -0.021933},{0.931282, 1.568427, -0.021933},{
      0.934482, 1.578276, -0.005178}}],
    Polygon[{{0.917727, 1.578276, 0.005178},{0.934482, 1.578276, -0.005178},{
      0.931282, 1.568427, -0.021933},{0.912549, 1.562341, -0.021933},{
      0.904171, 1.568427, -0.005178}}],
    Polygon[{{0.898994, 1.552492, 0.005178},{0.904171, 1.568427, -0.005178},{
      0.912549, 1.562341, -0.021933},{0.912549, 1.542644, -0.021933},{
      0.904171, 1.536557, -0.005178}}],
    Polygon[{{0.917727, 1.526709, 0.005178},{0.904171, 1.536557, -0.005178},{
      0.912549, 1.542644, -0.021933},{0.931282, 1.536557, -0.021933},{
      0.934482, 1.526709, -0.005178}}],
    Polygon[{{0.948037, 1.536557, 0.005178},{0.934482, 1.526709, -0.005178},{
      0.931282, 1.536557, -0.021933},{0.942859, 1.552492, -0.021933},{
      0.953214, 1.552492, -0.005178}}],
    Polygon[{{0.931282, 1.568427, -0.021933},{0.942859, 1.552492, -0.021933},{
      0.931282, 1.536557, -0.021933},{0.912549, 1.542644, -0.021933},{
      0.912549, 1.562341, -0.021933}}],
    Polygon[{{0.904131, 1.531061, 0.011754},{0.894092, 1.534323, 0.011754},{
      0.887887, 1.525783, 0.011754},{0.894092, 1.517244, 0.011754},{
      0.904131, 1.520506, 0.011754}}],
    Polygon[{{0.904131, 1.531061, 0.011754},{0.904131, 1.520506, 0.011754},{
      0.908620, 1.517244, 0.002775},{0.911395, 1.525783, -0.002775},{
      0.908620, 1.534323, 0.002775}}],
    Polygon[{{0.904131, 1.531061, 0.011754},{0.908620, 1.534323, 0.002775},{
      0.901356, 1.539601, -0.002775},{0.892377, 1.539601, 0.002775},{
      0.894092, 1.534323, 0.011754}}],
    Polygon[{{0.894092, 1.534323, 0.011754},{0.892377, 1.539601, 0.002775},{
      0.885113, 1.534323, -0.002775},{0.882338, 1.525783, 0.002775},{
      0.887887, 1.525783, 0.011754}}],
    Polygon[{{0.887887, 1.525783, 0.011754},{0.882338, 1.525783, 0.002775},{
      0.885113, 1.517244, -0.002775},{0.892377, 1.511966, 0.002775},{
      0.894092, 1.517244, 0.011754}}],
    Polygon[{{0.894092, 1.517244, 0.011754},{0.904131, 1.520506, 0.011754},{
      0.908620, 1.517244, 0.002775},{0.901356, 1.511966, -0.002775},{
      0.892377, 1.511966, 0.002775}}],
    Polygon[{{0.908620, 1.534323, 0.002775},{0.911395, 1.525783, -0.002775},{
      0.905845, 1.525783, -0.011754},{0.899641, 1.534323, -0.011754},{
      0.901356, 1.539601, -0.002775}}],
    Polygon[{{0.892377, 1.539601, 0.002775},{0.901356, 1.539601, -0.002775},{
      0.899641, 1.534323, -0.011754},{0.889602, 1.531061, -0.011754},{
      0.885113, 1.534323, -0.002775}}],
    Polygon[{{0.882338, 1.525783, 0.002775},{0.885113, 1.534323, -0.002775},{
      0.889602, 1.531061, -0.011754},{0.889602, 1.520506, -0.011754},{
      0.885113, 1.517244, -0.002775}}],
    Polygon[{{0.892377, 1.511966, 0.002775},{0.885113, 1.517244, -0.002775},{
      0.889602, 1.520506, -0.011754},{0.899641, 1.517244, -0.011754},{
      0.901356, 1.511966, -0.002775}}],
    Polygon[{{0.908620, 1.517244, 0.002775},{0.901356, 1.511966, -0.002775},{
      0.899641, 1.517244, -0.011754},{0.905845, 1.525783, -0.011754},{
      0.911395, 1.525783, -0.002775}}],
    Polygon[{{0.899641, 1.534323, -0.011754},{0.905845, 1.525783, -0.011754},{
      0.899641, 1.517244, -0.011754},{0.889602, 1.520506, -0.011754},{
      0.889602, 1.531061, -0.011754}}],
    Polygon[{{0.932995, 1.591575, 0.008215},{0.925979, 1.593855, 0.008215},{
      0.921642, 1.587887, 0.008215},{0.925979, 1.581918, 0.008215},{
      0.932995, 1.584198, 0.008215}}],
    Polygon[{{0.932995, 1.591575, 0.008215},{0.932995, 1.584198, 0.008215},{
      0.936133, 1.581918, 0.001939},{0.938072, 1.587887, -0.001939},{
      0.936133, 1.593855, 0.001939}}],
    Polygon[{{0.932995, 1.591575, 0.008215},{0.936133, 1.593855, 0.001939},{
      0.931056, 1.597544, -0.001939},{0.924780, 1.597544, 0.001939},{
      0.925979, 1.593855, 0.008215}}],
    Polygon[{{0.925979, 1.593855, 0.008215},{0.924780, 1.597544, 0.001939},{
      0.919703, 1.593855, -0.001939},{0.917764, 1.587887, 0.001939},{
      0.921642, 1.587887, 0.008215}}],
    Polygon[{{0.921642, 1.587887, 0.008215},{0.917764, 1.587887, 0.001939},{
      0.919703, 1.581918, -0.001939},{0.924780, 1.578229, 0.001939},{
      0.925979, 1.581918, 0.008215}}],
    Polygon[{{0.925979, 1.581918, 0.008215},{0.932995, 1.584198, 0.008215},{
      0.936133, 1.581918, 0.001939},{0.931056, 1.578229, -0.001939},{
      0.924780, 1.578229, 0.001939}}],
    Polygon[{{0.936133, 1.593855, 0.001939},{0.938072, 1.587887, -0.001939},{
      0.934193, 1.587887, -0.008215},{0.929857, 1.593855, -0.008215},{
      0.931056, 1.597544, -0.001939}}],
    Polygon[{{0.924780, 1.597544, 0.001939},{0.931056, 1.597544, -0.001939},{
      0.929857, 1.593855, -0.008215},{0.922841, 1.591575, -0.008215},{
      0.919703, 1.593855, -0.001939}}],
    Polygon[{{0.917764, 1.587887, 0.001939},{0.919703, 1.593855, -0.001939},{
      0.922841, 1.591575, -0.008215},{0.922841, 1.584198, -0.008215},{
      0.919703, 1.581918, -0.001939}}],
    Polygon[{{0.924780, 1.578229, 0.001939},{0.919703, 1.581918, -0.001939},{
      0.922841, 1.584198, -0.008215},{0.929857, 1.581918, -0.008215},{
      0.931056, 1.578229, -0.001939}}],
    Polygon[{{0.936133, 1.581918, 0.001939},{0.931056, 1.578229, -0.001939},{
      0.929857, 1.581918, -0.008215},{0.934193, 1.587887, -0.008215},{
      0.938072, 1.587887, -0.001939}}],
    Polygon[{{0.929857, 1.593855, -0.008215},{0.934193, 1.587887, -0.008215},{
      0.929857, 1.581918, -0.008215},{0.922841, 1.584198, -0.008215},{
      0.922841, 1.591575, -0.008215}}],
    Polygon[{{0.963569, 1.547004, 0.007140},{0.957471, 1.548985, 0.007140},{
      0.953702, 1.543797, 0.007140},{0.957471, 1.538610, 0.007140},{
      0.963569, 1.540591, 0.007140}}],
    Polygon[{{0.963569, 1.547004, 0.007140},{0.963569, 1.540591, 0.007140},{
      0.966297, 1.538610, 0.001686},{0.967982, 1.543797, -0.001686},{
      0.966297, 1.548985, 0.001686}}],
    Polygon[{{0.963569, 1.547004, 0.007140},{0.966297, 1.548985, 0.001686},{
      0.961884, 1.552191, -0.001686},{0.956429, 1.552191, 0.001686},{
      0.957471, 1.548985, 0.007140}}],
    Polygon[{{0.957471, 1.548985, 0.007140},{0.956429, 1.552191, 0.001686},{
      0.952017, 1.548985, -0.001686},{0.950331, 1.543797, 0.001686},{
      0.953702, 1.543797, 0.007140}}],
    Polygon[{{0.953702, 1.543797, 0.007140},{0.950331, 1.543797, 0.001686},{
      0.952017, 1.538610, -0.001686},{0.956429, 1.535404, 0.001686},{
      0.957471, 1.538610, 0.007140}}],
    Polygon[{{0.957471, 1.538610, 0.007140},{0.963569, 1.540591, 0.007140},{
      0.966297, 1.538610, 0.001686},{0.961884, 1.535404, -0.001686},{
      0.956429, 1.535404, 0.001686}}],
    Polygon[{{0.966297, 1.548985, 0.001686},{0.967982, 1.543797, -0.001686},{
      0.964611, 1.543797, -0.007140},{0.960842, 1.548985, -0.007140},{
      0.961884, 1.552191, -0.001686}}],
    Polygon[{{0.956429, 1.552191, 0.001686},{0.961884, 1.552191, -0.001686},{
      0.960842, 1.548985, -0.007140},{0.954744, 1.547004, -0.007140},{
      0.952017, 1.548985, -0.001686}}],
    Polygon[{{0.950331, 1.543797, 0.001686},{0.952017, 1.548985, -0.001686},{
      0.954744, 1.547004, -0.007140},{0.954744, 1.540591, -0.007140},{
      0.952017, 1.538610, -0.001686}}],
    Polygon[{{0.956429, 1.535404, 0.001686},{0.952017, 1.538610, -0.001686},{
      0.954744, 1.540591, -0.007140},{0.960842, 1.538610, -0.007140},{
      0.961884, 1.535404, -0.001686}}],
    Polygon[{{0.966297, 1.538610, 0.001686},{0.961884, 1.535404, -0.001686},{
      0.960842, 1.538610, -0.007140},{0.964611, 1.543797, -0.007140},{
      0.967982, 1.543797, -0.001686}}],
    Polygon[{{0.960842, 1.548985, -0.007140},{0.964611, 1.543797, -0.007140},{
      0.960842, 1.538610, -0.007140},{0.954744, 1.540591, -0.007140},{
      0.954744, 1.547004, -0.007140}}],
    Polygon[{{1.087451, 1.562341, 0.021933},{1.068718, 1.568427, 0.021933},{
      1.057141, 1.552492, 0.021933},{1.068718, 1.536557, 0.021933},{
      1.087451, 1.542644, 0.021933}}],
    Polygon[{{1.087451, 1.562341, 0.021933},{1.087451, 1.542644, 0.021933},{
      1.095829, 1.536557, 0.005178},{1.101006, 1.552492, -0.005178},{
      1.095829, 1.568427, 0.005178}}],
    Polygon[{{1.087451, 1.562341, 0.021933},{1.095829, 1.568427, 0.005178},{
      1.082273, 1.578276, -0.005178},{1.065518, 1.578276, 0.005178},{
      1.068718, 1.568427, 0.021933}}],
    Polygon[{{1.068718, 1.568427, 0.021933},{1.065518, 1.578276, 0.005178},{
      1.051963, 1.568427, -0.005178},{1.046786, 1.552492, 0.005178},{
      1.057141, 1.552492, 0.021933}}],
    Polygon[{{1.057141, 1.552492, 0.021933},{1.046786, 1.552492, 0.005178},{
      1.051963, 1.536557, -0.005178},{1.065518, 1.526709, 0.005178},{
      1.068718, 1.536557, 0.021933}}],
    Polygon[{{1.068718, 1.536557, 0.021933},{1.087451, 1.542644, 0.021933},{
      1.095829, 1.536557, 0.005178},{1.082273, 1.526709, -0.005178},{
      1.065518, 1.526709, 0.005178}}],
    Polygon[{{1.095829, 1.568427, 0.005178},{1.101006, 1.552492, -0.005178},{
      1.090651, 1.552492, -0.021933},{1.079074, 1.568427, -0.021933},{
      1.082273, 1.578276, -0.005178}}],
    Polygon[{{1.065518, 1.578276, 0.005178},{1.082273, 1.578276, -0.005178},{
      1.079074, 1.568427, -0.021933},{1.060341, 1.562341, -0.021933},{
      1.051963, 1.568427, -0.005178}}],
    Polygon[{{1.046786, 1.552492, 0.005178},{1.051963, 1.568427, -0.005178},{
      1.060341, 1.562341, -0.021933},{1.060341, 1.542644, -0.021933},{
      1.051963, 1.536557, -0.005178}}],
    Polygon[{{1.065518, 1.526709, 0.005178},{1.051963, 1.536557, -0.005178},{
      1.060341, 1.542644, -0.021933},{1.079074, 1.536557, -0.021933},{
      1.082273, 1.526709, -0.005178}}],
    Polygon[{{1.095829, 1.536557, 0.005178},{1.082273, 1.526709, -0.005178},{
      1.079074, 1.536557, -0.021933},{1.090651, 1.552492, -0.021933},{
      1.101006, 1.552492, -0.005178}}],
    Polygon[{{1.079074, 1.568427, -0.021933},{1.090651, 1.552492, -0.021933},{
      1.079074, 1.536557, -0.021933},{1.060341, 1.542644, -0.021933},{
      1.060341, 1.562341, -0.021933}}],
    Polygon[{{1.110398, 1.531061, 0.011754},{1.100359, 1.534323, 0.011754},{
      1.094155, 1.525783, 0.011754},{1.100359, 1.517244, 0.011754},{
      1.110398, 1.520506, 0.011754}}],
    Polygon[{{1.110398, 1.531061, 0.011754},{1.110398, 1.520506, 0.011754},{
      1.114887, 1.517244, 0.002775},{1.117662, 1.525783, -0.002775},{
      1.114887, 1.534323, 0.002775}}],
    Polygon[{{1.110398, 1.531061, 0.011754},{1.114887, 1.534323, 0.002775},{
      1.107623, 1.539601, -0.002775},{1.098644, 1.539601, 0.002775},{
      1.100359, 1.534323, 0.011754}}],
    Polygon[{{1.100359, 1.534323, 0.011754},{1.098644, 1.539601, 0.002775},{
      1.091380, 1.534323, -0.002775},{1.088605, 1.525783, 0.002775},{
      1.094155, 1.525783, 0.011754}}],
    Polygon[{{1.094155, 1.525783, 0.011754},{1.088605, 1.525783, 0.002775},{
      1.091380, 1.517244, -0.002775},{1.098644, 1.511966, 0.002775},{
      1.100359, 1.517244, 0.011754}}],
    Polygon[{{1.100359, 1.517244, 0.011754},{1.110398, 1.520506, 0.011754},{
      1.114887, 1.517244, 0.002775},{1.107623, 1.511966, -0.002775},{
      1.098644, 1.511966, 0.002775}}],
    Polygon[{{1.114887, 1.534323, 0.002775},{1.117662, 1.525783, -0.002775},{
      1.112113, 1.525783, -0.011754},{1.105908, 1.534323, -0.011754},{
      1.107623, 1.539601, -0.002775}}],
    Polygon[{{1.098644, 1.539601, 0.002775},{1.107623, 1.539601, -0.002775},{
      1.105908, 1.534323, -0.011754},{1.095870, 1.531061, -0.011754},{
      1.091380, 1.534323, -0.002775}}],
    Polygon[{{1.088605, 1.525783, 0.002775},{1.091380, 1.534323, -0.002775},{
      1.095870, 1.531061, -0.011754},{1.095870, 1.520506, -0.011754},{
      1.091380, 1.517244, -0.002775}}],
    Polygon[{{1.098644, 1.511966, 0.002775},{1.091380, 1.517244, -0.002775},{
      1.095870, 1.520506, -0.011754},{1.105908, 1.517244, -0.011754},{
      1.107623, 1.511966, -0.002775}}],
    Polygon[{{1.114887, 1.517244, 0.002775},{1.107623, 1.511966, -0.002775},{
      1.105908, 1.517244, -0.011754},{1.112113, 1.525783, -0.011754},{
      1.117662, 1.525783, -0.002775}}],
    Polygon[{{1.105908, 1.534323, -0.011754},{1.112113, 1.525783, -0.011754},{
      1.105908, 1.517244, -0.011754},{1.095870, 1.520506, -0.011754},{
      1.095870, 1.531061, -0.011754}}],
    Polygon[{{1.077159, 1.591575, 0.008215},{1.070143, 1.593855, 0.008215},{
      1.065807, 1.587887, 0.008215},{1.070143, 1.581918, 0.008215},{
      1.077159, 1.584198, 0.008215}}],
    Polygon[{{1.077159, 1.591575, 0.008215},{1.077159, 1.584198, 0.008215},{
      1.080297, 1.581918, 0.001939},{1.082236, 1.587887, -0.001939},{
      1.080297, 1.593855, 0.001939}}],
    Polygon[{{1.077159, 1.591575, 0.008215},{1.080297, 1.593855, 0.001939},{
      1.075220, 1.597544, -0.001939},{1.068944, 1.597544, 0.001939},{
      1.070143, 1.593855, 0.008215}}],
    Polygon[{{1.070143, 1.593855, 0.008215},{1.068944, 1.597544, 0.001939},{
      1.063867, 1.593855, -0.001939},{1.061928, 1.587887, 0.001939},{
      1.065807, 1.587887, 0.008215}}],
    Polygon[{{1.065807, 1.587887, 0.008215},{1.061928, 1.587887, 0.001939},{
      1.063867, 1.581918, -0.001939},{1.068944, 1.578229, 0.001939},{
      1.070143, 1.581918, 0.008215}}],
    Polygon[{{1.070143, 1.581918, 0.008215},{1.077159, 1.584198, 0.008215},{
      1.080297, 1.581918, 0.001939},{1.075220, 1.578229, -0.001939},{
      1.068944, 1.578229, 0.001939}}],
    Polygon[{{1.080297, 1.593855, 0.001939},{1.082236, 1.587887, -0.001939},{
      1.078358, 1.587887, -0.008215},{1.074021, 1.593855, -0.008215},{
      1.075220, 1.597544, -0.001939}}],
    Polygon[{{1.068944, 1.597544, 0.001939},{1.075220, 1.597544, -0.001939},{
      1.074021, 1.593855, -0.008215},{1.067005, 1.591575, -0.008215},{
      1.063867, 1.593855, -0.001939}}],
    Polygon[{{1.061928, 1.587887, 0.001939},{1.063867, 1.593855, -0.001939},{
      1.067005, 1.591575, -0.008215},{1.067005, 1.584198, -0.008215},{
      1.063867, 1.581918, -0.001939}}],
    Polygon[{{1.068944, 1.578229, 0.001939},{1.063867, 1.581918, -0.001939},{
      1.067005, 1.584198, -0.008215},{1.074021, 1.581918, -0.008215},{
      1.075220, 1.578229, -0.001939}}],
    Polygon[{{1.080297, 1.581918, 0.001939},{1.075220, 1.578229, -0.001939},{
      1.074021, 1.581918, -0.008215},{1.078358, 1.587887, -0.008215},{
      1.082236, 1.587887, -0.001939}}],
    Polygon[{{1.074021, 1.593855, -0.008215},{1.078358, 1.587887, -0.008215},{
      1.074021, 1.581918, -0.008215},{1.067005, 1.584198, -0.008215},{
      1.067005, 1.591575, -0.008215}}],
    Polygon[{{1.045256, 1.547004, 0.007140},{1.039158, 1.548985, 0.007140},{
      1.035389, 1.543797, 0.007140},{1.039158, 1.538610, 0.007140},{
      1.045256, 1.540591, 0.007140}}],
    Polygon[{{1.045256, 1.547004, 0.007140},{1.045256, 1.540591, 0.007140},{
      1.047984, 1.538610, 0.001686},{1.049669, 1.543797, -0.001686},{
      1.047984, 1.548985, 0.001686}}],
    Polygon[{{1.045256, 1.547004, 0.007140},{1.047984, 1.548985, 0.001686},{
      1.043571, 1.552191, -0.001686},{1.038116, 1.552191, 0.001686},{
      1.039158, 1.548985, 0.007140}}],
    Polygon[{{1.039158, 1.548985, 0.007140},{1.038116, 1.552191, 0.001686},{
      1.033703, 1.548985, -0.001686},{1.032018, 1.543797, 0.001686},{
      1.035389, 1.543797, 0.007140}}],
    Polygon[{{1.035389, 1.543797, 0.007140},{1.032018, 1.543797, 0.001686},{
      1.033703, 1.538610, -0.001686},{1.038116, 1.535404, 0.001686},{
      1.039158, 1.538610, 0.007140}}],
    Polygon[{{1.039158, 1.538610, 0.007140},{1.045256, 1.540591, 0.007140},{
      1.047984, 1.538610, 0.001686},{1.043571, 1.535404, -0.001686},{
      1.038116, 1.535404, 0.001686}}],
    Polygon[{{1.047984, 1.548985, 0.001686},{1.049669, 1.543797, -0.001686},{
      1.046298, 1.543797, -0.007140},{1.042529, 1.548985, -0.007140},{
      1.043571, 1.552191, -0.001686}}],
    Polygon[{{1.038116, 1.552191, 0.001686},{1.043571, 1.552191, -0.001686},{
      1.042529, 1.548985, -0.007140},{1.036431, 1.547004, -0.007140},{
      1.033703, 1.548985, -0.001686}}],
    Polygon[{{1.032018, 1.543797, 0.001686},{1.033703, 1.548985, -0.001686},{
      1.036431, 1.547004, -0.007140},{1.036431, 1.540591, -0.007140},{
      1.033703, 1.538610, -0.001686}}],
    Polygon[{{1.038116, 1.535404, 0.001686},{1.033703, 1.538610, -0.001686},{
      1.036431, 1.540591, -0.007140},{1.042529, 1.538610, -0.007140},{
      1.043571, 1.535404, -0.001686}}],
    Polygon[{{1.047984, 1.538610, 0.001686},{1.043571, 1.535404, -0.001686},{
      1.042529, 1.538610, -0.007140},{1.046298, 1.543797, -0.007140},{
      1.049669, 1.543797, -0.001686}}],
    Polygon[{{1.042529, 1.548985, -0.007140},{1.046298, 1.543797, -0.007140},{
      1.042529, 1.538610, -0.007140},{1.036431, 1.540591, -0.007140},{
      1.036431, 1.547004, -0.007140}}],
    Polygon[{{0.818978, 1.222921, 0.065798},{0.762779, 1.241181, 0.065798},{
      0.728047, 1.193376, 0.065798},{0.762779, 1.145571, 0.065798},{
      0.818978, 1.163831, 0.065798}}],
    Polygon[{{0.818978, 1.222921, 0.065798},{0.818978, 1.163831, 0.065798},{
      0.844110, 1.145571, 0.015533},{0.859643, 1.193376, -0.015533},{
      0.844110, 1.241181, 0.015533}}],
    Polygon[{{0.818978, 1.222921, 0.065798},{0.844110, 1.241181, 0.015533},{
      0.803445, 1.270726, -0.015533},{0.753180, 1.270726, 0.015533},{
      0.762779, 1.241181, 0.065798}}],
    Polygon[{{0.762779, 1.241181, 0.065798},{0.753180, 1.270726, 0.015533},{
      0.712514, 1.241181, -0.015533},{0.696981, 1.193376, 0.015533},{
      0.728047, 1.193376, 0.065798}}],
    Polygon[{{0.728047, 1.193376, 0.065798},{0.696981, 1.193376, 0.015533},{
      0.712514, 1.145571, -0.015533},{0.753180, 1.116025, 0.015533},{
      0.762779, 1.145571, 0.065798}}],
    Polygon[{{0.762779, 1.145571, 0.065798},{0.818978, 1.163831, 0.065798},{
      0.844110, 1.145571, 0.015533},{0.803445, 1.116025, -0.015533},{
      0.753180, 1.116025, 0.015533}}],
    Polygon[{{0.844110, 1.241181, 0.015533},{0.859643, 1.193376, -0.015533},{
      0.828577, 1.193376, -0.065798},{0.793845, 1.241181, -0.065798},{
      0.803445, 1.270726, -0.015533}}],
    Polygon[{{0.753180, 1.270726, 0.015533},{0.803445, 1.270726, -0.015533},{
      0.793845, 1.241181, -0.065798},{0.737647, 1.222921, -0.065798},{
      0.712514, 1.241181, -0.015533}}],
    Polygon[{{0.696981, 1.193376, 0.015533},{0.712514, 1.241181, -0.015533},{
      0.737647, 1.222921, -0.065798},{0.737647, 1.163831, -0.065798},{
      0.712514, 1.145571, -0.015533}}],
    Polygon[{{0.753180, 1.116025, 0.015533},{0.712514, 1.145571, -0.015533},{
      0.737647, 1.163831, -0.065798},{0.793845, 1.145571, -0.065798},{
      0.803445, 1.116025, -0.015533}}],
    Polygon[{{0.844110, 1.145571, 0.015533},{0.803445, 1.116025, -0.015533},{
      0.793845, 1.145571, -0.065798},{0.828577, 1.193376, -0.065798},{
      0.859643, 1.193376, -0.015533}}],
    Polygon[{{0.793845, 1.241181, -0.065798},{0.828577, 1.193376, -0.065798},{
      0.793845, 1.145571, -0.065798},{0.737647, 1.163831, -0.065798},{
      0.737647, 1.222921, -0.065798}}],
    Polygon[{{0.712391, 1.129082, 0.035261},{0.682275, 1.138867, 0.035261},{
      0.663662, 1.113249, 0.035261},{0.682275, 1.087630, 0.035261},{
      0.712391, 1.097415, 0.035261}}],
    Polygon[{{0.712391, 1.129082, 0.035261},{0.712391, 1.097415, 0.035261},{
      0.725860, 1.087630, 0.008324},{0.734184, 1.113249, -0.008324},{
      0.725860, 1.138867, 0.008324}}],
    Polygon[{{0.712391, 1.129082, 0.035261},{0.725860, 1.138867, 0.008324},{
      0.704067, 1.154701, -0.008324},{0.677130, 1.154701, 0.008324},{
      0.682275, 1.138867, 0.035261}}],
    Polygon[{{0.682275, 1.138867, 0.035261},{0.677130, 1.154701, 0.008324},{
      0.655338, 1.138867, -0.008324},{0.647014, 1.113249, 0.008324},{
      0.663662, 1.113249, 0.035261}}],
    Polygon[{{0.663662, 1.113249, 0.035261},{0.647014, 1.113249, 0.008324},{
      0.655338, 1.087630, -0.008324},{0.677130, 1.071797, 0.008324},{
      0.682275, 1.087630, 0.035261}}],
    Polygon[{{0.682275, 1.087630, 0.035261},{0.712391, 1.097415, 0.035261},{
      0.725860, 1.087630, 0.008324},{0.704067, 1.071797, -0.008324},{
      0.677130, 1.071797, 0.008324}}],
    Polygon[{{0.725860, 1.138867, 0.008324},{0.734184, 1.113249, -0.008324},{
      0.717536, 1.113249, -0.035261},{0.698923, 1.138867, -0.035261},{
      0.704067, 1.154701, -0.008324}}],
    Polygon[{{0.677130, 1.154701, 0.008324},{0.704067, 1.154701, -0.008324},{
      0.698923, 1.138867, -0.035261},{0.668806, 1.129082, -0.035261},{
      0.655338, 1.138867, -0.008324}}],
    Polygon[{{0.647014, 1.113249, 0.008324},{0.655338, 1.138867, -0.008324},{
      0.668806, 1.129082, -0.035261},{0.668806, 1.097415, -0.035261},{
      0.655338, 1.087630, -0.008324}}],
    Polygon[{{0.677130, 1.071797, 0.008324},{0.655338, 1.087630, -0.008324},{
      0.668806, 1.097415, -0.035261},{0.698923, 1.087630, -0.035261},{
      0.704067, 1.071797, -0.008324}}],
    Polygon[{{0.725860, 1.087630, 0.008324},{0.704067, 1.071797, -0.008324},{
      0.698923, 1.087630, -0.035261},{0.717536, 1.113249, -0.035261},{
      0.734184, 1.113249, -0.008324}}],
    Polygon[{{0.698923, 1.138867, -0.035261},{0.717536, 1.113249, -0.035261},{
      0.698923, 1.087630, -0.035261},{0.668806, 1.097415, -0.035261},{
      0.668806, 1.129082, -0.035261}}],
    Polygon[{{0.657893, 1.074307, 0.021933},{0.639160, 1.080394, 0.021933},{
      0.627582, 1.064459, 0.021933},{0.639160, 1.048524, 0.021933},{
      0.657893, 1.054610, 0.021933}}],
    Polygon[{{0.657893, 1.074307, 0.021933},{0.657893, 1.054610, 0.021933},{
      0.666270, 1.048524, 0.005178},{0.671448, 1.064459, -0.005178},{
      0.666270, 1.080394, 0.005178}}],
    Polygon[{{0.657893, 1.074307, 0.021933},{0.666270, 1.080394, 0.005178},{
      0.652715, 1.090242, -0.005178},{0.635960, 1.090242, 0.005178},{
      0.639160, 1.080394, 0.021933}}],
    Polygon[{{0.639160, 1.080394, 0.021933},{0.635960, 1.090242, 0.005178},{
      0.622405, 1.080394, -0.005178},{0.617227, 1.064459, 0.005178},{
      0.627582, 1.064459, 0.021933}}],
    Polygon[{{0.627582, 1.064459, 0.021933},{0.617227, 1.064459, 0.005178},{
      0.622405, 1.048524, -0.005178},{0.635960, 1.038675, 0.005178},{
      0.639160, 1.048524, 0.021933}}],
    Polygon[{{0.639160, 1.048524, 0.021933},{0.657893, 1.054610, 0.021933},{
      0.666270, 1.048524, 0.005178},{0.652715, 1.038675, -0.005178},{
      0.635960, 1.038675, 0.005178}}],
    Polygon[{{0.666270, 1.080394, 0.005178},{0.671448, 1.064459, -0.005178},{
      0.661093, 1.064459, -0.021933},{0.649515, 1.080394, -0.021933},{
      0.652715, 1.090242, -0.005178}}],
    Polygon[{{0.635960, 1.090242, 0.005178},{0.652715, 1.090242, -0.005178},{
      0.649515, 1.080394, -0.021933},{0.630782, 1.074307, -0.021933},{
      0.622405, 1.080394, -0.005178}}],
    Polygon[{{0.617227, 1.064459, 0.005178},{0.622405, 1.080394, -0.005178},{
      0.630782, 1.074307, -0.021933},{0.630782, 1.054610, -0.021933},{
      0.622405, 1.048524, -0.005178}}],
    Polygon[{{0.635960, 1.038675, 0.005178},{0.622405, 1.048524, -0.005178},{
      0.630782, 1.054610, -0.021933},{0.649515, 1.048524, -0.021933},{
      0.652715, 1.038675, -0.005178}}],
    Polygon[{{0.666270, 1.048524, 0.005178},{0.652715, 1.038675, -0.005178},{
      0.649515, 1.048524, -0.021933},{0.661093, 1.064459, -0.021933},{
      0.671448, 1.064459, -0.005178}}],
    Polygon[{{0.649515, 1.080394, -0.021933},{0.661093, 1.064459, -0.021933},{
      0.649515, 1.048524, -0.021933},{0.630782, 1.054610, -0.021933},{
      0.630782, 1.074307, -0.021933}}],
    Polygon[{{0.697863, 1.173796, 0.011754},{0.687824, 1.177057, 0.011754},{
      0.681620, 1.168518, 0.011754},{0.687824, 1.159978, 0.011754},{
      0.697863, 1.163240, 0.011754}}],
    Polygon[{{0.697863, 1.173796, 0.011754},{0.697863, 1.163240, 0.011754},{
      0.702353, 1.159978, 0.002775},{0.705127, 1.168518, -0.002775},{
      0.702353, 1.177057, 0.002775}}],
    Polygon[{{0.697863, 1.173796, 0.011754},{0.702353, 1.177057, 0.002775},{
      0.695088, 1.182335, -0.002775},{0.686109, 1.182335, 0.002775},{
      0.687824, 1.177057, 0.011754}}],
    Polygon[{{0.687824, 1.177057, 0.011754},{0.686109, 1.182335, 0.002775},{
      0.678845, 1.177057, -0.002775},{0.676071, 1.168518, 0.002775},{
      0.681620, 1.168518, 0.011754}}],
    Polygon[{{0.681620, 1.168518, 0.011754},{0.676071, 1.168518, 0.002775},{
      0.678845, 1.159978, -0.002775},{0.686109, 1.154701, 0.002775},{
      0.687824, 1.159978, 0.011754}}],
    Polygon[{{0.687824, 1.159978, 0.011754},{0.697863, 1.163240, 0.011754},{
      0.702353, 1.159978, 0.002775},{0.695088, 1.154701, -0.002775},{
      0.686109, 1.154701, 0.002775}}],
    Polygon[{{0.702353, 1.177057, 0.002775},{0.705127, 1.168518, -0.002775},{
      0.699578, 1.168518, -0.011754},{0.693374, 1.177057, -0.011754},{
      0.695088, 1.182335, -0.002775}}],
    Polygon[{{0.686109, 1.182335, 0.002775},{0.695088, 1.182335, -0.002775},{
      0.693374, 1.177057, -0.011754},{0.683335, 1.173796, -0.011754},{
      0.678845, 1.177057, -0.002775}}],
    Polygon[{{0.676071, 1.168518, 0.002775},{0.678845, 1.177057, -0.002775},{
      0.683335, 1.173796, -0.011754},{0.683335, 1.163240, -0.011754},{
      0.678845, 1.159978, -0.002775}}],
    Polygon[{{0.686109, 1.154701, 0.002775},{0.678845, 1.159978, -0.002775},{
      0.683335, 1.163240, -0.011754},{0.693374, 1.159978, -0.011754},{
      0.695088, 1.154701, -0.002775}}],
    Polygon[{{0.702353, 1.159978, 0.002775},{0.695088, 1.154701, -0.002775},{
      0.693374, 1.159978, -0.011754},{0.699578, 1.168518, -0.011754},{
      0.705127, 1.168518, -0.002775}}],
    Polygon[{{0.693374, 1.177057, -0.011754},{0.699578, 1.168518, -0.011754},{
      0.693374, 1.159978, -0.011754},{0.683335, 1.163240, -0.011754},{
      0.683335, 1.173796, -0.011754}}],
    Polygon[{{0.751596, 1.114504, 0.010966},{0.742230, 1.117547, 0.010966},{
      0.736441, 1.109580, 0.010966},{0.742230, 1.101612, 0.010966},{
      0.751596, 1.104655, 0.010966}}],
    Polygon[{{0.751596, 1.114504, 0.010966},{0.751596, 1.104655, 0.010966},{
      0.755785, 1.101612, 0.002589},{0.758374, 1.109580, -0.002589},{
      0.755785, 1.117547, 0.002589}}],
    Polygon[{{0.751596, 1.114504, 0.010966},{0.755785, 1.117547, 0.002589},{
      0.749007, 1.122471, -0.002589},{0.740630, 1.122471, 0.002589},{
      0.742230, 1.117547, 0.010966}}],
    Polygon[{{0.742230, 1.117547, 0.010966},{0.740630, 1.122471, 0.002589},{
      0.733852, 1.117547, -0.002589},{0.731263, 1.109580, 0.002589},{
      0.736441, 1.109580, 0.010966}}],
    Polygon[{{0.736441, 1.109580, 0.010966},{0.731263, 1.109580, 0.002589},{
      0.733852, 1.101612, -0.002589},{0.740630, 1.096688, 0.002589},{
      0.742230, 1.101612, 0.010966}}],
    Polygon[{{0.742230, 1.101612, 0.010966},{0.751596, 1.104655, 0.010966},{
      0.755785, 1.101612, 0.002589},{0.749007, 1.096688, -0.002589},{
      0.740630, 1.096688, 0.002589}}],
    Polygon[{{0.755785, 1.117547, 0.002589},{0.758374, 1.109580, -0.002589},{
      0.753196, 1.109580, -0.010966},{0.747407, 1.117547, -0.010966},{
      0.749007, 1.122471, -0.002589}}],
    Polygon[{{0.740630, 1.122471, 0.002589},{0.749007, 1.122471, -0.002589},{
      0.747407, 1.117547, -0.010966},{0.738041, 1.114504, -0.010966},{
      0.733852, 1.117547, -0.002589}}],
    Polygon[{{0.731263, 1.109580, 0.002589},{0.733852, 1.117547, -0.002589},{
      0.738041, 1.114504, -0.010966},{0.738041, 1.104655, -0.010966},{
      0.733852, 1.101612, -0.002589}}],
    Polygon[{{0.740630, 1.096688, 0.002589},{0.733852, 1.101612, -0.002589},{
      0.738041, 1.104655, -0.010966},{0.747407, 1.101612, -0.010966},{
      0.749007, 1.096688, -0.002589}}],
    Polygon[{{0.755785, 1.101612, 0.002589},{0.749007, 1.096688, -0.002589},{
      0.747407, 1.101612, -0.010966},{0.753196, 1.109580, -0.010966},{
      0.758374, 1.109580, -0.002589}}],
    Polygon[{{0.747407, 1.117547, -0.010966},{0.753196, 1.109580, -0.010966},{
      0.747407, 1.101612, -0.010966},{0.738041, 1.104655, -0.010966},{
      0.738041, 1.114504, -0.010966}}],
    Polygon[{{0.798985, 1.310624, 0.024645},{0.777936, 1.317464, 0.024645},{
      0.764927, 1.299558, 0.024645},{0.777936, 1.281653, 0.024645},{
      0.798985, 1.288492, 0.024645}}],
    Polygon[{{0.798985, 1.310624, 0.024645},{0.798985, 1.288492, 0.024645},{
      0.808398, 1.281653, 0.005818},{0.814216, 1.299558, -0.005818},{
      0.808398, 1.317464, 0.005818}}],
    Polygon[{{0.798985, 1.310624, 0.024645},{0.808398, 1.317464, 0.005818},{
      0.793167, 1.328530, -0.005818},{0.774340, 1.328530, 0.005818},{
      0.777936, 1.317464, 0.024645}}],
    Polygon[{{0.777936, 1.317464, 0.024645},{0.774340, 1.328530, 0.005818},{
      0.759109, 1.317464, -0.005818},{0.753291, 1.299558, 0.005818},{
      0.764927, 1.299558, 0.024645}}],
    Polygon[{{0.764927, 1.299558, 0.024645},{0.753291, 1.299558, 0.005818},{
      0.759109, 1.281653, -0.005818},{0.774340, 1.270587, 0.005818},{
      0.777936, 1.281653, 0.024645}}],
    Polygon[{{0.777936, 1.281653, 0.024645},{0.798985, 1.288492, 0.024645},{
      0.808398, 1.281653, 0.005818},{0.793167, 1.270587, -0.005818},{
      0.774340, 1.270587, 0.005818}}],
    Polygon[{{0.808398, 1.317464, 0.005818},{0.814216, 1.299558, -0.005818},{
      0.802580, 1.299558, -0.024645},{0.789571, 1.317464, -0.024645},{
      0.793167, 1.328530, -0.005818}}],
    Polygon[{{0.774340, 1.328530, 0.005818},{0.793167, 1.328530, -0.005818},{
      0.789571, 1.317464, -0.024645},{0.768522, 1.310624, -0.024645},{
      0.759109, 1.317464, -0.005818}}],
    Polygon[{{0.753291, 1.299558, 0.005818},{0.759109, 1.317464, -0.005818},{
      0.768522, 1.310624, -0.024645},{0.768522, 1.288492, -0.024645},{
      0.759109, 1.281653, -0.005818}}],
    Polygon[{{0.774340, 1.270587, 0.005818},{0.759109, 1.281653, -0.005818},{
      0.768522, 1.288492, -0.024645},{0.789571, 1.281653, -0.024645},{
      0.793167, 1.270587, -0.005818}}],
    Polygon[{{0.808398, 1.281653, 0.005818},{0.793167, 1.270587, -0.005818},{
      0.789571, 1.281653, -0.024645},{0.802580, 1.299558, -0.024645},{
      0.814216, 1.299558, -0.005818}}],
    Polygon[{{0.789571, 1.317464, -0.024645},{0.802580, 1.299558, -0.024645},{
      0.789571, 1.281653, -0.024645},{0.768522, 1.288492, -0.024645},{
      0.768522, 1.310624, -0.024645}}],
    Polygon[{{0.800466, 1.348422, 0.012792},{0.789540, 1.351972, 0.012792},{
      0.782788, 1.342678, 0.012792},{0.789540, 1.333384, 0.012792},{
      0.800466, 1.336934, 0.012792}}],
    Polygon[{{0.800466, 1.348422, 0.012792},{0.800466, 1.336934, 0.012792},{
      0.805352, 1.333384, 0.003020},{0.808372, 1.342678, -0.003020},{
      0.805352, 1.351972, 0.003020}}],
    Polygon[{{0.800466, 1.348422, 0.012792},{0.805352, 1.351972, 0.003020},{
      0.797446, 1.357716, -0.003020},{0.787674, 1.357716, 0.003020},{
      0.789540, 1.351972, 0.012792}}],
    Polygon[{{0.789540, 1.351972, 0.012792},{0.787674, 1.357716, 0.003020},{
      0.779768, 1.351972, -0.003020},{0.776748, 1.342678, 0.003020},{
      0.782788, 1.342678, 0.012792}}],
    Polygon[{{0.782788, 1.342678, 0.012792},{0.776748, 1.342678, 0.003020},{
      0.779768, 1.333384, -0.003020},{0.787674, 1.327640, 0.003020},{
      0.789540, 1.333384, 0.012792}}],
    Polygon[{{0.789540, 1.333384, 0.012792},{0.800466, 1.336934, 0.012792},{
      0.805352, 1.333384, 0.003020},{0.797446, 1.327640, -0.003020},{
      0.787674, 1.327640, 0.003020}}],
    Polygon[{{0.805352, 1.351972, 0.003020},{0.808372, 1.342678, -0.003020},{
      0.802332, 1.342678, -0.012792},{0.795580, 1.351972, -0.012792},{
      0.797446, 1.357716, -0.003020}}],
    Polygon[{{0.787674, 1.357716, 0.003020},{0.797446, 1.357716, -0.003020},{
      0.795580, 1.351972, -0.012792},{0.784654, 1.348422, -0.012792},{
      0.779768, 1.351972, -0.003020}}],
    Polygon[{{0.776748, 1.342678, 0.003020},{0.779768, 1.351972, -0.003020},{
      0.784654, 1.348422, -0.012792},{0.784654, 1.336934, -0.012792},{
      0.779768, 1.333384, -0.003020}}],
    Polygon[{{0.787674, 1.327640, 0.003020},{0.779768, 1.333384, -0.003020},{
      0.784654, 1.336934, -0.012792},{0.795580, 1.333384, -0.012792},{
      0.797446, 1.327640, -0.003020}}],
    Polygon[{{0.805352, 1.333384, 0.003020},{0.797446, 1.327640, -0.003020},{
      0.795580, 1.333384, -0.012792},{0.802332, 1.342678, -0.012792},{
      0.808372, 1.342678, -0.003020}}],
    Polygon[{{0.795580, 1.351972, -0.012792},{0.802332, 1.342678, -0.012792},{
      0.795580, 1.333384, -0.012792},{0.784654, 1.336934, -0.012792},{
      0.784654, 1.348422, -0.012792}}],
    Polygon[{{0.756208, 1.281599, 0.009484},{0.748108, 1.284231, 0.009484},{
      0.743101, 1.277340, 0.009484},{0.748108, 1.270450, 0.009484},{
      0.756208, 1.273082, 0.009484}}],
    Polygon[{{0.756208, 1.281599, 0.009484},{0.756208, 1.273082, 0.009484},{
      0.759831, 1.270450, 0.002239},{0.762069, 1.277340, -0.002239},{
      0.759831, 1.284231, 0.002239}}],
    Polygon[{{0.756208, 1.281599, 0.009484},{0.759831, 1.284231, 0.002239},{
      0.753969, 1.288489, -0.002239},{0.746724, 1.288489, 0.002239},{
      0.748108, 1.284231, 0.009484}}],
    Polygon[{{0.748108, 1.284231, 0.009484},{0.746724, 1.288489, 0.002239},{
      0.740863, 1.284231, -0.002239},{0.738624, 1.277340, 0.002239},{
      0.743101, 1.277340, 0.009484}}],
    Polygon[{{0.743101, 1.277340, 0.009484},{0.738624, 1.277340, 0.002239},{
      0.740863, 1.270450, -0.002239},{0.746724, 1.266191, 0.002239},{
      0.748108, 1.270450, 0.009484}}],
    Polygon[{{0.748108, 1.270450, 0.009484},{0.756208, 1.273082, 0.009484},{
      0.759831, 1.270450, 0.002239},{0.753969, 1.266191, -0.002239},{
      0.746724, 1.266191, 0.002239}}],
    Polygon[{{0.759831, 1.284231, 0.002239},{0.762069, 1.277340, -0.002239},{
      0.757592, 1.277340, -0.009484},{0.752585, 1.284231, -0.009484},{
      0.753969, 1.288489, -0.002239}}],
    Polygon[{{0.746724, 1.288489, 0.002239},{0.753969, 1.288489, -0.002239},{
      0.752585, 1.284231, -0.009484},{0.744485, 1.281599, -0.009484},{
      0.740863, 1.284231, -0.002239}}],
    Polygon[{{0.738624, 1.277340, 0.002239},{0.740863, 1.284231, -0.002239},{
      0.744485, 1.281599, -0.009484},{0.744485, 1.273082, -0.009484},{
      0.740863, 1.270450, -0.002239}}],
    Polygon[{{0.746724, 1.266191, 0.002239},{0.740863, 1.270450, -0.002239},{
      0.744485, 1.273082, -0.009484},{0.752585, 1.270450, -0.009484},{
      0.753969, 1.266191, -0.002239}}],
    Polygon[{{0.759831, 1.270450, 0.002239},{0.753969, 1.266191, -0.002239},{
      0.752585, 1.270450, -0.009484},{0.757592, 1.277340, -0.009484},{
      0.762069, 1.277340, -0.002239}}],
    Polygon[{{0.752585, 1.284231, -0.009484},{0.757592, 1.277340, -0.009484},{
      0.752585, 1.270450, -0.009484},{0.744485, 1.273082, -0.009484},{
      0.744485, 1.281599, -0.009484}}],
    Polygon[{{0.816982, 1.277057, 0.008080},{0.810081, 1.279299, 0.008080},{
      0.805816, 1.273429, 0.008080},{0.810081, 1.267559, 0.008080},{
      0.816982, 1.269801, 0.008080}}],
    Polygon[{{0.816982, 1.277057, 0.008080},{0.816982, 1.269801, 0.008080},{
      0.820068, 1.267559, 0.001907},{0.821976, 1.273429, -0.001907},{
      0.820068, 1.279299, 0.001907}}],
    Polygon[{{0.816982, 1.277057, 0.008080},{0.820068, 1.279299, 0.001907},{
      0.815075, 1.282928, -0.001907},{0.808902, 1.282928, 0.001907},{
      0.810081, 1.279299, 0.008080}}],
    Polygon[{{0.810081, 1.279299, 0.008080},{0.808902, 1.282928, 0.001907},{
      0.803909, 1.279299, -0.001907},{0.802001, 1.273429, 0.001907},{
      0.805816, 1.273429, 0.008080}}],
    Polygon[{{0.805816, 1.273429, 0.008080},{0.802001, 1.273429, 0.001907},{
      0.803909, 1.267559, -0.001907},{0.808902, 1.263931, 0.001907},{
      0.810081, 1.267559, 0.008080}}],
    Polygon[{{0.810081, 1.267559, 0.008080},{0.816982, 1.269801, 0.008080},{
      0.820068, 1.267559, 0.001907},{0.815075, 1.263931, -0.001907},{
      0.808902, 1.263931, 0.001907}}],
    Polygon[{{0.820068, 1.279299, 0.001907},{0.821976, 1.273429, -0.001907},{
      0.818161, 1.273429, -0.008080},{0.813896, 1.279299, -0.008080},{
      0.815075, 1.282928, -0.001907}}],
    Polygon[{{0.808902, 1.282928, 0.001907},{0.815075, 1.282928, -0.001907},{
      0.813896, 1.279299, -0.008080},{0.806995, 1.277057, -0.008080},{
      0.803909, 1.279299, -0.001907}}],
    Polygon[{{0.802001, 1.273429, 0.001907},{0.803909, 1.279299, -0.001907},{
      0.806995, 1.277057, -0.008080},{0.806995, 1.269801, -0.008080},{
      0.803909, 1.267559, -0.001907}}],
    Polygon[{{0.808902, 1.263931, 0.001907},{0.803909, 1.267559, -0.001907},{
      0.806995, 1.269801, -0.008080},{0.813896, 1.267559, -0.008080},{
      0.815075, 1.263931, -0.001907}}],
    Polygon[{{0.820068, 1.267559, 0.001907},{0.815075, 1.263931, -0.001907},{
      0.813896, 1.267559, -0.008080},{0.818161, 1.273429, -0.008080},{
      0.821976, 1.273429, -0.001907}}],
    Polygon[{{0.813896, 1.279299, -0.008080},{0.818161, 1.273429, -0.008080},{
      0.813896, 1.267559, -0.008080},{0.806995, 1.269801, -0.008080},{
      0.806995, 1.277057, -0.008080}}],
    Polygon[{{0.890708, 1.176909, 0.021420},{0.872413, 1.182853, 0.021420},{
      0.861106, 1.167291, 0.021420},{0.872413, 1.151728, 0.021420},{
      0.890708, 1.157673, 0.021420}}],
    Polygon[{{0.890708, 1.176909, 0.021420},{0.890708, 1.157673, 0.021420},{
      0.898890, 1.151728, 0.005057},{0.903946, 1.167291, -0.005057},{
      0.898890, 1.182853, 0.005057}}],
    Polygon[{{0.890708, 1.176909, 0.021420},{0.898890, 1.182853, 0.005057},{
      0.885651, 1.192472, -0.005057},{0.869288, 1.192472, 0.005057},{
      0.872413, 1.182853, 0.021420}}],
    Polygon[{{0.872413, 1.182853, 0.021420},{0.869288, 1.192472, 0.005057},{
      0.856050, 1.182853, -0.005057},{0.850993, 1.167291, 0.005057},{
      0.861106, 1.167291, 0.021420}}],
    Polygon[{{0.861106, 1.167291, 0.021420},{0.850993, 1.167291, 0.005057},{
      0.856050, 1.151728, -0.005057},{0.869288, 1.142110, 0.005057},{
      0.872413, 1.151728, 0.021420}}],
    Polygon[{{0.872413, 1.151728, 0.021420},{0.890708, 1.157673, 0.021420},{
      0.898890, 1.151728, 0.005057},{0.885651, 1.142110, -0.005057},{
      0.869288, 1.142110, 0.005057}}],
    Polygon[{{0.898890, 1.182853, 0.005057},{0.903946, 1.167291, -0.005057},{
      0.893833, 1.167291, -0.021420},{0.882526, 1.182853, -0.021420},{
      0.885651, 1.192472, -0.005057}}],
    Polygon[{{0.869288, 1.192472, 0.005057},{0.885651, 1.192472, -0.005057},{
      0.882526, 1.182853, -0.021420},{0.864231, 1.176909, -0.021420},{
      0.856050, 1.182853, -0.005057}}],
    Polygon[{{0.850993, 1.167291, 0.005057},{0.856050, 1.182853, -0.005057},{
      0.864231, 1.176909, -0.021420},{0.864231, 1.157673, -0.021420},{
      0.856050, 1.151728, -0.005057}}],
    Polygon[{{0.869288, 1.142110, 0.005057},{0.856050, 1.151728, -0.005057},{
      0.864231, 1.157673, -0.021420},{0.882526, 1.151728, -0.021420},{
      0.885651, 1.142110, -0.005057}}],
    Polygon[{{0.898890, 1.151728, 0.005057},{0.885651, 1.142110, -0.005057},{
      0.882526, 1.151728, -0.021420},{0.893833, 1.167291, -0.021420},{
      0.903946, 1.167291, -0.005057}}],
    Polygon[{{0.882526, 1.182853, -0.021420},{0.893833, 1.167291, -0.021420},{
      0.882526, 1.151728, -0.021420},{0.864231, 1.157673, -0.021420},{
      0.864231, 1.176909, -0.021420}}],
    Polygon[{{0.921095, 1.165677, 0.010586},{0.912054, 1.168614, 0.010586},{
      0.906465, 1.160923, 0.010586},{0.912054, 1.153232, 0.010586},{
      0.921095, 1.156169, 0.010586}}],
    Polygon[{{0.921095, 1.165677, 0.010586},{0.921095, 1.156169, 0.010586},{
      0.925139, 1.153232, 0.002499},{0.927638, 1.160923, -0.002499},{
      0.925139, 1.168614, 0.002499}}],
    Polygon[{{0.921095, 1.165677, 0.010586},{0.925139, 1.168614, 0.002499},{
      0.918596, 1.173368, -0.002499},{0.910509, 1.173368, 0.002499},{
      0.912054, 1.168614, 0.010586}}],
    Polygon[{{0.912054, 1.168614, 0.010586},{0.910509, 1.173368, 0.002499},{
      0.903966, 1.168614, -0.002499},{0.901467, 1.160923, 0.002499},{
      0.906465, 1.160923, 0.010586}}],
    Polygon[{{0.906465, 1.160923, 0.010586},{0.901467, 1.160923, 0.002499},{
      0.903966, 1.153232, -0.002499},{0.910509, 1.148478, 0.002499},{
      0.912054, 1.153232, 0.010586}}],
    Polygon[{{0.912054, 1.153232, 0.010586},{0.921095, 1.156169, 0.010586},{
      0.925139, 1.153232, 0.002499},{0.918596, 1.148478, -0.002499},{
      0.910509, 1.148478, 0.002499}}],
    Polygon[{{0.925139, 1.168614, 0.002499},{0.927638, 1.160923, -0.002499},{
      0.922640, 1.160923, -0.010586},{0.917052, 1.168614, -0.010586},{
      0.918596, 1.173368, -0.002499}}],
    Polygon[{{0.910509, 1.173368, 0.002499},{0.918596, 1.173368, -0.002499},{
      0.917052, 1.168614, -0.010586},{0.908010, 1.165677, -0.010586},{
      0.903966, 1.168614, -0.002499}}],
    Polygon[{{0.901467, 1.160923, 0.002499},{0.903966, 1.168614, -0.002499},{
      0.908010, 1.165677, -0.010586},{0.908010, 1.156169, -0.010586},{
      0.903966, 1.153232, -0.002499}}],
    Polygon[{{0.910509, 1.148478, 0.002499},{0.903966, 1.153232, -0.002499},{
      0.908010, 1.156169, -0.010586},{0.917052, 1.153232, -0.010586},{
      0.918596, 1.148478, -0.002499}}],
    Polygon[{{0.925139, 1.153232, 0.002499},{0.918596, 1.148478, -0.002499},{
      0.917052, 1.153232, -0.010586},{0.922640, 1.160923, -0.010586},{
      0.927638, 1.160923, -0.002499}}],
    Polygon[{{0.917052, 1.168614, -0.010586},{0.922640, 1.160923, -0.010586},{
      0.917052, 1.153232, -0.010586},{0.908010, 1.156169, -0.010586},{
      0.908010, 1.165677, -0.010586}}],
    Polygon[{{0.855738, 1.148732, 0.008215},{0.848721, 1.151012, 0.008215},{
      0.844385, 1.145043, 0.008215},{0.848721, 1.139075, 0.008215},{
      0.855738, 1.141355, 0.008215}}],
    Polygon[{{0.855738, 1.148732, 0.008215},{0.855738, 1.141355, 0.008215},{
      0.858875, 1.139075, 0.001939},{0.860815, 1.145043, -0.001939},{
      0.858875, 1.151012, 0.001939}}],
    Polygon[{{0.855738, 1.148732, 0.008215},{0.858875, 1.151012, 0.001939},{
      0.853798, 1.154701, -0.001939},{0.847523, 1.154701, 0.001939},{
      0.848721, 1.151012, 0.008215}}],
    Polygon[{{0.848721, 1.151012, 0.008215},{0.847523, 1.154701, 0.001939},{
      0.842446, 1.151012, -0.001939},{0.840506, 1.145043, 0.001939},{
      0.844385, 1.145043, 0.008215}}],
    Polygon[{{0.844385, 1.145043, 0.008215},{0.840506, 1.145043, 0.001939},{
      0.842446, 1.139075, -0.001939},{0.847523, 1.135386, 0.001939},{
      0.848721, 1.139075, 0.008215}}],
    Polygon[{{0.848721, 1.139075, 0.008215},{0.855738, 1.141355, 0.008215},{
      0.858875, 1.139075, 0.001939},{0.853798, 1.135386, -0.001939},{
      0.847523, 1.135386, 0.001939}}],
    Polygon[{{0.858875, 1.151012, 0.001939},{0.860815, 1.145043, -0.001939},{
      0.856936, 1.145043, -0.008215},{0.852600, 1.151012, -0.008215},{
      0.853798, 1.154701, -0.001939}}],
    Polygon[{{0.847523, 1.154701, 0.001939},{0.853798, 1.154701, -0.001939},{
      0.852600, 1.151012, -0.008215},{0.845583, 1.148732, -0.008215},{
      0.842446, 1.151012, -0.001939}}],
    Polygon[{{0.840506, 1.145043, 0.001939},{0.842446, 1.151012, -0.001939},{
      0.845583, 1.148732, -0.008215},{0.845583, 1.141355, -0.008215},{
      0.842446, 1.139075, -0.001939}}],
    Polygon[{{0.847523, 1.135386, 0.001939},{0.842446, 1.139075, -0.001939},{
      0.845583, 1.141355, -0.008215},{0.852600, 1.139075, -0.008215},{
      0.853798, 1.135386, -0.001939}}],
    Polygon[{{0.858875, 1.139075, 0.001939},{0.853798, 1.135386, -0.001939},{
      0.852600, 1.139075, -0.008215},{0.856936, 1.145043, -0.008215},{
      0.860815, 1.145043, -0.001939}}],
    Polygon[{{0.852600, 1.151012, -0.008215},{0.856936, 1.145043, -0.008215},{
      0.852600, 1.139075, -0.008215},{0.845583, 1.141355, -0.008215},{
      0.845583, 1.148732, -0.008215}}],
    Polygon[{{0.868895, 1.201935, 0.007466},{0.862519, 1.204007, 0.007466},{
      0.858578, 1.198582, 0.007466},{0.862519, 1.193158, 0.007466},{
      0.868895, 1.195230, 0.007466}}],
    Polygon[{{0.868895, 1.201935, 0.007466},{0.868895, 1.195230, 0.007466},{
      0.871747, 1.193158, 0.001762},{0.873509, 1.198582, -0.001762},{
      0.871747, 1.204007, 0.001762}}],
    Polygon[{{0.868895, 1.201935, 0.007466},{0.871747, 1.204007, 0.001762},{
      0.867133, 1.207359, -0.001762},{0.861430, 1.207359, 0.001762},{
      0.862519, 1.204007, 0.007466}}],
    Polygon[{{0.862519, 1.204007, 0.007466},{0.861430, 1.207359, 0.001762},{
      0.856816, 1.204007, -0.001762},{0.855053, 1.198582, 0.001762},{
      0.858578, 1.198582, 0.007466}}],
    Polygon[{{0.858578, 1.198582, 0.007466},{0.855053, 1.198582, 0.001762},{
      0.856816, 1.193158, -0.001762},{0.861430, 1.189806, 0.001762},{
      0.862519, 1.193158, 0.007466}}],
    Polygon[{{0.862519, 1.193158, 0.007466},{0.868895, 1.195230, 0.007466},{
      0.871747, 1.193158, 0.001762},{0.867133, 1.189806, -0.001762},{
      0.861430, 1.189806, 0.001762}}],
    Polygon[{{0.871747, 1.204007, 0.001762},{0.873509, 1.198582, -0.001762},{
      0.869985, 1.198582, -0.007466},{0.866044, 1.204007, -0.007466},{
      0.867133, 1.207359, -0.001762}}],
    Polygon[{{0.861430, 1.207359, 0.001762},{0.867133, 1.207359, -0.001762},{
      0.866044, 1.204007, -0.007466},{0.859667, 1.201935, -0.007466},{
      0.856816, 1.204007, -0.001762}}],
    Polygon[{{0.855053, 1.198582, 0.001762},{0.856816, 1.204007, -0.001762},{
      0.859667, 1.201935, -0.007466},{0.859667, 1.195230, -0.007466},{
      0.856816, 1.193158, -0.001762}}],
    Polygon[{{0.861430, 1.189806, 0.001762},{0.856816, 1.193158, -0.001762},{
      0.859667, 1.195230, -0.007466},{0.866044, 1.193158, -0.007466},{
      0.867133, 1.189806, -0.001762}}],
    Polygon[{{0.871747, 1.193158, 0.001762},{0.867133, 1.189806, -0.001762},{
      0.866044, 1.193158, -0.007466},{0.869985, 1.198582, -0.007466},{
      0.873509, 1.198582, -0.001762}}],
    Polygon[{{0.866044, 1.204007, -0.007466},{0.869985, 1.198582, -0.007466},{
      0.866044, 1.193158, -0.007466},{0.859667, 1.195230, -0.007466},{
      0.859667, 1.201935, -0.007466}}],
    Polygon[{{1.262353, 1.222921, 0.065798},{1.206155, 1.241181, 0.065798},{
      1.171423, 1.193376, 0.065798},{1.206155, 1.145571, 0.065798},{
      1.262353, 1.163831, 0.065798}}],
    Polygon[{{1.262353, 1.222921, 0.065798},{1.262353, 1.163831, 0.065798},{
      1.287486, 1.145571, 0.015533},{1.303019, 1.193376, -0.015533},{
      1.287486, 1.241181, 0.015533}}],
    Polygon[{{1.262353, 1.222921, 0.065798},{1.287486, 1.241181, 0.015533},{
      1.246820, 1.270726, -0.015533},{1.196555, 1.270726, 0.015533},{
      1.206155, 1.241181, 0.065798}}],
    Polygon[{{1.206155, 1.241181, 0.065798},{1.196555, 1.270726, 0.015533},{
      1.155890, 1.241181, -0.015533},{1.140357, 1.193376, 0.015533},{
      1.171423, 1.193376, 0.065798}}],
    Polygon[{{1.171423, 1.193376, 0.065798},{1.140357, 1.193376, 0.015533},{
      1.155890, 1.145571, -0.015533},{1.196555, 1.116025, 0.015533},{
      1.206155, 1.145571, 0.065798}}],
    Polygon[{{1.206155, 1.145571, 0.065798},{1.262353, 1.163831, 0.065798},{
      1.287486, 1.145571, 0.015533},{1.246820, 1.116025, -0.015533},{
      1.196555, 1.116025, 0.015533}}],
    Polygon[{{1.287486, 1.241181, 0.015533},{1.303019, 1.193376, -0.015533},{
      1.271953, 1.193376, -0.065798},{1.237221, 1.241181, -0.065798},{
      1.246820, 1.270726, -0.015533}}],
    Polygon[{{1.196555, 1.270726, 0.015533},{1.246820, 1.270726, -0.015533},{
      1.237221, 1.241181, -0.065798},{1.181022, 1.222921, -0.065798},{
      1.155890, 1.241181, -0.015533}}],
    Polygon[{{1.140357, 1.193376, 0.015533},{1.155890, 1.241181, -0.015533},{
      1.181022, 1.222921, -0.065798},{1.181022, 1.163831, -0.065798},{
      1.155890, 1.145571, -0.015533}}],
    Polygon[{{1.196555, 1.116025, 0.015533},{1.155890, 1.145571, -0.015533},{
      1.181022, 1.163831, -0.065798},{1.237221, 1.145571, -0.065798},{
      1.246820, 1.116025, -0.015533}}],
    Polygon[{{1.287486, 1.145571, 0.015533},{1.246820, 1.116025, -0.015533},{
      1.237221, 1.145571, -0.065798},{1.271953, 1.193376, -0.065798},{
      1.303019, 1.193376, -0.015533}}],
    Polygon[{{1.237221, 1.241181, -0.065798},{1.271953, 1.193376, -0.065798},{
      1.237221, 1.145571, -0.065798},{1.181022, 1.163831, -0.065798},{
      1.181022, 1.222921, -0.065798}}],
    Polygon[{{1.331194, 1.129082, 0.035261},{1.301077, 1.138867, 0.035261},{
      1.282464, 1.113249, 0.035261},{1.301077, 1.087630, 0.035261},{
      1.331194, 1.097415, 0.035261}}],
    Polygon[{{1.331194, 1.129082, 0.035261},{1.331194, 1.097415, 0.035261},{
      1.344662, 1.087630, 0.008324},{1.352986, 1.113249, -0.008324},{
      1.344662, 1.138867, 0.008324}}],
    Polygon[{{1.331194, 1.129082, 0.035261},{1.344662, 1.138867, 0.008324},{
      1.322870, 1.154701, -0.008324},{1.295933, 1.154701, 0.008324},{
      1.301077, 1.138867, 0.035261}}],
    Polygon[{{1.301077, 1.138867, 0.035261},{1.295933, 1.154701, 0.008324},{
      1.274140, 1.138867, -0.008324},{1.265816, 1.113249, 0.008324},{
      1.282464, 1.113249, 0.035261}}],
    Polygon[{{1.282464, 1.113249, 0.035261},{1.265816, 1.113249, 0.008324},{
      1.274140, 1.087630, -0.008324},{1.295933, 1.071797, 0.008324},{
      1.301077, 1.087630, 0.035261}}],
    Polygon[{{1.301077, 1.087630, 0.035261},{1.331194, 1.097415, 0.035261},{
      1.344662, 1.087630, 0.008324},{1.322870, 1.071797, -0.008324},{
      1.295933, 1.071797, 0.008324}}],
    Polygon[{{1.344662, 1.138867, 0.008324},{1.352986, 1.113249, -0.008324},{
      1.336338, 1.113249, -0.035261},{1.317725, 1.138867, -0.035261},{
      1.322870, 1.154701, -0.008324}}],
    Polygon[{{1.295933, 1.154701, 0.008324},{1.322870, 1.154701, -0.008324},{
      1.317725, 1.138867, -0.035261},{1.287609, 1.129082, -0.035261},{
      1.274140, 1.138867, -0.008324}}],
    Polygon[{{1.265816, 1.113249, 0.008324},{1.274140, 1.138867, -0.008324},{
      1.287609, 1.129082, -0.035261},{1.287609, 1.097415, -0.035261},{
      1.274140, 1.087630, -0.008324}}],
    Polygon[{{1.295933, 1.071797, 0.008324},{1.274140, 1.087630, -0.008324},{
      1.287609, 1.097415, -0.035261},{1.317725, 1.087630, -0.035261},{
      1.322870, 1.071797, -0.008324}}],
    Polygon[{{1.344662, 1.087630, 0.008324},{1.322870, 1.071797, -0.008324},{
      1.317725, 1.087630, -0.035261},{1.336338, 1.113249, -0.035261},{
      1.352986, 1.113249, -0.008324}}],
    Polygon[{{1.317725, 1.138867, -0.035261},{1.336338, 1.113249, -0.035261},{
      1.317725, 1.087630, -0.035261},{1.287609, 1.097415, -0.035261},{
      1.287609, 1.129082, -0.035261}}],
    Polygon[{{1.369218, 1.074307, 0.021933},{1.350485, 1.080394, 0.021933},{
      1.338907, 1.064459, 0.021933},{1.350485, 1.048524, 0.021933},{
      1.369218, 1.054610, 0.021933}}],
    Polygon[{{1.369218, 1.074307, 0.021933},{1.369218, 1.054610, 0.021933},{
      1.377595, 1.048524, 0.005178},{1.382773, 1.064459, -0.005178},{
      1.377595, 1.080394, 0.005178}}],
    Polygon[{{1.369218, 1.074307, 0.021933},{1.377595, 1.080394, 0.005178},{
      1.364040, 1.090242, -0.005178},{1.347285, 1.090242, 0.005178},{
      1.350485, 1.080394, 0.021933}}],
    Polygon[{{1.350485, 1.080394, 0.021933},{1.347285, 1.090242, 0.005178},{
      1.333730, 1.080394, -0.005178},{1.328552, 1.064459, 0.005178},{
      1.338907, 1.064459, 0.021933}}],
    Polygon[{{1.338907, 1.064459, 0.021933},{1.328552, 1.064459, 0.005178},{
      1.333730, 1.048524, -0.005178},{1.347285, 1.038675, 0.005178},{
      1.350485, 1.048524, 0.021933}}],
    Polygon[{{1.350485, 1.048524, 0.021933},{1.369218, 1.054610, 0.021933},{
      1.377595, 1.048524, 0.005178},{1.364040, 1.038675, -0.005178},{
      1.347285, 1.038675, 0.005178}}],
    Polygon[{{1.377595, 1.080394, 0.005178},{1.382773, 1.064459, -0.005178},{
      1.372418, 1.064459, -0.021933},{1.360840, 1.080394, -0.021933},{
      1.364040, 1.090242, -0.005178}}],
    Polygon[{{1.347285, 1.090242, 0.005178},{1.364040, 1.090242, -0.005178},{
      1.360840, 1.080394, -0.021933},{1.342107, 1.074307, -0.021933},{
      1.333730, 1.080394, -0.005178}}],
    Polygon[{{1.328552, 1.064459, 0.005178},{1.333730, 1.080394, -0.005178},{
      1.342107, 1.074307, -0.021933},{1.342107, 1.054610, -0.021933},{
      1.333730, 1.048524, -0.005178}}],
    Polygon[{{1.347285, 1.038675, 0.005178},{1.333730, 1.048524, -0.005178},{
      1.342107, 1.054610, -0.021933},{1.360840, 1.048524, -0.021933},{
      1.364040, 1.038675, -0.005178}}],
    Polygon[{{1.377595, 1.048524, 0.005178},{1.364040, 1.038675, -0.005178},{
      1.360840, 1.048524, -0.021933},{1.372418, 1.064459, -0.021933},{
      1.382773, 1.064459, -0.005178}}],
    Polygon[{{1.360840, 1.080394, -0.021933},{1.372418, 1.064459, -0.021933},{
      1.360840, 1.048524, -0.021933},{1.342107, 1.054610, -0.021933},{
      1.342107, 1.074307, -0.021933}}],
    Polygon[{{1.316665, 1.173796, 0.011754},{1.306626, 1.177057, 0.011754},{
      1.300422, 1.168518, 0.011754},{1.306626, 1.159978, 0.011754},{
      1.316665, 1.163240, 0.011754}}],
    Polygon[{{1.316665, 1.173796, 0.011754},{1.316665, 1.163240, 0.011754},{
      1.321155, 1.159978, 0.002775},{1.323929, 1.168518, -0.002775},{
      1.321155, 1.177057, 0.002775}}],
    Polygon[{{1.316665, 1.173796, 0.011754},{1.321155, 1.177057, 0.002775},{
      1.313891, 1.182335, -0.002775},{1.304912, 1.182335, 0.002775},{
      1.306626, 1.177057, 0.011754}}],
    Polygon[{{1.306626, 1.177057, 0.011754},{1.304912, 1.182335, 0.002775},{
      1.297647, 1.177057, -0.002775},{1.294873, 1.168518, 0.002775},{
      1.300422, 1.168518, 0.011754}}],
    Polygon[{{1.300422, 1.168518, 0.011754},{1.294873, 1.168518, 0.002775},{
      1.297647, 1.159978, -0.002775},{1.304912, 1.154701, 0.002775},{
      1.306626, 1.159978, 0.011754}}],
    Polygon[{{1.306626, 1.159978, 0.011754},{1.316665, 1.163240, 0.011754},{
      1.321155, 1.159978, 0.002775},{1.313891, 1.154701, -0.002775},{
      1.304912, 1.154701, 0.002775}}],
    Polygon[{{1.321155, 1.177057, 0.002775},{1.323929, 1.168518, -0.002775},{
      1.318380, 1.168518, -0.011754},{1.312176, 1.177057, -0.011754},{
      1.313891, 1.182335, -0.002775}}],
    Polygon[{{1.304912, 1.182335, 0.002775},{1.313891, 1.182335, -0.002775},{
      1.312176, 1.177057, -0.011754},{1.302137, 1.173796, -0.011754},{
      1.297647, 1.177057, -0.002775}}],
    Polygon[{{1.294873, 1.168518, 0.002775},{1.297647, 1.177057, -0.002775},{
      1.302137, 1.173796, -0.011754},{1.302137, 1.163240, -0.011754},{
      1.297647, 1.159978, -0.002775}}],
    Polygon[{{1.304912, 1.154701, 0.002775},{1.297647, 1.159978, -0.002775},{
      1.302137, 1.163240, -0.011754},{1.312176, 1.159978, -0.011754},{
      1.313891, 1.154701, -0.002775}}],
    Polygon[{{1.321155, 1.159978, 0.002775},{1.313891, 1.154701, -0.002775},{
      1.312176, 1.159978, -0.011754},{1.318380, 1.168518, -0.011754},{
      1.323929, 1.168518, -0.002775}}],
    Polygon[{{1.312176, 1.177057, -0.011754},{1.318380, 1.168518, -0.011754},{
      1.312176, 1.159978, -0.011754},{1.302137, 1.163240, -0.011754},{
      1.302137, 1.173796, -0.011754}}],
    Polygon[{{1.261959, 1.114504, 0.010966},{1.252593, 1.117547, 0.010966},{
      1.246804, 1.109580, 0.010966},{1.252593, 1.101612, 0.010966},{
      1.261959, 1.104655, 0.010966}}],
    Polygon[{{1.261959, 1.114504, 0.010966},{1.261959, 1.104655, 0.010966},{
      1.266148, 1.101612, 0.002589},{1.268737, 1.109580, -0.002589},{
      1.266148, 1.117547, 0.002589}}],
    Polygon[{{1.261959, 1.114504, 0.010966},{1.266148, 1.117547, 0.002589},{
      1.259370, 1.122471, -0.002589},{1.250993, 1.122471, 0.002589},{
      1.252593, 1.117547, 0.010966}}],
    Polygon[{{1.252593, 1.117547, 0.010966},{1.250993, 1.122471, 0.002589},{
      1.244215, 1.117547, -0.002589},{1.241626, 1.109580, 0.002589},{
      1.246804, 1.109580, 0.010966}}],
    Polygon[{{1.246804, 1.109580, 0.010966},{1.241626, 1.109580, 0.002589},{
      1.244215, 1.101612, -0.002589},{1.250993, 1.096688, 0.002589},{
      1.252593, 1.101612, 0.010966}}],
    Polygon[{{1.252593, 1.101612, 0.010966},{1.261959, 1.104655, 0.010966},{
      1.266148, 1.101612, 0.002589},{1.259370, 1.096688, -0.002589},{
      1.250993, 1.096688, 0.002589}}],
    Polygon[{{1.266148, 1.117547, 0.002589},{1.268737, 1.109580, -0.002589},{
      1.263559, 1.109580, -0.010966},{1.257770, 1.117547, -0.010966},{
      1.259370, 1.122471, -0.002589}}],
    Polygon[{{1.250993, 1.122471, 0.002589},{1.259370, 1.122471, -0.002589},{
      1.257770, 1.117547, -0.010966},{1.248404, 1.114504, -0.010966},{
      1.244215, 1.117547, -0.002589}}],
    Polygon[{{1.241626, 1.109580, 0.002589},{1.244215, 1.117547, -0.002589},{
      1.248404, 1.114504, -0.010966},{1.248404, 1.104655, -0.010966},{
      1.244215, 1.101612, -0.002589}}],
    Polygon[{{1.250993, 1.096688, 0.002589},{1.244215, 1.101612, -0.002589},{
      1.248404, 1.104655, -0.010966},{1.257770, 1.101612, -0.010966},{
      1.259370, 1.096688, -0.002589}}],
    Polygon[{{1.266148, 1.101612, 0.002589},{1.259370, 1.096688, -0.002589},{
      1.257770, 1.101612, -0.010966},{1.263559, 1.109580, -0.010966},{
      1.268737, 1.109580, -0.002589}}],
    Polygon[{{1.257770, 1.117547, -0.010966},{1.263559, 1.109580, -0.010966},{
      1.257770, 1.101612, -0.010966},{1.248404, 1.104655, -0.010966},{
      1.248404, 1.114504, -0.010966}}],
    Polygon[{{1.231478, 1.310624, 0.024645},{1.210428, 1.317464, 0.024645},{
      1.197420, 1.299558, 0.024645},{1.210428, 1.281653, 0.024645},{
      1.231478, 1.288492, 0.024645}}],
    Polygon[{{1.231478, 1.310624, 0.024645},{1.231478, 1.288492, 0.024645},{
      1.240891, 1.281653, 0.005818},{1.246709, 1.299558, -0.005818},{
      1.240891, 1.317464, 0.005818}}],
    Polygon[{{1.231478, 1.310624, 0.024645},{1.240891, 1.317464, 0.005818},{
      1.225660, 1.328530, -0.005818},{1.206833, 1.328530, 0.005818},{
      1.210428, 1.317464, 0.024645}}],
    Polygon[{{1.210428, 1.317464, 0.024645},{1.206833, 1.328530, 0.005818},{
      1.191602, 1.317464, -0.005818},{1.185784, 1.299558, 0.005818},{
      1.197420, 1.299558, 0.024645}}],
    Polygon[{{1.197420, 1.299558, 0.024645},{1.185784, 1.299558, 0.005818},{
      1.191602, 1.281653, -0.005818},{1.206833, 1.270587, 0.005818},{
      1.210428, 1.281653, 0.024645}}],
    Polygon[{{1.210428, 1.281653, 0.024645},{1.231478, 1.288492, 0.024645},{
      1.240891, 1.281653, 0.005818},{1.225660, 1.270587, -0.005818},{
      1.206833, 1.270587, 0.005818}}],
    Polygon[{{1.240891, 1.317464, 0.005818},{1.246709, 1.299558, -0.005818},{
      1.235073, 1.299558, -0.024645},{1.222064, 1.317464, -0.024645},{
      1.225660, 1.328530, -0.005818}}],
    Polygon[{{1.206833, 1.328530, 0.005818},{1.225660, 1.328530, -0.005818},{
      1.222064, 1.317464, -0.024645},{1.201015, 1.310624, -0.024645},{
      1.191602, 1.317464, -0.005818}}],
    Polygon[{{1.185784, 1.299558, 0.005818},{1.191602, 1.317464, -0.005818},{
      1.201015, 1.310624, -0.024645},{1.201015, 1.288492, -0.024645},{
      1.191602, 1.281653, -0.005818}}],
    Polygon[{{1.206833, 1.270587, 0.005818},{1.191602, 1.281653, -0.005818},{
      1.201015, 1.288492, -0.024645},{1.222064, 1.281653, -0.024645},{
      1.225660, 1.270587, -0.005818}}],
    Polygon[{{1.240891, 1.281653, 0.005818},{1.225660, 1.270587, -0.005818},{
      1.222064, 1.281653, -0.024645},{1.235073, 1.299558, -0.024645},{
      1.246709, 1.299558, -0.005818}}],
    Polygon[{{1.222064, 1.317464, -0.024645},{1.235073, 1.299558, -0.024645},{
      1.222064, 1.281653, -0.024645},{1.201015, 1.288492, -0.024645},{
      1.201015, 1.310624, -0.024645}}],
    Polygon[{{1.215346, 1.348422, 0.012792},{1.204420, 1.351972, 0.012792},{
      1.197668, 1.342678, 0.012792},{1.204420, 1.333384, 0.012792},{
      1.215346, 1.336934, 0.012792}}],
    Polygon[{{1.215346, 1.348422, 0.012792},{1.215346, 1.336934, 0.012792},{
      1.220232, 1.333384, 0.003020},{1.223252, 1.342678, -0.003020},{
      1.220232, 1.351972, 0.003020}}],
    Polygon[{{1.215346, 1.348422, 0.012792},{1.220232, 1.351972, 0.003020},{
      1.212326, 1.357716, -0.003020},{1.202554, 1.357716, 0.003020},{
      1.204420, 1.351972, 0.012792}}],
    Polygon[{{1.204420, 1.351972, 0.012792},{1.202554, 1.357716, 0.003020},{
      1.194648, 1.351972, -0.003020},{1.191628, 1.342678, 0.003020},{
      1.197668, 1.342678, 0.012792}}],
    Polygon[{{1.197668, 1.342678, 0.012792},{1.191628, 1.342678, 0.003020},{
      1.194648, 1.333384, -0.003020},{1.202554, 1.327640, 0.003020},{
      1.204420, 1.333384, 0.012792}}],
    Polygon[{{1.204420, 1.333384, 0.012792},{1.215346, 1.336934, 0.012792},{
      1.220232, 1.333384, 0.003020},{1.212326, 1.327640, -0.003020},{
      1.202554, 1.327640, 0.003020}}],
    Polygon[{{1.220232, 1.351972, 0.003020},{1.223252, 1.342678, -0.003020},{
      1.217212, 1.342678, -0.012792},{1.210460, 1.351972, -0.012792},{
      1.212326, 1.357716, -0.003020}}],
    Polygon[{{1.202554, 1.357716, 0.003020},{1.212326, 1.357716, -0.003020},{
      1.210460, 1.351972, -0.012792},{1.199534, 1.348422, -0.012792},{
      1.194648, 1.351972, -0.003020}}],
    Polygon[{{1.191628, 1.342678, 0.003020},{1.194648, 1.351972, -0.003020},{
      1.199534, 1.348422, -0.012792},{1.199534, 1.336934, -0.012792},{
      1.194648, 1.333384, -0.003020}}],
    Polygon[{{1.202554, 1.327640, 0.003020},{1.194648, 1.333384, -0.003020},{
      1.199534, 1.336934, -0.012792},{1.210460, 1.333384, -0.012792},{
      1.212326, 1.327640, -0.003020}}],
    Polygon[{{1.220232, 1.333384, 0.003020},{1.212326, 1.327640, -0.003020},{
      1.210460, 1.333384, -0.012792},{1.217212, 1.342678, -0.012792},{
      1.223252, 1.342678, -0.003020}}],
    Polygon[{{1.210460, 1.351972, -0.012792},{1.217212, 1.342678, -0.012792},{
      1.210460, 1.333384, -0.012792},{1.199534, 1.336934, -0.012792},{
      1.199534, 1.348422, -0.012792}}],
    Polygon[{{1.255515, 1.281599, 0.009484},{1.247414, 1.284231, 0.009484},{
      1.242408, 1.277340, 0.009484},{1.247414, 1.270450, 0.009484},{
      1.255515, 1.273082, 0.009484}}],
    Polygon[{{1.255515, 1.281599, 0.009484},{1.255515, 1.273082, 0.009484},{
      1.259137, 1.270450, 0.002239},{1.261376, 1.277340, -0.002239},{
      1.259137, 1.284231, 0.002239}}],
    Polygon[{{1.255515, 1.281599, 0.009484},{1.259137, 1.284231, 0.002239},{
      1.253276, 1.288489, -0.002239},{1.246031, 1.288489, 0.002239},{
      1.247414, 1.284231, 0.009484}}],
    Polygon[{{1.247414, 1.284231, 0.009484},{1.246031, 1.288489, 0.002239},{
      1.240169, 1.284231, -0.002239},{1.237931, 1.277340, 0.002239},{
      1.242408, 1.277340, 0.009484}}],
    Polygon[{{1.242408, 1.277340, 0.009484},{1.237931, 1.277340, 0.002239},{
      1.240169, 1.270450, -0.002239},{1.246031, 1.266191, 0.002239},{
      1.247414, 1.270450, 0.009484}}],
    Polygon[{{1.247414, 1.270450, 0.009484},{1.255515, 1.273082, 0.009484},{
      1.259137, 1.270450, 0.002239},{1.253276, 1.266191, -0.002239},{
      1.246031, 1.266191, 0.002239}}],
    Polygon[{{1.259137, 1.284231, 0.002239},{1.261376, 1.277340, -0.002239},{
      1.256899, 1.277340, -0.009484},{1.251892, 1.284231, -0.009484},{
      1.253276, 1.288489, -0.002239}}],
    Polygon[{{1.246031, 1.288489, 0.002239},{1.253276, 1.288489, -0.002239},{
      1.251892, 1.284231, -0.009484},{1.243792, 1.281599, -0.009484},{
      1.240169, 1.284231, -0.002239}}],
    Polygon[{{1.237931, 1.277340, 0.002239},{1.240169, 1.284231, -0.002239},{
      1.243792, 1.281599, -0.009484},{1.243792, 1.273082, -0.009484},{
      1.240169, 1.270450, -0.002239}}],
    Polygon[{{1.246031, 1.266191, 0.002239},{1.240169, 1.270450, -0.002239},{
      1.243792, 1.273082, -0.009484},{1.251892, 1.270450, -0.009484},{
      1.253276, 1.266191, -0.002239}}],
    Polygon[{{1.259137, 1.270450, 0.002239},{1.253276, 1.266191, -0.002239},{
      1.251892, 1.270450, -0.009484},{1.256899, 1.277340, -0.009484},{
      1.261376, 1.277340, -0.002239}}],
    Polygon[{{1.251892, 1.284231, -0.009484},{1.256899, 1.277340, -0.009484},{
      1.251892, 1.270450, -0.009484},{1.243792, 1.273082, -0.009484},{
      1.243792, 1.281599, -0.009484}}],
    Polygon[{{1.193005, 1.277057, 0.008080},{1.186104, 1.279299, 0.008080},{
      1.181839, 1.273429, 0.008080},{1.186104, 1.267559, 0.008080},{
      1.193005, 1.269801, 0.008080}}],
    Polygon[{{1.193005, 1.277057, 0.008080},{1.193005, 1.269801, 0.008080},{
      1.196091, 1.267559, 0.001907},{1.197999, 1.273429, -0.001907},{
      1.196091, 1.279299, 0.001907}}],
    Polygon[{{1.193005, 1.277057, 0.008080},{1.196091, 1.279299, 0.001907},{
      1.191098, 1.282928, -0.001907},{1.184925, 1.282928, 0.001907},{
      1.186104, 1.279299, 0.008080}}],
    Polygon[{{1.186104, 1.279299, 0.008080},{1.184925, 1.282928, 0.001907},{
      1.179932, 1.279299, -0.001907},{1.178024, 1.273429, 0.001907},{
      1.181839, 1.273429, 0.008080}}],
    Polygon[{{1.181839, 1.273429, 0.008080},{1.178024, 1.273429, 0.001907},{
      1.179932, 1.267559, -0.001907},{1.184925, 1.263931, 0.001907},{
      1.186104, 1.267559, 0.008080}}],
    Polygon[{{1.186104, 1.267559, 0.008080},{1.193005, 1.269801, 0.008080},{
      1.196091, 1.267559, 0.001907},{1.191098, 1.263931, -0.001907},{
      1.184925, 1.263931, 0.001907}}],
    Polygon[{{1.196091, 1.279299, 0.001907},{1.197999, 1.273429, -0.001907},{
      1.194184, 1.273429, -0.008080},{1.189919, 1.279299, -0.008080},{
      1.191098, 1.282928, -0.001907}}],
    Polygon[{{1.184925, 1.282928, 0.001907},{1.191098, 1.282928, -0.001907},{
      1.189919, 1.279299, -0.008080},{1.183018, 1.277057, -0.008080},{
      1.179932, 1.279299, -0.001907}}],
    Polygon[{{1.178024, 1.273429, 0.001907},{1.179932, 1.279299, -0.001907},{
      1.183018, 1.277057, -0.008080},{1.183018, 1.269801, -0.008080},{
      1.179932, 1.267559, -0.001907}}],
    Polygon[{{1.184925, 1.263931, 0.001907},{1.179932, 1.267559, -0.001907},{
      1.183018, 1.269801, -0.008080},{1.189919, 1.267559, -0.008080},{
      1.191098, 1.263931, -0.001907}}],
    Polygon[{{1.196091, 1.267559, 0.001907},{1.191098, 1.263931, -0.001907},{
      1.189919, 1.267559, -0.008080},{1.194184, 1.273429, -0.008080},{
      1.197999, 1.273429, -0.001907}}],
    Polygon[{{1.189919, 1.279299, -0.008080},{1.194184, 1.273429, -0.008080},{
      1.189919, 1.267559, -0.008080},{1.183018, 1.269801, -0.008080},{
      1.183018, 1.277057, -0.008080}}],
    Polygon[{{1.135769, 1.176909, 0.021420},{1.117474, 1.182853, 0.021420},{
      1.106167, 1.167291, 0.021420},{1.117474, 1.151728, 0.021420},{
      1.135769, 1.157673, 0.021420}}],
    Polygon[{{1.135769, 1.176909, 0.021420},{1.135769, 1.157673, 0.021420},{
      1.143950, 1.151728, 0.005057},{1.149007, 1.167291, -0.005057},{
      1.143950, 1.182853, 0.005057}}],
    Polygon[{{1.135769, 1.176909, 0.021420},{1.143950, 1.182853, 0.005057},{
      1.130712, 1.192472, -0.005057},{1.114349, 1.192472, 0.005057},{
      1.117474, 1.182853, 0.021420}}],
    Polygon[{{1.117474, 1.182853, 0.021420},{1.114349, 1.192472, 0.005057},{
      1.101110, 1.182853, -0.005057},{1.096054, 1.167291, 0.005057},{
      1.106167, 1.167291, 0.021420}}],
    Polygon[{{1.106167, 1.167291, 0.021420},{1.096054, 1.167291, 0.005057},{
      1.101110, 1.151728, -0.005057},{1.114349, 1.142110, 0.005057},{
      1.117474, 1.151728, 0.021420}}],
    Polygon[{{1.117474, 1.151728, 0.021420},{1.135769, 1.157673, 0.021420},{
      1.143950, 1.151728, 0.005057},{1.130712, 1.142110, -0.005057},{
      1.114349, 1.142110, 0.005057}}],
    Polygon[{{1.143950, 1.182853, 0.005057},{1.149007, 1.167291, -0.005057},{
      1.138894, 1.167291, -0.021420},{1.127587, 1.182853, -0.021420},{
      1.130712, 1.192472, -0.005057}}],
    Polygon[{{1.114349, 1.192472, 0.005057},{1.130712, 1.192472, -0.005057},{
      1.127587, 1.182853, -0.021420},{1.109292, 1.176909, -0.021420},{
      1.101110, 1.182853, -0.005057}}],
    Polygon[{{1.096054, 1.167291, 0.005057},{1.101110, 1.182853, -0.005057},{
      1.109292, 1.176909, -0.021420},{1.109292, 1.157673, -0.021420},{
      1.101110, 1.151728, -0.005057}}],
    Polygon[{{1.114349, 1.142110, 0.005057},{1.101110, 1.151728, -0.005057},{
      1.109292, 1.157673, -0.021420},{1.127587, 1.151728, -0.021420},{
      1.130712, 1.142110, -0.005057}}],
    Polygon[{{1.143950, 1.151728, 0.005057},{1.130712, 1.142110, -0.005057},{
      1.127587, 1.151728, -0.021420},{1.138894, 1.167291, -0.021420},{
      1.149007, 1.167291, -0.005057}}],
    Polygon[{{1.127587, 1.182853, -0.021420},{1.138894, 1.167291, -0.021420},{
      1.127587, 1.151728, -0.021420},{1.109292, 1.157673, -0.021420},{
      1.109292, 1.176909, -0.021420}}],
    Polygon[{{1.091990, 1.165677, 0.010586},{1.082948, 1.168614, 0.010586},{
      1.077360, 1.160923, 0.010586},{1.082948, 1.153232, 0.010586},{
      1.091990, 1.156169, 0.010586}}],
    Polygon[{{1.091990, 1.165677, 0.010586},{1.091990, 1.156169, 0.010586},{
      1.096034, 1.153232, 0.002499},{1.098533, 1.160923, -0.002499},{
      1.096034, 1.168614, 0.002499}}],
    Polygon[{{1.091990, 1.165677, 0.010586},{1.096034, 1.168614, 0.002499},{
      1.089491, 1.173368, -0.002499},{1.081404, 1.173368, 0.002499},{
      1.082948, 1.168614, 0.010586}}],
    Polygon[{{1.082948, 1.168614, 0.010586},{1.081404, 1.173368, 0.002499},{
      1.074861, 1.168614, -0.002499},{1.072362, 1.160923, 0.002499},{
      1.077360, 1.160923, 0.010586}}],
    Polygon[{{1.077360, 1.160923, 0.010586},{1.072362, 1.160923, 0.002499},{
      1.074861, 1.153232, -0.002499},{1.081404, 1.148478, 0.002499},{
      1.082948, 1.153232, 0.010586}}],
    Polygon[{{1.082948, 1.153232, 0.010586},{1.091990, 1.156169, 0.010586},{
      1.096034, 1.153232, 0.002499},{1.089491, 1.148478, -0.002499},{
      1.081404, 1.148478, 0.002499}}],
    Polygon[{{1.096034, 1.168614, 0.002499},{1.098533, 1.160923, -0.002499},{
      1.093535, 1.160923, -0.010586},{1.087947, 1.168614, -0.010586},{
      1.089491, 1.173368, -0.002499}}],
    Polygon[{{1.081404, 1.173368, 0.002499},{1.089491, 1.173368, -0.002499},{
      1.087947, 1.168614, -0.010586},{1.078905, 1.165677, -0.010586},{
      1.074861, 1.168614, -0.002499}}],
    Polygon[{{1.072362, 1.160923, 0.002499},{1.074861, 1.168614, -0.002499},{
      1.078905, 1.165677, -0.010586},{1.078905, 1.156169, -0.010586},{
      1.074861, 1.153232, -0.002499}}],
    Polygon[{{1.081404, 1.148478, 0.002499},{1.074861, 1.153232, -0.002499},{
      1.078905, 1.156169, -0.010586},{1.087947, 1.153232, -0.010586},{
      1.089491, 1.148478, -0.002499}}],
    Polygon[{{1.096034, 1.153232, 0.002499},{1.089491, 1.148478, -0.002499},{
      1.087947, 1.153232, -0.010586},{1.093535, 1.160923, -0.010586},{
      1.098533, 1.160923, -0.002499}}],
    Polygon[{{1.087947, 1.168614, -0.010586},{1.093535, 1.160923, -0.010586},{
      1.087947, 1.153232, -0.010586},{1.078905, 1.156169, -0.010586},{
      1.078905, 1.165677, -0.010586}}],
    Polygon[{{1.154417, 1.148732, 0.008215},{1.147400, 1.151012, 0.008215},{
      1.143064, 1.145043, 0.008215},{1.147400, 1.139075, 0.008215},{
      1.154417, 1.141355, 0.008215}}],
    Polygon[{{1.154417, 1.148732, 0.008215},{1.154417, 1.141355, 0.008215},{
      1.157554, 1.139075, 0.001939},{1.159494, 1.145043, -0.001939},{
      1.157554, 1.151012, 0.001939}}],
    Polygon[{{1.154417, 1.148732, 0.008215},{1.157554, 1.151012, 0.001939},{
      1.152477, 1.154701, -0.001939},{1.146202, 1.154701, 0.001939},{
      1.147400, 1.151012, 0.008215}}],
    Polygon[{{1.147400, 1.151012, 0.008215},{1.146202, 1.154701, 0.001939},{
      1.141125, 1.151012, -0.001939},{1.139185, 1.145043, 0.001939},{
      1.143064, 1.145043, 0.008215}}],
    Polygon[{{1.143064, 1.145043, 0.008215},{1.139185, 1.145043, 0.001939},{
      1.141125, 1.139075, -0.001939},{1.146202, 1.135386, 0.001939},{
      1.147400, 1.139075, 0.008215}}],
    Polygon[{{1.147400, 1.139075, 0.008215},{1.154417, 1.141355, 0.008215},{
      1.157554, 1.139075, 0.001939},{1.152477, 1.135386, -0.001939},{
      1.146202, 1.135386, 0.001939}}],
    Polygon[{{1.157554, 1.151012, 0.001939},{1.159494, 1.145043, -0.001939},{
      1.155615, 1.145043, -0.008215},{1.151279, 1.151012, -0.008215},{
      1.152477, 1.154701, -0.001939}}],
    Polygon[{{1.146202, 1.154701, 0.001939},{1.152477, 1.154701, -0.001939},{
      1.151279, 1.151012, -0.008215},{1.144262, 1.148732, -0.008215},{
      1.141125, 1.151012, -0.001939}}],
    Polygon[{{1.139185, 1.145043, 0.001939},{1.141125, 1.151012, -0.001939},{
      1.144262, 1.148732, -0.008215},{1.144262, 1.141355, -0.008215},{
      1.141125, 1.139075, -0.001939}}],
    Polygon[{{1.146202, 1.135386, 0.001939},{1.141125, 1.139075, -0.001939},{
      1.144262, 1.141355, -0.008215},{1.151279, 1.139075, -0.008215},{
      1.152477, 1.135386, -0.001939}}],
    Polygon[{{1.157554, 1.139075, 0.001939},{1.152477, 1.135386, -0.001939},{
      1.151279, 1.139075, -0.008215},{1.155615, 1.145043, -0.008215},{
      1.159494, 1.145043, -0.001939}}],
    Polygon[{{1.151279, 1.151012, -0.008215},{1.155615, 1.145043, -0.008215},{
      1.151279, 1.139075, -0.008215},{1.144262, 1.141355, -0.008215},{
      1.144262, 1.148732, -0.008215}}],
    Polygon[{{1.140333, 1.201935, 0.007466},{1.133956, 1.204007, 0.007466},{
      1.130015, 1.198582, 0.007466},{1.133956, 1.193158, 0.007466},{
      1.140333, 1.195230, 0.007466}}],
    Polygon[{{1.140333, 1.201935, 0.007466},{1.140333, 1.195230, 0.007466},{
      1.143184, 1.193158, 0.001762},{1.144947, 1.198582, -0.001762},{
      1.143184, 1.204007, 0.001762}}],
    Polygon[{{1.140333, 1.201935, 0.007466},{1.143184, 1.204007, 0.001762},{
      1.138570, 1.207359, -0.001762},{1.132867, 1.207359, 0.001762},{
      1.133956, 1.204007, 0.007466}}],
    Polygon[{{1.133956, 1.204007, 0.007466},{1.132867, 1.207359, 0.001762},{
      1.128253, 1.204007, -0.001762},{1.126491, 1.198582, 0.001762},{
      1.130015, 1.198582, 0.007466}}],
    Polygon[{{1.130015, 1.198582, 0.007466},{1.126491, 1.198582, 0.001762},{
      1.128253, 1.193158, -0.001762},{1.132867, 1.189806, 0.001762},{
      1.133956, 1.193158, 0.007466}}],
    Polygon[{{1.133956, 1.193158, 0.007466},{1.140333, 1.195230, 0.007466},{
      1.143184, 1.193158, 0.001762},{1.138570, 1.189806, -0.001762},{
      1.132867, 1.189806, 0.001762}}],
    Polygon[{{1.143184, 1.204007, 0.001762},{1.144947, 1.198582, -0.001762},{
      1.141422, 1.198582, -0.007466},{1.137481, 1.204007, -0.007466},{
      1.138570, 1.207359, -0.001762}}],
    Polygon[{{1.132867, 1.207359, 0.001762},{1.138570, 1.207359, -0.001762},{
      1.137481, 1.204007, -0.007466},{1.131105, 1.201935, -0.007466},{
      1.128253, 1.204007, -0.001762}}],
    Polygon[{{1.126491, 1.198582, 0.001762},{1.128253, 1.204007, -0.001762},{
      1.131105, 1.201935, -0.007466},{1.131105, 1.195230, -0.007466},{
      1.128253, 1.193158, -0.001762}}],
    Polygon[{{1.132867, 1.189806, 0.001762},{1.128253, 1.193158, -0.001762},{
      1.131105, 1.195230, -0.007466},{1.137481, 1.193158, -0.007466},{
      1.138570, 1.189806, -0.001762}}],
    Polygon[{{1.143184, 1.193158, 0.001762},{1.138570, 1.189806, -0.001762},{
      1.137481, 1.193158, -0.007466},{1.141422, 1.198582, -0.007466},{
      1.144947, 1.198582, -0.001762}}],
    Polygon[{{1.137481, 1.204007, -0.007466},{1.141422, 1.198582, -0.007466},{
      1.137481, 1.193158, -0.007466},{1.131105, 1.195230, -0.007466},{
      1.131105, 1.201935, -0.007466}}]},
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {0.519168, -0.252441, 3.491893}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00_@3ooolS00000400oooo002E0?ooobP00000803oool00`000000oooo
0?ooo`02000003h0oooo001/0?ooobT00000B03oool00`000000oooo0?ooo`020?ooo`<00000>`3o
ool004<0oooo:@00001a0?ooo`030000003oool0oooo00D0oooo0`00000h0?ooo`00?@3oool60000
09X0oooo00<000000?ooo`3oool0203oool2000003H0oooo000k0?ooo`8000000P3oool00`000000
oooo0?ooo`200?ooobT00000=@3oool003P0oooo0`0000040?ooo`030000003oool0oooo05L0oooo
:@00000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003H0oooo0P00
00070?ooo`030000003oool0oooo02h0oooo:@0000140?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0<`3oool003<0oooo0`0000090?ooo`030000003oool0oooo00H0oooo:000001]
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool00340oooo5`00001j0?oo
o`D000000`3oool01`000000oooo000000000000oooo0000003oool02`0000000`3oool000000?oo
o`0;0?ooo`030000003oool0oooo03<0oooo000a0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0D03oool<00000080oooo0P0000030?ooo`<0000000<0oooo0000000000000P3oool5
000000030?ooo`000000000000H000000P3oool5000000D0Vc<c2P0000000`0c<c<0000009/c<`02
09/c<`H0000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`0c0?ooo`00<@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool000000P3oool3
00000080oooo0P0000080?ooo`h00000302K<c<800000080Vc<c1P00000409/c<`<0000000<0<c<c
0000000000001@0000000`0c<c<0000009/c<`0909/c<`@0000000<0b:W80000000000000P0c<c<2
000000<0Vc<c0P0000001@38ZLP000000?ooo`3oool0000000`0oooo00<000000?ooo`3oool0<`3o
ool00340oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool0
1P000000oooo000000000000oooo00000080oooo30000000103oool000000000003oool:00000003
09/c<`000000000000@000000P2K<c<6000000030?ooo`000000000000<000006`2K<c<200000004
0<RYb0000000000003<c<`H000000`0c<c<00`000000Vc<c09/c<`0209/c<`<0000000<0b:W80000
000000000P00000303<c<`030000002K<c<0Vc<c00T0Vc<c1@00000303<c<`0300000038ZLP00000
0080000000@0m=5c00000000000000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo03<0oooo000b0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001`00000209/c
<`D0000000<0Vc<c0000000000000`00000;09/c<`T0000000<0<c<c0000002K<c<0102K<c<30000
000303<c<`000000000000@0000000<0b:W80000000000000P00000O09/c<`80000000@0b:W80000
0000000000000`38ZLP2000000@0<c<c0`00000209/c<`<0000000@0b:W80000000000000000100c
<c<00`000000Vc<c09/c<`0:09/c<`@000000P0c<c<00`000000b:W80<RYb0020<RYb0040000003d
dG<00000000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`00<P3o
ool00`000000oooo0?ooo`0:0?ooo`050000003oool0000000000038ZLP00P0000000`0c<c<00000
09/c<`0409/c<`80000000<0b:W80000000000000P0000000`0c<c<0000009/c<`0;09/c<`<00000
0P38ZLP2000000<0<c<c00<0000009/c<`2K<c<00`2K<c<300000080b:W800<000000?CAL`000000
0`00000303<c<`030000002K<c<0Vc<c01d0Vc<c1@0000030<RYb08000000`0c<c<010000000b:W8
0<RYb038ZLP2000000030?CAL`0000000000008000001`0c<c<00`000000Vc<c09/c<`0;09/c<`D0
00001038ZLP00`000000m=5c000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0<`3oool00380oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040000000403<c
<`000000000000000080Vc<c0`0000001038ZLP0000000000000000203<c<`030000002K<c<0Vc<c
00/0Vc<c1P00000203<c<`0300000038ZLP000000080000000<0Vc<c0000003ddG<00P0000030<RY
b0@00000100c<c<00`000000Vc<c09/c<`0P09/c<`030000000cD;l0000000@000000P0c<c<00`00
0000b:W80<RYb0030<RYb0030000003ddG<0m=5c00800000200c<c<00`000000Vc<c09/c<`0<09/c
<`80000000<0<e2o00000038ZLP00`38ZLP00`000000m=5c000000040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`3oool200000080<c<c00<000000<RYb038ZLP00P0000020?CAL`@00000100c<c<00`00
0000Vc<c09/c<`0<09/c<`<000000P0c<c<00`000000b:W80<RYb0030<RYb0070000003ddG<0m=5c
0000000cD;l000000<RYb003000000H0<c<c00<0000009/c<`2K<c<08@2K<c<200000080Vnc^1000
00060<RYb0040000003ddG<0m=5c000000X0<c<c00<0000009/c<`2K<c<02`2K<c<20000000303=@
_`000000b:W800<0b:W800<000000?CAL`000000103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo03<0oooo000b0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo
0P0000000`0c<c<000000<RYb0030<RYb0030000003ddG<0m=5c008000001P0c<c<00`000000Vc<c
09/c<`0=09/c<`8000000P0c<c<00`000000b:W80<RYb0030<RYb0030000003ddG<0m=5c00@00000
00<0Vnc^0000000c<c<01P0c<c<00`000000Vc<c09/c<`0R09/c<`D000000P0cD;l00`000000b:W8
0<RYb0030<RYb0040000003ddG<0m=5c000000T0<c<c00<000000<RYb00000000P00000909/c<`03
0000003ddG<000000080<e2o100000000`2Kk>h000000?ooo`040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`8000001@38ZLP010000000m=5c0?CAL`00000703<c<`030000002K<c<0Vc<c00d0
Vc<c100000060<RYb0030000003ddG<0m=5c00D000002@0c<c<00`000000Vc<c09/c<`0S09/c<`<0
00000P0cD;l00`000000b:W80<RYb0030<RYb0030000003ddG<0000000X0<c<c00<000000<RYb038
ZLP00P38ZLP3000000D0Vc<c00L000000?CAL`3ddG<0m=5c0000000cD;l0000000<0Vnc^00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000b0?oo
o`030000003oool0oooo00/0oooo00L000000?ooo`3oool0oooo0000000cD;l0000000@0b:W800@0
00000?CAL`3ddG<000001`0c<c<2000000d0Vc<c00<000000?CAL`0000000P0cD;l00`000000b:W8
0<RYb0030<RYb0030000003ddG<0m=5c00<000002`0c<c<00`000000Vc<c09/c<`0U09/c<`050000
000cD;l0<e2o03=@_`0000000P38ZLP5000000T0<c<c00<000000<RYb038ZLP01P38ZLP400000003
09/c<`000000m=5c0080m=5c1P0000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0<`3oool00380oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`040000
000cD;l000000<RYb0H000001P0c<c<00`000000b:W80<RYb004000000P0Vc<c00L000000?CAL`3d
dG<0m=5c0000000cD;l0000000D0b:W800<000000?CAL`3ddG<00P00000<03<c<`030000002K<c<0
Vc<c02H0Vc<c00@0000003=@_`0cD;l0<e2o0P00000309_/kP800000200c<c<00`000000b:W80<RY
b00;0<RYb0030000003ddG<0m=5c0080m=5c1P0000070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`030000000cD;l0000000@0Vnc^00<0000003<c<`0c<c<01@0c<c<00`000000b:W80<RYb004
0<RYb0<00000102K<c<00`000000m=5c0?CAL`020?CAL`050000000cD;l0<e2o00000038ZLP00`00
0000102Kk>h0000000000000000>03<c<`030000002K<c<0Vc<c02H0Vc<c0P0000000`0cD;l00000
09_/kP0209_/kP8000002@0c<c<00`000000b:W80<RYb00;0<RYb0030000003ddG<0m=5c0080m=5c
0P0000020<RYb0030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0c0?ooo`00<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo1`00
000603<c<`0300000038ZLP0b:W800P0b:W8100000060?CAL`040000000cD;l0<e2o000000@0Vnc^
0P00000?03<c<`030000002K<c<0Vc<c02P0Vc<c1`00000803<c<`0300000038ZLP0b:W800`0b:W8
00<000000?CAL`3ddG<00`3ddG<4000000P0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0c0?ooo`00<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo0`00
00000`2K<c<000000000000603<c<`0300000038ZLP0b:W800/0b:W800<000000?CAL`3ddG<01@3d
dG<400000080Vnc^0P00000A03<c<`030000002K<c<0Vc<c02T0Vc<c1P00000703<c<`0300000038
ZLP0b:W800d0b:W800<000000?CAL`3ddG<00`3ddG<3000000T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0c0?ooo`00<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00D0oooo1@00000603<c<`0300000038ZLP0b:W800/0b:W800<000000?CAL`3ddG<01P3ddG<6
00000180<c<c00<0000009/c<`2K<c<0:P2K<c<2000000030<RYb0000000000000H0<c<c00<00000
0<RYb038ZLP03P38ZLP00`000000m=5c0?CAL`030?CAL`<000002@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03<0oooo000b0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01@3oool2000000030<RYb0000000000000D0<c<c00<000000<RYb038ZLP03038ZLP00`00
0000m=5c0?CAL`060?CAL`0300000038ZLP0000000800000500c<c<00`000000Vc<c09/c<`0[09/c
<`D00000100c<c<00`000000b:W80<RYb00>0<RYb0030000003ddG<0m=5c00<0m=5c0P00000:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`060?ooo`<000001@0c<c<00`000000b:W80<RYb00=0<RYb003
0000003ddG<0m=5c00H0m=5c00@000000<RYb000000000005@0c<c<00`000000Vc<c09/c<`0/09/c
<`8000000P0cD;l400000140b:W800<000000?CAL`3ddG<00`3ddG<00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`8000001@0c<c<00`000000b:W80<RYb00=0<RYb003
0000003ddG<0m=5c00H0m=5c1000000E03<c<`030000002K<c<0Vc<c02d0Vc<c0P00000503=@_`03
00000038ZLP0b:W800h0b:W800<000000?CAL`3ddG<00P3ddG<00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool00380oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`L000004038ZLP00`000000m=5c0?CAL`060?CAL`<00000
5P0c<c<00`000000Vc<c09/c<`0_09/c<`030000000cD;l0<e2o00<0<e2o00<000000<RYb038ZLP0
3@38ZLP00`000000m=5c0?CAL`020?CAL`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0c0?ooo`00<P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<0000003=@_`0cD;l00P0cD;l00`000000b:W80<RYb00?0<RYb0030000003d
dG<0m=5c00D0m=5c0P00000H03<c<`030000002K<c<0Vc<c02d0Vc<c0P00000503=@_`0300000038
ZLP0b:W800d0b:W800<000000?CAL`3ddG<00P3ddG<00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000000cD;l0<e2o0080<e2o00<000000<RYb038ZLP03P38ZLP0
0`000000m=5c0?CAL`040?CAL`030000000c<c<0<c<c01P0<c<c00<0000009/c<`2K<c<0;02K<c<0
0`000000m=5c0000000603=@_`0300000038ZLP0b:W800`0b:W800<000000?CAL`3ddG<00P3ddG<0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool0
03<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000000cD;l0<e2o
00<0<e2o00<000000<RYb038ZLP03@38ZLP00`000000m=5c0?CAL`040?CAL`030000000c<c<0<c<c
01P0<c<c00<0000009/c<`2K<c<0:`2K<c<01@000000m=5c0?CAL`3ddG<0000000H0<e2o00<00000
0<RYb038ZLP02`38ZLP01@000000m=5c0?CAL`3ddG<0000000d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0c0?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<0000003=@_`0cD;l00P0cD;l00`000000b:W80<RYb00=0<RYb0030000003ddG<0
m=5c00@0m=5c00<0000003<c<`0c<c<0600c<c<2000002/0Vc<c00<000000?CAL`3ddG<00P3ddG<0
0`000000<e2o03=@_`0503=@_`0300000038ZLP0b:W800L0b:W80`0000001@2Kk>h000000?CAL`3d
dG<0000000d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`00<`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0000003=@_`0cD;l00`0cD;l0
0`000000b:W80<RYb00<0<RYb0030000003ddG<0m=5c00@0m=5c00<0000003<c<`0c<c<0600c<c<0
0`000000b:W800000002000002L0Vc<c00<000000?CAL`3ddG<00`3ddG<00`000000<e2o03=@_`05
03=@_`0300000038ZLP0b:W800@0b:W80`00000509_/kP<000003@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03<0oooo000c0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000<e2o03=@_`0303=@_`0300000038ZLP0b:W800T0b:W8100000040?CA
L`030000000c<c<0<c<c01P0<c<c00<000000<RYb038ZLP00`38ZLP3000002<0Vc<c00<000000?CA
L`3ddG<01@3ddG<00`000000<e2o03=@_`0503=@_`0300000038ZLP0b:W800<000002@2Kk>h00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000000cD;l0<e2o00@0
<e2o00<000000<RYb038ZLP01P38ZLP2000000@0Vnc^0P0000020?CAL`030000000c<c<0<c<c01P0
<c<c00<000000<RYb038ZLP01P38ZLP4000001h0Vc<c00<000000?CAL`3ddG<01P3ddG<00`000000
<e2o03=@_`0603=@_`8000002P2Kk>h2000000l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0c0?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo
00<0000003=@_`0cD;l0100cD;l00`000000b:W80<RYb0020<RYb0<00000202Kk>h3000001T0<c<c
00<000000<RYb038ZLP02`38ZLP3000001/0Vc<c00<000000?CAL`3ddG<01P3ddG<2000000H0<e2o
00<0000009_/kP2Kk>h02@2Kk>h00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0<`3oool003<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0=0?ooo`030000000cD;l0<e2o00<0<e2o00<000000<RYb00000000P00000;09_/kP8000006@0c
<c<00`000000b:W80<RYb00?0<RYb0<000005`2K<c<00`000000m=5c0?CAL`080?CAL`<00000100c
D;l00`000000Vnc^09_/kP0709_/kP8000004P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo03<0oooo000c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool0
0`000000<e2o03=@_`0303=@_`030000002Kk>h0Vnc^00/0Vnc^0P00000J03<c<`0300000038ZLP0
b:W80180b:W81000000B09/c<`030000003ddG<0m=5c00T0m=5c1000000203=@_`030000002Kk>h0
Vnc^00H0Vnc^1@00000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool0
03<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`8000000`0cD;l00`00
0000Vnc^09_/kP0909_/kP@000006@0c<c<00`000000b:W80<RYb00G0<RYb0<000003P2K<c<00`00
0000m=5c0?CAL`0:0?CAL`D0000000<0<e2o0000002Kk>h020000000102K<c<0000000000000000A
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`8000000P0cD;l00`000000Vnc^09_/kP0809_/
kP@000006@0c<c<00`000000b:W80<RYb00K0<RYb0@000002@2K<c<00`000000m=5c0?CAL`0<0?CA
L`80000000<0b:W80000000000000P00000309/c<`@0000000<0b:W80000000000004`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000c0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool4000000L0Vnc^2000000I03<c<`0300000038ZLP0b:W801l0
b:W80`00000509/c<`030000003ddG<0m=5c00d0m=5c1000000203<c<`030000002K<c<0Vc<c0080
Vc<c0`0000000`38ZLP000000000000C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0<`3oool003<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`800000
00<0<c<c0000000000001`0000000`2K<c<00000000000020<RYb0800000600c<c<00`000000b:W8
0<RYb00S0<RYb0<0000000<0Vc<c0000003ddG<03`3ddG<3000000<0<c<c0P00000409/c<`030000
000cD;l00000008000004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo
000c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool2000000030<RYb000
0000m=5c00<000001@2K<c<4000001P0<c<c00<000000<RYb038ZLP09`38ZLP200000140m=5c0P00
000303<c<`0300000038ZLP0000000<0000000@0m=5c0000000000000000503oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000c0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0403oool2000000030<RYb000000000000080<c<c00<0000009/c<`2K<c<0102K
<c<3000001P0<c<c00<000000<RYb038ZLP0:038ZLP00`000000m=5c0?CAL`0?0?CAL`050000000c
<c<0<c<c03<c<`0000001@38ZLP00`000000m=5c00000002000001@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0c0?ooo`00<`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0140oooo1000000203<c<`@000000P2K<c<010000000m=5c00000000000G03<c<`030000
0038ZLP0b:W802T0b:W800<000000?CAL`3ddG<03`3ddG<010000000<c<c03<c<`0000060<RYb003
0000003ddG<0000001H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`00
<`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo0`00000203<c<`040000
0038ZLP0b:W80<RYb08000000P3ddG<00`000000<c<c03<c<`0E03<c<`0300000038ZLP0b:W802X0
b:W800<000000?CAL`3ddG<03`3ddG<4000000H0b:W800<000000?CAL`0000005P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000c0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04P3oool200000080<c<c00<000000<RYb038ZLP00`38ZLP010000000m=5c
0?CAL`00000F03<c<`0300000038ZLP0b:W802/0b:W800<000000?CAL`3ddG<0403ddG<010000000
<e2o03=@_`0000050<RYb0030000003ddG<0000001H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0c0?ooo`00=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0
oooo0`0000060<RYb0040000003ddG<0m=5c000001H0<c<c00<000000<RYb038ZLP0:`38ZLP00`00
0000m=5c0?CAL`0@0?CAL`040000000cD;l0<e2o000000@0b:W80P0000000`3ddG<000000?ooo`0E
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000000cD;l0000000D0b:W800<000000?CA
L`0000005P0c<c<00`000000b:W80<RYb00/0<RYb0030000003ddG<0m=5c0100m=5c0P00000203=@
_`@000000P2Kk>h00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<`3oool003@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`03
0000000cD;l0000000D0b:W800<000000?CAL`0000005@0c<c<00`000000b:W80<RYb00]0<RYb003
0000003ddG<0m=5c0100m=5c0`0000000`0cD;l0000009_/kP0209_/kP800000603oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000d0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool05@3oool00`000000<e2o000000020<RYb080000000<0Vnc^000000000000
5@0c<c<00`000000b:W80<RYb00]0<RYb0030000003ddG<0m=5c0100m=5c2@00000I0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0F0?ooo`040000000cD;l00000000000<0Vnc^0P00000D03<c<`030000
0038ZLP0b:W802h0b:W800<000000?CAL`3ddG<04@3ddG<00`000000<c<c0000000209/c<`030000
0038ZLP0000001T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`00=03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo1`00000D03<c<`0300000038
ZLP0b:W802l0b:W800<000000?CAL`3ddG<0403ddG<010000000<c<c00000038ZLP4000001X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`00=03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01L0oooo1@0000000`2K<c<0000003<c<`0C03<c<`0300000038
ZLP0b:W802l0b:W800<000000?CAL`3ddG<0403ddG<300000080b:W800<000000?CAL`0000006P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo000d0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool05`3oool30000000403<c<`0000000000000001<0<c<c00<0
00000<RYb038ZLP0<038ZLP00`000000m=5c0?CAL`0@0?CAL`030000000cD;l000000080b:W80P00
000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`050000000c<c<000000<RYb00000004`0c
<c<00`000000b:W80<RYb00a0<RYb0030000003ddG<0m=5c0140m=5c00<0000003=@_`0000000`00
000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`80000000<0b:W80000000c<c<04P0c<c<0
0`000000b:W80<RYb00a0<RYb0030000003ddG<0m=5c0140m=5c1@00000L0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0H0?ooo`80000000@0b:W80000000000000000400c<c<00`000000b:W80<RYb00b
0<RYb0030000003ddG<0m=5c0100m=5c00<0000003<c<`0000000P00000M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0I0?ooo`<000000P0cD;l4000000/0<c<c00<000000<RYb038ZLP0<`38ZLP00`00
0000m=5c0?CAL`0@0?CAL`80000000<0b:W80000000000007@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03<0oooo000d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool06`3oool2000000D0<e2o1000000703<c<`0300000038ZLP0b:W803<0b:W800<000000?CAL`3d
dG<0403ddG<5000001d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00
=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo0`00000903=@_`@00000
0P0c<c<00`000000b:W80<RYb00d0<RYb0030000003ddG<0m=5c0100m=5c0`00000O0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0K0?ooo`0300000038ZLP0000000`0<e2o0P00000g0<RYb0030000003d
dG<0m=5c00l0m=5c00<000000?ooo`3oool0803oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo03@0oooo000d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool2
000000h0<e2o00<000000<RYb038ZLP0=038ZLP00`000000m=5c0?CAL`0?0?CAL`030000003oool0
oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<0000003=@_`0cD;l0300cD;l00`00
0000b:W80<RYb00c0<RYb0030000003ddG<0m=5c00l0m=5c00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool07P3oool00`000000<e2o03=@_`0<03=@_`0300000038ZLP0b:W803<0
b:W800<000000?CAL`3ddG<03`3ddG<00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0O0?ooo`030000000cD;l0<e2o00`0<e2o00<000000<RYb038ZLP0<P38ZLP00`000000m=5c
0?CAL`0>0?CAL`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0d0?ooo`00=@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<0
000003=@_`0cD;l03@0cD;l00`000000b:W80<RYb00a0<RYb0030000003ddG<0m=5c00h0m=5c00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000e
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`000000<e2o03=@_`0=
03=@_`0300000038ZLP0b:W80300b:W800<000000?CAL`3ddG<03P3ddG<00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000000cD;l0<e2o00h0<e2o00<000000<RY
b038ZLP0;`38ZLP00`000000m=5c0?CAL`0>0?CAL`030000003oool0oooo0240oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0240oooo00<0000003=@_`0cD;l03@0cD;l00`000000b:W80<RYb00_0<RYb003
0000003ddG<0m=5c00d0m=5c00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
8@3oool00`000000<e2o03=@_`0>03=@_`0300000038ZLP0b:W802h0b:W800<000000?CAL`3ddG<0
3@3ddG<00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
=03oool003D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000000c
D;l0<e2o00h0<e2o00<000000<RYb038ZLP0;@38ZLP00`000000m=5c0?CAL`0=0?CAL`030000003o
ool0oooo0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<0000003=@_`0cD;l03`0cD;l0
0`000000b:W80<RYb00/0<RYb0030000003ddG<0m=5c00d0m=5c00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool08`3oool00`000000<e2o03=@_`0?03=@_`0300000038ZLP0b:W8
02/0b:W800<000000?CAL`3ddG<03@3ddG<00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0R0?ooo`030000000cD;l0<e2o00l0<e2o00<000000<RYb038ZLP0:`38ZLP00`000000
m=5c0?CAL`0<0?CAL`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0d0?ooo`00=@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo
00<0000003=@_`0cD;l03`0cD;l00`000000b:W80<RYb00Z0<RYb0030000003ddG<0m=5c00`0m=5c
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo
000e0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000<e2o03=@
_`0@03=@_`0300000038ZLP0b:W802T0b:W800<000000?CAL`3ddG<0303ddG<00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`030000000cD;l0<e2o0100<e2o00<00000
0<RYb038ZLP0:038ZLP00`000000m=5c0?CAL`0<0?CAL`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02@0oooo00<0000003=@_`0cD;l0400cD;l00`000000b:W80<RYb00V0<RY
b0H000002P3ddG<00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0=03oool003D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`03
0000000cD;l0<e2o0100<e2o00<000000<RYb038ZLP08P38ZLP3000000H0Vnc^0`0000070?CAL`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00
=@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<0000003=@_`0cD;l0
4@0cD;l00`000000b:W80<RYb00N0<RYb0<00000302Kk>h3000000@0m=5c00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000<e2o03=@_`0A03=@_`0300000038
ZLP0b:W801X0b:W80`00000B09_/kP<0000000<0m=5c0000003oool09@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool09`3oool200000180<e2o00<000000<RYb038ZLP05P38ZLP3000001P0Vnc^00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000<e2o03=@_`0?03=@
_`0300000038ZLP0b:W801<0b:W80`00000I09_/kP800000:03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0:P3oool00`000000<e2o03=@_`0?03=@_`0300000038ZLP0b:W800l0b:W80`00000J09_/kP80
0000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00`000000<e2o03=@_`0?03=@_`030000
0038ZLP0b:W800/0b:W80`00000K09_/kP800000;03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03@0oooo000f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;03o
ool00`000000<e2o03=@_`0?03=@_`0300000038ZLP0b:W800L0b:W80`00000L09_/kP800000;P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000<e2o03=@_`0?03=@_`0300000038ZLP0
b:W800<0b:W80`00000N09_/kP030000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02h0oooo00<0000003=@_`0cD;l03P0cD;l010000000b:W80<RYb038ZLP2000001l0Vnc^0`00000`
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`<000003`0cD;l3000001l0Vnc^1@00000`0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0]0?ooo`<0000000<0Vc<c0000000cD;l03@0cD;l00`000000
Vnc^09_/kP0M09_/kPD0000000<0b:W8000000000000;`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03@0oooo000f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
;@3oool2000000040<RYb00000000000000000`0<e2o00<0000009_/kP2Kk>h0702Kk>h300000080
Vc<c1000000`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`80000000<0b:W8000000000000
0P00000;03=@_`030000002Kk>h0Vnc^01X0Vnc^0`00000203<c<`030000002K<c<0Vc<c00800000
<@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0;@3oool30000000403<c<`000000Vc<c000000X0<e2o
00<0000009_/kP2Kk>h06@2Kk>h40000000303<c<`000000b:W800<00000<P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0;`3oool2000000040<RYb00000000000000000P0<e2o00<0000009_/kP2Kk>h0
602Kk>h7000000<0b:W80P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
=03oool003H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0^0?ooo`<000000P38
ZLP010000000m=5c00000000000603=@_`030000002Kk>h0Vnc^01<0Vnc^1P00000409/c<`<00000
0P38ZLP200000380oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02l0oooo0P0000020<RYb0<0000000<0
<c<c0000000cD;l00`0cD;l00`000000Vnc^09_/kP0>09_/kPT000000P0c<c<00`000000Vc<c09/c
<`0309/c<`D00000<`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000f
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<03oool500000080<c<c0P000003
03=@_`030000002Kk>h0Vnc^00P0Vnc^1P0000000`2K<c<0000000000005000000@0<c<c00<00000
09/c<`2K<c<00P2K<c<4000003@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d
0?ooo`00=`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0340oooo0`00000303<c
<`<0000000<0<e2o0000002Kk>h0102Kk>h6000000P0Vc<c0`0000000`38ZLP000000000000303<c
<`0300000038ZLP0000000<0000000@0m=5c0000000000000000=03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<@3oool300000080<c<c00<000000<RYb038ZLP02`0000000`0c<c<0000009/c<`0:09/c
<`@000000P0c<c<00`000000b:W80<RYb0030<RYb0040000003ddG<0m=5c000003D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0380oooo00D0000003<c<`0c<c<0<c<c000000040<RYb0030000003ddG<0
m=5c00@000000`0c<c<00`000000Vc<c09/c<`0:09/c<`@0000000<0<c<c00000038ZLP01038ZLP0
10000000m=5c0?CAL`00000e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03o
ool003L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0b0?ooo`@000001@38ZLP0
0`000000m=5c0?CAL`02000000D0<c<c00<0000009/c<`2K<c<02`2K<c<20000000303=@_`000000
b:W800D0b:W800<000000?CAL`000000=P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03@0oooo000g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<`3oool00`00
0000<e2o000000050<RYb0040000003ddG<0m=5c000000H0<c<c00<0000009/c<`2K<c<0302K<c<2
0000000303=@_`000000b:W800@0b:W800<000000?CAL`000000=P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<`3oool010000000<e2o03=@_`0000040<RYb0040000003ddG<0m=5c000000L0<c<c00<0
000009/c<`2K<c<0302K<c<20000000303=@_`000000b:W80080b:W81000000f0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0=03oool003L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0d0?ooo`030000000cD;l000000080b:W81@00000803<c<`030000002K<c<0
Vc<c00`0Vc<c0P00000203=@_`<0000000<0Vnc^000000000000=`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0=@3oool010000000<e2o00000000000209_/kP8000002@0c<c<00`000000Vc<c09/c<`0;
09/c<`030000003ddG<0000000L00000>03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03@0oooo000g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=P3oool70000
00T0<c<c1000000909/c<`040000003ddG<0m=5c0?CAL`<0000000@0Vc<c0000000000000000>03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0=P3oool20000000303<c<`000000Vc<c00800000200c<c<0
0`000000b:W80<RYb0020<RYb0<000001@2K<c<00`000000m=5c0?CAL`020?CAL`030000000c<c<0
000000<00000>@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000g0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=`3oool2000000030<RYb00000000000
00P0<c<c00<000000<RYb038ZLP01P38ZLP40000000309/c<`000000m=5c00@0m=5c00<000000<RY
b038ZLP00P00000i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003L0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?ooo`80000000<0b:W800000000
0000200c<c<00`000000b:W80<RYb00:0<RYb0030000003ddG<0m=5c00@0m=5c1000000j0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0h0?ooo`@000001`0c<c<00`000000b:W80<RYb00;0<RYb0030000
003ddG<0m=5c00@0m=5c0`00000k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
=03oool003L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`8000001`0c
<c<00`000000b:W80<RYb00<0<RYb0030000003ddG<0m=5c00@0m=5c0`00000k0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0=03oool003L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0h0?ooo`8000001`0c<c<00`000000b:W80<RYb00<0<RYb0030000003ddG<0
m=5c00@0m=5c00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03@0oooo000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>P3oool30000
00<0<c<c00<000000<RYb038ZLP03@38ZLP00`000000m=5c0?CAL`040?CAL`030000003oool0oooo
03/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00=`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo00<0000003=@_`0cD;l00`00000@0<RYb003
0000003ddG<0m=5c00<0m=5c00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03@0oooo000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
>P3oool00`000000<e2o03=@_`0203=@_`0300000038ZLP0b:W800h0b:W800<000000?CAL`3ddG<0
0`3ddG<00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
=03oool003P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0k0?ooo`030000000c
D;l0<e2o0080<e2o00<000000<RYb038ZLP03@38ZLP00`000000m=5c0?CAL`030?CAL`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00>03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo00<0000003=@_`0cD;l00`0cD;l0
0`000000b:W80<RYb00<0<RYb0030000003ddG<0m=5c00<0m=5c00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo000h0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0?03oool00`000000<e2o03=@_`0303=@_`0300000038ZLP0b:W8
00/0b:W800<000000?CAL`3ddG<00P3ddG<00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0=03oool003P0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0l0?ooo`030000000cD;l0<e2o00<0<e2o00<000000<RYb038ZLP02`38ZLP00`000000
m=5c0?CAL`020?CAL`030000003oool0oooo03d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo
00<0000003=@_`0cD;l00`0cD;l00`000000b:W80<RYb0080<RYb0P00000?`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03@0oooo000h0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0?P3oool2000000@0<e2o00<000000<RYb038ZLP01038ZLP3000000D0Vnc^0P00
00100?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`030000000cD;l0<e2o0080<e2o00<00000
0<RYb038ZLP00`00000609_/kP800000@P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03@0oooo000h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool00`00
0000<e2o03=@_`0203=@_`8000001`2Kk>h3000004<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0400
oooo0`00000203=@_`030000002Kk>h0Vnc^00@0Vnc^1P0000130?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0=03oool003P0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`100?ooo`@0000000<0<e2o0000002Kk>h01P0000000`0c<c<0000000000002000004<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0440oooo0P0000000`38ZLP0000000000002000000@0Vc<c0P00
00000`38ZLP00000000000140?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03o
ool003P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`120?ooo`0400000038ZLP0
000000000080<c<c00<0000009/c<`2K<c<00P2K<c<4000004@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo04<0oooo0P00000303<c<`8000000P2K<c<4000004D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
04<0oooo0P00000203<c<`0300000038ZLP0b:W8008000000P3ddG<2000004D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04@0oooo00<0000003<c<`0000001038ZLP010000000m=5c0?CAL`0000160?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool003P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`130?ooo`<000001038ZLP00`000000m=5c0000000U0?ooob<0
00002`3oool00`000000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04@0oooo00<0000003=@_`0000000`38ZLP00`000000m=5c0000000U00000280oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01d0oooo:P0000000`38ZLP0000000000003000004P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`0:
0?ooob000000:@3oool5000004X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d
0?ooo`00>@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04L0oooo1@00001;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`170?ooo`80000000<0b:W8000000000000B`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0B@3oool3000004d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo0P00
001=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool003T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0=03oool003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0=03oool003T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03o
ool003T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool003T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool003T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2R0?ooo`050000003oool0oooo0?ooo`000000
=P3oool003T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2S0?ooo`050000003o
ool0oooo0?ooo`000000=P3oool003X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2T0?ooo`040000003oool0oooo000003H0oooo000j0?ooo`050000003oool0oooo0?ooo`000000
Y`3oool010000000oooo0?ooo`00000f0?ooo`00>P3oool01@000000oooo0?ooo`3oool000000:P0
oooo00<000000?ooo`000000=P3oool003X0oooo00@000000?ooo`3oool00000Z@3oool00`000000
oooo0000000f0?ooo`00>P3oool010000000oooo0?ooo`00002Z0?ooo`800000=P3oool003X0oooo
00<000000?ooo`000000Z`3oool2000003H0oooo000j0?ooo`030000003oool0000009P0oooo5@00
000f0?ooo`00>P3oool2000006h0oooo:`00001;0?ooo`00>P3oool2000004<0oooo:`00001f0?oo
o`00>P3oool2000001P0oooo:`00002Q0?ooo`00>P3ooolJ00000<`0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< Graphics`Shapes`\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(sphe[{x_, y_}, r_] := 
      TranslateShape[
        Graphics3D[Sphere[r, 20, 20]], {x, y, 
          0}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(cir = 
        type[0, {0, 0}, {2, 0}, {1. , \@3}, 5];\)\), "\[IndentingNewLine]", 
    \(\(Show[\(sphe[First[#], Last[#]] &\) /@ cir, Boxed \[Rule] False, 
        FaceGrids \[Rule] None, AspectRatio \[Rule] Automatic];\)\)}], "Input",\

  CellLabel->"In[353]:="],

Cell[BoxData[
  Graphics3D[{
    Polygon[{{1.090317, 0.577350, -0.570242},{1.085897, 0.605260, -0.570242},{
      1.073068, 0.630438, -0.570242},{1.053087, 0.650419, -0.570242},{
      1.027910, 0.663247, -0.570242},{1.000000, 0.667668, -0.570242},{
      0.972090, 0.663247, -0.570242},{0.946913, 0.650419, -0.570242},{
      0.926932, 0.630438, -0.570242},{0.914103, 0.605260, -0.570242},{
      0.909683, 0.577350, -0.570242},{0.914103, 0.549441, -0.570242},{
      0.926932, 0.524263, -0.570242},{0.946913, 0.504282, -0.570242},{
      0.972090, 0.491453, -0.570242},{1.000000, 0.487033, -0.570242},{
      1.027910, 0.491453, -0.570242},{1.053087, 0.504282, -0.570242},{
      1.073068, 0.524263, -0.570242},{1.085897, 0.549441, -0.570242}}],
    Polygon[{{1.085897, 0.549441, 0.570242},{1.073068, 0.524263, 0.570242},{
      1.053087, 0.504282, 0.570242},{1.027910, 0.491453, 0.570242},{
      1.000000, 0.487033, 0.570242},{0.972090, 0.491453, 0.570242},{
      0.946913, 0.504282, 0.570242},{0.926932, 0.524263, 0.570242},{
      0.914103, 0.549441, 0.570242},{0.909683, 0.577350, 0.570242},{
      0.914103, 0.605260, 0.570242},{0.926932, 0.630438, 0.570242},{
      0.946913, 0.650419, 0.570242},{0.972090, 0.663247, 0.570242},{
      1.000000, 0.667668, 0.570242},{1.027910, 0.663247, 0.570242},{
      1.053087, 0.650419, 0.570242},{1.073068, 0.630438, 0.570242},{
      1.085897, 0.605260, 0.570242},{1.090317, 0.577350, 0.570242}}],
    Polygon[{{0.363439, 0.192450, -0.190081},{0.361966, 0.201753, -0.190081},{
      0.357689, 0.210146, -0.190081},{0.351029, 0.216806, -0.190081},{
      0.342637, 0.221082, -0.190081},{0.333333, 0.222556, -0.190081},{
      0.324030, 0.221082, -0.190081},{0.315638, 0.216806, -0.190081},{
      0.308977, 0.210146, -0.190081},{0.304701, 0.201753, -0.190081},{
      0.303228, 0.192450, -0.190081},{0.304701, 0.183147, -0.190081},{
      0.308977, 0.174754, -0.190081},{0.315638, 0.168094, -0.190081},{
      0.324030, 0.163818, -0.190081},{0.333333, 0.162344, -0.190081},{
      0.342637, 0.163818, -0.190081},{0.351029, 0.168094, -0.190081},{
      0.357689, 0.174754, -0.190081},{0.361966, 0.183147, -0.190081}}],
    Polygon[{{0.361966, 0.183147, 0.190081},{0.357689, 0.174754, 0.190081},{
      0.351029, 0.168094, 0.190081},{0.342637, 0.163818, 0.190081},{
      0.333333, 0.162344, 0.190081},{0.324030, 0.163818, 0.190081},{
      0.315638, 0.168094, 0.190081},{0.308977, 0.174754, 0.190081},{
      0.304701, 0.183147, 0.190081},{0.303228, 0.192450, 0.190081},{
      0.304701, 0.201753, 0.190081},{0.308977, 0.210146, 0.190081},{
      0.315638, 0.216806, 0.190081},{0.324030, 0.221082, 0.190081},{
      0.333333, 0.222556, 0.190081},{0.342637, 0.221082, 0.190081},{
      0.351029, 0.216806, 0.190081},{0.357689, 0.210146, 0.190081},{
      0.361966, 0.201753, 0.190081},{0.363439, 0.192450, 0.190081}}],
    Polygon[{{0.121146, 0.064150, -0.063360},{0.120655, 0.067251, -0.063360},{
      0.119230, 0.070049, -0.063360},{0.117010, 0.072269, -0.063360},{
      0.114212, 0.073694, -0.063360},{0.111111, 0.074185, -0.063360},{
      0.108010, 0.073694, -0.063360},{0.105213, 0.072269, -0.063360},{
      0.102992, 0.070049, -0.063360},{0.101567, 0.067251, -0.063360},{
      0.101076, 0.064150, -0.063360},{0.101567, 0.061049, -0.063360},{
      0.102992, 0.058251, -0.063360},{0.105213, 0.056031, -0.063360},{
      0.108010, 0.054606, -0.063360},{0.111111, 0.054115, -0.063360},{
      0.114212, 0.054606, -0.063360},{0.117010, 0.056031, -0.063360},{
      0.119230, 0.058251, -0.063360},{0.120655, 0.061049, -0.063360}}],
    Polygon[{{0.120655, 0.061049, 0.063360},{0.119230, 0.058251, 0.063360},{
      0.117010, 0.056031, 0.063360},{0.114212, 0.054606, 0.063360},{
      0.111111, 0.054115, 0.063360},{0.108010, 0.054606, 0.063360},{
      0.105213, 0.056031, 0.063360},{0.102992, 0.058251, 0.063360},{
      0.101567, 0.061049, 0.063360},{0.101076, 0.064150, 0.063360},{
      0.101567, 0.067251, 0.063360},{0.102992, 0.070049, 0.063360},{
      0.105213, 0.072269, 0.063360},{0.108010, 0.073694, 0.063360},{
      0.111111, 0.074185, 0.063360},{0.114212, 0.073694, 0.063360},{
      0.117010, 0.072269, 0.063360},{0.119230, 0.070049, 0.063360},{
      0.120655, 0.067251, 0.063360},{0.121146, 0.064150, 0.063360}}],
    Polygon[{{0.040382, 0.021383, -0.021120},{0.040218, 0.022417, -0.021120},{
      0.039743, 0.023350, -0.021120},{0.039003, 0.024090, -0.021120},{
      0.038071, 0.024565, -0.021120},{0.037037, 0.024728, -0.021120},{
      0.036003, 0.024565, -0.021120},{0.035071, 0.024090, -0.021120},{
      0.034331, 0.023350, -0.021120},{0.033856, 0.022417, -0.021120},{
      0.033692, 0.021383, -0.021120},{0.033856, 0.020350, -0.021120},{
      0.034331, 0.019417, -0.021120},{0.035071, 0.018677, -0.021120},{
      0.036003, 0.018202, -0.021120},{0.037037, 0.018038, -0.021120},{
      0.038071, 0.018202, -0.021120},{0.039003, 0.018677, -0.021120},{
      0.039743, 0.019417, -0.021120},{0.040218, 0.020350, -0.021120}}],
    Polygon[{{0.040218, 0.020350, 0.021120},{0.039743, 0.019417, 0.021120},{
      0.039003, 0.018677, 0.021120},{0.038071, 0.018202, 0.021120},{
      0.037037, 0.018038, 0.021120},{0.036003, 0.018202, 0.021120},{
      0.035071, 0.018677, 0.021120},{0.034331, 0.019417, 0.021120},{
      0.033856, 0.020350, 0.021120},{0.033692, 0.021383, 0.021120},{
      0.033856, 0.022417, 0.021120},{0.034331, 0.023350, 0.021120},{
      0.035071, 0.024090, 0.021120},{0.036003, 0.024565, 0.021120},{
      0.037037, 0.024728, 0.021120},{0.038071, 0.024565, 0.021120},{
      0.039003, 0.024090, 0.021120},{0.039743, 0.023350, 0.021120},{
      0.040218, 0.022417, 0.021120},{0.040382, 0.021383, 0.021120}}],
    Polygon[{{0.013461, 0.007128, -0.007040},{0.013406, 0.007472, -0.007040},{
      0.013248, 0.007783, -0.007040},{0.013001, 0.008030, -0.007040},{
      0.012690, 0.008188, -0.007040},{0.012346, 0.008243, -0.007040},{
      0.012001, 0.008188, -0.007040},{0.011690, 0.008030, -0.007040},{
      0.011444, 0.007783, -0.007040},{0.011285, 0.007472, -0.007040},{
      0.011231, 0.007128, -0.007040},{0.011285, 0.006783, -0.007040},{
      0.011444, 0.006472, -0.007040},{0.011690, 0.006226, -0.007040},{
      0.012001, 0.006067, -0.007040},{0.012346, 0.006013, -0.007040},{
      0.012690, 0.006067, -0.007040},{0.013001, 0.006226, -0.007040},{
      0.013248, 0.006472, -0.007040},{0.013406, 0.006783, -0.007040}}],
    Polygon[{{0.013406, 0.006783, 0.007040},{0.013248, 0.006472, 0.007040},{
      0.013001, 0.006226, 0.007040},{0.012690, 0.006067, 0.007040},{
      0.012346, 0.006013, 0.007040},{0.012001, 0.006067, 0.007040},{
      0.011690, 0.006226, 0.007040},{0.011444, 0.006472, 0.007040},{
      0.011285, 0.006783, 0.007040},{0.011231, 0.007128, 0.007040},{
      0.011285, 0.007472, 0.007040},{0.011444, 0.007783, 0.007040},{
      0.011690, 0.008030, 0.007040},{0.012001, 0.008188, 0.007040},{
      0.012346, 0.008243, 0.007040},{0.012690, 0.008188, 0.007040},{
      0.013001, 0.008030, 0.007040},{0.013248, 0.007783, 0.007040},{
      0.013406, 0.007472, 0.007040},{0.013461, 0.007128, 0.007040}}],
    Polygon[{{0.065495, 0.008594, -0.008489},{0.065429, 0.009010, -0.008489},{
      0.065238, 0.009385, -0.008489},{0.064940, 0.009682, -0.008489},{
      0.064565, 0.009873, -0.008489},{0.064150, 0.009939, -0.008489},{
      0.063735, 0.009873, -0.008489},{0.063360, 0.009682, -0.008489},{
      0.063062, 0.009385, -0.008489},{0.062871, 0.009010, -0.008489},{
      0.062806, 0.008594, -0.008489},{0.062871, 0.008179, -0.008489},{
      0.063062, 0.007804, -0.008489},{0.063360, 0.007507, -0.008489},{
      0.063735, 0.007316, -0.008489},{0.064150, 0.007250, -0.008489},{
      0.064565, 0.007316, -0.008489},{0.064940, 0.007507, -0.008489},{
      0.065238, 0.007804, -0.008489},{0.065429, 0.008179, -0.008489}}],
    Polygon[{{0.065429, 0.008179, 0.008489},{0.065238, 0.007804, 0.008489},{
      0.064940, 0.007507, 0.008489},{0.064565, 0.007316, 0.008489},{
      0.064150, 0.007250, 0.008489},{0.063735, 0.007316, 0.008489},{
      0.063360, 0.007507, 0.008489},{0.063062, 0.007804, 0.008489},{
      0.062871, 0.008179, 0.008489},{0.062806, 0.008594, 0.008489},{
      0.062871, 0.009010, 0.008489},{0.063062, 0.009385, 0.008489},{
      0.063360, 0.009682, 0.008489},{0.063735, 0.009873, 0.008489},{
      0.064150, 0.009939, 0.008489},{0.064565, 0.009873, 0.008489},{
      0.064940, 0.009682, 0.008489},{0.065238, 0.009385, 0.008489},{
      0.065429, 0.009010, 0.008489},{0.065495, 0.008594, 0.008489}}],
    Polygon[{{0.040863, 0.051258, -0.008489},{0.040797, 0.051674, -0.008489},{
      0.040606, 0.052049, -0.008489},{0.040308, 0.052346, -0.008489},{
      0.039934, 0.052537, -0.008489},{0.039518, 0.052603, -0.008489},{
      0.039103, 0.052537, -0.008489},{0.038728, 0.052346, -0.008489},{
      0.038430, 0.052049, -0.008489},{0.038239, 0.051674, -0.008489},{
      0.038174, 0.051258, -0.008489},{0.038239, 0.050843, -0.008489},{
      0.038430, 0.050468, -0.008489},{0.038728, 0.050171, -0.008489},{
      0.039103, 0.049980, -0.008489},{0.039518, 0.049914, -0.008489},{
      0.039934, 0.049980, -0.008489},{0.040308, 0.050171, -0.008489},{
      0.040606, 0.050468, -0.008489},{0.040797, 0.050843, -0.008489}}],
    Polygon[{{0.040797, 0.050843, 0.008489},{0.040606, 0.050468, 0.008489},{
      0.040308, 0.050171, 0.008489},{0.039934, 0.049980, 0.008489},{
      0.039518, 0.049914, 0.008489},{0.039103, 0.049980, 0.008489},{
      0.038728, 0.050171, 0.008489},{0.038430, 0.050468, 0.008489},{
      0.038239, 0.050843, 0.008489},{0.038174, 0.051258, 0.008489},{
      0.038239, 0.051674, 0.008489},{0.038430, 0.052049, 0.008489},{
      0.038728, 0.052346, 0.008489},{0.039103, 0.052537, 0.008489},{
      0.039518, 0.052603, 0.008489},{0.039934, 0.052537, 0.008489},{
      0.040308, 0.052346, 0.008489},{0.040606, 0.052049, 0.008489},{
      0.040797, 0.051674, 0.008489},{0.040863, 0.051258, 0.008489}}],
    Polygon[{{0.196484, 0.025783, -0.025466},{0.196286, 0.027030, -0.025466},{
      0.195713, 0.028154, -0.025466},{0.194821, 0.029047, -0.025466},{
      0.193696, 0.029619, -0.025466},{0.192450, 0.029817, -0.025466},{
      0.191204, 0.029619, -0.025466},{0.190079, 0.029047, -0.025466},{
      0.189187, 0.028154, -0.025466},{0.188614, 0.027030, -0.025466},{
      0.188417, 0.025783, -0.025466},{0.188614, 0.024537, -0.025466},{
      0.189187, 0.023413, -0.025466},{0.190079, 0.022520, -0.025466},{
      0.191204, 0.021947, -0.025466},{0.192450, 0.021750, -0.025466},{
      0.193696, 0.021947, -0.025466},{0.194821, 0.022520, -0.025466},{
      0.195713, 0.023413, -0.025466},{0.196286, 0.024537, -0.025466}}],
    Polygon[{{0.196286, 0.024537, 0.025466},{0.195713, 0.023413, 0.025466},{
      0.194821, 0.022520, 0.025466},{0.193696, 0.021947, 0.025466},{
      0.192450, 0.021750, 0.025466},{0.191204, 0.021947, 0.025466},{
      0.190079, 0.022520, 0.025466},{0.189187, 0.023413, 0.025466},{
      0.188614, 0.024537, 0.025466},{0.188417, 0.025783, 0.025466},{
      0.188614, 0.027030, 0.025466},{0.189187, 0.028154, 0.025466},{
      0.190079, 0.029047, 0.025466},{0.191204, 0.029619, 0.025466},{
      0.192450, 0.029817, 0.025466},{0.193696, 0.029619, 0.025466},{
      0.194821, 0.029047, 0.025466},{0.195713, 0.028154, 0.025466},{
      0.196286, 0.027030, 0.025466},{0.196484, 0.025783, 0.025466}}],
    Polygon[{{0.232361, 0.013817, -0.013647},{0.232255, 0.014485, -0.013647},{
      0.231948, 0.015088, -0.013647},{0.231470, 0.015566, -0.013647},{
      0.230868, 0.015873, -0.013647},{0.230200, 0.015979, -0.013647},{
      0.229532, 0.015873, -0.013647},{0.228929, 0.015566, -0.013647},{
      0.228451, 0.015088, -0.013647},{0.228144, 0.014485, -0.013647},{
      0.228038, 0.013817, -0.013647},{0.228144, 0.013149, -0.013647},{
      0.228451, 0.012547, -0.013647},{0.228929, 0.012069, -0.013647},{
      0.229532, 0.011762, -0.013647},{0.230200, 0.011656, -0.013647},{
      0.230868, 0.011762, -0.013647},{0.231470, 0.012069, -0.013647},{
      0.231948, 0.012547, -0.013647},{0.232255, 0.013149, -0.013647}}],
    Polygon[{{0.232255, 0.013149, 0.013647},{0.231948, 0.012547, 0.013647},{
      0.231470, 0.012069, 0.013647},{0.230868, 0.011762, 0.013647},{
      0.230200, 0.011656, 0.013647},{0.229532, 0.011762, 0.013647},{
      0.228929, 0.012069, 0.013647},{0.228451, 0.012547, 0.013647},{
      0.228144, 0.013149, 0.013647},{0.228038, 0.013817, 0.013647},{
      0.228144, 0.014485, 0.013647},{0.228451, 0.015088, 0.013647},{
      0.228929, 0.015566, 0.013647},{0.229532, 0.015873, 0.013647},{
      0.230200, 0.015979, 0.013647},{0.230868, 0.015873, 0.013647},{
      0.231470, 0.015566, 0.013647},{0.231948, 0.015088, 0.013647},{
      0.232255, 0.014485, 0.013647},{0.232361, 0.013817, 0.013647}}],
    Polygon[{{0.162402, 0.009657, -0.009538},{0.162328, 0.010124, -0.009538},{
      0.162113, 0.010545, -0.009538},{0.161779, 0.010879, -0.009538},{
      0.161358, 0.011094, -0.009538},{0.160891, 0.011168, -0.009538},{
      0.160424, 0.011094, -0.009538},{0.160003, 0.010879, -0.009538},{
      0.159669, 0.010545, -0.009538},{0.159454, 0.010124, -0.009538},{
      0.159380, 0.009657, -0.009538},{0.159454, 0.009190, -0.009538},{
      0.159669, 0.008769, -0.009538},{0.160003, 0.008435, -0.009538},{
      0.160424, 0.008220, -0.009538},{0.160891, 0.008146, -0.009538},{
      0.161358, 0.008220, -0.009538},{0.161779, 0.008435, -0.009538},{
      0.162113, 0.008769, -0.009538},{0.162328, 0.009190, -0.009538}}],
    Polygon[{{0.162328, 0.009190, 0.009538},{0.162113, 0.008769, 0.009538},{
      0.161779, 0.008435, 0.009538},{0.161358, 0.008220, 0.009538},{
      0.160891, 0.008146, 0.009538},{0.160424, 0.008220, 0.009538},{
      0.160003, 0.008435, 0.009538},{0.159669, 0.008769, 0.009538},{
      0.159454, 0.009190, 0.009538},{0.159380, 0.009657, 0.009538},{
      0.159454, 0.010124, 0.009538},{0.159669, 0.010545, 0.009538},{
      0.160003, 0.010879, 0.009538},{0.160424, 0.011094, 0.009538},{
      0.160891, 0.011168, 0.009538},{0.161358, 0.011094, 0.009538},{
      0.161779, 0.010879, 0.009538},{0.162113, 0.010545, 0.009538},{
      0.162328, 0.010124, 0.009538},{0.162402, 0.009657, 0.009538}}],
    Polygon[{{0.184767, 0.058755, -0.008290},{0.184703, 0.059161, -0.008290},{
      0.184516, 0.059527, -0.008290},{0.184226, 0.059817, -0.008290},{
      0.183860, 0.060004, -0.008290},{0.183454, 0.060068, -0.008290},{
      0.183048, 0.060004, -0.008290},{0.182682, 0.059817, -0.008290},{
      0.182392, 0.059527, -0.008290},{0.182205, 0.059161, -0.008290},{
      0.182141, 0.058755, -0.008290},{0.182205, 0.058349, -0.008290},{
      0.182392, 0.057983, -0.008290},{0.182682, 0.057693, -0.008290},{
      0.183048, 0.057506, -0.008290},{0.183454, 0.057442, -0.008290},{
      0.183860, 0.057506, -0.008290},{0.184226, 0.057693, -0.008290},{
      0.184516, 0.057983, -0.008290},{0.184703, 0.058349, -0.008290}}],
    Polygon[{{0.184703, 0.058349, 0.008290},{0.184516, 0.057983, 0.008290},{
      0.184226, 0.057693, 0.008290},{0.183860, 0.057506, 0.008290},{
      0.183454, 0.057442, 0.008290},{0.183048, 0.057506, 0.008290},{
      0.182682, 0.057693, 0.008290},{0.182392, 0.057983, 0.008290},{
      0.182205, 0.058349, 0.008290},{0.182141, 0.058755, 0.008290},{
      0.182205, 0.059161, 0.008290},{0.182392, 0.059527, 0.008290},{
      0.182682, 0.059817, 0.008290},{0.183048, 0.060004, 0.008290},{
      0.183454, 0.060068, 0.008290},{0.183860, 0.060004, 0.008290},{
      0.184226, 0.059817, 0.008290},{0.184516, 0.059527, 0.008290},{
      0.184703, 0.059161, 0.008290},{0.184767, 0.058755, 0.008290}}],
    Polygon[{{0.122588, 0.153775, -0.025466},{0.122390, 0.155021, -0.025466},{
      0.121817, 0.156146, -0.025466},{0.120925, 0.157038, -0.025466},{
      0.119801, 0.157611, -0.025466},{0.118554, 0.157808, -0.025466},{
      0.117308, 0.157611, -0.025466},{0.116183, 0.157038, -0.025466},{
      0.115291, 0.156146, -0.025466},{0.114718, 0.155021, -0.025466},{
      0.114521, 0.153775, -0.025466},{0.114718, 0.152529, -0.025466},{
      0.115291, 0.151404, -0.025466},{0.116183, 0.150512, -0.025466},{
      0.117308, 0.149939, -0.025466},{0.118554, 0.149742, -0.025466},{
      0.119801, 0.149939, -0.025466},{0.120925, 0.150512, -0.025466},{
      0.121817, 0.151404, -0.025466},{0.122390, 0.152529, -0.025466}}],
    Polygon[{{0.122390, 0.152529, 0.025466},{0.121817, 0.151404, 0.025466},{
      0.120925, 0.150512, 0.025466},{0.119801, 0.149939, 0.025466},{
      0.118554, 0.149742, 0.025466},{0.117308, 0.149939, 0.025466},{
      0.116183, 0.150512, 0.025466},{0.115291, 0.151404, 0.025466},{
      0.114718, 0.152529, 0.025466},{0.114521, 0.153775, 0.025466},{
      0.114718, 0.155021, 0.025466},{0.115291, 0.156146, 0.025466},{
      0.116183, 0.157038, 0.025466},{0.117308, 0.157611, 0.025466},{
      0.118554, 0.157808, 0.025466},{0.119801, 0.157611, 0.025466},{
      0.120925, 0.157038, 0.025466},{0.121817, 0.156146, 0.025466},{
      0.122390, 0.155021, 0.025466},{0.122588, 0.153775, 0.025466}}],
    Polygon[{{0.129227, 0.192450, -0.013647},{0.129122, 0.193118, -0.013647},{
      0.128815, 0.193721, -0.013647},{0.128336, 0.194199, -0.013647},{
      0.127734, 0.194506, -0.013647},{0.127066, 0.194612, -0.013647},{
      0.126398, 0.194506, -0.013647},{0.125795, 0.194199, -0.013647},{
      0.125317, 0.193721, -0.013647},{0.125010, 0.193118, -0.013647},{
      0.124904, 0.192450, -0.013647},{0.125010, 0.191782, -0.013647},{
      0.125317, 0.191180, -0.013647},{0.125795, 0.190701, -0.013647},{
      0.126398, 0.190394, -0.013647},{0.127066, 0.190289, -0.013647},{
      0.127734, 0.190394, -0.013647},{0.128336, 0.190701, -0.013647},{
      0.128815, 0.191180, -0.013647},{0.129122, 0.191782, -0.013647}}],
    Polygon[{{0.129122, 0.191782, 0.013647},{0.128815, 0.191180, 0.013647},{
      0.128336, 0.190701, 0.013647},{0.127734, 0.190394, 0.013647},{
      0.127066, 0.190289, 0.013647},{0.126398, 0.190394, 0.013647},{
      0.125795, 0.190701, 0.013647},{0.125317, 0.191180, 0.013647},{
      0.125010, 0.191782, 0.013647},{0.124904, 0.192450, 0.013647},{
      0.125010, 0.193118, 0.013647},{0.125317, 0.193721, 0.013647},{
      0.125795, 0.194199, 0.013647},{0.126398, 0.194506, 0.013647},{
      0.127066, 0.194612, 0.013647},{0.127734, 0.194506, 0.013647},{
      0.128336, 0.194199, 0.013647},{0.128815, 0.193721, 0.013647},{
      0.129122, 0.193118, 0.013647},{0.129227, 0.192450, 0.013647}}],
    Polygon[{{0.090320, 0.134507, -0.009538},{0.090246, 0.134974, -0.009538},{
      0.090031, 0.135395, -0.009538},{0.089697, 0.135729, -0.009538},{
      0.089276, 0.135944, -0.009538},{0.088809, 0.136018, -0.009538},{
      0.088342, 0.135944, -0.009538},{0.087921, 0.135729, -0.009538},{
      0.087587, 0.135395, -0.009538},{0.087372, 0.134974, -0.009538},{
      0.087298, 0.134507, -0.009538},{0.087372, 0.134040, -0.009538},{
      0.087587, 0.133619, -0.009538},{0.087921, 0.133285, -0.009538},{
      0.088342, 0.133070, -0.009538},{0.088809, 0.132996, -0.009538},{
      0.089276, 0.133070, -0.009538},{0.089697, 0.133285, -0.009538},{
      0.090031, 0.133619, -0.009538},{0.090246, 0.134040, -0.009538}}],
    Polygon[{{0.090246, 0.134040, 0.009538},{0.090031, 0.133619, 0.009538},{
      0.089697, 0.133285, 0.009538},{0.089276, 0.133070, 0.009538},{
      0.088809, 0.132996, 0.009538},{0.088342, 0.133070, 0.009538},{
      0.087921, 0.133285, 0.009538},{0.087587, 0.133619, 0.009538},{
      0.087372, 0.134040, 0.009538},{0.087298, 0.134507, 0.009538},{
      0.087372, 0.134974, 0.009538},{0.087587, 0.135395, 0.009538},{
      0.087921, 0.135729, 0.009538},{0.088342, 0.135944, 0.009538},{
      0.088809, 0.136018, 0.009538},{0.089276, 0.135944, 0.009538},{
      0.089697, 0.135729, 0.009538},{0.090031, 0.135395, 0.009538},{
      0.090246, 0.134974, 0.009538},{0.090320, 0.134507, 0.009538}}],
    Polygon[{{0.143923, 0.129498, -0.008290},{0.143859, 0.129904, -0.008290},{
      0.143673, 0.130270, -0.008290},{0.143382, 0.130560, -0.008290},{
      0.143016, 0.130747, -0.008290},{0.142610, 0.130811, -0.008290},{
      0.142205, 0.130747, -0.008290},{0.141839, 0.130560, -0.008290},{
      0.141548, 0.130270, -0.008290},{0.141362, 0.129904, -0.008290},{
      0.141297, 0.129498, -0.008290},{0.141362, 0.129092, -0.008290},{
      0.141548, 0.128726, -0.008290},{0.141839, 0.128436, -0.008290},{
      0.142205, 0.128249, -0.008290},{0.142610, 0.128185, -0.008290},{
      0.143016, 0.128249, -0.008290},{0.143382, 0.128436, -0.008290},{
      0.143673, 0.128726, -0.008290},{0.143859, 0.129092, -0.008290}}],
    Polygon[{{0.143859, 0.129092, 0.008290},{0.143673, 0.128726, 0.008290},{
      0.143382, 0.128436, 0.008290},{0.143016, 0.128249, 0.008290},{
      0.142610, 0.128185, 0.008290},{0.142205, 0.128249, 0.008290},{
      0.141839, 0.128436, 0.008290},{0.141548, 0.128726, 0.008290},{
      0.141362, 0.129092, 0.008290},{0.141297, 0.129498, 0.008290},{
      0.141362, 0.129904, 0.008290},{0.141548, 0.130270, 0.008290},{
      0.141839, 0.130560, 0.008290},{0.142205, 0.130747, 0.008290},{
      0.142610, 0.130811, 0.008290},{0.143016, 0.130747, 0.008290},{
      0.143382, 0.130560, 0.008290},{0.143673, 0.130270, 0.008290},{
      0.143859, 0.129904, 0.008290},{0.143923, 0.129498, 0.008290}}],
    Polygon[{{0.589451, 0.077350, -0.076398},{0.588858, 0.081089, -0.076398},{
      0.587140, 0.084463, -0.076398},{0.584463, 0.087140, -0.076398},{
      0.581089, 0.088858, -0.076398},{0.577350, 0.089451, -0.076398},{
      0.573611, 0.088858, -0.076398},{0.570238, 0.087140, -0.076398},{
      0.567561, 0.084463, -0.076398},{0.565842, 0.081089, -0.076398},{
      0.565250, 0.077350, -0.076398},{0.565842, 0.073611, -0.076398},{
      0.567561, 0.070238, -0.076398},{0.570238, 0.067561, -0.076398},{
      0.573611, 0.065842, -0.076398},{0.577350, 0.065250, -0.076398},{
      0.581089, 0.065842, -0.076398},{0.584463, 0.067561, -0.076398},{
      0.587140, 0.070238, -0.076398},{0.588858, 0.073611, -0.076398}}],
    Polygon[{{0.588858, 0.073611, 0.076398},{0.587140, 0.070238, 0.076398},{
      0.584463, 0.067561, 0.076398},{0.581089, 0.065842, 0.076398},{
      0.577350, 0.065250, 0.076398},{0.573611, 0.065842, 0.076398},{
      0.570238, 0.067561, 0.076398},{0.567561, 0.070238, 0.076398},{
      0.565842, 0.073611, 0.076398},{0.565250, 0.077350, 0.076398},{
      0.565842, 0.081089, 0.076398},{0.567561, 0.084463, 0.076398},{
      0.570238, 0.087140, 0.076398},{0.573611, 0.088858, 0.076398},{
      0.577350, 0.089451, 0.076398},{0.581089, 0.088858, 0.076398},{
      0.584463, 0.087140, 0.076398},{0.587140, 0.084463, 0.076398},{
      0.588858, 0.081089, 0.076398},{0.589451, 0.077350, 0.076398}}],
    Polygon[{{0.697083, 0.041452, -0.040942},{0.696766, 0.043456, -0.040942},{
      0.695845, 0.045263, -0.040942},{0.694410, 0.046698, -0.040942},{
      0.692603, 0.047619, -0.040942},{0.690599, 0.047936, -0.040942},{
      0.688595, 0.047619, -0.040942},{0.686787, 0.046698, -0.040942},{
      0.685353, 0.045263, -0.040942},{0.684432, 0.043456, -0.040942},{
      0.684114, 0.041452, -0.040942},{0.684432, 0.039448, -0.040942},{
      0.685353, 0.037640, -0.040942},{0.686787, 0.036206, -0.040942},{
      0.688595, 0.035285, -0.040942},{0.690599, 0.034967, -0.040942},{
      0.692603, 0.035285, -0.040942},{0.694410, 0.036206, -0.040942},{
      0.695845, 0.037640, -0.040942},{0.696766, 0.039448, -0.040942}}],
    Polygon[{{0.696766, 0.039448, 0.040942},{0.695845, 0.037640, 0.040942},{
      0.694410, 0.036206, 0.040942},{0.692603, 0.035285, 0.040942},{
      0.690599, 0.034967, 0.040942},{0.688595, 0.035285, 0.040942},{
      0.686787, 0.036206, 0.040942},{0.685353, 0.037640, 0.040942},{
      0.684432, 0.039448, 0.040942},{0.684114, 0.041452, 0.040942},{
      0.684432, 0.043456, 0.040942},{0.685353, 0.045263, 0.040942},{
      0.686787, 0.046698, 0.040942},{0.688595, 0.047619, 0.040942},{
      0.690599, 0.047936, 0.040942},{0.692603, 0.047619, 0.040942},{
      0.694410, 0.046698, 0.040942},{0.695845, 0.045263, 0.040942},{
      0.696766, 0.043456, 0.040942},{0.697083, 0.041452, 0.040942}}],
    Polygon[{{0.760017, 0.025783, -0.025466},{0.759819, 0.027030, -0.025466},{
      0.759246, 0.028154, -0.025466},{0.758354, 0.029047, -0.025466},{
      0.757229, 0.029619, -0.025466},{0.755983, 0.029817, -0.025466},{
      0.754737, 0.029619, -0.025466},{0.753612, 0.029047, -0.025466},{
      0.752720, 0.028154, -0.025466},{0.752147, 0.027030, -0.025466},{
      0.751950, 0.025783, -0.025466},{0.752147, 0.024537, -0.025466},{
      0.752720, 0.023413, -0.025466},{0.753612, 0.022520, -0.025466},{
      0.754737, 0.021947, -0.025466},{0.755983, 0.021750, -0.025466},{
      0.757229, 0.021947, -0.025466},{0.758354, 0.022520, -0.025466},{
      0.759246, 0.023413, -0.025466},{0.759819, 0.024537, -0.025466}}],
    Polygon[{{0.759819, 0.024537, 0.025466},{0.759246, 0.023413, 0.025466},{
      0.758354, 0.022520, 0.025466},{0.757229, 0.021947, 0.025466},{
      0.755983, 0.021750, 0.025466},{0.754737, 0.021947, 0.025466},{
      0.753612, 0.022520, 0.025466},{0.752720, 0.023413, 0.025466},{
      0.752147, 0.024537, 0.025466},{0.751950, 0.025783, 0.025466},{
      0.752147, 0.027030, 0.025466},{0.752720, 0.028154, 0.025466},{
      0.753612, 0.029047, 0.025466},{0.754737, 0.029619, 0.025466},{
      0.755983, 0.029817, 0.025466},{0.757229, 0.029619, 0.025466},{
      0.758354, 0.029047, 0.025466},{0.759246, 0.028154, 0.025466},{
      0.759819, 0.027030, 0.025466},{0.760017, 0.025783, 0.025466}}],
    Polygon[{{0.644896, 0.013817, -0.013647},{0.644790, 0.014485, -0.013647},{
      0.644483, 0.015088, -0.013647},{0.644005, 0.015566, -0.013647},{
      0.643402, 0.015873, -0.013647},{0.642734, 0.015979, -0.013647},{
      0.642066, 0.015873, -0.013647},{0.641464, 0.015566, -0.013647},{
      0.640986, 0.015088, -0.013647},{0.640679, 0.014485, -0.013647},{
      0.640573, 0.013817, -0.013647},{0.640679, 0.013149, -0.013647},{
      0.640986, 0.012547, -0.013647},{0.641464, 0.012069, -0.013647},{
      0.642066, 0.011762, -0.013647},{0.642734, 0.011656, -0.013647},{
      0.643402, 0.011762, -0.013647},{0.644005, 0.012069, -0.013647},{
      0.644483, 0.012547, -0.013647},{0.644790, 0.013149, -0.013647}}],
    Polygon[{{0.644790, 0.013149, 0.013647},{0.644483, 0.012547, 0.013647},{
      0.644005, 0.012069, 0.013647},{0.643402, 0.011762, 0.013647},{
      0.642734, 0.011656, 0.013647},{0.642066, 0.011762, 0.013647},{
      0.641464, 0.012069, 0.013647},{0.640986, 0.012547, 0.013647},{
      0.640679, 0.013149, 0.013647},{0.640573, 0.013817, 0.013647},{
      0.640679, 0.014485, 0.013647},{0.640986, 0.015088, 0.013647},{
      0.641464, 0.015566, 0.013647},{0.642066, 0.015873, 0.013647},{
      0.642734, 0.015979, 0.013647},{0.643402, 0.015873, 0.013647},{
      0.644005, 0.015566, 0.013647},{0.644483, 0.015088, 0.013647},{
      0.644790, 0.014485, 0.013647},{0.644896, 0.013817, 0.013647}}],
    Polygon[{{0.668683, 0.090242, -0.012733},{0.668585, 0.090865, -0.012733},{
      0.668298, 0.091427, -0.012733},{0.667852, 0.091874, -0.012733},{
      0.667290, 0.092160, -0.012733},{0.666667, 0.092259, -0.012733},{
      0.666043, 0.092160, -0.012733},{0.665481, 0.091874, -0.012733},{
      0.665035, 0.091427, -0.012733},{0.664749, 0.090865, -0.012733},{
      0.664650, 0.090242, -0.012733},{0.664749, 0.089619, -0.012733},{
      0.665035, 0.089057, -0.012733},{0.665481, 0.088610, -0.012733},{
      0.666043, 0.088324, -0.012733},{0.666667, 0.088225, -0.012733},{
      0.667290, 0.088324, -0.012733},{0.667852, 0.088610, -0.012733},{
      0.668298, 0.089057, -0.012733},{0.668585, 0.089619, -0.012733}}],
    Polygon[{{0.668585, 0.089619, 0.012733},{0.668298, 0.089057, 0.012733},{
      0.667852, 0.088610, 0.012733},{0.667290, 0.088324, 0.012733},{
      0.666667, 0.088225, 0.012733},{0.666043, 0.088324, 0.012733},{
      0.665481, 0.088610, 0.012733},{0.665035, 0.089057, 0.012733},{
      0.664749, 0.089619, 0.012733},{0.664650, 0.090242, 0.012733},{
      0.664749, 0.090865, 0.012733},{0.665035, 0.091427, 0.012733},{
      0.665481, 0.091874, 0.012733},{0.666043, 0.092160, 0.012733},{
      0.666667, 0.092259, 0.012733},{0.667290, 0.092160, 0.012733},{
      0.667852, 0.091874, 0.012733},{0.668298, 0.091427, 0.012733},{
      0.668585, 0.090865, 0.012733},{0.668683, 0.090242, 0.012733}}],
    Polygon[{{0.487205, 0.028972, -0.028615},{0.486983, 0.030372, -0.028615},{
      0.486339, 0.031635, -0.028615},{0.485337, 0.032638, -0.028615},{
      0.484073, 0.033282, -0.028615},{0.482673, 0.033504, -0.028615},{
      0.481272, 0.033282, -0.028615},{0.480009, 0.032638, -0.028615},{
      0.479006, 0.031635, -0.028615},{0.478363, 0.030372, -0.028615},{
      0.478141, 0.028972, -0.028615},{0.478363, 0.027571, -0.028615},{
      0.479006, 0.026308, -0.028615},{0.480009, 0.025305, -0.028615},{
      0.481272, 0.024661, -0.028615},{0.482673, 0.024439, -0.028615},{
      0.484073, 0.024661, -0.028615},{0.485337, 0.025305, -0.028615},{
      0.486339, 0.026308, -0.028615},{0.486983, 0.027571, -0.028615}}],
    Polygon[{{0.486983, 0.027571, 0.028615},{0.486339, 0.026308, 0.028615},{
      0.485337, 0.025305, 0.028615},{0.484073, 0.024661, 0.028615},{
      0.482673, 0.024439, 0.028615},{0.481272, 0.024661, 0.028615},{
      0.480009, 0.025305, 0.028615},{0.479006, 0.026308, 0.028615},{
      0.478363, 0.027571, 0.028615},{0.478141, 0.028972, 0.028615},{
      0.478363, 0.030372, 0.028615},{0.479006, 0.031635, 0.028615},{
      0.480009, 0.032638, 0.028615},{0.481272, 0.033282, 0.028615},{
      0.482673, 0.033504, 0.028615},{0.484073, 0.033282, 0.028615},{
      0.485337, 0.032638, 0.028615},{0.486339, 0.031635, 0.028615},{
      0.486983, 0.030372, 0.028615},{0.487205, 0.028972, 0.028615}}],
    Polygon[{{0.443279, 0.015038, -0.014853},{0.443164, 0.015765, -0.014853},{
      0.442830, 0.016421, -0.014853},{0.442310, 0.016941, -0.014853},{
      0.441654, 0.017276, -0.014853},{0.440927, 0.017391, -0.014853},{
      0.440200, 0.017276, -0.014853},{0.439544, 0.016941, -0.014853},{
      0.439024, 0.016421, -0.014853},{0.438690, 0.015765, -0.014853},{
      0.438574, 0.015038, -0.014853},{0.438690, 0.014311, -0.014853},{
      0.439024, 0.013655, -0.014853},{0.439544, 0.013135, -0.014853},{
      0.440200, 0.012801, -0.014853},{0.440927, 0.012686, -0.014853},{
      0.441654, 0.012801, -0.014853},{0.442310, 0.013135, -0.014853},{
      0.442830, 0.013655, -0.014853},{0.443164, 0.014311, -0.014853}}],
    Polygon[{{0.443164, 0.014311, 0.014853},{0.442830, 0.013655, 0.014853},{
      0.442310, 0.013135, 0.014853},{0.441654, 0.012801, 0.014853},{
      0.440927, 0.012686, 0.014853},{0.440200, 0.012801, 0.014853},{
      0.439544, 0.013135, 0.014853},{0.439024, 0.013655, 0.014853},{
      0.438690, 0.014311, 0.014853},{0.438574, 0.015038, 0.014853},{
      0.438690, 0.015765, 0.014853},{0.439024, 0.016421, 0.014853},{
      0.439544, 0.016941, 0.014853},{0.440200, 0.017276, 0.014853},{
      0.440927, 0.017391, 0.014853},{0.441654, 0.017276, 0.014853},{
      0.442310, 0.016941, 0.014853},{0.442830, 0.016421, 0.014853},{
      0.443164, 0.015765, 0.014853},{0.443279, 0.015038, 0.014853}}],
    Polygon[{{0.520362, 0.011149, -0.011012},{0.520276, 0.011688, -0.011012},{
      0.520029, 0.012174, -0.011012},{0.519643, 0.012560, -0.011012},{
      0.519157, 0.012808, -0.011012},{0.518618, 0.012893, -0.011012},{
      0.518079, 0.012808, -0.011012},{0.517592, 0.012560, -0.011012},{
      0.517207, 0.012174, -0.011012},{0.516959, 0.011688, -0.011012},{
      0.516873, 0.011149, -0.011012},{0.516959, 0.010610, -0.011012},{
      0.517207, 0.010124, -0.011012},{0.517592, 0.009738, -0.011012},{
      0.518079, 0.009490, -0.011012},{0.518618, 0.009405, -0.011012},{
      0.519157, 0.009490, -0.011012},{0.519643, 0.009738, -0.011012},{
      0.520029, 0.010124, -0.011012},{0.520276, 0.010610, -0.011012}}],
    Polygon[{{0.520276, 0.010610, 0.011012},{0.520029, 0.010124, 0.011012},{
      0.519643, 0.009738, 0.011012},{0.519157, 0.009490, 0.011012},{
      0.518618, 0.009405, 0.011012},{0.518079, 0.009490, 0.011012},{
      0.517592, 0.009738, 0.011012},{0.517207, 0.010124, 0.011012},{
      0.516959, 0.010610, 0.011012},{0.516873, 0.011149, 0.011012},{
      0.516959, 0.011688, 0.011012},{0.517207, 0.012174, 0.011012},{
      0.517592, 0.012560, 0.011012},{0.518079, 0.012808, 0.011012},{
      0.518618, 0.012893, 0.011012},{0.519157, 0.012808, 0.011012},{
      0.519643, 0.012560, 0.011012},{0.520029, 0.012174, 0.011012},{
      0.520276, 0.011688, 0.011012},{0.520362, 0.011149, 0.011012}}],
    Polygon[{{0.492670, 0.066488, -0.009381},{0.492597, 0.066947, -0.009381},{
      0.492386, 0.067361, -0.009381},{0.492057, 0.067690, -0.009381},{
      0.491643, 0.067901, -0.009381},{0.491184, 0.067974, -0.009381},{
      0.490725, 0.067901, -0.009381},{0.490310, 0.067690, -0.009381},{
      0.489982, 0.067361, -0.009381},{0.489771, 0.066947, -0.009381},{
      0.489698, 0.066488, -0.009381},{0.489771, 0.066029, -0.009381},{
      0.489982, 0.065615, -0.009381},{0.490310, 0.065286, -0.009381},{
      0.490725, 0.065075, -0.009381},{0.491184, 0.065002, -0.009381},{
      0.491643, 0.065075, -0.009381},{0.492057, 0.065286, -0.009381},{
      0.492386, 0.065615, -0.009381},{0.492597, 0.066029, -0.009381}}],
    Polygon[{{0.492597, 0.066029, 0.009381},{0.492386, 0.065615, 0.009381},{
      0.492057, 0.065286, 0.009381},{0.491643, 0.065075, 0.009381},{
      0.491184, 0.065002, 0.009381},{0.490725, 0.065075, 0.009381},{
      0.490310, 0.065286, 0.009381},{0.489982, 0.065615, 0.009381},{
      0.489771, 0.066029, 0.009381},{0.489698, 0.066488, 0.009381},{
      0.489771, 0.066947, 0.009381},{0.489982, 0.067361, 0.009381},{
      0.490310, 0.067690, 0.009381},{0.490725, 0.067901, 0.009381},{
      0.491184, 0.067974, 0.009381},{0.491643, 0.067901, 0.009381},{
      0.492057, 0.067690, 0.009381},{0.492386, 0.067361, 0.009381},{
      0.492597, 0.066947, 0.009381},{0.492670, 0.066488, 0.009381}}],
    Polygon[{{0.554301, 0.176266, -0.024871},{0.554108, 0.177483, -0.024871},{
      0.553548, 0.178581, -0.024871},{0.552677, 0.179452, -0.024871},{
      0.551579, 0.180012, -0.024871},{0.550362, 0.180205, -0.024871},{
      0.549144, 0.180012, -0.024871},{0.548046, 0.179452, -0.024871},{
      0.547175, 0.178581, -0.024871},{0.546615, 0.177483, -0.024871},{
      0.546422, 0.176266, -0.024871},{0.546615, 0.175048, -0.024871},{
      0.547175, 0.173950, -0.024871},{0.548046, 0.173079, -0.024871},{
      0.549144, 0.172519, -0.024871},{0.550362, 0.172326, -0.024871},{
      0.551579, 0.172519, -0.024871},{0.552677, 0.173079, -0.024871},{
      0.553548, 0.173950, -0.024871},{0.554108, 0.175048, -0.024871}}],
    Polygon[{{0.554108, 0.175048, 0.024871},{0.553548, 0.173950, 0.024871},{
      0.552677, 0.173079, 0.024871},{0.551579, 0.172519, 0.024871},{
      0.550362, 0.172326, 0.024871},{0.549144, 0.172519, 0.024871},{
      0.548046, 0.173079, 0.024871},{0.547175, 0.173950, 0.024871},{
      0.546615, 0.175048, 0.024871},{0.546422, 0.176266, 0.024871},{
      0.546615, 0.177483, 0.024871},{0.547175, 0.178581, 0.024871},{
      0.548046, 0.179452, 0.024871},{0.549144, 0.180012, 0.024871},{
      0.550362, 0.180205, 0.024871},{0.551579, 0.180012, 0.024871},{
      0.552677, 0.179452, 0.024871},{0.553548, 0.178581, 0.024871},{
      0.554108, 0.177483, 0.024871},{0.554301, 0.176266, 0.024871}}],
    Polygon[{{0.539282, 0.211564, -0.012292},{0.539186, 0.212166, -0.012292},{
      0.538910, 0.212709, -0.012292},{0.538479, 0.213139, -0.012292},{
      0.537936, 0.213416, -0.012292},{0.537335, 0.213511, -0.012292},{
      0.536733, 0.213416, -0.012292},{0.536191, 0.213139, -0.012292},{
      0.535760, 0.212709, -0.012292},{0.535483, 0.212166, -0.012292},{
      0.535388, 0.211564, -0.012292},{0.535483, 0.210963, -0.012292},{
      0.535760, 0.210420, -0.012292},{0.536191, 0.209989, -0.012292},{
      0.536733, 0.209713, -0.012292},{0.537335, 0.209617, -0.012292},{
      0.537936, 0.209713, -0.012292},{0.538479, 0.209989, -0.012292},{
      0.538910, 0.210420, -0.012292},{0.539186, 0.210963, -0.012292}}],
    Polygon[{{0.539186, 0.210963, 0.012292},{0.538910, 0.210420, 0.012292},{
      0.538479, 0.209989, 0.012292},{0.537936, 0.209713, 0.012292},{
      0.537335, 0.209617, 0.012292},{0.536733, 0.209713, 0.012292},{
      0.536191, 0.209989, 0.012292},{0.535760, 0.210420, 0.012292},{
      0.535483, 0.210963, 0.012292},{0.535388, 0.211564, 0.012292},{
      0.535483, 0.212166, 0.012292},{0.535760, 0.212709, 0.012292},{
      0.536191, 0.213139, 0.012292},{0.536733, 0.213416, 0.012292},{
      0.537335, 0.213511, 0.012292},{0.537936, 0.213416, 0.012292},{
      0.538479, 0.213139, 0.012292},{0.538910, 0.212709, 0.012292},{
      0.539186, 0.212166, 0.012292},{0.539282, 0.211564, 0.012292}}],
    Polygon[{{0.584544, 0.164172, -0.009538},{0.584470, 0.164639, -0.009538},{
      0.584255, 0.165060, -0.009538},{0.583921, 0.165394, -0.009538},{
      0.583500, 0.165609, -0.009538},{0.583033, 0.165683, -0.009538},{
      0.582566, 0.165609, -0.009538},{0.582145, 0.165394, -0.009538},{
      0.581811, 0.165060, -0.009538},{0.581596, 0.164639, -0.009538},{
      0.581522, 0.164172, -0.009538},{0.581596, 0.163705, -0.009538},{
      0.581811, 0.163284, -0.009538},{0.582145, 0.162950, -0.009538},{
      0.582566, 0.162735, -0.009538},{0.583033, 0.162661, -0.009538},{
      0.583500, 0.162735, -0.009538},{0.583921, 0.162950, -0.009538},{
      0.584255, 0.163284, -0.009538},{0.584470, 0.163705, -0.009538}}],
    Polygon[{{0.584470, 0.163705, 0.009538},{0.584255, 0.163284, 0.009538},{
      0.583921, 0.162950, 0.009538},{0.583500, 0.162735, 0.009538},{
      0.583033, 0.162661, 0.009538},{0.582566, 0.162735, 0.009538},{
      0.582145, 0.162950, 0.009538},{0.581811, 0.163284, 0.009538},{
      0.581596, 0.163705, 0.009538},{0.581522, 0.164172, 0.009538},{
      0.581596, 0.164639, 0.009538},{0.581811, 0.165060, 0.009538},{
      0.582145, 0.165394, 0.009538},{0.582566, 0.165609, 0.009538},{
      0.583033, 0.165683, 0.009538},{0.583500, 0.165609, 0.009538},{
      0.583921, 0.165394, 0.009538},{0.584255, 0.165060, 0.009538},{
      0.584470, 0.164639, 0.009538},{0.584544, 0.164172, 0.009538}}],
    Polygon[{{0.531229, 0.149198, -0.008668},{0.531162, 0.149623, -0.008668},{
      0.530967, 0.150005, -0.008668},{0.530664, 0.150309, -0.008668},{
      0.530281, 0.150504, -0.008668},{0.529857, 0.150571, -0.008668},{
      0.529432, 0.150504, -0.008668},{0.529050, 0.150309, -0.008668},{
      0.528746, 0.150005, -0.008668},{0.528551, 0.149623, -0.008668},{
      0.528484, 0.149198, -0.008668},{0.528551, 0.148774, -0.008668},{
      0.528746, 0.148391, -0.008668},{0.529050, 0.148088, -0.008668},{
      0.529432, 0.147893, -0.008668},{0.529857, 0.147825, -0.008668},{
      0.530281, 0.147893, -0.008668},{0.530664, 0.148088, -0.008668},{
      0.530967, 0.148391, -0.008668},{0.531162, 0.148774, -0.008668}}],
    Polygon[{{0.531162, 0.148774, 0.008668},{0.530967, 0.148391, 0.008668},{
      0.530664, 0.148088, 0.008668},{0.530281, 0.147893, 0.008668},{
      0.529857, 0.147825, 0.008668},{0.529432, 0.147893, 0.008668},{
      0.529050, 0.148088, 0.008668},{0.528746, 0.148391, 0.008668},{
      0.528551, 0.148774, 0.008668},{0.528484, 0.149198, 0.008668},{
      0.528551, 0.149623, 0.008668},{0.528746, 0.150005, 0.008668},{
      0.529050, 0.150309, 0.008668},{0.529432, 0.150504, 0.008668},{
      0.529857, 0.150571, 0.008668},{0.530281, 0.150504, 0.008668},{
      0.530664, 0.150309, 0.008668},{0.530967, 0.150005, 0.008668},{
      0.531162, 0.149623, 0.008668},{0.531229, 0.149198, 0.008668}}],
    Polygon[{{0.367763, 0.461325, -0.076398},{0.367170, 0.465064, -0.076398},{
      0.365452, 0.468437, -0.076398},{0.362775, 0.471114, -0.076398},{
      0.359402, 0.472833, -0.076398},{0.355662, 0.473425, -0.076398},{
      0.351923, 0.472833, -0.076398},{0.348550, 0.471114, -0.076398},{
      0.345873, 0.468437, -0.076398},{0.344154, 0.465064, -0.076398},{
      0.343562, 0.461325, -0.076398},{0.344154, 0.457586, -0.076398},{
      0.345873, 0.454213, -0.076398},{0.348550, 0.451536, -0.076398},{
      0.351923, 0.449817, -0.076398},{0.355662, 0.449225, -0.076398},{
      0.359402, 0.449817, -0.076398},{0.362775, 0.451536, -0.076398},{
      0.365452, 0.454213, -0.076398},{0.367170, 0.457586, -0.076398}}],
    Polygon[{{0.367170, 0.457586, 0.076398},{0.365452, 0.454213, 0.076398},{
      0.362775, 0.451536, 0.076398},{0.359402, 0.449817, 0.076398},{
      0.355662, 0.449225, 0.076398},{0.351923, 0.449817, 0.076398},{
      0.348550, 0.451536, 0.076398},{0.345873, 0.454213, 0.076398},{
      0.344154, 0.457586, 0.076398},{0.343562, 0.461325, 0.076398},{
      0.344154, 0.465064, 0.076398},{0.345873, 0.468437, 0.076398},{
      0.348550, 0.471114, 0.076398},{0.351923, 0.472833, 0.076398},{
      0.355662, 0.473425, 0.076398},{0.359402, 0.472833, 0.076398},{
      0.362775, 0.471114, 0.076398},{0.365452, 0.468437, 0.076398},{
      0.367170, 0.465064, 0.076398},{0.367763, 0.461325, 0.076398}}],
    Polygon[{{0.387682, 0.577350, -0.040942},{0.387365, 0.579354, -0.040942},{
      0.386444, 0.581162, -0.040942},{0.385009, 0.582596, -0.040942},{
      0.383202, 0.583517, -0.040942},{0.381198, 0.583835, -0.040942},{
      0.379194, 0.583517, -0.040942},{0.377386, 0.582596, -0.040942},{
      0.375952, 0.581162, -0.040942},{0.375031, 0.579354, -0.040942},{
      0.374713, 0.577350, -0.040942},{0.375031, 0.575346, -0.040942},{
      0.375952, 0.573539, -0.040942},{0.377386, 0.572104, -0.040942},{
      0.379194, 0.571183, -0.040942},{0.381198, 0.570866, -0.040942},{
      0.383202, 0.571183, -0.040942},{0.385009, 0.572104, -0.040942},{
      0.386444, 0.573539, -0.040942},{0.387365, 0.575346, -0.040942}}],
    Polygon[{{0.387365, 0.575346, 0.040942},{0.386444, 0.573539, 0.040942},{
      0.385009, 0.572104, 0.040942},{0.383202, 0.571183, 0.040942},{
      0.381198, 0.570866, 0.040942},{0.379194, 0.571183, 0.040942},{
      0.377386, 0.572104, 0.040942},{0.375952, 0.573539, 0.040942},{
      0.375031, 0.575346, 0.040942},{0.374713, 0.577350, 0.040942},{
      0.375031, 0.579354, 0.040942},{0.375952, 0.581162, 0.040942},{
      0.377386, 0.582596, 0.040942},{0.379194, 0.583517, 0.040942},{
      0.381198, 0.583835, 0.040942},{0.383202, 0.583517, 0.040942},{
      0.385009, 0.582596, 0.040942},{0.386444, 0.581162, 0.040942},{
      0.387365, 0.579354, 0.040942},{0.387682, 0.577350, 0.040942}}],
    Polygon[{{0.404354, 0.641809, -0.025466},{0.404157, 0.643055, -0.025466},{
      0.403584, 0.644180, -0.025466},{0.402691, 0.645072, -0.025466},{
      0.401567, 0.645645, -0.025466},{0.400321, 0.645842, -0.025466},{
      0.399074, 0.645645, -0.025466},{0.397950, 0.645072, -0.025466},{
      0.397058, 0.644180, -0.025466},{0.396485, 0.643055, -0.025466},{
      0.396287, 0.641809, -0.025466},{0.396485, 0.640562, -0.025466},{
      0.397058, 0.639438, -0.025466},{0.397950, 0.638546, -0.025466},{
      0.399074, 0.637973, -0.025466},{0.400321, 0.637775, -0.025466},{
      0.401567, 0.637973, -0.025466},{0.402691, 0.638546, -0.025466},{
      0.403584, 0.639438, -0.025466},{0.404157, 0.640562, -0.025466}}],
    Polygon[{{0.404157, 0.640562, 0.025466},{0.403584, 0.639438, 0.025466},{
      0.402691, 0.638546, 0.025466},{0.401567, 0.637973, 0.025466},{
      0.400321, 0.637775, 0.025466},{0.399074, 0.637973, 0.025466},{
      0.397950, 0.638546, 0.025466},{0.397058, 0.639438, 0.025466},{
      0.396485, 0.640562, 0.025466},{0.396287, 0.641809, 0.025466},{
      0.396485, 0.643055, 0.025466},{0.397058, 0.644180, 0.025466},{
      0.397950, 0.645072, 0.025466},{0.399074, 0.645645, 0.025466},{
      0.400321, 0.645842, 0.025466},{0.401567, 0.645645, 0.025466},{
      0.402691, 0.645072, 0.025466},{0.403584, 0.644180, 0.025466},{
      0.404157, 0.643055, 0.025466},{0.404354, 0.641809, 0.025466}}],
    Polygon[{{0.335495, 0.549716, -0.013647},{0.335389, 0.550384, -0.013647},{
      0.335082, 0.550986, -0.013647},{0.334604, 0.551464, -0.013647},{
      0.334001, 0.551771, -0.013647},{0.333333, 0.551877, -0.013647},{
      0.332665, 0.551771, -0.013647},{0.332063, 0.551464, -0.013647},{
      0.331585, 0.550986, -0.013647},{0.331278, 0.550384, -0.013647},{
      0.331172, 0.549716, -0.013647},{0.331278, 0.549048, -0.013647},{
      0.331585, 0.548445, -0.013647},{0.332063, 0.547967, -0.013647},{
      0.332665, 0.547660, -0.013647},{0.333333, 0.547554, -0.013647},{
      0.334001, 0.547660, -0.013647},{0.334604, 0.547967, -0.013647},{
      0.335082, 0.548445, -0.013647},{0.335389, 0.549048, -0.013647}}],
    Polygon[{{0.335389, 0.549048, 0.013647},{0.335082, 0.548445, 0.013647},{
      0.334604, 0.547967, 0.013647},{0.334001, 0.547660, 0.013647},{
      0.333333, 0.547554, 0.013647},{0.332665, 0.547660, 0.013647},{
      0.332063, 0.547967, 0.013647},{0.331585, 0.548445, 0.013647},{
      0.331278, 0.549048, 0.013647},{0.331172, 0.549716, 0.013647},{
      0.331278, 0.550384, 0.013647},{0.331585, 0.550986, 0.013647},{
      0.332063, 0.551464, 0.013647},{0.332665, 0.551771, 0.013647},{
      0.333333, 0.551877, 0.013647},{0.334001, 0.551771, 0.013647},{
      0.334604, 0.551464, 0.013647},{0.335082, 0.550986, 0.013647},{
      0.335389, 0.550384, 0.013647},{0.335495, 0.549716, 0.013647}}],
    Polygon[{{0.413502, 0.532229, -0.012733},{0.413403, 0.532852, -0.012733},{
      0.413117, 0.533415, -0.012733},{0.412671, 0.533861, -0.012733},{
      0.412108, 0.534147, -0.012733},{0.411485, 0.534246, -0.012733},{
      0.410862, 0.534147, -0.012733},{0.410300, 0.533861, -0.012733},{
      0.409854, 0.533415, -0.012733},{0.409567, 0.532852, -0.012733},{
      0.409468, 0.532229, -0.012733},{0.409567, 0.531606, -0.012733},{
      0.409854, 0.531044, -0.012733},{0.410300, 0.530598, -0.012733},{
      0.410862, 0.530311, -0.012733},{0.411485, 0.530213, -0.012733},{
      0.412108, 0.530311, -0.012733},{0.412671, 0.530598, -0.012733},{
      0.413117, 0.531044, -0.012733},{0.413403, 0.531606, -0.012733}}],
    Polygon[{{0.413403, 0.531606, 0.012733},{0.413117, 0.531044, 0.012733},{
      0.412671, 0.530598, 0.012733},{0.412108, 0.530311, 0.012733},{
      0.411485, 0.530213, 0.012733},{0.410862, 0.530311, 0.012733},{
      0.410300, 0.530598, 0.012733},{0.409854, 0.531044, 0.012733},{
      0.409567, 0.531606, 0.012733},{0.409468, 0.532229, 0.012733},{
      0.409567, 0.532852, 0.012733},{0.409854, 0.533415, 0.012733},{
      0.410300, 0.533861, 0.012733},{0.410862, 0.534147, 0.012733},{
      0.411485, 0.534246, 0.012733},{0.412108, 0.534147, 0.012733},{
      0.412671, 0.533861, 0.012733},{0.413117, 0.533415, 0.012733},{
      0.413403, 0.532852, 0.012733},{0.413502, 0.532229, 0.012733}}],
    Polygon[{{0.270959, 0.403521, -0.028615},{0.270737, 0.404922, -0.028615},{
      0.270093, 0.406185, -0.028615},{0.269090, 0.407188, -0.028615},{
      0.267827, 0.407831, -0.028615},{0.266426, 0.408053, -0.028615},{
      0.265026, 0.407831, -0.028615},{0.263763, 0.407188, -0.028615},{
      0.262760, 0.406185, -0.028615},{0.262116, 0.404922, -0.028615},{
      0.261894, 0.403521, -0.028615},{0.262116, 0.402121, -0.028615},{
      0.262760, 0.400857, -0.028615},{0.263763, 0.399855, -0.028615},{
      0.265026, 0.399211, -0.028615},{0.266426, 0.398989, -0.028615},{
      0.267827, 0.399211, -0.028615},{0.269090, 0.399855, -0.028615},{
      0.270093, 0.400857, -0.028615},{0.270737, 0.402121, -0.028615}}],
    Polygon[{{0.270737, 0.402121, 0.028615},{0.270093, 0.400857, 0.028615},{
      0.269090, 0.399855, 0.028615},{0.267827, 0.399211, 0.028615},{
      0.266426, 0.398989, 0.028615},{0.265026, 0.399211, 0.028615},{
      0.263763, 0.399855, 0.028615},{0.262760, 0.400857, 0.028615},{
      0.262116, 0.402121, 0.028615},{0.261894, 0.403521, 0.028615},{
      0.262116, 0.404922, 0.028615},{0.262760, 0.406185, 0.028615},{
      0.263763, 0.407188, 0.028615},{0.265026, 0.407831, 0.028615},{
      0.266426, 0.408053, 0.028615},{0.267827, 0.407831, 0.028615},{
      0.269090, 0.407188, 0.028615},{0.270093, 0.406185, 0.028615},{
      0.270737, 0.404922, 0.028615},{0.270959, 0.403521, 0.028615}}],
    Polygon[{{0.235839, 0.374335, -0.014853},{0.235724, 0.375062, -0.014853},{
      0.235390, 0.375718, -0.014853},{0.234870, 0.376238, -0.014853},{
      0.234214, 0.376572, -0.014853},{0.233487, 0.376687, -0.014853},{
      0.232760, 0.376572, -0.014853},{0.232104, 0.376238, -0.014853},{
      0.231584, 0.375718, -0.014853},{0.231250, 0.375062, -0.014853},{
      0.231134, 0.374335, -0.014853},{0.231250, 0.373608, -0.014853},{
      0.231584, 0.372952, -0.014853},{0.232104, 0.372432, -0.014853},{
      0.232760, 0.372098, -0.014853},{0.233487, 0.371982, -0.014853},{
      0.234214, 0.372098, -0.014853},{0.234870, 0.372432, -0.014853},{
      0.235390, 0.372952, -0.014853},{0.235724, 0.373608, -0.014853}}],
    Polygon[{{0.235724, 0.373608, 0.014853},{0.235390, 0.372952, 0.014853},{
      0.234870, 0.372432, 0.014853},{0.234214, 0.372098, 0.014853},{
      0.233487, 0.371982, 0.014853},{0.232760, 0.372098, 0.014853},{
      0.232104, 0.372432, 0.014853},{0.231584, 0.372952, 0.014853},{
      0.231250, 0.373608, 0.014853},{0.231134, 0.374335, 0.014853},{
      0.231250, 0.375062, 0.014853},{0.231584, 0.375718, 0.014853},{
      0.232104, 0.376238, 0.014853},{0.232760, 0.376572, 0.014853},{
      0.233487, 0.376687, 0.014853},{0.234214, 0.376572, 0.014853},{
      0.234870, 0.376238, 0.014853},{0.235390, 0.375718, 0.014853},{
      0.235724, 0.375062, 0.014853},{0.235839, 0.374335, 0.014853}}],
    Polygon[{{0.270708, 0.443561, -0.011012},{0.270623, 0.444100, -0.011012},{
      0.270375, 0.444587, -0.011012},{0.269989, 0.444972, -0.011012},{
      0.269503, 0.445220, -0.011012},{0.268964, 0.445306, -0.011012},{
      0.268425, 0.445220, -0.011012},{0.267939, 0.444972, -0.011012},{
      0.267553, 0.444587, -0.011012},{0.267305, 0.444100, -0.011012},{
      0.267220, 0.443561, -0.011012},{0.267305, 0.443022, -0.011012},{
      0.267553, 0.442536, -0.011012},{0.267939, 0.442150, -0.011012},{
      0.268425, 0.441903, -0.011012},{0.268964, 0.441817, -0.011012},{
      0.269503, 0.441903, -0.011012},{0.269989, 0.442150, -0.011012},{
      0.270375, 0.442536, -0.011012},{0.270623, 0.443022, -0.011012}}],
    Polygon[{{0.270623, 0.443022, 0.011012},{0.270375, 0.442536, 0.011012},{
      0.269989, 0.442150, 0.011012},{0.269503, 0.441903, 0.011012},{
      0.268964, 0.441817, 0.011012},{0.268425, 0.441903, 0.011012},{
      0.267939, 0.442150, 0.011012},{0.267553, 0.442536, 0.011012},{
      0.267305, 0.443022, 0.011012},{0.267220, 0.443561, 0.011012},{
      0.267305, 0.444100, 0.011012},{0.267553, 0.444587, 0.011012},{
      0.267939, 0.444972, 0.011012},{0.268425, 0.445220, 0.011012},{
      0.268964, 0.445306, 0.011012},{0.269503, 0.445220, 0.011012},{
      0.269989, 0.444972, 0.011012},{0.270375, 0.444587, 0.011012},{
      0.270623, 0.444100, 0.011012},{0.270708, 0.443561, 0.011012}}],
    Polygon[{{0.304658, 0.392133, -0.009381},{0.304585, 0.392593, -0.009381},{
      0.304374, 0.393007, -0.009381},{0.304046, 0.393336, -0.009381},{
      0.303631, 0.393547, -0.009381},{0.303172, 0.393619, -0.009381},{
      0.302713, 0.393547, -0.009381},{0.302299, 0.393336, -0.009381},{
      0.301970, 0.393007, -0.009381},{0.301759, 0.392593, -0.009381},{
      0.301686, 0.392133, -0.009381},{0.301759, 0.391674, -0.009381},{
      0.301970, 0.391260, -0.009381},{0.302299, 0.390931, -0.009381},{
      0.302713, 0.390720, -0.009381},{0.303172, 0.390648, -0.009381},{
      0.303631, 0.390720, -0.009381},{0.304046, 0.390931, -0.009381},{
      0.304374, 0.391260, -0.009381},{0.304585, 0.391674, -0.009381}}],
    Polygon[{{0.304585, 0.391674, 0.009381},{0.304374, 0.391260, 0.009381},{
      0.304046, 0.390931, 0.009381},{0.303631, 0.390720, 0.009381},{
      0.303172, 0.390648, 0.009381},{0.302713, 0.390720, 0.009381},{
      0.302299, 0.390931, 0.009381},{0.301970, 0.391260, 0.009381},{
      0.301759, 0.391674, 0.009381},{0.301686, 0.392133, 0.009381},{
      0.301759, 0.392593, 0.009381},{0.301970, 0.393007, 0.009381},{
      0.302299, 0.393336, 0.009381},{0.302713, 0.393547, 0.009381},{
      0.303172, 0.393619, 0.009381},{0.303631, 0.393547, 0.009381},{
      0.304046, 0.393336, 0.009381},{0.304374, 0.393007, 0.009381},{
      0.304585, 0.392593, 0.009381},{0.304658, 0.392133, 0.009381}}],
    Polygon[{{0.431770, 0.388494, -0.024871},{0.431578, 0.389712, -0.024871},{
      0.431018, 0.390810, -0.024871},{0.430147, 0.391681, -0.024871},{
      0.429048, 0.392241, -0.024871},{0.427831, 0.392433, -0.024871},{
      0.426614, 0.392241, -0.024871},{0.425516, 0.391681, -0.024871},{
      0.424644, 0.390810, -0.024871},{0.424085, 0.389712, -0.024871},{
      0.423892, 0.388494, -0.024871},{0.424085, 0.387277, -0.024871},{
      0.424644, 0.386179, -0.024871},{0.425516, 0.385308, -0.024871},{
      0.426614, 0.384748, -0.024871},{0.427831, 0.384555, -0.024871},{
      0.429048, 0.384748, -0.024871},{0.430147, 0.385308, -0.024871},{
      0.431018, 0.386179, -0.024871},{0.431578, 0.387277, -0.024871}}],
    Polygon[{{0.431578, 0.387277, 0.024871},{0.431018, 0.386179, 0.024871},{
      0.430147, 0.385308, 0.024871},{0.429048, 0.384748, 0.024871},{
      0.427831, 0.384555, 0.024871},{0.426614, 0.384748, 0.024871},{
      0.425516, 0.385308, 0.024871},{0.424644, 0.386179, 0.024871},{
      0.424085, 0.387277, 0.024871},{0.423892, 0.388494, 0.024871},{
      0.424085, 0.389712, 0.024871},{0.424644, 0.390810, 0.024871},{
      0.425516, 0.391681, 0.024871},{0.426614, 0.392241, 0.024871},{
      0.427831, 0.392433, 0.024871},{0.429048, 0.392241, 0.024871},{
      0.430147, 0.391681, 0.024871},{0.431018, 0.390810, 0.024871},{
      0.431578, 0.389712, 0.024871},{0.431770, 0.388494, 0.024871}}],
    Polygon[{{0.453834, 0.359563, -0.012292},{0.453739, 0.360165, -0.012292},{
      0.453462, 0.360708, -0.012292},{0.453032, 0.361139, -0.012292},{
      0.452489, 0.361415, -0.012292},{0.451887, 0.361510, -0.012292},{
      0.451286, 0.361415, -0.012292},{0.450743, 0.361139, -0.012292},{
      0.450312, 0.360708, -0.012292},{0.450036, 0.360165, -0.012292},{
      0.449941, 0.359563, -0.012292},{0.450036, 0.358962, -0.012292},{
      0.450312, 0.358419, -0.012292},{0.450743, 0.357989, -0.012292},{
      0.451286, 0.357712, -0.012292},{0.451887, 0.357617, -0.012292},{
      0.452489, 0.357712, -0.012292},{0.453032, 0.357989, -0.012292},{
      0.453462, 0.358419, -0.012292},{0.453739, 0.358962, -0.012292}}],
    Polygon[{{0.453739, 0.358962, 0.012292},{0.453462, 0.358419, 0.012292},{
      0.453032, 0.357989, 0.012292},{0.452489, 0.357712, 0.012292},{
      0.451887, 0.357617, 0.012292},{0.451286, 0.357712, 0.012292},{
      0.450743, 0.357989, 0.012292},{0.450312, 0.358419, 0.012292},{
      0.450036, 0.358962, 0.012292},{0.449941, 0.359563, 0.012292},{
      0.450036, 0.360165, 0.012292},{0.450312, 0.360708, 0.012292},{
      0.450743, 0.361139, 0.012292},{0.451286, 0.361415, 0.012292},{
      0.451887, 0.361510, 0.012292},{0.452489, 0.361415, 0.012292},{
      0.453032, 0.361139, 0.012292},{0.453462, 0.360708, 0.012292},{
      0.453739, 0.360165, 0.012292},{0.453834, 0.359563, 0.012292}}],
    Polygon[{{0.435204, 0.422836, -0.009538},{0.435130, 0.423302, -0.009538},{
      0.434916, 0.423723, -0.009538},{0.434582, 0.424058, -0.009538},{
      0.434160, 0.424272, -0.009538},{0.433694, 0.424346, -0.009538},{
      0.433227, 0.424272, -0.009538},{0.432806, 0.424058, -0.009538},{
      0.432471, 0.423723, -0.009538},{0.432257, 0.423302, -0.009538},{
      0.432183, 0.422836, -0.009538},{0.432257, 0.422369, -0.009538},{
      0.432471, 0.421948, -0.009538},{0.432806, 0.421613, -0.009538},{
      0.433227, 0.421399, -0.009538},{0.433694, 0.421325, -0.009538},{
      0.434160, 0.421399, -0.009538},{0.434582, 0.421613, -0.009538},{
      0.434916, 0.421948, -0.009538},{0.435130, 0.422369, -0.009538}}],
    Polygon[{{0.435130, 0.422369, 0.009538},{0.434916, 0.421948, 0.009538},{
      0.434582, 0.421613, 0.009538},{0.434160, 0.421399, 0.009538},{
      0.433694, 0.421325, 0.009538},{0.433227, 0.421399, 0.009538},{
      0.432806, 0.421613, 0.009538},{0.432471, 0.421948, 0.009538},{
      0.432257, 0.422369, 0.009538},{0.432183, 0.422836, 0.009538},{
      0.432257, 0.423302, 0.009538},{0.432471, 0.423723, 0.009538},{
      0.432806, 0.424058, 0.009538},{0.433227, 0.424272, 0.009538},{
      0.433694, 0.424346, 0.009538},{0.434160, 0.424272, 0.009538},{
      0.434582, 0.424058, 0.009538},{0.434916, 0.423723, 0.009538},{
      0.435130, 0.423302, 0.009538},{0.435204, 0.422836, 0.009538}}],
    Polygon[{{0.395511, 0.384270, -0.008668},{0.395444, 0.384694, -0.008668},{
      0.395249, 0.385077, -0.008668},{0.394945, 0.385381, -0.008668},{
      0.394562, 0.385576, -0.008668},{0.394138, 0.385643, -0.008668},{
      0.393714, 0.385576, -0.008668},{0.393331, 0.385381, -0.008668},{
      0.393027, 0.385077, -0.008668},{0.392832, 0.384694, -0.008668},{
      0.392765, 0.384270, -0.008668},{0.392832, 0.383846, -0.008668},{
      0.393027, 0.383463, -0.008668},{0.393331, 0.383159, -0.008668},{
      0.393714, 0.382964, -0.008668},{0.394138, 0.382897, -0.008668},{
      0.394562, 0.382964, -0.008668},{0.394945, 0.383159, -0.008668},{
      0.395249, 0.383463, -0.008668},{0.395444, 0.383846, -0.008668}}],
    Polygon[{{0.395444, 0.383846, 0.008668},{0.395249, 0.383463, 0.008668},{
      0.394945, 0.383159, 0.008668},{0.394562, 0.382964, 0.008668},{
      0.394138, 0.382897, 0.008668},{0.393714, 0.382964, 0.008668},{
      0.393331, 0.383159, 0.008668},{0.393027, 0.383463, 0.008668},{
      0.392832, 0.383846, 0.008668},{0.392765, 0.384270, 0.008668},{
      0.392832, 0.384694, 0.008668},{0.393027, 0.385077, 0.008668},{
      0.393331, 0.385381, 0.008668},{0.393714, 0.385576, 0.008668},{
      0.394138, 0.385643, 0.008668},{0.394562, 0.385576, 0.008668},{
      0.394945, 0.385381, 0.008668},{0.395249, 0.385077, 0.008668},{
      0.395444, 0.384694, 0.008668},{0.395511, 0.384270, 0.008668}}],
    Polygon[{{1.696772, 0.192450, -0.190081},{1.695299, 0.201753, -0.190081},{
      1.691023, 0.210146, -0.190081},{1.684362, 0.216806, -0.190081},{
      1.675970, 0.221082, -0.190081},{1.666667, 0.222556, -0.190081},{
      1.657363, 0.221082, -0.190081},{1.648971, 0.216806, -0.190081},{
      1.642311, 0.210146, -0.190081},{1.638034, 0.201753, -0.190081},{
      1.636561, 0.192450, -0.190081},{1.638034, 0.183147, -0.190081},{
      1.642311, 0.174754, -0.190081},{1.648971, 0.168094, -0.190081},{
      1.657363, 0.163818, -0.190081},{1.666667, 0.162344, -0.190081},{
      1.675970, 0.163818, -0.190081},{1.684362, 0.168094, -0.190081},{
      1.691023, 0.174754, -0.190081},{1.695299, 0.183147, -0.190081}}],
    Polygon[{{1.695299, 0.183147, 0.190081},{1.691023, 0.174754, 0.190081},{
      1.684362, 0.168094, 0.190081},{1.675970, 0.163818, 0.190081},{
      1.666667, 0.162344, 0.190081},{1.657363, 0.163818, 0.190081},{
      1.648971, 0.168094, 0.190081},{1.642311, 0.174754, 0.190081},{
      1.638034, 0.183147, 0.190081},{1.636561, 0.192450, 0.190081},{
      1.638034, 0.201753, 0.190081},{1.642311, 0.210146, 0.190081},{
      1.648971, 0.216806, 0.190081},{1.657363, 0.221082, 0.190081},{
      1.666667, 0.222556, 0.190081},{1.675970, 0.221082, 0.190081},{
      1.684362, 0.216806, 0.190081},{1.691023, 0.210146, 0.190081},{
      1.695299, 0.201753, 0.190081},{1.696772, 0.192450, 0.190081}}],
    Polygon[{{1.898924, 0.064150, -0.063360},{1.898433, 0.067251, -0.063360},{
      1.897008, 0.070049, -0.063360},{1.894787, 0.072269, -0.063360},{
      1.891990, 0.073694, -0.063360},{1.888889, 0.074185, -0.063360},{
      1.885788, 0.073694, -0.063360},{1.882990, 0.072269, -0.063360},{
      1.880770, 0.070049, -0.063360},{1.879345, 0.067251, -0.063360},{
      1.878854, 0.064150, -0.063360},{1.879345, 0.061049, -0.063360},{
      1.880770, 0.058251, -0.063360},{1.882990, 0.056031, -0.063360},{
      1.885788, 0.054606, -0.063360},{1.888889, 0.054115, -0.063360},{
      1.891990, 0.054606, -0.063360},{1.894787, 0.056031, -0.063360},{
      1.897008, 0.058251, -0.063360},{1.898433, 0.061049, -0.063360}}],
    Polygon[{{1.898433, 0.061049, 0.063360},{1.897008, 0.058251, 0.063360},{
      1.894787, 0.056031, 0.063360},{1.891990, 0.054606, 0.063360},{
      1.888889, 0.054115, 0.063360},{1.885788, 0.054606, 0.063360},{
      1.882990, 0.056031, 0.063360},{1.880770, 0.058251, 0.063360},{
      1.879345, 0.061049, 0.063360},{1.878854, 0.064150, 0.063360},{
      1.879345, 0.067251, 0.063360},{1.880770, 0.070049, 0.063360},{
      1.882990, 0.072269, 0.063360},{1.885788, 0.073694, 0.063360},{
      1.888889, 0.074185, 0.063360},{1.891990, 0.073694, 0.063360},{
      1.894787, 0.072269, 0.063360},{1.897008, 0.070049, 0.063360},{
      1.898433, 0.067251, 0.063360},{1.898924, 0.064150, 0.063360}}],
    Polygon[{{1.966308, 0.021383, -0.021120},{1.966144, 0.022417, -0.021120},{
      1.965669, 0.023350, -0.021120},{1.964929, 0.024090, -0.021120},{
      1.963997, 0.024565, -0.021120},{1.962963, 0.024728, -0.021120},{
      1.961929, 0.024565, -0.021120},{1.960997, 0.024090, -0.021120},{
      1.960257, 0.023350, -0.021120},{1.959782, 0.022417, -0.021120},{
      1.959618, 0.021383, -0.021120},{1.959782, 0.020350, -0.021120},{
      1.960257, 0.019417, -0.021120},{1.960997, 0.018677, -0.021120},{
      1.961929, 0.018202, -0.021120},{1.962963, 0.018038, -0.021120},{
      1.963997, 0.018202, -0.021120},{1.964929, 0.018677, -0.021120},{
      1.965669, 0.019417, -0.021120},{1.966144, 0.020350, -0.021120}}],
    Polygon[{{1.966144, 0.020350, 0.021120},{1.965669, 0.019417, 0.021120},{
      1.964929, 0.018677, 0.021120},{1.963997, 0.018202, 0.021120},{
      1.962963, 0.018038, 0.021120},{1.961929, 0.018202, 0.021120},{
      1.960997, 0.018677, 0.021120},{1.960257, 0.019417, 0.021120},{
      1.959782, 0.020350, 0.021120},{1.959618, 0.021383, 0.021120},{
      1.959782, 0.022417, 0.021120},{1.960257, 0.023350, 0.021120},{
      1.960997, 0.024090, 0.021120},{1.961929, 0.024565, 0.021120},{
      1.962963, 0.024728, 0.021120},{1.963997, 0.024565, 0.021120},{
      1.964929, 0.024090, 0.021120},{1.965669, 0.023350, 0.021120},{
      1.966144, 0.022417, 0.021120},{1.966308, 0.021383, 0.021120}}],
    Polygon[{{1.988769, 0.007128, -0.007040},{1.988715, 0.007472, -0.007040},{
      1.988556, 0.007783, -0.007040},{1.988310, 0.008030, -0.007040},{
      1.987999, 0.008188, -0.007040},{1.987654, 0.008243, -0.007040},{
      1.987310, 0.008188, -0.007040},{1.986999, 0.008030, -0.007040},{
      1.986752, 0.007783, -0.007040},{1.986594, 0.007472, -0.007040},{
      1.986539, 0.007128, -0.007040},{1.986594, 0.006783, -0.007040},{
      1.986752, 0.006472, -0.007040},{1.986999, 0.006226, -0.007040},{
      1.987310, 0.006067, -0.007040},{1.987654, 0.006013, -0.007040},{
      1.987999, 0.006067, -0.007040},{1.988310, 0.006226, -0.007040},{
      1.988556, 0.006472, -0.007040},{1.988715, 0.006783, -0.007040}}],
    Polygon[{{1.988715, 0.006783, 0.007040},{1.988556, 0.006472, 0.007040},{
      1.988310, 0.006226, 0.007040},{1.987999, 0.006067, 0.007040},{
      1.987654, 0.006013, 0.007040},{1.987310, 0.006067, 0.007040},{
      1.986999, 0.006226, 0.007040},{1.986752, 0.006472, 0.007040},{
      1.986594, 0.006783, 0.007040},{1.986539, 0.007128, 0.007040},{
      1.986594, 0.007472, 0.007040},{1.986752, 0.007783, 0.007040},{
      1.986999, 0.008030, 0.007040},{1.987310, 0.008188, 0.007040},{
      1.987654, 0.008243, 0.007040},{1.987999, 0.008188, 0.007040},{
      1.988310, 0.008030, 0.007040},{1.988556, 0.007783, 0.007040},{
      1.988715, 0.007472, 0.007040},{1.988769, 0.007128, 0.007040}}],
    Polygon[{{1.937194, 0.008594, -0.008489},{1.937129, 0.009010, -0.008489},{
      1.936938, 0.009385, -0.008489},{1.936640, 0.009682, -0.008489},{
      1.936265, 0.009873, -0.008489},{1.935850, 0.009939, -0.008489},{
      1.935434, 0.009873, -0.008489},{1.935060, 0.009682, -0.008489},{
      1.934762, 0.009385, -0.008489},{1.934571, 0.009010, -0.008489},{
      1.934505, 0.008594, -0.008489},{1.934571, 0.008179, -0.008489},{
      1.934762, 0.007804, -0.008489},{1.935060, 0.007507, -0.008489},{
      1.935434, 0.007316, -0.008489},{1.935850, 0.007250, -0.008489},{
      1.936265, 0.007316, -0.008489},{1.936640, 0.007507, -0.008489},{
      1.936938, 0.007804, -0.008489},{1.937129, 0.008179, -0.008489}}],
    Polygon[{{1.937129, 0.008179, 0.008489},{1.936938, 0.007804, 0.008489},{
      1.936640, 0.007507, 0.008489},{1.936265, 0.007316, 0.008489},{
      1.935850, 0.007250, 0.008489},{1.935434, 0.007316, 0.008489},{
      1.935060, 0.007507, 0.008489},{1.934762, 0.007804, 0.008489},{
      1.934571, 0.008179, 0.008489},{1.934505, 0.008594, 0.008489},{
      1.934571, 0.009010, 0.008489},{1.934762, 0.009385, 0.008489},{
      1.935060, 0.009682, 0.008489},{1.935434, 0.009873, 0.008489},{
      1.935850, 0.009939, 0.008489},{1.936265, 0.009873, 0.008489},{
      1.936640, 0.009682, 0.008489},{1.936938, 0.009385, 0.008489},{
      1.937129, 0.009010, 0.008489},{1.937194, 0.008594, 0.008489}}],
    Polygon[{{1.961826, 0.051258, -0.008489},{1.961761, 0.051674, -0.008489},{
      1.961570, 0.052049, -0.008489},{1.961272, 0.052346, -0.008489},{
      1.960897, 0.052537, -0.008489},{1.960482, 0.052603, -0.008489},{
      1.960066, 0.052537, -0.008489},{1.959692, 0.052346, -0.008489},{
      1.959394, 0.052049, -0.008489},{1.959203, 0.051674, -0.008489},{
      1.959137, 0.051258, -0.008489},{1.959203, 0.050843, -0.008489},{
      1.959394, 0.050468, -0.008489},{1.959692, 0.050171, -0.008489},{
      1.960066, 0.049980, -0.008489},{1.960482, 0.049914, -0.008489},{
      1.960897, 0.049980, -0.008489},{1.961272, 0.050171, -0.008489},{
      1.961570, 0.050468, -0.008489},{1.961761, 0.050843, -0.008489}}],
    Polygon[{{1.961761, 0.050843, 0.008489},{1.961570, 0.050468, 0.008489},{
      1.961272, 0.050171, 0.008489},{1.960897, 0.049980, 0.008489},{
      1.960482, 0.049914, 0.008489},{1.960066, 0.049980, 0.008489},{
      1.959692, 0.050171, 0.008489},{1.959394, 0.050468, 0.008489},{
      1.959203, 0.050843, 0.008489},{1.959137, 0.051258, 0.008489},{
      1.959203, 0.051674, 0.008489},{1.959394, 0.052049, 0.008489},{
      1.959692, 0.052346, 0.008489},{1.960066, 0.052537, 0.008489},{
      1.960482, 0.052603, 0.008489},{1.960897, 0.052537, 0.008489},{
      1.961272, 0.052346, 0.008489},{1.961570, 0.052049, 0.008489},{
      1.961761, 0.051674, 0.008489},{1.961826, 0.051258, 0.008489}}],
    Polygon[{{1.811583, 0.025783, -0.025466},{1.811386, 0.027030, -0.025466},{
      1.810813, 0.028154, -0.025466},{1.809921, 0.029047, -0.025466},{
      1.808796, 0.029619, -0.025466},{1.807550, 0.029817, -0.025466},{
      1.806304, 0.029619, -0.025466},{1.805179, 0.029047, -0.025466},{
      1.804287, 0.028154, -0.025466},{1.803714, 0.027030, -0.025466},{
      1.803517, 0.025783, -0.025466},{1.803714, 0.024537, -0.025466},{
      1.804287, 0.023413, -0.025466},{1.805179, 0.022520, -0.025466},{
      1.806304, 0.021947, -0.025466},{1.807550, 0.021750, -0.025466},{
      1.808796, 0.021947, -0.025466},{1.809921, 0.022520, -0.025466},{
      1.810813, 0.023413, -0.025466},{1.811386, 0.024537, -0.025466}}],
    Polygon[{{1.811386, 0.024537, 0.025466},{1.810813, 0.023413, 0.025466},{
      1.809921, 0.022520, 0.025466},{1.808796, 0.021947, 0.025466},{
      1.807550, 0.021750, 0.025466},{1.806304, 0.021947, 0.025466},{
      1.805179, 0.022520, 0.025466},{1.804287, 0.023413, 0.025466},{
      1.803714, 0.024537, 0.025466},{1.803517, 0.025783, 0.025466},{
      1.803714, 0.027030, 0.025466},{1.804287, 0.028154, 0.025466},{
      1.805179, 0.029047, 0.025466},{1.806304, 0.029619, 0.025466},{
      1.807550, 0.029817, 0.025466},{1.808796, 0.029619, 0.025466},{
      1.809921, 0.029047, 0.025466},{1.810813, 0.028154, 0.025466},{
      1.811386, 0.027030, 0.025466},{1.811583, 0.025783, 0.025466}}],
    Polygon[{{1.771962, 0.013817, -0.013647},{1.771856, 0.014485, -0.013647},{
      1.771549, 0.015088, -0.013647},{1.771071, 0.015566, -0.013647},{
      1.770468, 0.015873, -0.013647},{1.769800, 0.015979, -0.013647},{
      1.769132, 0.015873, -0.013647},{1.768530, 0.015566, -0.013647},{
      1.768052, 0.015088, -0.013647},{1.767745, 0.014485, -0.013647},{
      1.767639, 0.013817, -0.013647},{1.767745, 0.013149, -0.013647},{
      1.768052, 0.012547, -0.013647},{1.768530, 0.012069, -0.013647},{
      1.769132, 0.011762, -0.013647},{1.769800, 0.011656, -0.013647},{
      1.770468, 0.011762, -0.013647},{1.771071, 0.012069, -0.013647},{
      1.771549, 0.012547, -0.013647},{1.771856, 0.013149, -0.013647}}],
    Polygon[{{1.771856, 0.013149, 0.013647},{1.771549, 0.012547, 0.013647},{
      1.771071, 0.012069, 0.013647},{1.770468, 0.011762, 0.013647},{
      1.769800, 0.011656, 0.013647},{1.769132, 0.011762, 0.013647},{
      1.768530, 0.012069, 0.013647},{1.768052, 0.012547, 0.013647},{
      1.767745, 0.013149, 0.013647},{1.767639, 0.013817, 0.013647},{
      1.767745, 0.014485, 0.013647},{1.768052, 0.015088, 0.013647},{
      1.768530, 0.015566, 0.013647},{1.769132, 0.015873, 0.013647},{
      1.769800, 0.015979, 0.013647},{1.770468, 0.015873, 0.013647},{
      1.771071, 0.015566, 0.013647},{1.771549, 0.015088, 0.013647},{
      1.771856, 0.014485, 0.013647},{1.771962, 0.013817, 0.013647}}],
    Polygon[{{1.840620, 0.009657, -0.009538},{1.840546, 0.010124, -0.009538},{
      1.840331, 0.010545, -0.009538},{1.839997, 0.010879, -0.009538},{
      1.839576, 0.011094, -0.009538},{1.839109, 0.011168, -0.009538},{
      1.838642, 0.011094, -0.009538},{1.838221, 0.010879, -0.009538},{
      1.837887, 0.010545, -0.009538},{1.837672, 0.010124, -0.009538},{
      1.837598, 0.009657, -0.009538},{1.837672, 0.009190, -0.009538},{
      1.837887, 0.008769, -0.009538},{1.838221, 0.008435, -0.009538},{
      1.838642, 0.008220, -0.009538},{1.839109, 0.008146, -0.009538},{
      1.839576, 0.008220, -0.009538},{1.839997, 0.008435, -0.009538},{
      1.840331, 0.008769, -0.009538},{1.840546, 0.009190, -0.009538}}],
    Polygon[{{1.840546, 0.009190, 0.009538},{1.840331, 0.008769, 0.009538},{
      1.839997, 0.008435, 0.009538},{1.839576, 0.008220, 0.009538},{
      1.839109, 0.008146, 0.009538},{1.838642, 0.008220, 0.009538},{
      1.838221, 0.008435, 0.009538},{1.837887, 0.008769, 0.009538},{
      1.837672, 0.009190, 0.009538},{1.837598, 0.009657, 0.009538},{
      1.837672, 0.010124, 0.009538},{1.837887, 0.010545, 0.009538},{
      1.838221, 0.010879, 0.009538},{1.838642, 0.011094, 0.009538},{
      1.839109, 0.011168, 0.009538},{1.839576, 0.011094, 0.009538},{
      1.839997, 0.010879, 0.009538},{1.840331, 0.010545, 0.009538},{
      1.840546, 0.010124, 0.009538},{1.840620, 0.009657, 0.009538}}],
    Polygon[{{1.817859, 0.058755, -0.008290},{1.817795, 0.059161, -0.008290},{
      1.817608, 0.059527, -0.008290},{1.817318, 0.059817, -0.008290},{
      1.816952, 0.060004, -0.008290},{1.816546, 0.060068, -0.008290},{
      1.816140, 0.060004, -0.008290},{1.815774, 0.059817, -0.008290},{
      1.815484, 0.059527, -0.008290},{1.815297, 0.059161, -0.008290},{
      1.815233, 0.058755, -0.008290},{1.815297, 0.058349, -0.008290},{
      1.815484, 0.057983, -0.008290},{1.815774, 0.057693, -0.008290},{
      1.816140, 0.057506, -0.008290},{1.816546, 0.057442, -0.008290},{
      1.816952, 0.057506, -0.008290},{1.817318, 0.057693, -0.008290},{
      1.817608, 0.057983, -0.008290},{1.817795, 0.058349, -0.008290}}],
    Polygon[{{1.817795, 0.058349, 0.008290},{1.817608, 0.057983, 0.008290},{
      1.817318, 0.057693, 0.008290},{1.816952, 0.057506, 0.008290},{
      1.816546, 0.057442, 0.008290},{1.816140, 0.057506, 0.008290},{
      1.815774, 0.057693, 0.008290},{1.815484, 0.057983, 0.008290},{
      1.815297, 0.058349, 0.008290},{1.815233, 0.058755, 0.008290},{
      1.815297, 0.059161, 0.008290},{1.815484, 0.059527, 0.008290},{
      1.815774, 0.059817, 0.008290},{1.816140, 0.060004, 0.008290},{
      1.816546, 0.060068, 0.008290},{1.816952, 0.060004, 0.008290},{
      1.817318, 0.059817, 0.008290},{1.817608, 0.059527, 0.008290},{
      1.817795, 0.059161, 0.008290},{1.817859, 0.058755, 0.008290}}],
    Polygon[{{1.885479, 0.153775, -0.025466},{1.885282, 0.155021, -0.025466},{
      1.884709, 0.156146, -0.025466},{1.883817, 0.157038, -0.025466},{
      1.882692, 0.157611, -0.025466},{1.881446, 0.157808, -0.025466},{
      1.880199, 0.157611, -0.025466},{1.879075, 0.157038, -0.025466},{
      1.878183, 0.156146, -0.025466},{1.877610, 0.155021, -0.025466},{
      1.877412, 0.153775, -0.025466},{1.877610, 0.152529, -0.025466},{
      1.878183, 0.151404, -0.025466},{1.879075, 0.150512, -0.025466},{
      1.880199, 0.149939, -0.025466},{1.881446, 0.149742, -0.025466},{
      1.882692, 0.149939, -0.025466},{1.883817, 0.150512, -0.025466},{
      1.884709, 0.151404, -0.025466},{1.885282, 0.152529, -0.025466}}],
    Polygon[{{1.885282, 0.152529, 0.025466},{1.884709, 0.151404, 0.025466},{
      1.883817, 0.150512, 0.025466},{1.882692, 0.149939, 0.025466},{
      1.881446, 0.149742, 0.025466},{1.880199, 0.149939, 0.025466},{
      1.879075, 0.150512, 0.025466},{1.878183, 0.151404, 0.025466},{
      1.877610, 0.152529, 0.025466},{1.877412, 0.153775, 0.025466},{
      1.877610, 0.155021, 0.025466},{1.878183, 0.156146, 0.025466},{
      1.879075, 0.157038, 0.025466},{1.880199, 0.157611, 0.025466},{
      1.881446, 0.157808, 0.025466},{1.882692, 0.157611, 0.025466},{
      1.883817, 0.157038, 0.025466},{1.884709, 0.156146, 0.025466},{
      1.885282, 0.155021, 0.025466},{1.885479, 0.153775, 0.025466}}],
    Polygon[{{1.875096, 0.192450, -0.013647},{1.874990, 0.193118, -0.013647},{
      1.874683, 0.193721, -0.013647},{1.874205, 0.194199, -0.013647},{
      1.873602, 0.194506, -0.013647},{1.872934, 0.194612, -0.013647},{
      1.872266, 0.194506, -0.013647},{1.871664, 0.194199, -0.013647},{
      1.871185, 0.193721, -0.013647},{1.870878, 0.193118, -0.013647},{
      1.870773, 0.192450, -0.013647},{1.870878, 0.191782, -0.013647},{
      1.871185, 0.191180, -0.013647},{1.871664, 0.190701, -0.013647},{
      1.872266, 0.190394, -0.013647},{1.872934, 0.190289, -0.013647},{
      1.873602, 0.190394, -0.013647},{1.874205, 0.190701, -0.013647},{
      1.874683, 0.191180, -0.013647},{1.874990, 0.191782, -0.013647}}],
    Polygon[{{1.874990, 0.191782, 0.013647},{1.874683, 0.191180, 0.013647},{
      1.874205, 0.190701, 0.013647},{1.873602, 0.190394, 0.013647},{
      1.872934, 0.190289, 0.013647},{1.872266, 0.190394, 0.013647},{
      1.871664, 0.190701, 0.013647},{1.871185, 0.191180, 0.013647},{
      1.870878, 0.191782, 0.013647},{1.870773, 0.192450, 0.013647},{
      1.870878, 0.193118, 0.013647},{1.871185, 0.193721, 0.013647},{
      1.871664, 0.194199, 0.013647},{1.872266, 0.194506, 0.013647},{
      1.872934, 0.194612, 0.013647},{1.873602, 0.194506, 0.013647},{
      1.874205, 0.194199, 0.013647},{1.874683, 0.193721, 0.013647},{
      1.874990, 0.193118, 0.013647},{1.875096, 0.192450, 0.013647}}],
    Polygon[{{1.912702, 0.134507, -0.009538},{1.912628, 0.134974, -0.009538},{
      1.912413, 0.135395, -0.009538},{1.912079, 0.135729, -0.009538},{
      1.911658, 0.135944, -0.009538},{1.911191, 0.136018, -0.009538},{
      1.910724, 0.135944, -0.009538},{1.910303, 0.135729, -0.009538},{
      1.909969, 0.135395, -0.009538},{1.909754, 0.134974, -0.009538},{
      1.909680, 0.134507, -0.009538},{1.909754, 0.134040, -0.009538},{
      1.909969, 0.133619, -0.009538},{1.910303, 0.133285, -0.009538},{
      1.910724, 0.133070, -0.009538},{1.911191, 0.132996, -0.009538},{
      1.911658, 0.133070, -0.009538},{1.912079, 0.133285, -0.009538},{
      1.912413, 0.133619, -0.009538},{1.912628, 0.134040, -0.009538}}],
    Polygon[{{1.912628, 0.134040, 0.009538},{1.912413, 0.133619, 0.009538},{
      1.912079, 0.133285, 0.009538},{1.911658, 0.133070, 0.009538},{
      1.911191, 0.132996, 0.009538},{1.910724, 0.133070, 0.009538},{
      1.910303, 0.133285, 0.009538},{1.909969, 0.133619, 0.009538},{
      1.909754, 0.134040, 0.009538},{1.909680, 0.134507, 0.009538},{
      1.909754, 0.134974, 0.009538},{1.909969, 0.135395, 0.009538},{
      1.910303, 0.135729, 0.009538},{1.910724, 0.135944, 0.009538},{
      1.911191, 0.136018, 0.009538},{1.911658, 0.135944, 0.009538},{
      1.912079, 0.135729, 0.009538},{1.912413, 0.135395, 0.009538},{
      1.912628, 0.134974, 0.009538},{1.912702, 0.134507, 0.009538}}],
    Polygon[{{1.858703, 0.129498, -0.008290},{1.858638, 0.129904, -0.008290},{
      1.858452, 0.130270, -0.008290},{1.858161, 0.130560, -0.008290},{
      1.857795, 0.130747, -0.008290},{1.857390, 0.130811, -0.008290},{
      1.856984, 0.130747, -0.008290},{1.856618, 0.130560, -0.008290},{
      1.856327, 0.130270, -0.008290},{1.856141, 0.129904, -0.008290},{
      1.856077, 0.129498, -0.008290},{1.856141, 0.129092, -0.008290},{
      1.856327, 0.128726, -0.008290},{1.856618, 0.128436, -0.008290},{
      1.856984, 0.128249, -0.008290},{1.857390, 0.128185, -0.008290},{
      1.857795, 0.128249, -0.008290},{1.858161, 0.128436, -0.008290},{
      1.858452, 0.128726, -0.008290},{1.858638, 0.129092, -0.008290}}],
    Polygon[{{1.858638, 0.129092, 0.008290},{1.858452, 0.128726, 0.008290},{
      1.858161, 0.128436, 0.008290},{1.857795, 0.128249, 0.008290},{
      1.857390, 0.128185, 0.008290},{1.856984, 0.128249, 0.008290},{
      1.856618, 0.128436, 0.008290},{1.856327, 0.128726, 0.008290},{
      1.856141, 0.129092, 0.008290},{1.856077, 0.129498, 0.008290},{
      1.856141, 0.129904, 0.008290},{1.856327, 0.130270, 0.008290},{
      1.856618, 0.130560, 0.008290},{1.856984, 0.130747, 0.008290},{
      1.857390, 0.130811, 0.008290},{1.857795, 0.130747, 0.008290},{
      1.858161, 0.130560, 0.008290},{1.858452, 0.130270, 0.008290},{
      1.858638, 0.129904, 0.008290},{1.858703, 0.129498, 0.008290}}],
    Polygon[{{1.434750, 0.077350, -0.076398},{1.434158, 0.081089, -0.076398},{
      1.432439, 0.084463, -0.076398},{1.429762, 0.087140, -0.076398},{
      1.426389, 0.088858, -0.076398},{1.422650, 0.089451, -0.076398},{
      1.418911, 0.088858, -0.076398},{1.415537, 0.087140, -0.076398},{
      1.412860, 0.084463, -0.076398},{1.411142, 0.081089, -0.076398},{
      1.410550, 0.077350, -0.076398},{1.411142, 0.073611, -0.076398},{
      1.412860, 0.070238, -0.076398},{1.415537, 0.067561, -0.076398},{
      1.418911, 0.065842, -0.076398},{1.422650, 0.065250, -0.076398},{
      1.426389, 0.065842, -0.076398},{1.429762, 0.067561, -0.076398},{
      1.432439, 0.070238, -0.076398},{1.434158, 0.073611, -0.076398}}],
    Polygon[{{1.434158, 0.073611, 0.076398},{1.432439, 0.070238, 0.076398},{
      1.429762, 0.067561, 0.076398},{1.426389, 0.065842, 0.076398},{
      1.422650, 0.065250, 0.076398},{1.418911, 0.065842, 0.076398},{
      1.415537, 0.067561, 0.076398},{1.412860, 0.070238, 0.076398},{
      1.411142, 0.073611, 0.076398},{1.410550, 0.077350, 0.076398},{
      1.411142, 0.081089, 0.076398},{1.412860, 0.084463, 0.076398},{
      1.415537, 0.087140, 0.076398},{1.418911, 0.088858, 0.076398},{
      1.422650, 0.089451, 0.076398},{1.426389, 0.088858, 0.076398},{
      1.429762, 0.087140, 0.076398},{1.432439, 0.084463, 0.076398},{
      1.434158, 0.081089, 0.076398},{1.434750, 0.077350, 0.076398}}],
    Polygon[{{1.315886, 0.041452, -0.040942},{1.315568, 0.043456, -0.040942},{
      1.314647, 0.045263, -0.040942},{1.313213, 0.046698, -0.040942},{
      1.311405, 0.047619, -0.040942},{1.309401, 0.047936, -0.040942},{
      1.307397, 0.047619, -0.040942},{1.305590, 0.046698, -0.040942},{
      1.304155, 0.045263, -0.040942},{1.303234, 0.043456, -0.040942},{
      1.302917, 0.041452, -0.040942},{1.303234, 0.039448, -0.040942},{
      1.304155, 0.037640, -0.040942},{1.305590, 0.036206, -0.040942},{
      1.307397, 0.035285, -0.040942},{1.309401, 0.034967, -0.040942},{
      1.311405, 0.035285, -0.040942},{1.313213, 0.036206, -0.040942},{
      1.314647, 0.037640, -0.040942},{1.315568, 0.039448, -0.040942}}],
    Polygon[{{1.315568, 0.039448, 0.040942},{1.314647, 0.037640, 0.040942},{
      1.313213, 0.036206, 0.040942},{1.311405, 0.035285, 0.040942},{
      1.309401, 0.034967, 0.040942},{1.307397, 0.035285, 0.040942},{
      1.305590, 0.036206, 0.040942},{1.304155, 0.037640, 0.040942},{
      1.303234, 0.039448, 0.040942},{1.302917, 0.041452, 0.040942},{
      1.303234, 0.043456, 0.040942},{1.304155, 0.045263, 0.040942},{
      1.305590, 0.046698, 0.040942},{1.307397, 0.047619, 0.040942},{
      1.309401, 0.047936, 0.040942},{1.311405, 0.047619, 0.040942},{
      1.313213, 0.046698, 0.040942},{1.314647, 0.045263, 0.040942},{
      1.315568, 0.043456, 0.040942},{1.315886, 0.041452, 0.040942}}],
    Polygon[{{1.248050, 0.025783, -0.025466},{1.247853, 0.027030, -0.025466},{
      1.247280, 0.028154, -0.025466},{1.246388, 0.029047, -0.025466},{
      1.245263, 0.029619, -0.025466},{1.244017, 0.029817, -0.025466},{
      1.242771, 0.029619, -0.025466},{1.241646, 0.029047, -0.025466},{
      1.240754, 0.028154, -0.025466},{1.240181, 0.027030, -0.025466},{
      1.239984, 0.025783, -0.025466},{1.240181, 0.024537, -0.025466},{
      1.240754, 0.023413, -0.025466},{1.241646, 0.022520, -0.025466},{
      1.242771, 0.021947, -0.025466},{1.244017, 0.021750, -0.025466},{
      1.245263, 0.021947, -0.025466},{1.246388, 0.022520, -0.025466},{
      1.247280, 0.023413, -0.025466},{1.247853, 0.024537, -0.025466}}],
    Polygon[{{1.247853, 0.024537, 0.025466},{1.247280, 0.023413, 0.025466},{
      1.246388, 0.022520, 0.025466},{1.245263, 0.021947, 0.025466},{
      1.244017, 0.021750, 0.025466},{1.242771, 0.021947, 0.025466},{
      1.241646, 0.022520, 0.025466},{1.240754, 0.023413, 0.025466},{
      1.240181, 0.024537, 0.025466},{1.239984, 0.025783, 0.025466},{
      1.240181, 0.027030, 0.025466},{1.240754, 0.028154, 0.025466},{
      1.241646, 0.029047, 0.025466},{1.242771, 0.029619, 0.025466},{
      1.244017, 0.029817, 0.025466},{1.245263, 0.029619, 0.025466},{
      1.246388, 0.029047, 0.025466},{1.247280, 0.028154, 0.025466},{
      1.247853, 0.027030, 0.025466},{1.248050, 0.025783, 0.025466}}],
    Polygon[{{1.359427, 0.013817, -0.013647},{1.359321, 0.014485, -0.013647},{
      1.359014, 0.015088, -0.013647},{1.358536, 0.015566, -0.013647},{
      1.357934, 0.015873, -0.013647},{1.357266, 0.015979, -0.013647},{
      1.356598, 0.015873, -0.013647},{1.355995, 0.015566, -0.013647},{
      1.355517, 0.015088, -0.013647},{1.355210, 0.014485, -0.013647},{
      1.355104, 0.013817, -0.013647},{1.355210, 0.013149, -0.013647},{
      1.355517, 0.012547, -0.013647},{1.355995, 0.012069, -0.013647},{
      1.356598, 0.011762, -0.013647},{1.357266, 0.011656, -0.013647},{
      1.357934, 0.011762, -0.013647},{1.358536, 0.012069, -0.013647},{
      1.359014, 0.012547, -0.013647},{1.359321, 0.013149, -0.013647}}],
    Polygon[{{1.359321, 0.013149, 0.013647},{1.359014, 0.012547, 0.013647},{
      1.358536, 0.012069, 0.013647},{1.357934, 0.011762, 0.013647},{
      1.357266, 0.011656, 0.013647},{1.356598, 0.011762, 0.013647},{
      1.355995, 0.012069, 0.013647},{1.355517, 0.012547, 0.013647},{
      1.355210, 0.013149, 0.013647},{1.355104, 0.013817, 0.013647},{
      1.355210, 0.014485, 0.013647},{1.355517, 0.015088, 0.013647},{
      1.355995, 0.015566, 0.013647},{1.356598, 0.015873, 0.013647},{
      1.357266, 0.015979, 0.013647},{1.357934, 0.015873, 0.013647},{
      1.358536, 0.015566, 0.013647},{1.359014, 0.015088, 0.013647},{
      1.359321, 0.014485, 0.013647},{1.359427, 0.013817, 0.013647}}],
    Polygon[{{1.335350, 0.090242, -0.012733},{1.335251, 0.090865, -0.012733},{
      1.334965, 0.091427, -0.012733},{1.334519, 0.091874, -0.012733},{
      1.333956, 0.092160, -0.012733},{1.333333, 0.092259, -0.012733},{
      1.332710, 0.092160, -0.012733},{1.332148, 0.091874, -0.012733},{
      1.331702, 0.091427, -0.012733},{1.331415, 0.090865, -0.012733},{
      1.331317, 0.090242, -0.012733},{1.331415, 0.089619, -0.012733},{
      1.331702, 0.089057, -0.012733},{1.332148, 0.088610, -0.012733},{
      1.332710, 0.088324, -0.012733},{1.333333, 0.088225, -0.012733},{
      1.333956, 0.088324, -0.012733},{1.334519, 0.088610, -0.012733},{
      1.334965, 0.089057, -0.012733},{1.335251, 0.089619, -0.012733}}],
    Polygon[{{1.335251, 0.089619, 0.012733},{1.334965, 0.089057, 0.012733},{
      1.334519, 0.088610, 0.012733},{1.333956, 0.088324, 0.012733},{
      1.333333, 0.088225, 0.012733},{1.332710, 0.088324, 0.012733},{
      1.332148, 0.088610, 0.012733},{1.331702, 0.089057, 0.012733},{
      1.331415, 0.089619, 0.012733},{1.331317, 0.090242, 0.012733},{
      1.331415, 0.090865, 0.012733},{1.331702, 0.091427, 0.012733},{
      1.332148, 0.091874, 0.012733},{1.332710, 0.092160, 0.012733},{
      1.333333, 0.092259, 0.012733},{1.333956, 0.092160, 0.012733},{
      1.334519, 0.091874, 0.012733},{1.334965, 0.091427, 0.012733},{
      1.335251, 0.090865, 0.012733},{1.335350, 0.090242, 0.012733}}],
    Polygon[{{1.521859, 0.028972, -0.028615},{1.521638, 0.030372, -0.028615},{
      1.520994, 0.031635, -0.028615},{1.519991, 0.032638, -0.028615},{
      1.518728, 0.033282, -0.028615},{1.517327, 0.033504, -0.028615},{
      1.515927, 0.033282, -0.028615},{1.514663, 0.032638, -0.028615},{
      1.513661, 0.031635, -0.028615},{1.513017, 0.030372, -0.028615},{
      1.512795, 0.028972, -0.028615},{1.513017, 0.027571, -0.028615},{
      1.513661, 0.026308, -0.028615},{1.514663, 0.025305, -0.028615},{
      1.515927, 0.024661, -0.028615},{1.517327, 0.024439, -0.028615},{
      1.518728, 0.024661, -0.028615},{1.519991, 0.025305, -0.028615},{
      1.520994, 0.026308, -0.028615},{1.521638, 0.027571, -0.028615}}],
    Polygon[{{1.521638, 0.027571, 0.028615},{1.520994, 0.026308, 0.028615},{
      1.519991, 0.025305, 0.028615},{1.518728, 0.024661, 0.028615},{
      1.517327, 0.024439, 0.028615},{1.515927, 0.024661, 0.028615},{
      1.514663, 0.025305, 0.028615},{1.513661, 0.026308, 0.028615},{
      1.513017, 0.027571, 0.028615},{1.512795, 0.028972, 0.028615},{
      1.513017, 0.030372, 0.028615},{1.513661, 0.031635, 0.028615},{
      1.514663, 0.032638, 0.028615},{1.515927, 0.033282, 0.028615},{
      1.517327, 0.033504, 0.028615},{1.518728, 0.033282, 0.028615},{
      1.519991, 0.032638, 0.028615},{1.520994, 0.031635, 0.028615},{
      1.521638, 0.030372, 0.028615},{1.521859, 0.028972, 0.028615}}],
    Polygon[{{1.561425, 0.015038, -0.014853},{1.561310, 0.015765, -0.014853},{
      1.560976, 0.016421, -0.014853},{1.560456, 0.016941, -0.014853},{
      1.559800, 0.017276, -0.014853},{1.559073, 0.017391, -0.014853},{
      1.558346, 0.017276, -0.014853},{1.557690, 0.016941, -0.014853},{
      1.557170, 0.016421, -0.014853},{1.556836, 0.015765, -0.014853},{
      1.556720, 0.015038, -0.014853},{1.556836, 0.014311, -0.014853},{
      1.557170, 0.013655, -0.014853},{1.557690, 0.013135, -0.014853},{
      1.558346, 0.012801, -0.014853},{1.559073, 0.012686, -0.014853},{
      1.559800, 0.012801, -0.014853},{1.560456, 0.013135, -0.014853},{
      1.560976, 0.013655, -0.014853},{1.561310, 0.014311, -0.014853}}],
    Polygon[{{1.561310, 0.014311, 0.014853},{1.560976, 0.013655, 0.014853},{
      1.560456, 0.013135, 0.014853},{1.559800, 0.012801, 0.014853},{
      1.559073, 0.012686, 0.014853},{1.558346, 0.012801, 0.014853},{
      1.557690, 0.013135, 0.014853},{1.557170, 0.013655, 0.014853},{
      1.556836, 0.014311, 0.014853},{1.556720, 0.015038, 0.014853},{
      1.556836, 0.015765, 0.014853},{1.557170, 0.016421, 0.014853},{
      1.557690, 0.016941, 0.014853},{1.558346, 0.017276, 0.014853},{
      1.559073, 0.017391, 0.014853},{1.559800, 0.017276, 0.014853},{
      1.560456, 0.016941, 0.014853},{1.560976, 0.016421, 0.014853},{
      1.561310, 0.015765, 0.014853},{1.561425, 0.015038, 0.014853}}],
    Polygon[{{1.483127, 0.011149, -0.011012},{1.483041, 0.011688, -0.011012},{
      1.482793, 0.012174, -0.011012},{1.482408, 0.012560, -0.011012},{
      1.481921, 0.012808, -0.011012},{1.481382, 0.012893, -0.011012},{
      1.480844, 0.012808, -0.011012},{1.480357, 0.012560, -0.011012},{
      1.479971, 0.012174, -0.011012},{1.479724, 0.011688, -0.011012},{
      1.479638, 0.011149, -0.011012},{1.479724, 0.010610, -0.011012},{
      1.479971, 0.010124, -0.011012},{1.480357, 0.009738, -0.011012},{
      1.480844, 0.009490, -0.011012},{1.481382, 0.009405, -0.011012},{
      1.481921, 0.009490, -0.011012},{1.482408, 0.009738, -0.011012},{
      1.482793, 0.010124, -0.011012},{1.483041, 0.010610, -0.011012}}],
    Polygon[{{1.483041, 0.010610, 0.011012},{1.482793, 0.010124, 0.011012},{
      1.482408, 0.009738, 0.011012},{1.481921, 0.009490, 0.011012},{
      1.481382, 0.009405, 0.011012},{1.480844, 0.009490, 0.011012},{
      1.480357, 0.009738, 0.011012},{1.479971, 0.010124, 0.011012},{
      1.479724, 0.010610, 0.011012},{1.479638, 0.011149, 0.011012},{
      1.479724, 0.011688, 0.011012},{1.479971, 0.012174, 0.011012},{
      1.480357, 0.012560, 0.011012},{1.480844, 0.012808, 0.011012},{
      1.481382, 0.012893, 0.011012},{1.481921, 0.012808, 0.011012},{
      1.482408, 0.012560, 0.011012},{1.482793, 0.012174, 0.011012},{
      1.483041, 0.011688, 0.011012},{1.483127, 0.011149, 0.011012}}],
    Polygon[{{1.510302, 0.066488, -0.009381},{1.510229, 0.066947, -0.009381},{
      1.510018, 0.067361, -0.009381},{1.509690, 0.067690, -0.009381},{
      1.509276, 0.067901, -0.009381},{1.508816, 0.067974, -0.009381},{
      1.508357, 0.067901, -0.009381},{1.507943, 0.067690, -0.009381},{
      1.507614, 0.067361, -0.009381},{1.507403, 0.066947, -0.009381},{
      1.507331, 0.066488, -0.009381},{1.507403, 0.066029, -0.009381},{
      1.507614, 0.065615, -0.009381},{1.507943, 0.065286, -0.009381},{
      1.508357, 0.065075, -0.009381},{1.508816, 0.065002, -0.009381},{
      1.509276, 0.065075, -0.009381},{1.509690, 0.065286, -0.009381},{
      1.510018, 0.065615, -0.009381},{1.510229, 0.066029, -0.009381}}],
    Polygon[{{1.510229, 0.066029, 0.009381},{1.510018, 0.065615, 0.009381},{
      1.509690, 0.065286, 0.009381},{1.509276, 0.065075, 0.009381},{
      1.508816, 0.065002, 0.009381},{1.508357, 0.065075, 0.009381},{
      1.507943, 0.065286, 0.009381},{1.507614, 0.065615, 0.009381},{
      1.507403, 0.066029, 0.009381},{1.507331, 0.066488, 0.009381},{
      1.507403, 0.066947, 0.009381},{1.507614, 0.067361, 0.009381},{
      1.507943, 0.067690, 0.009381},{1.508357, 0.067901, 0.009381},{
      1.508816, 0.067974, 0.009381},{1.509276, 0.067901, 0.009381},{
      1.509690, 0.067690, 0.009381},{1.510018, 0.067361, 0.009381},{
      1.510229, 0.066947, 0.009381},{1.510302, 0.066488, 0.009381}}],
    Polygon[{{1.453578, 0.176266, -0.024871},{1.453385, 0.177483, -0.024871},{
      1.452825, 0.178581, -0.024871},{1.451954, 0.179452, -0.024871},{
      1.450856, 0.180012, -0.024871},{1.449638, 0.180205, -0.024871},{
      1.448421, 0.180012, -0.024871},{1.447323, 0.179452, -0.024871},{
      1.446452, 0.178581, -0.024871},{1.445892, 0.177483, -0.024871},{
      1.445699, 0.176266, -0.024871},{1.445892, 0.175048, -0.024871},{
      1.446452, 0.173950, -0.024871},{1.447323, 0.173079, -0.024871},{
      1.448421, 0.172519, -0.024871},{1.449638, 0.172326, -0.024871},{
      1.450856, 0.172519, -0.024871},{1.451954, 0.173079, -0.024871},{
      1.452825, 0.173950, -0.024871},{1.453385, 0.175048, -0.024871}}],
    Polygon[{{1.453385, 0.175048, 0.024871},{1.452825, 0.173950, 0.024871},{
      1.451954, 0.173079, 0.024871},{1.450856, 0.172519, 0.024871},{
      1.449638, 0.172326, 0.024871},{1.448421, 0.172519, 0.024871},{
      1.447323, 0.173079, 0.024871},{1.446452, 0.173950, 0.024871},{
      1.445892, 0.175048, 0.024871},{1.445699, 0.176266, 0.024871},{
      1.445892, 0.177483, 0.024871},{1.446452, 0.178581, 0.024871},{
      1.447323, 0.179452, 0.024871},{1.448421, 0.180012, 0.024871},{
      1.449638, 0.180205, 0.024871},{1.450856, 0.180012, 0.024871},{
      1.451954, 0.179452, 0.024871},{1.452825, 0.178581, 0.024871},{
      1.453385, 0.177483, 0.024871},{1.453578, 0.176266, 0.024871}}],
    Polygon[{{1.464612, 0.211564, -0.012292},{1.464517, 0.212166, -0.012292},{
      1.464240, 0.212709, -0.012292},{1.463809, 0.213139, -0.012292},{
      1.463267, 0.213416, -0.012292},{1.462665, 0.213511, -0.012292},{
      1.462064, 0.213416, -0.012292},{1.461521, 0.213139, -0.012292},{
      1.461090, 0.212709, -0.012292},{1.460814, 0.212166, -0.012292},{
      1.460718, 0.211564, -0.012292},{1.460814, 0.210963, -0.012292},{
      1.461090, 0.210420, -0.012292},{1.461521, 0.209989, -0.012292},{
      1.462064, 0.209713, -0.012292},{1.462665, 0.209617, -0.012292},{
      1.463267, 0.209713, -0.012292},{1.463809, 0.209989, -0.012292},{
      1.464240, 0.210420, -0.012292},{1.464517, 0.210963, -0.012292}}],
    Polygon[{{1.464517, 0.210963, 0.012292},{1.464240, 0.210420, 0.012292},{
      1.463809, 0.209989, 0.012292},{1.463267, 0.209713, 0.012292},{
      1.462665, 0.209617, 0.012292},{1.462064, 0.209713, 0.012292},{
      1.461521, 0.209989, 0.012292},{1.461090, 0.210420, 0.012292},{
      1.460814, 0.210963, 0.012292},{1.460718, 0.211564, 0.012292},{
      1.460814, 0.212166, 0.012292},{1.461090, 0.212709, 0.012292},{
      1.461521, 0.213139, 0.012292},{1.462064, 0.213416, 0.012292},{
      1.462665, 0.213511, 0.012292},{1.463267, 0.213416, 0.012292},{
      1.463809, 0.213139, 0.012292},{1.464240, 0.212709, 0.012292},{
      1.464517, 0.212166, 0.012292},{1.464612, 0.211564, 0.012292}}],
    Polygon[{{1.418478, 0.164172, -0.009538},{1.418404, 0.164639, -0.009538},{
      1.418189, 0.165060, -0.009538},{1.417855, 0.165394, -0.009538},{
      1.417434, 0.165609, -0.009538},{1.416967, 0.165683, -0.009538},{
      1.416500, 0.165609, -0.009538},{1.416079, 0.165394, -0.009538},{
      1.415745, 0.165060, -0.009538},{1.415530, 0.164639, -0.009538},{
      1.415456, 0.164172, -0.009538},{1.415530, 0.163705, -0.009538},{
      1.415745, 0.163284, -0.009538},{1.416079, 0.162950, -0.009538},{
      1.416500, 0.162735, -0.009538},{1.416967, 0.162661, -0.009538},{
      1.417434, 0.162735, -0.009538},{1.417855, 0.162950, -0.009538},{
      1.418189, 0.163284, -0.009538},{1.418404, 0.163705, -0.009538}}],
    Polygon[{{1.418404, 0.163705, 0.009538},{1.418189, 0.163284, 0.009538},{
      1.417855, 0.162950, 0.009538},{1.417434, 0.162735, 0.009538},{
      1.416967, 0.162661, 0.009538},{1.416500, 0.162735, 0.009538},{
      1.416079, 0.162950, 0.009538},{1.415745, 0.163284, 0.009538},{
      1.415530, 0.163705, 0.009538},{1.415456, 0.164172, 0.009538},{
      1.415530, 0.164639, 0.009538},{1.415745, 0.165060, 0.009538},{
      1.416079, 0.165394, 0.009538},{1.416500, 0.165609, 0.009538},{
      1.416967, 0.165683, 0.009538},{1.417434, 0.165609, 0.009538},{
      1.417855, 0.165394, 0.009538},{1.418189, 0.165060, 0.009538},{
      1.418404, 0.164639, 0.009538},{1.418478, 0.164172, 0.009538}}],
    Polygon[{{1.471516, 0.149198, -0.008668},{1.471449, 0.149623, -0.008668},{
      1.471254, 0.150005, -0.008668},{1.470950, 0.150309, -0.008668},{
      1.470568, 0.150504, -0.008668},{1.470143, 0.150571, -0.008668},{
      1.469719, 0.150504, -0.008668},{1.469337, 0.150309, -0.008668},{
      1.469033, 0.150005, -0.008668},{1.468838, 0.149623, -0.008668},{
      1.468771, 0.149198, -0.008668},{1.468838, 0.148774, -0.008668},{
      1.469033, 0.148391, -0.008668},{1.469337, 0.148088, -0.008668},{
      1.469719, 0.147893, -0.008668},{1.470143, 0.147825, -0.008668},{
      1.470568, 0.147893, -0.008668},{1.470950, 0.148088, -0.008668},{
      1.471254, 0.148391, -0.008668},{1.471449, 0.148774, -0.008668}}],
    Polygon[{{1.471449, 0.148774, 0.008668},{1.471254, 0.148391, 0.008668},{
      1.470950, 0.148088, 0.008668},{1.470568, 0.147893, 0.008668},{
      1.470143, 0.147825, 0.008668},{1.469719, 0.147893, 0.008668},{
      1.469337, 0.148088, 0.008668},{1.469033, 0.148391, 0.008668},{
      1.468838, 0.148774, 0.008668},{1.468771, 0.149198, 0.008668},{
      1.468838, 0.149623, 0.008668},{1.469033, 0.150005, 0.008668},{
      1.469337, 0.150309, 0.008668},{1.469719, 0.150504, 0.008668},{
      1.470143, 0.150571, 0.008668},{1.470568, 0.150504, 0.008668},{
      1.470950, 0.150309, 0.008668},{1.471254, 0.150005, 0.008668},{
      1.471449, 0.149623, 0.008668},{1.471516, 0.149198, 0.008668}}],
    Polygon[{{1.656438, 0.461325, -0.076398},{1.655846, 0.465064, -0.076398},{
      1.654127, 0.468437, -0.076398},{1.651450, 0.471114, -0.076398},{
      1.648077, 0.472833, -0.076398},{1.644338, 0.473425, -0.076398},{
      1.640598, 0.472833, -0.076398},{1.637225, 0.471114, -0.076398},{
      1.634548, 0.468437, -0.076398},{1.632830, 0.465064, -0.076398},{
      1.632237, 0.461325, -0.076398},{1.632830, 0.457586, -0.076398},{
      1.634548, 0.454213, -0.076398},{1.637225, 0.451536, -0.076398},{
      1.640598, 0.449817, -0.076398},{1.644338, 0.449225, -0.076398},{
      1.648077, 0.449817, -0.076398},{1.651450, 0.451536, -0.076398},{
      1.654127, 0.454213, -0.076398},{1.655846, 0.457586, -0.076398}}],
    Polygon[{{1.655846, 0.457586, 0.076398},{1.654127, 0.454213, 0.076398},{
      1.651450, 0.451536, 0.076398},{1.648077, 0.449817, 0.076398},{
      1.644338, 0.449225, 0.076398},{1.640598, 0.449817, 0.076398},{
      1.637225, 0.451536, 0.076398},{1.634548, 0.454213, 0.076398},{
      1.632830, 0.457586, 0.076398},{1.632237, 0.461325, 0.076398},{
      1.632830, 0.465064, 0.076398},{1.634548, 0.468437, 0.076398},{
      1.637225, 0.471114, 0.076398},{1.640598, 0.472833, 0.076398},{
      1.644338, 0.473425, 0.076398},{1.648077, 0.472833, 0.076398},{
      1.651450, 0.471114, 0.076398},{1.654127, 0.468437, 0.076398},{
      1.655846, 0.465064, 0.076398},{1.656438, 0.461325, 0.076398}}],
    Polygon[{{1.625287, 0.577350, -0.040942},{1.624969, 0.579354, -0.040942},{
      1.624048, 0.581162, -0.040942},{1.622614, 0.582596, -0.040942},{
      1.620806, 0.583517, -0.040942},{1.618802, 0.583835, -0.040942},{
      1.616798, 0.583517, -0.040942},{1.614991, 0.582596, -0.040942},{
      1.613556, 0.581162, -0.040942},{1.612635, 0.579354, -0.040942},{
      1.612318, 0.577350, -0.040942},{1.612635, 0.575346, -0.040942},{
      1.613556, 0.573539, -0.040942},{1.614991, 0.572104, -0.040942},{
      1.616798, 0.571183, -0.040942},{1.618802, 0.570866, -0.040942},{
      1.620806, 0.571183, -0.040942},{1.622614, 0.572104, -0.040942},{
      1.624048, 0.573539, -0.040942},{1.624969, 0.575346, -0.040942}}],
    Polygon[{{1.624969, 0.575346, 0.040942},{1.624048, 0.573539, 0.040942},{
      1.622614, 0.572104, 0.040942},{1.620806, 0.571183, 0.040942},{
      1.618802, 0.570866, 0.040942},{1.616798, 0.571183, 0.040942},{
      1.614991, 0.572104, 0.040942},{1.613556, 0.573539, 0.040942},{
      1.612635, 0.575346, 0.040942},{1.612318, 0.577350, 0.040942},{
      1.612635, 0.579354, 0.040942},{1.613556, 0.581162, 0.040942},{
      1.614991, 0.582596, 0.040942},{1.616798, 0.583517, 0.040942},{
      1.618802, 0.583835, 0.040942},{1.620806, 0.583517, 0.040942},{
      1.622614, 0.582596, 0.040942},{1.624048, 0.581162, 0.040942},{
      1.624969, 0.579354, 0.040942},{1.625287, 0.577350, 0.040942}}],
    Polygon[{{1.603713, 0.641809, -0.025466},{1.603515, 0.643055, -0.025466},{
      1.602942, 0.644180, -0.025466},{1.602050, 0.645072, -0.025466},{
      1.600926, 0.645645, -0.025466},{1.599679, 0.645842, -0.025466},{
      1.598433, 0.645645, -0.025466},{1.597309, 0.645072, -0.025466},{
      1.596416, 0.644180, -0.025466},{1.595843, 0.643055, -0.025466},{
      1.595646, 0.641809, -0.025466},{1.595843, 0.640562, -0.025466},{
      1.596416, 0.639438, -0.025466},{1.597309, 0.638546, -0.025466},{
      1.598433, 0.637973, -0.025466},{1.599679, 0.637775, -0.025466},{
      1.600926, 0.637973, -0.025466},{1.602050, 0.638546, -0.025466},{
      1.602942, 0.639438, -0.025466},{1.603515, 0.640562, -0.025466}}],
    Polygon[{{1.603515, 0.640562, 0.025466},{1.602942, 0.639438, 0.025466},{
      1.602050, 0.638546, 0.025466},{1.600926, 0.637973, 0.025466},{
      1.599679, 0.637775, 0.025466},{1.598433, 0.637973, 0.025466},{
      1.597309, 0.638546, 0.025466},{1.596416, 0.639438, 0.025466},{
      1.595843, 0.640562, 0.025466},{1.595646, 0.641809, 0.025466},{
      1.595843, 0.643055, 0.025466},{1.596416, 0.644180, 0.025466},{
      1.597309, 0.645072, 0.025466},{1.598433, 0.645645, 0.025466},{
      1.599679, 0.645842, 0.025466},{1.600926, 0.645645, 0.025466},{
      1.602050, 0.645072, 0.025466},{1.602942, 0.644180, 0.025466},{
      1.603515, 0.643055, 0.025466},{1.603713, 0.641809, 0.025466}}],
    Polygon[{{1.668828, 0.549716, -0.013647},{1.668722, 0.550384, -0.013647},{
      1.668415, 0.550986, -0.013647},{1.667937, 0.551464, -0.013647},{
      1.667335, 0.551771, -0.013647},{1.666667, 0.551877, -0.013647},{
      1.665999, 0.551771, -0.013647},{1.665396, 0.551464, -0.013647},{
      1.664918, 0.550986, -0.013647},{1.664611, 0.550384, -0.013647},{
      1.664505, 0.549716, -0.013647},{1.664611, 0.549048, -0.013647},{
      1.664918, 0.548445, -0.013647},{1.665396, 0.547967, -0.013647},{
      1.665999, 0.547660, -0.013647},{1.666667, 0.547554, -0.013647},{
      1.667335, 0.547660, -0.013647},{1.667937, 0.547967, -0.013647},{
      1.668415, 0.548445, -0.013647},{1.668722, 0.549048, -0.013647}}],
    Polygon[{{1.668722, 0.549048, 0.013647},{1.668415, 0.548445, 0.013647},{
      1.667937, 0.547967, 0.013647},{1.667335, 0.547660, 0.013647},{
      1.666667, 0.547554, 0.013647},{1.665999, 0.547660, 0.013647},{
      1.665396, 0.547967, 0.013647},{1.664918, 0.548445, 0.013647},{
      1.664611, 0.549048, 0.013647},{1.664505, 0.549716, 0.013647},{
      1.664611, 0.550384, 0.013647},{1.664918, 0.550986, 0.013647},{
      1.665396, 0.551464, 0.013647},{1.665999, 0.551771, 0.013647},{
      1.666667, 0.551877, 0.013647},{1.667335, 0.551771, 0.013647},{
      1.667937, 0.551464, 0.013647},{1.668415, 0.550986, 0.013647},{
      1.668722, 0.550384, 0.013647},{1.668828, 0.549716, 0.013647}}],
    Polygon[{{1.590531, 0.532229, -0.012733},{1.590433, 0.532852, -0.012733},{
      1.590146, 0.533415, -0.012733},{1.589700, 0.533861, -0.012733},{
      1.589138, 0.534147, -0.012733},{1.588515, 0.534246, -0.012733},{
      1.587892, 0.534147, -0.012733},{1.587329, 0.533861, -0.012733},{
      1.586883, 0.533415, -0.012733},{1.586597, 0.532852, -0.012733},{
      1.586498, 0.532229, -0.012733},{1.586597, 0.531606, -0.012733},{
      1.586883, 0.531044, -0.012733},{1.587329, 0.530598, -0.012733},{
      1.587892, 0.530311, -0.012733},{1.588515, 0.530213, -0.012733},{
      1.589138, 0.530311, -0.012733},{1.589700, 0.530598, -0.012733},{
      1.590146, 0.531044, -0.012733},{1.590433, 0.531606, -0.012733}}],
    Polygon[{{1.590433, 0.531606, 0.012733},{1.590146, 0.531044, 0.012733},{
      1.589700, 0.530598, 0.012733},{1.589138, 0.530311, 0.012733},{
      1.588515, 0.530213, 0.012733},{1.587892, 0.530311, 0.012733},{
      1.587329, 0.530598, 0.012733},{1.586883, 0.531044, 0.012733},{
      1.586597, 0.531606, 0.012733},{1.586498, 0.532229, 0.012733},{
      1.586597, 0.532852, 0.012733},{1.586883, 0.533415, 0.012733},{
      1.587329, 0.533861, 0.012733},{1.587892, 0.534147, 0.012733},{
      1.588515, 0.534246, 0.012733},{1.589138, 0.534147, 0.012733},{
      1.589700, 0.533861, 0.012733},{1.590146, 0.533415, 0.012733},{
      1.590433, 0.532852, 0.012733},{1.590531, 0.532229, 0.012733}}],
    Polygon[{{1.738106, 0.403521, -0.028615},{1.737884, 0.404922, -0.028615},{
      1.737240, 0.406185, -0.028615},{1.736237, 0.407188, -0.028615},{
      1.734974, 0.407831, -0.028615},{1.733574, 0.408053, -0.028615},{
      1.732173, 0.407831, -0.028615},{1.730910, 0.407188, -0.028615},{
      1.729907, 0.406185, -0.028615},{1.729263, 0.404922, -0.028615},{
      1.729041, 0.403521, -0.028615},{1.729263, 0.402121, -0.028615},{
      1.729907, 0.400857, -0.028615},{1.730910, 0.399855, -0.028615},{
      1.732173, 0.399211, -0.028615},{1.733574, 0.398989, -0.028615},{
      1.734974, 0.399211, -0.028615},{1.736237, 0.399855, -0.028615},{
      1.737240, 0.400857, -0.028615},{1.737884, 0.402121, -0.028615}}],
    Polygon[{{1.737884, 0.402121, 0.028615},{1.737240, 0.400857, 0.028615},{
      1.736237, 0.399855, 0.028615},{1.734974, 0.399211, 0.028615},{
      1.733574, 0.398989, 0.028615},{1.732173, 0.399211, 0.028615},{
      1.730910, 0.399855, 0.028615},{1.729907, 0.400857, 0.028615},{
      1.729263, 0.402121, 0.028615},{1.729041, 0.403521, 0.028615},{
      1.729263, 0.404922, 0.028615},{1.729907, 0.406185, 0.028615},{
      1.730910, 0.407188, 0.028615},{1.732173, 0.407831, 0.028615},{
      1.733574, 0.408053, 0.028615},{1.734974, 0.407831, 0.028615},{
      1.736237, 0.407188, 0.028615},{1.737240, 0.406185, 0.028615},{
      1.737884, 0.404922, 0.028615},{1.738106, 0.403521, 0.028615}}],
    Polygon[{{1.768866, 0.374335, -0.014853},{1.768750, 0.375062, -0.014853},{
      1.768416, 0.375718, -0.014853},{1.767896, 0.376238, -0.014853},{
      1.767240, 0.376572, -0.014853},{1.766513, 0.376687, -0.014853},{
      1.765786, 0.376572, -0.014853},{1.765130, 0.376238, -0.014853},{
      1.764610, 0.375718, -0.014853},{1.764276, 0.375062, -0.014853},{
      1.764161, 0.374335, -0.014853},{1.764276, 0.373608, -0.014853},{
      1.764610, 0.372952, -0.014853},{1.765130, 0.372432, -0.014853},{
      1.765786, 0.372098, -0.014853},{1.766513, 0.371982, -0.014853},{
      1.767240, 0.372098, -0.014853},{1.767896, 0.372432, -0.014853},{
      1.768416, 0.372952, -0.014853},{1.768750, 0.373608, -0.014853}}],
    Polygon[{{1.768750, 0.373608, 0.014853},{1.768416, 0.372952, 0.014853},{
      1.767896, 0.372432, 0.014853},{1.767240, 0.372098, 0.014853},{
      1.766513, 0.371982, 0.014853},{1.765786, 0.372098, 0.014853},{
      1.765130, 0.372432, 0.014853},{1.764610, 0.372952, 0.014853},{
      1.764276, 0.373608, 0.014853},{1.764161, 0.374335, 0.014853},{
      1.764276, 0.375062, 0.014853},{1.764610, 0.375718, 0.014853},{
      1.765130, 0.376238, 0.014853},{1.765786, 0.376572, 0.014853},{
      1.766513, 0.376687, 0.014853},{1.767240, 0.376572, 0.014853},{
      1.767896, 0.376238, 0.014853},{1.768416, 0.375718, 0.014853},{
      1.768750, 0.375062, 0.014853},{1.768866, 0.374335, 0.014853}}],
    Polygon[{{1.732780, 0.443561, -0.011012},{1.732695, 0.444100, -0.011012},{
      1.732447, 0.444587, -0.011012},{1.732061, 0.444972, -0.011012},{
      1.731575, 0.445220, -0.011012},{1.731036, 0.445306, -0.011012},{
      1.730497, 0.445220, -0.011012},{1.730011, 0.444972, -0.011012},{
      1.729625, 0.444587, -0.011012},{1.729377, 0.444100, -0.011012},{
      1.729292, 0.443561, -0.011012},{1.729377, 0.443022, -0.011012},{
      1.729625, 0.442536, -0.011012},{1.730011, 0.442150, -0.011012},{
      1.730497, 0.441903, -0.011012},{1.731036, 0.441817, -0.011012},{
      1.731575, 0.441903, -0.011012},{1.732061, 0.442150, -0.011012},{
      1.732447, 0.442536, -0.011012},{1.732695, 0.443022, -0.011012}}],
    Polygon[{{1.732695, 0.443022, 0.011012},{1.732447, 0.442536, 0.011012},{
      1.732061, 0.442150, 0.011012},{1.731575, 0.441903, 0.011012},{
      1.731036, 0.441817, 0.011012},{1.730497, 0.441903, 0.011012},{
      1.730011, 0.442150, 0.011012},{1.729625, 0.442536, 0.011012},{
      1.729377, 0.443022, 0.011012},{1.729292, 0.443561, 0.011012},{
      1.729377, 0.444100, 0.011012},{1.729625, 0.444587, 0.011012},{
      1.730011, 0.444972, 0.011012},{1.730497, 0.445220, 0.011012},{
      1.731036, 0.445306, 0.011012},{1.731575, 0.445220, 0.011012},{
      1.732061, 0.444972, 0.011012},{1.732447, 0.444587, 0.011012},{
      1.732695, 0.444100, 0.011012},{1.732780, 0.443561, 0.011012}}],
    Polygon[{{1.698314, 0.392133, -0.009381},{1.698241, 0.392593, -0.009381},{
      1.698030, 0.393007, -0.009381},{1.697701, 0.393336, -0.009381},{
      1.697287, 0.393547, -0.009381},{1.696828, 0.393619, -0.009381},{
      1.696369, 0.393547, -0.009381},{1.695954, 0.393336, -0.009381},{
      1.695626, 0.393007, -0.009381},{1.695415, 0.392593, -0.009381},{
      1.695342, 0.392133, -0.009381},{1.695415, 0.391674, -0.009381},{
      1.695626, 0.391260, -0.009381},{1.695954, 0.390931, -0.009381},{
      1.696369, 0.390720, -0.009381},{1.696828, 0.390648, -0.009381},{
      1.697287, 0.390720, -0.009381},{1.697701, 0.390931, -0.009381},{
      1.698030, 0.391260, -0.009381},{1.698241, 0.391674, -0.009381}}],
    Polygon[{{1.698241, 0.391674, 0.009381},{1.698030, 0.391260, 0.009381},{
      1.697701, 0.390931, 0.009381},{1.697287, 0.390720, 0.009381},{
      1.696828, 0.390648, 0.009381},{1.696369, 0.390720, 0.009381},{
      1.695954, 0.390931, 0.009381},{1.695626, 0.391260, 0.009381},{
      1.695415, 0.391674, 0.009381},{1.695342, 0.392133, 0.009381},{
      1.695415, 0.392593, 0.009381},{1.695626, 0.393007, 0.009381},{
      1.695954, 0.393336, 0.009381},{1.696369, 0.393547, 0.009381},{
      1.696828, 0.393619, 0.009381},{1.697287, 0.393547, 0.009381},{
      1.697701, 0.393336, 0.009381},{1.698030, 0.393007, 0.009381},{
      1.698241, 0.392593, 0.009381},{1.698314, 0.392133, 0.009381}}],
    Polygon[{{1.576108, 0.388494, -0.024871},{1.575915, 0.389712, -0.024871},{
      1.575356, 0.390810, -0.024871},{1.574484, 0.391681, -0.024871},{
      1.573386, 0.392241, -0.024871},{1.572169, 0.392433, -0.024871},{
      1.570951, 0.392241, -0.024871},{1.569853, 0.391681, -0.024871},{
      1.568982, 0.390810, -0.024871},{1.568422, 0.389712, -0.024871},{
      1.568230, 0.388494, -0.024871},{1.568422, 0.387277, -0.024871},{
      1.568982, 0.386179, -0.024871},{1.569853, 0.385308, -0.024871},{
      1.570951, 0.384748, -0.024871},{1.572169, 0.384555, -0.024871},{
      1.573386, 0.384748, -0.024871},{1.574484, 0.385308, -0.024871},{
      1.575356, 0.386179, -0.024871},{1.575915, 0.387277, -0.024871}}],
    Polygon[{{1.575915, 0.387277, 0.024871},{1.575356, 0.386179, 0.024871},{
      1.574484, 0.385308, 0.024871},{1.573386, 0.384748, 0.024871},{
      1.572169, 0.384555, 0.024871},{1.570951, 0.384748, 0.024871},{
      1.569853, 0.385308, 0.024871},{1.568982, 0.386179, 0.024871},{
      1.568422, 0.387277, 0.024871},{1.568230, 0.388494, 0.024871},{
      1.568422, 0.389712, 0.024871},{1.568982, 0.390810, 0.024871},{
      1.569853, 0.391681, 0.024871},{1.570951, 0.392241, 0.024871},{
      1.572169, 0.392433, 0.024871},{1.573386, 0.392241, 0.024871},{
      1.574484, 0.391681, 0.024871},{1.575356, 0.390810, 0.024871},{
      1.575915, 0.389712, 0.024871},{1.576108, 0.388494, 0.024871}}],
    Polygon[{{1.550059, 0.359563, -0.012292},{1.549964, 0.360165, -0.012292},{
      1.549688, 0.360708, -0.012292},{1.549257, 0.361139, -0.012292},{
      1.548714, 0.361415, -0.012292},{1.548113, 0.361510, -0.012292},{
      1.547511, 0.361415, -0.012292},{1.546968, 0.361139, -0.012292},{
      1.546538, 0.360708, -0.012292},{1.546261, 0.360165, -0.012292},{
      1.546166, 0.359563, -0.012292},{1.546261, 0.358962, -0.012292},{
      1.546538, 0.358419, -0.012292},{1.546968, 0.357989, -0.012292},{
      1.547511, 0.357712, -0.012292},{1.548113, 0.357617, -0.012292},{
      1.548714, 0.357712, -0.012292},{1.549257, 0.357989, -0.012292},{
      1.549688, 0.358419, -0.012292},{1.549964, 0.358962, -0.012292}}],
    Polygon[{{1.549964, 0.358962, 0.012292},{1.549688, 0.358419, 0.012292},{
      1.549257, 0.357989, 0.012292},{1.548714, 0.357712, 0.012292},{
      1.548113, 0.357617, 0.012292},{1.547511, 0.357712, 0.012292},{
      1.546968, 0.357989, 0.012292},{1.546538, 0.358419, 0.012292},{
      1.546261, 0.358962, 0.012292},{1.546166, 0.359563, 0.012292},{
      1.546261, 0.360165, 0.012292},{1.546538, 0.360708, 0.012292},{
      1.546968, 0.361139, 0.012292},{1.547511, 0.361415, 0.012292},{
      1.548113, 0.361510, 0.012292},{1.548714, 0.361415, 0.012292},{
      1.549257, 0.361139, 0.012292},{1.549688, 0.360708, 0.012292},{
      1.549964, 0.360165, 0.012292},{1.550059, 0.359563, 0.012292}}],
    Polygon[{{1.567817, 0.422836, -0.009538},{1.567743, 0.423302, -0.009538},{
      1.567529, 0.423723, -0.009538},{1.567194, 0.424058, -0.009538},{
      1.566773, 0.424272, -0.009538},{1.566306, 0.424346, -0.009538},{
      1.565840, 0.424272, -0.009538},{1.565418, 0.424058, -0.009538},{
      1.565084, 0.423723, -0.009538},{1.564870, 0.423302, -0.009538},{
      1.564796, 0.422836, -0.009538},{1.564870, 0.422369, -0.009538},{
      1.565084, 0.421948, -0.009538},{1.565418, 0.421613, -0.009538},{
      1.565840, 0.421399, -0.009538},{1.566306, 0.421325, -0.009538},{
      1.566773, 0.421399, -0.009538},{1.567194, 0.421613, -0.009538},{
      1.567529, 0.421948, -0.009538},{1.567743, 0.422369, -0.009538}}],
    Polygon[{{1.567743, 0.422369, 0.009538},{1.567529, 0.421948, 0.009538},{
      1.567194, 0.421613, 0.009538},{1.566773, 0.421399, 0.009538},{
      1.566306, 0.421325, 0.009538},{1.565840, 0.421399, 0.009538},{
      1.565418, 0.421613, 0.009538},{1.565084, 0.421948, 0.009538},{
      1.564870, 0.422369, 0.009538},{1.564796, 0.422836, 0.009538},{
      1.564870, 0.423302, 0.009538},{1.565084, 0.423723, 0.009538},{
      1.565418, 0.424058, 0.009538},{1.565840, 0.424272, 0.009538},{
      1.566306, 0.424346, 0.009538},{1.566773, 0.424272, 0.009538},{
      1.567194, 0.424058, 0.009538},{1.567529, 0.423723, 0.009538},{
      1.567743, 0.423302, 0.009538},{1.567817, 0.422836, 0.009538}}],
    Polygon[{{1.607235, 0.384270, -0.008668},{1.607168, 0.384694, -0.008668},{
      1.606973, 0.385077, -0.008668},{1.606669, 0.385381, -0.008668},{
      1.606286, 0.385576, -0.008668},{1.605862, 0.385643, -0.008668},{
      1.605438, 0.385576, -0.008668},{1.605055, 0.385381, -0.008668},{
      1.604751, 0.385077, -0.008668},{1.604556, 0.384694, -0.008668},{
      1.604489, 0.384270, -0.008668},{1.604556, 0.383846, -0.008668},{
      1.604751, 0.383463, -0.008668},{1.605055, 0.383159, -0.008668},{
      1.605438, 0.382964, -0.008668},{1.605862, 0.382897, -0.008668},{
      1.606286, 0.382964, -0.008668},{1.606669, 0.383159, -0.008668},{
      1.606973, 0.383463, -0.008668},{1.607168, 0.383846, -0.008668}}],
    Polygon[{{1.607168, 0.383846, 0.008668},{1.606973, 0.383463, 0.008668},{
      1.606669, 0.383159, 0.008668},{1.606286, 0.382964, 0.008668},{
      1.605862, 0.382897, 0.008668},{1.605438, 0.382964, 0.008668},{
      1.605055, 0.383159, 0.008668},{1.604751, 0.383463, 0.008668},{
      1.604556, 0.383846, 0.008668},{1.604489, 0.384270, 0.008668},{
      1.604556, 0.384694, 0.008668},{1.604751, 0.385077, 0.008668},{
      1.605055, 0.385381, 0.008668},{1.605438, 0.385576, 0.008668},{
      1.605862, 0.385643, 0.008668},{1.606286, 0.385576, 0.008668},{
      1.606669, 0.385381, 0.008668},{1.606973, 0.385077, 0.008668},{
      1.607168, 0.384694, 0.008668},{1.607235, 0.384270, 0.008668}}],
    Polygon[{{1.030106, 1.347151, -0.190081},{1.028632, 1.356454, -0.190081},{
      1.024356, 1.364846, -0.190081},{1.017696, 1.371507, -0.190081},{
      1.009303, 1.375783, -0.190081},{1.000000, 1.377257, -0.190081},{
      0.990697, 1.375783, -0.190081},{0.982304, 1.371507, -0.190081},{
      0.975644, 1.364846, -0.190081},{0.971368, 1.356454, -0.190081},{
      0.969894, 1.347151, -0.190081},{0.971368, 1.337847, -0.190081},{
      0.975644, 1.329455, -0.190081},{0.982304, 1.322795, -0.190081},{
      0.990697, 1.318518, -0.190081},{1.000000, 1.317045, -0.190081},{
      1.009303, 1.318518, -0.190081},{1.017696, 1.322795, -0.190081},{
      1.024356, 1.329455, -0.190081},{1.028632, 1.337847, -0.190081}}],
    Polygon[{{1.028632, 1.337847, 0.190081},{1.024356, 1.329455, 0.190081},{
      1.017696, 1.322795, 0.190081},{1.009303, 1.318518, 0.190081},{
      1.000000, 1.317045, 0.190081},{0.990697, 1.318518, 0.190081},{
      0.982304, 1.322795, 0.190081},{0.975644, 1.329455, 0.190081},{
      0.971368, 1.337847, 0.190081},{0.969894, 1.347151, 0.190081},{
      0.971368, 1.356454, 0.190081},{0.975644, 1.364846, 0.190081},{
      0.982304, 1.371507, 0.190081},{0.990697, 1.375783, 0.190081},{
      1.000000, 1.377257, 0.190081},{1.009303, 1.375783, 0.190081},{
      1.017696, 1.371507, 0.190081},{1.024356, 1.364846, 0.190081},{
      1.028632, 1.356454, 0.190081},{1.030106, 1.347151, 0.190081}}],
    Polygon[{{1.010035, 1.603751, -0.063360},{1.009544, 1.606852, -0.063360},{
      1.008119, 1.609649, -0.063360},{1.005899, 1.611869, -0.063360},{
      1.003101, 1.613295, -0.063360},{1.000000, 1.613786, -0.063360},{
      0.996899, 1.613295, -0.063360},{0.994101, 1.611869, -0.063360},{
      0.991881, 1.609649, -0.063360},{0.990456, 1.606852, -0.063360},{
      0.989965, 1.603751, -0.063360},{0.990456, 1.600650, -0.063360},{
      0.991881, 1.597852, -0.063360},{0.994101, 1.595632, -0.063360},{
      0.996899, 1.594207, -0.063360},{1.000000, 1.593715, -0.063360},{
      1.003101, 1.594207, -0.063360},{1.005899, 1.595632, -0.063360},{
      1.008119, 1.597852, -0.063360},{1.009544, 1.600650, -0.063360}}],
    Polygon[{{1.009544, 1.600650, 0.063360},{1.008119, 1.597852, 0.063360},{
      1.005899, 1.595632, 0.063360},{1.003101, 1.594207, 0.063360},{
      1.000000, 1.593715, 0.063360},{0.996899, 1.594207, 0.063360},{
      0.994101, 1.595632, 0.063360},{0.991881, 1.597852, 0.063360},{
      0.990456, 1.600650, 0.063360},{0.989965, 1.603751, 0.063360},{
      0.990456, 1.606852, 0.063360},{0.991881, 1.609649, 0.063360},{
      0.994101, 1.611869, 0.063360},{0.996899, 1.613295, 0.063360},{
      1.000000, 1.613786, 0.063360},{1.003101, 1.613295, 0.063360},{
      1.005899, 1.611869, 0.063360},{1.008119, 1.609649, 0.063360},{
      1.009544, 1.606852, 0.063360},{1.010035, 1.603751, 0.063360}}],
    Polygon[{{1.003345, 1.689284, -0.021120},{1.003181, 1.690318, -0.021120},{
      1.002706, 1.691250, -0.021120},{1.001966, 1.691990, -0.021120},{
      1.001034, 1.692466, -0.021120},{1.000000, 1.692629, -0.021120},{
      0.998966, 1.692466, -0.021120},{0.998034, 1.691990, -0.021120},{
      0.997294, 1.691250, -0.021120},{0.996819, 1.690318, -0.021120},{
      0.996655, 1.689284, -0.021120},{0.996819, 1.688250, -0.021120},{
      0.997294, 1.687318, -0.021120},{0.998034, 1.686578, -0.021120},{
      0.998966, 1.686103, -0.021120},{1.000000, 1.685939, -0.021120},{
      1.001034, 1.686103, -0.021120},{1.001966, 1.686578, -0.021120},{
      1.002706, 1.687318, -0.021120},{1.003181, 1.688250, -0.021120}}],
    Polygon[{{1.003181, 1.688250, 0.021120},{1.002706, 1.687318, 0.021120},{
      1.001966, 1.686578, 0.021120},{1.001034, 1.686103, 0.021120},{
      1.000000, 1.685939, 0.021120},{0.998966, 1.686103, 0.021120},{
      0.998034, 1.686578, 0.021120},{0.997294, 1.687318, 0.021120},{
      0.996819, 1.688250, 0.021120},{0.996655, 1.689284, 0.021120},{
      0.996819, 1.690318, 0.021120},{0.997294, 1.691250, 0.021120},{
      0.998034, 1.691990, 0.021120},{0.998966, 1.692466, 0.021120},{
      1.000000, 1.692629, 0.021120},{1.001034, 1.692466, 0.021120},{
      1.001966, 1.691990, 0.021120},{1.002706, 1.691250, 0.021120},{
      1.003181, 1.690318, 0.021120},{1.003345, 1.689284, 0.021120}}],
    Polygon[{{1.001115, 1.717795, -0.007040},{1.001060, 1.718140, -0.007040},{
      1.000902, 1.718451, -0.007040},{1.000655, 1.718697, -0.007040},{
      1.000345, 1.718856, -0.007040},{1.000000, 1.718910, -0.007040},{
      0.999655, 1.718856, -0.007040},{0.999345, 1.718697, -0.007040},{
      0.999098, 1.718451, -0.007040},{0.998940, 1.718140, -0.007040},{
      0.998885, 1.717795, -0.007040},{0.998940, 1.717451, -0.007040},{
      0.999098, 1.717140, -0.007040},{0.999345, 1.716893, -0.007040},{
      0.999655, 1.716735, -0.007040},{1.000000, 1.716680, -0.007040},{
      1.000345, 1.716735, -0.007040},{1.000655, 1.716893, -0.007040},{
      1.000902, 1.717140, -0.007040},{1.001060, 1.717451, -0.007040}}],
    Polygon[{{1.001060, 1.717451, 0.007040},{1.000902, 1.717140, 0.007040},{
      1.000655, 1.716893, 0.007040},{1.000345, 1.716735, 0.007040},{
      1.000000, 1.716680, 0.007040},{0.999655, 1.716735, 0.007040},{
      0.999345, 1.716893, 0.007040},{0.999098, 1.717140, 0.007040},{
      0.998940, 1.717451, 0.007040},{0.998885, 1.717795, 0.007040},{
      0.998940, 1.718140, 0.007040},{0.999098, 1.718451, 0.007040},{
      0.999345, 1.718697, 0.007040},{0.999655, 1.718856, 0.007040},{
      1.000000, 1.718910, 0.007040},{1.000345, 1.718856, 0.007040},{
      1.000655, 1.718697, 0.007040},{1.000902, 1.718451, 0.007040},{
      1.001060, 1.718140, 0.007040},{1.001115, 1.717795, 0.007040}}],
    Polygon[{{0.976712, 1.672198, -0.008489},{0.976647, 1.672614, -0.008489},{
      0.976456, 1.672988, -0.008489},{0.976158, 1.673286, -0.008489},{
      0.975783, 1.673477, -0.008489},{0.975368, 1.673542, -0.008489},{
      0.974953, 1.673477, -0.008489},{0.974578, 1.673286, -0.008489},{
      0.974280, 1.672988, -0.008489},{0.974089, 1.672614, -0.008489},{
      0.974024, 1.672198, -0.008489},{0.974089, 1.671782, -0.008489},{
      0.974280, 1.671408, -0.008489},{0.974578, 1.671110, -0.008489},{
      0.974953, 1.670919, -0.008489},{0.975368, 1.670853, -0.008489},{
      0.975783, 1.670919, -0.008489},{0.976158, 1.671110, -0.008489},{
      0.976456, 1.671408, -0.008489},{0.976647, 1.671782, -0.008489}}],
    Polygon[{{0.976647, 1.671782, 0.008489},{0.976456, 1.671408, 0.008489},{
      0.976158, 1.671110, 0.008489},{0.975783, 1.670919, 0.008489},{
      0.975368, 1.670853, 0.008489},{0.974953, 1.670919, 0.008489},{
      0.974578, 1.671110, 0.008489},{0.974280, 1.671408, 0.008489},{
      0.974089, 1.671782, 0.008489},{0.974024, 1.672198, 0.008489},{
      0.974089, 1.672614, 0.008489},{0.974280, 1.672988, 0.008489},{
      0.974578, 1.673286, 0.008489},{0.974953, 1.673477, 0.008489},{
      0.975368, 1.673542, 0.008489},{0.975783, 1.673477, 0.008489},{
      0.976158, 1.673286, 0.008489},{0.976456, 1.672988, 0.008489},{
      0.976647, 1.672614, 0.008489},{0.976712, 1.672198, 0.008489}}],
    Polygon[{{1.025976, 1.672198, -0.008489},{1.025911, 1.672614, -0.008489},{
      1.025720, 1.672988, -0.008489},{1.025422, 1.673286, -0.008489},{
      1.025047, 1.673477, -0.008489},{1.024632, 1.673542, -0.008489},{
      1.024217, 1.673477, -0.008489},{1.023842, 1.673286, -0.008489},{
      1.023544, 1.672988, -0.008489},{1.023353, 1.672614, -0.008489},{
      1.023288, 1.672198, -0.008489},{1.023353, 1.671782, -0.008489},{
      1.023544, 1.671408, -0.008489},{1.023842, 1.671110, -0.008489},{
      1.024217, 1.670919, -0.008489},{1.024632, 1.670853, -0.008489},{
      1.025047, 1.670919, -0.008489},{1.025422, 1.671110, -0.008489},{
      1.025720, 1.671408, -0.008489},{1.025911, 1.671782, -0.008489}}],
    Polygon[{{1.025911, 1.671782, 0.008489},{1.025720, 1.671408, 0.008489},{
      1.025422, 1.671110, 0.008489},{1.025047, 1.670919, 0.008489},{
      1.024632, 1.670853, 0.008489},{1.024217, 1.670919, 0.008489},{
      1.023842, 1.671110, 0.008489},{1.023544, 1.671408, 0.008489},{
      1.023353, 1.671782, 0.008489},{1.023288, 1.672198, 0.008489},{
      1.023353, 1.672614, 0.008489},{1.023544, 1.672988, 0.008489},{
      1.023842, 1.673286, 0.008489},{1.024217, 1.673477, 0.008489},{
      1.024632, 1.673542, 0.008489},{1.025047, 1.673477, 0.008489},{
      1.025422, 1.673286, 0.008489},{1.025720, 1.672988, 0.008489},{
      1.025911, 1.672614, 0.008489},{1.025976, 1.672198, 0.008489}}],
    Polygon[{{0.930137, 1.552492, -0.025466},{0.929940, 1.553739, -0.025466},{
      0.929367, 1.554863, -0.025466},{0.928475, 1.555755, -0.025466},{
      0.927350, 1.556328, -0.025466},{0.926104, 1.556526, -0.025466},{
      0.924858, 1.556328, -0.025466},{0.923733, 1.555755, -0.025466},{
      0.922841, 1.554863, -0.025466},{0.922268, 1.553739, -0.025466},{
      0.922071, 1.552492, -0.025466},{0.922268, 1.551246, -0.025466},{
      0.922841, 1.550122, -0.025466},{0.923733, 1.549229, -0.025466},{
      0.924858, 1.548656, -0.025466},{0.926104, 1.548459, -0.025466},{
      0.927350, 1.548656, -0.025466},{0.928475, 1.549229, -0.025466},{
      0.929367, 1.550122, -0.025466},{0.929940, 1.551246, -0.025466}}],
    Polygon[{{0.929940, 1.551246, 0.025466},{0.929367, 1.550122, 0.025466},{
      0.928475, 1.549229, 0.025466},{0.927350, 1.548656, 0.025466},{
      0.926104, 1.548459, 0.025466},{0.924858, 1.548656, 0.025466},{
      0.923733, 1.549229, 0.025466},{0.922841, 1.550122, 0.025466},{
      0.922268, 1.551246, 0.025466},{0.922071, 1.552492, 0.025466},{
      0.922268, 1.553739, 0.025466},{0.922841, 1.554863, 0.025466},{
      0.923733, 1.555755, 0.025466},{0.924858, 1.556328, 0.025466},{
      0.926104, 1.556526, 0.025466},{0.927350, 1.556328, 0.025466},{
      0.928475, 1.555755, 0.025466},{0.929367, 1.554863, 0.025466},{
      0.929940, 1.553739, 0.025466},{0.930137, 1.552492, 0.025466}}],
    Polygon[{{0.899028, 1.525783, -0.013647},{0.898922, 1.526451, -0.013647},{
      0.898615, 1.527054, -0.013647},{0.898137, 1.527532, -0.013647},{
      0.897534, 1.527839, -0.013647},{0.896866, 1.527945, -0.013647},{
      0.896198, 1.527839, -0.013647},{0.895596, 1.527532, -0.013647},{
      0.895118, 1.527054, -0.013647},{0.894811, 1.526451, -0.013647},{
      0.894705, 1.525783, -0.013647},{0.894811, 1.525115, -0.013647},{
      0.895118, 1.524513, -0.013647},{0.895596, 1.524035, -0.013647},{
      0.896198, 1.523728, -0.013647},{0.896866, 1.523622, -0.013647},{
      0.897534, 1.523728, -0.013647},{0.898137, 1.524035, -0.013647},{
      0.898615, 1.524513, -0.013647},{0.898922, 1.525115, -0.013647}}],
    Polygon[{{0.898922, 1.525115, 0.013647},{0.898615, 1.524513, 0.013647},{
      0.898137, 1.524035, 0.013647},{0.897534, 1.523728, 0.013647},{
      0.896866, 1.523622, 0.013647},{0.896198, 1.523728, 0.013647},{
      0.895596, 1.524035, 0.013647},{0.895118, 1.524513, 0.013647},{
      0.894811, 1.525115, 0.013647},{0.894705, 1.525783, 0.013647},{
      0.894811, 1.526451, 0.013647},{0.895118, 1.527054, 0.013647},{
      0.895596, 1.527532, 0.013647},{0.896198, 1.527839, 0.013647},{
      0.896866, 1.527945, 0.013647},{0.897534, 1.527839, 0.013647},{
      0.898137, 1.527532, 0.013647},{0.898615, 1.527054, 0.013647},{
      0.898922, 1.526451, 0.013647},{0.899028, 1.525783, 0.013647}}],
    Polygon[{{0.929429, 1.587887, -0.009538},{0.929355, 1.588353, -0.009538},{
      0.929140, 1.588775, -0.009538},{0.928806, 1.589109, -0.009538},{
      0.928385, 1.589323, -0.009538},{0.927918, 1.589397, -0.009538},{
      0.927451, 1.589323, -0.009538},{0.927030, 1.589109, -0.009538},{
      0.926696, 1.588775, -0.009538},{0.926481, 1.588353, -0.009538},{
      0.926407, 1.587887, -0.009538},{0.926481, 1.587420, -0.009538},{
      0.926696, 1.586999, -0.009538},{0.927030, 1.586664, -0.009538},{
      0.927451, 1.586450, -0.009538},{0.927918, 1.586376, -0.009538},{
      0.928385, 1.586450, -0.009538},{0.928806, 1.586664, -0.009538},{
      0.929140, 1.586999, -0.009538},{0.929355, 1.587420, -0.009538}}],
    Polygon[{{0.929355, 1.587420, 0.009538},{0.929140, 1.586999, 0.009538},{
      0.928806, 1.586664, 0.009538},{0.928385, 1.586450, 0.009538},{
      0.927918, 1.586376, 0.009538},{0.927451, 1.586450, 0.009538},{
      0.927030, 1.586664, 0.009538},{0.926696, 1.586999, 0.009538},{
      0.926481, 1.587420, 0.009538},{0.926407, 1.587887, 0.009538},{
      0.926481, 1.588353, 0.009538},{0.926696, 1.588775, 0.009538},{
      0.927030, 1.589109, 0.009538},{0.927451, 1.589323, 0.009538},{
      0.927918, 1.589397, 0.009538},{0.928385, 1.589323, 0.009538},{
      0.928806, 1.589109, 0.009538},{0.929140, 1.588775, 0.009538},{
      0.929355, 1.588353, 0.009538},{0.929429, 1.587887, 0.009538}}],
    Polygon[{{0.960470, 1.543797, -0.008290},{0.960405, 1.544203, -0.008290},{
      0.960219, 1.544569, -0.008290},{0.959928, 1.544860, -0.008290},{
      0.959562, 1.545046, -0.008290},{0.959157, 1.545111, -0.008290},{
      0.958751, 1.545046, -0.008290},{0.958385, 1.544860, -0.008290},{
      0.958094, 1.544569, -0.008290},{0.957908, 1.544203, -0.008290},{
      0.957843, 1.543797, -0.008290},{0.957908, 1.543392, -0.008290},{
      0.958094, 1.543026, -0.008290},{0.958385, 1.542735, -0.008290},{
      0.958751, 1.542549, -0.008290},{0.959157, 1.542485, -0.008290},{
      0.959562, 1.542549, -0.008290},{0.959928, 1.542735, -0.008290},{
      0.960219, 1.543026, -0.008290},{0.960405, 1.543392, -0.008290}}],
    Polygon[{{0.960405, 1.543392, 0.008290},{0.960219, 1.543026, 0.008290},{
      0.959928, 1.542735, 0.008290},{0.959562, 1.542549, 0.008290},{
      0.959157, 1.542485, 0.008290},{0.958751, 1.542549, 0.008290},{
      0.958385, 1.542735, 0.008290},{0.958094, 1.543026, 0.008290},{
      0.957908, 1.543392, 0.008290},{0.957843, 1.543797, 0.008290},{
      0.957908, 1.544203, 0.008290},{0.958094, 1.544569, 0.008290},{
      0.958385, 1.544860, 0.008290},{0.958751, 1.545046, 0.008290},{
      0.959157, 1.545111, 0.008290},{0.959562, 1.545046, 0.008290},{
      0.959928, 1.544860, 0.008290},{0.960219, 1.544569, 0.008290},{
      0.960405, 1.544203, 0.008290},{0.960470, 1.543797, 0.008290}}],
    Polygon[{{1.077929, 1.552492, -0.025466},{1.077732, 1.553739, -0.025466},{
      1.077159, 1.554863, -0.025466},{1.076267, 1.555755, -0.025466},{
      1.075142, 1.556328, -0.025466},{1.073896, 1.556526, -0.025466},{
      1.072650, 1.556328, -0.025466},{1.071525, 1.555755, -0.025466},{
      1.070633, 1.554863, -0.025466},{1.070060, 1.553739, -0.025466},{
      1.069862, 1.552492, -0.025466},{1.070060, 1.551246, -0.025466},{
      1.070633, 1.550122, -0.025466},{1.071525, 1.549229, -0.025466},{
      1.072650, 1.548656, -0.025466},{1.073896, 1.548459, -0.025466},{
      1.075142, 1.548656, -0.025466},{1.076267, 1.549229, -0.025466},{
      1.077159, 1.550122, -0.025466},{1.077732, 1.551246, -0.025466}}],
    Polygon[{{1.077732, 1.551246, 0.025466},{1.077159, 1.550122, 0.025466},{
      1.076267, 1.549229, 0.025466},{1.075142, 1.548656, 0.025466},{
      1.073896, 1.548459, 0.025466},{1.072650, 1.548656, 0.025466},{
      1.071525, 1.549229, 0.025466},{1.070633, 1.550122, 0.025466},{
      1.070060, 1.551246, 0.025466},{1.069862, 1.552492, 0.025466},{
      1.070060, 1.553739, 0.025466},{1.070633, 1.554863, 0.025466},{
      1.071525, 1.555755, 0.025466},{1.072650, 1.556328, 0.025466},{
      1.073896, 1.556526, 0.025466},{1.075142, 1.556328, 0.025466},{
      1.076267, 1.555755, 0.025466},{1.077159, 1.554863, 0.025466},{
      1.077732, 1.553739, 0.025466},{1.077929, 1.552492, 0.025466}}],
    Polygon[{{1.105295, 1.525783, -0.013647},{1.105189, 1.526451, -0.013647},{
      1.104882, 1.527054, -0.013647},{1.104404, 1.527532, -0.013647},{
      1.103802, 1.527839, -0.013647},{1.103134, 1.527945, -0.013647},{
      1.102466, 1.527839, -0.013647},{1.101863, 1.527532, -0.013647},{
      1.101385, 1.527054, -0.013647},{1.101078, 1.526451, -0.013647},{
      1.100972, 1.525783, -0.013647},{1.101078, 1.525115, -0.013647},{
      1.101385, 1.524513, -0.013647},{1.101863, 1.524035, -0.013647},{
      1.102466, 1.523728, -0.013647},{1.103134, 1.523622, -0.013647},{
      1.103802, 1.523728, -0.013647},{1.104404, 1.524035, -0.013647},{
      1.104882, 1.524513, -0.013647},{1.105189, 1.525115, -0.013647}}],
    Polygon[{{1.105189, 1.525115, 0.013647},{1.104882, 1.524513, 0.013647},{
      1.104404, 1.524035, 0.013647},{1.103802, 1.523728, 0.013647},{
      1.103134, 1.523622, 0.013647},{1.102466, 1.523728, 0.013647},{
      1.101863, 1.524035, 0.013647},{1.101385, 1.524513, 0.013647},{
      1.101078, 1.525115, 0.013647},{1.100972, 1.525783, 0.013647},{
      1.101078, 1.526451, 0.013647},{1.101385, 1.527054, 0.013647},{
      1.101863, 1.527532, 0.013647},{1.102466, 1.527839, 0.013647},{
      1.103134, 1.527945, 0.013647},{1.103802, 1.527839, 0.013647},{
      1.104404, 1.527532, 0.013647},{1.104882, 1.527054, 0.013647},{
      1.105189, 1.526451, 0.013647},{1.105295, 1.525783, 0.013647}}],
    Polygon[{{1.073593, 1.587887, -0.009538},{1.073519, 1.588353, -0.009538},{
      1.073304, 1.588775, -0.009538},{1.072970, 1.589109, -0.009538},{
      1.072549, 1.589323, -0.009538},{1.072082, 1.589397, -0.009538},{
      1.071615, 1.589323, -0.009538},{1.071194, 1.589109, -0.009538},{
      1.070860, 1.588775, -0.009538},{1.070645, 1.588353, -0.009538},{
      1.070571, 1.587887, -0.009538},{1.070645, 1.587420, -0.009538},{
      1.070860, 1.586999, -0.009538},{1.071194, 1.586664, -0.009538},{
      1.071615, 1.586450, -0.009538},{1.072082, 1.586376, -0.009538},{
      1.072549, 1.586450, -0.009538},{1.072970, 1.586664, -0.009538},{
      1.073304, 1.586999, -0.009538},{1.073519, 1.587420, -0.009538}}],
    Polygon[{{1.073519, 1.587420, 0.009538},{1.073304, 1.586999, 0.009538},{
      1.072970, 1.586664, 0.009538},{1.072549, 1.586450, 0.009538},{
      1.072082, 1.586376, 0.009538},{1.071615, 1.586450, 0.009538},{
      1.071194, 1.586664, 0.009538},{1.070860, 1.586999, 0.009538},{
      1.070645, 1.587420, 0.009538},{1.070571, 1.587887, 0.009538},{
      1.070645, 1.588353, 0.009538},{1.070860, 1.588775, 0.009538},{
      1.071194, 1.589109, 0.009538},{1.071615, 1.589323, 0.009538},{
      1.072082, 1.589397, 0.009538},{1.072549, 1.589323, 0.009538},{
      1.072970, 1.589109, 0.009538},{1.073304, 1.588775, 0.009538},{
      1.073519, 1.588353, 0.009538},{1.073593, 1.587887, 0.009538}}],
    Polygon[{{1.042156, 1.543797, -0.008290},{1.042092, 1.544203, -0.008290},{
      1.041906, 1.544569, -0.008290},{1.041615, 1.544860, -0.008290},{
      1.041249, 1.545046, -0.008290},{1.040843, 1.545111, -0.008290},{
      1.040438, 1.545046, -0.008290},{1.040072, 1.544860, -0.008290},{
      1.039781, 1.544569, -0.008290},{1.039595, 1.544203, -0.008290},{
      1.039530, 1.543797, -0.008290},{1.039595, 1.543392, -0.008290},{
      1.039781, 1.543026, -0.008290},{1.040072, 1.542735, -0.008290},{
      1.040438, 1.542549, -0.008290},{1.040843, 1.542485, -0.008290},{
      1.041249, 1.542549, -0.008290},{1.041615, 1.542735, -0.008290},{
      1.041906, 1.543026, -0.008290},{1.042092, 1.543392, -0.008290}}],
    Polygon[{{1.042092, 1.543392, 0.008290},{1.041906, 1.543026, 0.008290},{
      1.041615, 1.542735, 0.008290},{1.041249, 1.542549, 0.008290},{
      1.040843, 1.542485, 0.008290},{1.040438, 1.542549, 0.008290},{
      1.040072, 1.542735, 0.008290},{1.039781, 1.543026, 0.008290},{
      1.039595, 1.543392, 0.008290},{1.039530, 1.543797, 0.008290},{
      1.039595, 1.544203, 0.008290},{1.039781, 1.544569, 0.008290},{
      1.040072, 1.544860, 0.008290},{1.040438, 1.545046, 0.008290},{
      1.040843, 1.545111, 0.008290},{1.041249, 1.545046, 0.008290},{
      1.041615, 1.544860, 0.008290},{1.041906, 1.544569, 0.008290},{
      1.042092, 1.544203, 0.008290},{1.042156, 1.543797, 0.008290}}],
    Polygon[{{0.790412, 1.193376, -0.076398},{0.789820, 1.197115, -0.076398},{
      0.788101, 1.200488, -0.076398},{0.785425, 1.203165, -0.076398},{
      0.782051, 1.204884, -0.076398},{0.778312, 1.205476, -0.076398},{
      0.774573, 1.204884, -0.076398},{0.771200, 1.203165, -0.076398},{
      0.768523, 1.200488, -0.076398},{0.766804, 1.197115, -0.076398},{
      0.766212, 1.193376, -0.076398},{0.766804, 1.189636, -0.076398},{
      0.768523, 1.186263, -0.076398},{0.771200, 1.183586, -0.076398},{
      0.774573, 1.181868, -0.076398},{0.778312, 1.181275, -0.076398},{
      0.782051, 1.181868, -0.076398},{0.785425, 1.183586, -0.076398},{
      0.788101, 1.186263, -0.076398},{0.789820, 1.189636, -0.076398}}],
    Polygon[{{0.789820, 1.189636, 0.076398},{0.788101, 1.186263, 0.076398},{
      0.785425, 1.183586, 0.076398},{0.782051, 1.181868, 0.076398},{
      0.778312, 1.181275, 0.076398},{0.774573, 1.181868, 0.076398},{
      0.771200, 1.183586, 0.076398},{0.768523, 1.186263, 0.076398},{
      0.766804, 1.189636, 0.076398},{0.766212, 1.193376, 0.076398},{
      0.766804, 1.197115, 0.076398},{0.768523, 1.200488, 0.076398},{
      0.771200, 1.203165, 0.076398},{0.774573, 1.204884, 0.076398},{
      0.778312, 1.205476, 0.076398},{0.782051, 1.204884, 0.076398},{
      0.785425, 1.203165, 0.076398},{0.788101, 1.200488, 0.076398},{
      0.789820, 1.197115, 0.076398},{0.790412, 1.193376, 0.076398}}],
    Polygon[{{0.697083, 1.113249, -0.040942},{0.696766, 1.115252, -0.040942},{
      0.695845, 1.117060, -0.040942},{0.694410, 1.118495, -0.040942},{
      0.692603, 1.119416, -0.040942},{0.690599, 1.119733, -0.040942},{
      0.688595, 1.119416, -0.040942},{0.686787, 1.118495, -0.040942},{
      0.685353, 1.117060, -0.040942},{0.684432, 1.115252, -0.040942},{
      0.684114, 1.113249, -0.040942},{0.684432, 1.111245, -0.040942},{
      0.685353, 1.109437, -0.040942},{0.686787, 1.108003, -0.040942},{
      0.688595, 1.107082, -0.040942},{0.690599, 1.106764, -0.040942},{
      0.692603, 1.107082, -0.040942},{0.694410, 1.108003, -0.040942},{
      0.695845, 1.109437, -0.040942},{0.696766, 1.111245, -0.040942}}],
    Polygon[{{0.696766, 1.111245, 0.040942},{0.695845, 1.109437, 0.040942},{
      0.694410, 1.108003, 0.040942},{0.692603, 1.107082, 0.040942},{
      0.690599, 1.106764, 0.040942},{0.688595, 1.107082, 0.040942},{
      0.686787, 1.108003, 0.040942},{0.685353, 1.109437, 0.040942},{
      0.684432, 1.111245, 0.040942},{0.684114, 1.113249, 0.040942},{
      0.684432, 1.115252, 0.040942},{0.685353, 1.117060, 0.040942},{
      0.686787, 1.118495, 0.040942},{0.688595, 1.119416, 0.040942},{
      0.690599, 1.119733, 0.040942},{0.692603, 1.119416, 0.040942},{
      0.694410, 1.118495, 0.040942},{0.695845, 1.117060, 0.040942},{
      0.696766, 1.115252, 0.040942},{0.697083, 1.113249, 0.040942}}],
    Polygon[{{0.648371, 1.064459, -0.025466},{0.648174, 1.065705, -0.025466},{
      0.647601, 1.066829, -0.025466},{0.646708, 1.067722, -0.025466},{
      0.645584, 1.068295, -0.025466},{0.644338, 1.068492, -0.025466},{
      0.643091, 1.068295, -0.025466},{0.641967, 1.067722, -0.025466},{
      0.641074, 1.066829, -0.025466},{0.640502, 1.065705, -0.025466},{
      0.640304, 1.064459, -0.025466},{0.640502, 1.063212, -0.025466},{
      0.641074, 1.062088, -0.025466},{0.641967, 1.061195, -0.025466},{
      0.643091, 1.060623, -0.025466},{0.644338, 1.060425, -0.025466},{
      0.645584, 1.060623, -0.025466},{0.646708, 1.061195, -0.025466},{
      0.647601, 1.062088, -0.025466},{0.648174, 1.063212, -0.025466}}],
    Polygon[{{0.648174, 1.063212, 0.025466},{0.647601, 1.062088, 0.025466},{
      0.646708, 1.061195, 0.025466},{0.645584, 1.060623, 0.025466},{
      0.644338, 1.060425, 0.025466},{0.643091, 1.060623, 0.025466},{
      0.641967, 1.061195, 0.025466},{0.641074, 1.062088, 0.025466},{
      0.640502, 1.063212, 0.025466},{0.640304, 1.064459, 0.025466},{
      0.640502, 1.065705, 0.025466},{0.641074, 1.066829, 0.025466},{
      0.641967, 1.067722, 0.025466},{0.643091, 1.068295, 0.025466},{
      0.644338, 1.068492, 0.025466},{0.645584, 1.068295, 0.025466},{
      0.646708, 1.067722, 0.025466},{0.647601, 1.066829, 0.025466},{
      0.648174, 1.065705, 0.025466},{0.648371, 1.064459, 0.025466}}],
    Polygon[{{0.692760, 1.168518, -0.013647},{0.692655, 1.169186, -0.013647},{
      0.692348, 1.169788, -0.013647},{0.691869, 1.170267, -0.013647},{
      0.691267, 1.170574, -0.013647},{0.690599, 1.170679, -0.013647},{
      0.689931, 1.170574, -0.013647},{0.689328, 1.170267, -0.013647},{
      0.688850, 1.169788, -0.013647},{0.688543, 1.169186, -0.013647},{
      0.688437, 1.168518, -0.013647},{0.688543, 1.167850, -0.013647},{
      0.688850, 1.167247, -0.013647},{0.689328, 1.166769, -0.013647},{
      0.689931, 1.166462, -0.013647},{0.690599, 1.166356, -0.013647},{
      0.691267, 1.166462, -0.013647},{0.691869, 1.166769, -0.013647},{
      0.692348, 1.167247, -0.013647},{0.692655, 1.167850, -0.013647}}],
    Polygon[{{0.692655, 1.167850, 0.013647},{0.692348, 1.167247, 0.013647},{
      0.691869, 1.166769, 0.013647},{0.691267, 1.166462, 0.013647},{
      0.690599, 1.166356, 0.013647},{0.689931, 1.166462, 0.013647},{
      0.689328, 1.166769, 0.013647},{0.688850, 1.167247, 0.013647},{
      0.688543, 1.167850, 0.013647},{0.688437, 1.168518, 0.013647},{
      0.688543, 1.169186, 0.013647},{0.688850, 1.169788, 0.013647},{
      0.689328, 1.170267, 0.013647},{0.689931, 1.170574, 0.013647},{
      0.690599, 1.170679, 0.013647},{0.691267, 1.170574, 0.013647},{
      0.691869, 1.170267, 0.013647},{0.692348, 1.169788, 0.013647},{
      0.692655, 1.169186, 0.013647},{0.692760, 1.168518, 0.013647}}],
    Polygon[{{0.746835, 1.109580, -0.012733},{0.746737, 1.110203, -0.012733},{
      0.746450, 1.110765, -0.012733},{0.746004, 1.111211, -0.012733},{
      0.745442, 1.111498, -0.012733},{0.744819, 1.111596, -0.012733},{
      0.744195, 1.111498, -0.012733},{0.743633, 1.111211, -0.012733},{
      0.743187, 1.110765, -0.012733},{0.742900, 1.110203, -0.012733},{
      0.742802, 1.109580, -0.012733},{0.742900, 1.108956, -0.012733},{
      0.743187, 1.108394, -0.012733},{0.743633, 1.107948, -0.012733},{
      0.744195, 1.107661, -0.012733},{0.744819, 1.107563, -0.012733},{
      0.745442, 1.107661, -0.012733},{0.746004, 1.107948, -0.012733},{
      0.746450, 1.108394, -0.012733},{0.746737, 1.108956, -0.012733}}],
    Polygon[{{0.746737, 1.108956, 0.012733},{0.746450, 1.108394, 0.012733},{
      0.746004, 1.107948, 0.012733},{0.745442, 1.107661, 0.012733},{
      0.744819, 1.107563, 0.012733},{0.744195, 1.107661, 0.012733},{
      0.743633, 1.107948, 0.012733},{0.743187, 1.108394, 0.012733},{
      0.742900, 1.108956, 0.012733},{0.742802, 1.109580, 0.012733},{
      0.742900, 1.110203, 0.012733},{0.743187, 1.110765, 0.012733},{
      0.743633, 1.111211, 0.012733},{0.744195, 1.111498, 0.012733},{
      0.744819, 1.111596, 0.012733},{0.745442, 1.111498, 0.012733},{
      0.746004, 1.111211, 0.012733},{0.746450, 1.110765, 0.012733},{
      0.746737, 1.110203, 0.012733},{0.746835, 1.109580, 0.012733}}],
    Polygon[{{0.788286, 1.299558, -0.028615},{0.788064, 1.300959, -0.028615},{
      0.787420, 1.302222, -0.028615},{0.786418, 1.303225, -0.028615},{
      0.785154, 1.303868, -0.028615},{0.783754, 1.304090, -0.028615},{
      0.782353, 1.303868, -0.028615},{0.781090, 1.303225, -0.028615},{
      0.780087, 1.302222, -0.028615},{0.779443, 1.300959, -0.028615},{
      0.779222, 1.299558, -0.028615},{0.779443, 1.298158, -0.028615},{
      0.780087, 1.296894, -0.028615},{0.781090, 1.295892, -0.028615},{
      0.782353, 1.295248, -0.028615},{0.783754, 1.295026, -0.028615},{
      0.785154, 1.295248, -0.028615},{0.786418, 1.295892, -0.028615},{
      0.787420, 1.296894, -0.028615},{0.788064, 1.298158, -0.028615}}],
    Polygon[{{0.788064, 1.298158, 0.028615},{0.787420, 1.296894, 0.028615},{
      0.786418, 1.295892, 0.028615},{0.785154, 1.295248, 0.028615},{
      0.783754, 1.295026, 0.028615},{0.782353, 1.295248, 0.028615},{
      0.781090, 1.295892, 0.028615},{0.780087, 1.296894, 0.028615},{
      0.779443, 1.298158, 0.028615},{0.779222, 1.299558, 0.028615},{
      0.779443, 1.300959, 0.028615},{0.780087, 1.302222, 0.028615},{
      0.781090, 1.303225, 0.028615},{0.782353, 1.303868, 0.028615},{
      0.783754, 1.304090, 0.028615},{0.785154, 1.303868, 0.028615},{
      0.786418, 1.303225, 0.028615},{0.787420, 1.302222, 0.028615},{
      0.788064, 1.300959, 0.028615},{0.788286, 1.299558, 0.028615}}],
    Polygon[{{0.794912, 1.342678, -0.014853},{0.794797, 1.343405, -0.014853},{
      0.794463, 1.344061, -0.014853},{0.793943, 1.344581, -0.014853},{
      0.793287, 1.344915, -0.014853},{0.792560, 1.345030, -0.014853},{
      0.791833, 1.344915, -0.014853},{0.791177, 1.344581, -0.014853},{
      0.790657, 1.344061, -0.014853},{0.790323, 1.343405, -0.014853},{
      0.790207, 1.342678, -0.014853},{0.790323, 1.341951, -0.014853},{
      0.790657, 1.341295, -0.014853},{0.791177, 1.340775, -0.014853},{
      0.791833, 1.340440, -0.014853},{0.792560, 1.340325, -0.014853},{
      0.793287, 1.340440, -0.014853},{0.793943, 1.340775, -0.014853},{
      0.794463, 1.341295, -0.014853},{0.794797, 1.341951, -0.014853}}],
    Polygon[{{0.794797, 1.341951, 0.014853},{0.794463, 1.341295, 0.014853},{
      0.793943, 1.340775, 0.014853},{0.793287, 1.340440, 0.014853},{
      0.792560, 1.340325, 0.014853},{0.791833, 1.340440, 0.014853},{
      0.791177, 1.340775, 0.014853},{0.790657, 1.341295, 0.014853},{
      0.790323, 1.341951, 0.014853},{0.790207, 1.342678, 0.014853},{
      0.790323, 1.343405, 0.014853},{0.790657, 1.344061, 0.014853},{
      0.791177, 1.344581, 0.014853},{0.791833, 1.344915, 0.014853},{
      0.792560, 1.345030, 0.014853},{0.793287, 1.344915, 0.014853},{
      0.793943, 1.344581, 0.014853},{0.794463, 1.344061, 0.014853},{
      0.794797, 1.343405, 0.014853},{0.794912, 1.342678, 0.014853}}],
    Polygon[{{0.752091, 1.277340, -0.011012},{0.752005, 1.277879, -0.011012},{
      0.751758, 1.278365, -0.011012},{0.751372, 1.278751, -0.011012},{
      0.750886, 1.278999, -0.011012},{0.750347, 1.279084, -0.011012},{
      0.749808, 1.278999, -0.011012},{0.749321, 1.278751, -0.011012},{
      0.748936, 1.278365, -0.011012},{0.748688, 1.277879, -0.011012},{
      0.748603, 1.277340, -0.011012},{0.748688, 1.276801, -0.011012},{
      0.748936, 1.276315, -0.011012},{0.749321, 1.275929, -0.011012},{
      0.749808, 1.275682, -0.011012},{0.750347, 1.275596, -0.011012},{
      0.750886, 1.275682, -0.011012},{0.751372, 1.275929, -0.011012},{
      0.751758, 1.276315, -0.011012},{0.752005, 1.276801, -0.011012}}],
    Polygon[{{0.752005, 1.276801, 0.011012},{0.751758, 1.276315, 0.011012},{
      0.751372, 1.275929, 0.011012},{0.750886, 1.275682, 0.011012},{
      0.750347, 1.275596, 0.011012},{0.749808, 1.275682, 0.011012},{
      0.749321, 1.275929, 0.011012},{0.748936, 1.276315, 0.011012},{
      0.748688, 1.276801, 0.011012},{0.748603, 1.277340, 0.011012},{
      0.748688, 1.277879, 0.011012},{0.748936, 1.278365, 0.011012},{
      0.749321, 1.278751, 0.011012},{0.749808, 1.278999, 0.011012},{
      0.750347, 1.279084, 0.011012},{0.750886, 1.278999, 0.011012},{
      0.751372, 1.278751, 0.011012},{0.751758, 1.278365, 0.011012},{
      0.752005, 1.277879, 0.011012},{0.752091, 1.277340, 0.011012}}],
    Polygon[{{0.813474, 1.273429, -0.009381},{0.813402, 1.273888, -0.009381},{
      0.813191, 1.274303, -0.009381},{0.812862, 1.274631, -0.009381},{
      0.812448, 1.274842, -0.009381},{0.811989, 1.274915, -0.009381},{
      0.811529, 1.274842, -0.009381},{0.811115, 1.274631, -0.009381},{
      0.810786, 1.274303, -0.009381},{0.810575, 1.273888, -0.009381},{
      0.810503, 1.273429, -0.009381},{0.810575, 1.272970, -0.009381},{
      0.810786, 1.272556, -0.009381},{0.811115, 1.272227, -0.009381},{
      0.811529, 1.272016, -0.009381},{0.811989, 1.271943, -0.009381},{
      0.812448, 1.272016, -0.009381},{0.812862, 1.272227, -0.009381},{
      0.813191, 1.272556, -0.009381},{0.813402, 1.272970, -0.009381}}],
    Polygon[{{0.813402, 1.272970, 0.009381},{0.813191, 1.272556, 0.009381},{
      0.812862, 1.272227, 0.009381},{0.812448, 1.272016, 0.009381},{
      0.811989, 1.271943, 0.009381},{0.811529, 1.272016, 0.009381},{
      0.811115, 1.272227, 0.009381},{0.810786, 1.272556, 0.009381},{
      0.810575, 1.272970, 0.009381},{0.810503, 1.273429, 0.009381},{
      0.810575, 1.273888, 0.009381},{0.810786, 1.274303, 0.009381},{
      0.811115, 1.274631, 0.009381},{0.811529, 1.274842, 0.009381},{
      0.811989, 1.274915, 0.009381},{0.812448, 1.274842, 0.009381},{
      0.812862, 1.274631, 0.009381},{0.813191, 1.274303, 0.009381},{
      0.813402, 1.273888, 0.009381},{0.813474, 1.273429, 0.009381}}],
    Polygon[{{0.881409, 1.167291, -0.024871},{0.881216, 1.168508, -0.024871},{
      0.880656, 1.169606, -0.024871},{0.879785, 1.170478, -0.024871},{
      0.878687, 1.171037, -0.024871},{0.877470, 1.171230, -0.024871},{
      0.876252, 1.171037, -0.024871},{0.875154, 1.170478, -0.024871},{
      0.874283, 1.169606, -0.024871},{0.873723, 1.168508, -0.024871},{
      0.873531, 1.167291, -0.024871},{0.873723, 1.166074, -0.024871},{
      0.874283, 1.164976, -0.024871},{0.875154, 1.164104, -0.024871},{
      0.876252, 1.163545, -0.024871},{0.877470, 1.163352, -0.024871},{
      0.878687, 1.163545, -0.024871},{0.879785, 1.164104, -0.024871},{
      0.880656, 1.164976, -0.024871},{0.881216, 1.166074, -0.024871}}],
    Polygon[{{0.881216, 1.166074, 0.024871},{0.880656, 1.164976, 0.024871},{
      0.879785, 1.164104, 0.024871},{0.878687, 1.163545, 0.024871},{
      0.877470, 1.163352, 0.024871},{0.876252, 1.163545, 0.024871},{
      0.875154, 1.164104, 0.024871},{0.874283, 1.164976, 0.024871},{
      0.873723, 1.166074, 0.024871},{0.873531, 1.167291, 0.024871},{
      0.873723, 1.168508, 0.024871},{0.874283, 1.169606, 0.024871},{
      0.875154, 1.170478, 0.024871},{0.876252, 1.171037, 0.024871},{
      0.877470, 1.171230, 0.024871},{0.878687, 1.171037, 0.024871},{
      0.879785, 1.170478, 0.024871},{0.880656, 1.169606, 0.024871},{
      0.881216, 1.168508, 0.024871},{0.881409, 1.167291, 0.024871}}],
    Polygon[{{0.916499, 1.160923, -0.012292},{0.916404, 1.161525, -0.012292},{
      0.916128, 1.162067, -0.012292},{0.915697, 1.162498, -0.012292},{
      0.915154, 1.162775, -0.012292},{0.914553, 1.162870, -0.012292},{
      0.913951, 1.162775, -0.012292},{0.913408, 1.162498, -0.012292},{
      0.912978, 1.162067, -0.012292},{0.912701, 1.161525, -0.012292},{
      0.912606, 1.160923, -0.012292},{0.912701, 1.160321, -0.012292},{
      0.912978, 1.159779, -0.012292},{0.913408, 1.159348, -0.012292},{
      0.913951, 1.159071, -0.012292},{0.914553, 1.158976, -0.012292},{
      0.915154, 1.159071, -0.012292},{0.915697, 1.159348, -0.012292},{
      0.916128, 1.159779, -0.012292},{0.916404, 1.160321, -0.012292}}],
    Polygon[{{0.916404, 1.160321, 0.012292},{0.916128, 1.159779, 0.012292},{
      0.915697, 1.159348, 0.012292},{0.915154, 1.159071, 0.012292},{
      0.914553, 1.158976, 0.012292},{0.913951, 1.159071, 0.012292},{
      0.913408, 1.159348, 0.012292},{0.912978, 1.159779, 0.012292},{
      0.912701, 1.160321, 0.012292},{0.912606, 1.160923, 0.012292},{
      0.912701, 1.161525, 0.012292},{0.912978, 1.162067, 0.012292},{
      0.913408, 1.162498, 0.012292},{0.913951, 1.162775, 0.012292},{
      0.914553, 1.162870, 0.012292},{0.915154, 1.162775, 0.012292},{
      0.915697, 1.162498, 0.012292},{0.916128, 1.162067, 0.012292},{
      0.916404, 1.161525, 0.012292},{0.916499, 1.160923, 0.012292}}],
    Polygon[{{0.852171, 1.145043, -0.009538},{0.852097, 1.145510, -0.009538},{
      0.851883, 1.145931, -0.009538},{0.851548, 1.146266, -0.009538},{
      0.851127, 1.146480, -0.009538},{0.850661, 1.146554, -0.009538},{
      0.850194, 1.146480, -0.009538},{0.849773, 1.146266, -0.009538},{
      0.849438, 1.145931, -0.009538},{0.849224, 1.145510, -0.009538},{
      0.849150, 1.145043, -0.009538},{0.849224, 1.144577, -0.009538},{
      0.849438, 1.144155, -0.009538},{0.849773, 1.143821, -0.009538},{
      0.850194, 1.143607, -0.009538},{0.850661, 1.143533, -0.009538},{
      0.851127, 1.143607, -0.009538},{0.851548, 1.143821, -0.009538},{
      0.851883, 1.144155, -0.009538},{0.852097, 1.144577, -0.009538}}],
    Polygon[{{0.852097, 1.144577, 0.009538},{0.851883, 1.144155, 0.009538},{
      0.851548, 1.143821, 0.009538},{0.851127, 1.143607, 0.009538},{
      0.850661, 1.143533, 0.009538},{0.850194, 1.143607, 0.009538},{
      0.849773, 1.143821, 0.009538},{0.849438, 1.144155, 0.009538},{
      0.849224, 1.144577, 0.009538},{0.849150, 1.145043, 0.009538},{
      0.849224, 1.145510, 0.009538},{0.849438, 1.145931, 0.009538},{
      0.849773, 1.146266, 0.009538},{0.850194, 1.146480, 0.009538},{
      0.850661, 1.146554, 0.009538},{0.851127, 1.146480, 0.009538},{
      0.851548, 1.146266, 0.009538},{0.851883, 1.145931, 0.009538},{
      0.852097, 1.145510, 0.009538},{0.852171, 1.145043, 0.009538}}],
    Polygon[{{0.865654, 1.198582, -0.008668},{0.865587, 1.199007, -0.008668},{
      0.865392, 1.199389, -0.008668},{0.865088, 1.199693, -0.008668},{
      0.864706, 1.199888, -0.008668},{0.864281, 1.199955, -0.008668},{
      0.863857, 1.199888, -0.008668},{0.863474, 1.199693, -0.008668},{
      0.863171, 1.199389, -0.008668},{0.862976, 1.199007, -0.008668},{
      0.862908, 1.198582, -0.008668},{0.862976, 1.198158, -0.008668},{
      0.863171, 1.197775, -0.008668},{0.863474, 1.197472, -0.008668},{
      0.863857, 1.197277, -0.008668},{0.864281, 1.197209, -0.008668},{
      0.864706, 1.197277, -0.008668},{0.865088, 1.197472, -0.008668},{
      0.865392, 1.197775, -0.008668},{0.865587, 1.198158, -0.008668}}],
    Polygon[{{0.865587, 1.198158, 0.008668},{0.865392, 1.197775, 0.008668},{
      0.865088, 1.197472, 0.008668},{0.864706, 1.197277, 0.008668},{
      0.864281, 1.197209, 0.008668},{0.863857, 1.197277, 0.008668},{
      0.863474, 1.197472, 0.008668},{0.863171, 1.197775, 0.008668},{
      0.862976, 1.198158, 0.008668},{0.862908, 1.198582, 0.008668},{
      0.862976, 1.199007, 0.008668},{0.863171, 1.199389, 0.008668},{
      0.863474, 1.199693, 0.008668},{0.863857, 1.199888, 0.008668},{
      0.864281, 1.199955, 0.008668},{0.864706, 1.199888, 0.008668},{
      0.865088, 1.199693, 0.008668},{0.865392, 1.199389, 0.008668},{
      0.865587, 1.199007, 0.008668},{0.865654, 1.198582, 0.008668}}],
    Polygon[{{1.233788, 1.193376, -0.076398},{1.233196, 1.197115, -0.076398},{
      1.231477, 1.200488, -0.076398},{1.228800, 1.203165, -0.076398},{
      1.225427, 1.204884, -0.076398},{1.221688, 1.205476, -0.076398},{
      1.217949, 1.204884, -0.076398},{1.214576, 1.203165, -0.076398},{
      1.211899, 1.200488, -0.076398},{1.210180, 1.197115, -0.076398},{
      1.209588, 1.193376, -0.076398},{1.210180, 1.189636, -0.076398},{
      1.211899, 1.186263, -0.076398},{1.214576, 1.183586, -0.076398},{
      1.217949, 1.181868, -0.076398},{1.221688, 1.181275, -0.076398},{
      1.225427, 1.181868, -0.076398},{1.228800, 1.183586, -0.076398},{
      1.231477, 1.186263, -0.076398},{1.233196, 1.189636, -0.076398}}],
    Polygon[{{1.233196, 1.189636, 0.076398},{1.231477, 1.186263, 0.076398},{
      1.228800, 1.183586, 0.076398},{1.225427, 1.181868, 0.076398},{
      1.221688, 1.181275, 0.076398},{1.217949, 1.181868, 0.076398},{
      1.214576, 1.183586, 0.076398},{1.211899, 1.186263, 0.076398},{
      1.210180, 1.189636, 0.076398},{1.209588, 1.193376, 0.076398},{
      1.210180, 1.197115, 0.076398},{1.211899, 1.200488, 0.076398},{
      1.214576, 1.203165, 0.076398},{1.217949, 1.204884, 0.076398},{
      1.221688, 1.205476, 0.076398},{1.225427, 1.204884, 0.076398},{
      1.228800, 1.203165, 0.076398},{1.231477, 1.200488, 0.076398},{
      1.233196, 1.197115, 0.076398},{1.233788, 1.193376, 0.076398}}],
    Polygon[{{1.315886, 1.113249, -0.040942},{1.315568, 1.115252, -0.040942},{
      1.314647, 1.117060, -0.040942},{1.313213, 1.118495, -0.040942},{
      1.311405, 1.119416, -0.040942},{1.309401, 1.119733, -0.040942},{
      1.307397, 1.119416, -0.040942},{1.305590, 1.118495, -0.040942},{
      1.304155, 1.117060, -0.040942},{1.303234, 1.115252, -0.040942},{
      1.302917, 1.113249, -0.040942},{1.303234, 1.111245, -0.040942},{
      1.304155, 1.109437, -0.040942},{1.305590, 1.108003, -0.040942},{
      1.307397, 1.107082, -0.040942},{1.309401, 1.106764, -0.040942},{
      1.311405, 1.107082, -0.040942},{1.313213, 1.108003, -0.040942},{
      1.314647, 1.109437, -0.040942},{1.315568, 1.111245, -0.040942}}],
    Polygon[{{1.315568, 1.111245, 0.040942},{1.314647, 1.109437, 0.040942},{
      1.313213, 1.108003, 0.040942},{1.311405, 1.107082, 0.040942},{
      1.309401, 1.106764, 0.040942},{1.307397, 1.107082, 0.040942},{
      1.305590, 1.108003, 0.040942},{1.304155, 1.109437, 0.040942},{
      1.303234, 1.111245, 0.040942},{1.302917, 1.113249, 0.040942},{
      1.303234, 1.115252, 0.040942},{1.304155, 1.117060, 0.040942},{
      1.305590, 1.118495, 0.040942},{1.307397, 1.119416, 0.040942},{
      1.309401, 1.119733, 0.040942},{1.311405, 1.119416, 0.040942},{
      1.313213, 1.118495, 0.040942},{1.314647, 1.117060, 0.040942},{
      1.315568, 1.115252, 0.040942},{1.315886, 1.113249, 0.040942}}],
    Polygon[{{1.359696, 1.064459, -0.025466},{1.359498, 1.065705, -0.025466},{
      1.358926, 1.066829, -0.025466},{1.358033, 1.067722, -0.025466},{
      1.356909, 1.068295, -0.025466},{1.355662, 1.068492, -0.025466},{
      1.354416, 1.068295, -0.025466},{1.353292, 1.067722, -0.025466},{
      1.352399, 1.066829, -0.025466},{1.351826, 1.065705, -0.025466},{
      1.351629, 1.064459, -0.025466},{1.351826, 1.063212, -0.025466},{
      1.352399, 1.062088, -0.025466},{1.353292, 1.061195, -0.025466},{
      1.354416, 1.060623, -0.025466},{1.355662, 1.060425, -0.025466},{
      1.356909, 1.060623, -0.025466},{1.358033, 1.061195, -0.025466},{
      1.358926, 1.062088, -0.025466},{1.359498, 1.063212, -0.025466}}],
    Polygon[{{1.359498, 1.063212, 0.025466},{1.358926, 1.062088, 0.025466},{
      1.358033, 1.061195, 0.025466},{1.356909, 1.060623, 0.025466},{
      1.355662, 1.060425, 0.025466},{1.354416, 1.060623, 0.025466},{
      1.353292, 1.061195, 0.025466},{1.352399, 1.062088, 0.025466},{
      1.351826, 1.063212, 0.025466},{1.351629, 1.064459, 0.025466},{
      1.351826, 1.065705, 0.025466},{1.352399, 1.066829, 0.025466},{
      1.353292, 1.067722, 0.025466},{1.354416, 1.068295, 0.025466},{
      1.355662, 1.068492, 0.025466},{1.356909, 1.068295, 0.025466},{
      1.358033, 1.067722, 0.025466},{1.358926, 1.066829, 0.025466},{
      1.359498, 1.065705, 0.025466},{1.359696, 1.064459, 0.025466}}],
    Polygon[{{1.311563, 1.168518, -0.013647},{1.311457, 1.169186, -0.013647},{
      1.311150, 1.169788, -0.013647},{1.310672, 1.170267, -0.013647},{
      1.310069, 1.170574, -0.013647},{1.309401, 1.170679, -0.013647},{
      1.308733, 1.170574, -0.013647},{1.308131, 1.170267, -0.013647},{
      1.307652, 1.169788, -0.013647},{1.307345, 1.169186, -0.013647},{
      1.307240, 1.168518, -0.013647},{1.307345, 1.167850, -0.013647},{
      1.307652, 1.167247, -0.013647},{1.308131, 1.166769, -0.013647},{
      1.308733, 1.166462, -0.013647},{1.309401, 1.166356, -0.013647},{
      1.310069, 1.166462, -0.013647},{1.310672, 1.166769, -0.013647},{
      1.311150, 1.167247, -0.013647},{1.311457, 1.167850, -0.013647}}],
    Polygon[{{1.311457, 1.167850, 0.013647},{1.311150, 1.167247, 0.013647},{
      1.310672, 1.166769, 0.013647},{1.310069, 1.166462, 0.013647},{
      1.309401, 1.166356, 0.013647},{1.308733, 1.166462, 0.013647},{
      1.308131, 1.166769, 0.013647},{1.307652, 1.167247, 0.013647},{
      1.307345, 1.167850, 0.013647},{1.307240, 1.168518, 0.013647},{
      1.307345, 1.169186, 0.013647},{1.307652, 1.169788, 0.013647},{
      1.308131, 1.170267, 0.013647},{1.308733, 1.170574, 0.013647},{
      1.309401, 1.170679, 0.013647},{1.310069, 1.170574, 0.013647},{
      1.310672, 1.170267, 0.013647},{1.311150, 1.169788, 0.013647},{
      1.311457, 1.169186, 0.013647},{1.311563, 1.168518, 0.013647}}],
    Polygon[{{1.257198, 1.109580, -0.012733},{1.257100, 1.110203, -0.012733},{
      1.256813, 1.110765, -0.012733},{1.256367, 1.111211, -0.012733},{
      1.255805, 1.111498, -0.012733},{1.255181, 1.111596, -0.012733},{
      1.254558, 1.111498, -0.012733},{1.253996, 1.111211, -0.012733},{
      1.253550, 1.110765, -0.012733},{1.253263, 1.110203, -0.012733},{
      1.253165, 1.109580, -0.012733},{1.253263, 1.108956, -0.012733},{
      1.253550, 1.108394, -0.012733},{1.253996, 1.107948, -0.012733},{
      1.254558, 1.107661, -0.012733},{1.255181, 1.107563, -0.012733},{
      1.255805, 1.107661, -0.012733},{1.256367, 1.107948, -0.012733},{
      1.256813, 1.108394, -0.012733},{1.257100, 1.108956, -0.012733}}],
    Polygon[{{1.257100, 1.108956, 0.012733},{1.256813, 1.108394, 0.012733},{
      1.256367, 1.107948, 0.012733},{1.255805, 1.107661, 0.012733},{
      1.255181, 1.107563, 0.012733},{1.254558, 1.107661, 0.012733},{
      1.253996, 1.107948, 0.012733},{1.253550, 1.108394, 0.012733},{
      1.253263, 1.108956, 0.012733},{1.253165, 1.109580, 0.012733},{
      1.253263, 1.110203, 0.012733},{1.253550, 1.110765, 0.012733},{
      1.253996, 1.111211, 0.012733},{1.254558, 1.111498, 0.012733},{
      1.255181, 1.111596, 0.012733},{1.255805, 1.111498, 0.012733},{
      1.256367, 1.111211, 0.012733},{1.256813, 1.110765, 0.012733},{
      1.257100, 1.110203, 0.012733},{1.257198, 1.109580, 0.012733}}],
    Polygon[{{1.220778, 1.299558, -0.028615},{1.220557, 1.300959, -0.028615},{
      1.219913, 1.302222, -0.028615},{1.218910, 1.303225, -0.028615},{
      1.217647, 1.303868, -0.028615},{1.216246, 1.304090, -0.028615},{
      1.214846, 1.303868, -0.028615},{1.213582, 1.303225, -0.028615},{
      1.212580, 1.302222, -0.028615},{1.211936, 1.300959, -0.028615},{
      1.211714, 1.299558, -0.028615},{1.211936, 1.298158, -0.028615},{
      1.212580, 1.296894, -0.028615},{1.213582, 1.295892, -0.028615},{
      1.214846, 1.295248, -0.028615},{1.216246, 1.295026, -0.028615},{
      1.217647, 1.295248, -0.028615},{1.218910, 1.295892, -0.028615},{
      1.219913, 1.296894, -0.028615},{1.220557, 1.298158, -0.028615}}],
    Polygon[{{1.220557, 1.298158, 0.028615},{1.219913, 1.296894, 0.028615},{
      1.218910, 1.295892, 0.028615},{1.217647, 1.295248, 0.028615},{
      1.216246, 1.295026, 0.028615},{1.214846, 1.295248, 0.028615},{
      1.213582, 1.295892, 0.028615},{1.212580, 1.296894, 0.028615},{
      1.211936, 1.298158, 0.028615},{1.211714, 1.299558, 0.028615},{
      1.211936, 1.300959, 0.028615},{1.212580, 1.302222, 0.028615},{
      1.213582, 1.303225, 0.028615},{1.214846, 1.303868, 0.028615},{
      1.216246, 1.304090, 0.028615},{1.217647, 1.303868, 0.028615},{
      1.218910, 1.303225, 0.028615},{1.219913, 1.302222, 0.028615},{
      1.220557, 1.300959, 0.028615},{1.220778, 1.299558, 0.028615}}],
    Polygon[{{1.209792, 1.342678, -0.014853},{1.209677, 1.343405, -0.014853},{
      1.209343, 1.344061, -0.014853},{1.208823, 1.344581, -0.014853},{
      1.208167, 1.344915, -0.014853},{1.207440, 1.345030, -0.014853},{
      1.206713, 1.344915, -0.014853},{1.206057, 1.344581, -0.014853},{
      1.205537, 1.344061, -0.014853},{1.205203, 1.343405, -0.014853},{
      1.205088, 1.342678, -0.014853},{1.205203, 1.341951, -0.014853},{
      1.205537, 1.341295, -0.014853},{1.206057, 1.340775, -0.014853},{
      1.206713, 1.340440, -0.014853},{1.207440, 1.340325, -0.014853},{
      1.208167, 1.340440, -0.014853},{1.208823, 1.340775, -0.014853},{
      1.209343, 1.341295, -0.014853},{1.209677, 1.341951, -0.014853}}],
    Polygon[{{1.209677, 1.341951, 0.014853},{1.209343, 1.341295, 0.014853},{
      1.208823, 1.340775, 0.014853},{1.208167, 1.340440, 0.014853},{
      1.207440, 1.340325, 0.014853},{1.206713, 1.340440, 0.014853},{
      1.206057, 1.340775, 0.014853},{1.205537, 1.341295, 0.014853},{
      1.205203, 1.341951, 0.014853},{1.205088, 1.342678, 0.014853},{
      1.205203, 1.343405, 0.014853},{1.205537, 1.344061, 0.014853},{
      1.206057, 1.344581, 0.014853},{1.206713, 1.344915, 0.014853},{
      1.207440, 1.345030, 0.014853},{1.208167, 1.344915, 0.014853},{
      1.208823, 1.344581, 0.014853},{1.209343, 1.344061, 0.014853},{
      1.209677, 1.343405, 0.014853},{1.209792, 1.342678, 0.014853}}],
    Polygon[{{1.251397, 1.277340, -0.011012},{1.251312, 1.277879, -0.011012},{
      1.251064, 1.278365, -0.011012},{1.250679, 1.278751, -0.011012},{
      1.250192, 1.278999, -0.011012},{1.249653, 1.279084, -0.011012},{
      1.249114, 1.278999, -0.011012},{1.248628, 1.278751, -0.011012},{
      1.248242, 1.278365, -0.011012},{1.247995, 1.277879, -0.011012},{
      1.247909, 1.277340, -0.011012},{1.247995, 1.276801, -0.011012},{
      1.248242, 1.276315, -0.011012},{1.248628, 1.275929, -0.011012},{
      1.249114, 1.275682, -0.011012},{1.249653, 1.275596, -0.011012},{
      1.250192, 1.275682, -0.011012},{1.250679, 1.275929, -0.011012},{
      1.251064, 1.276315, -0.011012},{1.251312, 1.276801, -0.011012}}],
    Polygon[{{1.251312, 1.276801, 0.011012},{1.251064, 1.276315, 0.011012},{
      1.250679, 1.275929, 0.011012},{1.250192, 1.275682, 0.011012},{
      1.249653, 1.275596, 0.011012},{1.249114, 1.275682, 0.011012},{
      1.248628, 1.275929, 0.011012},{1.248242, 1.276315, 0.011012},{
      1.247995, 1.276801, 0.011012},{1.247909, 1.277340, 0.011012},{
      1.247995, 1.277879, 0.011012},{1.248242, 1.278365, 0.011012},{
      1.248628, 1.278751, 0.011012},{1.249114, 1.278999, 0.011012},{
      1.249653, 1.279084, 0.011012},{1.250192, 1.278999, 0.011012},{
      1.250679, 1.278751, 0.011012},{1.251064, 1.278365, 0.011012},{
      1.251312, 1.277879, 0.011012},{1.251397, 1.277340, 0.011012}}],
    Polygon[{{1.189497, 1.273429, -0.009381},{1.189425, 1.273888, -0.009381},{
      1.189214, 1.274303, -0.009381},{1.188885, 1.274631, -0.009381},{
      1.188471, 1.274842, -0.009381},{1.188011, 1.274915, -0.009381},{
      1.187552, 1.274842, -0.009381},{1.187138, 1.274631, -0.009381},{
      1.186809, 1.274303, -0.009381},{1.186598, 1.273888, -0.009381},{
      1.186526, 1.273429, -0.009381},{1.186598, 1.272970, -0.009381},{
      1.186809, 1.272556, -0.009381},{1.187138, 1.272227, -0.009381},{
      1.187552, 1.272016, -0.009381},{1.188011, 1.271943, -0.009381},{
      1.188471, 1.272016, -0.009381},{1.188885, 1.272227, -0.009381},{
      1.189214, 1.272556, -0.009381},{1.189425, 1.272970, -0.009381}}],
    Polygon[{{1.189425, 1.272970, 0.009381},{1.189214, 1.272556, 0.009381},{
      1.188885, 1.272227, 0.009381},{1.188471, 1.272016, 0.009381},{
      1.188011, 1.271943, 0.009381},{1.187552, 1.272016, 0.009381},{
      1.187138, 1.272227, 0.009381},{1.186809, 1.272556, 0.009381},{
      1.186598, 1.272970, 0.009381},{1.186526, 1.273429, 0.009381},{
      1.186598, 1.273888, 0.009381},{1.186809, 1.274303, 0.009381},{
      1.187138, 1.274631, 0.009381},{1.187552, 1.274842, 0.009381},{
      1.188011, 1.274915, 0.009381},{1.188471, 1.274842, 0.009381},{
      1.188885, 1.274631, 0.009381},{1.189214, 1.274303, 0.009381},{
      1.189425, 1.273888, 0.009381},{1.189497, 1.273429, 0.009381}}],
    Polygon[{{1.126469, 1.167291, -0.024871},{1.126277, 1.168508, -0.024871},{
      1.125717, 1.169606, -0.024871},{1.124846, 1.170478, -0.024871},{
      1.123748, 1.171037, -0.024871},{1.122530, 1.171230, -0.024871},{
      1.121313, 1.171037, -0.024871},{1.120215, 1.170478, -0.024871},{
      1.119344, 1.169606, -0.024871},{1.118784, 1.168508, -0.024871},{
      1.118591, 1.167291, -0.024871},{1.118784, 1.166074, -0.024871},{
      1.119344, 1.164976, -0.024871},{1.120215, 1.164104, -0.024871},{
      1.121313, 1.163545, -0.024871},{1.122530, 1.163352, -0.024871},{
      1.123748, 1.163545, -0.024871},{1.124846, 1.164104, -0.024871},{
      1.125717, 1.164976, -0.024871},{1.126277, 1.166074, -0.024871}}],
    Polygon[{{1.126277, 1.166074, 0.024871},{1.125717, 1.164976, 0.024871},{
      1.124846, 1.164104, 0.024871},{1.123748, 1.163545, 0.024871},{
      1.122530, 1.163352, 0.024871},{1.121313, 1.163545, 0.024871},{
      1.120215, 1.164104, 0.024871},{1.119344, 1.164976, 0.024871},{
      1.118784, 1.166074, 0.024871},{1.118591, 1.167291, 0.024871},{
      1.118784, 1.168508, 0.024871},{1.119344, 1.169606, 0.024871},{
      1.120215, 1.170478, 0.024871},{1.121313, 1.171037, 0.024871},{
      1.122530, 1.171230, 0.024871},{1.123748, 1.171037, 0.024871},{
      1.124846, 1.170478, 0.024871},{1.125717, 1.169606, 0.024871},{
      1.126277, 1.168508, 0.024871},{1.126469, 1.167291, 0.024871}}],
    Polygon[{{1.087394, 1.160923, -0.012292},{1.087299, 1.161525, -0.012292},{
      1.087022, 1.162067, -0.012292},{1.086592, 1.162498, -0.012292},{
      1.086049, 1.162775, -0.012292},{1.085447, 1.162870, -0.012292},{
      1.084846, 1.162775, -0.012292},{1.084303, 1.162498, -0.012292},{
      1.083872, 1.162067, -0.012292},{1.083596, 1.161525, -0.012292},{
      1.083501, 1.160923, -0.012292},{1.083596, 1.160321, -0.012292},{
      1.083872, 1.159779, -0.012292},{1.084303, 1.159348, -0.012292},{
      1.084846, 1.159071, -0.012292},{1.085447, 1.158976, -0.012292},{
      1.086049, 1.159071, -0.012292},{1.086592, 1.159348, -0.012292},{
      1.087022, 1.159779, -0.012292},{1.087299, 1.160321, -0.012292}}],
    Polygon[{{1.087299, 1.160321, 0.012292},{1.087022, 1.159779, 0.012292},{
      1.086592, 1.159348, 0.012292},{1.086049, 1.159071, 0.012292},{
      1.085447, 1.158976, 0.012292},{1.084846, 1.159071, 0.012292},{
      1.084303, 1.159348, 0.012292},{1.083872, 1.159779, 0.012292},{
      1.083596, 1.160321, 0.012292},{1.083501, 1.160923, 0.012292},{
      1.083596, 1.161525, 0.012292},{1.083872, 1.162067, 0.012292},{
      1.084303, 1.162498, 0.012292},{1.084846, 1.162775, 0.012292},{
      1.085447, 1.162870, 0.012292},{1.086049, 1.162775, 0.012292},{
      1.086592, 1.162498, 0.012292},{1.087022, 1.162067, 0.012292},{
      1.087299, 1.161525, 0.012292},{1.087394, 1.160923, 0.012292}}],
    Polygon[{{1.150850, 1.145043, -0.009538},{1.150776, 1.145510, -0.009538},{
      1.150562, 1.145931, -0.009538},{1.150227, 1.146266, -0.009538},{
      1.149806, 1.146480, -0.009538},{1.149339, 1.146554, -0.009538},{
      1.148873, 1.146480, -0.009538},{1.148452, 1.146266, -0.009538},{
      1.148117, 1.145931, -0.009538},{1.147903, 1.145510, -0.009538},{
      1.147829, 1.145043, -0.009538},{1.147903, 1.144577, -0.009538},{
      1.148117, 1.144155, -0.009538},{1.148452, 1.143821, -0.009538},{
      1.148873, 1.143607, -0.009538},{1.149339, 1.143533, -0.009538},{
      1.149806, 1.143607, -0.009538},{1.150227, 1.143821, -0.009538},{
      1.150562, 1.144155, -0.009538},{1.150776, 1.144577, -0.009538}}],
    Polygon[{{1.150776, 1.144577, 0.009538},{1.150562, 1.144155, 0.009538},{
      1.150227, 1.143821, 0.009538},{1.149806, 1.143607, 0.009538},{
      1.149339, 1.143533, 0.009538},{1.148873, 1.143607, 0.009538},{
      1.148452, 1.143821, 0.009538},{1.148117, 1.144155, 0.009538},{
      1.147903, 1.144577, 0.009538},{1.147829, 1.145043, 0.009538},{
      1.147903, 1.145510, 0.009538},{1.148117, 1.145931, 0.009538},{
      1.148452, 1.146266, 0.009538},{1.148873, 1.146480, 0.009538},{
      1.149339, 1.146554, 0.009538},{1.149806, 1.146480, 0.009538},{
      1.150227, 1.146266, 0.009538},{1.150562, 1.145931, 0.009538},{
      1.150776, 1.145510, 0.009538},{1.150850, 1.145043, 0.009538}}],
    Polygon[{{1.137092, 1.198582, -0.008668},{1.137024, 1.199007, -0.008668},{
      1.136829, 1.199389, -0.008668},{1.136526, 1.199693, -0.008668},{
      1.136143, 1.199888, -0.008668},{1.135719, 1.199955, -0.008668},{
      1.135294, 1.199888, -0.008668},{1.134912, 1.199693, -0.008668},{
      1.134608, 1.199389, -0.008668},{1.134413, 1.199007, -0.008668},{
      1.134346, 1.198582, -0.008668},{1.134413, 1.198158, -0.008668},{
      1.134608, 1.197775, -0.008668},{1.134912, 1.197472, -0.008668},{
      1.135294, 1.197277, -0.008668},{1.135719, 1.197209, -0.008668},{
      1.136143, 1.197277, -0.008668},{1.136526, 1.197472, -0.008668},{
      1.136829, 1.197775, -0.008668},{1.137024, 1.198158, -0.008668}}],
    Polygon[{{1.137024, 1.198158, 0.008668},{1.136829, 1.197775, 0.008668},{
      1.136526, 1.197472, 0.008668},{1.136143, 1.197277, 0.008668},{
      1.135719, 1.197209, 0.008668},{1.135294, 1.197277, 0.008668},{
      1.134912, 1.197472, 0.008668},{1.134608, 1.197775, 0.008668},{
      1.134413, 1.198158, 0.008668},{1.134346, 1.198582, 0.008668},{
      1.134413, 1.199007, 0.008668},{1.134608, 1.199389, 0.008668},{
      1.134912, 1.199693, 0.008668},{1.135294, 1.199888, 0.008668},{
      1.135719, 1.199955, 0.008668},{1.136143, 1.199888, 0.008668},{
      1.136526, 1.199693, 0.008668},{1.136829, 1.199389, 0.008668},{
      1.137024, 1.199007, 0.008668},{1.137092, 1.198582, 0.008668}}],
    Polygon[{{1.090317, 0.577350, -0.570242},{1.178411, 0.577350, -0.549093},{
      1.169679, 0.632482, -0.549093},{1.085897, 0.605260, -0.570242}}],
    Polygon[{{1.178411, 0.577350, -0.549093},{1.262112, 0.577350, -0.514423},{
      1.249283, 0.658347, -0.514423},{1.169679, 0.632482, -0.549093}}],
    Polygon[{{1.262112, 0.577350, -0.514423},{1.339358, 0.577350, -0.467086},{
      1.322749, 0.682218, -0.467086},{1.249283, 0.658347, -0.514423}}],
    Polygon[{{1.339358, 0.577350, -0.467086},{1.408248, 0.577350, -0.408248},{
      1.388267, 0.703506, -0.408248},{1.322749, 0.682218, -0.467086}}],
    Polygon[{{1.408248, 0.577350, -0.408248},{1.467086, 0.577350, -0.339358},{
      1.444225, 0.721688, -0.339358},{1.388267, 0.703506, -0.408248}}],
    Polygon[{{1.467086, 0.577350, -0.339358},{1.514423, 0.577350, -0.262112},{
      1.489245, 0.736316, -0.262112},{1.444225, 0.721688, -0.339358}}],
    Polygon[{{1.514423, 0.577350, -0.262112},{1.549093, 0.577350, -0.178411},{
      1.522218, 0.747029, -0.178411},{1.489245, 0.736316, -0.262112}}],
    Polygon[{{1.549093, 0.577350, -0.178411},{1.570242, 0.577350, -0.090317},{
      1.542333, 0.753565, -0.090317},{1.522218, 0.747029, -0.178411}}],
    Polygon[{{1.570242, 0.577350, -0.090317},{1.577350, 0.577350, 0.000000},{
      1.549093, 0.755761, 0.000000},{1.542333, 0.753565, -0.090317}}],
    Polygon[{{1.577350, 0.577350, 0.000000},{1.570242, 0.577350, 0.090317},{
      1.542333, 0.753565, 0.090317},{1.549093, 0.755761, 0.000000}}],
    Polygon[{{1.570242, 0.577350, 0.090317},{1.549093, 0.577350, 0.178411},{
      1.522218, 0.747029, 0.178411},{1.542333, 0.753565, 0.090317}}],
    Polygon[{{1.549093, 0.577350, 0.178411},{1.514423, 0.577350, 0.262112},{
      1.489245, 0.736316, 0.262112},{1.522218, 0.747029, 0.178411}}],
    Polygon[{{1.514423, 0.577350, 0.262112},{1.467086, 0.577350, 0.339358},{
      1.444225, 0.721688, 0.339358},{1.489245, 0.736316, 0.262112}}],
    Polygon[{{1.467086, 0.577350, 0.339358},{1.408248, 0.577350, 0.408248},{
      1.388267, 0.703506, 0.408248},{1.444225, 0.721688, 0.339358}}],
    Polygon[{{1.408248, 0.577350, 0.408248},{1.339358, 0.577350, 0.467086},{
      1.322749, 0.682218, 0.467086},{1.388267, 0.703506, 0.408248}}],
    Polygon[{{1.339358, 0.577350, 0.467086},{1.262112, 0.577350, 0.514423},{
      1.249283, 0.658347, 0.514423},{1.322749, 0.682218, 0.467086}}],
    Polygon[{{1.262112, 0.577350, 0.514423},{1.178411, 0.577350, 0.549093},{
      1.169679, 0.632482, 0.549093},{1.249283, 0.658347, 0.514423}}],
    Polygon[{{1.178411, 0.577350, 0.549093},{1.090317, 0.577350, 0.570242},{
      1.085897, 0.605260, 0.570242},{1.169679, 0.632482, 0.549093}}],
    Polygon[{{1.085897, 0.605260, -0.570242},{1.169679, 0.632482, -0.549093},{
      1.144338, 0.682218, -0.549093},{1.073068, 0.630438, -0.570242}}],
    Polygon[{{1.169679, 0.632482, -0.549093},{1.249283, 0.658347, -0.514423},{
      1.212053, 0.731416, -0.514423},{1.144338, 0.682218, -0.549093}}],
    Polygon[{{1.249283, 0.658347, -0.514423},{1.322749, 0.682218, -0.467086},{
      1.274546, 0.776820, -0.467086},{1.212053, 0.731416, -0.514423}}],
    Polygon[{{1.322749, 0.682218, -0.467086},{1.388267, 0.703506, -0.408248},{
      1.330280, 0.817313, -0.408248},{1.274546, 0.776820, -0.467086}}],
    Polygon[{{1.388267, 0.703506, -0.408248},{1.444225, 0.721688, -0.339358},{
      1.377881, 0.851897, -0.339358},{1.330280, 0.817313, -0.408248}}],
    Polygon[{{1.444225, 0.721688, -0.339358},{1.489245, 0.736316, -0.262112},{
      1.416177, 0.879720, -0.262112},{1.377881, 0.851897, -0.339358}}],
    Polygon[{{1.489245, 0.736316, -0.262112},{1.522218, 0.747029, -0.178411},{
      1.444225, 0.900099, -0.178411},{1.416177, 0.879720, -0.262112}}],
    Polygon[{{1.522218, 0.747029, -0.178411},{1.542333, 0.753565, -0.090317},{
      1.461336, 0.912530, -0.090317},{1.444225, 0.900099, -0.178411}}],
    Polygon[{{1.542333, 0.753565, -0.090317},{1.549093, 0.755761, 0.000000},{
      1.467086, 0.916708, 0.000000},{1.461336, 0.912530, -0.090317}}],
    Polygon[{{1.549093, 0.755761, 0.000000},{1.542333, 0.753565, 0.090317},{
      1.461336, 0.912530, 0.090317},{1.467086, 0.916708, 0.000000}}],
    Polygon[{{1.542333, 0.753565, 0.090317},{1.522218, 0.747029, 0.178411},{
      1.444225, 0.900099, 0.178411},{1.461336, 0.912530, 0.090317}}],
    Polygon[{{1.522218, 0.747029, 0.178411},{1.489245, 0.736316, 0.262112},{
      1.416177, 0.879720, 0.262112},{1.444225, 0.900099, 0.178411}}],
    Polygon[{{1.489245, 0.736316, 0.262112},{1.444225, 0.721688, 0.339358},{
      1.377881, 0.851897, 0.339358},{1.416177, 0.879720, 0.262112}}],
    Polygon[{{1.444225, 0.721688, 0.339358},{1.388267, 0.703506, 0.408248},{
      1.330280, 0.817313, 0.408248},{1.377881, 0.851897, 0.339358}}],
    Polygon[{{1.388267, 0.703506, 0.408248},{1.322749, 0.682218, 0.467086},{
      1.274546, 0.776820, 0.467086},{1.330280, 0.817313, 0.408248}}],
    Polygon[{{1.322749, 0.682218, 0.467086},{1.249283, 0.658347, 0.514423},{
      1.212053, 0.731416, 0.514423},{1.274546, 0.776820, 0.467086}}],
    Polygon[{{1.249283, 0.658347, 0.514423},{1.169679, 0.632482, 0.549093},{
      1.144338, 0.682218, 0.549093},{1.212053, 0.731416, 0.514423}}],
    Polygon[{{1.169679, 0.632482, 0.549093},{1.085897, 0.605260, 0.570242},{
      1.073068, 0.630438, 0.570242},{1.144338, 0.682218, 0.549093}}],
    Polygon[{{1.073068, 0.630438, -0.570242},{1.144338, 0.682218, -0.549093},{
      1.104867, 0.721688, -0.549093},{1.053087, 0.650419, -0.570242}}],
    Polygon[{{1.144338, 0.682218, -0.549093},{1.212053, 0.731416, -0.514423},{
      1.154065, 0.789403, -0.514423},{1.104867, 0.721688, -0.549093}}],
    Polygon[{{1.212053, 0.731416, -0.514423},{1.274546, 0.776820, -0.467086},{
      1.199470, 0.851897, -0.467086},{1.154065, 0.789403, -0.514423}}],
    Polygon[{{1.274546, 0.776820, -0.467086},{1.330280, 0.817313, -0.408248},{
      1.239962, 0.907630, -0.408248},{1.199470, 0.851897, -0.467086}}],
    Polygon[{{1.330280, 0.817313, -0.408248},{1.377881, 0.851897, -0.339358},{
      1.274546, 0.955231, -0.339358},{1.239962, 0.907630, -0.408248}}],
    Polygon[{{1.377881, 0.851897, -0.339358},{1.416177, 0.879720, -0.262112},{
      1.302370, 0.993527, -0.262112},{1.274546, 0.955231, -0.339358}}],
    Polygon[{{1.416177, 0.879720, -0.262112},{1.444225, 0.900099, -0.178411},{
      1.322749, 1.021576, -0.178411},{1.302370, 0.993527, -0.262112}}],
    Polygon[{{1.444225, 0.900099, -0.178411},{1.461336, 0.912530, -0.090317},{
      1.335180, 1.038686, -0.090317},{1.322749, 1.021576, -0.178411}}],
    Polygon[{{1.461336, 0.912530, -0.090317},{1.467086, 0.916708, 0.000000},{
      1.339358, 1.044436, 0.000000},{1.335180, 1.038686, -0.090317}}],
    Polygon[{{1.467086, 0.916708, 0.000000},{1.461336, 0.912530, 0.090317},{
      1.335180, 1.038686, 0.090317},{1.339358, 1.044436, 0.000000}}],
    Polygon[{{1.461336, 0.912530, 0.090317},{1.444225, 0.900099, 0.178411},{
      1.322749, 1.021576, 0.178411},{1.335180, 1.038686, 0.090317}}],
    Polygon[{{1.444225, 0.900099, 0.178411},{1.416177, 0.879720, 0.262112},{
      1.302370, 0.993527, 0.262112},{1.322749, 1.021576, 0.178411}}],
    Polygon[{{1.416177, 0.879720, 0.262112},{1.377881, 0.851897, 0.339358},{
      1.274546, 0.955231, 0.339358},{1.302370, 0.993527, 0.262112}}],
    Polygon[{{1.377881, 0.851897, 0.339358},{1.330280, 0.817313, 0.408248},{
      1.239962, 0.907630, 0.408248},{1.274546, 0.955231, 0.339358}}],
    Polygon[{{1.330280, 0.817313, 0.408248},{1.274546, 0.776820, 0.467086},{
      1.199470, 0.851897, 0.467086},{1.239962, 0.907630, 0.408248}}],
    Polygon[{{1.274546, 0.776820, 0.467086},{1.212053, 0.731416, 0.514423},{
      1.154065, 0.789403, 0.514423},{1.199470, 0.851897, 0.467086}}],
    Polygon[{{1.212053, 0.731416, 0.514423},{1.144338, 0.682218, 0.549093},{
      1.104867, 0.721688, 0.549093},{1.154065, 0.789403, 0.514423}}],
    Polygon[{{1.144338, 0.682218, 0.549093},{1.073068, 0.630438, 0.570242},{
      1.053087, 0.650419, 0.570242},{1.104867, 0.721688, 0.549093}}],
    Polygon[{{1.053087, 0.650419, -0.570242},{1.104867, 0.721688, -0.549093},{
      1.055132, 0.747029, -0.549093},{1.027910, 0.663247, -0.570242}}],
    Polygon[{{1.104867, 0.721688, -0.549093},{1.154065, 0.789403, -0.514423},{
      1.080997, 0.826633, -0.514423},{1.055132, 0.747029, -0.549093}}],
    Polygon[{{1.154065, 0.789403, -0.514423},{1.199470, 0.851897, -0.467086},{
      1.104867, 0.900099, -0.467086},{1.080997, 0.826633, -0.514423}}],
    Polygon[{{1.199470, 0.851897, -0.467086},{1.239962, 0.907630, -0.408248},{
      1.126156, 0.965617, -0.408248},{1.104867, 0.900099, -0.467086}}],
    Polygon[{{1.239962, 0.907630, -0.408248},{1.274546, 0.955231, -0.339358},{
      1.144338, 1.021576, -0.339358},{1.126156, 0.965617, -0.408248}}],
    Polygon[{{1.274546, 0.955231, -0.339358},{1.302370, 0.993527, -0.262112},{
      1.158965, 1.066595, -0.262112},{1.144338, 1.021576, -0.339358}}],
    Polygon[{{1.302370, 0.993527, -0.262112},{1.322749, 1.021576, -0.178411},{
      1.169679, 1.099568, -0.178411},{1.158965, 1.066595, -0.262112}}],
    Polygon[{{1.322749, 1.021576, -0.178411},{1.335180, 1.038686, -0.090317},{
      1.176214, 1.119683, -0.090317},{1.169679, 1.099568, -0.178411}}],
    Polygon[{{1.335180, 1.038686, -0.090317},{1.339358, 1.044436, 0.000000},{
      1.178411, 1.126443, 0.000000},{1.176214, 1.119683, -0.090317}}],
    Polygon[{{1.339358, 1.044436, 0.000000},{1.335180, 1.038686, 0.090317},{
      1.176214, 1.119683, 0.090317},{1.178411, 1.126443, 0.000000}}],
    Polygon[{{1.335180, 1.038686, 0.090317},{1.322749, 1.021576, 0.178411},{
      1.169679, 1.099568, 0.178411},{1.176214, 1.119683, 0.090317}}],
    Polygon[{{1.322749, 1.021576, 0.178411},{1.302370, 0.993527, 0.262112},{
      1.158965, 1.066595, 0.262112},{1.169679, 1.099568, 0.178411}}],
    Polygon[{{1.302370, 0.993527, 0.262112},{1.274546, 0.955231, 0.339358},{
      1.144338, 1.021576, 0.339358},{1.158965, 1.066595, 0.262112}}],
    Polygon[{{1.274546, 0.955231, 0.339358},{1.239962, 0.907630, 0.408248},{
      1.126156, 0.965617, 0.408248},{1.144338, 1.021576, 0.339358}}],
    Polygon[{{1.239962, 0.907630, 0.408248},{1.199470, 0.851897, 0.467086},{
      1.104867, 0.900099, 0.467086},{1.126156, 0.965617, 0.408248}}],
    Polygon[{{1.199470, 0.851897, 0.467086},{1.154065, 0.789403, 0.514423},{
      1.080997, 0.826633, 0.514423},{1.104867, 0.900099, 0.467086}}],
    Polygon[{{1.154065, 0.789403, 0.514423},{1.104867, 0.721688, 0.549093},{
      1.055132, 0.747029, 0.549093},{1.080997, 0.826633, 0.514423}}],
    Polygon[{{1.104867, 0.721688, 0.549093},{1.053087, 0.650419, 0.570242},{
      1.027910, 0.663247, 0.570242},{1.055132, 0.747029, 0.549093}}],
    Polygon[{{1.027910, 0.663247, -0.570242},{1.055132, 0.747029, -0.549093},{
      1.000000, 0.755761, -0.549093},{1.000000, 0.667668, -0.570242}}],
    Polygon[{{1.055132, 0.747029, -0.549093},{1.080997, 0.826633, -0.514423},{
      1.000000, 0.839462, -0.514423},{1.000000, 0.755761, -0.549093}}],
    Polygon[{{1.080997, 0.826633, -0.514423},{1.104867, 0.900099, -0.467086},{
      1.000000, 0.916708, -0.467086},{1.000000, 0.839462, -0.514423}}],
    Polygon[{{1.104867, 0.900099, -0.467086},{1.126156, 0.965617, -0.408248},{
      1.000000, 0.985599, -0.408248},{1.000000, 0.916708, -0.467086}}],
    Polygon[{{1.126156, 0.965617, -0.408248},{1.144338, 1.021576, -0.339358},{
      1.000000, 1.044436, -0.339358},{1.000000, 0.985599, -0.408248}}],
    Polygon[{{1.144338, 1.021576, -0.339358},{1.158965, 1.066595, -0.262112},{
      1.000000, 1.091773, -0.262112},{1.000000, 1.044436, -0.339358}}],
    Polygon[{{1.158965, 1.066595, -0.262112},{1.169679, 1.099568, -0.178411},{
      1.000000, 1.126443, -0.178411},{1.000000, 1.091773, -0.262112}}],
    Polygon[{{1.169679, 1.099568, -0.178411},{1.176214, 1.119683, -0.090317},{
      1.000000, 1.147592, -0.090317},{1.000000, 1.126443, -0.178411}}],
    Polygon[{{1.176214, 1.119683, -0.090317},{1.178411, 1.126443, 0.000000},{
      1.000000, 1.154701, 0.000000},{1.000000, 1.147592, -0.090317}}],
    Polygon[{{1.178411, 1.126443, 0.000000},{1.176214, 1.119683, 0.090317},{
      1.000000, 1.147592, 0.090317},{1.000000, 1.154701, 0.000000}}],
    Polygon[{{1.176214, 1.119683, 0.090317},{1.169679, 1.099568, 0.178411},{
      1.000000, 1.126443, 0.178411},{1.000000, 1.147592, 0.090317}}],
    Polygon[{{1.169679, 1.099568, 0.178411},{1.158965, 1.066595, 0.262112},{
      1.000000, 1.091773, 0.262112},{1.000000, 1.126443, 0.178411}}],
    Polygon[{{1.158965, 1.066595, 0.262112},{1.144338, 1.021576, 0.339358},{
      1.000000, 1.044436, 0.339358},{1.000000, 1.091773, 0.262112}}],
    Polygon[{{1.144338, 1.021576, 0.339358},{1.126156, 0.965617, 0.408248},{
      1.000000, 0.985599, 0.408248},{1.000000, 1.044436, 0.339358}}],
    Polygon[{{1.126156, 0.965617, 0.408248},{1.104867, 0.900099, 0.467086},{
      1.000000, 0.916708, 0.467086},{1.000000, 0.985599, 0.408248}}],
    Polygon[{{1.104867, 0.900099, 0.467086},{1.080997, 0.826633, 0.514423},{
      1.000000, 0.839462, 0.514423},{1.000000, 0.916708, 0.467086}}],
    Polygon[{{1.080997, 0.826633, 0.514423},{1.055132, 0.747029, 0.549093},{
      1.000000, 0.755761, 0.549093},{1.000000, 0.839462, 0.514423}}],
    Polygon[{{1.055132, 0.747029, 0.549093},{1.027910, 0.663247, 0.570242},{
      1.000000, 0.667668, 0.570242},{1.000000, 0.755761, 0.549093}}],
    Polygon[{{1.000000, 0.667668, -0.570242},{1.000000, 0.755761, -0.549093},{
      0.944868, 0.747029, -0.549093},{0.972090, 0.663247, -0.570242}}],
    Polygon[{{1.000000, 0.755761, -0.549093},{1.000000, 0.839462, -0.514423},{
      0.919003, 0.826633, -0.514423},{0.944868, 0.747029, -0.549093}}],
    Polygon[{{1.000000, 0.839462, -0.514423},{1.000000, 0.916708, -0.467086},{
      0.895133, 0.900099, -0.467086},{0.919003, 0.826633, -0.514423}}],
    Polygon[{{1.000000, 0.916708, -0.467086},{1.000000, 0.985599, -0.408248},{
      0.873844, 0.965617, -0.408248},{0.895133, 0.900099, -0.467086}}],
    Polygon[{{1.000000, 0.985599, -0.408248},{1.000000, 1.044436, -0.339358},{
      0.855662, 1.021576, -0.339358},{0.873844, 0.965617, -0.408248}}],
    Polygon[{{1.000000, 1.044436, -0.339358},{1.000000, 1.091773, -0.262112},{
      0.841035, 1.066595, -0.262112},{0.855662, 1.021576, -0.339358}}],
    Polygon[{{1.000000, 1.091773, -0.262112},{1.000000, 1.126443, -0.178411},{
      0.830321, 1.099568, -0.178411},{0.841035, 1.066595, -0.262112}}],
    Polygon[{{1.000000, 1.126443, -0.178411},{1.000000, 1.147592, -0.090317},{
      0.823785, 1.119683, -0.090317},{0.830321, 1.099568, -0.178411}}],
    Polygon[{{1.000000, 1.147592, -0.090317},{1.000000, 1.154701, 0.000000},{
      0.821589, 1.126443, 0.000000},{0.823785, 1.119683, -0.090317}}],
    Polygon[{{1.000000, 1.154701, 0.000000},{1.000000, 1.147592, 0.090317},{
      0.823785, 1.119683, 0.090317},{0.821589, 1.126443, 0.000000}}],
    Polygon[{{1.000000, 1.147592, 0.090317},{1.000000, 1.126443, 0.178411},{
      0.830321, 1.099568, 0.178411},{0.823785, 1.119683, 0.090317}}],
    Polygon[{{1.000000, 1.126443, 0.178411},{1.000000, 1.091773, 0.262112},{
      0.841035, 1.066595, 0.262112},{0.830321, 1.099568, 0.178411}}],
    Polygon[{{1.000000, 1.091773, 0.262112},{1.000000, 1.044436, 0.339358},{
      0.855662, 1.021576, 0.339358},{0.841035, 1.066595, 0.262112}}],
    Polygon[{{1.000000, 1.044436, 0.339358},{1.000000, 0.985599, 0.408248},{
      0.873844, 0.965617, 0.408248},{0.855662, 1.021576, 0.339358}}],
    Polygon[{{1.000000, 0.985599, 0.408248},{1.000000, 0.916708, 0.467086},{
      0.895133, 0.900099, 0.467086},{0.873844, 0.965617, 0.408248}}],
    Polygon[{{1.000000, 0.916708, 0.467086},{1.000000, 0.839462, 0.514423},{
      0.919003, 0.826633, 0.514423},{0.895133, 0.900099, 0.467086}}],
    Polygon[{{1.000000, 0.839462, 0.514423},{1.000000, 0.755761, 0.549093},{
      0.944868, 0.747029, 0.549093},{0.919003, 0.826633, 0.514423}}],
    Polygon[{{1.000000, 0.755761, 0.549093},{1.000000, 0.667668, 0.570242},{
      0.972090, 0.663247, 0.570242},{0.944868, 0.747029, 0.549093}}],
    Polygon[{{0.972090, 0.663247, -0.570242},{0.944868, 0.747029, -0.549093},{
      0.895133, 0.721688, -0.549093},{0.946913, 0.650419, -0.570242}}],
    Polygon[{{0.944868, 0.747029, -0.549093},{0.919003, 0.826633, -0.514423},{
      0.845935, 0.789403, -0.514423},{0.895133, 0.721688, -0.549093}}],
    Polygon[{{0.919003, 0.826633, -0.514423},{0.895133, 0.900099, -0.467086},{
      0.800530, 0.851897, -0.467086},{0.845935, 0.789403, -0.514423}}],
    Polygon[{{0.895133, 0.900099, -0.467086},{0.873844, 0.965617, -0.408248},{
      0.760038, 0.907630, -0.408248},{0.800530, 0.851897, -0.467086}}],
    Polygon[{{0.873844, 0.965617, -0.408248},{0.855662, 1.021576, -0.339358},{
      0.725454, 0.955231, -0.339358},{0.760038, 0.907630, -0.408248}}],
    Polygon[{{0.855662, 1.021576, -0.339358},{0.841035, 1.066595, -0.262112},{
      0.697630, 0.993527, -0.262112},{0.725454, 0.955231, -0.339358}}],
    Polygon[{{0.841035, 1.066595, -0.262112},{0.830321, 1.099568, -0.178411},{
      0.677251, 1.021576, -0.178411},{0.697630, 0.993527, -0.262112}}],
    Polygon[{{0.830321, 1.099568, -0.178411},{0.823785, 1.119683, -0.090317},{
      0.664820, 1.038686, -0.090317},{0.677251, 1.021576, -0.178411}}],
    Polygon[{{0.823785, 1.119683, -0.090317},{0.821589, 1.126443, 0.000000},{
      0.660642, 1.044436, 0.000000},{0.664820, 1.038686, -0.090317}}],
    Polygon[{{0.821589, 1.126443, 0.000000},{0.823785, 1.119683, 0.090317},{
      0.664820, 1.038686, 0.090317},{0.660642, 1.044436, 0.000000}}],
    Polygon[{{0.823785, 1.119683, 0.090317},{0.830321, 1.099568, 0.178411},{
      0.677251, 1.021576, 0.178411},{0.664820, 1.038686, 0.090317}}],
    Polygon[{{0.830321, 1.099568, 0.178411},{0.841035, 1.066595, 0.262112},{
      0.697630, 0.993527, 0.262112},{0.677251, 1.021576, 0.178411}}],
    Polygon[{{0.841035, 1.066595, 0.262112},{0.855662, 1.021576, 0.339358},{
      0.725454, 0.955231, 0.339358},{0.697630, 0.993527, 0.262112}}],
    Polygon[{{0.855662, 1.021576, 0.339358},{0.873844, 0.965617, 0.408248},{
      0.760038, 0.907630, 0.408248},{0.725454, 0.955231, 0.339358}}],
    Polygon[{{0.873844, 0.965617, 0.408248},{0.895133, 0.900099, 0.467086},{
      0.800530, 0.851897, 0.467086},{0.760038, 0.907630, 0.408248}}],
    Polygon[{{0.895133, 0.900099, 0.467086},{0.919003, 0.826633, 0.514423},{
      0.845935, 0.789403, 0.514423},{0.800530, 0.851897, 0.467086}}],
    Polygon[{{0.919003, 0.826633, 0.514423},{0.944868, 0.747029, 0.549093},{
      0.895133, 0.721688, 0.549093},{0.845935, 0.789403, 0.514423}}],
    Polygon[{{0.944868, 0.747029, 0.549093},{0.972090, 0.663247, 0.570242},{
      0.946913, 0.650419, 0.570242},{0.895133, 0.721688, 0.549093}}],
    Polygon[{{0.946913, 0.650419, -0.570242},{0.895133, 0.721688, -0.549093},{
      0.855662, 0.682218, -0.549093},{0.926932, 0.630438, -0.570242}}],
    Polygon[{{0.895133, 0.721688, -0.549093},{0.845935, 0.789403, -0.514423},{
      0.787947, 0.731416, -0.514423},{0.855662, 0.682218, -0.549093}}],
    Polygon[{{0.845935, 0.789403, -0.514423},{0.800530, 0.851897, -0.467086},{
      0.725454, 0.776820, -0.467086},{0.787947, 0.731416, -0.514423}}],
    Polygon[{{0.800530, 0.851897, -0.467086},{0.760038, 0.907630, -0.408248},{
      0.669720, 0.817313, -0.408248},{0.725454, 0.776820, -0.467086}}],
    Polygon[{{0.760038, 0.907630, -0.408248},{0.725454, 0.955231, -0.339358},{
      0.622119, 0.851897, -0.339358},{0.669720, 0.817313, -0.408248}}],
    Polygon[{{0.725454, 0.955231, -0.339358},{0.697630, 0.993527, -0.262112},{
      0.583823, 0.879720, -0.262112},{0.622119, 0.851897, -0.339358}}],
    Polygon[{{0.697630, 0.993527, -0.262112},{0.677251, 1.021576, -0.178411},{
      0.555775, 0.900099, -0.178411},{0.583823, 0.879720, -0.262112}}],
    Polygon[{{0.677251, 1.021576, -0.178411},{0.664820, 1.038686, -0.090317},{
      0.538664, 0.912530, -0.090317},{0.555775, 0.900099, -0.178411}}],
    Polygon[{{0.664820, 1.038686, -0.090317},{0.660642, 1.044436, 0.000000},{
      0.532914, 0.916708, 0.000000},{0.538664, 0.912530, -0.090317}}],
    Polygon[{{0.660642, 1.044436, 0.000000},{0.664820, 1.038686, 0.090317},{
      0.538664, 0.912530, 0.090317},{0.532914, 0.916708, 0.000000}}],
    Polygon[{{0.664820, 1.038686, 0.090317},{0.677251, 1.021576, 0.178411},{
      0.555775, 0.900099, 0.178411},{0.538664, 0.912530, 0.090317}}],
    Polygon[{{0.677251, 1.021576, 0.178411},{0.697630, 0.993527, 0.262112},{
      0.583823, 0.879720, 0.262112},{0.555775, 0.900099, 0.178411}}],
    Polygon[{{0.697630, 0.993527, 0.262112},{0.725454, 0.955231, 0.339358},{
      0.622119, 0.851897, 0.339358},{0.583823, 0.879720, 0.262112}}],
    Polygon[{{0.725454, 0.955231, 0.339358},{0.760038, 0.907630, 0.408248},{
      0.669720, 0.817313, 0.408248},{0.622119, 0.851897, 0.339358}}],
    Polygon[{{0.760038, 0.907630, 0.408248},{0.800530, 0.851897, 0.467086},{
      0.725454, 0.776820, 0.467086},{0.669720, 0.817313, 0.408248}}],
    Polygon[{{0.800530, 0.851897, 0.467086},{0.845935, 0.789403, 0.514423},{
      0.787947, 0.731416, 0.514423},{0.725454, 0.776820, 0.467086}}],
    Polygon[{{0.845935, 0.789403, 0.514423},{0.895133, 0.721688, 0.549093},{
      0.855662, 0.682218, 0.549093},{0.787947, 0.731416, 0.514423}}],
    Polygon[{{0.895133, 0.721688, 0.549093},{0.946913, 0.650419, 0.570242},{
      0.926932, 0.630438, 0.570242},{0.855662, 0.682218, 0.549093}}],
    Polygon[{{0.926932, 0.630438, -0.570242},{0.855662, 0.682218, -0.549093},{
      0.830321, 0.632482, -0.549093},{0.914103, 0.605260, -0.570242}}],
    Polygon[{{0.855662, 0.682218, -0.549093},{0.787947, 0.731416, -0.514423},{
      0.750717, 0.658347, -0.514423},{0.830321, 0.632482, -0.549093}}],
    Polygon[{{0.787947, 0.731416, -0.514423},{0.725454, 0.776820, -0.467086},{
      0.677251, 0.682218, -0.467086},{0.750717, 0.658347, -0.514423}}],
    Polygon[{{0.725454, 0.776820, -0.467086},{0.669720, 0.817313, -0.408248},{
      0.611733, 0.703506, -0.408248},{0.677251, 0.682218, -0.467086}}],
    Polygon[{{0.669720, 0.817313, -0.408248},{0.622119, 0.851897, -0.339358},{
      0.555775, 0.721688, -0.339358},{0.611733, 0.703506, -0.408248}}],
    Polygon[{{0.622119, 0.851897, -0.339358},{0.583823, 0.879720, -0.262112},{
      0.510755, 0.736316, -0.262112},{0.555775, 0.721688, -0.339358}}],
    Polygon[{{0.583823, 0.879720, -0.262112},{0.555775, 0.900099, -0.178411},{
      0.477782, 0.747029, -0.178411},{0.510755, 0.736316, -0.262112}}],
    Polygon[{{0.555775, 0.900099, -0.178411},{0.538664, 0.912530, -0.090317},{
      0.457667, 0.753565, -0.090317},{0.477782, 0.747029, -0.178411}}],
    Polygon[{{0.538664, 0.912530, -0.090317},{0.532914, 0.916708, 0.000000},{
      0.450907, 0.755761, 0.000000},{0.457667, 0.753565, -0.090317}}],
    Polygon[{{0.532914, 0.916708, 0.000000},{0.538664, 0.912530, 0.090317},{
      0.457667, 0.753565, 0.090317},{0.450907, 0.755761, 0.000000}}],
    Polygon[{{0.538664, 0.912530, 0.090317},{0.555775, 0.900099, 0.178411},{
      0.477782, 0.747029, 0.178411},{0.457667, 0.753565, 0.090317}}],
    Polygon[{{0.555775, 0.900099, 0.178411},{0.583823, 0.879720, 0.262112},{
      0.510755, 0.736316, 0.262112},{0.477782, 0.747029, 0.178411}}],
    Polygon[{{0.583823, 0.879720, 0.262112},{0.622119, 0.851897, 0.339358},{
      0.555775, 0.721688, 0.339358},{0.510755, 0.736316, 0.262112}}],
    Polygon[{{0.622119, 0.851897, 0.339358},{0.669720, 0.817313, 0.408248},{
      0.611733, 0.703506, 0.408248},{0.555775, 0.721688, 0.339358}}],
    Polygon[{{0.669720, 0.817313, 0.408248},{0.725454, 0.776820, 0.467086},{
      0.677251, 0.682218, 0.467086},{0.611733, 0.703506, 0.408248}}],
    Polygon[{{0.725454, 0.776820, 0.467086},{0.787947, 0.731416, 0.514423},{
      0.750717, 0.658347, 0.514423},{0.677251, 0.682218, 0.467086}}],
    Polygon[{{0.787947, 0.731416, 0.514423},{0.855662, 0.682218, 0.549093},{
      0.830321, 0.632482, 0.549093},{0.750717, 0.658347, 0.514423}}],
    Polygon[{{0.855662, 0.682218, 0.549093},{0.926932, 0.630438, 0.570242},{
      0.914103, 0.605260, 0.570242},{0.830321, 0.632482, 0.549093}}],
    Polygon[{{0.914103, 0.605260, -0.570242},{0.830321, 0.632482, -0.549093},{
      0.821589, 0.577350, -0.549093},{0.909683, 0.577350, -0.570242}}],
    Polygon[{{0.830321, 0.632482, -0.549093},{0.750717, 0.658347, -0.514423},{
      0.737888, 0.577350, -0.514423},{0.821589, 0.577350, -0.549093}}],
    Polygon[{{0.750717, 0.658347, -0.514423},{0.677251, 0.682218, -0.467086},{
      0.660642, 0.577350, -0.467086},{0.737888, 0.577350, -0.514423}}],
    Polygon[{{0.677251, 0.682218, -0.467086},{0.611733, 0.703506, -0.408248},{
      0.591752, 0.577350, -0.408248},{0.660642, 0.577350, -0.467086}}],
    Polygon[{{0.611733, 0.703506, -0.408248},{0.555775, 0.721688, -0.339358},{
      0.532914, 0.577350, -0.339358},{0.591752, 0.577350, -0.408248}}],
    Polygon[{{0.555775, 0.721688, -0.339358},{0.510755, 0.736316, -0.262112},{
      0.485577, 0.577350, -0.262112},{0.532914, 0.577350, -0.339358}}],
    Polygon[{{0.510755, 0.736316, -0.262112},{0.477782, 0.747029, -0.178411},{
      0.450907, 0.577350, -0.178411},{0.485577, 0.577350, -0.262112}}],
    Polygon[{{0.477782, 0.747029, -0.178411},{0.457667, 0.753565, -0.090317},{
      0.429758, 0.577350, -0.090317},{0.450907, 0.577350, -0.178411}}],
    Polygon[{{0.457667, 0.753565, -0.090317},{0.450907, 0.755761, 0.000000},{
      0.422650, 0.577350, 0.000000},{0.429758, 0.577350, -0.090317}}],
    Polygon[{{0.450907, 0.755761, 0.000000},{0.457667, 0.753565, 0.090317},{
      0.429758, 0.577350, 0.090317},{0.422650, 0.577350, 0.000000}}],
    Polygon[{{0.457667, 0.753565, 0.090317},{0.477782, 0.747029, 0.178411},{
      0.450907, 0.577350, 0.178411},{0.429758, 0.577350, 0.090317}}],
    Polygon[{{0.477782, 0.747029, 0.178411},{0.510755, 0.736316, 0.262112},{
      0.485577, 0.577350, 0.262112},{0.450907, 0.577350, 0.178411}}],
    Polygon[{{0.510755, 0.736316, 0.262112},{0.555775, 0.721688, 0.339358},{
      0.532914, 0.577350, 0.339358},{0.485577, 0.577350, 0.262112}}],
    Polygon[{{0.555775, 0.721688, 0.339358},{0.611733, 0.703506, 0.408248},{
      0.591752, 0.577350, 0.408248},{0.532914, 0.577350, 0.339358}}],
    Polygon[{{0.611733, 0.703506, 0.408248},{0.677251, 0.682218, 0.467086},{
      0.660642, 0.577350, 0.467086},{0.591752, 0.577350, 0.408248}}],
    Polygon[{{0.677251, 0.682218, 0.467086},{0.750717, 0.658347, 0.514423},{
      0.737888, 0.577350, 0.514423},{0.660642, 0.577350, 0.467086}}],
    Polygon[{{0.750717, 0.658347, 0.514423},{0.830321, 0.632482, 0.549093},{
      0.821589, 0.577350, 0.549093},{0.737888, 0.577350, 0.514423}}],
    Polygon[{{0.830321, 0.632482, 0.549093},{0.914103, 0.605260, 0.570242},{
      0.909683, 0.577350, 0.570242},{0.821589, 0.577350, 0.549093}}],
    Polygon[{{0.909683, 0.577350, -0.570242},{0.821589, 0.577350, -0.549093},{
      0.830321, 0.522218, -0.549093},{0.914103, 0.549441, -0.570242}}],
    Polygon[{{0.821589, 0.577350, -0.549093},{0.737888, 0.577350, -0.514423},{
      0.750717, 0.496353, -0.514423},{0.830321, 0.522218, -0.549093}}],
    Polygon[{{0.737888, 0.577350, -0.514423},{0.660642, 0.577350, -0.467086},{
      0.677251, 0.472483, -0.467086},{0.750717, 0.496353, -0.514423}}],
    Polygon[{{0.660642, 0.577350, -0.467086},{0.591752, 0.577350, -0.408248},{
      0.611733, 0.451195, -0.408248},{0.677251, 0.472483, -0.467086}}],
    Polygon[{{0.591752, 0.577350, -0.408248},{0.532914, 0.577350, -0.339358},{
      0.555775, 0.433013, -0.339358},{0.611733, 0.451195, -0.408248}}],
    Polygon[{{0.532914, 0.577350, -0.339358},{0.485577, 0.577350, -0.262112},{
      0.510755, 0.418385, -0.262112},{0.555775, 0.433013, -0.339358}}],
    Polygon[{{0.485577, 0.577350, -0.262112},{0.450907, 0.577350, -0.178411},{
      0.477782, 0.407671, -0.178411},{0.510755, 0.418385, -0.262112}}],
    Polygon[{{0.450907, 0.577350, -0.178411},{0.429758, 0.577350, -0.090317},{
      0.457667, 0.401136, -0.090317},{0.477782, 0.407671, -0.178411}}],
    Polygon[{{0.429758, 0.577350, -0.090317},{0.422650, 0.577350, 0.000000},{
      0.450907, 0.398939, 0.000000},{0.457667, 0.401136, -0.090317}}],
    Polygon[{{0.422650, 0.577350, 0.000000},{0.429758, 0.577350, 0.090317},{
      0.457667, 0.401136, 0.090317},{0.450907, 0.398939, 0.000000}}],
    Polygon[{{0.429758, 0.577350, 0.090317},{0.450907, 0.577350, 0.178411},{
      0.477782, 0.407671, 0.178411},{0.457667, 0.401136, 0.090317}}],
    Polygon[{{0.450907, 0.577350, 0.178411},{0.485577, 0.577350, 0.262112},{
      0.510755, 0.418385, 0.262112},{0.477782, 0.407671, 0.178411}}],
    Polygon[{{0.485577, 0.577350, 0.262112},{0.532914, 0.577350, 0.339358},{
      0.555775, 0.433013, 0.339358},{0.510755, 0.418385, 0.262112}}],
    Polygon[{{0.532914, 0.577350, 0.339358},{0.591752, 0.577350, 0.408248},{
      0.611733, 0.451195, 0.408248},{0.555775, 0.433013, 0.339358}}],
    Polygon[{{0.591752, 0.577350, 0.408248},{0.660642, 0.577350, 0.467086},{
      0.677251, 0.472483, 0.467086},{0.611733, 0.451195, 0.408248}}],
    Polygon[{{0.660642, 0.577350, 0.467086},{0.737888, 0.577350, 0.514423},{
      0.750717, 0.496353, 0.514423},{0.677251, 0.472483, 0.467086}}],
    Polygon[{{0.737888, 0.577350, 0.514423},{0.821589, 0.577350, 0.549093},{
      0.830321, 0.522218, 0.549093},{0.750717, 0.496353, 0.514423}}],
    Polygon[{{0.821589, 0.577350, 0.549093},{0.909683, 0.577350, 0.570242},{
      0.914103, 0.549441, 0.570242},{0.830321, 0.522218, 0.549093}}],
    Polygon[{{0.914103, 0.549441, -0.570242},{0.830321, 0.522218, -0.549093},{
      0.855662, 0.472483, -0.549093},{0.926932, 0.524263, -0.570242}}],
    Polygon[{{0.830321, 0.522218, -0.549093},{0.750717, 0.496353, -0.514423},{
      0.787947, 0.423285, -0.514423},{0.855662, 0.472483, -0.549093}}],
    Polygon[{{0.750717, 0.496353, -0.514423},{0.677251, 0.472483, -0.467086},{
      0.725454, 0.377881, -0.467086},{0.787947, 0.423285, -0.514423}}],
    Polygon[{{0.677251, 0.472483, -0.467086},{0.611733, 0.451195, -0.408248},{
      0.669720, 0.337388, -0.408248},{0.725454, 0.377881, -0.467086}}],
    Polygon[{{0.611733, 0.451195, -0.408248},{0.555775, 0.433013, -0.339358},{
      0.622119, 0.302804, -0.339358},{0.669720, 0.337388, -0.408248}}],
    Polygon[{{0.555775, 0.433013, -0.339358},{0.510755, 0.418385, -0.262112},{
      0.583823, 0.274980, -0.262112},{0.622119, 0.302804, -0.339358}}],
    Polygon[{{0.510755, 0.418385, -0.262112},{0.477782, 0.407671, -0.178411},{
      0.555775, 0.254602, -0.178411},{0.583823, 0.274980, -0.262112}}],
    Polygon[{{0.477782, 0.407671, -0.178411},{0.457667, 0.401136, -0.090317},{
      0.538664, 0.242170, -0.090317},{0.555775, 0.254602, -0.178411}}],
    Polygon[{{0.457667, 0.401136, -0.090317},{0.450907, 0.398939, 0.000000},{
      0.532914, 0.237992, 0.000000},{0.538664, 0.242170, -0.090317}}],
    Polygon[{{0.450907, 0.398939, 0.000000},{0.457667, 0.401136, 0.090317},{
      0.538664, 0.242170, 0.090317},{0.532914, 0.237992, 0.000000}}],
    Polygon[{{0.457667, 0.401136, 0.090317},{0.477782, 0.407671, 0.178411},{
      0.555775, 0.254602, 0.178411},{0.538664, 0.242170, 0.090317}}],
    Polygon[{{0.477782, 0.407671, 0.178411},{0.510755, 0.418385, 0.262112},{
      0.583823, 0.274980, 0.262112},{0.555775, 0.254602, 0.178411}}],
    Polygon[{{0.510755, 0.418385, 0.262112},{0.555775, 0.433013, 0.339358},{
      0.622119, 0.302804, 0.339358},{0.583823, 0.274980, 0.262112}}],
    Polygon[{{0.555775, 0.433013, 0.339358},{0.611733, 0.451195, 0.408248},{
      0.669720, 0.337388, 0.408248},{0.622119, 0.302804, 0.339358}}],
    Polygon[{{0.611733, 0.451195, 0.408248},{0.677251, 0.472483, 0.467086},{
      0.725454, 0.377881, 0.467086},{0.669720, 0.337388, 0.408248}}],
    Polygon[{{0.677251, 0.472483, 0.467086},{0.750717, 0.496353, 0.514423},{
      0.787947, 0.423285, 0.514423},{0.725454, 0.377881, 0.467086}}],
    Polygon[{{0.750717, 0.496353, 0.514423},{0.830321, 0.522218, 0.549093},{
      0.855662, 0.472483, 0.549093},{0.787947, 0.423285, 0.514423}}],
    Polygon[{{0.830321, 0.522218, 0.549093},{0.914103, 0.549441, 0.570242},{
      0.926932, 0.524263, 0.570242},{0.855662, 0.472483, 0.549093}}],
    Polygon[{{0.926932, 0.524263, -0.570242},{0.855662, 0.472483, -0.549093},{
      0.895133, 0.433013, -0.549093},{0.946913, 0.504282, -0.570242}}],
    Polygon[{{0.855662, 0.472483, -0.549093},{0.787947, 0.423285, -0.514423},{
      0.845935, 0.365298, -0.514423},{0.895133, 0.433013, -0.549093}}],
    Polygon[{{0.787947, 0.423285, -0.514423},{0.725454, 0.377881, -0.467086},{
      0.800530, 0.302804, -0.467086},{0.845935, 0.365298, -0.514423}}],
    Polygon[{{0.725454, 0.377881, -0.467086},{0.669720, 0.337388, -0.408248},{
      0.760038, 0.247070, -0.408248},{0.800530, 0.302804, -0.467086}}],
    Polygon[{{0.669720, 0.337388, -0.408248},{0.622119, 0.302804, -0.339358},{
      0.725454, 0.199470, -0.339358},{0.760038, 0.247070, -0.408248}}],
    Polygon[{{0.622119, 0.302804, -0.339358},{0.583823, 0.274980, -0.262112},{
      0.697630, 0.161173, -0.262112},{0.725454, 0.199470, -0.339358}}],
    Polygon[{{0.583823, 0.274980, -0.262112},{0.555775, 0.254602, -0.178411},{
      0.677251, 0.133125, -0.178411},{0.697630, 0.161173, -0.262112}}],
    Polygon[{{0.555775, 0.254602, -0.178411},{0.538664, 0.242170, -0.090317},{
      0.664820, 0.116015, -0.090317},{0.677251, 0.133125, -0.178411}}],
    Polygon[{{0.538664, 0.242170, -0.090317},{0.532914, 0.237992, 0.000000},{
      0.660642, 0.110264, 0.000000},{0.664820, 0.116015, -0.090317}}],
    Polygon[{{0.532914, 0.237992, 0.000000},{0.538664, 0.242170, 0.090317},{
      0.664820, 0.116015, 0.090317},{0.660642, 0.110264, 0.000000}}],
    Polygon[{{0.538664, 0.242170, 0.090317},{0.555775, 0.254602, 0.178411},{
      0.677251, 0.133125, 0.178411},{0.664820, 0.116015, 0.090317}}],
    Polygon[{{0.555775, 0.254602, 0.178411},{0.583823, 0.274980, 0.262112},{
      0.697630, 0.161173, 0.262112},{0.677251, 0.133125, 0.178411}}],
    Polygon[{{0.583823, 0.274980, 0.262112},{0.622119, 0.302804, 0.339358},{
      0.725454, 0.199470, 0.339358},{0.697630, 0.161173, 0.262112}}],
    Polygon[{{0.622119, 0.302804, 0.339358},{0.669720, 0.337388, 0.408248},{
      0.760038, 0.247070, 0.408248},{0.725454, 0.199470, 0.339358}}],
    Polygon[{{0.669720, 0.337388, 0.408248},{0.725454, 0.377881, 0.467086},{
      0.800530, 0.302804, 0.467086},{0.760038, 0.247070, 0.408248}}],
    Polygon[{{0.725454, 0.377881, 0.467086},{0.787947, 0.423285, 0.514423},{
      0.845935, 0.365298, 0.514423},{0.800530, 0.302804, 0.467086}}],
    Polygon[{{0.787947, 0.423285, 0.514423},{0.855662, 0.472483, 0.549093},{
      0.895133, 0.433013, 0.549093},{0.845935, 0.365298, 0.514423}}],
    Polygon[{{0.855662, 0.472483, 0.549093},{0.926932, 0.524263, 0.570242},{
      0.946913, 0.504282, 0.570242},{0.895133, 0.433013, 0.549093}}],
    Polygon[{{0.946913, 0.504282, -0.570242},{0.895133, 0.433013, -0.549093},{
      0.944868, 0.407671, -0.549093},{0.972090, 0.491453, -0.570242}}],
    Polygon[{{0.895133, 0.433013, -0.549093},{0.845935, 0.365298, -0.514423},{
      0.919003, 0.328067, -0.514423},{0.944868, 0.407671, -0.549093}}],
    Polygon[{{0.845935, 0.365298, -0.514423},{0.800530, 0.302804, -0.467086},{
      0.895133, 0.254602, -0.467086},{0.919003, 0.328067, -0.514423}}],
    Polygon[{{0.800530, 0.302804, -0.467086},{0.760038, 0.247070, -0.408248},{
      0.873844, 0.189083, -0.408248},{0.895133, 0.254602, -0.467086}}],
    Polygon[{{0.760038, 0.247070, -0.408248},{0.725454, 0.199470, -0.339358},{
      0.855662, 0.133125, -0.339358},{0.873844, 0.189083, -0.408248}}],
    Polygon[{{0.725454, 0.199470, -0.339358},{0.697630, 0.161173, -0.262112},{
      0.841035, 0.088105, -0.262112},{0.855662, 0.133125, -0.339358}}],
    Polygon[{{0.697630, 0.161173, -0.262112},{0.677251, 0.133125, -0.178411},{
      0.830321, 0.055132, -0.178411},{0.841035, 0.088105, -0.262112}}],
    Polygon[{{0.677251, 0.133125, -0.178411},{0.664820, 0.116015, -0.090317},{
      0.823785, 0.035018, -0.090317},{0.830321, 0.055132, -0.178411}}],
    Polygon[{{0.664820, 0.116015, -0.090317},{0.660642, 0.110264, 0.000000},{
      0.821589, 0.028258, 0.000000},{0.823785, 0.035018, -0.090317}}],
    Polygon[{{0.660642, 0.110264, 0.000000},{0.664820, 0.116015, 0.090317},{
      0.823785, 0.035018, 0.090317},{0.821589, 0.028258, 0.000000}}],
    Polygon[{{0.664820, 0.116015, 0.090317},{0.677251, 0.133125, 0.178411},{
      0.830321, 0.055132, 0.178411},{0.823785, 0.035018, 0.090317}}],
    Polygon[{{0.677251, 0.133125, 0.178411},{0.697630, 0.161173, 0.262112},{
      0.841035, 0.088105, 0.262112},{0.830321, 0.055132, 0.178411}}],
    Polygon[{{0.697630, 0.161173, 0.262112},{0.725454, 0.199470, 0.339358},{
      0.855662, 0.133125, 0.339358},{0.841035, 0.088105, 0.262112}}],
    Polygon[{{0.725454, 0.199470, 0.339358},{0.760038, 0.247070, 0.408248},{
      0.873844, 0.189083, 0.408248},{0.855662, 0.133125, 0.339358}}],
    Polygon[{{0.760038, 0.247070, 0.408248},{0.800530, 0.302804, 0.467086},{
      0.895133, 0.254602, 0.467086},{0.873844, 0.189083, 0.408248}}],
    Polygon[{{0.800530, 0.302804, 0.467086},{0.845935, 0.365298, 0.514423},{
      0.919003, 0.328067, 0.514423},{0.895133, 0.254602, 0.467086}}],
    Polygon[{{0.845935, 0.365298, 0.514423},{0.895133, 0.433013, 0.549093},{
      0.944868, 0.407671, 0.549093},{0.919003, 0.328067, 0.514423}}],
    Polygon[{{0.895133, 0.433013, 0.549093},{0.946913, 0.504282, 0.570242},{
      0.972090, 0.491453, 0.570242},{0.944868, 0.407671, 0.549093}}],
    Polygon[{{0.972090, 0.491453, -0.570242},{0.944868, 0.407671, -0.549093},{
      1.000000, 0.398939, -0.549093},{1.000000, 0.487033, -0.570242}}],
    Polygon[{{0.944868, 0.407671, -0.549093},{0.919003, 0.328067, -0.514423},{
      1.000000, 0.315239, -0.514423},{1.000000, 0.398939, -0.549093}}],
    Polygon[{{0.919003, 0.328067, -0.514423},{0.895133, 0.254602, -0.467086},{
      1.000000, 0.237992, -0.467086},{1.000000, 0.315239, -0.514423}}],
    Polygon[{{0.895133, 0.254602, -0.467086},{0.873844, 0.189083, -0.408248},{
      1.000000, 0.169102, -0.408248},{1.000000, 0.237992, -0.467086}}],
    Polygon[{{0.873844, 0.189083, -0.408248},{0.855662, 0.133125, -0.339358},{
      1.000000, 0.110264, -0.339358},{1.000000, 0.169102, -0.408248}}],
    Polygon[{{0.855662, 0.133125, -0.339358},{0.841035, 0.088105, -0.262112},{
      1.000000, 0.062927, -0.262112},{1.000000, 0.110264, -0.339358}}],
    Polygon[{{0.841035, 0.088105, -0.262112},{0.830321, 0.055132, -0.178411},{
      1.000000, 0.028258, -0.178411},{1.000000, 0.062927, -0.262112}}],
    Polygon[{{0.830321, 0.055132, -0.178411},{0.823785, 0.035018, -0.090317},{
      1.000000, 0.007108, -0.090317},{1.000000, 0.028258, -0.178411}}],
    Polygon[{{0.823785, 0.035018, -0.090317},{0.821589, 0.028258, 0.000000},{
      1.000000, 0.000000, 0.000000},{1.000000, 0.007108, -0.090317}}],
    Polygon[{{0.821589, 0.028258, 0.000000},{0.823785, 0.035018, 0.090317},{
      1.000000, 0.007108, 0.090317},{1.000000, 0.000000, 0.000000}}],
    Polygon[{{0.823785, 0.035018, 0.090317},{0.830321, 0.055132, 0.178411},{
      1.000000, 0.028258, 0.178411},{1.000000, 0.007108, 0.090317}}],
    Polygon[{{0.830321, 0.055132, 0.178411},{0.841035, 0.088105, 0.262112},{
      1.000000, 0.062927, 0.262112},{1.000000, 0.028258, 0.178411}}],
    Polygon[{{0.841035, 0.088105, 0.262112},{0.855662, 0.133125, 0.339358},{
      1.000000, 0.110264, 0.339358},{1.000000, 0.062927, 0.262112}}],
    Polygon[{{0.855662, 0.133125, 0.339358},{0.873844, 0.189083, 0.408248},{
      1.000000, 0.169102, 0.408248},{1.000000, 0.110264, 0.339358}}],
    Polygon[{{0.873844, 0.189083, 0.408248},{0.895133, 0.254602, 0.467086},{
      1.000000, 0.237992, 0.467086},{1.000000, 0.169102, 0.408248}}],
    Polygon[{{0.895133, 0.254602, 0.467086},{0.919003, 0.328067, 0.514423},{
      1.000000, 0.315239, 0.514423},{1.000000, 0.237992, 0.467086}}],
    Polygon[{{0.919003, 0.328067, 0.514423},{0.944868, 0.407671, 0.549093},{
      1.000000, 0.398939, 0.549093},{1.000000, 0.315239, 0.514423}}],
    Polygon[{{0.944868, 0.407671, 0.549093},{0.972090, 0.491453, 0.570242},{
      1.000000, 0.487033, 0.570242},{1.000000, 0.398939, 0.549093}}],
    Polygon[{{1.000000, 0.487033, -0.570242},{1.000000, 0.398939, -0.549093},{
      1.055132, 0.407671, -0.549093},{1.027910, 0.491453, -0.570242}}],
    Polygon[{{1.000000, 0.398939, -0.549093},{1.000000, 0.315239, -0.514423},{
      1.080997, 0.328067, -0.514423},{1.055132, 0.407671, -0.549093}}],
    Polygon[{{1.000000, 0.315239, -0.514423},{1.000000, 0.237992, -0.467086},{
      1.104867, 0.254602, -0.467086},{1.080997, 0.328067, -0.514423}}],
    Polygon[{{1.000000, 0.237992, -0.467086},{1.000000, 0.169102, -0.408248},{
      1.126156, 0.189083, -0.408248},{1.104867, 0.254602, -0.467086}}],
    Polygon[{{1.000000, 0.169102, -0.408248},{1.000000, 0.110264, -0.339358},{
      1.144338, 0.133125, -0.339358},{1.126156, 0.189083, -0.408248}}],
    Polygon[{{1.000000, 0.110264, -0.339358},{1.000000, 0.062927, -0.262112},{
      1.158965, 0.088105, -0.262112},{1.144338, 0.133125, -0.339358}}],
    Polygon[{{1.000000, 0.062927, -0.262112},{1.000000, 0.028258, -0.178411},{
      1.169679, 0.055132, -0.178411},{1.158965, 0.088105, -0.262112}}],
    Polygon[{{1.000000, 0.028258, -0.178411},{1.000000, 0.007108, -0.090317},{
      1.176214, 0.035018, -0.090317},{1.169679, 0.055132, -0.178411}}],
    Polygon[{{1.000000, 0.007108, -0.090317},{1.000000, 0.000000, 0.000000},{
      1.178411, 0.028258, 0.000000},{1.176214, 0.035018, -0.090317}}],
    Polygon[{{1.000000, 0.000000, 0.000000},{1.000000, 0.007108, 0.090317},{
      1.176214, 0.035018, 0.090317},{1.178411, 0.028258, 0.000000}}],
    Polygon[{{1.000000, 0.007108, 0.090317},{1.000000, 0.028258, 0.178411},{
      1.169679, 0.055132, 0.178411},{1.176214, 0.035018, 0.090317}}],
    Polygon[{{1.000000, 0.028258, 0.178411},{1.000000, 0.062927, 0.262112},{
      1.158965, 0.088105, 0.262112},{1.169679, 0.055132, 0.178411}}],
    Polygon[{{1.000000, 0.062927, 0.262112},{1.000000, 0.110264, 0.339358},{
      1.144338, 0.133125, 0.339358},{1.158965, 0.088105, 0.262112}}],
    Polygon[{{1.000000, 0.110264, 0.339358},{1.000000, 0.169102, 0.408248},{
      1.126156, 0.189083, 0.408248},{1.144338, 0.133125, 0.339358}}],
    Polygon[{{1.000000, 0.169102, 0.408248},{1.000000, 0.237992, 0.467086},{
      1.104867, 0.254602, 0.467086},{1.126156, 0.189083, 0.408248}}],
    Polygon[{{1.000000, 0.237992, 0.467086},{1.000000, 0.315239, 0.514423},{
      1.080997, 0.328067, 0.514423},{1.104867, 0.254602, 0.467086}}],
    Polygon[{{1.000000, 0.315239, 0.514423},{1.000000, 0.398939, 0.549093},{
      1.055132, 0.407671, 0.549093},{1.080997, 0.328067, 0.514423}}],
    Polygon[{{1.000000, 0.398939, 0.549093},{1.000000, 0.487033, 0.570242},{
      1.027910, 0.491453, 0.570242},{1.055132, 0.407671, 0.549093}}],
    Polygon[{{1.027910, 0.491453, -0.570242},{1.055132, 0.407671, -0.549093},{
      1.104867, 0.433013, -0.549093},{1.053087, 0.504282, -0.570242}}],
    Polygon[{{1.055132, 0.407671, -0.549093},{1.080997, 0.328067, -0.514423},{
      1.154065, 0.365298, -0.514423},{1.104867, 0.433013, -0.549093}}],
    Polygon[{{1.080997, 0.328067, -0.514423},{1.104867, 0.254602, -0.467086},{
      1.199470, 0.302804, -0.467086},{1.154065, 0.365298, -0.514423}}],
    Polygon[{{1.104867, 0.254602, -0.467086},{1.126156, 0.189083, -0.408248},{
      1.239962, 0.247070, -0.408248},{1.199470, 0.302804, -0.467086}}],
    Polygon[{{1.126156, 0.189083, -0.408248},{1.144338, 0.133125, -0.339358},{
      1.274546, 0.199470, -0.339358},{1.239962, 0.247070, -0.408248}}],
    Polygon[{{1.144338, 0.133125, -0.339358},{1.158965, 0.088105, -0.262112},{
      1.302370, 0.161173, -0.262112},{1.274546, 0.199470, -0.339358}}],
    Polygon[{{1.158965, 0.088105, -0.262112},{1.169679, 0.055132, -0.178411},{
      1.322749, 0.133125, -0.178411},{1.302370, 0.161173, -0.262112}}],
    Polygon[{{1.169679, 0.055132, -0.178411},{1.176214, 0.035018, -0.090317},{
      1.335180, 0.116015, -0.090317},{1.322749, 0.133125, -0.178411}}],
    Polygon[{{1.176214, 0.035018, -0.090317},{1.178411, 0.028258, 0.000000},{
      1.339358, 0.110264, 0.000000},{1.335180, 0.116015, -0.090317}}],
    Polygon[{{1.178411, 0.028258, 0.000000},{1.176214, 0.035018, 0.090317},{
      1.335180, 0.116015, 0.090317},{1.339358, 0.110264, 0.000000}}],
    Polygon[{{1.176214, 0.035018, 0.090317},{1.169679, 0.055132, 0.178411},{
      1.322749, 0.133125, 0.178411},{1.335180, 0.116015, 0.090317}}],
    Polygon[{{1.169679, 0.055132, 0.178411},{1.158965, 0.088105, 0.262112},{
      1.302370, 0.161173, 0.262112},{1.322749, 0.133125, 0.178411}}],
    Polygon[{{1.158965, 0.088105, 0.262112},{1.144338, 0.133125, 0.339358},{
      1.274546, 0.199470, 0.339358},{1.302370, 0.161173, 0.262112}}],
    Polygon[{{1.144338, 0.133125, 0.339358},{1.126156, 0.189083, 0.408248},{
      1.239962, 0.247070, 0.408248},{1.274546, 0.199470, 0.339358}}],
    Polygon[{{1.126156, 0.189083, 0.408248},{1.104867, 0.254602, 0.467086},{
      1.199470, 0.302804, 0.467086},{1.239962, 0.247070, 0.408248}}],
    Polygon[{{1.104867, 0.254602, 0.467086},{1.080997, 0.328067, 0.514423},{
      1.154065, 0.365298, 0.514423},{1.199470, 0.302804, 0.467086}}],
    Polygon[{{1.080997, 0.328067, 0.514423},{1.055132, 0.407671, 0.549093},{
      1.104867, 0.433013, 0.549093},{1.154065, 0.365298, 0.514423}}],
    Polygon[{{1.055132, 0.407671, 0.549093},{1.027910, 0.491453, 0.570242},{
      1.053087, 0.504282, 0.570242},{1.104867, 0.433013, 0.549093}}],
    Polygon[{{1.053087, 0.504282, -0.570242},{1.104867, 0.433013, -0.549093},{
      1.144338, 0.472483, -0.549093},{1.073068, 0.524263, -0.570242}}],
    Polygon[{{1.104867, 0.433013, -0.549093},{1.154065, 0.365298, -0.514423},{
      1.212053, 0.423285, -0.514423},{1.144338, 0.472483, -0.549093}}],
    Polygon[{{1.154065, 0.365298, -0.514423},{1.199470, 0.302804, -0.467086},{
      1.274546, 0.377881, -0.467086},{1.212053, 0.423285, -0.514423}}],
    Polygon[{{1.199470, 0.302804, -0.467086},{1.239962, 0.247070, -0.408248},{
      1.330280, 0.337388, -0.408248},{1.274546, 0.377881, -0.467086}}],
    Polygon[{{1.239962, 0.247070, -0.408248},{1.274546, 0.199470, -0.339358},{
      1.377881, 0.302804, -0.339358},{1.330280, 0.337388, -0.408248}}],
    Polygon[{{1.274546, 0.199470, -0.339358},{1.302370, 0.161173, -0.262112},{
      1.416177, 0.274980, -0.262112},{1.377881, 0.302804, -0.339358}}],
    Polygon[{{1.302370, 0.161173, -0.262112},{1.322749, 0.133125, -0.178411},{
      1.444225, 0.254602, -0.178411},{1.416177, 0.274980, -0.262112}}],
    Polygon[{{1.322749, 0.133125, -0.178411},{1.335180, 0.116015, -0.090317},{
      1.461336, 0.242170, -0.090317},{1.444225, 0.254602, -0.178411}}],
    Polygon[{{1.335180, 0.116015, -0.090317},{1.339358, 0.110264, 0.000000},{
      1.467086, 0.237992, 0.000000},{1.461336, 0.242170, -0.090317}}],
    Polygon[{{1.339358, 0.110264, 0.000000},{1.335180, 0.116015, 0.090317},{
      1.461336, 0.242170, 0.090317},{1.467086, 0.237992, 0.000000}}],
    Polygon[{{1.335180, 0.116015, 0.090317},{1.322749, 0.133125, 0.178411},{
      1.444225, 0.254602, 0.178411},{1.461336, 0.242170, 0.090317}}],
    Polygon[{{1.322749, 0.133125, 0.178411},{1.302370, 0.161173, 0.262112},{
      1.416177, 0.274980, 0.262112},{1.444225, 0.254602, 0.178411}}],
    Polygon[{{1.302370, 0.161173, 0.262112},{1.274546, 0.199470, 0.339358},{
      1.377881, 0.302804, 0.339358},{1.416177, 0.274980, 0.262112}}],
    Polygon[{{1.274546, 0.199470, 0.339358},{1.239962, 0.247070, 0.408248},{
      1.330280, 0.337388, 0.408248},{1.377881, 0.302804, 0.339358}}],
    Polygon[{{1.239962, 0.247070, 0.408248},{1.199470, 0.302804, 0.467086},{
      1.274546, 0.377881, 0.467086},{1.330280, 0.337388, 0.408248}}],
    Polygon[{{1.199470, 0.302804, 0.467086},{1.154065, 0.365298, 0.514423},{
      1.212053, 0.423285, 0.514423},{1.274546, 0.377881, 0.467086}}],
    Polygon[{{1.154065, 0.365298, 0.514423},{1.104867, 0.433013, 0.549093},{
      1.144338, 0.472483, 0.549093},{1.212053, 0.423285, 0.514423}}],
    Polygon[{{1.104867, 0.433013, 0.549093},{1.053087, 0.504282, 0.570242},{
      1.073068, 0.524263, 0.570242},{1.144338, 0.472483, 0.549093}}],
    Polygon[{{1.073068, 0.524263, -0.570242},{1.144338, 0.472483, -0.549093},{
      1.169679, 0.522218, -0.549093},{1.085897, 0.549441, -0.570242}}],
    Polygon[{{1.144338, 0.472483, -0.549093},{1.212053, 0.423285, -0.514423},{
      1.249283, 0.496353, -0.514423},{1.169679, 0.522218, -0.549093}}],
    Polygon[{{1.212053, 0.423285, -0.514423},{1.274546, 0.377881, -0.467086},{
      1.322749, 0.472483, -0.467086},{1.249283, 0.496353, -0.514423}}],
    Polygon[{{1.274546, 0.377881, -0.467086},{1.330280, 0.337388, -0.408248},{
      1.388267, 0.451195, -0.408248},{1.322749, 0.472483, -0.467086}}],
    Polygon[{{1.330280, 0.337388, -0.408248},{1.377881, 0.302804, -0.339358},{
      1.444225, 0.433013, -0.339358},{1.388267, 0.451195, -0.408248}}],
    Polygon[{{1.377881, 0.302804, -0.339358},{1.416177, 0.274980, -0.262112},{
      1.489245, 0.418385, -0.262112},{1.444225, 0.433013, -0.339358}}],
    Polygon[{{1.416177, 0.274980, -0.262112},{1.444225, 0.254602, -0.178411},{
      1.522218, 0.407671, -0.178411},{1.489245, 0.418385, -0.262112}}],
    Polygon[{{1.444225, 0.254602, -0.178411},{1.461336, 0.242170, -0.090317},{
      1.542333, 0.401136, -0.090317},{1.522218, 0.407671, -0.178411}}],
    Polygon[{{1.461336, 0.242170, -0.090317},{1.467086, 0.237992, 0.000000},{
      1.549093, 0.398939, 0.000000},{1.542333, 0.401136, -0.090317}}],
    Polygon[{{1.467086, 0.237992, 0.000000},{1.461336, 0.242170, 0.090317},{
      1.542333, 0.401136, 0.090317},{1.549093, 0.398939, 0.000000}}],
    Polygon[{{1.461336, 0.242170, 0.090317},{1.444225, 0.254602, 0.178411},{
      1.522218, 0.407671, 0.178411},{1.542333, 0.401136, 0.090317}}],
    Polygon[{{1.444225, 0.254602, 0.178411},{1.416177, 0.274980, 0.262112},{
      1.489245, 0.418385, 0.262112},{1.522218, 0.407671, 0.178411}}],
    Polygon[{{1.416177, 0.274980, 0.262112},{1.377881, 0.302804, 0.339358},{
      1.444225, 0.433013, 0.339358},{1.489245, 0.418385, 0.262112}}],
    Polygon[{{1.377881, 0.302804, 0.339358},{1.330280, 0.337388, 0.408248},{
      1.388267, 0.451195, 0.408248},{1.444225, 0.433013, 0.339358}}],
    Polygon[{{1.330280, 0.337388, 0.408248},{1.274546, 0.377881, 0.467086},{
      1.322749, 0.472483, 0.467086},{1.388267, 0.451195, 0.408248}}],
    Polygon[{{1.274546, 0.377881, 0.467086},{1.212053, 0.423285, 0.514423},{
      1.249283, 0.496353, 0.514423},{1.322749, 0.472483, 0.467086}}],
    Polygon[{{1.212053, 0.423285, 0.514423},{1.144338, 0.472483, 0.549093},{
      1.169679, 0.522218, 0.549093},{1.249283, 0.496353, 0.514423}}],
    Polygon[{{1.144338, 0.472483, 0.549093},{1.073068, 0.524263, 0.570242},{
      1.085897, 0.549441, 0.570242},{1.169679, 0.522218, 0.549093}}],
    Polygon[{{1.085897, 0.549441, -0.570242},{1.169679, 0.522218, -0.549093},{
      1.178411, 0.577350, -0.549093},{1.090317, 0.577350, -0.570242}}],
    Polygon[{{1.169679, 0.522218, -0.549093},{1.249283, 0.496353, -0.514423},{
      1.262112, 0.577350, -0.514423},{1.178411, 0.577350, -0.549093}}],
    Polygon[{{1.249283, 0.496353, -0.514423},{1.322749, 0.472483, -0.467086},{
      1.339358, 0.577350, -0.467086},{1.262112, 0.577350, -0.514423}}],
    Polygon[{{1.322749, 0.472483, -0.467086},{1.388267, 0.451195, -0.408248},{
      1.408248, 0.577350, -0.408248},{1.339358, 0.577350, -0.467086}}],
    Polygon[{{1.388267, 0.451195, -0.408248},{1.444225, 0.433013, -0.339358},{
      1.467086, 0.577350, -0.339358},{1.408248, 0.577350, -0.408248}}],
    Polygon[{{1.444225, 0.433013, -0.339358},{1.489245, 0.418385, -0.262112},{
      1.514423, 0.577350, -0.262112},{1.467086, 0.577350, -0.339358}}],
    Polygon[{{1.489245, 0.418385, -0.262112},{1.522218, 0.407671, -0.178411},{
      1.549093, 0.577350, -0.178411},{1.514423, 0.577350, -0.262112}}],
    Polygon[{{1.522218, 0.407671, -0.178411},{1.542333, 0.401136, -0.090317},{
      1.570242, 0.577350, -0.090317},{1.549093, 0.577350, -0.178411}}],
    Polygon[{{1.542333, 0.401136, -0.090317},{1.549093, 0.398939, 0.000000},{
      1.577350, 0.577350, 0.000000},{1.570242, 0.577350, -0.090317}}],
    Polygon[{{1.549093, 0.398939, 0.000000},{1.542333, 0.401136, 0.090317},{
      1.570242, 0.577350, 0.090317},{1.577350, 0.577350, 0.000000}}],
    Polygon[{{1.542333, 0.401136, 0.090317},{1.522218, 0.407671, 0.178411},{
      1.549093, 0.577350, 0.178411},{1.570242, 0.577350, 0.090317}}],
    Polygon[{{1.522218, 0.407671, 0.178411},{1.489245, 0.418385, 0.262112},{
      1.514423, 0.577350, 0.262112},{1.549093, 0.577350, 0.178411}}],
    Polygon[{{1.489245, 0.418385, 0.262112},{1.444225, 0.433013, 0.339358},{
      1.467086, 0.577350, 0.339358},{1.514423, 0.577350, 0.262112}}],
    Polygon[{{1.444225, 0.433013, 0.339358},{1.388267, 0.451195, 0.408248},{
      1.408248, 0.577350, 0.408248},{1.467086, 0.577350, 0.339358}}],
    Polygon[{{1.388267, 0.451195, 0.408248},{1.322749, 0.472483, 0.467086},{
      1.339358, 0.577350, 0.467086},{1.408248, 0.577350, 0.408248}}],
    Polygon[{{1.322749, 0.472483, 0.467086},{1.249283, 0.496353, 0.514423},{
      1.262112, 0.577350, 0.514423},{1.339358, 0.577350, 0.467086}}],
    Polygon[{{1.249283, 0.496353, 0.514423},{1.169679, 0.522218, 0.549093},{
      1.178411, 0.577350, 0.549093},{1.262112, 0.577350, 0.514423}}],
    Polygon[{{1.169679, 0.522218, 0.549093},{1.085897, 0.549441, 0.570242},{
      1.090317, 0.577350, 0.570242},{1.178411, 0.577350, 0.549093}}],
    Polygon[{{0.363439, 0.192450, -0.190081},{0.392804, 0.192450, -0.183031},{
      0.389893, 0.210827, -0.183031},{0.361966, 0.201753, -0.190081}}],
    Polygon[{{0.392804, 0.192450, -0.183031},{0.420704, 0.192450, -0.171474},{
      0.416428, 0.219449, -0.171474},{0.389893, 0.210827, -0.183031}}],
    Polygon[{{0.420704, 0.192450, -0.171474},{0.446453, 0.192450, -0.155695},{
      0.440916, 0.227406, -0.155695},{0.416428, 0.219449, -0.171474}}],
    Polygon[{{0.446453, 0.192450, -0.155695},{0.469416, 0.192450, -0.136083},{
      0.462756, 0.234502, -0.136083},{0.440916, 0.227406, -0.155695}}],
    Polygon[{{0.469416, 0.192450, -0.136083},{0.489029, 0.192450, -0.113119},{
      0.481408, 0.240563, -0.113119},{0.462756, 0.234502, -0.136083}}],
    Polygon[{{0.489029, 0.192450, -0.113119},{0.504808, 0.192450, -0.087371},{
      0.496415, 0.245439, -0.087371},{0.481408, 0.240563, -0.113119}}],
    Polygon[{{0.504808, 0.192450, -0.087371},{0.516364, 0.192450, -0.059470},{
      0.507406, 0.249010, -0.059470},{0.496415, 0.245439, -0.087371}}],
    Polygon[{{0.516364, 0.192450, -0.059470},{0.523414, 0.192450, -0.030106},{
      0.514111, 0.251188, -0.030106},{0.507406, 0.249010, -0.059470}}],
    Polygon[{{0.523414, 0.192450, -0.030106},{0.525783, 0.192450, 0.000000},{
      0.516364, 0.251920, 0.000000},{0.514111, 0.251188, -0.030106}}],
    Polygon[{{0.525783, 0.192450, 0.000000},{0.523414, 0.192450, 0.030106},{
      0.514111, 0.251188, 0.030106},{0.516364, 0.251920, 0.000000}}],
    Polygon[{{0.523414, 0.192450, 0.030106},{0.516364, 0.192450, 0.059470},{
      0.507406, 0.249010, 0.059470},{0.514111, 0.251188, 0.030106}}],
    Polygon[{{0.516364, 0.192450, 0.059470},{0.504808, 0.192450, 0.087371},{
      0.496415, 0.245439, 0.087371},{0.507406, 0.249010, 0.059470}}],
    Polygon[{{0.504808, 0.192450, 0.087371},{0.489029, 0.192450, 0.113119},{
      0.481408, 0.240563, 0.113119},{0.496415, 0.245439, 0.087371}}],
    Polygon[{{0.489029, 0.192450, 0.113119},{0.469416, 0.192450, 0.136083},{
      0.462756, 0.234502, 0.136083},{0.481408, 0.240563, 0.113119}}],
    Polygon[{{0.469416, 0.192450, 0.136083},{0.446453, 0.192450, 0.155695},{
      0.440916, 0.227406, 0.155695},{0.462756, 0.234502, 0.136083}}],
    Polygon[{{0.446453, 0.192450, 0.155695},{0.420704, 0.192450, 0.171474},{
      0.416428, 0.219449, 0.171474},{0.440916, 0.227406, 0.155695}}],
    Polygon[{{0.420704, 0.192450, 0.171474},{0.392804, 0.192450, 0.183031},{
      0.389893, 0.210827, 0.183031},{0.416428, 0.219449, 0.171474}}],
    Polygon[{{0.392804, 0.192450, 0.183031},{0.363439, 0.192450, 0.190081},{
      0.361966, 0.201753, 0.190081},{0.389893, 0.210827, 0.183031}}],
    Polygon[{{0.361966, 0.201753, -0.190081},{0.389893, 0.210827, -0.183031},{
      0.381446, 0.227406, -0.183031},{0.357689, 0.210146, -0.190081}}],
    Polygon[{{0.389893, 0.210827, -0.183031},{0.416428, 0.219449, -0.171474},{
      0.404018, 0.243805, -0.171474},{0.381446, 0.227406, -0.183031}}],
    Polygon[{{0.416428, 0.219449, -0.171474},{0.440916, 0.227406, -0.155695},{
      0.424849, 0.258940, -0.155695},{0.404018, 0.243805, -0.171474}}],
    Polygon[{{0.440916, 0.227406, -0.155695},{0.462756, 0.234502, -0.136083},{
      0.443427, 0.272438, -0.136083},{0.424849, 0.258940, -0.155695}}],
    Polygon[{{0.462756, 0.234502, -0.136083},{0.481408, 0.240563, -0.113119},{
      0.459294, 0.283966, -0.113119},{0.443427, 0.272438, -0.136083}}],
    Polygon[{{0.481408, 0.240563, -0.113119},{0.496415, 0.245439, -0.087371},{
      0.472059, 0.293240, -0.087371},{0.459294, 0.283966, -0.113119}}],
    Polygon[{{0.496415, 0.245439, -0.087371},{0.507406, 0.249010, -0.059470},{
      0.481408, 0.300033, -0.059470},{0.472059, 0.293240, -0.087371}}],
    Polygon[{{0.507406, 0.249010, -0.059470},{0.514111, 0.251188, -0.030106},{
      0.487112, 0.304177, -0.030106},{0.481408, 0.300033, -0.059470}}],
    Polygon[{{0.514111, 0.251188, -0.030106},{0.516364, 0.251920, 0.000000},{
      0.489029, 0.305569, 0.000000},{0.487112, 0.304177, -0.030106}}],
    Polygon[{{0.516364, 0.251920, 0.000000},{0.514111, 0.251188, 0.030106},{
      0.487112, 0.304177, 0.030106},{0.489029, 0.305569, 0.000000}}],
    Polygon[{{0.514111, 0.251188, 0.030106},{0.507406, 0.249010, 0.059470},{
      0.481408, 0.300033, 0.059470},{0.487112, 0.304177, 0.030106}}],
    Polygon[{{0.507406, 0.249010, 0.059470},{0.496415, 0.245439, 0.087371},{
      0.472059, 0.293240, 0.087371},{0.481408, 0.300033, 0.059470}}],
    Polygon[{{0.496415, 0.245439, 0.087371},{0.481408, 0.240563, 0.113119},{
      0.459294, 0.283966, 0.113119},{0.472059, 0.293240, 0.087371}}],
    Polygon[{{0.481408, 0.240563, 0.113119},{0.462756, 0.234502, 0.136083},{
      0.443427, 0.272438, 0.136083},{0.459294, 0.283966, 0.113119}}],
    Polygon[{{0.462756, 0.234502, 0.136083},{0.440916, 0.227406, 0.155695},{
      0.424849, 0.258940, 0.155695},{0.443427, 0.272438, 0.136083}}],
    Polygon[{{0.440916, 0.227406, 0.155695},{0.416428, 0.219449, 0.171474},{
      0.404018, 0.243805, 0.171474},{0.424849, 0.258940, 0.155695}}],
    Polygon[{{0.416428, 0.219449, 0.171474},{0.389893, 0.210827, 0.183031},{
      0.381446, 0.227406, 0.183031},{0.404018, 0.243805, 0.171474}}],
    Polygon[{{0.389893, 0.210827, 0.183031},{0.361966, 0.201753, 0.190081},{
      0.357689, 0.210146, 0.190081},{0.381446, 0.227406, 0.183031}}],
    Polygon[{{0.357689, 0.210146, -0.190081},{0.381446, 0.227406, -0.183031},{
      0.368289, 0.240563, -0.183031},{0.351029, 0.216806, -0.190081}}],
    Polygon[{{0.381446, 0.227406, -0.183031},{0.404018, 0.243805, -0.171474},{
      0.384688, 0.263134, -0.171474},{0.368289, 0.240563, -0.183031}}],
    Polygon[{{0.404018, 0.243805, -0.171474},{0.424849, 0.258940, -0.155695},{
      0.399823, 0.283966, -0.155695},{0.384688, 0.263134, -0.171474}}],
    Polygon[{{0.424849, 0.258940, -0.155695},{0.443427, 0.272438, -0.136083},{
      0.413321, 0.302543, -0.136083},{0.399823, 0.283966, -0.155695}}],
    Polygon[{{0.443427, 0.272438, -0.136083},{0.459294, 0.283966, -0.113119},{
      0.424849, 0.318410, -0.113119},{0.413321, 0.302543, -0.136083}}],
    Polygon[{{0.459294, 0.283966, -0.113119},{0.472059, 0.293240, -0.087371},{
      0.434123, 0.331176, -0.087371},{0.424849, 0.318410, -0.113119}}],
    Polygon[{{0.472059, 0.293240, -0.087371},{0.481408, 0.300033, -0.059470},{
      0.440916, 0.340525, -0.059470},{0.434123, 0.331176, -0.087371}}],
    Polygon[{{0.481408, 0.300033, -0.059470},{0.487112, 0.304177, -0.030106},{
      0.445060, 0.346229, -0.030106},{0.440916, 0.340525, -0.059470}}],
    Polygon[{{0.487112, 0.304177, -0.030106},{0.489029, 0.305569, 0.000000},{
      0.446453, 0.348145, 0.000000},{0.445060, 0.346229, -0.030106}}],
    Polygon[{{0.489029, 0.305569, 0.000000},{0.487112, 0.304177, 0.030106},{
      0.445060, 0.346229, 0.030106},{0.446453, 0.348145, 0.000000}}],
    Polygon[{{0.487112, 0.304177, 0.030106},{0.481408, 0.300033, 0.059470},{
      0.440916, 0.340525, 0.059470},{0.445060, 0.346229, 0.030106}}],
    Polygon[{{0.481408, 0.300033, 0.059470},{0.472059, 0.293240, 0.087371},{
      0.434123, 0.331176, 0.087371},{0.440916, 0.340525, 0.059470}}],
    Polygon[{{0.472059, 0.293240, 0.087371},{0.459294, 0.283966, 0.113119},{
      0.424849, 0.318410, 0.113119},{0.434123, 0.331176, 0.087371}}],
    Polygon[{{0.459294, 0.283966, 0.113119},{0.443427, 0.272438, 0.136083},{
      0.413321, 0.302543, 0.136083},{0.424849, 0.318410, 0.113119}}],
    Polygon[{{0.443427, 0.272438, 0.136083},{0.424849, 0.258940, 0.155695},{
      0.399823, 0.283966, 0.155695},{0.413321, 0.302543, 0.136083}}],
    Polygon[{{0.424849, 0.258940, 0.155695},{0.404018, 0.243805, 0.171474},{
      0.384688, 0.263134, 0.171474},{0.399823, 0.283966, 0.155695}}],
    Polygon[{{0.404018, 0.243805, 0.171474},{0.381446, 0.227406, 0.183031},{
      0.368289, 0.240563, 0.183031},{0.384688, 0.263134, 0.171474}}],
    Polygon[{{0.381446, 0.227406, 0.183031},{0.357689, 0.210146, 0.190081},{
      0.351029, 0.216806, 0.190081},{0.368289, 0.240563, 0.183031}}],
    Polygon[{{0.351029, 0.216806, -0.190081},{0.368289, 0.240563, -0.183031},{
      0.351711, 0.249010, -0.183031},{0.342637, 0.221082, -0.190081}}],
    Polygon[{{0.368289, 0.240563, -0.183031},{0.384688, 0.263134, -0.171474},{
      0.360332, 0.275544, -0.171474},{0.351711, 0.249010, -0.183031}}],
    Polygon[{{0.384688, 0.263134, -0.171474},{0.399823, 0.283966, -0.155695},{
      0.368289, 0.300033, -0.155695},{0.360332, 0.275544, -0.171474}}],
    Polygon[{{0.399823, 0.283966, -0.155695},{0.413321, 0.302543, -0.136083},{
      0.375385, 0.321873, -0.136083},{0.368289, 0.300033, -0.155695}}],
    Polygon[{{0.413321, 0.302543, -0.136083},{0.424849, 0.318410, -0.113119},{
      0.381446, 0.340525, -0.113119},{0.375385, 0.321873, -0.136083}}],
    Polygon[{{0.424849, 0.318410, -0.113119},{0.434123, 0.331176, -0.087371},{
      0.386322, 0.355532, -0.087371},{0.381446, 0.340525, -0.113119}}],
    Polygon[{{0.434123, 0.331176, -0.087371},{0.440916, 0.340525, -0.059470},{
      0.389893, 0.366523, -0.059470},{0.386322, 0.355532, -0.087371}}],
    Polygon[{{0.440916, 0.340525, -0.059470},{0.445060, 0.346229, -0.030106},{
      0.392072, 0.373228, -0.030106},{0.389893, 0.366523, -0.059470}}],
    Polygon[{{0.445060, 0.346229, -0.030106},{0.446453, 0.348145, 0.000000},{
      0.392804, 0.375481, 0.000000},{0.392072, 0.373228, -0.030106}}],
    Polygon[{{0.446453, 0.348145, 0.000000},{0.445060, 0.346229, 0.030106},{
      0.392072, 0.373228, 0.030106},{0.392804, 0.375481, 0.000000}}],
    Polygon[{{0.445060, 0.346229, 0.030106},{0.440916, 0.340525, 0.059470},{
      0.389893, 0.366523, 0.059470},{0.392072, 0.373228, 0.030106}}],
    Polygon[{{0.440916, 0.340525, 0.059470},{0.434123, 0.331176, 0.087371},{
      0.386322, 0.355532, 0.087371},{0.389893, 0.366523, 0.059470}}],
    Polygon[{{0.434123, 0.331176, 0.087371},{0.424849, 0.318410, 0.113119},{
      0.381446, 0.340525, 0.113119},{0.386322, 0.355532, 0.087371}}],
    Polygon[{{0.424849, 0.318410, 0.113119},{0.413321, 0.302543, 0.136083},{
      0.375385, 0.321873, 0.136083},{0.381446, 0.340525, 0.113119}}],
    Polygon[{{0.413321, 0.302543, 0.136083},{0.399823, 0.283966, 0.155695},{
      0.368289, 0.300033, 0.155695},{0.375385, 0.321873, 0.136083}}],
    Polygon[{{0.399823, 0.283966, 0.155695},{0.384688, 0.263134, 0.171474},{
      0.360332, 0.275544, 0.171474},{0.368289, 0.300033, 0.155695}}],
    Polygon[{{0.384688, 0.263134, 0.171474},{0.368289, 0.240563, 0.183031},{
      0.351711, 0.249010, 0.183031},{0.360332, 0.275544, 0.171474}}],
    Polygon[{{0.368289, 0.240563, 0.183031},{0.351029, 0.216806, 0.190081},{
      0.342637, 0.221082, 0.190081},{0.351711, 0.249010, 0.183031}}],
    Polygon[{{0.342637, 0.221082, -0.190081},{0.351711, 0.249010, -0.183031},{
      0.333333, 0.251920, -0.183031},{0.333333, 0.222556, -0.190081}}],
    Polygon[{{0.351711, 0.249010, -0.183031},{0.360332, 0.275544, -0.171474},{
      0.333333, 0.279821, -0.171474},{0.333333, 0.251920, -0.183031}}],
    Polygon[{{0.360332, 0.275544, -0.171474},{0.368289, 0.300033, -0.155695},{
      0.333333, 0.305569, -0.155695},{0.333333, 0.279821, -0.171474}}],
    Polygon[{{0.368289, 0.300033, -0.155695},{0.375385, 0.321873, -0.136083},{
      0.333333, 0.328533, -0.136083},{0.333333, 0.305569, -0.155695}}],
    Polygon[{{0.375385, 0.321873, -0.136083},{0.381446, 0.340525, -0.113119},{
      0.333333, 0.348145, -0.113119},{0.333333, 0.328533, -0.136083}}],
    Polygon[{{0.381446, 0.340525, -0.113119},{0.386322, 0.355532, -0.087371},{
      0.333333, 0.363924, -0.087371},{0.333333, 0.348145, -0.113119}}],
    Polygon[{{0.386322, 0.355532, -0.087371},{0.389893, 0.366523, -0.059470},{
      0.333333, 0.375481, -0.059470},{0.333333, 0.363924, -0.087371}}],
    Polygon[{{0.389893, 0.366523, -0.059470},{0.392072, 0.373228, -0.030106},{
      0.333333, 0.382531, -0.030106},{0.333333, 0.375481, -0.059470}}],
    Polygon[{{0.392072, 0.373228, -0.030106},{0.392804, 0.375481, 0.000000},{
      0.333333, 0.384900, 0.000000},{0.333333, 0.382531, -0.030106}}],
    Polygon[{{0.392804, 0.375481, 0.000000},{0.392072, 0.373228, 0.030106},{
      0.333333, 0.382531, 0.030106},{0.333333, 0.384900, 0.000000}}],
    Polygon[{{0.392072, 0.373228, 0.030106},{0.389893, 0.366523, 0.059470},{
      0.333333, 0.375481, 0.059470},{0.333333, 0.382531, 0.030106}}],
    Polygon[{{0.389893, 0.366523, 0.059470},{0.386322, 0.355532, 0.087371},{
      0.333333, 0.363924, 0.087371},{0.333333, 0.375481, 0.059470}}],
    Polygon[{{0.386322, 0.355532, 0.087371},{0.381446, 0.340525, 0.113119},{
      0.333333, 0.348145, 0.113119},{0.333333, 0.363924, 0.087371}}],
    Polygon[{{0.381446, 0.340525, 0.113119},{0.375385, 0.321873, 0.136083},{
      0.333333, 0.328533, 0.136083},{0.333333, 0.348145, 0.113119}}],
    Polygon[{{0.375385, 0.321873, 0.136083},{0.368289, 0.300033, 0.155695},{
      0.333333, 0.305569, 0.155695},{0.333333, 0.328533, 0.136083}}],
    Polygon[{{0.368289, 0.300033, 0.155695},{0.360332, 0.275544, 0.171474},{
      0.333333, 0.279821, 0.171474},{0.333333, 0.305569, 0.155695}}],
    Polygon[{{0.360332, 0.275544, 0.171474},{0.351711, 0.249010, 0.183031},{
      0.333333, 0.251920, 0.183031},{0.333333, 0.279821, 0.171474}}],
    Polygon[{{0.351711, 0.249010, 0.183031},{0.342637, 0.221082, 0.190081},{
      0.333333, 0.222556, 0.190081},{0.333333, 0.251920, 0.183031}}],
    Polygon[{{0.333333, 0.222556, -0.190081},{0.333333, 0.251920, -0.183031},{
      0.314956, 0.249010, -0.183031},{0.324030, 0.221082, -0.190081}}],
    Polygon[{{0.333333, 0.251920, -0.183031},{0.333333, 0.279821, -0.171474},{
      0.306334, 0.275544, -0.171474},{0.314956, 0.249010, -0.183031}}],
    Polygon[{{0.333333, 0.279821, -0.171474},{0.333333, 0.305569, -0.155695},{
      0.298378, 0.300033, -0.155695},{0.306334, 0.275544, -0.171474}}],
    Polygon[{{0.333333, 0.305569, -0.155695},{0.333333, 0.328533, -0.136083},{
      0.291281, 0.321873, -0.136083},{0.298378, 0.300033, -0.155695}}],
    Polygon[{{0.333333, 0.328533, -0.136083},{0.333333, 0.348145, -0.113119},{
      0.285221, 0.340525, -0.113119},{0.291281, 0.321873, -0.136083}}],
    Polygon[{{0.333333, 0.348145, -0.113119},{0.333333, 0.363924, -0.087371},{
      0.280345, 0.355532, -0.087371},{0.285221, 0.340525, -0.113119}}],
    Polygon[{{0.333333, 0.363924, -0.087371},{0.333333, 0.375481, -0.059470},{
      0.276774, 0.366523, -0.059470},{0.280345, 0.355532, -0.087371}}],
    Polygon[{{0.333333, 0.375481, -0.059470},{0.333333, 0.382531, -0.030106},{
      0.274595, 0.373228, -0.030106},{0.276774, 0.366523, -0.059470}}],
    Polygon[{{0.333333, 0.382531, -0.030106},{0.333333, 0.384900, 0.000000},{
      0.273863, 0.375481, 0.000000},{0.274595, 0.373228, -0.030106}}],
    Polygon[{{0.333333, 0.384900, 0.000000},{0.333333, 0.382531, 0.030106},{
      0.274595, 0.373228, 0.030106},{0.273863, 0.375481, 0.000000}}],
    Polygon[{{0.333333, 0.382531, 0.030106},{0.333333, 0.375481, 0.059470},{
      0.276774, 0.366523, 0.059470},{0.274595, 0.373228, 0.030106}}],
    Polygon[{{0.333333, 0.375481, 0.059470},{0.333333, 0.363924, 0.087371},{
      0.280345, 0.355532, 0.087371},{0.276774, 0.366523, 0.059470}}],
    Polygon[{{0.333333, 0.363924, 0.087371},{0.333333, 0.348145, 0.113119},{
      0.285221, 0.340525, 0.113119},{0.280345, 0.355532, 0.087371}}],
    Polygon[{{0.333333, 0.348145, 0.113119},{0.333333, 0.328533, 0.136083},{
      0.291281, 0.321873, 0.136083},{0.285221, 0.340525, 0.113119}}],
    Polygon[{{0.333333, 0.328533, 0.136083},{0.333333, 0.305569, 0.155695},{
      0.298378, 0.300033, 0.155695},{0.291281, 0.321873, 0.136083}}],
    Polygon[{{0.333333, 0.305569, 0.155695},{0.333333, 0.279821, 0.171474},{
      0.306334, 0.275544, 0.171474},{0.298378, 0.300033, 0.155695}}],
    Polygon[{{0.333333, 0.279821, 0.171474},{0.333333, 0.251920, 0.183031},{
      0.314956, 0.249010, 0.183031},{0.306334, 0.275544, 0.171474}}],
    Polygon[{{0.333333, 0.251920, 0.183031},{0.333333, 0.222556, 0.190081},{
      0.324030, 0.221082, 0.190081},{0.314956, 0.249010, 0.183031}}],
    Polygon[{{0.324030, 0.221082, -0.190081},{0.314956, 0.249010, -0.183031},{
      0.298378, 0.240563, -0.183031},{0.315638, 0.216806, -0.190081}}],
    Polygon[{{0.314956, 0.249010, -0.183031},{0.306334, 0.275544, -0.171474},{
      0.281978, 0.263134, -0.171474},{0.298378, 0.240563, -0.183031}}],
    Polygon[{{0.306334, 0.275544, -0.171474},{0.298378, 0.300033, -0.155695},{
      0.266843, 0.283966, -0.155695},{0.281978, 0.263134, -0.171474}}],
    Polygon[{{0.298378, 0.300033, -0.155695},{0.291281, 0.321873, -0.136083},{
      0.253346, 0.302543, -0.136083},{0.266843, 0.283966, -0.155695}}],
    Polygon[{{0.291281, 0.321873, -0.136083},{0.285221, 0.340525, -0.113119},{
      0.241818, 0.318410, -0.113119},{0.253346, 0.302543, -0.136083}}],
    Polygon[{{0.285221, 0.340525, -0.113119},{0.280345, 0.355532, -0.087371},{
      0.232543, 0.331176, -0.087371},{0.241818, 0.318410, -0.113119}}],
    Polygon[{{0.280345, 0.355532, -0.087371},{0.276774, 0.366523, -0.059470},{
      0.225750, 0.340525, -0.059470},{0.232543, 0.331176, -0.087371}}],
    Polygon[{{0.276774, 0.366523, -0.059470},{0.274595, 0.373228, -0.030106},{
      0.221607, 0.346229, -0.030106},{0.225750, 0.340525, -0.059470}}],
    Polygon[{{0.274595, 0.373228, -0.030106},{0.273863, 0.375481, 0.000000},{
      0.220214, 0.348145, 0.000000},{0.221607, 0.346229, -0.030106}}],
    Polygon[{{0.273863, 0.375481, 0.000000},{0.274595, 0.373228, 0.030106},{
      0.221607, 0.346229, 0.030106},{0.220214, 0.348145, 0.000000}}],
    Polygon[{{0.274595, 0.373228, 0.030106},{0.276774, 0.366523, 0.059470},{
      0.225750, 0.340525, 0.059470},{0.221607, 0.346229, 0.030106}}],
    Polygon[{{0.276774, 0.366523, 0.059470},{0.280345, 0.355532, 0.087371},{
      0.232543, 0.331176, 0.087371},{0.225750, 0.340525, 0.059470}}],
    Polygon[{{0.280345, 0.355532, 0.087371},{0.285221, 0.340525, 0.113119},{
      0.241818, 0.318410, 0.113119},{0.232543, 0.331176, 0.087371}}],
    Polygon[{{0.285221, 0.340525, 0.113119},{0.291281, 0.321873, 0.136083},{
      0.253346, 0.302543, 0.136083},{0.241818, 0.318410, 0.113119}}],
    Polygon[{{0.291281, 0.321873, 0.136083},{0.298378, 0.300033, 0.155695},{
      0.266843, 0.283966, 0.155695},{0.253346, 0.302543, 0.136083}}],
    Polygon[{{0.298378, 0.300033, 0.155695},{0.306334, 0.275544, 0.171474},{
      0.281978, 0.263134, 0.171474},{0.266843, 0.283966, 0.155695}}],
    Polygon[{{0.306334, 0.275544, 0.171474},{0.314956, 0.249010, 0.183031},{
      0.298378, 0.240563, 0.183031},{0.281978, 0.263134, 0.171474}}],
    Polygon[{{0.314956, 0.249010, 0.183031},{0.324030, 0.221082, 0.190081},{
      0.315638, 0.216806, 0.190081},{0.298378, 0.240563, 0.183031}}],
    Polygon[{{0.315638, 0.216806, -0.190081},{0.298378, 0.240563, -0.183031},{
      0.285221, 0.227406, -0.183031},{0.308977, 0.210146, -0.190081}}],
    Polygon[{{0.298378, 0.240563, -0.183031},{0.281978, 0.263134, -0.171474},{
      0.262649, 0.243805, -0.171474},{0.285221, 0.227406, -0.183031}}],
    Polygon[{{0.281978, 0.263134, -0.171474},{0.266843, 0.283966, -0.155695},{
      0.241818, 0.258940, -0.155695},{0.262649, 0.243805, -0.171474}}],
    Polygon[{{0.266843, 0.283966, -0.155695},{0.253346, 0.302543, -0.136083},{
      0.223240, 0.272438, -0.136083},{0.241818, 0.258940, -0.155695}}],
    Polygon[{{0.253346, 0.302543, -0.136083},{0.241818, 0.318410, -0.113119},{
      0.207373, 0.283966, -0.113119},{0.223240, 0.272438, -0.136083}}],
    Polygon[{{0.241818, 0.318410, -0.113119},{0.232543, 0.331176, -0.087371},{
      0.194608, 0.293240, -0.087371},{0.207373, 0.283966, -0.113119}}],
    Polygon[{{0.232543, 0.331176, -0.087371},{0.225750, 0.340525, -0.059470},{
      0.185258, 0.300033, -0.059470},{0.194608, 0.293240, -0.087371}}],
    Polygon[{{0.225750, 0.340525, -0.059470},{0.221607, 0.346229, -0.030106},{
      0.179555, 0.304177, -0.030106},{0.185258, 0.300033, -0.059470}}],
    Polygon[{{0.221607, 0.346229, -0.030106},{0.220214, 0.348145, 0.000000},{
      0.177638, 0.305569, 0.000000},{0.179555, 0.304177, -0.030106}}],
    Polygon[{{0.220214, 0.348145, 0.000000},{0.221607, 0.346229, 0.030106},{
      0.179555, 0.304177, 0.030106},{0.177638, 0.305569, 0.000000}}],
    Polygon[{{0.221607, 0.346229, 0.030106},{0.225750, 0.340525, 0.059470},{
      0.185258, 0.300033, 0.059470},{0.179555, 0.304177, 0.030106}}],
    Polygon[{{0.225750, 0.340525, 0.059470},{0.232543, 0.331176, 0.087371},{
      0.194608, 0.293240, 0.087371},{0.185258, 0.300033, 0.059470}}],
    Polygon[{{0.232543, 0.331176, 0.087371},{0.241818, 0.318410, 0.113119},{
      0.207373, 0.283966, 0.113119},{0.194608, 0.293240, 0.087371}}],
    Polygon[{{0.241818, 0.318410, 0.113119},{0.253346, 0.302543, 0.136083},{
      0.223240, 0.272438, 0.136083},{0.207373, 0.283966, 0.113119}}],
    Polygon[{{0.253346, 0.302543, 0.136083},{0.266843, 0.283966, 0.155695},{
      0.241818, 0.258940, 0.155695},{0.223240, 0.272438, 0.136083}}],
    Polygon[{{0.266843, 0.283966, 0.155695},{0.281978, 0.263134, 0.171474},{
      0.262649, 0.243805, 0.171474},{0.241818, 0.258940, 0.155695}}],
    Polygon[{{0.281978, 0.263134, 0.171474},{0.298378, 0.240563, 0.183031},{
      0.285221, 0.227406, 0.183031},{0.262649, 0.243805, 0.171474}}],
    Polygon[{{0.298378, 0.240563, 0.183031},{0.315638, 0.216806, 0.190081},{
      0.308977, 0.210146, 0.190081},{0.285221, 0.227406, 0.183031}}],
    Polygon[{{0.308977, 0.210146, -0.190081},{0.285221, 0.227406, -0.183031},{
      0.276774, 0.210827, -0.183031},{0.304701, 0.201753, -0.190081}}],
    Polygon[{{0.285221, 0.227406, -0.183031},{0.262649, 0.243805, -0.171474},{
      0.250239, 0.219449, -0.171474},{0.276774, 0.210827, -0.183031}}],
    Polygon[{{0.262649, 0.243805, -0.171474},{0.241818, 0.258940, -0.155695},{
      0.225750, 0.227406, -0.155695},{0.250239, 0.219449, -0.171474}}],
    Polygon[{{0.241818, 0.258940, -0.155695},{0.223240, 0.272438, -0.136083},{
      0.203911, 0.234502, -0.136083},{0.225750, 0.227406, -0.155695}}],
    Polygon[{{0.223240, 0.272438, -0.136083},{0.207373, 0.283966, -0.113119},{
      0.185258, 0.240563, -0.113119},{0.203911, 0.234502, -0.136083}}],
    Polygon[{{0.207373, 0.283966, -0.113119},{0.194608, 0.293240, -0.087371},{
      0.170252, 0.245439, -0.087371},{0.185258, 0.240563, -0.113119}}],
    Polygon[{{0.194608, 0.293240, -0.087371},{0.185258, 0.300033, -0.059470},{
      0.159261, 0.249010, -0.059470},{0.170252, 0.245439, -0.087371}}],
    Polygon[{{0.185258, 0.300033, -0.059470},{0.179555, 0.304177, -0.030106},{
      0.152556, 0.251188, -0.030106},{0.159261, 0.249010, -0.059470}}],
    Polygon[{{0.179555, 0.304177, -0.030106},{0.177638, 0.305569, 0.000000},{
      0.150302, 0.251920, 0.000000},{0.152556, 0.251188, -0.030106}}],
    Polygon[{{0.177638, 0.305569, 0.000000},{0.179555, 0.304177, 0.030106},{
      0.152556, 0.251188, 0.030106},{0.150302, 0.251920, 0.000000}}],
    Polygon[{{0.179555, 0.304177, 0.030106},{0.185258, 0.300033, 0.059470},{
      0.159261, 0.249010, 0.059470},{0.152556, 0.251188, 0.030106}}],
    Polygon[{{0.185258, 0.300033, 0.059470},{0.194608, 0.293240, 0.087371},{
      0.170252, 0.245439, 0.087371},{0.159261, 0.249010, 0.059470}}],
    Polygon[{{0.194608, 0.293240, 0.087371},{0.207373, 0.283966, 0.113119},{
      0.185258, 0.240563, 0.113119},{0.170252, 0.245439, 0.087371}}],
    Polygon[{{0.207373, 0.283966, 0.113119},{0.223240, 0.272438, 0.136083},{
      0.203911, 0.234502, 0.136083},{0.185258, 0.240563, 0.113119}}],
    Polygon[{{0.223240, 0.272438, 0.136083},{0.241818, 0.258940, 0.155695},{
      0.225750, 0.227406, 0.155695},{0.203911, 0.234502, 0.136083}}],
    Polygon[{{0.241818, 0.258940, 0.155695},{0.262649, 0.243805, 0.171474},{
      0.250239, 0.219449, 0.171474},{0.225750, 0.227406, 0.155695}}],
    Polygon[{{0.262649, 0.243805, 0.171474},{0.285221, 0.227406, 0.183031},{
      0.276774, 0.210827, 0.183031},{0.250239, 0.219449, 0.171474}}],
    Polygon[{{0.285221, 0.227406, 0.183031},{0.308977, 0.210146, 0.190081},{
      0.304701, 0.201753, 0.190081},{0.276774, 0.210827, 0.183031}}],
    Polygon[{{0.304701, 0.201753, -0.190081},{0.276774, 0.210827, -0.183031},{
      0.273863, 0.192450, -0.183031},{0.303228, 0.192450, -0.190081}}],
    Polygon[{{0.276774, 0.210827, -0.183031},{0.250239, 0.219449, -0.171474},{
      0.245963, 0.192450, -0.171474},{0.273863, 0.192450, -0.183031}}],
    Polygon[{{0.250239, 0.219449, -0.171474},{0.225750, 0.227406, -0.155695},{
      0.220214, 0.192450, -0.155695},{0.245963, 0.192450, -0.171474}}],
    Polygon[{{0.225750, 0.227406, -0.155695},{0.203911, 0.234502, -0.136083},{
      0.197251, 0.192450, -0.136083},{0.220214, 0.192450, -0.155695}}],
    Polygon[{{0.203911, 0.234502, -0.136083},{0.185258, 0.240563, -0.113119},{
      0.177638, 0.192450, -0.113119},{0.197251, 0.192450, -0.136083}}],
    Polygon[{{0.185258, 0.240563, -0.113119},{0.170252, 0.245439, -0.087371},{
      0.161859, 0.192450, -0.087371},{0.177638, 0.192450, -0.113119}}],
    Polygon[{{0.170252, 0.245439, -0.087371},{0.159261, 0.249010, -0.059470},{
      0.150302, 0.192450, -0.059470},{0.161859, 0.192450, -0.087371}}],
    Polygon[{{0.159261, 0.249010, -0.059470},{0.152556, 0.251188, -0.030106},{
      0.143253, 0.192450, -0.030106},{0.150302, 0.192450, -0.059470}}],
    Polygon[{{0.152556, 0.251188, -0.030106},{0.150302, 0.251920, 0.000000},{
      0.140883, 0.192450, 0.000000},{0.143253, 0.192450, -0.030106}}],
    Polygon[{{0.150302, 0.251920, 0.000000},{0.152556, 0.251188, 0.030106},{
      0.143253, 0.192450, 0.030106},{0.140883, 0.192450, 0.000000}}],
    Polygon[{{0.152556, 0.251188, 0.030106},{0.159261, 0.249010, 0.059470},{
      0.150302, 0.192450, 0.059470},{0.143253, 0.192450, 0.030106}}],
    Polygon[{{0.159261, 0.249010, 0.059470},{0.170252, 0.245439, 0.087371},{
      0.161859, 0.192450, 0.087371},{0.150302, 0.192450, 0.059470}}],
    Polygon[{{0.170252, 0.245439, 0.087371},{0.185258, 0.240563, 0.113119},{
      0.177638, 0.192450, 0.113119},{0.161859, 0.192450, 0.087371}}],
    Polygon[{{0.185258, 0.240563, 0.113119},{0.203911, 0.234502, 0.136083},{
      0.197251, 0.192450, 0.136083},{0.177638, 0.192450, 0.113119}}],
    Polygon[{{0.203911, 0.234502, 0.136083},{0.225750, 0.227406, 0.155695},{
      0.220214, 0.192450, 0.155695},{0.197251, 0.192450, 0.136083}}],
    Polygon[{{0.225750, 0.227406, 0.155695},{0.250239, 0.219449, 0.171474},{
      0.245963, 0.192450, 0.171474},{0.220214, 0.192450, 0.155695}}],
    Polygon[{{0.250239, 0.219449, 0.171474},{0.276774, 0.210827, 0.183031},{
      0.273863, 0.192450, 0.183031},{0.245963, 0.192450, 0.171474}}],
    Polygon[{{0.276774, 0.210827, 0.183031},{0.304701, 0.201753, 0.190081},{
      0.303228, 0.192450, 0.190081},{0.273863, 0.192450, 0.183031}}],
    Polygon[{{0.303228, 0.192450, -0.190081},{0.273863, 0.192450, -0.183031},{
      0.276774, 0.174073, -0.183031},{0.304701, 0.183147, -0.190081}}],
    Polygon[{{0.273863, 0.192450, -0.183031},{0.245963, 0.192450, -0.171474},{
      0.250239, 0.165451, -0.171474},{0.276774, 0.174073, -0.183031}}],
    Polygon[{{0.245963, 0.192450, -0.171474},{0.220214, 0.192450, -0.155695},{
      0.225750, 0.157494, -0.155695},{0.250239, 0.165451, -0.171474}}],
    Polygon[{{0.220214, 0.192450, -0.155695},{0.197251, 0.192450, -0.136083},{
      0.203911, 0.150398, -0.136083},{0.225750, 0.157494, -0.155695}}],
    Polygon[{{0.197251, 0.192450, -0.136083},{0.177638, 0.192450, -0.113119},{
      0.185258, 0.144338, -0.113119},{0.203911, 0.150398, -0.136083}}],
    Polygon[{{0.177638, 0.192450, -0.113119},{0.161859, 0.192450, -0.087371},{
      0.170252, 0.139462, -0.087371},{0.185258, 0.144338, -0.113119}}],
    Polygon[{{0.161859, 0.192450, -0.087371},{0.150302, 0.192450, -0.059470},{
      0.159261, 0.135890, -0.059470},{0.170252, 0.139462, -0.087371}}],
    Polygon[{{0.150302, 0.192450, -0.059470},{0.143253, 0.192450, -0.030106},{
      0.152556, 0.133712, -0.030106},{0.159261, 0.135890, -0.059470}}],
    Polygon[{{0.143253, 0.192450, -0.030106},{0.140883, 0.192450, 0.000000},{
      0.150302, 0.132980, 0.000000},{0.152556, 0.133712, -0.030106}}],
    Polygon[{{0.140883, 0.192450, 0.000000},{0.143253, 0.192450, 0.030106},{
      0.152556, 0.133712, 0.030106},{0.150302, 0.132980, 0.000000}}],
    Polygon[{{0.143253, 0.192450, 0.030106},{0.150302, 0.192450, 0.059470},{
      0.159261, 0.135890, 0.059470},{0.152556, 0.133712, 0.030106}}],
    Polygon[{{0.150302, 0.192450, 0.059470},{0.161859, 0.192450, 0.087371},{
      0.170252, 0.139462, 0.087371},{0.159261, 0.135890, 0.059470}}],
    Polygon[{{0.161859, 0.192450, 0.087371},{0.177638, 0.192450, 0.113119},{
      0.185258, 0.144338, 0.113119},{0.170252, 0.139462, 0.087371}}],
    Polygon[{{0.177638, 0.192450, 0.113119},{0.197251, 0.192450, 0.136083},{
      0.203911, 0.150398, 0.136083},{0.185258, 0.144338, 0.113119}}],
    Polygon[{{0.197251, 0.192450, 0.136083},{0.220214, 0.192450, 0.155695},{
      0.225750, 0.157494, 0.155695},{0.203911, 0.150398, 0.136083}}],
    Polygon[{{0.220214, 0.192450, 0.155695},{0.245963, 0.192450, 0.171474},{
      0.250239, 0.165451, 0.171474},{0.225750, 0.157494, 0.155695}}],
    Polygon[{{0.245963, 0.192450, 0.171474},{0.273863, 0.192450, 0.183031},{
      0.276774, 0.174073, 0.183031},{0.250239, 0.165451, 0.171474}}],
    Polygon[{{0.273863, 0.192450, 0.183031},{0.303228, 0.192450, 0.190081},{
      0.304701, 0.183147, 0.190081},{0.276774, 0.174073, 0.183031}}],
    Polygon[{{0.304701, 0.183147, -0.190081},{0.276774, 0.174073, -0.183031},{
      0.285221, 0.157494, -0.183031},{0.308977, 0.174754, -0.190081}}],
    Polygon[{{0.276774, 0.174073, -0.183031},{0.250239, 0.165451, -0.171474},{
      0.262649, 0.141095, -0.171474},{0.285221, 0.157494, -0.183031}}],
    Polygon[{{0.250239, 0.165451, -0.171474},{0.225750, 0.157494, -0.155695},{
      0.241818, 0.125960, -0.155695},{0.262649, 0.141095, -0.171474}}],
    Polygon[{{0.225750, 0.157494, -0.155695},{0.203911, 0.150398, -0.136083},{
      0.223240, 0.112463, -0.136083},{0.241818, 0.125960, -0.155695}}],
    Polygon[{{0.203911, 0.150398, -0.136083},{0.185258, 0.144338, -0.113119},{
      0.207373, 0.100935, -0.113119},{0.223240, 0.112463, -0.136083}}],
    Polygon[{{0.185258, 0.144338, -0.113119},{0.170252, 0.139462, -0.087371},{
      0.194608, 0.091660, -0.087371},{0.207373, 0.100935, -0.113119}}],
    Polygon[{{0.170252, 0.139462, -0.087371},{0.159261, 0.135890, -0.059470},{
      0.185258, 0.084867, -0.059470},{0.194608, 0.091660, -0.087371}}],
    Polygon[{{0.159261, 0.135890, -0.059470},{0.152556, 0.133712, -0.030106},{
      0.179555, 0.080723, -0.030106},{0.185258, 0.084867, -0.059470}}],
    Polygon[{{0.152556, 0.133712, -0.030106},{0.150302, 0.132980, 0.000000},{
      0.177638, 0.079331, 0.000000},{0.179555, 0.080723, -0.030106}}],
    Polygon[{{0.150302, 0.132980, 0.000000},{0.152556, 0.133712, 0.030106},{
      0.179555, 0.080723, 0.030106},{0.177638, 0.079331, 0.000000}}],
    Polygon[{{0.152556, 0.133712, 0.030106},{0.159261, 0.135890, 0.059470},{
      0.185258, 0.084867, 0.059470},{0.179555, 0.080723, 0.030106}}],
    Polygon[{{0.159261, 0.135890, 0.059470},{0.170252, 0.139462, 0.087371},{
      0.194608, 0.091660, 0.087371},{0.185258, 0.084867, 0.059470}}],
    Polygon[{{0.170252, 0.139462, 0.087371},{0.185258, 0.144338, 0.113119},{
      0.207373, 0.100935, 0.113119},{0.194608, 0.091660, 0.087371}}],
    Polygon[{{0.185258, 0.144338, 0.113119},{0.203911, 0.150398, 0.136083},{
      0.223240, 0.112463, 0.136083},{0.207373, 0.100935, 0.113119}}],
    Polygon[{{0.203911, 0.150398, 0.136083},{0.225750, 0.157494, 0.155695},{
      0.241818, 0.125960, 0.155695},{0.223240, 0.112463, 0.136083}}],
    Polygon[{{0.225750, 0.157494, 0.155695},{0.250239, 0.165451, 0.171474},{
      0.262649, 0.141095, 0.171474},{0.241818, 0.125960, 0.155695}}],
    Polygon[{{0.250239, 0.165451, 0.171474},{0.276774, 0.174073, 0.183031},{
      0.285221, 0.157494, 0.183031},{0.262649, 0.141095, 0.171474}}],
    Polygon[{{0.276774, 0.174073, 0.183031},{0.304701, 0.183147, 0.190081},{
      0.308977, 0.174754, 0.190081},{0.285221, 0.157494, 0.183031}}],
    Polygon[{{0.308977, 0.174754, -0.190081},{0.285221, 0.157494, -0.183031},{
      0.298378, 0.144338, -0.183031},{0.315638, 0.168094, -0.190081}}],
    Polygon[{{0.285221, 0.157494, -0.183031},{0.262649, 0.141095, -0.171474},{
      0.281978, 0.121766, -0.171474},{0.298378, 0.144338, -0.183031}}],
    Polygon[{{0.262649, 0.141095, -0.171474},{0.241818, 0.125960, -0.155695},{
      0.266843, 0.100935, -0.155695},{0.281978, 0.121766, -0.171474}}],
    Polygon[{{0.241818, 0.125960, -0.155695},{0.223240, 0.112463, -0.136083},{
      0.253346, 0.082357, -0.136083},{0.266843, 0.100935, -0.155695}}],
    Polygon[{{0.223240, 0.112463, -0.136083},{0.207373, 0.100935, -0.113119},{
      0.241818, 0.066490, -0.113119},{0.253346, 0.082357, -0.136083}}],
    Polygon[{{0.207373, 0.100935, -0.113119},{0.194608, 0.091660, -0.087371},{
      0.232543, 0.053724, -0.087371},{0.241818, 0.066490, -0.113119}}],
    Polygon[{{0.194608, 0.091660, -0.087371},{0.185258, 0.084867, -0.059470},{
      0.225750, 0.044375, -0.059470},{0.232543, 0.053724, -0.087371}}],
    Polygon[{{0.185258, 0.084867, -0.059470},{0.179555, 0.080723, -0.030106},{
      0.221607, 0.038672, -0.030106},{0.225750, 0.044375, -0.059470}}],
    Polygon[{{0.179555, 0.080723, -0.030106},{0.177638, 0.079331, 0.000000},{
      0.220214, 0.036755, 0.000000},{0.221607, 0.038672, -0.030106}}],
    Polygon[{{0.177638, 0.079331, 0.000000},{0.179555, 0.080723, 0.030106},{
      0.221607, 0.038672, 0.030106},{0.220214, 0.036755, 0.000000}}],
    Polygon[{{0.179555, 0.080723, 0.030106},{0.185258, 0.084867, 0.059470},{
      0.225750, 0.044375, 0.059470},{0.221607, 0.038672, 0.030106}}],
    Polygon[{{0.185258, 0.084867, 0.059470},{0.194608, 0.091660, 0.087371},{
      0.232543, 0.053724, 0.087371},{0.225750, 0.044375, 0.059470}}],
    Polygon[{{0.194608, 0.091660, 0.087371},{0.207373, 0.100935, 0.113119},{
      0.241818, 0.066490, 0.113119},{0.232543, 0.053724, 0.087371}}],
    Polygon[{{0.207373, 0.100935, 0.113119},{0.223240, 0.112463, 0.136083},{
      0.253346, 0.082357, 0.136083},{0.241818, 0.066490, 0.113119}}],
    Polygon[{{0.223240, 0.112463, 0.136083},{0.241818, 0.125960, 0.155695},{
      0.266843, 0.100935, 0.155695},{0.253346, 0.082357, 0.136083}}],
    Polygon[{{0.241818, 0.125960, 0.155695},{0.262649, 0.141095, 0.171474},{
      0.281978, 0.121766, 0.171474},{0.266843, 0.100935, 0.155695}}],
    Polygon[{{0.262649, 0.141095, 0.171474},{0.285221, 0.157494, 0.183031},{
      0.298378, 0.144338, 0.183031},{0.281978, 0.121766, 0.171474}}],
    Polygon[{{0.285221, 0.157494, 0.183031},{0.308977, 0.174754, 0.190081},{
      0.315638, 0.168094, 0.190081},{0.298378, 0.144338, 0.183031}}],
    Polygon[{{0.315638, 0.168094, -0.190081},{0.298378, 0.144338, -0.183031},{
      0.314956, 0.135890, -0.183031},{0.324030, 0.163818, -0.190081}}],
    Polygon[{{0.298378, 0.144338, -0.183031},{0.281978, 0.121766, -0.171474},{
      0.306334, 0.109356, -0.171474},{0.314956, 0.135890, -0.183031}}],
    Polygon[{{0.281978, 0.121766, -0.171474},{0.266843, 0.100935, -0.155695},{
      0.298378, 0.084867, -0.155695},{0.306334, 0.109356, -0.171474}}],
    Polygon[{{0.266843, 0.100935, -0.155695},{0.253346, 0.082357, -0.136083},{
      0.291281, 0.063028, -0.136083},{0.298378, 0.084867, -0.155695}}],
    Polygon[{{0.253346, 0.082357, -0.136083},{0.241818, 0.066490, -0.113119},{
      0.285221, 0.044375, -0.113119},{0.291281, 0.063028, -0.136083}}],
    Polygon[{{0.241818, 0.066490, -0.113119},{0.232543, 0.053724, -0.087371},{
      0.280345, 0.029368, -0.087371},{0.285221, 0.044375, -0.113119}}],
    Polygon[{{0.232543, 0.053724, -0.087371},{0.225750, 0.044375, -0.059470},{
      0.276774, 0.018377, -0.059470},{0.280345, 0.029368, -0.087371}}],
    Polygon[{{0.225750, 0.044375, -0.059470},{0.221607, 0.038672, -0.030106},{
      0.274595, 0.011673, -0.030106},{0.276774, 0.018377, -0.059470}}],
    Polygon[{{0.221607, 0.038672, -0.030106},{0.220214, 0.036755, 0.000000},{
      0.273863, 0.009419, 0.000000},{0.274595, 0.011673, -0.030106}}],
    Polygon[{{0.220214, 0.036755, 0.000000},{0.221607, 0.038672, 0.030106},{
      0.274595, 0.011673, 0.030106},{0.273863, 0.009419, 0.000000}}],
    Polygon[{{0.221607, 0.038672, 0.030106},{0.225750, 0.044375, 0.059470},{
      0.276774, 0.018377, 0.059470},{0.274595, 0.011673, 0.030106}}],
    Polygon[{{0.225750, 0.044375, 0.059470},{0.232543, 0.053724, 0.087371},{
      0.280345, 0.029368, 0.087371},{0.276774, 0.018377, 0.059470}}],
    Polygon[{{0.232543, 0.053724, 0.087371},{0.241818, 0.066490, 0.113119},{
      0.285221, 0.044375, 0.113119},{0.280345, 0.029368, 0.087371}}],
    Polygon[{{0.241818, 0.066490, 0.113119},{0.253346, 0.082357, 0.136083},{
      0.291281, 0.063028, 0.136083},{0.285221, 0.044375, 0.113119}}],
    Polygon[{{0.253346, 0.082357, 0.136083},{0.266843, 0.100935, 0.155695},{
      0.298378, 0.084867, 0.155695},{0.291281, 0.063028, 0.136083}}],
    Polygon[{{0.266843, 0.100935, 0.155695},{0.281978, 0.121766, 0.171474},{
      0.306334, 0.109356, 0.171474},{0.298378, 0.084867, 0.155695}}],
    Polygon[{{0.281978, 0.121766, 0.171474},{0.298378, 0.144338, 0.183031},{
      0.314956, 0.135890, 0.183031},{0.306334, 0.109356, 0.171474}}],
    Polygon[{{0.298378, 0.144338, 0.183031},{0.315638, 0.168094, 0.190081},{
      0.324030, 0.163818, 0.190081},{0.314956, 0.135890, 0.183031}}],
    Polygon[{{0.324030, 0.163818, -0.190081},{0.314956, 0.135890, -0.183031},{
      0.333333, 0.132980, -0.183031},{0.333333, 0.162344, -0.190081}}],
    Polygon[{{0.314956, 0.135890, -0.183031},{0.306334, 0.109356, -0.171474},{
      0.333333, 0.105080, -0.171474},{0.333333, 0.132980, -0.183031}}],
    Polygon[{{0.306334, 0.109356, -0.171474},{0.298378, 0.084867, -0.155695},{
      0.333333, 0.079331, -0.155695},{0.333333, 0.105080, -0.171474}}],
    Polygon[{{0.298378, 0.084867, -0.155695},{0.291281, 0.063028, -0.136083},{
      0.333333, 0.056367, -0.136083},{0.333333, 0.079331, -0.155695}}],
    Polygon[{{0.291281, 0.063028, -0.136083},{0.285221, 0.044375, -0.113119},{
      0.333333, 0.036755, -0.113119},{0.333333, 0.056367, -0.136083}}],
    Polygon[{{0.285221, 0.044375, -0.113119},{0.280345, 0.029368, -0.087371},{
      0.333333, 0.020976, -0.087371},{0.333333, 0.036755, -0.113119}}],
    Polygon[{{0.280345, 0.029368, -0.087371},{0.276774, 0.018377, -0.059470},{
      0.333333, 0.009419, -0.059470},{0.333333, 0.020976, -0.087371}}],
    Polygon[{{0.276774, 0.018377, -0.059470},{0.274595, 0.011673, -0.030106},{
      0.333333, 0.002369, -0.030106},{0.333333, 0.009419, -0.059470}}],
    Polygon[{{0.274595, 0.011673, -0.030106},{0.273863, 0.009419, 0.000000},{
      0.333333, 0.000000, 0.000000},{0.333333, 0.002369, -0.030106}}],
    Polygon[{{0.273863, 0.009419, 0.000000},{0.274595, 0.011673, 0.030106},{
      0.333333, 0.002369, 0.030106},{0.333333, 0.000000, 0.000000}}],
    Polygon[{{0.274595, 0.011673, 0.030106},{0.276774, 0.018377, 0.059470},{
      0.333333, 0.009419, 0.059470},{0.333333, 0.002369, 0.030106}}],
    Polygon[{{0.276774, 0.018377, 0.059470},{0.280345, 0.029368, 0.087371},{
      0.333333, 0.020976, 0.087371},{0.333333, 0.009419, 0.059470}}],
    Polygon[{{0.280345, 0.029368, 0.087371},{0.285221, 0.044375, 0.113119},{
      0.333333, 0.036755, 0.113119},{0.333333, 0.020976, 0.087371}}],
    Polygon[{{0.285221, 0.044375, 0.113119},{0.291281, 0.063028, 0.136083},{
      0.333333, 0.056367, 0.136083},{0.333333, 0.036755, 0.113119}}],
    Polygon[{{0.291281, 0.063028, 0.136083},{0.298378, 0.084867, 0.155695},{
      0.333333, 0.079331, 0.155695},{0.333333, 0.056367, 0.136083}}],
    Polygon[{{0.298378, 0.084867, 0.155695},{0.306334, 0.109356, 0.171474},{
      0.333333, 0.105080, 0.171474},{0.333333, 0.079331, 0.155695}}],
    Polygon[{{0.306334, 0.109356, 0.171474},{0.314956, 0.135890, 0.183031},{
      0.333333, 0.132980, 0.183031},{0.333333, 0.105080, 0.171474}}],
    Polygon[{{0.314956, 0.135890, 0.183031},{0.324030, 0.163818, 0.190081},{
      0.333333, 0.162344, 0.190081},{0.333333, 0.132980, 0.183031}}],
    Polygon[{{0.333333, 0.162344, -0.190081},{0.333333, 0.132980, -0.183031},{
      0.351711, 0.135890, -0.183031},{0.342637, 0.163818, -0.190081}}],
    Polygon[{{0.333333, 0.132980, -0.183031},{0.333333, 0.105080, -0.171474},{
      0.360332, 0.109356, -0.171474},{0.351711, 0.135890, -0.183031}}],
    Polygon[{{0.333333, 0.105080, -0.171474},{0.333333, 0.079331, -0.155695},{
      0.368289, 0.084867, -0.155695},{0.360332, 0.109356, -0.171474}}],
    Polygon[{{0.333333, 0.079331, -0.155695},{0.333333, 0.056367, -0.136083},{
      0.375385, 0.063028, -0.136083},{0.368289, 0.084867, -0.155695}}],
    Polygon[{{0.333333, 0.056367, -0.136083},{0.333333, 0.036755, -0.113119},{
      0.381446, 0.044375, -0.113119},{0.375385, 0.063028, -0.136083}}],
    Polygon[{{0.333333, 0.036755, -0.113119},{0.333333, 0.020976, -0.087371},{
      0.386322, 0.029368, -0.087371},{0.381446, 0.044375, -0.113119}}],
    Polygon[{{0.333333, 0.020976, -0.087371},{0.333333, 0.009419, -0.059470},{
      0.389893, 0.018377, -0.059470},{0.386322, 0.029368, -0.087371}}],
    Polygon[{{0.333333, 0.009419, -0.059470},{0.333333, 0.002369, -0.030106},{
      0.392072, 0.011673, -0.030106},{0.389893, 0.018377, -0.059470}}],
    Polygon[{{0.333333, 0.002369, -0.030106},{0.333333, 0.000000, 0.000000},{
      0.392804, 0.009419, 0.000000},{0.392072, 0.011673, -0.030106}}],
    Polygon[{{0.333333, 0.000000, 0.000000},{0.333333, 0.002369, 0.030106},{
      0.392072, 0.011673, 0.030106},{0.392804, 0.009419, 0.000000}}],
    Polygon[{{0.333333, 0.002369, 0.030106},{0.333333, 0.009419, 0.059470},{
      0.389893, 0.018377, 0.059470},{0.392072, 0.011673, 0.030106}}],
    Polygon[{{0.333333, 0.009419, 0.059470},{0.333333, 0.020976, 0.087371},{
      0.386322, 0.029368, 0.087371},{0.389893, 0.018377, 0.059470}}],
    Polygon[{{0.333333, 0.020976, 0.087371},{0.333333, 0.036755, 0.113119},{
      0.381446, 0.044375, 0.113119},{0.386322, 0.029368, 0.087371}}],
    Polygon[{{0.333333, 0.036755, 0.113119},{0.333333, 0.056367, 0.136083},{
      0.375385, 0.063028, 0.136083},{0.381446, 0.044375, 0.113119}}],
    Polygon[{{0.333333, 0.056367, 0.136083},{0.333333, 0.079331, 0.155695},{
      0.368289, 0.084867, 0.155695},{0.375385, 0.063028, 0.136083}}],
    Polygon[{{0.333333, 0.079331, 0.155695},{0.333333, 0.105080, 0.171474},{
      0.360332, 0.109356, 0.171474},{0.368289, 0.084867, 0.155695}}],
    Polygon[{{0.333333, 0.105080, 0.171474},{0.333333, 0.132980, 0.183031},{
      0.351711, 0.135890, 0.183031},{0.360332, 0.109356, 0.171474}}],
    Polygon[{{0.333333, 0.132980, 0.183031},{0.333333, 0.162344, 0.190081},{
      0.342637, 0.163818, 0.190081},{0.351711, 0.135890, 0.183031}}],
    Polygon[{{0.342637, 0.163818, -0.190081},{0.351711, 0.135890, -0.183031},{
      0.368289, 0.144338, -0.183031},{0.351029, 0.168094, -0.190081}}],
    Polygon[{{0.351711, 0.135890, -0.183031},{0.360332, 0.109356, -0.171474},{
      0.384688, 0.121766, -0.171474},{0.368289, 0.144338, -0.183031}}],
    Polygon[{{0.360332, 0.109356, -0.171474},{0.368289, 0.084867, -0.155695},{
      0.399823, 0.100935, -0.155695},{0.384688, 0.121766, -0.171474}}],
    Polygon[{{0.368289, 0.084867, -0.155695},{0.375385, 0.063028, -0.136083},{
      0.413321, 0.082357, -0.136083},{0.399823, 0.100935, -0.155695}}],
    Polygon[{{0.375385, 0.063028, -0.136083},{0.381446, 0.044375, -0.113119},{
      0.424849, 0.066490, -0.113119},{0.413321, 0.082357, -0.136083}}],
    Polygon[{{0.381446, 0.044375, -0.113119},{0.386322, 0.029368, -0.087371},{
      0.434123, 0.053724, -0.087371},{0.424849, 0.066490, -0.113119}}],
    Polygon[{{0.386322, 0.029368, -0.087371},{0.389893, 0.018377, -0.059470},{
      0.440916, 0.044375, -0.059470},{0.434123, 0.053724, -0.087371}}],
    Polygon[{{0.389893, 0.018377, -0.059470},{0.392072, 0.011673, -0.030106},{
      0.445060, 0.038672, -0.030106},{0.440916, 0.044375, -0.059470}}],
    Polygon[{{0.392072, 0.011673, -0.030106},{0.392804, 0.009419, 0.000000},{
      0.446453, 0.036755, 0.000000},{0.445060, 0.038672, -0.030106}}],
    Polygon[{{0.392804, 0.009419, 0.000000},{0.392072, 0.011673, 0.030106},{
      0.445060, 0.038672, 0.030106},{0.446453, 0.036755, 0.000000}}],
    Polygon[{{0.392072, 0.011673, 0.030106},{0.389893, 0.018377, 0.059470},{
      0.440916, 0.044375, 0.059470},{0.445060, 0.038672, 0.030106}}],
    Polygon[{{0.389893, 0.018377, 0.059470},{0.386322, 0.029368, 0.087371},{
      0.434123, 0.053724, 0.087371},{0.440916, 0.044375, 0.059470}}],
    Polygon[{{0.386322, 0.029368, 0.087371},{0.381446, 0.044375, 0.113119},{
      0.424849, 0.066490, 0.113119},{0.434123, 0.053724, 0.087371}}],
    Polygon[{{0.381446, 0.044375, 0.113119},{0.375385, 0.063028, 0.136083},{
      0.413321, 0.082357, 0.136083},{0.424849, 0.066490, 0.113119}}],
    Polygon[{{0.375385, 0.063028, 0.136083},{0.368289, 0.084867, 0.155695},{
      0.399823, 0.100935, 0.155695},{0.413321, 0.082357, 0.136083}}],
    Polygon[{{0.368289, 0.084867, 0.155695},{0.360332, 0.109356, 0.171474},{
      0.384688, 0.121766, 0.171474},{0.399823, 0.100935, 0.155695}}],
    Polygon[{{0.360332, 0.109356, 0.171474},{0.351711, 0.135890, 0.183031},{
      0.368289, 0.144338, 0.183031},{0.384688, 0.121766, 0.171474}}],
    Polygon[{{0.351711, 0.135890, 0.183031},{0.342637, 0.163818, 0.190081},{
      0.351029, 0.168094, 0.190081},{0.368289, 0.144338, 0.183031}}],
    Polygon[{{0.351029, 0.168094, -0.190081},{0.368289, 0.144338, -0.183031},{
      0.381446, 0.157494, -0.183031},{0.357689, 0.174754, -0.190081}}],
    Polygon[{{0.368289, 0.144338, -0.183031},{0.384688, 0.121766, -0.171474},{
      0.404018, 0.141095, -0.171474},{0.381446, 0.157494, -0.183031}}],
    Polygon[{{0.384688, 0.121766, -0.171474},{0.399823, 0.100935, -0.155695},{
      0.424849, 0.125960, -0.155695},{0.404018, 0.141095, -0.171474}}],
    Polygon[{{0.399823, 0.100935, -0.155695},{0.413321, 0.082357, -0.136083},{
      0.443427, 0.112463, -0.136083},{0.424849, 0.125960, -0.155695}}],
    Polygon[{{0.413321, 0.082357, -0.136083},{0.424849, 0.066490, -0.113119},{
      0.459294, 0.100935, -0.113119},{0.443427, 0.112463, -0.136083}}],
    Polygon[{{0.424849, 0.066490, -0.113119},{0.434123, 0.053724, -0.087371},{
      0.472059, 0.091660, -0.087371},{0.459294, 0.100935, -0.113119}}],
    Polygon[{{0.434123, 0.053724, -0.087371},{0.440916, 0.044375, -0.059470},{
      0.481408, 0.084867, -0.059470},{0.472059, 0.091660, -0.087371}}],
    Polygon[{{0.440916, 0.044375, -0.059470},{0.445060, 0.038672, -0.030106},{
      0.487112, 0.080723, -0.030106},{0.481408, 0.084867, -0.059470}}],
    Polygon[{{0.445060, 0.038672, -0.030106},{0.446453, 0.036755, 0.000000},{
      0.489029, 0.079331, 0.000000},{0.487112, 0.080723, -0.030106}}],
    Polygon[{{0.446453, 0.036755, 0.000000},{0.445060, 0.038672, 0.030106},{
      0.487112, 0.080723, 0.030106},{0.489029, 0.079331, 0.000000}}],
    Polygon[{{0.445060, 0.038672, 0.030106},{0.440916, 0.044375, 0.059470},{
      0.481408, 0.084867, 0.059470},{0.487112, 0.080723, 0.030106}}],
    Polygon[{{0.440916, 0.044375, 0.059470},{0.434123, 0.053724, 0.087371},{
      0.472059, 0.091660, 0.087371},{0.481408, 0.084867, 0.059470}}],
    Polygon[{{0.434123, 0.053724, 0.087371},{0.424849, 0.066490, 0.113119},{
      0.459294, 0.100935, 0.113119},{0.472059, 0.091660, 0.087371}}],
    Polygon[{{0.424849, 0.066490, 0.113119},{0.413321, 0.082357, 0.136083},{
      0.443427, 0.112463, 0.136083},{0.459294, 0.100935, 0.113119}}],
    Polygon[{{0.413321, 0.082357, 0.136083},{0.399823, 0.100935, 0.155695},{
      0.424849, 0.125960, 0.155695},{0.443427, 0.112463, 0.136083}}],
    Polygon[{{0.399823, 0.100935, 0.155695},{0.384688, 0.121766, 0.171474},{
      0.404018, 0.141095, 0.171474},{0.424849, 0.125960, 0.155695}}],
    Polygon[{{0.384688, 0.121766, 0.171474},{0.368289, 0.144338, 0.183031},{
      0.381446, 0.157494, 0.183031},{0.404018, 0.141095, 0.171474}}],
    Polygon[{{0.368289, 0.144338, 0.183031},{0.351029, 0.168094, 0.190081},{
      0.357689, 0.174754, 0.190081},{0.381446, 0.157494, 0.183031}}],
    Polygon[{{0.357689, 0.174754, -0.190081},{0.381446, 0.157494, -0.183031},{
      0.389893, 0.174073, -0.183031},{0.361966, 0.183147, -0.190081}}],
    Polygon[{{0.381446, 0.157494, -0.183031},{0.404018, 0.141095, -0.171474},{
      0.416428, 0.165451, -0.171474},{0.389893, 0.174073, -0.183031}}],
    Polygon[{{0.404018, 0.141095, -0.171474},{0.424849, 0.125960, -0.155695},{
      0.440916, 0.157494, -0.155695},{0.416428, 0.165451, -0.171474}}],
    Polygon[{{0.424849, 0.125960, -0.155695},{0.443427, 0.112463, -0.136083},{
      0.462756, 0.150398, -0.136083},{0.440916, 0.157494, -0.155695}}],
    Polygon[{{0.443427, 0.112463, -0.136083},{0.459294, 0.100935, -0.113119},{
      0.481408, 0.144338, -0.113119},{0.462756, 0.150398, -0.136083}}],
    Polygon[{{0.459294, 0.100935, -0.113119},{0.472059, 0.091660, -0.087371},{
      0.496415, 0.139462, -0.087371},{0.481408, 0.144338, -0.113119}}],
    Polygon[{{0.472059, 0.091660, -0.087371},{0.481408, 0.084867, -0.059470},{
      0.507406, 0.135890, -0.059470},{0.496415, 0.139462, -0.087371}}],
    Polygon[{{0.481408, 0.084867, -0.059470},{0.487112, 0.080723, -0.030106},{
      0.514111, 0.133712, -0.030106},{0.507406, 0.135890, -0.059470}}],
    Polygon[{{0.487112, 0.080723, -0.030106},{0.489029, 0.079331, 0.000000},{
      0.516364, 0.132980, 0.000000},{0.514111, 0.133712, -0.030106}}],
    Polygon[{{0.489029, 0.079331, 0.000000},{0.487112, 0.080723, 0.030106},{
      0.514111, 0.133712, 0.030106},{0.516364, 0.132980, 0.000000}}],
    Polygon[{{0.487112, 0.080723, 0.030106},{0.481408, 0.084867, 0.059470},{
      0.507406, 0.135890, 0.059470},{0.514111, 0.133712, 0.030106}}],
    Polygon[{{0.481408, 0.084867, 0.059470},{0.472059, 0.091660, 0.087371},{
      0.496415, 0.139462, 0.087371},{0.507406, 0.135890, 0.059470}}],
    Polygon[{{0.472059, 0.091660, 0.087371},{0.459294, 0.100935, 0.113119},{
      0.481408, 0.144338, 0.113119},{0.496415, 0.139462, 0.087371}}],
    Polygon[{{0.459294, 0.100935, 0.113119},{0.443427, 0.112463, 0.136083},{
      0.462756, 0.150398, 0.136083},{0.481408, 0.144338, 0.113119}}],
    Polygon[{{0.443427, 0.112463, 0.136083},{0.424849, 0.125960, 0.155695},{
      0.440916, 0.157494, 0.155695},{0.462756, 0.150398, 0.136083}}],
    Polygon[{{0.424849, 0.125960, 0.155695},{0.404018, 0.141095, 0.171474},{
      0.416428, 0.165451, 0.171474},{0.440916, 0.157494, 0.155695}}],
    Polygon[{{0.404018, 0.141095, 0.171474},{0.381446, 0.157494, 0.183031},{
      0.389893, 0.174073, 0.183031},{0.416428, 0.165451, 0.171474}}],
    Polygon[{{0.381446, 0.157494, 0.183031},{0.357689, 0.174754, 0.190081},{
      0.361966, 0.183147, 0.190081},{0.389893, 0.174073, 0.183031}}],
    Polygon[{{0.361966, 0.183147, -0.190081},{0.389893, 0.174073, -0.183031},{
      0.392804, 0.192450, -0.183031},{0.363439, 0.192450, -0.190081}}],
    Polygon[{{0.389893, 0.174073, -0.183031},{0.416428, 0.165451, -0.171474},{
      0.420704, 0.192450, -0.171474},{0.392804, 0.192450, -0.183031}}],
    Polygon[{{0.416428, 0.165451, -0.171474},{0.440916, 0.157494, -0.155695},{
      0.446453, 0.192450, -0.155695},{0.420704, 0.192450, -0.171474}}],
    Polygon[{{0.440916, 0.157494, -0.155695},{0.462756, 0.150398, -0.136083},{
      0.469416, 0.192450, -0.136083},{0.446453, 0.192450, -0.155695}}],
    Polygon[{{0.462756, 0.150398, -0.136083},{0.481408, 0.144338, -0.113119},{
      0.489029, 0.192450, -0.113119},{0.469416, 0.192450, -0.136083}}],
    Polygon[{{0.481408, 0.144338, -0.113119},{0.496415, 0.139462, -0.087371},{
      0.504808, 0.192450, -0.087371},{0.489029, 0.192450, -0.113119}}],
    Polygon[{{0.496415, 0.139462, -0.087371},{0.507406, 0.135890, -0.059470},{
      0.516364, 0.192450, -0.059470},{0.504808, 0.192450, -0.087371}}],
    Polygon[{{0.507406, 0.135890, -0.059470},{0.514111, 0.133712, -0.030106},{
      0.523414, 0.192450, -0.030106},{0.516364, 0.192450, -0.059470}}],
    Polygon[{{0.514111, 0.133712, -0.030106},{0.516364, 0.132980, 0.000000},{
      0.525783, 0.192450, 0.000000},{0.523414, 0.192450, -0.030106}}],
    Polygon[{{0.516364, 0.132980, 0.000000},{0.514111, 0.133712, 0.030106},{
      0.523414, 0.192450, 0.030106},{0.525783, 0.192450, 0.000000}}],
    Polygon[{{0.514111, 0.133712, 0.030106},{0.507406, 0.135890, 0.059470},{
      0.516364, 0.192450, 0.059470},{0.523414, 0.192450, 0.030106}}],
    Polygon[{{0.507406, 0.135890, 0.059470},{0.496415, 0.139462, 0.087371},{
      0.504808, 0.192450, 0.087371},{0.516364, 0.192450, 0.059470}}],
    Polygon[{{0.496415, 0.139462, 0.087371},{0.481408, 0.144338, 0.113119},{
      0.489029, 0.192450, 0.113119},{0.504808, 0.192450, 0.087371}}],
    Polygon[{{0.481408, 0.144338, 0.113119},{0.462756, 0.150398, 0.136083},{
      0.469416, 0.192450, 0.136083},{0.489029, 0.192450, 0.113119}}],
    Polygon[{{0.462756, 0.150398, 0.136083},{0.440916, 0.157494, 0.155695},{
      0.446453, 0.192450, 0.155695},{0.469416, 0.192450, 0.136083}}],
    Polygon[{{0.440916, 0.157494, 0.155695},{0.416428, 0.165451, 0.171474},{
      0.420704, 0.192450, 0.171474},{0.446453, 0.192450, 0.155695}}],
    Polygon[{{0.416428, 0.165451, 0.171474},{0.389893, 0.174073, 0.183031},{
      0.392804, 0.192450, 0.183031},{0.420704, 0.192450, 0.171474}}],
    Polygon[{{0.389893, 0.174073, 0.183031},{0.361966, 0.183147, 0.190081},{
      0.363439, 0.192450, 0.190081},{0.392804, 0.192450, 0.183031}}],
    Polygon[{{0.121146, 0.064150, -0.063360},{0.130935, 0.064150, -0.061010},{
      0.129964, 0.070276, -0.061010},{0.120655, 0.067251, -0.063360}}],
    Polygon[{{0.130935, 0.064150, -0.061010},{0.140235, 0.064150, -0.057158},{
      0.138809, 0.073150, -0.057158},{0.129964, 0.070276, -0.061010}}],
    Polygon[{{0.140235, 0.064150, -0.057158},{0.148818, 0.064150, -0.051898},{
      0.146972, 0.075802, -0.051898},{0.138809, 0.073150, -0.057158}}],
    Polygon[{{0.148818, 0.064150, -0.051898},{0.156472, 0.064150, -0.045361},{
      0.154252, 0.078167, -0.045361},{0.146972, 0.075802, -0.051898}}],
    Polygon[{{0.156472, 0.064150, -0.045361},{0.163010, 0.064150, -0.037706},{
      0.160469, 0.080188, -0.037706},{0.154252, 0.078167, -0.045361}}],
    Polygon[{{0.163010, 0.064150, -0.037706},{0.168269, 0.064150, -0.029124},{
      0.165472, 0.081813, -0.029124},{0.160469, 0.080188, -0.037706}}],
    Polygon[{{0.168269, 0.064150, -0.029124},{0.172121, 0.064150, -0.019823},{
      0.169135, 0.083003, -0.019823},{0.165472, 0.081813, -0.029124}}],
    Polygon[{{0.172121, 0.064150, -0.019823},{0.174471, 0.064150, -0.010035},{
      0.171370, 0.083729, -0.010035},{0.169135, 0.083003, -0.019823}}],
    Polygon[{{0.174471, 0.064150, -0.010035},{0.175261, 0.064150, 0.000000},{
      0.172121, 0.083973, 0.000000},{0.171370, 0.083729, -0.010035}}],
    Polygon[{{0.175261, 0.064150, 0.000000},{0.174471, 0.064150, 0.010035},{
      0.171370, 0.083729, 0.010035},{0.172121, 0.083973, 0.000000}}],
    Polygon[{{0.174471, 0.064150, 0.010035},{0.172121, 0.064150, 0.019823},{
      0.169135, 0.083003, 0.019823},{0.171370, 0.083729, 0.010035}}],
    Polygon[{{0.172121, 0.064150, 0.019823},{0.168269, 0.064150, 0.029124},{
      0.165472, 0.081813, 0.029124},{0.169135, 0.083003, 0.019823}}],
    Polygon[{{0.168269, 0.064150, 0.029124},{0.163010, 0.064150, 0.037706},{
      0.160469, 0.080188, 0.037706},{0.165472, 0.081813, 0.029124}}],
    Polygon[{{0.163010, 0.064150, 0.037706},{0.156472, 0.064150, 0.045361},{
      0.154252, 0.078167, 0.045361},{0.160469, 0.080188, 0.037706}}],
    Polygon[{{0.156472, 0.064150, 0.045361},{0.148818, 0.064150, 0.051898},{
      0.146972, 0.075802, 0.051898},{0.154252, 0.078167, 0.045361}}],
    Polygon[{{0.148818, 0.064150, 0.051898},{0.140235, 0.064150, 0.057158},{
      0.138809, 0.073150, 0.057158},{0.146972, 0.075802, 0.051898}}],
    Polygon[{{0.140235, 0.064150, 0.057158},{0.130935, 0.064150, 0.061010},{
      0.129964, 0.070276, 0.061010},{0.138809, 0.073150, 0.057158}}],
    Polygon[{{0.130935, 0.064150, 0.061010},{0.121146, 0.064150, 0.063360},{
      0.120655, 0.067251, 0.063360},{0.129964, 0.070276, 0.061010}}],
    Polygon[{{0.120655, 0.067251, -0.063360},{0.129964, 0.070276, -0.061010},{
      0.127149, 0.075802, -0.061010},{0.119230, 0.070049, -0.063360}}],
    Polygon[{{0.129964, 0.070276, -0.061010},{0.138809, 0.073150, -0.057158},{
      0.134673, 0.081268, -0.057158},{0.127149, 0.075802, -0.061010}}],
    Polygon[{{0.138809, 0.073150, -0.057158},{0.146972, 0.075802, -0.051898},{
      0.141616, 0.086313, -0.051898},{0.134673, 0.081268, -0.057158}}],
    Polygon[{{0.146972, 0.075802, -0.051898},{0.154252, 0.078167, -0.045361},{
      0.147809, 0.090813, -0.045361},{0.141616, 0.086313, -0.051898}}],
    Polygon[{{0.154252, 0.078167, -0.045361},{0.160469, 0.080188, -0.037706},{
      0.153098, 0.094655, -0.037706},{0.147809, 0.090813, -0.045361}}],
    Polygon[{{0.160469, 0.080188, -0.037706},{0.165472, 0.081813, -0.029124},{
      0.157353, 0.097747, -0.029124},{0.153098, 0.094655, -0.037706}}],
    Polygon[{{0.165472, 0.081813, -0.029124},{0.169135, 0.083003, -0.019823},{
      0.160469, 0.100011, -0.019823},{0.157353, 0.097747, -0.029124}}],
    Polygon[{{0.169135, 0.083003, -0.019823},{0.171370, 0.083729, -0.010035},{
      0.162371, 0.101392, -0.010035},{0.160469, 0.100011, -0.019823}}],
    Polygon[{{0.171370, 0.083729, -0.010035},{0.172121, 0.083973, 0.000000},{
      0.163010, 0.101856, 0.000000},{0.162371, 0.101392, -0.010035}}],
    Polygon[{{0.172121, 0.083973, 0.000000},{0.171370, 0.083729, 0.010035},{
      0.162371, 0.101392, 0.010035},{0.163010, 0.101856, 0.000000}}],
    Polygon[{{0.171370, 0.083729, 0.010035},{0.169135, 0.083003, 0.019823},{
      0.160469, 0.100011, 0.019823},{0.162371, 0.101392, 0.010035}}],
    Polygon[{{0.169135, 0.083003, 0.019823},{0.165472, 0.081813, 0.029124},{
      0.157353, 0.097747, 0.029124},{0.160469, 0.100011, 0.019823}}],
    Polygon[{{0.165472, 0.081813, 0.029124},{0.160469, 0.080188, 0.037706},{
      0.153098, 0.094655, 0.037706},{0.157353, 0.097747, 0.029124}}],
    Polygon[{{0.160469, 0.080188, 0.037706},{0.154252, 0.078167, 0.045361},{
      0.147809, 0.090813, 0.045361},{0.153098, 0.094655, 0.037706}}],
    Polygon[{{0.154252, 0.078167, 0.045361},{0.146972, 0.075802, 0.051898},{
      0.141616, 0.086313, 0.051898},{0.147809, 0.090813, 0.045361}}],
    Polygon[{{0.146972, 0.075802, 0.051898},{0.138809, 0.073150, 0.057158},{
      0.134673, 0.081268, 0.057158},{0.141616, 0.086313, 0.051898}}],
    Polygon[{{0.138809, 0.073150, 0.057158},{0.129964, 0.070276, 0.061010},{
      0.127149, 0.075802, 0.061010},{0.134673, 0.081268, 0.057158}}],
    Polygon[{{0.129964, 0.070276, 0.061010},{0.120655, 0.067251, 0.063360},{
      0.119230, 0.070049, 0.063360},{0.127149, 0.075802, 0.061010}}],
    Polygon[{{0.119230, 0.070049, -0.063360},{0.127149, 0.075802, -0.061010},{
      0.122763, 0.080188, -0.061010},{0.117010, 0.072269, -0.063360}}],
    Polygon[{{0.127149, 0.075802, -0.061010},{0.134673, 0.081268, -0.057158},{
      0.128229, 0.087711, -0.057158},{0.122763, 0.080188, -0.061010}}],
    Polygon[{{0.134673, 0.081268, -0.057158},{0.141616, 0.086313, -0.051898},{
      0.133274, 0.094655, -0.051898},{0.128229, 0.087711, -0.057158}}],
    Polygon[{{0.141616, 0.086313, -0.051898},{0.147809, 0.090813, -0.045361},{
      0.137774, 0.100848, -0.045361},{0.133274, 0.094655, -0.051898}}],
    Polygon[{{0.147809, 0.090813, -0.045361},{0.153098, 0.094655, -0.037706},{
      0.141616, 0.106137, -0.037706},{0.137774, 0.100848, -0.045361}}],
    Polygon[{{0.153098, 0.094655, -0.037706},{0.157353, 0.097747, -0.029124},{
      0.144708, 0.110392, -0.029124},{0.141616, 0.106137, -0.037706}}],
    Polygon[{{0.157353, 0.097747, -0.029124},{0.160469, 0.100011, -0.019823},{
      0.146972, 0.113508, -0.019823},{0.144708, 0.110392, -0.029124}}],
    Polygon[{{0.160469, 0.100011, -0.019823},{0.162371, 0.101392, -0.010035},{
      0.148353, 0.115410, -0.010035},{0.146972, 0.113508, -0.019823}}],
    Polygon[{{0.162371, 0.101392, -0.010035},{0.163010, 0.101856, 0.000000},{
      0.148818, 0.116048, 0.000000},{0.148353, 0.115410, -0.010035}}],
    Polygon[{{0.163010, 0.101856, 0.000000},{0.162371, 0.101392, 0.010035},{
      0.148353, 0.115410, 0.010035},{0.148818, 0.116048, 0.000000}}],
    Polygon[{{0.162371, 0.101392, 0.010035},{0.160469, 0.100011, 0.019823},{
      0.146972, 0.113508, 0.019823},{0.148353, 0.115410, 0.010035}}],
    Polygon[{{0.160469, 0.100011, 0.019823},{0.157353, 0.097747, 0.029124},{
      0.144708, 0.110392, 0.029124},{0.146972, 0.113508, 0.019823}}],
    Polygon[{{0.157353, 0.097747, 0.029124},{0.153098, 0.094655, 0.037706},{
      0.141616, 0.106137, 0.037706},{0.144708, 0.110392, 0.029124}}],
    Polygon[{{0.153098, 0.094655, 0.037706},{0.147809, 0.090813, 0.045361},{
      0.137774, 0.100848, 0.045361},{0.141616, 0.106137, 0.037706}}],
    Polygon[{{0.147809, 0.090813, 0.045361},{0.141616, 0.086313, 0.051898},{
      0.133274, 0.094655, 0.051898},{0.137774, 0.100848, 0.045361}}],
    Polygon[{{0.141616, 0.086313, 0.051898},{0.134673, 0.081268, 0.057158},{
      0.128229, 0.087711, 0.057158},{0.133274, 0.094655, 0.051898}}],
    Polygon[{{0.134673, 0.081268, 0.057158},{0.127149, 0.075802, 0.061010},{
      0.122763, 0.080188, 0.061010},{0.128229, 0.087711, 0.057158}}],
    Polygon[{{0.127149, 0.075802, 0.061010},{0.119230, 0.070049, 0.063360},{
      0.117010, 0.072269, 0.063360},{0.122763, 0.080188, 0.061010}}],
    Polygon[{{0.117010, 0.072269, -0.063360},{0.122763, 0.080188, -0.061010},{
      0.117237, 0.083003, -0.061010},{0.114212, 0.073694, -0.063360}}],
    Polygon[{{0.122763, 0.080188, -0.061010},{0.128229, 0.087711, -0.057158},{
      0.120111, 0.091848, -0.057158},{0.117237, 0.083003, -0.061010}}],
    Polygon[{{0.128229, 0.087711, -0.057158},{0.133274, 0.094655, -0.051898},{
      0.122763, 0.100011, -0.051898},{0.120111, 0.091848, -0.057158}}],
    Polygon[{{0.133274, 0.094655, -0.051898},{0.137774, 0.100848, -0.045361},{
      0.125128, 0.107291, -0.045361},{0.122763, 0.100011, -0.051898}}],
    Polygon[{{0.137774, 0.100848, -0.045361},{0.141616, 0.106137, -0.037706},{
      0.127149, 0.113508, -0.037706},{0.125128, 0.107291, -0.045361}}],
    Polygon[{{0.141616, 0.106137, -0.037706},{0.144708, 0.110392, -0.029124},{
      0.128774, 0.118511, -0.029124},{0.127149, 0.113508, -0.037706}}],
    Polygon[{{0.144708, 0.110392, -0.029124},{0.146972, 0.113508, -0.019823},{
      0.129964, 0.122174, -0.019823},{0.128774, 0.118511, -0.029124}}],
    Polygon[{{0.146972, 0.113508, -0.019823},{0.148353, 0.115410, -0.010035},{
      0.130691, 0.124409, -0.010035},{0.129964, 0.122174, -0.019823}}],
    Polygon[{{0.148353, 0.115410, -0.010035},{0.148818, 0.116048, 0.000000},{
      0.130935, 0.125160, 0.000000},{0.130691, 0.124409, -0.010035}}],
    Polygon[{{0.148818, 0.116048, 0.000000},{0.148353, 0.115410, 0.010035},{
      0.130691, 0.124409, 0.010035},{0.130935, 0.125160, 0.000000}}],
    Polygon[{{0.148353, 0.115410, 0.010035},{0.146972, 0.113508, 0.019823},{
      0.129964, 0.122174, 0.019823},{0.130691, 0.124409, 0.010035}}],
    Polygon[{{0.146972, 0.113508, 0.019823},{0.144708, 0.110392, 0.029124},{
      0.128774, 0.118511, 0.029124},{0.129964, 0.122174, 0.019823}}],
    Polygon[{{0.144708, 0.110392, 0.029124},{0.141616, 0.106137, 0.037706},{
      0.127149, 0.113508, 0.037706},{0.128774, 0.118511, 0.029124}}],
    Polygon[{{0.141616, 0.106137, 0.037706},{0.137774, 0.100848, 0.045361},{
      0.125128, 0.107291, 0.045361},{0.127149, 0.113508, 0.037706}}],
    Polygon[{{0.137774, 0.100848, 0.045361},{0.133274, 0.094655, 0.051898},{
      0.122763, 0.100011, 0.051898},{0.125128, 0.107291, 0.045361}}],
    Polygon[{{0.133274, 0.094655, 0.051898},{0.128229, 0.087711, 0.057158},{
      0.120111, 0.091848, 0.057158},{0.122763, 0.100011, 0.051898}}],
    Polygon[{{0.128229, 0.087711, 0.057158},{0.122763, 0.080188, 0.061010},{
      0.117237, 0.083003, 0.061010},{0.120111, 0.091848, 0.057158}}],
    Polygon[{{0.122763, 0.080188, 0.061010},{0.117010, 0.072269, 0.063360},{
      0.114212, 0.073694, 0.063360},{0.117237, 0.083003, 0.061010}}],
    Polygon[{{0.114212, 0.073694, -0.063360},{0.117237, 0.083003, -0.061010},{
      0.111111, 0.083973, -0.061010},{0.111111, 0.074185, -0.063360}}],
    Polygon[{{0.117237, 0.083003, -0.061010},{0.120111, 0.091848, -0.057158},{
      0.111111, 0.093274, -0.057158},{0.111111, 0.083973, -0.061010}}],
    Polygon[{{0.120111, 0.091848, -0.057158},{0.122763, 0.100011, -0.051898},{
      0.111111, 0.101856, -0.051898},{0.111111, 0.093274, -0.057158}}],
    Polygon[{{0.122763, 0.100011, -0.051898},{0.125128, 0.107291, -0.045361},{
      0.111111, 0.109511, -0.045361},{0.111111, 0.101856, -0.051898}}],
    Polygon[{{0.125128, 0.107291, -0.045361},{0.127149, 0.113508, -0.037706},{
      0.111111, 0.116048, -0.037706},{0.111111, 0.109511, -0.045361}}],
    Polygon[{{0.127149, 0.113508, -0.037706},{0.128774, 0.118511, -0.029124},{
      0.111111, 0.121308, -0.029124},{0.111111, 0.116048, -0.037706}}],
    Polygon[{{0.128774, 0.118511, -0.029124},{0.129964, 0.122174, -0.019823},{
      0.111111, 0.125160, -0.019823},{0.111111, 0.121308, -0.029124}}],
    Polygon[{{0.129964, 0.122174, -0.019823},{0.130691, 0.124409, -0.010035},{
      0.111111, 0.127510, -0.010035},{0.111111, 0.125160, -0.019823}}],
    Polygon[{{0.130691, 0.124409, -0.010035},{0.130935, 0.125160, 0.000000},{
      0.111111, 0.128300, 0.000000},{0.111111, 0.127510, -0.010035}}],
    Polygon[{{0.130935, 0.125160, 0.000000},{0.130691, 0.124409, 0.010035},{
      0.111111, 0.127510, 0.010035},{0.111111, 0.128300, 0.000000}}],
    Polygon[{{0.130691, 0.124409, 0.010035},{0.129964, 0.122174, 0.019823},{
      0.111111, 0.125160, 0.019823},{0.111111, 0.127510, 0.010035}}],
    Polygon[{{0.129964, 0.122174, 0.019823},{0.128774, 0.118511, 0.029124},{
      0.111111, 0.121308, 0.029124},{0.111111, 0.125160, 0.019823}}],
    Polygon[{{0.128774, 0.118511, 0.029124},{0.127149, 0.113508, 0.037706},{
      0.111111, 0.116048, 0.037706},{0.111111, 0.121308, 0.029124}}],
    Polygon[{{0.127149, 0.113508, 0.037706},{0.125128, 0.107291, 0.045361},{
      0.111111, 0.109511, 0.045361},{0.111111, 0.116048, 0.037706}}],
    Polygon[{{0.125128, 0.107291, 0.045361},{0.122763, 0.100011, 0.051898},{
      0.111111, 0.101856, 0.051898},{0.111111, 0.109511, 0.045361}}],
    Polygon[{{0.122763, 0.100011, 0.051898},{0.120111, 0.091848, 0.057158},{
      0.111111, 0.093274, 0.057158},{0.111111, 0.101856, 0.051898}}],
    Polygon[{{0.120111, 0.091848, 0.057158},{0.117237, 0.083003, 0.061010},{
      0.111111, 0.083973, 0.061010},{0.111111, 0.093274, 0.057158}}],
    Polygon[{{0.117237, 0.083003, 0.061010},{0.114212, 0.073694, 0.063360},{
      0.111111, 0.074185, 0.063360},{0.111111, 0.083973, 0.061010}}],
    Polygon[{{0.111111, 0.074185, -0.063360},{0.111111, 0.083973, -0.061010},{
      0.104985, 0.083003, -0.061010},{0.108010, 0.073694, -0.063360}}],
    Polygon[{{0.111111, 0.083973, -0.061010},{0.111111, 0.093274, -0.057158},{
      0.102111, 0.091848, -0.057158},{0.104985, 0.083003, -0.061010}}],
    Polygon[{{0.111111, 0.093274, -0.057158},{0.111111, 0.101856, -0.051898},{
      0.099459, 0.100011, -0.051898},{0.102111, 0.091848, -0.057158}}],
    Polygon[{{0.111111, 0.101856, -0.051898},{0.111111, 0.109511, -0.045361},{
      0.097094, 0.107291, -0.045361},{0.099459, 0.100011, -0.051898}}],
    Polygon[{{0.111111, 0.109511, -0.045361},{0.111111, 0.116048, -0.037706},{
      0.095074, 0.113508, -0.037706},{0.097094, 0.107291, -0.045361}}],
    Polygon[{{0.111111, 0.116048, -0.037706},{0.111111, 0.121308, -0.029124},{
      0.093448, 0.118511, -0.029124},{0.095074, 0.113508, -0.037706}}],
    Polygon[{{0.111111, 0.121308, -0.029124},{0.111111, 0.125160, -0.019823},{
      0.092258, 0.122174, -0.019823},{0.093448, 0.118511, -0.029124}}],
    Polygon[{{0.111111, 0.125160, -0.019823},{0.111111, 0.127510, -0.010035},{
      0.091532, 0.124409, -0.010035},{0.092258, 0.122174, -0.019823}}],
    Polygon[{{0.111111, 0.127510, -0.010035},{0.111111, 0.128300, 0.000000},{
      0.091288, 0.125160, 0.000000},{0.091532, 0.124409, -0.010035}}],
    Polygon[{{0.111111, 0.128300, 0.000000},{0.111111, 0.127510, 0.010035},{
      0.091532, 0.124409, 0.010035},{0.091288, 0.125160, 0.000000}}],
    Polygon[{{0.111111, 0.127510, 0.010035},{0.111111, 0.125160, 0.019823},{
      0.092258, 0.122174, 0.019823},{0.091532, 0.124409, 0.010035}}],
    Polygon[{{0.111111, 0.125160, 0.019823},{0.111111, 0.121308, 0.029124},{
      0.093448, 0.118511, 0.029124},{0.092258, 0.122174, 0.019823}}],
    Polygon[{{0.111111, 0.121308, 0.029124},{0.111111, 0.116048, 0.037706},{
      0.095074, 0.113508, 0.037706},{0.093448, 0.118511, 0.029124}}],
    Polygon[{{0.111111, 0.116048, 0.037706},{0.111111, 0.109511, 0.045361},{
      0.097094, 0.107291, 0.045361},{0.095074, 0.113508, 0.037706}}],
    Polygon[{{0.111111, 0.109511, 0.045361},{0.111111, 0.101856, 0.051898},{
      0.099459, 0.100011, 0.051898},{0.097094, 0.107291, 0.045361}}],
    Polygon[{{0.111111, 0.101856, 0.051898},{0.111111, 0.093274, 0.057158},{
      0.102111, 0.091848, 0.057158},{0.099459, 0.100011, 0.051898}}],
    Polygon[{{0.111111, 0.093274, 0.057158},{0.111111, 0.083973, 0.061010},{
      0.104985, 0.083003, 0.061010},{0.102111, 0.091848, 0.057158}}],
    Polygon[{{0.111111, 0.083973, 0.061010},{0.111111, 0.074185, 0.063360},{
      0.108010, 0.073694, 0.063360},{0.104985, 0.083003, 0.061010}}],
    Polygon[{{0.108010, 0.073694, -0.063360},{0.104985, 0.083003, -0.061010},{
      0.099459, 0.080188, -0.061010},{0.105213, 0.072269, -0.063360}}],
    Polygon[{{0.104985, 0.083003, -0.061010},{0.102111, 0.091848, -0.057158},{
      0.093993, 0.087711, -0.057158},{0.099459, 0.080188, -0.061010}}],
    Polygon[{{0.102111, 0.091848, -0.057158},{0.099459, 0.100011, -0.051898},{
      0.088948, 0.094655, -0.051898},{0.093993, 0.087711, -0.057158}}],
    Polygon[{{0.099459, 0.100011, -0.051898},{0.097094, 0.107291, -0.045361},{
      0.084449, 0.100848, -0.045361},{0.088948, 0.094655, -0.051898}}],
    Polygon[{{0.097094, 0.107291, -0.045361},{0.095074, 0.113508, -0.037706},{
      0.080606, 0.106137, -0.037706},{0.084449, 0.100848, -0.045361}}],
    Polygon[{{0.095074, 0.113508, -0.037706},{0.093448, 0.118511, -0.029124},{
      0.077514, 0.110392, -0.029124},{0.080606, 0.106137, -0.037706}}],
    Polygon[{{0.093448, 0.118511, -0.029124},{0.092258, 0.122174, -0.019823},{
      0.075250, 0.113508, -0.019823},{0.077514, 0.110392, -0.029124}}],
    Polygon[{{0.092258, 0.122174, -0.019823},{0.091532, 0.124409, -0.010035},{
      0.073869, 0.115410, -0.010035},{0.075250, 0.113508, -0.019823}}],
    Polygon[{{0.091532, 0.124409, -0.010035},{0.091288, 0.125160, 0.000000},{
      0.073405, 0.116048, 0.000000},{0.073869, 0.115410, -0.010035}}],
    Polygon[{{0.091288, 0.125160, 0.000000},{0.091532, 0.124409, 0.010035},{
      0.073869, 0.115410, 0.010035},{0.073405, 0.116048, 0.000000}}],
    Polygon[{{0.091532, 0.124409, 0.010035},{0.092258, 0.122174, 0.019823},{
      0.075250, 0.113508, 0.019823},{0.073869, 0.115410, 0.010035}}],
    Polygon[{{0.092258, 0.122174, 0.019823},{0.093448, 0.118511, 0.029124},{
      0.077514, 0.110392, 0.029124},{0.075250, 0.113508, 0.019823}}],
    Polygon[{{0.093448, 0.118511, 0.029124},{0.095074, 0.113508, 0.037706},{
      0.080606, 0.106137, 0.037706},{0.077514, 0.110392, 0.029124}}],
    Polygon[{{0.095074, 0.113508, 0.037706},{0.097094, 0.107291, 0.045361},{
      0.084449, 0.100848, 0.045361},{0.080606, 0.106137, 0.037706}}],
    Polygon[{{0.097094, 0.107291, 0.045361},{0.099459, 0.100011, 0.051898},{
      0.088948, 0.094655, 0.051898},{0.084449, 0.100848, 0.045361}}],
    Polygon[{{0.099459, 0.100011, 0.051898},{0.102111, 0.091848, 0.057158},{
      0.093993, 0.087711, 0.057158},{0.088948, 0.094655, 0.051898}}],
    Polygon[{{0.102111, 0.091848, 0.057158},{0.104985, 0.083003, 0.061010},{
      0.099459, 0.080188, 0.061010},{0.093993, 0.087711, 0.057158}}],
    Polygon[{{0.104985, 0.083003, 0.061010},{0.108010, 0.073694, 0.063360},{
      0.105213, 0.072269, 0.063360},{0.099459, 0.080188, 0.061010}}],
    Polygon[{{0.105213, 0.072269, -0.063360},{0.099459, 0.080188, -0.061010},{
      0.095074, 0.075802, -0.061010},{0.102992, 0.070049, -0.063360}}],
    Polygon[{{0.099459, 0.080188, -0.061010},{0.093993, 0.087711, -0.057158},{
      0.087550, 0.081268, -0.057158},{0.095074, 0.075802, -0.061010}}],
    Polygon[{{0.093993, 0.087711, -0.057158},{0.088948, 0.094655, -0.051898},{
      0.080606, 0.086313, -0.051898},{0.087550, 0.081268, -0.057158}}],
    Polygon[{{0.088948, 0.094655, -0.051898},{0.084449, 0.100848, -0.045361},{
      0.074413, 0.090813, -0.045361},{0.080606, 0.086313, -0.051898}}],
    Polygon[{{0.084449, 0.100848, -0.045361},{0.080606, 0.106137, -0.037706},{
      0.069124, 0.094655, -0.037706},{0.074413, 0.090813, -0.045361}}],
    Polygon[{{0.080606, 0.106137, -0.037706},{0.077514, 0.110392, -0.029124},{
      0.064869, 0.097747, -0.029124},{0.069124, 0.094655, -0.037706}}],
    Polygon[{{0.077514, 0.110392, -0.029124},{0.075250, 0.113508, -0.019823},{
      0.061753, 0.100011, -0.019823},{0.064869, 0.097747, -0.029124}}],
    Polygon[{{0.075250, 0.113508, -0.019823},{0.073869, 0.115410, -0.010035},{
      0.059852, 0.101392, -0.010035},{0.061753, 0.100011, -0.019823}}],
    Polygon[{{0.073869, 0.115410, -0.010035},{0.073405, 0.116048, 0.000000},{
      0.059213, 0.101856, 0.000000},{0.059852, 0.101392, -0.010035}}],
    Polygon[{{0.073405, 0.116048, 0.000000},{0.073869, 0.115410, 0.010035},{
      0.059852, 0.101392, 0.010035},{0.059213, 0.101856, 0.000000}}],
    Polygon[{{0.073869, 0.115410, 0.010035},{0.075250, 0.113508, 0.019823},{
      0.061753, 0.100011, 0.019823},{0.059852, 0.101392, 0.010035}}],
    Polygon[{{0.075250, 0.113508, 0.019823},{0.077514, 0.110392, 0.029124},{
      0.064869, 0.097747, 0.029124},{0.061753, 0.100011, 0.019823}}],
    Polygon[{{0.077514, 0.110392, 0.029124},{0.080606, 0.106137, 0.037706},{
      0.069124, 0.094655, 0.037706},{0.064869, 0.097747, 0.029124}}],
    Polygon[{{0.080606, 0.106137, 0.037706},{0.084449, 0.100848, 0.045361},{
      0.074413, 0.090813, 0.045361},{0.069124, 0.094655, 0.037706}}],
    Polygon[{{0.084449, 0.100848, 0.045361},{0.088948, 0.094655, 0.051898},{
      0.080606, 0.086313, 0.051898},{0.074413, 0.090813, 0.045361}}],
    Polygon[{{0.088948, 0.094655, 0.051898},{0.093993, 0.087711, 0.057158},{
      0.087550, 0.081268, 0.057158},{0.080606, 0.086313, 0.051898}}],
    Polygon[{{0.093993, 0.087711, 0.057158},{0.099459, 0.080188, 0.061010},{
      0.095074, 0.075802, 0.061010},{0.087550, 0.081268, 0.057158}}],
    Polygon[{{0.099459, 0.080188, 0.061010},{0.105213, 0.072269, 0.063360},{
      0.102992, 0.070049, 0.063360},{0.095074, 0.075802, 0.061010}}],
    Polygon[{{0.102992, 0.070049, -0.063360},{0.095074, 0.075802, -0.061010},{
      0.092258, 0.070276, -0.061010},{0.101567, 0.067251, -0.063360}}],
    Polygon[{{0.095074, 0.075802, -0.061010},{0.087550, 0.081268, -0.057158},{
      0.083413, 0.073150, -0.057158},{0.092258, 0.070276, -0.061010}}],
    Polygon[{{0.087550, 0.081268, -0.057158},{0.080606, 0.086313, -0.051898},{
      0.075250, 0.075802, -0.051898},{0.083413, 0.073150, -0.057158}}],
    Polygon[{{0.080606, 0.086313, -0.051898},{0.074413, 0.090813, -0.045361},{
      0.067970, 0.078167, -0.045361},{0.075250, 0.075802, -0.051898}}],
    Polygon[{{0.074413, 0.090813, -0.045361},{0.069124, 0.094655, -0.037706},{
      0.061753, 0.080188, -0.037706},{0.067970, 0.078167, -0.045361}}],
    Polygon[{{0.069124, 0.094655, -0.037706},{0.064869, 0.097747, -0.029124},{
      0.056751, 0.081813, -0.029124},{0.061753, 0.080188, -0.037706}}],
    Polygon[{{0.064869, 0.097747, -0.029124},{0.061753, 0.100011, -0.019823},{
      0.053087, 0.083003, -0.019823},{0.056751, 0.081813, -0.029124}}],
    Polygon[{{0.061753, 0.100011, -0.019823},{0.059852, 0.101392, -0.010035},{
      0.050852, 0.083729, -0.010035},{0.053087, 0.083003, -0.019823}}],
    Polygon[{{0.059852, 0.101392, -0.010035},{0.059213, 0.101856, 0.000000},{
      0.050101, 0.083973, 0.000000},{0.050852, 0.083729, -0.010035}}],
    Polygon[{{0.059213, 0.101856, 0.000000},{0.059852, 0.101392, 0.010035},{
      0.050852, 0.083729, 0.010035},{0.050101, 0.083973, 0.000000}}],
    Polygon[{{0.059852, 0.101392, 0.010035},{0.061753, 0.100011, 0.019823},{
      0.053087, 0.083003, 0.019823},{0.050852, 0.083729, 0.010035}}],
    Polygon[{{0.061753, 0.100011, 0.019823},{0.064869, 0.097747, 0.029124},{
      0.056751, 0.081813, 0.029124},{0.053087, 0.083003, 0.019823}}],
    Polygon[{{0.064869, 0.097747, 0.029124},{0.069124, 0.094655, 0.037706},{
      0.061753, 0.080188, 0.037706},{0.056751, 0.081813, 0.029124}}],
    Polygon[{{0.069124, 0.094655, 0.037706},{0.074413, 0.090813, 0.045361},{
      0.067970, 0.078167, 0.045361},{0.061753, 0.080188, 0.037706}}],
    Polygon[{{0.074413, 0.090813, 0.045361},{0.080606, 0.086313, 0.051898},{
      0.075250, 0.075802, 0.051898},{0.067970, 0.078167, 0.045361}}],
    Polygon[{{0.080606, 0.086313, 0.051898},{0.087550, 0.081268, 0.057158},{
      0.083413, 0.073150, 0.057158},{0.075250, 0.075802, 0.051898}}],
    Polygon[{{0.087550, 0.081268, 0.057158},{0.095074, 0.075802, 0.061010},{
      0.092258, 0.070276, 0.061010},{0.083413, 0.073150, 0.057158}}],
    Polygon[{{0.095074, 0.075802, 0.061010},{0.102992, 0.070049, 0.063360},{
      0.101567, 0.067251, 0.063360},{0.092258, 0.070276, 0.061010}}],
    Polygon[{{0.101567, 0.067251, -0.063360},{0.092258, 0.070276, -0.061010},{
      0.091288, 0.064150, -0.061010},{0.101076, 0.064150, -0.063360}}],
    Polygon[{{0.092258, 0.070276, -0.061010},{0.083413, 0.073150, -0.057158},{
      0.081988, 0.064150, -0.057158},{0.091288, 0.064150, -0.061010}}],
    Polygon[{{0.083413, 0.073150, -0.057158},{0.075250, 0.075802, -0.051898},{
      0.073405, 0.064150, -0.051898},{0.081988, 0.064150, -0.057158}}],
    Polygon[{{0.075250, 0.075802, -0.051898},{0.067970, 0.078167, -0.045361},{
      0.065750, 0.064150, -0.045361},{0.073405, 0.064150, -0.051898}}],
    Polygon[{{0.067970, 0.078167, -0.045361},{0.061753, 0.080188, -0.037706},{
      0.059213, 0.064150, -0.037706},{0.065750, 0.064150, -0.045361}}],
    Polygon[{{0.061753, 0.080188, -0.037706},{0.056751, 0.081813, -0.029124},{
      0.053953, 0.064150, -0.029124},{0.059213, 0.064150, -0.037706}}],
    Polygon[{{0.056751, 0.081813, -0.029124},{0.053087, 0.083003, -0.019823},{
      0.050101, 0.064150, -0.019823},{0.053953, 0.064150, -0.029124}}],
    Polygon[{{0.053087, 0.083003, -0.019823},{0.050852, 0.083729, -0.010035},{
      0.047751, 0.064150, -0.010035},{0.050101, 0.064150, -0.019823}}],
    Polygon[{{0.050852, 0.083729, -0.010035},{0.050101, 0.083973, 0.000000},{
      0.046961, 0.064150, 0.000000},{0.047751, 0.064150, -0.010035}}],
    Polygon[{{0.050101, 0.083973, 0.000000},{0.050852, 0.083729, 0.010035},{
      0.047751, 0.064150, 0.010035},{0.046961, 0.064150, 0.000000}}],
    Polygon[{{0.050852, 0.083729, 0.010035},{0.053087, 0.083003, 0.019823},{
      0.050101, 0.064150, 0.019823},{0.047751, 0.064150, 0.010035}}],
    Polygon[{{0.053087, 0.083003, 0.019823},{0.056751, 0.081813, 0.029124},{
      0.053953, 0.064150, 0.029124},{0.050101, 0.064150, 0.019823}}],
    Polygon[{{0.056751, 0.081813, 0.029124},{0.061753, 0.080188, 0.037706},{
      0.059213, 0.064150, 0.037706},{0.053953, 0.064150, 0.029124}}],
    Polygon[{{0.061753, 0.080188, 0.037706},{0.067970, 0.078167, 0.045361},{
      0.065750, 0.064150, 0.045361},{0.059213, 0.064150, 0.037706}}],
    Polygon[{{0.067970, 0.078167, 0.045361},{0.075250, 0.075802, 0.051898},{
      0.073405, 0.064150, 0.051898},{0.065750, 0.064150, 0.045361}}],
    Polygon[{{0.075250, 0.075802, 0.051898},{0.083413, 0.073150, 0.057158},{
      0.081988, 0.064150, 0.057158},{0.073405, 0.064150, 0.051898}}],
    Polygon[{{0.083413, 0.073150, 0.057158},{0.092258, 0.070276, 0.061010},{
      0.091288, 0.064150, 0.061010},{0.081988, 0.064150, 0.057158}}],
    Polygon[{{0.092258, 0.070276, 0.061010},{0.101567, 0.067251, 0.063360},{
      0.101076, 0.064150, 0.063360},{0.091288, 0.064150, 0.061010}}],
    Polygon[{{0.101076, 0.064150, -0.063360},{0.091288, 0.064150, -0.061010},{
      0.092258, 0.058024, -0.061010},{0.101567, 0.061049, -0.063360}}],
    Polygon[{{0.091288, 0.064150, -0.061010},{0.081988, 0.064150, -0.057158},{
      0.083413, 0.055150, -0.057158},{0.092258, 0.058024, -0.061010}}],
    Polygon[{{0.081988, 0.064150, -0.057158},{0.073405, 0.064150, -0.051898},{
      0.075250, 0.052498, -0.051898},{0.083413, 0.055150, -0.057158}}],
    Polygon[{{0.073405, 0.064150, -0.051898},{0.065750, 0.064150, -0.045361},{
      0.067970, 0.050133, -0.045361},{0.075250, 0.052498, -0.051898}}],
    Polygon[{{0.065750, 0.064150, -0.045361},{0.059213, 0.064150, -0.037706},{
      0.061753, 0.048113, -0.037706},{0.067970, 0.050133, -0.045361}}],
    Polygon[{{0.059213, 0.064150, -0.037706},{0.053953, 0.064150, -0.029124},{
      0.056751, 0.046487, -0.029124},{0.061753, 0.048113, -0.037706}}],
    Polygon[{{0.053953, 0.064150, -0.029124},{0.050101, 0.064150, -0.019823},{
      0.053087, 0.045297, -0.019823},{0.056751, 0.046487, -0.029124}}],
    Polygon[{{0.050101, 0.064150, -0.019823},{0.047751, 0.064150, -0.010035},{
      0.050852, 0.044571, -0.010035},{0.053087, 0.045297, -0.019823}}],
    Polygon[{{0.047751, 0.064150, -0.010035},{0.046961, 0.064150, 0.000000},{
      0.050101, 0.044327, 0.000000},{0.050852, 0.044571, -0.010035}}],
    Polygon[{{0.046961, 0.064150, 0.000000},{0.047751, 0.064150, 0.010035},{
      0.050852, 0.044571, 0.010035},{0.050101, 0.044327, 0.000000}}],
    Polygon[{{0.047751, 0.064150, 0.010035},{0.050101, 0.064150, 0.019823},{
      0.053087, 0.045297, 0.019823},{0.050852, 0.044571, 0.010035}}],
    Polygon[{{0.050101, 0.064150, 0.019823},{0.053953, 0.064150, 0.029124},{
      0.056751, 0.046487, 0.029124},{0.053087, 0.045297, 0.019823}}],
    Polygon[{{0.053953, 0.064150, 0.029124},{0.059213, 0.064150, 0.037706},{
      0.061753, 0.048113, 0.037706},{0.056751, 0.046487, 0.029124}}],
    Polygon[{{0.059213, 0.064150, 0.037706},{0.065750, 0.064150, 0.045361},{
      0.067970, 0.050133, 0.045361},{0.061753, 0.048113, 0.037706}}],
    Polygon[{{0.065750, 0.064150, 0.045361},{0.073405, 0.064150, 0.051898},{
      0.075250, 0.052498, 0.051898},{0.067970, 0.050133, 0.045361}}],
    Polygon[{{0.073405, 0.064150, 0.051898},{0.081988, 0.064150, 0.057158},{
      0.083413, 0.055150, 0.057158},{0.075250, 0.052498, 0.051898}}],
    Polygon[{{0.081988, 0.064150, 0.057158},{0.091288, 0.064150, 0.061010},{
      0.092258, 0.058024, 0.061010},{0.083413, 0.055150, 0.057158}}],
    Polygon[{{0.091288, 0.064150, 0.061010},{0.101076, 0.064150, 0.063360},{
      0.101567, 0.061049, 0.063360},{0.092258, 0.058024, 0.061010}}],
    Polygon[{{0.101567, 0.061049, -0.063360},{0.092258, 0.058024, -0.061010},{
      0.095074, 0.052498, -0.061010},{0.102992, 0.058251, -0.063360}}],
    Polygon[{{0.092258, 0.058024, -0.061010},{0.083413, 0.055150, -0.057158},{
      0.087550, 0.047032, -0.057158},{0.095074, 0.052498, -0.061010}}],
    Polygon[{{0.083413, 0.055150, -0.057158},{0.075250, 0.052498, -0.051898},{
      0.080606, 0.041987, -0.051898},{0.087550, 0.047032, -0.057158}}],
    Polygon[{{0.075250, 0.052498, -0.051898},{0.067970, 0.050133, -0.045361},{
      0.074413, 0.037488, -0.045361},{0.080606, 0.041987, -0.051898}}],
    Polygon[{{0.067970, 0.050133, -0.045361},{0.061753, 0.048113, -0.037706},{
      0.069124, 0.033645, -0.037706},{0.074413, 0.037488, -0.045361}}],
    Polygon[{{0.061753, 0.048113, -0.037706},{0.056751, 0.046487, -0.029124},{
      0.064869, 0.030553, -0.029124},{0.069124, 0.033645, -0.037706}}],
    Polygon[{{0.056751, 0.046487, -0.029124},{0.053087, 0.045297, -0.019823},{
      0.061753, 0.028289, -0.019823},{0.064869, 0.030553, -0.029124}}],
    Polygon[{{0.053087, 0.045297, -0.019823},{0.050852, 0.044571, -0.010035},{
      0.059852, 0.026908, -0.010035},{0.061753, 0.028289, -0.019823}}],
    Polygon[{{0.050852, 0.044571, -0.010035},{0.050101, 0.044327, 0.000000},{
      0.059213, 0.026444, 0.000000},{0.059852, 0.026908, -0.010035}}],
    Polygon[{{0.050101, 0.044327, 0.000000},{0.050852, 0.044571, 0.010035},{
      0.059852, 0.026908, 0.010035},{0.059213, 0.026444, 0.000000}}],
    Polygon[{{0.050852, 0.044571, 0.010035},{0.053087, 0.045297, 0.019823},{
      0.061753, 0.028289, 0.019823},{0.059852, 0.026908, 0.010035}}],
    Polygon[{{0.053087, 0.045297, 0.019823},{0.056751, 0.046487, 0.029124},{
      0.064869, 0.030553, 0.029124},{0.061753, 0.028289, 0.019823}}],
    Polygon[{{0.056751, 0.046487, 0.029124},{0.061753, 0.048113, 0.037706},{
      0.069124, 0.033645, 0.037706},{0.064869, 0.030553, 0.029124}}],
    Polygon[{{0.061753, 0.048113, 0.037706},{0.067970, 0.050133, 0.045361},{
      0.074413, 0.037488, 0.045361},{0.069124, 0.033645, 0.037706}}],
    Polygon[{{0.067970, 0.050133, 0.045361},{0.075250, 0.052498, 0.051898},{
      0.080606, 0.041987, 0.051898},{0.074413, 0.037488, 0.045361}}],
    Polygon[{{0.075250, 0.052498, 0.051898},{0.083413, 0.055150, 0.057158},{
      0.087550, 0.047032, 0.057158},{0.080606, 0.041987, 0.051898}}],
    Polygon[{{0.083413, 0.055150, 0.057158},{0.092258, 0.058024, 0.061010},{
      0.095074, 0.052498, 0.061010},{0.087550, 0.047032, 0.057158}}],
    Polygon[{{0.092258, 0.058024, 0.061010},{0.101567, 0.061049, 0.063360},{
      0.102992, 0.058251, 0.063360},{0.095074, 0.052498, 0.061010}}],
    Polygon[{{0.102992, 0.058251, -0.063360},{0.095074, 0.052498, -0.061010},{
      0.099459, 0.048113, -0.061010},{0.105213, 0.056031, -0.063360}}],
    Polygon[{{0.095074, 0.052498, -0.061010},{0.087550, 0.047032, -0.057158},{
      0.093993, 0.040589, -0.057158},{0.099459, 0.048113, -0.061010}}],
    Polygon[{{0.087550, 0.047032, -0.057158},{0.080606, 0.041987, -0.051898},{
      0.088948, 0.033645, -0.051898},{0.093993, 0.040589, -0.057158}}],
    Polygon[{{0.080606, 0.041987, -0.051898},{0.074413, 0.037488, -0.045361},{
      0.084449, 0.027452, -0.045361},{0.088948, 0.033645, -0.051898}}],
    Polygon[{{0.074413, 0.037488, -0.045361},{0.069124, 0.033645, -0.037706},{
      0.080606, 0.022163, -0.037706},{0.084449, 0.027452, -0.045361}}],
    Polygon[{{0.069124, 0.033645, -0.037706},{0.064869, 0.030553, -0.029124},{
      0.077514, 0.017908, -0.029124},{0.080606, 0.022163, -0.037706}}],
    Polygon[{{0.064869, 0.030553, -0.029124},{0.061753, 0.028289, -0.019823},{
      0.075250, 0.014792, -0.019823},{0.077514, 0.017908, -0.029124}}],
    Polygon[{{0.061753, 0.028289, -0.019823},{0.059852, 0.026908, -0.010035},{
      0.073869, 0.012891, -0.010035},{0.075250, 0.014792, -0.019823}}],
    Polygon[{{0.059852, 0.026908, -0.010035},{0.059213, 0.026444, 0.000000},{
      0.073405, 0.012252, 0.000000},{0.073869, 0.012891, -0.010035}}],
    Polygon[{{0.059213, 0.026444, 0.000000},{0.059852, 0.026908, 0.010035},{
      0.073869, 0.012891, 0.010035},{0.073405, 0.012252, 0.000000}}],
    Polygon[{{0.059852, 0.026908, 0.010035},{0.061753, 0.028289, 0.019823},{
      0.075250, 0.014792, 0.019823},{0.073869, 0.012891, 0.010035}}],
    Polygon[{{0.061753, 0.028289, 0.019823},{0.064869, 0.030553, 0.029124},{
      0.077514, 0.017908, 0.029124},{0.075250, 0.014792, 0.019823}}],
    Polygon[{{0.064869, 0.030553, 0.029124},{0.069124, 0.033645, 0.037706},{
      0.080606, 0.022163, 0.037706},{0.077514, 0.017908, 0.029124}}],
    Polygon[{{0.069124, 0.033645, 0.037706},{0.074413, 0.037488, 0.045361},{
      0.084449, 0.027452, 0.045361},{0.080606, 0.022163, 0.037706}}],
    Polygon[{{0.074413, 0.037488, 0.045361},{0.080606, 0.041987, 0.051898},{
      0.088948, 0.033645, 0.051898},{0.084449, 0.027452, 0.045361}}],
    Polygon[{{0.080606, 0.041987, 0.051898},{0.087550, 0.047032, 0.057158},{
      0.093993, 0.040589, 0.057158},{0.088948, 0.033645, 0.051898}}],
    Polygon[{{0.087550, 0.047032, 0.057158},{0.095074, 0.052498, 0.061010},{
      0.099459, 0.048113, 0.061010},{0.093993, 0.040589, 0.057158}}],
    Polygon[{{0.095074, 0.052498, 0.061010},{0.102992, 0.058251, 0.063360},{
      0.105213, 0.056031, 0.063360},{0.099459, 0.048113, 0.061010}}],
    Polygon[{{0.105213, 0.056031, -0.063360},{0.099459, 0.048113, -0.061010},{
      0.104985, 0.045297, -0.061010},{0.108010, 0.054606, -0.063360}}],
    Polygon[{{0.099459, 0.048113, -0.061010},{0.093993, 0.040589, -0.057158},{
      0.102111, 0.036452, -0.057158},{0.104985, 0.045297, -0.061010}}],
    Polygon[{{0.093993, 0.040589, -0.057158},{0.088948, 0.033645, -0.051898},{
      0.099459, 0.028289, -0.051898},{0.102111, 0.036452, -0.057158}}],
    Polygon[{{0.088948, 0.033645, -0.051898},{0.084449, 0.027452, -0.045361},{
      0.097094, 0.021009, -0.045361},{0.099459, 0.028289, -0.051898}}],
    Polygon[{{0.084449, 0.027452, -0.045361},{0.080606, 0.022163, -0.037706},{
      0.095074, 0.014792, -0.037706},{0.097094, 0.021009, -0.045361}}],
    Polygon[{{0.080606, 0.022163, -0.037706},{0.077514, 0.017908, -0.029124},{
      0.093448, 0.009789, -0.029124},{0.095074, 0.014792, -0.037706}}],
    Polygon[{{0.077514, 0.017908, -0.029124},{0.075250, 0.014792, -0.019823},{
      0.092258, 0.006126, -0.019823},{0.093448, 0.009789, -0.029124}}],
    Polygon[{{0.075250, 0.014792, -0.019823},{0.073869, 0.012891, -0.010035},{
      0.091532, 0.003891, -0.010035},{0.092258, 0.006126, -0.019823}}],
    Polygon[{{0.073869, 0.012891, -0.010035},{0.073405, 0.012252, 0.000000},{
      0.091288, 0.003140, 0.000000},{0.091532, 0.003891, -0.010035}}],
    Polygon[{{0.073405, 0.012252, 0.000000},{0.073869, 0.012891, 0.010035},{
      0.091532, 0.003891, 0.010035},{0.091288, 0.003140, 0.000000}}],
    Polygon[{{0.073869, 0.012891, 0.010035},{0.075250, 0.014792, 0.019823},{
      0.092258, 0.006126, 0.019823},{0.091532, 0.003891, 0.010035}}],
    Polygon[{{0.075250, 0.014792, 0.019823},{0.077514, 0.017908, 0.029124},{
      0.093448, 0.009789, 0.029124},{0.092258, 0.006126, 0.019823}}],
    Polygon[{{0.077514, 0.017908, 0.029124},{0.080606, 0.022163, 0.037706},{
      0.095074, 0.014792, 0.037706},{0.093448, 0.009789, 0.029124}}],
    Polygon[{{0.080606, 0.022163, 0.037706},{0.084449, 0.027452, 0.045361},{
      0.097094, 0.021009, 0.045361},{0.095074, 0.014792, 0.037706}}],
    Polygon[{{0.084449, 0.027452, 0.045361},{0.088948, 0.033645, 0.051898},{
      0.099459, 0.028289, 0.051898},{0.097094, 0.021009, 0.045361}}],
    Polygon[{{0.088948, 0.033645, 0.051898},{0.093993, 0.040589, 0.057158},{
      0.102111, 0.036452, 0.057158},{0.099459, 0.028289, 0.051898}}],
    Polygon[{{0.093993, 0.040589, 0.057158},{0.099459, 0.048113, 0.061010},{
      0.104985, 0.045297, 0.061010},{0.102111, 0.036452, 0.057158}}],
    Polygon[{{0.099459, 0.048113, 0.061010},{0.105213, 0.056031, 0.063360},{
      0.108010, 0.054606, 0.063360},{0.104985, 0.045297, 0.061010}}],
    Polygon[{{0.108010, 0.054606, -0.063360},{0.104985, 0.045297, -0.061010},{
      0.111111, 0.044327, -0.061010},{0.111111, 0.054115, -0.063360}}],
    Polygon[{{0.104985, 0.045297, -0.061010},{0.102111, 0.036452, -0.057158},{
      0.111111, 0.035027, -0.057158},{0.111111, 0.044327, -0.061010}}],
    Polygon[{{0.102111, 0.036452, -0.057158},{0.099459, 0.028289, -0.051898},{
      0.111111, 0.026444, -0.051898},{0.111111, 0.035027, -0.057158}}],
    Polygon[{{0.099459, 0.028289, -0.051898},{0.097094, 0.021009, -0.045361},{
      0.111111, 0.018789, -0.045361},{0.111111, 0.026444, -0.051898}}],
    Polygon[{{0.097094, 0.021009, -0.045361},{0.095074, 0.014792, -0.037706},{
      0.111111, 0.012252, -0.037706},{0.111111, 0.018789, -0.045361}}],
    Polygon[{{0.095074, 0.014792, -0.037706},{0.093448, 0.009789, -0.029124},{
      0.111111, 0.006992, -0.029124},{0.111111, 0.012252, -0.037706}}],
    Polygon[{{0.093448, 0.009789, -0.029124},{0.092258, 0.006126, -0.019823},{
      0.111111, 0.003140, -0.019823},{0.111111, 0.006992, -0.029124}}],
    Polygon[{{0.092258, 0.006126, -0.019823},{0.091532, 0.003891, -0.010035},{
      0.111111, 0.000790, -0.010035},{0.111111, 0.003140, -0.019823}}],
    Polygon[{{0.091532, 0.003891, -0.010035},{0.091288, 0.003140, 0.000000},{
      0.111111, 0.000000, 0.000000},{0.111111, 0.000790, -0.010035}}],
    Polygon[{{0.091288, 0.003140, 0.000000},{0.091532, 0.003891, 0.010035},{
      0.111111, 0.000790, 0.010035},{0.111111, 0.000000, 0.000000}}],
    Polygon[{{0.091532, 0.003891, 0.010035},{0.092258, 0.006126, 0.019823},{
      0.111111, 0.003140, 0.019823},{0.111111, 0.000790, 0.010035}}],
    Polygon[{{0.092258, 0.006126, 0.019823},{0.093448, 0.009789, 0.029124},{
      0.111111, 0.006992, 0.029124},{0.111111, 0.003140, 0.019823}}],
    Polygon[{{0.093448, 0.009789, 0.029124},{0.095074, 0.014792, 0.037706},{
      0.111111, 0.012252, 0.037706},{0.111111, 0.006992, 0.029124}}],
    Polygon[{{0.095074, 0.014792, 0.037706},{0.097094, 0.021009, 0.045361},{
      0.111111, 0.018789, 0.045361},{0.111111, 0.012252, 0.037706}}],
    Polygon[{{0.097094, 0.021009, 0.045361},{0.099459, 0.028289, 0.051898},{
      0.111111, 0.026444, 0.051898},{0.111111, 0.018789, 0.045361}}],
    Polygon[{{0.099459, 0.028289, 0.051898},{0.102111, 0.036452, 0.057158},{
      0.111111, 0.035027, 0.057158},{0.111111, 0.026444, 0.051898}}],
    Polygon[{{0.102111, 0.036452, 0.057158},{0.104985, 0.045297, 0.061010},{
      0.111111, 0.044327, 0.061010},{0.111111, 0.035027, 0.057158}}],
    Polygon[{{0.104985, 0.045297, 0.061010},{0.108010, 0.054606, 0.063360},{
      0.111111, 0.054115, 0.063360},{0.111111, 0.044327, 0.061010}}],
    Polygon[{{0.111111, 0.054115, -0.063360},{0.111111, 0.044327, -0.061010},{
      0.117237, 0.045297, -0.061010},{0.114212, 0.054606, -0.063360}}],
    Polygon[{{0.111111, 0.044327, -0.061010},{0.111111, 0.035027, -0.057158},{
      0.120111, 0.036452, -0.057158},{0.117237, 0.045297, -0.061010}}],
    Polygon[{{0.111111, 0.035027, -0.057158},{0.111111, 0.026444, -0.051898},{
      0.122763, 0.028289, -0.051898},{0.120111, 0.036452, -0.057158}}],
    Polygon[{{0.111111, 0.026444, -0.051898},{0.111111, 0.018789, -0.045361},{
      0.125128, 0.021009, -0.045361},{0.122763, 0.028289, -0.051898}}],
    Polygon[{{0.111111, 0.018789, -0.045361},{0.111111, 0.012252, -0.037706},{
      0.127149, 0.014792, -0.037706},{0.125128, 0.021009, -0.045361}}],
    Polygon[{{0.111111, 0.012252, -0.037706},{0.111111, 0.006992, -0.029124},{
      0.128774, 0.009789, -0.029124},{0.127149, 0.014792, -0.037706}}],
    Polygon[{{0.111111, 0.006992, -0.029124},{0.111111, 0.003140, -0.019823},{
      0.129964, 0.006126, -0.019823},{0.128774, 0.009789, -0.029124}}],
    Polygon[{{0.111111, 0.003140, -0.019823},{0.111111, 0.000790, -0.010035},{
      0.130691, 0.003891, -0.010035},{0.129964, 0.006126, -0.019823}}],
    Polygon[{{0.111111, 0.000790, -0.010035},{0.111111, 0.000000, 0.000000},{
      0.130935, 0.003140, 0.000000},{0.130691, 0.003891, -0.010035}}],
    Polygon[{{0.111111, 0.000000, 0.000000},{0.111111, 0.000790, 0.010035},{
      0.130691, 0.003891, 0.010035},{0.130935, 0.003140, 0.000000}}],
    Polygon[{{0.111111, 0.000790, 0.010035},{0.111111, 0.003140, 0.019823},{
      0.129964, 0.006126, 0.019823},{0.130691, 0.003891, 0.010035}}],
    Polygon[{{0.111111, 0.003140, 0.019823},{0.111111, 0.006992, 0.029124},{
      0.128774, 0.009789, 0.029124},{0.129964, 0.006126, 0.019823}}],
    Polygon[{{0.111111, 0.006992, 0.029124},{0.111111, 0.012252, 0.037706},{
      0.127149, 0.014792, 0.037706},{0.128774, 0.009789, 0.029124}}],
    Polygon[{{0.111111, 0.012252, 0.037706},{0.111111, 0.018789, 0.045361},{
      0.125128, 0.021009, 0.045361},{0.127149, 0.014792, 0.037706}}],
    Polygon[{{0.111111, 0.018789, 0.045361},{0.111111, 0.026444, 0.051898},{
      0.122763, 0.028289, 0.051898},{0.125128, 0.021009, 0.045361}}],
    Polygon[{{0.111111, 0.026444, 0.051898},{0.111111, 0.035027, 0.057158},{
      0.120111, 0.036452, 0.057158},{0.122763, 0.028289, 0.051898}}],
    Polygon[{{0.111111, 0.035027, 0.057158},{0.111111, 0.044327, 0.061010},{
      0.117237, 0.045297, 0.061010},{0.120111, 0.036452, 0.057158}}],
    Polygon[{{0.111111, 0.044327, 0.061010},{0.111111, 0.054115, 0.063360},{
      0.114212, 0.054606, 0.063360},{0.117237, 0.045297, 0.061010}}],
    Polygon[{{0.114212, 0.054606, -0.063360},{0.117237, 0.045297, -0.061010},{
      0.122763, 0.048113, -0.061010},{0.117010, 0.056031, -0.063360}}],
    Polygon[{{0.117237, 0.045297, -0.061010},{0.120111, 0.036452, -0.057158},{
      0.128229, 0.040589, -0.057158},{0.122763, 0.048113, -0.061010}}],
    Polygon[{{0.120111, 0.036452, -0.057158},{0.122763, 0.028289, -0.051898},{
      0.133274, 0.033645, -0.051898},{0.128229, 0.040589, -0.057158}}],
    Polygon[{{0.122763, 0.028289, -0.051898},{0.125128, 0.021009, -0.045361},{
      0.137774, 0.027452, -0.045361},{0.133274, 0.033645, -0.051898}}],
    Polygon[{{0.125128, 0.021009, -0.045361},{0.127149, 0.014792, -0.037706},{
      0.141616, 0.022163, -0.037706},{0.137774, 0.027452, -0.045361}}],
    Polygon[{{0.127149, 0.014792, -0.037706},{0.128774, 0.009789, -0.029124},{
      0.144708, 0.017908, -0.029124},{0.141616, 0.022163, -0.037706}}],
    Polygon[{{0.128774, 0.009789, -0.029124},{0.129964, 0.006126, -0.019823},{
      0.146972, 0.014792, -0.019823},{0.144708, 0.017908, -0.029124}}],
    Polygon[{{0.129964, 0.006126, -0.019823},{0.130691, 0.003891, -0.010035},{
      0.148353, 0.012891, -0.010035},{0.146972, 0.014792, -0.019823}}],
    Polygon[{{0.130691, 0.003891, -0.010035},{0.130935, 0.003140, 0.000000},{
      0.148818, 0.012252, 0.000000},{0.148353, 0.012891, -0.010035}}],
    Polygon[{{0.130935, 0.003140, 0.000000},{0.130691, 0.003891, 0.010035},{
      0.148353, 0.012891, 0.010035},{0.148818, 0.012252, 0.000000}}],
    Polygon[{{0.130691, 0.003891, 0.010035},{0.129964, 0.006126, 0.019823},{
      0.146972, 0.014792, 0.019823},{0.148353, 0.012891, 0.010035}}],
    Polygon[{{0.129964, 0.006126, 0.019823},{0.128774, 0.009789, 0.029124},{
      0.144708, 0.017908, 0.029124},{0.146972, 0.014792, 0.019823}}],
    Polygon[{{0.128774, 0.009789, 0.029124},{0.127149, 0.014792, 0.037706},{
      0.141616, 0.022163, 0.037706},{0.144708, 0.017908, 0.029124}}],
    Polygon[{{0.127149, 0.014792, 0.037706},{0.125128, 0.021009, 0.045361},{
      0.137774, 0.027452, 0.045361},{0.141616, 0.022163, 0.037706}}],
    Polygon[{{0.125128, 0.021009, 0.045361},{0.122763, 0.028289, 0.051898},{
      0.133274, 0.033645, 0.051898},{0.137774, 0.027452, 0.045361}}],
    Polygon[{{0.122763, 0.028289, 0.051898},{0.120111, 0.036452, 0.057158},{
      0.128229, 0.040589, 0.057158},{0.133274, 0.033645, 0.051898}}],
    Polygon[{{0.120111, 0.036452, 0.057158},{0.117237, 0.045297, 0.061010},{
      0.122763, 0.048113, 0.061010},{0.128229, 0.040589, 0.057158}}],
    Polygon[{{0.117237, 0.045297, 0.061010},{0.114212, 0.054606, 0.063360},{
      0.117010, 0.056031, 0.063360},{0.122763, 0.048113, 0.061010}}],
    Polygon[{{0.117010, 0.056031, -0.063360},{0.122763, 0.048113, -0.061010},{
      0.127149, 0.052498, -0.061010},{0.119230, 0.058251, -0.063360}}],
    Polygon[{{0.122763, 0.048113, -0.061010},{0.128229, 0.040589, -0.057158},{
      0.134673, 0.047032, -0.057158},{0.127149, 0.052498, -0.061010}}],
    Polygon[{{0.128229, 0.040589, -0.057158},{0.133274, 0.033645, -0.051898},{
      0.141616, 0.041987, -0.051898},{0.134673, 0.047032, -0.057158}}],
    Polygon[{{0.133274, 0.033645, -0.051898},{0.137774, 0.027452, -0.045361},{
      0.147809, 0.037488, -0.045361},{0.141616, 0.041987, -0.051898}}],
    Polygon[{{0.137774, 0.027452, -0.045361},{0.141616, 0.022163, -0.037706},{
      0.153098, 0.033645, -0.037706},{0.147809, 0.037488, -0.045361}}],
    Polygon[{{0.141616, 0.022163, -0.037706},{0.144708, 0.017908, -0.029124},{
      0.157353, 0.030553, -0.029124},{0.153098, 0.033645, -0.037706}}],
    Polygon[{{0.144708, 0.017908, -0.029124},{0.146972, 0.014792, -0.019823},{
      0.160469, 0.028289, -0.019823},{0.157353, 0.030553, -0.029124}}],
    Polygon[{{0.146972, 0.014792, -0.019823},{0.148353, 0.012891, -0.010035},{
      0.162371, 0.026908, -0.010035},{0.160469, 0.028289, -0.019823}}],
    Polygon[{{0.148353, 0.012891, -0.010035},{0.148818, 0.012252, 0.000000},{
      0.163010, 0.026444, 0.000000},{0.162371, 0.026908, -0.010035}}],
    Polygon[{{0.148818, 0.012252, 0.000000},{0.148353, 0.012891, 0.010035},{
      0.162371, 0.026908, 0.010035},{0.163010, 0.026444, 0.000000}}],
    Polygon[{{0.148353, 0.012891, 0.010035},{0.146972, 0.014792, 0.019823},{
      0.160469, 0.028289, 0.019823},{0.162371, 0.026908, 0.010035}}],
    Polygon[{{0.146972, 0.014792, 0.019823},{0.144708, 0.017908, 0.029124},{
      0.157353, 0.030553, 0.029124},{0.160469, 0.028289, 0.019823}}],
    Polygon[{{0.144708, 0.017908, 0.029124},{0.141616, 0.022163, 0.037706},{
      0.153098, 0.033645, 0.037706},{0.157353, 0.030553, 0.029124}}],
    Polygon[{{0.141616, 0.022163, 0.037706},{0.137774, 0.027452, 0.045361},{
      0.147809, 0.037488, 0.045361},{0.153098, 0.033645, 0.037706}}],
    Polygon[{{0.137774, 0.027452, 0.045361},{0.133274, 0.033645, 0.051898},{
      0.141616, 0.041987, 0.051898},{0.147809, 0.037488, 0.045361}}],
    Polygon[{{0.133274, 0.033645, 0.051898},{0.128229, 0.040589, 0.057158},{
      0.134673, 0.047032, 0.057158},{0.141616, 0.041987, 0.051898}}],
    Polygon[{{0.128229, 0.040589, 0.057158},{0.122763, 0.048113, 0.061010},{
      0.127149, 0.052498, 0.061010},{0.134673, 0.047032, 0.057158}}],
    Polygon[{{0.122763, 0.048113, 0.061010},{0.117010, 0.056031, 0.063360},{
      0.119230, 0.058251, 0.063360},{0.127149, 0.052498, 0.061010}}],
    Polygon[{{0.119230, 0.058251, -0.063360},{0.127149, 0.052498, -0.061010},{
      0.129964, 0.058024, -0.061010},{0.120655, 0.061049, -0.063360}}],
    Polygon[{{0.127149, 0.052498, -0.061010},{0.134673, 0.047032, -0.057158},{
      0.138809, 0.055150, -0.057158},{0.129964, 0.058024, -0.061010}}],
    Polygon[{{0.134673, 0.047032, -0.057158},{0.141616, 0.041987, -0.051898},{
      0.146972, 0.052498, -0.051898},{0.138809, 0.055150, -0.057158}}],
    Polygon[{{0.141616, 0.041987, -0.051898},{0.147809, 0.037488, -0.045361},{
      0.154252, 0.050133, -0.045361},{0.146972, 0.052498, -0.051898}}],
    Polygon[{{0.147809, 0.037488, -0.045361},{0.153098, 0.033645, -0.037706},{
      0.160469, 0.048113, -0.037706},{0.154252, 0.050133, -0.045361}}],
    Polygon[{{0.153098, 0.033645, -0.037706},{0.157353, 0.030553, -0.029124},{
      0.165472, 0.046487, -0.029124},{0.160469, 0.048113, -0.037706}}],
    Polygon[{{0.157353, 0.030553, -0.029124},{0.160469, 0.028289, -0.019823},{
      0.169135, 0.045297, -0.019823},{0.165472, 0.046487, -0.029124}}],
    Polygon[{{0.160469, 0.028289, -0.019823},{0.162371, 0.026908, -0.010035},{
      0.171370, 0.044571, -0.010035},{0.169135, 0.045297, -0.019823}}],
    Polygon[{{0.162371, 0.026908, -0.010035},{0.163010, 0.026444, 0.000000},{
      0.172121, 0.044327, 0.000000},{0.171370, 0.044571, -0.010035}}],
    Polygon[{{0.163010, 0.026444, 0.000000},{0.162371, 0.026908, 0.010035},{
      0.171370, 0.044571, 0.010035},{0.172121, 0.044327, 0.000000}}],
    Polygon[{{0.162371, 0.026908, 0.010035},{0.160469, 0.028289, 0.019823},{
      0.169135, 0.045297, 0.019823},{0.171370, 0.044571, 0.010035}}],
    Polygon[{{0.160469, 0.028289, 0.019823},{0.157353, 0.030553, 0.029124},{
      0.165472, 0.046487, 0.029124},{0.169135, 0.045297, 0.019823}}],
    Polygon[{{0.157353, 0.030553, 0.029124},{0.153098, 0.033645, 0.037706},{
      0.160469, 0.048113, 0.037706},{0.165472, 0.046487, 0.029124}}],
    Polygon[{{0.153098, 0.033645, 0.037706},{0.147809, 0.037488, 0.045361},{
      0.154252, 0.050133, 0.045361},{0.160469, 0.048113, 0.037706}}],
    Polygon[{{0.147809, 0.037488, 0.045361},{0.141616, 0.041987, 0.051898},{
      0.146972, 0.052498, 0.051898},{0.154252, 0.050133, 0.045361}}],
    Polygon[{{0.141616, 0.041987, 0.051898},{0.134673, 0.047032, 0.057158},{
      0.138809, 0.055150, 0.057158},{0.146972, 0.052498, 0.051898}}],
    Polygon[{{0.134673, 0.047032, 0.057158},{0.127149, 0.052498, 0.061010},{
      0.129964, 0.058024, 0.061010},{0.138809, 0.055150, 0.057158}}],
    Polygon[{{0.127149, 0.052498, 0.061010},{0.119230, 0.058251, 0.063360},{
      0.120655, 0.061049, 0.063360},{0.129964, 0.058024, 0.061010}}],
    Polygon[{{0.120655, 0.061049, -0.063360},{0.129964, 0.058024, -0.061010},{
      0.130935, 0.064150, -0.061010},{0.121146, 0.064150, -0.063360}}],
    Polygon[{{0.129964, 0.058024, -0.061010},{0.138809, 0.055150, -0.057158},{
      0.140235, 0.064150, -0.057158},{0.130935, 0.064150, -0.061010}}],
    Polygon[{{0.138809, 0.055150, -0.057158},{0.146972, 0.052498, -0.051898},{
      0.148818, 0.064150, -0.051898},{0.140235, 0.064150, -0.057158}}],
    Polygon[{{0.146972, 0.052498, -0.051898},{0.154252, 0.050133, -0.045361},{
      0.156472, 0.064150, -0.045361},{0.148818, 0.064150, -0.051898}}],
    Polygon[{{0.154252, 0.050133, -0.045361},{0.160469, 0.048113, -0.037706},{
      0.163010, 0.064150, -0.037706},{0.156472, 0.064150, -0.045361}}],
    Polygon[{{0.160469, 0.048113, -0.037706},{0.165472, 0.046487, -0.029124},{
      0.168269, 0.064150, -0.029124},{0.163010, 0.064150, -0.037706}}],
    Polygon[{{0.165472, 0.046487, -0.029124},{0.169135, 0.045297, -0.019823},{
      0.172121, 0.064150, -0.019823},{0.168269, 0.064150, -0.029124}}],
    Polygon[{{0.169135, 0.045297, -0.019823},{0.171370, 0.044571, -0.010035},{
      0.174471, 0.064150, -0.010035},{0.172121, 0.064150, -0.019823}}],
    Polygon[{{0.171370, 0.044571, -0.010035},{0.172121, 0.044327, 0.000000},{
      0.175261, 0.064150, 0.000000},{0.174471, 0.064150, -0.010035}}],
    Polygon[{{0.172121, 0.044327, 0.000000},{0.171370, 0.044571, 0.010035},{
      0.174471, 0.064150, 0.010035},{0.175261, 0.064150, 0.000000}}],
    Polygon[{{0.171370, 0.044571, 0.010035},{0.169135, 0.045297, 0.019823},{
      0.172121, 0.064150, 0.019823},{0.174471, 0.064150, 0.010035}}],
    Polygon[{{0.169135, 0.045297, 0.019823},{0.165472, 0.046487, 0.029124},{
      0.168269, 0.064150, 0.029124},{0.172121, 0.064150, 0.019823}}],
    Polygon[{{0.165472, 0.046487, 0.029124},{0.160469, 0.048113, 0.037706},{
      0.163010, 0.064150, 0.037706},{0.168269, 0.064150, 0.029124}}],
    Polygon[{{0.160469, 0.048113, 0.037706},{0.154252, 0.050133, 0.045361},{
      0.156472, 0.064150, 0.045361},{0.163010, 0.064150, 0.037706}}],
    Polygon[{{0.154252, 0.050133, 0.045361},{0.146972, 0.052498, 0.051898},{
      0.148818, 0.064150, 0.051898},{0.156472, 0.064150, 0.045361}}],
    Polygon[{{0.146972, 0.052498, 0.051898},{0.138809, 0.055150, 0.057158},{
      0.140235, 0.064150, 0.057158},{0.148818, 0.064150, 0.051898}}],
    Polygon[{{0.138809, 0.055150, 0.057158},{0.129964, 0.058024, 0.061010},{
      0.130935, 0.064150, 0.061010},{0.140235, 0.064150, 0.057158}}],
    Polygon[{{0.129964, 0.058024, 0.061010},{0.120655, 0.061049, 0.063360},{
      0.121146, 0.064150, 0.063360},{0.130935, 0.064150, 0.061010}}],
    Polygon[{{0.040382, 0.021383, -0.021120},{0.043645, 0.021383, -0.020337},{
      0.043321, 0.023425, -0.020337},{0.040218, 0.022417, -0.021120}}],
    Polygon[{{0.043645, 0.021383, -0.020337},{0.046745, 0.021383, -0.019053},{
      0.046270, 0.024383, -0.019053},{0.043321, 0.023425, -0.020337}}],
    Polygon[{{0.046745, 0.021383, -0.019053},{0.049606, 0.021383, -0.017299},{
      0.048991, 0.025267, -0.017299},{0.046270, 0.024383, -0.019053}}],
    Polygon[{{0.049606, 0.021383, -0.017299},{0.052157, 0.021383, -0.015120},{
      0.051417, 0.026056, -0.015120},{0.048991, 0.025267, -0.017299}}],
    Polygon[{{0.052157, 0.021383, -0.015120},{0.054337, 0.021383, -0.012569},{
      0.053490, 0.026729, -0.012569},{0.051417, 0.026056, -0.015120}}],
    Polygon[{{0.054337, 0.021383, -0.012569},{0.056090, 0.021383, -0.009708},{
      0.055157, 0.027271, -0.009708},{0.053490, 0.026729, -0.012569}}],
    Polygon[{{0.056090, 0.021383, -0.009708},{0.057374, 0.021383, -0.006608},{
      0.056378, 0.027668, -0.006608},{0.055157, 0.027271, -0.009708}}],
    Polygon[{{0.057374, 0.021383, -0.006608},{0.058157, 0.021383, -0.003345},{
      0.057123, 0.027910, -0.003345},{0.056378, 0.027668, -0.006608}}],
    Polygon[{{0.058157, 0.021383, -0.003345},{0.058420, 0.021383, 0.000000},{
      0.057374, 0.027991, 0.000000},{0.057123, 0.027910, -0.003345}}],
    Polygon[{{0.058420, 0.021383, 0.000000},{0.058157, 0.021383, 0.003345},{
      0.057123, 0.027910, 0.003345},{0.057374, 0.027991, 0.000000}}],
    Polygon[{{0.058157, 0.021383, 0.003345},{0.057374, 0.021383, 0.006608},{
      0.056378, 0.027668, 0.006608},{0.057123, 0.027910, 0.003345}}],
    Polygon[{{0.057374, 0.021383, 0.006608},{0.056090, 0.021383, 0.009708},{
      0.055157, 0.027271, 0.009708},{0.056378, 0.027668, 0.006608}}],
    Polygon[{{0.056090, 0.021383, 0.009708},{0.054337, 0.021383, 0.012569},{
      0.053490, 0.026729, 0.012569},{0.055157, 0.027271, 0.009708}}],
    Polygon[{{0.054337, 0.021383, 0.012569},{0.052157, 0.021383, 0.015120},{
      0.051417, 0.026056, 0.015120},{0.053490, 0.026729, 0.012569}}],
    Polygon[{{0.052157, 0.021383, 0.015120},{0.049606, 0.021383, 0.017299},{
      0.048991, 0.025267, 0.017299},{0.051417, 0.026056, 0.015120}}],
    Polygon[{{0.049606, 0.021383, 0.017299},{0.046745, 0.021383, 0.019053},{
      0.046270, 0.024383, 0.019053},{0.048991, 0.025267, 0.017299}}],
    Polygon[{{0.046745, 0.021383, 0.019053},{0.043645, 0.021383, 0.020337},{
      0.043321, 0.023425, 0.020337},{0.046270, 0.024383, 0.019053}}],
    Polygon[{{0.043645, 0.021383, 0.020337},{0.040382, 0.021383, 0.021120},{
      0.040218, 0.022417, 0.021120},{0.043321, 0.023425, 0.020337}}],
    Polygon[{{0.040218, 0.022417, -0.021120},{0.043321, 0.023425, -0.020337},{
      0.042383, 0.025267, -0.020337},{0.039743, 0.023350, -0.021120}}],
    Polygon[{{0.043321, 0.023425, -0.020337},{0.046270, 0.024383, -0.019053},{
      0.044891, 0.027089, -0.019053},{0.042383, 0.025267, -0.020337}}],
    Polygon[{{0.046270, 0.024383, -0.019053},{0.048991, 0.025267, -0.017299},{
      0.047205, 0.028771, -0.017299},{0.044891, 0.027089, -0.019053}}],
    Polygon[{{0.048991, 0.025267, -0.017299},{0.051417, 0.026056, -0.015120},{
      0.049270, 0.030271, -0.015120},{0.047205, 0.028771, -0.017299}}],
    Polygon[{{0.051417, 0.026056, -0.015120},{0.053490, 0.026729, -0.012569},{
      0.051033, 0.031552, -0.012569},{0.049270, 0.030271, -0.015120}}],
    Polygon[{{0.053490, 0.026729, -0.012569},{0.055157, 0.027271, -0.009708},{
      0.052451, 0.032582, -0.009708},{0.051033, 0.031552, -0.012569}}],
    Polygon[{{0.055157, 0.027271, -0.009708},{0.056378, 0.027668, -0.006608},{
      0.053490, 0.033337, -0.006608},{0.052451, 0.032582, -0.009708}}],
    Polygon[{{0.056378, 0.027668, -0.006608},{0.057123, 0.027910, -0.003345},{
      0.054124, 0.033797, -0.003345},{0.053490, 0.033337, -0.006608}}],
    Polygon[{{0.057123, 0.027910, -0.003345},{0.057374, 0.027991, 0.000000},{
      0.054337, 0.033952, 0.000000},{0.054124, 0.033797, -0.003345}}],
    Polygon[{{0.057374, 0.027991, 0.000000},{0.057123, 0.027910, 0.003345},{
      0.054124, 0.033797, 0.003345},{0.054337, 0.033952, 0.000000}}],
    Polygon[{{0.057123, 0.027910, 0.003345},{0.056378, 0.027668, 0.006608},{
      0.053490, 0.033337, 0.006608},{0.054124, 0.033797, 0.003345}}],
    Polygon[{{0.056378, 0.027668, 0.006608},{0.055157, 0.027271, 0.009708},{
      0.052451, 0.032582, 0.009708},{0.053490, 0.033337, 0.006608}}],
    Polygon[{{0.055157, 0.027271, 0.009708},{0.053490, 0.026729, 0.012569},{
      0.051033, 0.031552, 0.012569},{0.052451, 0.032582, 0.009708}}],
    Polygon[{{0.053490, 0.026729, 0.012569},{0.051417, 0.026056, 0.015120},{
      0.049270, 0.030271, 0.015120},{0.051033, 0.031552, 0.012569}}],
    Polygon[{{0.051417, 0.026056, 0.015120},{0.048991, 0.025267, 0.017299},{
      0.047205, 0.028771, 0.017299},{0.049270, 0.030271, 0.015120}}],
    Polygon[{{0.048991, 0.025267, 0.017299},{0.046270, 0.024383, 0.019053},{
      0.044891, 0.027089, 0.019053},{0.047205, 0.028771, 0.017299}}],
    Polygon[{{0.046270, 0.024383, 0.019053},{0.043321, 0.023425, 0.020337},{
      0.042383, 0.025267, 0.020337},{0.044891, 0.027089, 0.019053}}],
    Polygon[{{0.043321, 0.023425, 0.020337},{0.040218, 0.022417, 0.021120},{
      0.039743, 0.023350, 0.021120},{0.042383, 0.025267, 0.020337}}],
    Polygon[{{0.039743, 0.023350, -0.021120},{0.042383, 0.025267, -0.020337},{
      0.040921, 0.026729, -0.020337},{0.039003, 0.024090, -0.021120}}],
    Polygon[{{0.042383, 0.025267, -0.020337},{0.044891, 0.027089, -0.019053},{
      0.042743, 0.029237, -0.019053},{0.040921, 0.026729, -0.020337}}],
    Polygon[{{0.044891, 0.027089, -0.019053},{0.047205, 0.028771, -0.017299},{
      0.044425, 0.031552, -0.017299},{0.042743, 0.029237, -0.019053}}],
    Polygon[{{0.047205, 0.028771, -0.017299},{0.049270, 0.030271, -0.015120},{
      0.045925, 0.033616, -0.015120},{0.044425, 0.031552, -0.017299}}],
    Polygon[{{0.049270, 0.030271, -0.015120},{0.051033, 0.031552, -0.012569},{
      0.047205, 0.035379, -0.012569},{0.045925, 0.033616, -0.015120}}],
    Polygon[{{0.051033, 0.031552, -0.012569},{0.052451, 0.032582, -0.009708},{
      0.048236, 0.036797, -0.009708},{0.047205, 0.035379, -0.012569}}],
    Polygon[{{0.052451, 0.032582, -0.009708},{0.053490, 0.033337, -0.006608},{
      0.048991, 0.037836, -0.006608},{0.048236, 0.036797, -0.009708}}],
    Polygon[{{0.053490, 0.033337, -0.006608},{0.054124, 0.033797, -0.003345},{
      0.049451, 0.038470, -0.003345},{0.048991, 0.037836, -0.006608}}],
    Polygon[{{0.054124, 0.033797, -0.003345},{0.054337, 0.033952, 0.000000},{
      0.049606, 0.038683, 0.000000},{0.049451, 0.038470, -0.003345}}],
    Polygon[{{0.054337, 0.033952, 0.000000},{0.054124, 0.033797, 0.003345},{
      0.049451, 0.038470, 0.003345},{0.049606, 0.038683, 0.000000}}],
    Polygon[{{0.054124, 0.033797, 0.003345},{0.053490, 0.033337, 0.006608},{
      0.048991, 0.037836, 0.006608},{0.049451, 0.038470, 0.003345}}],
    Polygon[{{0.053490, 0.033337, 0.006608},{0.052451, 0.032582, 0.009708},{
      0.048236, 0.036797, 0.009708},{0.048991, 0.037836, 0.006608}}],
    Polygon[{{0.052451, 0.032582, 0.009708},{0.051033, 0.031552, 0.012569},{
      0.047205, 0.035379, 0.012569},{0.048236, 0.036797, 0.009708}}],
    Polygon[{{0.051033, 0.031552, 0.012569},{0.049270, 0.030271, 0.015120},{
      0.045925, 0.033616, 0.015120},{0.047205, 0.035379, 0.012569}}],
    Polygon[{{0.049270, 0.030271, 0.015120},{0.047205, 0.028771, 0.017299},{
      0.044425, 0.031552, 0.017299},{0.045925, 0.033616, 0.015120}}],
    Polygon[{{0.047205, 0.028771, 0.017299},{0.044891, 0.027089, 0.019053},{
      0.042743, 0.029237, 0.019053},{0.044425, 0.031552, 0.017299}}],
    Polygon[{{0.044891, 0.027089, 0.019053},{0.042383, 0.025267, 0.020337},{
      0.040921, 0.026729, 0.020337},{0.042743, 0.029237, 0.019053}}],
    Polygon[{{0.042383, 0.025267, 0.020337},{0.039743, 0.023350, 0.021120},{
      0.039003, 0.024090, 0.021120},{0.040921, 0.026729, 0.020337}}],
    Polygon[{{0.039003, 0.024090, -0.021120},{0.040921, 0.026729, -0.020337},{
      0.039079, 0.027668, -0.020337},{0.038071, 0.024565, -0.021120}}],
    Polygon[{{0.040921, 0.026729, -0.020337},{0.042743, 0.029237, -0.019053},{
      0.040037, 0.030616, -0.019053},{0.039079, 0.027668, -0.020337}}],
    Polygon[{{0.042743, 0.029237, -0.019053},{0.044425, 0.031552, -0.017299},{
      0.040921, 0.033337, -0.017299},{0.040037, 0.030616, -0.019053}}],
    Polygon[{{0.044425, 0.031552, -0.017299},{0.045925, 0.033616, -0.015120},{
      0.041709, 0.035764, -0.015120},{0.040921, 0.033337, -0.017299}}],
    Polygon[{{0.045925, 0.033616, -0.015120},{0.047205, 0.035379, -0.012569},{
      0.042383, 0.037836, -0.012569},{0.041709, 0.035764, -0.015120}}],
    Polygon[{{0.047205, 0.035379, -0.012569},{0.048236, 0.036797, -0.009708},{
      0.042925, 0.039504, -0.009708},{0.042383, 0.037836, -0.012569}}],
    Polygon[{{0.048236, 0.036797, -0.009708},{0.048991, 0.037836, -0.006608},{
      0.043321, 0.040725, -0.006608},{0.042925, 0.039504, -0.009708}}],
    Polygon[{{0.048991, 0.037836, -0.006608},{0.049451, 0.038470, -0.003345},{
      0.043564, 0.041470, -0.003345},{0.043321, 0.040725, -0.006608}}],
    Polygon[{{0.049451, 0.038470, -0.003345},{0.049606, 0.038683, 0.000000},{
      0.043645, 0.041720, 0.000000},{0.043564, 0.041470, -0.003345}}],
    Polygon[{{0.049606, 0.038683, 0.000000},{0.049451, 0.038470, 0.003345},{
      0.043564, 0.041470, 0.003345},{0.043645, 0.041720, 0.000000}}],
    Polygon[{{0.049451, 0.038470, 0.003345},{0.048991, 0.037836, 0.006608},{
      0.043321, 0.040725, 0.006608},{0.043564, 0.041470, 0.003345}}],
    Polygon[{{0.048991, 0.037836, 0.006608},{0.048236, 0.036797, 0.009708},{
      0.042925, 0.039504, 0.009708},{0.043321, 0.040725, 0.006608}}],
    Polygon[{{0.048236, 0.036797, 0.009708},{0.047205, 0.035379, 0.012569},{
      0.042383, 0.037836, 0.012569},{0.042925, 0.039504, 0.009708}}],
    Polygon[{{0.047205, 0.035379, 0.012569},{0.045925, 0.033616, 0.015120},{
      0.041709, 0.035764, 0.015120},{0.042383, 0.037836, 0.012569}}],
    Polygon[{{0.045925, 0.033616, 0.015120},{0.044425, 0.031552, 0.017299},{
      0.040921, 0.033337, 0.017299},{0.041709, 0.035764, 0.015120}}],
    Polygon[{{0.044425, 0.031552, 0.017299},{0.042743, 0.029237, 0.019053},{
      0.040037, 0.030616, 0.019053},{0.040921, 0.033337, 0.017299}}],
    Polygon[{{0.042743, 0.029237, 0.019053},{0.040921, 0.026729, 0.020337},{
      0.039079, 0.027668, 0.020337},{0.040037, 0.030616, 0.019053}}],
    Polygon[{{0.040921, 0.026729, 0.020337},{0.039003, 0.024090, 0.021120},{
      0.038071, 0.024565, 0.021120},{0.039079, 0.027668, 0.020337}}],
    Polygon[{{0.038071, 0.024565, -0.021120},{0.039079, 0.027668, -0.020337},{
      0.037037, 0.027991, -0.020337},{0.037037, 0.024728, -0.021120}}],
    Polygon[{{0.039079, 0.027668, -0.020337},{0.040037, 0.030616, -0.019053},{
      0.037037, 0.031091, -0.019053},{0.037037, 0.027991, -0.020337}}],
    Polygon[{{0.040037, 0.030616, -0.019053},{0.040921, 0.033337, -0.017299},{
      0.037037, 0.033952, -0.017299},{0.037037, 0.031091, -0.019053}}],
    Polygon[{{0.040921, 0.033337, -0.017299},{0.041709, 0.035764, -0.015120},{
      0.037037, 0.036504, -0.015120},{0.037037, 0.033952, -0.017299}}],
    Polygon[{{0.041709, 0.035764, -0.015120},{0.042383, 0.037836, -0.012569},{
      0.037037, 0.038683, -0.012569},{0.037037, 0.036504, -0.015120}}],
    Polygon[{{0.042383, 0.037836, -0.012569},{0.042925, 0.039504, -0.009708},{
      0.037037, 0.040436, -0.009708},{0.037037, 0.038683, -0.012569}}],
    Polygon[{{0.042925, 0.039504, -0.009708},{0.043321, 0.040725, -0.006608},{
      0.037037, 0.041720, -0.006608},{0.037037, 0.040436, -0.009708}}],
    Polygon[{{0.043321, 0.040725, -0.006608},{0.043564, 0.041470, -0.003345},{
      0.037037, 0.042503, -0.003345},{0.037037, 0.041720, -0.006608}}],
    Polygon[{{0.043564, 0.041470, -0.003345},{0.043645, 0.041720, 0.000000},{
      0.037037, 0.042767, 0.000000},{0.037037, 0.042503, -0.003345}}],
    Polygon[{{0.043645, 0.041720, 0.000000},{0.043564, 0.041470, 0.003345},{
      0.037037, 0.042503, 0.003345},{0.037037, 0.042767, 0.000000}}],
    Polygon[{{0.043564, 0.041470, 0.003345},{0.043321, 0.040725, 0.006608},{
      0.037037, 0.041720, 0.006608},{0.037037, 0.042503, 0.003345}}],
    Polygon[{{0.043321, 0.040725, 0.006608},{0.042925, 0.039504, 0.009708},{
      0.037037, 0.040436, 0.009708},{0.037037, 0.041720, 0.006608}}],
    Polygon[{{0.042925, 0.039504, 0.009708},{0.042383, 0.037836, 0.012569},{
      0.037037, 0.038683, 0.012569},{0.037037, 0.040436, 0.009708}}],
    Polygon[{{0.042383, 0.037836, 0.012569},{0.041709, 0.035764, 0.015120},{
      0.037037, 0.036504, 0.015120},{0.037037, 0.038683, 0.012569}}],
    Polygon[{{0.041709, 0.035764, 0.015120},{0.040921, 0.033337, 0.017299},{
      0.037037, 0.033952, 0.017299},{0.037037, 0.036504, 0.015120}}],
    Polygon[{{0.040921, 0.033337, 0.017299},{0.040037, 0.030616, 0.019053},{
      0.037037, 0.031091, 0.019053},{0.037037, 0.033952, 0.017299}}],
    Polygon[{{0.040037, 0.030616, 0.019053},{0.039079, 0.027668, 0.020337},{
      0.037037, 0.027991, 0.020337},{0.037037, 0.031091, 0.019053}}],
    Polygon[{{0.039079, 0.027668, 0.020337},{0.038071, 0.024565, 0.021120},{
      0.037037, 0.024728, 0.021120},{0.037037, 0.027991, 0.020337}}],
    Polygon[{{0.037037, 0.024728, -0.021120},{0.037037, 0.027991, -0.020337},{
      0.034995, 0.027668, -0.020337},{0.036003, 0.024565, -0.021120}}],
    Polygon[{{0.037037, 0.027991, -0.020337},{0.037037, 0.031091, -0.019053},{
      0.034037, 0.030616, -0.019053},{0.034995, 0.027668, -0.020337}}],
    Polygon[{{0.037037, 0.031091, -0.019053},{0.037037, 0.033952, -0.017299},{
      0.033153, 0.033337, -0.017299},{0.034037, 0.030616, -0.019053}}],
    Polygon[{{0.037037, 0.033952, -0.017299},{0.037037, 0.036504, -0.015120},{
      0.032365, 0.035764, -0.015120},{0.033153, 0.033337, -0.017299}}],
    Polygon[{{0.037037, 0.036504, -0.015120},{0.037037, 0.038683, -0.012569},{
      0.031691, 0.037836, -0.012569},{0.032365, 0.035764, -0.015120}}],
    Polygon[{{0.037037, 0.038683, -0.012569},{0.037037, 0.040436, -0.009708},{
      0.031149, 0.039504, -0.009708},{0.031691, 0.037836, -0.012569}}],
    Polygon[{{0.037037, 0.040436, -0.009708},{0.037037, 0.041720, -0.006608},{
      0.030753, 0.040725, -0.006608},{0.031149, 0.039504, -0.009708}}],
    Polygon[{{0.037037, 0.041720, -0.006608},{0.037037, 0.042503, -0.003345},{
      0.030511, 0.041470, -0.003345},{0.030753, 0.040725, -0.006608}}],
    Polygon[{{0.037037, 0.042503, -0.003345},{0.037037, 0.042767, 0.000000},{
      0.030429, 0.041720, 0.000000},{0.030511, 0.041470, -0.003345}}],
    Polygon[{{0.037037, 0.042767, 0.000000},{0.037037, 0.042503, 0.003345},{
      0.030511, 0.041470, 0.003345},{0.030429, 0.041720, 0.000000}}],
    Polygon[{{0.037037, 0.042503, 0.003345},{0.037037, 0.041720, 0.006608},{
      0.030753, 0.040725, 0.006608},{0.030511, 0.041470, 0.003345}}],
    Polygon[{{0.037037, 0.041720, 0.006608},{0.037037, 0.040436, 0.009708},{
      0.031149, 0.039504, 0.009708},{0.030753, 0.040725, 0.006608}}],
    Polygon[{{0.037037, 0.040436, 0.009708},{0.037037, 0.038683, 0.012569},{
      0.031691, 0.037836, 0.012569},{0.031149, 0.039504, 0.009708}}],
    Polygon[{{0.037037, 0.038683, 0.012569},{0.037037, 0.036504, 0.015120},{
      0.032365, 0.035764, 0.015120},{0.031691, 0.037836, 0.012569}}],
    Polygon[{{0.037037, 0.036504, 0.015120},{0.037037, 0.033952, 0.017299},{
      0.033153, 0.033337, 0.017299},{0.032365, 0.035764, 0.015120}}],
    Polygon[{{0.037037, 0.033952, 0.017299},{0.037037, 0.031091, 0.019053},{
      0.034037, 0.030616, 0.019053},{0.033153, 0.033337, 0.017299}}],
    Polygon[{{0.037037, 0.031091, 0.019053},{0.037037, 0.027991, 0.020337},{
      0.034995, 0.027668, 0.020337},{0.034037, 0.030616, 0.019053}}],
    Polygon[{{0.037037, 0.027991, 0.020337},{0.037037, 0.024728, 0.021120},{
      0.036003, 0.024565, 0.021120},{0.034995, 0.027668, 0.020337}}],
    Polygon[{{0.036003, 0.024565, -0.021120},{0.034995, 0.027668, -0.020337},{
      0.033153, 0.026729, -0.020337},{0.035071, 0.024090, -0.021120}}],
    Polygon[{{0.034995, 0.027668, -0.020337},{0.034037, 0.030616, -0.019053},{
      0.031331, 0.029237, -0.019053},{0.033153, 0.026729, -0.020337}}],
    Polygon[{{0.034037, 0.030616, -0.019053},{0.033153, 0.033337, -0.017299},{
      0.029649, 0.031552, -0.017299},{0.031331, 0.029237, -0.019053}}],
    Polygon[{{0.033153, 0.033337, -0.017299},{0.032365, 0.035764, -0.015120},{
      0.028150, 0.033616, -0.015120},{0.029649, 0.031552, -0.017299}}],
    Polygon[{{0.032365, 0.035764, -0.015120},{0.031691, 0.037836, -0.012569},{
      0.026869, 0.035379, -0.012569},{0.028150, 0.033616, -0.015120}}],
    Polygon[{{0.031691, 0.037836, -0.012569},{0.031149, 0.039504, -0.009708},{
      0.025838, 0.036797, -0.009708},{0.026869, 0.035379, -0.012569}}],
    Polygon[{{0.031149, 0.039504, -0.009708},{0.030753, 0.040725, -0.006608},{
      0.025083, 0.037836, -0.006608},{0.025838, 0.036797, -0.009708}}],
    Polygon[{{0.030753, 0.040725, -0.006608},{0.030511, 0.041470, -0.003345},{
      0.024623, 0.038470, -0.003345},{0.025083, 0.037836, -0.006608}}],
    Polygon[{{0.030511, 0.041470, -0.003345},{0.030429, 0.041720, 0.000000},{
      0.024468, 0.038683, 0.000000},{0.024623, 0.038470, -0.003345}}],
    Polygon[{{0.030429, 0.041720, 0.000000},{0.030511, 0.041470, 0.003345},{
      0.024623, 0.038470, 0.003345},{0.024468, 0.038683, 0.000000}}],
    Polygon[{{0.030511, 0.041470, 0.003345},{0.030753, 0.040725, 0.006608},{
      0.025083, 0.037836, 0.006608},{0.024623, 0.038470, 0.003345}}],
    Polygon[{{0.030753, 0.040725, 0.006608},{0.031149, 0.039504, 0.009708},{
      0.025838, 0.036797, 0.009708},{0.025083, 0.037836, 0.006608}}],
    Polygon[{{0.031149, 0.039504, 0.009708},{0.031691, 0.037836, 0.012569},{
      0.026869, 0.035379, 0.012569},{0.025838, 0.036797, 0.009708}}],
    Polygon[{{0.031691, 0.037836, 0.012569},{0.032365, 0.035764, 0.015120},{
      0.028150, 0.033616, 0.015120},{0.026869, 0.035379, 0.012569}}],
    Polygon[{{0.032365, 0.035764, 0.015120},{0.033153, 0.033337, 0.017299},{
      0.029649, 0.031552, 0.017299},{0.028150, 0.033616, 0.015120}}],
    Polygon[{{0.033153, 0.033337, 0.017299},{0.034037, 0.030616, 0.019053},{
      0.031331, 0.029237, 0.019053},{0.029649, 0.031552, 0.017299}}],
    Polygon[{{0.034037, 0.030616, 0.019053},{0.034995, 0.027668, 0.020337},{
      0.033153, 0.026729, 0.020337},{0.031331, 0.029237, 0.019053}}],
    Polygon[{{0.034995, 0.027668, 0.020337},{0.036003, 0.024565, 0.021120},{
      0.035071, 0.024090, 0.021120},{0.033153, 0.026729, 0.020337}}],
    Polygon[{{0.035071, 0.024090, -0.021120},{0.033153, 0.026729, -0.020337},{
      0.031691, 0.025267, -0.020337},{0.034331, 0.023350, -0.021120}}],
    Polygon[{{0.033153, 0.026729, -0.020337},{0.031331, 0.029237, -0.019053},{
      0.029183, 0.027089, -0.019053},{0.031691, 0.025267, -0.020337}}],
    Polygon[{{0.031331, 0.029237, -0.019053},{0.029649, 0.031552, -0.017299},{
      0.026869, 0.028771, -0.017299},{0.029183, 0.027089, -0.019053}}],
    Polygon[{{0.029649, 0.031552, -0.017299},{0.028150, 0.033616, -0.015120},{
      0.024804, 0.030271, -0.015120},{0.026869, 0.028771, -0.017299}}],
    Polygon[{{0.028150, 0.033616, -0.015120},{0.026869, 0.035379, -0.012569},{
      0.023041, 0.031552, -0.012569},{0.024804, 0.030271, -0.015120}}],
    Polygon[{{0.026869, 0.035379, -0.012569},{0.025838, 0.036797, -0.009708},{
      0.021623, 0.032582, -0.009708},{0.023041, 0.031552, -0.012569}}],
    Polygon[{{0.025838, 0.036797, -0.009708},{0.025083, 0.037836, -0.006608},{
      0.020584, 0.033337, -0.006608},{0.021623, 0.032582, -0.009708}}],
    Polygon[{{0.025083, 0.037836, -0.006608},{0.024623, 0.038470, -0.003345},{
      0.019951, 0.033797, -0.003345},{0.020584, 0.033337, -0.006608}}],
    Polygon[{{0.024623, 0.038470, -0.003345},{0.024468, 0.038683, 0.000000},{
      0.019738, 0.033952, 0.000000},{0.019951, 0.033797, -0.003345}}],
    Polygon[{{0.024468, 0.038683, 0.000000},{0.024623, 0.038470, 0.003345},{
      0.019951, 0.033797, 0.003345},{0.019738, 0.033952, 0.000000}}],
    Polygon[{{0.024623, 0.038470, 0.003345},{0.025083, 0.037836, 0.006608},{
      0.020584, 0.033337, 0.006608},{0.019951, 0.033797, 0.003345}}],
    Polygon[{{0.025083, 0.037836, 0.006608},{0.025838, 0.036797, 0.009708},{
      0.021623, 0.032582, 0.009708},{0.020584, 0.033337, 0.006608}}],
    Polygon[{{0.025838, 0.036797, 0.009708},{0.026869, 0.035379, 0.012569},{
      0.023041, 0.031552, 0.012569},{0.021623, 0.032582, 0.009708}}],
    Polygon[{{0.026869, 0.035379, 0.012569},{0.028150, 0.033616, 0.015120},{
      0.024804, 0.030271, 0.015120},{0.023041, 0.031552, 0.012569}}],
    Polygon[{{0.028150, 0.033616, 0.015120},{0.029649, 0.031552, 0.017299},{
      0.026869, 0.028771, 0.017299},{0.024804, 0.030271, 0.015120}}],
    Polygon[{{0.029649, 0.031552, 0.017299},{0.031331, 0.029237, 0.019053},{
      0.029183, 0.027089, 0.019053},{0.026869, 0.028771, 0.017299}}],
    Polygon[{{0.031331, 0.029237, 0.019053},{0.033153, 0.026729, 0.020337},{
      0.031691, 0.025267, 0.020337},{0.029183, 0.027089, 0.019053}}],
    Polygon[{{0.033153, 0.026729, 0.020337},{0.035071, 0.024090, 0.021120},{
      0.034331, 0.023350, 0.021120},{0.031691, 0.025267, 0.020337}}],
    Polygon[{{0.034331, 0.023350, -0.021120},{0.031691, 0.025267, -0.020337},{
      0.030753, 0.023425, -0.020337},{0.033856, 0.022417, -0.021120}}],
    Polygon[{{0.031691, 0.025267, -0.020337},{0.029183, 0.027089, -0.019053},{
      0.027804, 0.024383, -0.019053},{0.030753, 0.023425, -0.020337}}],
    Polygon[{{0.029183, 0.027089, -0.019053},{0.026869, 0.028771, -0.017299},{
      0.025083, 0.025267, -0.017299},{0.027804, 0.024383, -0.019053}}],
    Polygon[{{0.026869, 0.028771, -0.017299},{0.024804, 0.030271, -0.015120},{
      0.022657, 0.026056, -0.015120},{0.025083, 0.025267, -0.017299}}],
    Polygon[{{0.024804, 0.030271, -0.015120},{0.023041, 0.031552, -0.012569},{
      0.020584, 0.026729, -0.012569},{0.022657, 0.026056, -0.015120}}],
    Polygon[{{0.023041, 0.031552, -0.012569},{0.021623, 0.032582, -0.009708},{
      0.018917, 0.027271, -0.009708},{0.020584, 0.026729, -0.012569}}],
    Polygon[{{0.021623, 0.032582, -0.009708},{0.020584, 0.033337, -0.006608},{
      0.017696, 0.027668, -0.006608},{0.018917, 0.027271, -0.009708}}],
    Polygon[{{0.020584, 0.033337, -0.006608},{0.019951, 0.033797, -0.003345},{
      0.016951, 0.027910, -0.003345},{0.017696, 0.027668, -0.006608}}],
    Polygon[{{0.019951, 0.033797, -0.003345},{0.019738, 0.033952, 0.000000},{
      0.016700, 0.027991, 0.000000},{0.016951, 0.027910, -0.003345}}],
    Polygon[{{0.019738, 0.033952, 0.000000},{0.019951, 0.033797, 0.003345},{
      0.016951, 0.027910, 0.003345},{0.016700, 0.027991, 0.000000}}],
    Polygon[{{0.019951, 0.033797, 0.003345},{0.020584, 0.033337, 0.006608},{
      0.017696, 0.027668, 0.006608},{0.016951, 0.027910, 0.003345}}],
    Polygon[{{0.020584, 0.033337, 0.006608},{0.021623, 0.032582, 0.009708},{
      0.018917, 0.027271, 0.009708},{0.017696, 0.027668, 0.006608}}],
    Polygon[{{0.021623, 0.032582, 0.009708},{0.023041, 0.031552, 0.012569},{
      0.020584, 0.026729, 0.012569},{0.018917, 0.027271, 0.009708}}],
    Polygon[{{0.023041, 0.031552, 0.012569},{0.024804, 0.030271, 0.015120},{
      0.022657, 0.026056, 0.015120},{0.020584, 0.026729, 0.012569}}],
    Polygon[{{0.024804, 0.030271, 0.015120},{0.026869, 0.028771, 0.017299},{
      0.025083, 0.025267, 0.017299},{0.022657, 0.026056, 0.015120}}],
    Polygon[{{0.026869, 0.028771, 0.017299},{0.029183, 0.027089, 0.019053},{
      0.027804, 0.024383, 0.019053},{0.025083, 0.025267, 0.017299}}],
    Polygon[{{0.029183, 0.027089, 0.019053},{0.031691, 0.025267, 0.020337},{
      0.030753, 0.023425, 0.020337},{0.027804, 0.024383, 0.019053}}],
    Polygon[{{0.031691, 0.025267, 0.020337},{0.034331, 0.023350, 0.021120},{
      0.033856, 0.022417, 0.021120},{0.030753, 0.023425, 0.020337}}],
    Polygon[{{0.033856, 0.022417, -0.021120},{0.030753, 0.023425, -0.020337},{
      0.030429, 0.021383, -0.020337},{0.033692, 0.021383, -0.021120}}],
    Polygon[{{0.030753, 0.023425, -0.020337},{0.027804, 0.024383, -0.019053},{
      0.027329, 0.021383, -0.019053},{0.030429, 0.021383, -0.020337}}],
    Polygon[{{0.027804, 0.024383, -0.019053},{0.025083, 0.025267, -0.017299},{
      0.024468, 0.021383, -0.017299},{0.027329, 0.021383, -0.019053}}],
    Polygon[{{0.025083, 0.025267, -0.017299},{0.022657, 0.026056, -0.015120},{
      0.021917, 0.021383, -0.015120},{0.024468, 0.021383, -0.017299}}],
    Polygon[{{0.022657, 0.026056, -0.015120},{0.020584, 0.026729, -0.012569},{
      0.019738, 0.021383, -0.012569},{0.021917, 0.021383, -0.015120}}],
    Polygon[{{0.020584, 0.026729, -0.012569},{0.018917, 0.027271, -0.009708},{
      0.017984, 0.021383, -0.009708},{0.019738, 0.021383, -0.012569}}],
    Polygon[{{0.018917, 0.027271, -0.009708},{0.017696, 0.027668, -0.006608},{
      0.016700, 0.021383, -0.006608},{0.017984, 0.021383, -0.009708}}],
    Polygon[{{0.017696, 0.027668, -0.006608},{0.016951, 0.027910, -0.003345},{
      0.015917, 0.021383, -0.003345},{0.016700, 0.021383, -0.006608}}],
    Polygon[{{0.016951, 0.027910, -0.003345},{0.016700, 0.027991, 0.000000},{
      0.015654, 0.021383, 0.000000},{0.015917, 0.021383, -0.003345}}],
    Polygon[{{0.016700, 0.027991, 0.000000},{0.016951, 0.027910, 0.003345},{
      0.015917, 0.021383, 0.003345},{0.015654, 0.021383, 0.000000}}],
    Polygon[{{0.016951, 0.027910, 0.003345},{0.017696, 0.027668, 0.006608},{
      0.016700, 0.021383, 0.006608},{0.015917, 0.021383, 0.003345}}],
    Polygon[{{0.017696, 0.027668, 0.006608},{0.018917, 0.027271, 0.009708},{
      0.017984, 0.021383, 0.009708},{0.016700, 0.021383, 0.006608}}],
    Polygon[{{0.018917, 0.027271, 0.009708},{0.020584, 0.026729, 0.012569},{
      0.019738, 0.021383, 0.012569},{0.017984, 0.021383, 0.009708}}],
    Polygon[{{0.020584, 0.026729, 0.012569},{0.022657, 0.026056, 0.015120},{
      0.021917, 0.021383, 0.015120},{0.019738, 0.021383, 0.012569}}],
    Polygon[{{0.022657, 0.026056, 0.015120},{0.025083, 0.025267, 0.017299},{
      0.024468, 0.021383, 0.017299},{0.021917, 0.021383, 0.015120}}],
    Polygon[{{0.025083, 0.025267, 0.017299},{0.027804, 0.024383, 0.019053},{
      0.027329, 0.021383, 0.019053},{0.024468, 0.021383, 0.017299}}],
    Polygon[{{0.027804, 0.024383, 0.019053},{0.030753, 0.023425, 0.020337},{
      0.030429, 0.021383, 0.020337},{0.027329, 0.021383, 0.019053}}],
    Polygon[{{0.030753, 0.023425, 0.020337},{0.033856, 0.022417, 0.021120},{
      0.033692, 0.021383, 0.021120},{0.030429, 0.021383, 0.020337}}],
    Polygon[{{0.033692, 0.021383, -0.021120},{0.030429, 0.021383, -0.020337},{
      0.030753, 0.019341, -0.020337},{0.033856, 0.020350, -0.021120}}],
    Polygon[{{0.030429, 0.021383, -0.020337},{0.027329, 0.021383, -0.019053},{
      0.027804, 0.018383, -0.019053},{0.030753, 0.019341, -0.020337}}],
    Polygon[{{0.027329, 0.021383, -0.019053},{0.024468, 0.021383, -0.017299},{
      0.025083, 0.017499, -0.017299},{0.027804, 0.018383, -0.019053}}],
    Polygon[{{0.024468, 0.021383, -0.017299},{0.021917, 0.021383, -0.015120},{
      0.022657, 0.016711, -0.015120},{0.025083, 0.017499, -0.017299}}],
    Polygon[{{0.021917, 0.021383, -0.015120},{0.019738, 0.021383, -0.012569},{
      0.020584, 0.016038, -0.012569},{0.022657, 0.016711, -0.015120}}],
    Polygon[{{0.019738, 0.021383, -0.012569},{0.017984, 0.021383, -0.009708},{
      0.018917, 0.015496, -0.009708},{0.020584, 0.016038, -0.012569}}],
    Polygon[{{0.017984, 0.021383, -0.009708},{0.016700, 0.021383, -0.006608},{
      0.017696, 0.015099, -0.006608},{0.018917, 0.015496, -0.009708}}],
    Polygon[{{0.016700, 0.021383, -0.006608},{0.015917, 0.021383, -0.003345},{
      0.016951, 0.014857, -0.003345},{0.017696, 0.015099, -0.006608}}],
    Polygon[{{0.015917, 0.021383, -0.003345},{0.015654, 0.021383, 0.000000},{
      0.016700, 0.014776, 0.000000},{0.016951, 0.014857, -0.003345}}],
    Polygon[{{0.015654, 0.021383, 0.000000},{0.015917, 0.021383, 0.003345},{
      0.016951, 0.014857, 0.003345},{0.016700, 0.014776, 0.000000}}],
    Polygon[{{0.015917, 0.021383, 0.003345},{0.016700, 0.021383, 0.006608},{
      0.017696, 0.015099, 0.006608},{0.016951, 0.014857, 0.003345}}],
    Polygon[{{0.016700, 0.021383, 0.006608},{0.017984, 0.021383, 0.009708},{
      0.018917, 0.015496, 0.009708},{0.017696, 0.015099, 0.006608}}],
    Polygon[{{0.017984, 0.021383, 0.009708},{0.019738, 0.021383, 0.012569},{
      0.020584, 0.016038, 0.012569},{0.018917, 0.015496, 0.009708}}],
    Polygon[{{0.019738, 0.021383, 0.012569},{0.021917, 0.021383, 0.015120},{
      0.022657, 0.016711, 0.015120},{0.020584, 0.016038, 0.012569}}],
    Polygon[{{0.021917, 0.021383, 0.015120},{0.024468, 0.021383, 0.017299},{
      0.025083, 0.017499, 0.017299},{0.022657, 0.016711, 0.015120}}],
    Polygon[{{0.024468, 0.021383, 0.017299},{0.027329, 0.021383, 0.019053},{
      0.027804, 0.018383, 0.019053},{0.025083, 0.017499, 0.017299}}],
    Polygon[{{0.027329, 0.021383, 0.019053},{0.030429, 0.021383, 0.020337},{
      0.030753, 0.019341, 0.020337},{0.027804, 0.018383, 0.019053}}],
    Polygon[{{0.030429, 0.021383, 0.020337},{0.033692, 0.021383, 0.021120},{
      0.033856, 0.020350, 0.021120},{0.030753, 0.019341, 0.020337}}],
    Polygon[{{0.033856, 0.020350, -0.021120},{0.030753, 0.019341, -0.020337},{
      0.031691, 0.017499, -0.020337},{0.034331, 0.019417, -0.021120}}],
    Polygon[{{0.030753, 0.019341, -0.020337},{0.027804, 0.018383, -0.019053},{
      0.029183, 0.015677, -0.019053},{0.031691, 0.017499, -0.020337}}],
    Polygon[{{0.027804, 0.018383, -0.019053},{0.025083, 0.017499, -0.017299},{
      0.026869, 0.013996, -0.017299},{0.029183, 0.015677, -0.019053}}],
    Polygon[{{0.025083, 0.017499, -0.017299},{0.022657, 0.016711, -0.015120},{
      0.024804, 0.012496, -0.015120},{0.026869, 0.013996, -0.017299}}],
    Polygon[{{0.022657, 0.016711, -0.015120},{0.020584, 0.016038, -0.012569},{
      0.023041, 0.011215, -0.012569},{0.024804, 0.012496, -0.015120}}],
    Polygon[{{0.020584, 0.016038, -0.012569},{0.018917, 0.015496, -0.009708},{
      0.021623, 0.010184, -0.009708},{0.023041, 0.011215, -0.012569}}],
    Polygon[{{0.018917, 0.015496, -0.009708},{0.017696, 0.015099, -0.006608},{
      0.020584, 0.009430, -0.006608},{0.021623, 0.010184, -0.009708}}],
    Polygon[{{0.017696, 0.015099, -0.006608},{0.016951, 0.014857, -0.003345},{
      0.019951, 0.008969, -0.003345},{0.020584, 0.009430, -0.006608}}],
    Polygon[{{0.016951, 0.014857, -0.003345},{0.016700, 0.014776, 0.000000},{
      0.019738, 0.008815, 0.000000},{0.019951, 0.008969, -0.003345}}],
    Polygon[{{0.016700, 0.014776, 0.000000},{0.016951, 0.014857, 0.003345},{
      0.019951, 0.008969, 0.003345},{0.019738, 0.008815, 0.000000}}],
    Polygon[{{0.016951, 0.014857, 0.003345},{0.017696, 0.015099, 0.006608},{
      0.020584, 0.009430, 0.006608},{0.019951, 0.008969, 0.003345}}],
    Polygon[{{0.017696, 0.015099, 0.006608},{0.018917, 0.015496, 0.009708},{
      0.021623, 0.010184, 0.009708},{0.020584, 0.009430, 0.006608}}],
    Polygon[{{0.018917, 0.015496, 0.009708},{0.020584, 0.016038, 0.012569},{
      0.023041, 0.011215, 0.012569},{0.021623, 0.010184, 0.009708}}],
    Polygon[{{0.020584, 0.016038, 0.012569},{0.022657, 0.016711, 0.015120},{
      0.024804, 0.012496, 0.015120},{0.023041, 0.011215, 0.012569}}],
    Polygon[{{0.022657, 0.016711, 0.015120},{0.025083, 0.017499, 0.017299},{
      0.026869, 0.013996, 0.017299},{0.024804, 0.012496, 0.015120}}],
    Polygon[{{0.025083, 0.017499, 0.017299},{0.027804, 0.018383, 0.019053},{
      0.029183, 0.015677, 0.019053},{0.026869, 0.013996, 0.017299}}],
    Polygon[{{0.027804, 0.018383, 0.019053},{0.030753, 0.019341, 0.020337},{
      0.031691, 0.017499, 0.020337},{0.029183, 0.015677, 0.019053}}],
    Polygon[{{0.030753, 0.019341, 0.020337},{0.033856, 0.020350, 0.021120},{
      0.034331, 0.019417, 0.021120},{0.031691, 0.017499, 0.020337}}],
    Polygon[{{0.034331, 0.019417, -0.021120},{0.031691, 0.017499, -0.020337},{
      0.033153, 0.016038, -0.020337},{0.035071, 0.018677, -0.021120}}],
    Polygon[{{0.031691, 0.017499, -0.020337},{0.029183, 0.015677, -0.019053},{
      0.031331, 0.013530, -0.019053},{0.033153, 0.016038, -0.020337}}],
    Polygon[{{0.029183, 0.015677, -0.019053},{0.026869, 0.013996, -0.017299},{
      0.029649, 0.011215, -0.017299},{0.031331, 0.013530, -0.019053}}],
    Polygon[{{0.026869, 0.013996, -0.017299},{0.024804, 0.012496, -0.015120},{
      0.028150, 0.009151, -0.015120},{0.029649, 0.011215, -0.017299}}],
    Polygon[{{0.024804, 0.012496, -0.015120},{0.023041, 0.011215, -0.012569},{
      0.026869, 0.007388, -0.012569},{0.028150, 0.009151, -0.015120}}],
    Polygon[{{0.023041, 0.011215, -0.012569},{0.021623, 0.010184, -0.009708},{
      0.025838, 0.005969, -0.009708},{0.026869, 0.007388, -0.012569}}],
    Polygon[{{0.021623, 0.010184, -0.009708},{0.020584, 0.009430, -0.006608},{
      0.025083, 0.004931, -0.006608},{0.025838, 0.005969, -0.009708}}],
    Polygon[{{0.020584, 0.009430, -0.006608},{0.019951, 0.008969, -0.003345},{
      0.024623, 0.004297, -0.003345},{0.025083, 0.004931, -0.006608}}],
    Polygon[{{0.019951, 0.008969, -0.003345},{0.019738, 0.008815, 0.000000},{
      0.024468, 0.004084, 0.000000},{0.024623, 0.004297, -0.003345}}],
    Polygon[{{0.019738, 0.008815, 0.000000},{0.019951, 0.008969, 0.003345},{
      0.024623, 0.004297, 0.003345},{0.024468, 0.004084, 0.000000}}],
    Polygon[{{0.019951, 0.008969, 0.003345},{0.020584, 0.009430, 0.006608},{
      0.025083, 0.004931, 0.006608},{0.024623, 0.004297, 0.003345}}],
    Polygon[{{0.020584, 0.009430, 0.006608},{0.021623, 0.010184, 0.009708},{
      0.025838, 0.005969, 0.009708},{0.025083, 0.004931, 0.006608}}],
    Polygon[{{0.021623, 0.010184, 0.009708},{0.023041, 0.011215, 0.012569},{
      0.026869, 0.007388, 0.012569},{0.025838, 0.005969, 0.009708}}],
    Polygon[{{0.023041, 0.011215, 0.012569},{0.024804, 0.012496, 0.015120},{
      0.028150, 0.009151, 0.015120},{0.026869, 0.007388, 0.012569}}],
    Polygon[{{0.024804, 0.012496, 0.015120},{0.026869, 0.013996, 0.017299},{
      0.029649, 0.011215, 0.017299},{0.028150, 0.009151, 0.015120}}],
    Polygon[{{0.026869, 0.013996, 0.017299},{0.029183, 0.015677, 0.019053},{
      0.031331, 0.013530, 0.019053},{0.029649, 0.011215, 0.017299}}],
    Polygon[{{0.029183, 0.015677, 0.019053},{0.031691, 0.017499, 0.020337},{
      0.033153, 0.016038, 0.020337},{0.031331, 0.013530, 0.019053}}],
    Polygon[{{0.031691, 0.017499, 0.020337},{0.034331, 0.019417, 0.021120},{
      0.035071, 0.018677, 0.021120},{0.033153, 0.016038, 0.020337}}],
    Polygon[{{0.035071, 0.018677, -0.021120},{0.033153, 0.016038, -0.020337},{
      0.034995, 0.015099, -0.020337},{0.036003, 0.018202, -0.021120}}],
    Polygon[{{0.033153, 0.016038, -0.020337},{0.031331, 0.013530, -0.019053},{
      0.034037, 0.012151, -0.019053},{0.034995, 0.015099, -0.020337}}],
    Polygon[{{0.031331, 0.013530, -0.019053},{0.029649, 0.011215, -0.017299},{
      0.033153, 0.009430, -0.017299},{0.034037, 0.012151, -0.019053}}],
    Polygon[{{0.029649, 0.011215, -0.017299},{0.028150, 0.009151, -0.015120},{
      0.032365, 0.007003, -0.015120},{0.033153, 0.009430, -0.017299}}],
    Polygon[{{0.028150, 0.009151, -0.015120},{0.026869, 0.007388, -0.012569},{
      0.031691, 0.004931, -0.012569},{0.032365, 0.007003, -0.015120}}],
    Polygon[{{0.026869, 0.007388, -0.012569},{0.025838, 0.005969, -0.009708},{
      0.031149, 0.003263, -0.009708},{0.031691, 0.004931, -0.012569}}],
    Polygon[{{0.025838, 0.005969, -0.009708},{0.025083, 0.004931, -0.006608},{
      0.030753, 0.002042, -0.006608},{0.031149, 0.003263, -0.009708}}],
    Polygon[{{0.025083, 0.004931, -0.006608},{0.024623, 0.004297, -0.003345},{
      0.030511, 0.001297, -0.003345},{0.030753, 0.002042, -0.006608}}],
    Polygon[{{0.024623, 0.004297, -0.003345},{0.024468, 0.004084, 0.000000},{
      0.030429, 0.001047, 0.000000},{0.030511, 0.001297, -0.003345}}],
    Polygon[{{0.024468, 0.004084, 0.000000},{0.024623, 0.004297, 0.003345},{
      0.030511, 0.001297, 0.003345},{0.030429, 0.001047, 0.000000}}],
    Polygon[{{0.024623, 0.004297, 0.003345},{0.025083, 0.004931, 0.006608},{
      0.030753, 0.002042, 0.006608},{0.030511, 0.001297, 0.003345}}],
    Polygon[{{0.025083, 0.004931, 0.006608},{0.025838, 0.005969, 0.009708},{
      0.031149, 0.003263, 0.009708},{0.030753, 0.002042, 0.006608}}],
    Polygon[{{0.025838, 0.005969, 0.009708},{0.026869, 0.007388, 0.012569},{
      0.031691, 0.004931, 0.012569},{0.031149, 0.003263, 0.009708}}],
    Polygon[{{0.026869, 0.007388, 0.012569},{0.028150, 0.009151, 0.015120},{
      0.032365, 0.007003, 0.015120},{0.031691, 0.004931, 0.012569}}],
    Polygon[{{0.028150, 0.009151, 0.015120},{0.029649, 0.011215, 0.017299},{
      0.033153, 0.009430, 0.017299},{0.032365, 0.007003, 0.015120}}],
    Polygon[{{0.029649, 0.011215, 0.017299},{0.031331, 0.013530, 0.019053},{
      0.034037, 0.012151, 0.019053},{0.033153, 0.009430, 0.017299}}],
    Polygon[{{0.031331, 0.013530, 0.019053},{0.033153, 0.016038, 0.020337},{
      0.034995, 0.015099, 0.020337},{0.034037, 0.012151, 0.019053}}],
    Polygon[{{0.033153, 0.016038, 0.020337},{0.035071, 0.018677, 0.021120},{
      0.036003, 0.018202, 0.021120},{0.034995, 0.015099, 0.020337}}],
    Polygon[{{0.036003, 0.018202, -0.021120},{0.034995, 0.015099, -0.020337},{
      0.037037, 0.014776, -0.020337},{0.037037, 0.018038, -0.021120}}],
    Polygon[{{0.034995, 0.015099, -0.020337},{0.034037, 0.012151, -0.019053},{
      0.037037, 0.011676, -0.019053},{0.037037, 0.014776, -0.020337}}],
    Polygon[{{0.034037, 0.012151, -0.019053},{0.033153, 0.009430, -0.017299},{
      0.037037, 0.008815, -0.017299},{0.037037, 0.011676, -0.019053}}],
    Polygon[{{0.033153, 0.009430, -0.017299},{0.032365, 0.007003, -0.015120},{
      0.037037, 0.006263, -0.015120},{0.037037, 0.008815, -0.017299}}],
    Polygon[{{0.032365, 0.007003, -0.015120},{0.031691, 0.004931, -0.012569},{
      0.037037, 0.004084, -0.012569},{0.037037, 0.006263, -0.015120}}],
    Polygon[{{0.031691, 0.004931, -0.012569},{0.031149, 0.003263, -0.009708},{
      0.037037, 0.002331, -0.009708},{0.037037, 0.004084, -0.012569}}],
    Polygon[{{0.031149, 0.003263, -0.009708},{0.030753, 0.002042, -0.006608},{
      0.037037, 0.001047, -0.006608},{0.037037, 0.002331, -0.009708}}],
    Polygon[{{0.030753, 0.002042, -0.006608},{0.030511, 0.001297, -0.003345},{
      0.037037, 0.000263, -0.003345},{0.037037, 0.001047, -0.006608}}],
    Polygon[{{0.030511, 0.001297, -0.003345},{0.030429, 0.001047, 0.000000},{
      0.037037, 0.000000, 0.000000},{0.037037, 0.000263, -0.003345}}],
    Polygon[{{0.030429, 0.001047, 0.000000},{0.030511, 0.001297, 0.003345},{
      0.037037, 0.000263, 0.003345},{0.037037, 0.000000, 0.000000}}],
    Polygon[{{0.030511, 0.001297, 0.003345},{0.030753, 0.002042, 0.006608},{
      0.037037, 0.001047, 0.006608},{0.037037, 0.000263, 0.003345}}],
    Polygon[{{0.030753, 0.002042, 0.006608},{0.031149, 0.003263, 0.009708},{
      0.037037, 0.002331, 0.009708},{0.037037, 0.001047, 0.006608}}],
    Polygon[{{0.031149, 0.003263, 0.009708},{0.031691, 0.004931, 0.012569},{
      0.037037, 0.004084, 0.012569},{0.037037, 0.002331, 0.009708}}],
    Polygon[{{0.031691, 0.004931, 0.012569},{0.032365, 0.007003, 0.015120},{
      0.037037, 0.006263, 0.015120},{0.037037, 0.004084, 0.012569}}],
    Polygon[{{0.032365, 0.007003, 0.015120},{0.033153, 0.009430, 0.017299},{
      0.037037, 0.008815, 0.017299},{0.037037, 0.006263, 0.015120}}],
    Polygon[{{0.033153, 0.009430, 0.017299},{0.034037, 0.012151, 0.019053},{
      0.037037, 0.011676, 0.019053},{0.037037, 0.008815, 0.017299}}],
    Polygon[{{0.034037, 0.012151, 0.019053},{0.034995, 0.015099, 0.020337},{
      0.037037, 0.014776, 0.020337},{0.037037, 0.011676, 0.019053}}],
    Polygon[{{0.034995, 0.015099, 0.020337},{0.036003, 0.018202, 0.021120},{
      0.037037, 0.018038, 0.021120},{0.037037, 0.014776, 0.020337}}],
    Polygon[{{0.037037, 0.018038, -0.021120},{0.037037, 0.014776, -0.020337},{
      0.039079, 0.015099, -0.020337},{0.038071, 0.018202, -0.021120}}],
    Polygon[{{0.037037, 0.014776, -0.020337},{0.037037, 0.011676, -0.019053},{
      0.040037, 0.012151, -0.019053},{0.039079, 0.015099, -0.020337}}],
    Polygon[{{0.037037, 0.011676, -0.019053},{0.037037, 0.008815, -0.017299},{
      0.040921, 0.009430, -0.017299},{0.040037, 0.012151, -0.019053}}],
    Polygon[{{0.037037, 0.008815, -0.017299},{0.037037, 0.006263, -0.015120},{
      0.041709, 0.007003, -0.015120},{0.040921, 0.009430, -0.017299}}],
    Polygon[{{0.037037, 0.006263, -0.015120},{0.037037, 0.004084, -0.012569},{
      0.042383, 0.004931, -0.012569},{0.041709, 0.007003, -0.015120}}],
    Polygon[{{0.037037, 0.004084, -0.012569},{0.037037, 0.002331, -0.009708},{
      0.042925, 0.003263, -0.009708},{0.042383, 0.004931, -0.012569}}],
    Polygon[{{0.037037, 0.002331, -0.009708},{0.037037, 0.001047, -0.006608},{
      0.043321, 0.002042, -0.006608},{0.042925, 0.003263, -0.009708}}],
    Polygon[{{0.037037, 0.001047, -0.006608},{0.037037, 0.000263, -0.003345},{
      0.043564, 0.001297, -0.003345},{0.043321, 0.002042, -0.006608}}],
    Polygon[{{0.037037, 0.000263, -0.003345},{0.037037, 0.000000, 0.000000},{
      0.043645, 0.001047, 0.000000},{0.043564, 0.001297, -0.003345}}],
    Polygon[{{0.037037, 0.000000, 0.000000},{0.037037, 0.000263, 0.003345},{
      0.043564, 0.001297, 0.003345},{0.043645, 0.001047, 0.000000}}],
    Polygon[{{0.037037, 0.000263, 0.003345},{0.037037, 0.001047, 0.006608},{
      0.043321, 0.002042, 0.006608},{0.043564, 0.001297, 0.003345}}],
    Polygon[{{0.037037, 0.001047, 0.006608},{0.037037, 0.002331, 0.009708},{
      0.042925, 0.003263, 0.009708},{0.043321, 0.002042, 0.006608}}],
    Polygon[{{0.037037, 0.002331, 0.009708},{0.037037, 0.004084, 0.012569},{
      0.042383, 0.004931, 0.012569},{0.042925, 0.003263, 0.009708}}],
    Polygon[{{0.037037, 0.004084, 0.012569},{0.037037, 0.006263, 0.015120},{
      0.041709, 0.007003, 0.015120},{0.042383, 0.004931, 0.012569}}],
    Polygon[{{0.037037, 0.006263, 0.015120},{0.037037, 0.008815, 0.017299},{
      0.040921, 0.009430, 0.017299},{0.041709, 0.007003, 0.015120}}],
    Polygon[{{0.037037, 0.008815, 0.017299},{0.037037, 0.011676, 0.019053},{
      0.040037, 0.012151, 0.019053},{0.040921, 0.009430, 0.017299}}],
    Polygon[{{0.037037, 0.011676, 0.019053},{0.037037, 0.014776, 0.020337},{
      0.039079, 0.015099, 0.020337},{0.040037, 0.012151, 0.019053}}],
    Polygon[{{0.037037, 0.014776, 0.020337},{0.037037, 0.018038, 0.021120},{
      0.038071, 0.018202, 0.021120},{0.039079, 0.015099, 0.020337}}],
    Polygon[{{0.038071, 0.018202, -0.021120},{0.039079, 0.015099, -0.020337},{
      0.040921, 0.016038, -0.020337},{0.039003, 0.018677, -0.021120}}],
    Polygon[{{0.039079, 0.015099, -0.020337},{0.040037, 0.012151, -0.019053},{
      0.042743, 0.013530, -0.019053},{0.040921, 0.016038, -0.020337}}],
    Polygon[{{0.040037, 0.012151, -0.019053},{0.040921, 0.009430, -0.017299},{
      0.044425, 0.011215, -0.017299},{0.042743, 0.013530, -0.019053}}],
    Polygon[{{0.040921, 0.009430, -0.017299},{0.041709, 0.007003, -0.015120},{
      0.045925, 0.009151, -0.015120},{0.044425, 0.011215, -0.017299}}],
    Polygon[{{0.041709, 0.007003, -0.015120},{0.042383, 0.004931, -0.012569},{
      0.047205, 0.007388, -0.012569},{0.045925, 0.009151, -0.015120}}],
    Polygon[{{0.042383, 0.004931, -0.012569},{0.042925, 0.003263, -0.009708},{
      0.048236, 0.005969, -0.009708},{0.047205, 0.007388, -0.012569}}],
    Polygon[{{0.042925, 0.003263, -0.009708},{0.043321, 0.002042, -0.006608},{
      0.048991, 0.004931, -0.006608},{0.048236, 0.005969, -0.009708}}],
    Polygon[{{0.043321, 0.002042, -0.006608},{0.043564, 0.001297, -0.003345},{
      0.049451, 0.004297, -0.003345},{0.048991, 0.004931, -0.006608}}],
    Polygon[{{0.043564, 0.001297, -0.003345},{0.043645, 0.001047, 0.000000},{
      0.049606, 0.004084, 0.000000},{0.049451, 0.004297, -0.003345}}],
    Polygon[{{0.043645, 0.001047, 0.000000},{0.043564, 0.001297, 0.003345},{
      0.049451, 0.004297, 0.003345},{0.049606, 0.004084, 0.000000}}],
    Polygon[{{0.043564, 0.001297, 0.003345},{0.043321, 0.002042, 0.006608},{
      0.048991, 0.004931, 0.006608},{0.049451, 0.004297, 0.003345}}],
    Polygon[{{0.043321, 0.002042, 0.006608},{0.042925, 0.003263, 0.009708},{
      0.048236, 0.005969, 0.009708},{0.048991, 0.004931, 0.006608}}],
    Polygon[{{0.042925, 0.003263, 0.009708},{0.042383, 0.004931, 0.012569},{
      0.047205, 0.007388, 0.012569},{0.048236, 0.005969, 0.009708}}],
    Polygon[{{0.042383, 0.004931, 0.012569},{0.041709, 0.007003, 0.015120},{
      0.045925, 0.009151, 0.015120},{0.047205, 0.007388, 0.012569}}],
    Polygon[{{0.041709, 0.007003, 0.015120},{0.040921, 0.009430, 0.017299},{
      0.044425, 0.011215, 0.017299},{0.045925, 0.009151, 0.015120}}],
    Polygon[{{0.040921, 0.009430, 0.017299},{0.040037, 0.012151, 0.019053},{
      0.042743, 0.013530, 0.019053},{0.044425, 0.011215, 0.017299}}],
    Polygon[{{0.040037, 0.012151, 0.019053},{0.039079, 0.015099, 0.020337},{
      0.040921, 0.016038, 0.020337},{0.042743, 0.013530, 0.019053}}],
    Polygon[{{0.039079, 0.015099, 0.020337},{0.038071, 0.018202, 0.021120},{
      0.039003, 0.018677, 0.021120},{0.040921, 0.016038, 0.020337}}],
    Polygon[{{0.039003, 0.018677, -0.021120},{0.040921, 0.016038, -0.020337},{
      0.042383, 0.017499, -0.020337},{0.039743, 0.019417, -0.021120}}],
    Polygon[{{0.040921, 0.016038, -0.020337},{0.042743, 0.013530, -0.019053},{
      0.044891, 0.015677, -0.019053},{0.042383, 0.017499, -0.020337}}],
    Polygon[{{0.042743, 0.013530, -0.019053},{0.044425, 0.011215, -0.017299},{
      0.047205, 0.013996, -0.017299},{0.044891, 0.015677, -0.019053}}],
    Polygon[{{0.044425, 0.011215, -0.017299},{0.045925, 0.009151, -0.015120},{
      0.049270, 0.012496, -0.015120},{0.047205, 0.013996, -0.017299}}],
    Polygon[{{0.045925, 0.009151, -0.015120},{0.047205, 0.007388, -0.012569},{
      0.051033, 0.011215, -0.012569},{0.049270, 0.012496, -0.015120}}],
    Polygon[{{0.047205, 0.007388, -0.012569},{0.048236, 0.005969, -0.009708},{
      0.052451, 0.010184, -0.009708},{0.051033, 0.011215, -0.012569}}],
    Polygon[{{0.048236, 0.005969, -0.009708},{0.048991, 0.004931, -0.006608},{
      0.053490, 0.009430, -0.006608},{0.052451, 0.010184, -0.009708}}],
    Polygon[{{0.048991, 0.004931, -0.006608},{0.049451, 0.004297, -0.003345},{
      0.054124, 0.008969, -0.003345},{0.053490, 0.009430, -0.006608}}],
    Polygon[{{0.049451, 0.004297, -0.003345},{0.049606, 0.004084, 0.000000},{
      0.054337, 0.008815, 0.000000},{0.054124, 0.008969, -0.003345}}],
    Polygon[{{0.049606, 0.004084, 0.000000},{0.049451, 0.004297, 0.003345},{
      0.054124, 0.008969, 0.003345},{0.054337, 0.008815, 0.000000}}],
    Polygon[{{0.049451, 0.004297, 0.003345},{0.048991, 0.004931, 0.006608},{
      0.053490, 0.009430, 0.006608},{0.054124, 0.008969, 0.003345}}],
    Polygon[{{0.048991, 0.004931, 0.006608},{0.048236, 0.005969, 0.009708},{
      0.052451, 0.010184, 0.009708},{0.053490, 0.009430, 0.006608}}],
    Polygon[{{0.048236, 0.005969, 0.009708},{0.047205, 0.007388, 0.012569},{
      0.051033, 0.011215, 0.012569},{0.052451, 0.010184, 0.009708}}],
    Polygon[{{0.047205, 0.007388, 0.012569},{0.045925, 0.009151, 0.015120},{
      0.049270, 0.012496, 0.015120},{0.051033, 0.011215, 0.012569}}],
    Polygon[{{0.045925, 0.009151, 0.015120},{0.044425, 0.011215, 0.017299},{
      0.047205, 0.013996, 0.017299},{0.049270, 0.012496, 0.015120}}],
    Polygon[{{0.044425, 0.011215, 0.017299},{0.042743, 0.013530, 0.019053},{
      0.044891, 0.015677, 0.019053},{0.047205, 0.013996, 0.017299}}],
    Polygon[{{0.042743, 0.013530, 0.019053},{0.040921, 0.016038, 0.020337},{
      0.042383, 0.017499, 0.020337},{0.044891, 0.015677, 0.019053}}],
    Polygon[{{0.040921, 0.016038, 0.020337},{0.039003, 0.018677, 0.021120},{
      0.039743, 0.019417, 0.021120},{0.042383, 0.017499, 0.020337}}],
    Polygon[{{0.039743, 0.019417, -0.021120},{0.042383, 0.017499, -0.020337},{
      0.043321, 0.019341, -0.020337},{0.040218, 0.020350, -0.021120}}],
    Polygon[{{0.042383, 0.017499, -0.020337},{0.044891, 0.015677, -0.019053},{
      0.046270, 0.018383, -0.019053},{0.043321, 0.019341, -0.020337}}],
    Polygon[{{0.044891, 0.015677, -0.019053},{0.047205, 0.013996, -0.017299},{
      0.048991, 0.017499, -0.017299},{0.046270, 0.018383, -0.019053}}],
    Polygon[{{0.047205, 0.013996, -0.017299},{0.049270, 0.012496, -0.015120},{
      0.051417, 0.016711, -0.015120},{0.048991, 0.017499, -0.017299}}],
    Polygon[{{0.049270, 0.012496, -0.015120},{0.051033, 0.011215, -0.012569},{
      0.053490, 0.016038, -0.012569},{0.051417, 0.016711, -0.015120}}],
    Polygon[{{0.051033, 0.011215, -0.012569},{0.052451, 0.010184, -0.009708},{
      0.055157, 0.015496, -0.009708},{0.053490, 0.016038, -0.012569}}],
    Polygon[{{0.052451, 0.010184, -0.009708},{0.053490, 0.009430, -0.006608},{
      0.056378, 0.015099, -0.006608},{0.055157, 0.015496, -0.009708}}],
    Polygon[{{0.053490, 0.009430, -0.006608},{0.054124, 0.008969, -0.003345},{
      0.057123, 0.014857, -0.003345},{0.056378, 0.015099, -0.006608}}],
    Polygon[{{0.054124, 0.008969, -0.003345},{0.054337, 0.008815, 0.000000},{
      0.057374, 0.014776, 0.000000},{0.057123, 0.014857, -0.003345}}],
    Polygon[{{0.054337, 0.008815, 0.000000},{0.054124, 0.008969, 0.003345},{
      0.057123, 0.014857, 0.003345},{0.057374, 0.014776, 0.000000}}],
    Polygon[{{0.054124, 0.008969, 0.003345},{0.053490, 0.009430, 0.006608},{
      0.056378, 0.015099, 0.006608},{0.057123, 0.014857, 0.003345}}],
    Polygon[{{0.053490, 0.009430, 0.006608},{0.052451, 0.010184, 0.009708},{
      0.055157, 0.015496, 0.009708},{0.056378, 0.015099, 0.006608}}],
    Polygon[{{0.052451, 0.010184, 0.009708},{0.051033, 0.011215, 0.012569},{
      0.053490, 0.016038, 0.012569},{0.055157, 0.015496, 0.009708}}],
    Polygon[{{0.051033, 0.011215, 0.012569},{0.049270, 0.012496, 0.015120},{
      0.051417, 0.016711, 0.015120},{0.053490, 0.016038, 0.012569}}],
    Polygon[{{0.049270, 0.012496, 0.015120},{0.047205, 0.013996, 0.017299},{
      0.048991, 0.017499, 0.017299},{0.051417, 0.016711, 0.015120}}],
    Polygon[{{0.047205, 0.013996, 0.017299},{0.044891, 0.015677, 0.019053},{
      0.046270, 0.018383, 0.019053},{0.048991, 0.017499, 0.017299}}],
    Polygon[{{0.044891, 0.015677, 0.019053},{0.042383, 0.017499, 0.020337},{
      0.043321, 0.019341, 0.020337},{0.046270, 0.018383, 0.019053}}],
    Polygon[{{0.042383, 0.017499, 0.020337},{0.039743, 0.019417, 0.021120},{
      0.040218, 0.020350, 0.021120},{0.043321, 0.019341, 0.020337}}],
    Polygon[{{0.040218, 0.020350, -0.021120},{0.043321, 0.019341, -0.020337},{
      0.043645, 0.021383, -0.020337},{0.040382, 0.021383, -0.021120}}],
    Polygon[{{0.043321, 0.019341, -0.020337},{0.046270, 0.018383, -0.019053},{
      0.046745, 0.021383, -0.019053},{0.043645, 0.021383, -0.020337}}],
    Polygon[{{0.046270, 0.018383, -0.019053},{0.048991, 0.017499, -0.017299},{
      0.049606, 0.021383, -0.017299},{0.046745, 0.021383, -0.019053}}],
    Polygon[{{0.048991, 0.017499, -0.017299},{0.051417, 0.016711, -0.015120},{
      0.052157, 0.021383, -0.015120},{0.049606, 0.021383, -0.017299}}],
    Polygon[{{0.051417, 0.016711, -0.015120},{0.053490, 0.016038, -0.012569},{
      0.054337, 0.021383, -0.012569},{0.052157, 0.021383, -0.015120}}],
    Polygon[{{0.053490, 0.016038, -0.012569},{0.055157, 0.015496, -0.009708},{
      0.056090, 0.021383, -0.009708},{0.054337, 0.021383, -0.012569}}],
    Polygon[{{0.055157, 0.015496, -0.009708},{0.056378, 0.015099, -0.006608},{
      0.057374, 0.021383, -0.006608},{0.056090, 0.021383, -0.009708}}],
    Polygon[{{0.056378, 0.015099, -0.006608},{0.057123, 0.014857, -0.003345},{
      0.058157, 0.021383, -0.003345},{0.057374, 0.021383, -0.006608}}],
    Polygon[{{0.057123, 0.014857, -0.003345},{0.057374, 0.014776, 0.000000},{
      0.058420, 0.021383, 0.000000},{0.058157, 0.021383, -0.003345}}],
    Polygon[{{0.057374, 0.014776, 0.000000},{0.057123, 0.014857, 0.003345},{
      0.058157, 0.021383, 0.003345},{0.058420, 0.021383, 0.000000}}],
    Polygon[{{0.057123, 0.014857, 0.003345},{0.056378, 0.015099, 0.006608},{
      0.057374, 0.021383, 0.006608},{0.058157, 0.021383, 0.003345}}],
    Polygon[{{0.056378, 0.015099, 0.006608},{0.055157, 0.015496, 0.009708},{
      0.056090, 0.021383, 0.009708},{0.057374, 0.021383, 0.006608}}],
    Polygon[{{0.055157, 0.015496, 0.009708},{0.053490, 0.016038, 0.012569},{
      0.054337, 0.021383, 0.012569},{0.056090, 0.021383, 0.009708}}],
    Polygon[{{0.053490, 0.016038, 0.012569},{0.051417, 0.016711, 0.015120},{
      0.052157, 0.021383, 0.015120},{0.054337, 0.021383, 0.012569}}],
    Polygon[{{0.051417, 0.016711, 0.015120},{0.048991, 0.017499, 0.017299},{
      0.049606, 0.021383, 0.017299},{0.052157, 0.021383, 0.015120}}],
    Polygon[{{0.048991, 0.017499, 0.017299},{0.046270, 0.018383, 0.019053},{
      0.046745, 0.021383, 0.019053},{0.049606, 0.021383, 0.017299}}],
    Polygon[{{0.046270, 0.018383, 0.019053},{0.043321, 0.019341, 0.020337},{
      0.043645, 0.021383, 0.020337},{0.046745, 0.021383, 0.019053}}],
    Polygon[{{0.043321, 0.019341, 0.020337},{0.040218, 0.020350, 0.021120},{
      0.040382, 0.021383, 0.021120},{0.043645, 0.021383, 0.020337}}],
    Polygon[{{0.013461, 0.007128, -0.007040},{0.014548, 0.007128, -0.006779},{
      0.014440, 0.007808, -0.006779},{0.013406, 0.007472, -0.007040}}],
    Polygon[{{0.014548, 0.007128, -0.006779},{0.015582, 0.007128, -0.006351},{
      0.015423, 0.008128, -0.006351},{0.014440, 0.007808, -0.006779}}],
    Polygon[{{0.015582, 0.007128, -0.006351},{0.016535, 0.007128, -0.005766},{
      0.016330, 0.008422, -0.005766},{0.015423, 0.008128, -0.006351}}],
    Polygon[{{0.016535, 0.007128, -0.005766},{0.017386, 0.007128, -0.005040},{
      0.017139, 0.008685, -0.005040},{0.016330, 0.008422, -0.005766}}],
    Polygon[{{0.017386, 0.007128, -0.005040},{0.018112, 0.007128, -0.004190},{
      0.017830, 0.008910, -0.004190},{0.017139, 0.008685, -0.005040}}],
    Polygon[{{0.018112, 0.007128, -0.004190},{0.018697, 0.007128, -0.003236},{
      0.018386, 0.009090, -0.003236},{0.017830, 0.008910, -0.004190}}],
    Polygon[{{0.018697, 0.007128, -0.003236},{0.019125, 0.007128, -0.002203},{
      0.018793, 0.009223, -0.002203},{0.018386, 0.009090, -0.003236}}],
    Polygon[{{0.019125, 0.007128, -0.002203},{0.019386, 0.007128, -0.001115},{
      0.019041, 0.009303, -0.001115},{0.018793, 0.009223, -0.002203}}],
    Polygon[{{0.019386, 0.007128, -0.001115},{0.019473, 0.007128, 0.000000},{
      0.019125, 0.009330, 0.000000},{0.019041, 0.009303, -0.001115}}],
    Polygon[{{0.019473, 0.007128, 0.000000},{0.019386, 0.007128, 0.001115},{
      0.019041, 0.009303, 0.001115},{0.019125, 0.009330, 0.000000}}],
    Polygon[{{0.019386, 0.007128, 0.001115},{0.019125, 0.007128, 0.002203},{
      0.018793, 0.009223, 0.002203},{0.019041, 0.009303, 0.001115}}],
    Polygon[{{0.019125, 0.007128, 0.002203},{0.018697, 0.007128, 0.003236},{
      0.018386, 0.009090, 0.003236},{0.018793, 0.009223, 0.002203}}],
    Polygon[{{0.018697, 0.007128, 0.003236},{0.018112, 0.007128, 0.004190},{
      0.017830, 0.008910, 0.004190},{0.018386, 0.009090, 0.003236}}],
    Polygon[{{0.018112, 0.007128, 0.004190},{0.017386, 0.007128, 0.005040},{
      0.017139, 0.008685, 0.005040},{0.017830, 0.008910, 0.004190}}],
    Polygon[{{0.017386, 0.007128, 0.005040},{0.016535, 0.007128, 0.005766},{
      0.016330, 0.008422, 0.005766},{0.017139, 0.008685, 0.005040}}],
    Polygon[{{0.016535, 0.007128, 0.005766},{0.015582, 0.007128, 0.006351},{
      0.015423, 0.008128, 0.006351},{0.016330, 0.008422, 0.005766}}],
    Polygon[{{0.015582, 0.007128, 0.006351},{0.014548, 0.007128, 0.006779},{
      0.014440, 0.007808, 0.006779},{0.015423, 0.008128, 0.006351}}],
    Polygon[{{0.014548, 0.007128, 0.006779},{0.013461, 0.007128, 0.007040},{
      0.013406, 0.007472, 0.007040},{0.014440, 0.007808, 0.006779}}],
    Polygon[{{0.013406, 0.007472, -0.007040},{0.014440, 0.007808, -0.006779},{
      0.014128, 0.008422, -0.006779},{0.013248, 0.007783, -0.007040}}],
    Polygon[{{0.014440, 0.007808, -0.006779},{0.015423, 0.008128, -0.006351},{
      0.014964, 0.009030, -0.006351},{0.014128, 0.008422, -0.006779}}],
    Polygon[{{0.015423, 0.008128, -0.006351},{0.016330, 0.008422, -0.005766},{
      0.015735, 0.009590, -0.005766},{0.014964, 0.009030, -0.006351}}],
    Polygon[{{0.016330, 0.008422, -0.005766},{0.017139, 0.008685, -0.005040},{
      0.016423, 0.010090, -0.005040},{0.015735, 0.009590, -0.005766}}],
    Polygon[{{0.017139, 0.008685, -0.005040},{0.017830, 0.008910, -0.004190},{
      0.017011, 0.010517, -0.004190},{0.016423, 0.010090, -0.005040}}],
    Polygon[{{0.017830, 0.008910, -0.004190},{0.018386, 0.009090, -0.003236},{
      0.017484, 0.010861, -0.003236},{0.017011, 0.010517, -0.004190}}],
    Polygon[{{0.018386, 0.009090, -0.003236},{0.018793, 0.009223, -0.002203},{
      0.017830, 0.011112, -0.002203},{0.017484, 0.010861, -0.003236}}],
    Polygon[{{0.018793, 0.009223, -0.002203},{0.019041, 0.009303, -0.001115},{
      0.018041, 0.011266, -0.001115},{0.017830, 0.011112, -0.002203}}],
    Polygon[{{0.019041, 0.009303, -0.001115},{0.019125, 0.009330, 0.000000},{
      0.018112, 0.011317, 0.000000},{0.018041, 0.011266, -0.001115}}],
    Polygon[{{0.019125, 0.009330, 0.000000},{0.019041, 0.009303, 0.001115},{
      0.018041, 0.011266, 0.001115},{0.018112, 0.011317, 0.000000}}],
    Polygon[{{0.019041, 0.009303, 0.001115},{0.018793, 0.009223, 0.002203},{
      0.017830, 0.011112, 0.002203},{0.018041, 0.011266, 0.001115}}],
    Polygon[{{0.018793, 0.009223, 0.002203},{0.018386, 0.009090, 0.003236},{
      0.017484, 0.010861, 0.003236},{0.017830, 0.011112, 0.002203}}],
    Polygon[{{0.018386, 0.009090, 0.003236},{0.017830, 0.008910, 0.004190},{
      0.017011, 0.010517, 0.004190},{0.017484, 0.010861, 0.003236}}],
    Polygon[{{0.017830, 0.008910, 0.004190},{0.017139, 0.008685, 0.005040},{
      0.016423, 0.010090, 0.005040},{0.017011, 0.010517, 0.004190}}],
    Polygon[{{0.017139, 0.008685, 0.005040},{0.016330, 0.008422, 0.005766},{
      0.015735, 0.009590, 0.005766},{0.016423, 0.010090, 0.005040}}],
    Polygon[{{0.016330, 0.008422, 0.005766},{0.015423, 0.008128, 0.006351},{
      0.014964, 0.009030, 0.006351},{0.015735, 0.009590, 0.005766}}],
    Polygon[{{0.015423, 0.008128, 0.006351},{0.014440, 0.007808, 0.006779},{
      0.014128, 0.008422, 0.006779},{0.014964, 0.009030, 0.006351}}],
    Polygon[{{0.014440, 0.007808, 0.006779},{0.013406, 0.007472, 0.007040},{
      0.013248, 0.007783, 0.007040},{0.014128, 0.008422, 0.006779}}],
    Polygon[{{0.013248, 0.007783, -0.007040},{0.014128, 0.008422, -0.006779},{
      0.013640, 0.008910, -0.006779},{0.013001, 0.008030, -0.007040}}],
    Polygon[{{0.014128, 0.008422, -0.006779},{0.014964, 0.009030, -0.006351},{
      0.014248, 0.009746, -0.006351},{0.013640, 0.008910, -0.006779}}],
    Polygon[{{0.014964, 0.009030, -0.006351},{0.015735, 0.009590, -0.005766},{
      0.014808, 0.010517, -0.005766},{0.014248, 0.009746, -0.006351}}],
    Polygon[{{0.015735, 0.009590, -0.005766},{0.016423, 0.010090, -0.005040},{
      0.015308, 0.011205, -0.005040},{0.014808, 0.010517, -0.005766}}],
    Polygon[{{0.016423, 0.010090, -0.005040},{0.017011, 0.010517, -0.004190},{
      0.015735, 0.011793, -0.004190},{0.015308, 0.011205, -0.005040}}],
    Polygon[{{0.017011, 0.010517, -0.004190},{0.017484, 0.010861, -0.003236},{
      0.016079, 0.012266, -0.003236},{0.015735, 0.011793, -0.004190}}],
    Polygon[{{0.017484, 0.010861, -0.003236},{0.017830, 0.011112, -0.002203},{
      0.016330, 0.012612, -0.002203},{0.016079, 0.012266, -0.003236}}],
    Polygon[{{0.017830, 0.011112, -0.002203},{0.018041, 0.011266, -0.001115},{
      0.016484, 0.012823, -0.001115},{0.016330, 0.012612, -0.002203}}],
    Polygon[{{0.018041, 0.011266, -0.001115},{0.018112, 0.011317, 0.000000},{
      0.016535, 0.012894, 0.000000},{0.016484, 0.012823, -0.001115}}],
    Polygon[{{0.018112, 0.011317, 0.000000},{0.018041, 0.011266, 0.001115},{
      0.016484, 0.012823, 0.001115},{0.016535, 0.012894, 0.000000}}],
    Polygon[{{0.018041, 0.011266, 0.001115},{0.017830, 0.011112, 0.002203},{
      0.016330, 0.012612, 0.002203},{0.016484, 0.012823, 0.001115}}],
    Polygon[{{0.017830, 0.011112, 0.002203},{0.017484, 0.010861, 0.003236},{
      0.016079, 0.012266, 0.003236},{0.016330, 0.012612, 0.002203}}],
    Polygon[{{0.017484, 0.010861, 0.003236},{0.017011, 0.010517, 0.004190},{
      0.015735, 0.011793, 0.004190},{0.016079, 0.012266, 0.003236}}],
    Polygon[{{0.017011, 0.010517, 0.004190},{0.016423, 0.010090, 0.005040},{
      0.015308, 0.011205, 0.005040},{0.015735, 0.011793, 0.004190}}],
    Polygon[{{0.016423, 0.010090, 0.005040},{0.015735, 0.009590, 0.005766},{
      0.014808, 0.010517, 0.005766},{0.015308, 0.011205, 0.005040}}],
    Polygon[{{0.015735, 0.009590, 0.005766},{0.014964, 0.009030, 0.006351},{
      0.014248, 0.009746, 0.006351},{0.014808, 0.010517, 0.005766}}],
    Polygon[{{0.014964, 0.009030, 0.006351},{0.014128, 0.008422, 0.006779},{
      0.013640, 0.008910, 0.006779},{0.014248, 0.009746, 0.006351}}],
    Polygon[{{0.014128, 0.008422, 0.006779},{0.013248, 0.007783, 0.007040},{
      0.013001, 0.008030, 0.007040},{0.013640, 0.008910, 0.006779}}],
    Polygon[{{0.013001, 0.008030, -0.007040},{0.013640, 0.008910, -0.006779},{
      0.013026, 0.009223, -0.006779},{0.012690, 0.008188, -0.007040}}],
    Polygon[{{0.013640, 0.008910, -0.006779},{0.014248, 0.009746, -0.006351},{
      0.013346, 0.010205, -0.006351},{0.013026, 0.009223, -0.006779}}],
    Polygon[{{0.014248, 0.009746, -0.006351},{0.014808, 0.010517, -0.005766},{
      0.013640, 0.011112, -0.005766},{0.013346, 0.010205, -0.006351}}],
    Polygon[{{0.014808, 0.010517, -0.005766},{0.015308, 0.011205, -0.005040},{
      0.013903, 0.011921, -0.005040},{0.013640, 0.011112, -0.005766}}],
    Polygon[{{0.015308, 0.011205, -0.005040},{0.015735, 0.011793, -0.004190},{
      0.014128, 0.012612, -0.004190},{0.013903, 0.011921, -0.005040}}],
    Polygon[{{0.015735, 0.011793, -0.004190},{0.016079, 0.012266, -0.003236},{
      0.014308, 0.013168, -0.003236},{0.014128, 0.012612, -0.004190}}],
    Polygon[{{0.016079, 0.012266, -0.003236},{0.016330, 0.012612, -0.002203},{
      0.014440, 0.013575, -0.002203},{0.014308, 0.013168, -0.003236}}],
    Polygon[{{0.016330, 0.012612, -0.002203},{0.016484, 0.012823, -0.001115},{
      0.014521, 0.013823, -0.001115},{0.014440, 0.013575, -0.002203}}],
    Polygon[{{0.016484, 0.012823, -0.001115},{0.016535, 0.012894, 0.000000},{
      0.014548, 0.013907, 0.000000},{0.014521, 0.013823, -0.001115}}],
    Polygon[{{0.016535, 0.012894, 0.000000},{0.016484, 0.012823, 0.001115},{
      0.014521, 0.013823, 0.001115},{0.014548, 0.013907, 0.000000}}],
    Polygon[{{0.016484, 0.012823, 0.001115},{0.016330, 0.012612, 0.002203},{
      0.014440, 0.013575, 0.002203},{0.014521, 0.013823, 0.001115}}],
    Polygon[{{0.016330, 0.012612, 0.002203},{0.016079, 0.012266, 0.003236},{
      0.014308, 0.013168, 0.003236},{0.014440, 0.013575, 0.002203}}],
    Polygon[{{0.016079, 0.012266, 0.003236},{0.015735, 0.011793, 0.004190},{
      0.014128, 0.012612, 0.004190},{0.014308, 0.013168, 0.003236}}],
    Polygon[{{0.015735, 0.011793, 0.004190},{0.015308, 0.011205, 0.005040},{
      0.013903, 0.011921, 0.005040},{0.014128, 0.012612, 0.004190}}],
    Polygon[{{0.015308, 0.011205, 0.005040},{0.014808, 0.010517, 0.005766},{
      0.013640, 0.011112, 0.005766},{0.013903, 0.011921, 0.005040}}],
    Polygon[{{0.014808, 0.010517, 0.005766},{0.014248, 0.009746, 0.006351},{
      0.013346, 0.010205, 0.006351},{0.013640, 0.011112, 0.005766}}],
    Polygon[{{0.014248, 0.009746, 0.006351},{0.013640, 0.008910, 0.006779},{
      0.013026, 0.009223, 0.006779},{0.013346, 0.010205, 0.006351}}],
    Polygon[{{0.013640, 0.008910, 0.006779},{0.013001, 0.008030, 0.007040},{
      0.012690, 0.008188, 0.007040},{0.013026, 0.009223, 0.006779}}],
    Polygon[{{0.012690, 0.008188, -0.007040},{0.013026, 0.009223, -0.006779},{
      0.012346, 0.009330, -0.006779},{0.012346, 0.008243, -0.007040}}],
    Polygon[{{0.013026, 0.009223, -0.006779},{0.013346, 0.010205, -0.006351},{
      0.012346, 0.010364, -0.006351},{0.012346, 0.009330, -0.006779}}],
    Polygon[{{0.013346, 0.010205, -0.006351},{0.013640, 0.011112, -0.005766},{
      0.012346, 0.011317, -0.005766},{0.012346, 0.010364, -0.006351}}],
    Polygon[{{0.013640, 0.011112, -0.005766},{0.013903, 0.011921, -0.005040},{
      0.012346, 0.012168, -0.005040},{0.012346, 0.011317, -0.005766}}],
    Polygon[{{0.013903, 0.011921, -0.005040},{0.014128, 0.012612, -0.004190},{
      0.012346, 0.012894, -0.004190},{0.012346, 0.012168, -0.005040}}],
    Polygon[{{0.014128, 0.012612, -0.004190},{0.014308, 0.013168, -0.003236},{
      0.012346, 0.013479, -0.003236},{0.012346, 0.012894, -0.004190}}],
    Polygon[{{0.014308, 0.013168, -0.003236},{0.014440, 0.013575, -0.002203},{
      0.012346, 0.013907, -0.002203},{0.012346, 0.013479, -0.003236}}],
    Polygon[{{0.014440, 0.013575, -0.002203},{0.014521, 0.013823, -0.001115},{
      0.012346, 0.014168, -0.001115},{0.012346, 0.013907, -0.002203}}],
    Polygon[{{0.014521, 0.013823, -0.001115},{0.014548, 0.013907, 0.000000},{
      0.012346, 0.014256, 0.000000},{0.012346, 0.014168, -0.001115}}],
    Polygon[{{0.014548, 0.013907, 0.000000},{0.014521, 0.013823, 0.001115},{
      0.012346, 0.014168, 0.001115},{0.012346, 0.014256, 0.000000}}],
    Polygon[{{0.014521, 0.013823, 0.001115},{0.014440, 0.013575, 0.002203},{
      0.012346, 0.013907, 0.002203},{0.012346, 0.014168, 0.001115}}],
    Polygon[{{0.014440, 0.013575, 0.002203},{0.014308, 0.013168, 0.003236},{
      0.012346, 0.013479, 0.003236},{0.012346, 0.013907, 0.002203}}],
    Polygon[{{0.014308, 0.013168, 0.003236},{0.014128, 0.012612, 0.004190},{
      0.012346, 0.012894, 0.004190},{0.012346, 0.013479, 0.003236}}],
    Polygon[{{0.014128, 0.012612, 0.004190},{0.013903, 0.011921, 0.005040},{
      0.012346, 0.012168, 0.005040},{0.012346, 0.012894, 0.004190}}],
    Polygon[{{0.013903, 0.011921, 0.005040},{0.013640, 0.011112, 0.005766},{
      0.012346, 0.011317, 0.005766},{0.012346, 0.012168, 0.005040}}],
    Polygon[{{0.013640, 0.011112, 0.005766},{0.013346, 0.010205, 0.006351},{
      0.012346, 0.010364, 0.006351},{0.012346, 0.011317, 0.005766}}],
    Polygon[{{0.013346, 0.010205, 0.006351},{0.013026, 0.009223, 0.006779},{
      0.012346, 0.009330, 0.006779},{0.012346, 0.010364, 0.006351}}],
    Polygon[{{0.013026, 0.009223, 0.006779},{0.012690, 0.008188, 0.007040},{
      0.012346, 0.008243, 0.007040},{0.012346, 0.009330, 0.006779}}],
    Polygon[{{0.012346, 0.008243, -0.007040},{0.012346, 0.009330, -0.006779},{
      0.011665, 0.009223, -0.006779},{0.012001, 0.008188, -0.007040}}],
    Polygon[{{0.012346, 0.009330, -0.006779},{0.012346, 0.010364, -0.006351},{
      0.011346, 0.010205, -0.006351},{0.011665, 0.009223, -0.006779}}],
    Polygon[{{0.012346, 0.010364, -0.006351},{0.012346, 0.011317, -0.005766},{
      0.011051, 0.011112, -0.005766},{0.011346, 0.010205, -0.006351}}],
    Polygon[{{0.012346, 0.011317, -0.005766},{0.012346, 0.012168, -0.005040},{
      0.010788, 0.011921, -0.005040},{0.011051, 0.011112, -0.005766}}],
    Polygon[{{0.012346, 0.012168, -0.005040},{0.012346, 0.012894, -0.004190},{
      0.010564, 0.012612, -0.004190},{0.010788, 0.011921, -0.005040}}],
    Polygon[{{0.012346, 0.012894, -0.004190},{0.012346, 0.013479, -0.003236},{
      0.010383, 0.013168, -0.003236},{0.010564, 0.012612, -0.004190}}],
    Polygon[{{0.012346, 0.013479, -0.003236},{0.012346, 0.013907, -0.002203},{
      0.010251, 0.013575, -0.002203},{0.010383, 0.013168, -0.003236}}],
    Polygon[{{0.012346, 0.013907, -0.002203},{0.012346, 0.014168, -0.001115},{
      0.010170, 0.013823, -0.001115},{0.010251, 0.013575, -0.002203}}],
    Polygon[{{0.012346, 0.014168, -0.001115},{0.012346, 0.014256, 0.000000},{
      0.010143, 0.013907, 0.000000},{0.010170, 0.013823, -0.001115}}],
    Polygon[{{0.012346, 0.014256, 0.000000},{0.012346, 0.014168, 0.001115},{
      0.010170, 0.013823, 0.001115},{0.010143, 0.013907, 0.000000}}],
    Polygon[{{0.012346, 0.014168, 0.001115},{0.012346, 0.013907, 0.002203},{
      0.010251, 0.013575, 0.002203},{0.010170, 0.013823, 0.001115}}],
    Polygon[{{0.012346, 0.013907, 0.002203},{0.012346, 0.013479, 0.003236},{
      0.010383, 0.013168, 0.003236},{0.010251, 0.013575, 0.002203}}],
    Polygon[{{0.012346, 0.013479, 0.003236},{0.012346, 0.012894, 0.004190},{
      0.010564, 0.012612, 0.004190},{0.010383, 0.013168, 0.003236}}],
    Polygon[{{0.012346, 0.012894, 0.004190},{0.012346, 0.012168, 0.005040},{
      0.010788, 0.011921, 0.005040},{0.010564, 0.012612, 0.004190}}],
    Polygon[{{0.012346, 0.012168, 0.005040},{0.012346, 0.011317, 0.005766},{
      0.011051, 0.011112, 0.005766},{0.010788, 0.011921, 0.005040}}],
    Polygon[{{0.012346, 0.011317, 0.005766},{0.012346, 0.010364, 0.006351},{
      0.011346, 0.010205, 0.006351},{0.011051, 0.011112, 0.005766}}],
    Polygon[{{0.012346, 0.010364, 0.006351},{0.012346, 0.009330, 0.006779},{
      0.011665, 0.009223, 0.006779},{0.011346, 0.010205, 0.006351}}],
    Polygon[{{0.012346, 0.009330, 0.006779},{0.012346, 0.008243, 0.007040},{
      0.012001, 0.008188, 0.007040},{0.011665, 0.009223, 0.006779}}],
    Polygon[{{0.012001, 0.008188, -0.007040},{0.011665, 0.009223, -0.006779},{
      0.011051, 0.008910, -0.006779},{0.011690, 0.008030, -0.007040}}],
    Polygon[{{0.011665, 0.009223, -0.006779},{0.011346, 0.010205, -0.006351},{
      0.010444, 0.009746, -0.006351},{0.011051, 0.008910, -0.006779}}],
    Polygon[{{0.011346, 0.010205, -0.006351},{0.011051, 0.011112, -0.005766},{
      0.009883, 0.010517, -0.005766},{0.010444, 0.009746, -0.006351}}],
    Polygon[{{0.011051, 0.011112, -0.005766},{0.010788, 0.011921, -0.005040},{
      0.009383, 0.011205, -0.005040},{0.009883, 0.010517, -0.005766}}],
    Polygon[{{0.010788, 0.011921, -0.005040},{0.010564, 0.012612, -0.004190},{
      0.008956, 0.011793, -0.004190},{0.009383, 0.011205, -0.005040}}],
    Polygon[{{0.010564, 0.012612, -0.004190},{0.010383, 0.013168, -0.003236},{
      0.008613, 0.012266, -0.003236},{0.008956, 0.011793, -0.004190}}],
    Polygon[{{0.010383, 0.013168, -0.003236},{0.010251, 0.013575, -0.002203},{
      0.008361, 0.012612, -0.002203},{0.008613, 0.012266, -0.003236}}],
    Polygon[{{0.010251, 0.013575, -0.002203},{0.010170, 0.013823, -0.001115},{
      0.008208, 0.012823, -0.001115},{0.008361, 0.012612, -0.002203}}],
    Polygon[{{0.010170, 0.013823, -0.001115},{0.010143, 0.013907, 0.000000},{
      0.008156, 0.012894, 0.000000},{0.008208, 0.012823, -0.001115}}],
    Polygon[{{0.010143, 0.013907, 0.000000},{0.010170, 0.013823, 0.001115},{
      0.008208, 0.012823, 0.001115},{0.008156, 0.012894, 0.000000}}],
    Polygon[{{0.010170, 0.013823, 0.001115},{0.010251, 0.013575, 0.002203},{
      0.008361, 0.012612, 0.002203},{0.008208, 0.012823, 0.001115}}],
    Polygon[{{0.010251, 0.013575, 0.002203},{0.010383, 0.013168, 0.003236},{
      0.008613, 0.012266, 0.003236},{0.008361, 0.012612, 0.002203}}],
    Polygon[{{0.010383, 0.013168, 0.003236},{0.010564, 0.012612, 0.004190},{
      0.008956, 0.011793, 0.004190},{0.008613, 0.012266, 0.003236}}],
    Polygon[{{0.010564, 0.012612, 0.004190},{0.010788, 0.011921, 0.005040},{
      0.009383, 0.011205, 0.005040},{0.008956, 0.011793, 0.004190}}],
    Polygon[{{0.010788, 0.011921, 0.005040},{0.011051, 0.011112, 0.005766},{
      0.009883, 0.010517, 0.005766},{0.009383, 0.011205, 0.005040}}],
    Polygon[{{0.011051, 0.011112, 0.005766},{0.011346, 0.010205, 0.006351},{
      0.010444, 0.009746, 0.006351},{0.009883, 0.010517, 0.005766}}],
    Polygon[{{0.011346, 0.010205, 0.006351},{0.011665, 0.009223, 0.006779},{
      0.011051, 0.008910, 0.006779},{0.010444, 0.009746, 0.006351}}],
    Polygon[{{0.011665, 0.009223, 0.006779},{0.012001, 0.008188, 0.007040},{
      0.011690, 0.008030, 0.007040},{0.011051, 0.008910, 0.006779}}],
    Polygon[{{0.011690, 0.008030, -0.007040},{0.011051, 0.008910, -0.006779},{
      0.010564, 0.008422, -0.006779},{0.011444, 0.007783, -0.007040}}],
    Polygon[{{0.011051, 0.008910, -0.006779},{0.010444, 0.009746, -0.006351},{
      0.009728, 0.009030, -0.006351},{0.010564, 0.008422, -0.006779}}],
    Polygon[{{0.010444, 0.009746, -0.006351},{0.009883, 0.010517, -0.005766},{
      0.008956, 0.009590, -0.005766},{0.009728, 0.009030, -0.006351}}],
    Polygon[{{0.009883, 0.010517, -0.005766},{0.009383, 0.011205, -0.005040},{
      0.008268, 0.010090, -0.005040},{0.008956, 0.009590, -0.005766}}],
    Polygon[{{0.009383, 0.011205, -0.005040},{0.008956, 0.011793, -0.004190},{
      0.007680, 0.010517, -0.004190},{0.008268, 0.010090, -0.005040}}],
    Polygon[{{0.008956, 0.011793, -0.004190},{0.008613, 0.012266, -0.003236},{
      0.007208, 0.010861, -0.003236},{0.007680, 0.010517, -0.004190}}],
    Polygon[{{0.008613, 0.012266, -0.003236},{0.008361, 0.012612, -0.002203},{
      0.006861, 0.011112, -0.002203},{0.007208, 0.010861, -0.003236}}],
    Polygon[{{0.008361, 0.012612, -0.002203},{0.008208, 0.012823, -0.001115},{
      0.006650, 0.011266, -0.001115},{0.006861, 0.011112, -0.002203}}],
    Polygon[{{0.008208, 0.012823, -0.001115},{0.008156, 0.012894, 0.000000},{
      0.006579, 0.011317, 0.000000},{0.006650, 0.011266, -0.001115}}],
    Polygon[{{0.008156, 0.012894, 0.000000},{0.008208, 0.012823, 0.001115},{
      0.006650, 0.011266, 0.001115},{0.006579, 0.011317, 0.000000}}],
    Polygon[{{0.008208, 0.012823, 0.001115},{0.008361, 0.012612, 0.002203},{
      0.006861, 0.011112, 0.002203},{0.006650, 0.011266, 0.001115}}],
    Polygon[{{0.008361, 0.012612, 0.002203},{0.008613, 0.012266, 0.003236},{
      0.007208, 0.010861, 0.003236},{0.006861, 0.011112, 0.002203}}],
    Polygon[{{0.008613, 0.012266, 0.003236},{0.008956, 0.011793, 0.004190},{
      0.007680, 0.010517, 0.004190},{0.007208, 0.010861, 0.003236}}],
    Polygon[{{0.008956, 0.011793, 0.004190},{0.009383, 0.011205, 0.005040},{
      0.008268, 0.010090, 0.005040},{0.007680, 0.010517, 0.004190}}],
    Polygon[{{0.009383, 0.011205, 0.005040},{0.009883, 0.010517, 0.005766},{
      0.008956, 0.009590, 0.005766},{0.008268, 0.010090, 0.005040}}],
    Polygon[{{0.009883, 0.010517, 0.005766},{0.010444, 0.009746, 0.006351},{
      0.009728, 0.009030, 0.006351},{0.008956, 0.009590, 0.005766}}],
    Polygon[{{0.010444, 0.009746, 0.006351},{0.011051, 0.008910, 0.006779},{
      0.010564, 0.008422, 0.006779},{0.009728, 0.009030, 0.006351}}],
    Polygon[{{0.011051, 0.008910, 0.006779},{0.011690, 0.008030, 0.007040},{
      0.011444, 0.007783, 0.007040},{0.010564, 0.008422, 0.006779}}],
    Polygon[{{0.011444, 0.007783, -0.007040},{0.010564, 0.008422, -0.006779},{
      0.010251, 0.007808, -0.006779},{0.011285, 0.007472, -0.007040}}],
    Polygon[{{0.010564, 0.008422, -0.006779},{0.009728, 0.009030, -0.006351},{
      0.009268, 0.008128, -0.006351},{0.010251, 0.007808, -0.006779}}],
    Polygon[{{0.009728, 0.009030, -0.006351},{0.008956, 0.009590, -0.005766},{
      0.008361, 0.008422, -0.005766},{0.009268, 0.008128, -0.006351}}],
    Polygon[{{0.008956, 0.009590, -0.005766},{0.008268, 0.010090, -0.005040},{
      0.007552, 0.008685, -0.005040},{0.008361, 0.008422, -0.005766}}],
    Polygon[{{0.008268, 0.010090, -0.005040},{0.007680, 0.010517, -0.004190},{
      0.006861, 0.008910, -0.004190},{0.007552, 0.008685, -0.005040}}],
    Polygon[{{0.007680, 0.010517, -0.004190},{0.007208, 0.010861, -0.003236},{
      0.006306, 0.009090, -0.003236},{0.006861, 0.008910, -0.004190}}],
    Polygon[{{0.007208, 0.010861, -0.003236},{0.006861, 0.011112, -0.002203},{
      0.005899, 0.009223, -0.002203},{0.006306, 0.009090, -0.003236}}],
    Polygon[{{0.006861, 0.011112, -0.002203},{0.006650, 0.011266, -0.001115},{
      0.005650, 0.009303, -0.001115},{0.005899, 0.009223, -0.002203}}],
    Polygon[{{0.006650, 0.011266, -0.001115},{0.006579, 0.011317, 0.000000},{
      0.005567, 0.009330, 0.000000},{0.005650, 0.009303, -0.001115}}],
    Polygon[{{0.006579, 0.011317, 0.000000},{0.006650, 0.011266, 0.001115},{
      0.005650, 0.009303, 0.001115},{0.005567, 0.009330, 0.000000}}],
    Polygon[{{0.006650, 0.011266, 0.001115},{0.006861, 0.011112, 0.002203},{
      0.005899, 0.009223, 0.002203},{0.005650, 0.009303, 0.001115}}],
    Polygon[{{0.006861, 0.011112, 0.002203},{0.007208, 0.010861, 0.003236},{
      0.006306, 0.009090, 0.003236},{0.005899, 0.009223, 0.002203}}],
    Polygon[{{0.007208, 0.010861, 0.003236},{0.007680, 0.010517, 0.004190},{
      0.006861, 0.008910, 0.004190},{0.006306, 0.009090, 0.003236}}],
    Polygon[{{0.007680, 0.010517, 0.004190},{0.008268, 0.010090, 0.005040},{
      0.007552, 0.008685, 0.005040},{0.006861, 0.008910, 0.004190}}],
    Polygon[{{0.008268, 0.010090, 0.005040},{0.008956, 0.009590, 0.005766},{
      0.008361, 0.008422, 0.005766},{0.007552, 0.008685, 0.005040}}],
    Polygon[{{0.008956, 0.009590, 0.005766},{0.009728, 0.009030, 0.006351},{
      0.009268, 0.008128, 0.006351},{0.008361, 0.008422, 0.005766}}],
    Polygon[{{0.009728, 0.009030, 0.006351},{0.010564, 0.008422, 0.006779},{
      0.010251, 0.007808, 0.006779},{0.009268, 0.008128, 0.006351}}],
    Polygon[{{0.010564, 0.008422, 0.006779},{0.011444, 0.007783, 0.007040},{
      0.011285, 0.007472, 0.007040},{0.010251, 0.007808, 0.006779}}],
    Polygon[{{0.011285, 0.007472, -0.007040},{0.010251, 0.007808, -0.006779},{
      0.010143, 0.007128, -0.006779},{0.011231, 0.007128, -0.007040}}],
    Polygon[{{0.010251, 0.007808, -0.006779},{0.009268, 0.008128, -0.006351},{
      0.009110, 0.007128, -0.006351},{0.010143, 0.007128, -0.006779}}],
    Polygon[{{0.009268, 0.008128, -0.006351},{0.008361, 0.008422, -0.005766},{
      0.008156, 0.007128, -0.005766},{0.009110, 0.007128, -0.006351}}],
    Polygon[{{0.008361, 0.008422, -0.005766},{0.007552, 0.008685, -0.005040},{
      0.007306, 0.007128, -0.005040},{0.008156, 0.007128, -0.005766}}],
    Polygon[{{0.007552, 0.008685, -0.005040},{0.006861, 0.008910, -0.004190},{
      0.006579, 0.007128, -0.004190},{0.007306, 0.007128, -0.005040}}],
    Polygon[{{0.006861, 0.008910, -0.004190},{0.006306, 0.009090, -0.003236},{
      0.005995, 0.007128, -0.003236},{0.006579, 0.007128, -0.004190}}],
    Polygon[{{0.006306, 0.009090, -0.003236},{0.005899, 0.009223, -0.002203},{
      0.005567, 0.007128, -0.002203},{0.005995, 0.007128, -0.003236}}],
    Polygon[{{0.005899, 0.009223, -0.002203},{0.005650, 0.009303, -0.001115},{
      0.005306, 0.007128, -0.001115},{0.005567, 0.007128, -0.002203}}],
    Polygon[{{0.005650, 0.009303, -0.001115},{0.005567, 0.009330, 0.000000},{
      0.005218, 0.007128, 0.000000},{0.005306, 0.007128, -0.001115}}],
    Polygon[{{0.005567, 0.009330, 0.000000},{0.005650, 0.009303, 0.001115},{
      0.005306, 0.007128, 0.001115},{0.005218, 0.007128, 0.000000}}],
    Polygon[{{0.005650, 0.009303, 0.001115},{0.005899, 0.009223, 0.002203},{
      0.005567, 0.007128, 0.002203},{0.005306, 0.007128, 0.001115}}],
    Polygon[{{0.005899, 0.009223, 0.002203},{0.006306, 0.009090, 0.003236},{
      0.005995, 0.007128, 0.003236},{0.005567, 0.007128, 0.002203}}],
    Polygon[{{0.006306, 0.009090, 0.003236},{0.006861, 0.008910, 0.004190},{
      0.006579, 0.007128, 0.004190},{0.005995, 0.007128, 0.003236}}],
    Polygon[{{0.006861, 0.008910, 0.004190},{0.007552, 0.008685, 0.005040},{
      0.007306, 0.007128, 0.005040},{0.006579, 0.007128, 0.004190}}],
    Polygon[{{0.007552, 0.008685, 0.005040},{0.008361, 0.008422, 0.005766},{
      0.008156, 0.007128, 0.005766},{0.007306, 0.007128, 0.005040}}],
    Polygon[{{0.008361, 0.008422, 0.005766},{0.009268, 0.008128, 0.006351},{
      0.009110, 0.007128, 0.006351},{0.008156, 0.007128, 0.005766}}],
    Polygon[{{0.009268, 0.008128, 0.006351},{0.010251, 0.007808, 0.006779},{
      0.010143, 0.007128, 0.006779},{0.009110, 0.007128, 0.006351}}],
    Polygon[{{0.010251, 0.007808, 0.006779},{0.011285, 0.007472, 0.007040},{
      0.011231, 0.007128, 0.007040},{0.010143, 0.007128, 0.006779}}],
    Polygon[{{0.011231, 0.007128, -0.007040},{0.010143, 0.007128, -0.006779},{
      0.010251, 0.006447, -0.006779},{0.011285, 0.006783, -0.007040}}],
    Polygon[{{0.010143, 0.007128, -0.006779},{0.009110, 0.007128, -0.006351},{
      0.009268, 0.006128, -0.006351},{0.010251, 0.006447, -0.006779}}],
    Polygon[{{0.009110, 0.007128, -0.006351},{0.008156, 0.007128, -0.005766},{
      0.008361, 0.005833, -0.005766},{0.009268, 0.006128, -0.006351}}],
    Polygon[{{0.008156, 0.007128, -0.005766},{0.007306, 0.007128, -0.005040},{
      0.007552, 0.005570, -0.005040},{0.008361, 0.005833, -0.005766}}],
    Polygon[{{0.007306, 0.007128, -0.005040},{0.006579, 0.007128, -0.004190},{
      0.006861, 0.005346, -0.004190},{0.007552, 0.005570, -0.005040}}],
    Polygon[{{0.006579, 0.007128, -0.004190},{0.005995, 0.007128, -0.003236},{
      0.006306, 0.005165, -0.003236},{0.006861, 0.005346, -0.004190}}],
    Polygon[{{0.005995, 0.007128, -0.003236},{0.005567, 0.007128, -0.002203},{
      0.005899, 0.005033, -0.002203},{0.006306, 0.005165, -0.003236}}],
    Polygon[{{0.005567, 0.007128, -0.002203},{0.005306, 0.007128, -0.001115},{
      0.005650, 0.004952, -0.001115},{0.005899, 0.005033, -0.002203}}],
    Polygon[{{0.005306, 0.007128, -0.001115},{0.005218, 0.007128, 0.000000},{
      0.005567, 0.004925, 0.000000},{0.005650, 0.004952, -0.001115}}],
    Polygon[{{0.005218, 0.007128, 0.000000},{0.005306, 0.007128, 0.001115},{
      0.005650, 0.004952, 0.001115},{0.005567, 0.004925, 0.000000}}],
    Polygon[{{0.005306, 0.007128, 0.001115},{0.005567, 0.007128, 0.002203},{
      0.005899, 0.005033, 0.002203},{0.005650, 0.004952, 0.001115}}],
    Polygon[{{0.005567, 0.007128, 0.002203},{0.005995, 0.007128, 0.003236},{
      0.006306, 0.005165, 0.003236},{0.005899, 0.005033, 0.002203}}],
    Polygon[{{0.005995, 0.007128, 0.003236},{0.006579, 0.007128, 0.004190},{
      0.006861, 0.005346, 0.004190},{0.006306, 0.005165, 0.003236}}],
    Polygon[{{0.006579, 0.007128, 0.004190},{0.007306, 0.007128, 0.005040},{
      0.007552, 0.005570, 0.005040},{0.006861, 0.005346, 0.004190}}],
    Polygon[{{0.007306, 0.007128, 0.005040},{0.008156, 0.007128, 0.005766},{
      0.008361, 0.005833, 0.005766},{0.007552, 0.005570, 0.005040}}],
    Polygon[{{0.008156, 0.007128, 0.005766},{0.009110, 0.007128, 0.006351},{
      0.009268, 0.006128, 0.006351},{0.008361, 0.005833, 0.005766}}],
    Polygon[{{0.009110, 0.007128, 0.006351},{0.010143, 0.007128, 0.006779},{
      0.010251, 0.006447, 0.006779},{0.009268, 0.006128, 0.006351}}],
    Polygon[{{0.010143, 0.007128, 0.006779},{0.011231, 0.007128, 0.007040},{
      0.011285, 0.006783, 0.007040},{0.010251, 0.006447, 0.006779}}],
    Polygon[{{0.011285, 0.006783, -0.007040},{0.010251, 0.006447, -0.006779},{
      0.010564, 0.005833, -0.006779},{0.011444, 0.006472, -0.007040}}],
    Polygon[{{0.010251, 0.006447, -0.006779},{0.009268, 0.006128, -0.006351},{
      0.009728, 0.005226, -0.006351},{0.010564, 0.005833, -0.006779}}],
    Polygon[{{0.009268, 0.006128, -0.006351},{0.008361, 0.005833, -0.005766},{
      0.008956, 0.004665, -0.005766},{0.009728, 0.005226, -0.006351}}],
    Polygon[{{0.008361, 0.005833, -0.005766},{0.007552, 0.005570, -0.005040},{
      0.008268, 0.004165, -0.005040},{0.008956, 0.004665, -0.005766}}],
    Polygon[{{0.007552, 0.005570, -0.005040},{0.006861, 0.005346, -0.004190},{
      0.007680, 0.003738, -0.004190},{0.008268, 0.004165, -0.005040}}],
    Polygon[{{0.006861, 0.005346, -0.004190},{0.006306, 0.005165, -0.003236},{
      0.007208, 0.003395, -0.003236},{0.007680, 0.003738, -0.004190}}],
    Polygon[{{0.006306, 0.005165, -0.003236},{0.005899, 0.005033, -0.002203},{
      0.006861, 0.003143, -0.002203},{0.007208, 0.003395, -0.003236}}],
    Polygon[{{0.005899, 0.005033, -0.002203},{0.005650, 0.004952, -0.001115},{
      0.006650, 0.002990, -0.001115},{0.006861, 0.003143, -0.002203}}],
    Polygon[{{0.005650, 0.004952, -0.001115},{0.005567, 0.004925, 0.000000},{
      0.006579, 0.002938, 0.000000},{0.006650, 0.002990, -0.001115}}],
    Polygon[{{0.005567, 0.004925, 0.000000},{0.005650, 0.004952, 0.001115},{
      0.006650, 0.002990, 0.001115},{0.006579, 0.002938, 0.000000}}],
    Polygon[{{0.005650, 0.004952, 0.001115},{0.005899, 0.005033, 0.002203},{
      0.006861, 0.003143, 0.002203},{0.006650, 0.002990, 0.001115}}],
    Polygon[{{0.005899, 0.005033, 0.002203},{0.006306, 0.005165, 0.003236},{
      0.007208, 0.003395, 0.003236},{0.006861, 0.003143, 0.002203}}],
    Polygon[{{0.006306, 0.005165, 0.003236},{0.006861, 0.005346, 0.004190},{
      0.007680, 0.003738, 0.004190},{0.007208, 0.003395, 0.003236}}],
    Polygon[{{0.006861, 0.005346, 0.004190},{0.007552, 0.005570, 0.005040},{
      0.008268, 0.004165, 0.005040},{0.007680, 0.003738, 0.004190}}],
    Polygon[{{0.007552, 0.005570, 0.005040},{0.008361, 0.005833, 0.005766},{
      0.008956, 0.004665, 0.005766},{0.008268, 0.004165, 0.005040}}],
    Polygon[{{0.008361, 0.005833, 0.005766},{0.009268, 0.006128, 0.006351},{
      0.009728, 0.005226, 0.006351},{0.008956, 0.004665, 0.005766}}],
    Polygon[{{0.009268, 0.006128, 0.006351},{0.010251, 0.006447, 0.006779},{
      0.010564, 0.005833, 0.006779},{0.009728, 0.005226, 0.006351}}],
    Polygon[{{0.010251, 0.006447, 0.006779},{0.011285, 0.006783, 0.007040},{
      0.011444, 0.006472, 0.007040},{0.010564, 0.005833, 0.006779}}],
    Polygon[{{0.011444, 0.006472, -0.007040},{0.010564, 0.005833, -0.006779},{
      0.011051, 0.005346, -0.006779},{0.011690, 0.006226, -0.007040}}],
    Polygon[{{0.010564, 0.005833, -0.006779},{0.009728, 0.005226, -0.006351},{
      0.010444, 0.004510, -0.006351},{0.011051, 0.005346, -0.006779}}],
    Polygon[{{0.009728, 0.005226, -0.006351},{0.008956, 0.004665, -0.005766},{
      0.009883, 0.003738, -0.005766},{0.010444, 0.004510, -0.006351}}],
    Polygon[{{0.008956, 0.004665, -0.005766},{0.008268, 0.004165, -0.005040},{
      0.009383, 0.003050, -0.005040},{0.009883, 0.003738, -0.005766}}],
    Polygon[{{0.008268, 0.004165, -0.005040},{0.007680, 0.003738, -0.004190},{
      0.008956, 0.002463, -0.004190},{0.009383, 0.003050, -0.005040}}],
    Polygon[{{0.007680, 0.003738, -0.004190},{0.007208, 0.003395, -0.003236},{
      0.008613, 0.001990, -0.003236},{0.008956, 0.002463, -0.004190}}],
    Polygon[{{0.007208, 0.003395, -0.003236},{0.006861, 0.003143, -0.002203},{
      0.008361, 0.001644, -0.002203},{0.008613, 0.001990, -0.003236}}],
    Polygon[{{0.006861, 0.003143, -0.002203},{0.006650, 0.002990, -0.001115},{
      0.008208, 0.001432, -0.001115},{0.008361, 0.001644, -0.002203}}],
    Polygon[{{0.006650, 0.002990, -0.001115},{0.006579, 0.002938, 0.000000},{
      0.008156, 0.001361, 0.000000},{0.008208, 0.001432, -0.001115}}],
    Polygon[{{0.006579, 0.002938, 0.000000},{0.006650, 0.002990, 0.001115},{
      0.008208, 0.001432, 0.001115},{0.008156, 0.001361, 0.000000}}],
    Polygon[{{0.006650, 0.002990, 0.001115},{0.006861, 0.003143, 0.002203},{
      0.008361, 0.001644, 0.002203},{0.008208, 0.001432, 0.001115}}],
    Polygon[{{0.006861, 0.003143, 0.002203},{0.007208, 0.003395, 0.003236},{
      0.008613, 0.001990, 0.003236},{0.008361, 0.001644, 0.002203}}],
    Polygon[{{0.007208, 0.003395, 0.003236},{0.007680, 0.003738, 0.004190},{
      0.008956, 0.002463, 0.004190},{0.008613, 0.001990, 0.003236}}],
    Polygon[{{0.007680, 0.003738, 0.004190},{0.008268, 0.004165, 0.005040},{
      0.009383, 0.003050, 0.005040},{0.008956, 0.002463, 0.004190}}],
    Polygon[{{0.008268, 0.004165, 0.005040},{0.008956, 0.004665, 0.005766},{
      0.009883, 0.003738, 0.005766},{0.009383, 0.003050, 0.005040}}],
    Polygon[{{0.008956, 0.004665, 0.005766},{0.009728, 0.005226, 0.006351},{
      0.010444, 0.004510, 0.006351},{0.009883, 0.003738, 0.005766}}],
    Polygon[{{0.009728, 0.005226, 0.006351},{0.010564, 0.005833, 0.006779},{
      0.011051, 0.005346, 0.006779},{0.010444, 0.004510, 0.006351}}],
    Polygon[{{0.010564, 0.005833, 0.006779},{0.011444, 0.006472, 0.007040},{
      0.011690, 0.006226, 0.007040},{0.011051, 0.005346, 0.006779}}],
    Polygon[{{0.011690, 0.006226, -0.007040},{0.011051, 0.005346, -0.006779},{
      0.011665, 0.005033, -0.006779},{0.012001, 0.006067, -0.007040}}],
    Polygon[{{0.011051, 0.005346, -0.006779},{0.010444, 0.004510, -0.006351},{
      0.011346, 0.004050, -0.006351},{0.011665, 0.005033, -0.006779}}],
    Polygon[{{0.010444, 0.004510, -0.006351},{0.009883, 0.003738, -0.005766},{
      0.011051, 0.003143, -0.005766},{0.011346, 0.004050, -0.006351}}],
    Polygon[{{0.009883, 0.003738, -0.005766},{0.009383, 0.003050, -0.005040},{
      0.010788, 0.002334, -0.005040},{0.011051, 0.003143, -0.005766}}],
    Polygon[{{0.009383, 0.003050, -0.005040},{0.008956, 0.002463, -0.004190},{
      0.010564, 0.001644, -0.004190},{0.010788, 0.002334, -0.005040}}],
    Polygon[{{0.008956, 0.002463, -0.004190},{0.008613, 0.001990, -0.003236},{
      0.010383, 0.001088, -0.003236},{0.010564, 0.001644, -0.004190}}],
    Polygon[{{0.008613, 0.001990, -0.003236},{0.008361, 0.001644, -0.002203},{
      0.010251, 0.000681, -0.002203},{0.010383, 0.001088, -0.003236}}],
    Polygon[{{0.008361, 0.001644, -0.002203},{0.008208, 0.001432, -0.001115},{
      0.010170, 0.000432, -0.001115},{0.010251, 0.000681, -0.002203}}],
    Polygon[{{0.008208, 0.001432, -0.001115},{0.008156, 0.001361, 0.000000},{
      0.010143, 0.000349, 0.000000},{0.010170, 0.000432, -0.001115}}],
    Polygon[{{0.008156, 0.001361, 0.000000},{0.008208, 0.001432, 0.001115},{
      0.010170, 0.000432, 0.001115},{0.010143, 0.000349, 0.000000}}],
    Polygon[{{0.008208, 0.001432, 0.001115},{0.008361, 0.001644, 0.002203},{
      0.010251, 0.000681, 0.002203},{0.010170, 0.000432, 0.001115}}],
    Polygon[{{0.008361, 0.001644, 0.002203},{0.008613, 0.001990, 0.003236},{
      0.010383, 0.001088, 0.003236},{0.010251, 0.000681, 0.002203}}],
    Polygon[{{0.008613, 0.001990, 0.003236},{0.008956, 0.002463, 0.004190},{
      0.010564, 0.001644, 0.004190},{0.010383, 0.001088, 0.003236}}],
    Polygon[{{0.008956, 0.002463, 0.004190},{0.009383, 0.003050, 0.005040},{
      0.010788, 0.002334, 0.005040},{0.010564, 0.001644, 0.004190}}],
    Polygon[{{0.009383, 0.003050, 0.005040},{0.009883, 0.003738, 0.005766},{
      0.011051, 0.003143, 0.005766},{0.010788, 0.002334, 0.005040}}],
    Polygon[{{0.009883, 0.003738, 0.005766},{0.010444, 0.004510, 0.006351},{
      0.011346, 0.004050, 0.006351},{0.011051, 0.003143, 0.005766}}],
    Polygon[{{0.010444, 0.004510, 0.006351},{0.011051, 0.005346, 0.006779},{
      0.011665, 0.005033, 0.006779},{0.011346, 0.004050, 0.006351}}],
    Polygon[{{0.011051, 0.005346, 0.006779},{0.011690, 0.006226, 0.007040},{
      0.012001, 0.006067, 0.007040},{0.011665, 0.005033, 0.006779}}],
    Polygon[{{0.012001, 0.006067, -0.007040},{0.011665, 0.005033, -0.006779},{
      0.012346, 0.004925, -0.006779},{0.012346, 0.006013, -0.007040}}],
    Polygon[{{0.011665, 0.005033, -0.006779},{0.011346, 0.004050, -0.006351},{
      0.012346, 0.003892, -0.006351},{0.012346, 0.004925, -0.006779}}],
    Polygon[{{0.011346, 0.004050, -0.006351},{0.011051, 0.003143, -0.005766},{
      0.012346, 0.002938, -0.005766},{0.012346, 0.003892, -0.006351}}],
    Polygon[{{0.011051, 0.003143, -0.005766},{0.010788, 0.002334, -0.005040},{
      0.012346, 0.002088, -0.005040},{0.012346, 0.002938, -0.005766}}],
    Polygon[{{0.010788, 0.002334, -0.005040},{0.010564, 0.001644, -0.004190},{
      0.012346, 0.001361, -0.004190},{0.012346, 0.002088, -0.005040}}],
    Polygon[{{0.010564, 0.001644, -0.004190},{0.010383, 0.001088, -0.003236},{
      0.012346, 0.000777, -0.003236},{0.012346, 0.001361, -0.004190}}],
    Polygon[{{0.010383, 0.001088, -0.003236},{0.010251, 0.000681, -0.002203},{
      0.012346, 0.000349, -0.002203},{0.012346, 0.000777, -0.003236}}],
    Polygon[{{0.010251, 0.000681, -0.002203},{0.010170, 0.000432, -0.001115},{
      0.012346, 0.000088, -0.001115},{0.012346, 0.000349, -0.002203}}],
    Polygon[{{0.010170, 0.000432, -0.001115},{0.010143, 0.000349, 0.000000},{
      0.012346, 0.000000, 0.000000},{0.012346, 0.000088, -0.001115}}],
    Polygon[{{0.010143, 0.000349, 0.000000},{0.010170, 0.000432, 0.001115},{
      0.012346, 0.000088, 0.001115},{0.012346, 0.000000, 0.000000}}],
    Polygon[{{0.010170, 0.000432, 0.001115},{0.010251, 0.000681, 0.002203},{
      0.012346, 0.000349, 0.002203},{0.012346, 0.000088, 0.001115}}],
    Polygon[{{0.010251, 0.000681, 0.002203},{0.010383, 0.001088, 0.003236},{
      0.012346, 0.000777, 0.003236},{0.012346, 0.000349, 0.002203}}],
    Polygon[{{0.010383, 0.001088, 0.003236},{0.010564, 0.001644, 0.004190},{
      0.012346, 0.001361, 0.004190},{0.012346, 0.000777, 0.003236}}],
    Polygon[{{0.010564, 0.001644, 0.004190},{0.010788, 0.002334, 0.005040},{
      0.012346, 0.002088, 0.005040},{0.012346, 0.001361, 0.004190}}],
    Polygon[{{0.010788, 0.002334, 0.005040},{0.011051, 0.003143, 0.005766},{
      0.012346, 0.002938, 0.005766},{0.012346, 0.002088, 0.005040}}],
    Polygon[{{0.011051, 0.003143, 0.005766},{0.011346, 0.004050, 0.006351},{
      0.012346, 0.003892, 0.006351},{0.012346, 0.002938, 0.005766}}],
    Polygon[{{0.011346, 0.004050, 0.006351},{0.011665, 0.005033, 0.006779},{
      0.012346, 0.004925, 0.006779},{0.012346, 0.003892, 0.006351}}],
    Polygon[{{0.011665, 0.005033, 0.006779},{0.012001, 0.006067, 0.007040},{
      0.012346, 0.006013, 0.007040},{0.012346, 0.004925, 0.006779}}],
    Polygon[{{0.012346, 0.006013, -0.007040},{0.012346, 0.004925, -0.006779},{
      0.013026, 0.005033, -0.006779},{0.012690, 0.006067, -0.007040}}],
    Polygon[{{0.012346, 0.004925, -0.006779},{0.012346, 0.003892, -0.006351},{
      0.013346, 0.004050, -0.006351},{0.013026, 0.005033, -0.006779}}],
    Polygon[{{0.012346, 0.003892, -0.006351},{0.012346, 0.002938, -0.005766},{
      0.013640, 0.003143, -0.005766},{0.013346, 0.004050, -0.006351}}],
    Polygon[{{0.012346, 0.002938, -0.005766},{0.012346, 0.002088, -0.005040},{
      0.013903, 0.002334, -0.005040},{0.013640, 0.003143, -0.005766}}],
    Polygon[{{0.012346, 0.002088, -0.005040},{0.012346, 0.001361, -0.004190},{
      0.014128, 0.001644, -0.004190},{0.013903, 0.002334, -0.005040}}],
    Polygon[{{0.012346, 0.001361, -0.004190},{0.012346, 0.000777, -0.003236},{
      0.014308, 0.001088, -0.003236},{0.014128, 0.001644, -0.004190}}],
    Polygon[{{0.012346, 0.000777, -0.003236},{0.012346, 0.000349, -0.002203},{
      0.014440, 0.000681, -0.002203},{0.014308, 0.001088, -0.003236}}],
    Polygon[{{0.012346, 0.000349, -0.002203},{0.012346, 0.000088, -0.001115},{
      0.014521, 0.000432, -0.001115},{0.014440, 0.000681, -0.002203}}],
    Polygon[{{0.012346, 0.000088, -0.001115},{0.012346, 0.000000, 0.000000},{
      0.014548, 0.000349, 0.000000},{0.014521, 0.000432, -0.001115}}],
    Polygon[{{0.012346, 0.000000, 0.000000},{0.012346, 0.000088, 0.001115},{
      0.014521, 0.000432, 0.001115},{0.014548, 0.000349, 0.000000}}],
    Polygon[{{0.012346, 0.000088, 0.001115},{0.012346, 0.000349, 0.002203},{
      0.014440, 0.000681, 0.002203},{0.014521, 0.000432, 0.001115}}],
    Polygon[{{0.012346, 0.000349, 0.002203},{0.012346, 0.000777, 0.003236},{
      0.014308, 0.001088, 0.003236},{0.014440, 0.000681, 0.002203}}],
    Polygon[{{0.012346, 0.000777, 0.003236},{0.012346, 0.001361, 0.004190},{
      0.014128, 0.001644, 0.004190},{0.014308, 0.001088, 0.003236}}],
    Polygon[{{0.012346, 0.001361, 0.004190},{0.012346, 0.002088, 0.005040},{
      0.013903, 0.002334, 0.005040},{0.014128, 0.001644, 0.004190}}],
    Polygon[{{0.012346, 0.002088, 0.005040},{0.012346, 0.002938, 0.005766},{
      0.013640, 0.003143, 0.005766},{0.013903, 0.002334, 0.005040}}],
    Polygon[{{0.012346, 0.002938, 0.005766},{0.012346, 0.003892, 0.006351},{
      0.013346, 0.004050, 0.006351},{0.013640, 0.003143, 0.005766}}],
    Polygon[{{0.012346, 0.003892, 0.006351},{0.012346, 0.004925, 0.006779},{
      0.013026, 0.005033, 0.006779},{0.013346, 0.004050, 0.006351}}],
    Polygon[{{0.012346, 0.004925, 0.006779},{0.012346, 0.006013, 0.007040},{
      0.012690, 0.006067, 0.007040},{0.013026, 0.005033, 0.006779}}],
    Polygon[{{0.012690, 0.006067, -0.007040},{0.013026, 0.005033, -0.006779},{
      0.013640, 0.005346, -0.006779},{0.013001, 0.006226, -0.007040}}],
    Polygon[{{0.013026, 0.005033, -0.006779},{0.013346, 0.004050, -0.006351},{
      0.014248, 0.004510, -0.006351},{0.013640, 0.005346, -0.006779}}],
    Polygon[{{0.013346, 0.004050, -0.006351},{0.013640, 0.003143, -0.005766},{
      0.014808, 0.003738, -0.005766},{0.014248, 0.004510, -0.006351}}],
    Polygon[{{0.013640, 0.003143, -0.005766},{0.013903, 0.002334, -0.005040},{
      0.015308, 0.003050, -0.005040},{0.014808, 0.003738, -0.005766}}],
    Polygon[{{0.013903, 0.002334, -0.005040},{0.014128, 0.001644, -0.004190},{
      0.015735, 0.002463, -0.004190},{0.015308, 0.003050, -0.005040}}],
    Polygon[{{0.014128, 0.001644, -0.004190},{0.014308, 0.001088, -0.003236},{
      0.016079, 0.001990, -0.003236},{0.015735, 0.002463, -0.004190}}],
    Polygon[{{0.014308, 0.001088, -0.003236},{0.014440, 0.000681, -0.002203},{
      0.016330, 0.001644, -0.002203},{0.016079, 0.001990, -0.003236}}],
    Polygon[{{0.014440, 0.000681, -0.002203},{0.014521, 0.000432, -0.001115},{
      0.016484, 0.001432, -0.001115},{0.016330, 0.001644, -0.002203}}],
    Polygon[{{0.014521, 0.000432, -0.001115},{0.014548, 0.000349, 0.000000},{
      0.016535, 0.001361, 0.000000},{0.016484, 0.001432, -0.001115}}],
    Polygon[{{0.014548, 0.000349, 0.000000},{0.014521, 0.000432, 0.001115},{
      0.016484, 0.001432, 0.001115},{0.016535, 0.001361, 0.000000}}],
    Polygon[{{0.014521, 0.000432, 0.001115},{0.014440, 0.000681, 0.002203},{
      0.016330, 0.001644, 0.002203},{0.016484, 0.001432, 0.001115}}],
    Polygon[{{0.014440, 0.000681, 0.002203},{0.014308, 0.001088, 0.003236},{
      0.016079, 0.001990, 0.003236},{0.016330, 0.001644, 0.002203}}],
    Polygon[{{0.014308, 0.001088, 0.003236},{0.014128, 0.001644, 0.004190},{
      0.015735, 0.002463, 0.004190},{0.016079, 0.001990, 0.003236}}],
    Polygon[{{0.014128, 0.001644, 0.004190},{0.013903, 0.002334, 0.005040},{
      0.015308, 0.003050, 0.005040},{0.015735, 0.002463, 0.004190}}],
    Polygon[{{0.013903, 0.002334, 0.005040},{0.013640, 0.003143, 0.005766},{
      0.014808, 0.003738, 0.005766},{0.015308, 0.003050, 0.005040}}],
    Polygon[{{0.013640, 0.003143, 0.005766},{0.013346, 0.004050, 0.006351},{
      0.014248, 0.004510, 0.006351},{0.014808, 0.003738, 0.005766}}],
    Polygon[{{0.013346, 0.004050, 0.006351},{0.013026, 0.005033, 0.006779},{
      0.013640, 0.005346, 0.006779},{0.014248, 0.004510, 0.006351}}],
    Polygon[{{0.013026, 0.005033, 0.006779},{0.012690, 0.006067, 0.007040},{
      0.013001, 0.006226, 0.007040},{0.013640, 0.005346, 0.006779}}],
    Polygon[{{0.013001, 0.006226, -0.007040},{0.013640, 0.005346, -0.006779},{
      0.014128, 0.005833, -0.006779},{0.013248, 0.006472, -0.007040}}],
    Polygon[{{0.013640, 0.005346, -0.006779},{0.014248, 0.004510, -0.006351},{
      0.014964, 0.005226, -0.006351},{0.014128, 0.005833, -0.006779}}],
    Polygon[{{0.014248, 0.004510, -0.006351},{0.014808, 0.003738, -0.005766},{
      0.015735, 0.004665, -0.005766},{0.014964, 0.005226, -0.006351}}],
    Polygon[{{0.014808, 0.003738, -0.005766},{0.015308, 0.003050, -0.005040},{
      0.016423, 0.004165, -0.005040},{0.015735, 0.004665, -0.005766}}],
    Polygon[{{0.015308, 0.003050, -0.005040},{0.015735, 0.002463, -0.004190},{
      0.017011, 0.003738, -0.004190},{0.016423, 0.004165, -0.005040}}],
    Polygon[{{0.015735, 0.002463, -0.004190},{0.016079, 0.001990, -0.003236},{
      0.017484, 0.003395, -0.003236},{0.017011, 0.003738, -0.004190}}],
    Polygon[{{0.016079, 0.001990, -0.003236},{0.016330, 0.001644, -0.002203},{
      0.017830, 0.003143, -0.002203},{0.017484, 0.003395, -0.003236}}],
    Polygon[{{0.016330, 0.001644, -0.002203},{0.016484, 0.001432, -0.001115},{
      0.018041, 0.002990, -0.001115},{0.017830, 0.003143, -0.002203}}],
    Polygon[{{0.016484, 0.001432, -0.001115},{0.016535, 0.001361, 0.000000},{
      0.018112, 0.002938, 0.000000},{0.018041, 0.002990, -0.001115}}],
    Polygon[{{0.016535, 0.001361, 0.000000},{0.016484, 0.001432, 0.001115},{
      0.018041, 0.002990, 0.001115},{0.018112, 0.002938, 0.000000}}],
    Polygon[{{0.016484, 0.001432, 0.001115},{0.016330, 0.001644, 0.002203},{
      0.017830, 0.003143, 0.002203},{0.018041, 0.002990, 0.001115}}],
    Polygon[{{0.016330, 0.001644, 0.002203},{0.016079, 0.001990, 0.003236},{
      0.017484, 0.003395, 0.003236},{0.017830, 0.003143, 0.002203}}],
    Polygon[{{0.016079, 0.001990, 0.003236},{0.015735, 0.002463, 0.004190},{
      0.017011, 0.003738, 0.004190},{0.017484, 0.003395, 0.003236}}],
    Polygon[{{0.015735, 0.002463, 0.004190},{0.015308, 0.003050, 0.005040},{
      0.016423, 0.004165, 0.005040},{0.017011, 0.003738, 0.004190}}],
    Polygon[{{0.015308, 0.003050, 0.005040},{0.014808, 0.003738, 0.005766},{
      0.015735, 0.004665, 0.005766},{0.016423, 0.004165, 0.005040}}],
    Polygon[{{0.014808, 0.003738, 0.005766},{0.014248, 0.004510, 0.006351},{
      0.014964, 0.005226, 0.006351},{0.015735, 0.004665, 0.005766}}],
    Polygon[{{0.014248, 0.004510, 0.006351},{0.013640, 0.005346, 0.006779},{
      0.014128, 0.005833, 0.006779},{0.014964, 0.005226, 0.006351}}],
    Polygon[{{0.013640, 0.005346, 0.006779},{0.013001, 0.006226, 0.007040},{
      0.013248, 0.006472, 0.007040},{0.014128, 0.005833, 0.006779}}],
    Polygon[{{0.013248, 0.006472, -0.007040},{0.014128, 0.005833, -0.006779},{
      0.014440, 0.006447, -0.006779},{0.013406, 0.006783, -0.007040}}],
    Polygon[{{0.014128, 0.005833, -0.006779},{0.014964, 0.005226, -0.006351},{
      0.015423, 0.006128, -0.006351},{0.014440, 0.006447, -0.006779}}],
    Polygon[{{0.014964, 0.005226, -0.006351},{0.015735, 0.004665, -0.005766},{
      0.016330, 0.005833, -0.005766},{0.015423, 0.006128, -0.006351}}],
    Polygon[{{0.015735, 0.004665, -0.005766},{0.016423, 0.004165, -0.005040},{
      0.017139, 0.005570, -0.005040},{0.016330, 0.005833, -0.005766}}],
    Polygon[{{0.016423, 0.004165, -0.005040},{0.017011, 0.003738, -0.004190},{
      0.017830, 0.005346, -0.004190},{0.017139, 0.005570, -0.005040}}],
    Polygon[{{0.017011, 0.003738, -0.004190},{0.017484, 0.003395, -0.003236},{
      0.018386, 0.005165, -0.003236},{0.017830, 0.005346, -0.004190}}],
    Polygon[{{0.017484, 0.003395, -0.003236},{0.017830, 0.003143, -0.002203},{
      0.018793, 0.005033, -0.002203},{0.018386, 0.005165, -0.003236}}],
    Polygon[{{0.017830, 0.003143, -0.002203},{0.018041, 0.002990, -0.001115},{
      0.019041, 0.004952, -0.001115},{0.018793, 0.005033, -0.002203}}],
    Polygon[{{0.018041, 0.002990, -0.001115},{0.018112, 0.002938, 0.000000},{
      0.019125, 0.004925, 0.000000},{0.019041, 0.004952, -0.001115}}],
    Polygon[{{0.018112, 0.002938, 0.000000},{0.018041, 0.002990, 0.001115},{
      0.019041, 0.004952, 0.001115},{0.019125, 0.004925, 0.000000}}],
    Polygon[{{0.018041, 0.002990, 0.001115},{0.017830, 0.003143, 0.002203},{
      0.018793, 0.005033, 0.002203},{0.019041, 0.004952, 0.001115}}],
    Polygon[{{0.017830, 0.003143, 0.002203},{0.017484, 0.003395, 0.003236},{
      0.018386, 0.005165, 0.003236},{0.018793, 0.005033, 0.002203}}],
    Polygon[{{0.017484, 0.003395, 0.003236},{0.017011, 0.003738, 0.004190},{
      0.017830, 0.005346, 0.004190},{0.018386, 0.005165, 0.003236}}],
    Polygon[{{0.017011, 0.003738, 0.004190},{0.016423, 0.004165, 0.005040},{
      0.017139, 0.005570, 0.005040},{0.017830, 0.005346, 0.004190}}],
    Polygon[{{0.016423, 0.004165, 0.005040},{0.015735, 0.004665, 0.005766},{
      0.016330, 0.005833, 0.005766},{0.017139, 0.005570, 0.005040}}],
    Polygon[{{0.015735, 0.004665, 0.005766},{0.014964, 0.005226, 0.006351},{
      0.015423, 0.006128, 0.006351},{0.016330, 0.005833, 0.005766}}],
    Polygon[{{0.014964, 0.005226, 0.006351},{0.014128, 0.005833, 0.006779},{
      0.014440, 0.006447, 0.006779},{0.015423, 0.006128, 0.006351}}],
    Polygon[{{0.014128, 0.005833, 0.006779},{0.013248, 0.006472, 0.007040},{
      0.013406, 0.006783, 0.007040},{0.014440, 0.006447, 0.006779}}],
    Polygon[{{0.013406, 0.006783, -0.007040},{0.014440, 0.006447, -0.006779},{
      0.014548, 0.007128, -0.006779},{0.013461, 0.007128, -0.007040}}],
    Polygon[{{0.014440, 0.006447, -0.006779},{0.015423, 0.006128, -0.006351},{
      0.015582, 0.007128, -0.006351},{0.014548, 0.007128, -0.006779}}],
    Polygon[{{0.015423, 0.006128, -0.006351},{0.016330, 0.005833, -0.005766},{
      0.016535, 0.007128, -0.005766},{0.015582, 0.007128, -0.006351}}],
    Polygon[{{0.016330, 0.005833, -0.005766},{0.017139, 0.005570, -0.005040},{
      0.017386, 0.007128, -0.005040},{0.016535, 0.007128, -0.005766}}],
    Polygon[{{0.017139, 0.005570, -0.005040},{0.017830, 0.005346, -0.004190},{
      0.018112, 0.007128, -0.004190},{0.017386, 0.007128, -0.005040}}],
    Polygon[{{0.017830, 0.005346, -0.004190},{0.018386, 0.005165, -0.003236},{
      0.018697, 0.007128, -0.003236},{0.018112, 0.007128, -0.004190}}],
    Polygon[{{0.018386, 0.005165, -0.003236},{0.018793, 0.005033, -0.002203},{
      0.019125, 0.007128, -0.002203},{0.018697, 0.007128, -0.003236}}],
    Polygon[{{0.018793, 0.005033, -0.002203},{0.019041, 0.004952, -0.001115},{
      0.019386, 0.007128, -0.001115},{0.019125, 0.007128, -0.002203}}],
    Polygon[{{0.019041, 0.004952, -0.001115},{0.019125, 0.004925, 0.000000},{
      0.019473, 0.007128, 0.000000},{0.019386, 0.007128, -0.001115}}],
    Polygon[{{0.019125, 0.004925, 0.000000},{0.019041, 0.004952, 0.001115},{
      0.019386, 0.007128, 0.001115},{0.019473, 0.007128, 0.000000}}],
    Polygon[{{0.019041, 0.004952, 0.001115},{0.018793, 0.005033, 0.002203},{
      0.019125, 0.007128, 0.002203},{0.019386, 0.007128, 0.001115}}],
    Polygon[{{0.018793, 0.005033, 0.002203},{0.018386, 0.005165, 0.003236},{
      0.018697, 0.007128, 0.003236},{0.019125, 0.007128, 0.002203}}],
    Polygon[{{0.018386, 0.005165, 0.003236},{0.017830, 0.005346, 0.004190},{
      0.018112, 0.007128, 0.004190},{0.018697, 0.007128, 0.003236}}],
    Polygon[{{0.017830, 0.005346, 0.004190},{0.017139, 0.005570, 0.005040},{
      0.017386, 0.007128, 0.005040},{0.018112, 0.007128, 0.004190}}],
    Polygon[{{0.017139, 0.005570, 0.005040},{0.016330, 0.005833, 0.005766},{
      0.016535, 0.007128, 0.005766},{0.017386, 0.007128, 0.005040}}],
    Polygon[{{0.016330, 0.005833, 0.005766},{0.015423, 0.006128, 0.006351},{
      0.015582, 0.007128, 0.006351},{0.016535, 0.007128, 0.005766}}],
    Polygon[{{0.015423, 0.006128, 0.006351},{0.014440, 0.006447, 0.006779},{
      0.014548, 0.007128, 0.006779},{0.015582, 0.007128, 0.006351}}],
    Polygon[{{0.014440, 0.006447, 0.006779},{0.013406, 0.006783, 0.007040},{
      0.013461, 0.007128, 0.007040},{0.014548, 0.007128, 0.006779}}],
    Polygon[{{0.065495, 0.008594, -0.008489},{0.066806, 0.008594, -0.008174},{
      0.066676, 0.009415, -0.008174},{0.065429, 0.009010, -0.008489}}],
    Polygon[{{0.066806, 0.008594, -0.008174},{0.068052, 0.008594, -0.007658},{
      0.067861, 0.009800, -0.007658},{0.066676, 0.009415, -0.008174}}],
    Polygon[{{0.068052, 0.008594, -0.007658},{0.069202, 0.008594, -0.006953},{
      0.068954, 0.010156, -0.006953},{0.067861, 0.009800, -0.007658}}],
    Polygon[{{0.069202, 0.008594, -0.006953},{0.070227, 0.008594, -0.006077},{
      0.069930, 0.010472, -0.006077},{0.068954, 0.010156, -0.006953}}],
    Polygon[{{0.070227, 0.008594, -0.006077},{0.071103, 0.008594, -0.005052},{
      0.070763, 0.010743, -0.005052},{0.069930, 0.010472, -0.006077}}],
    Polygon[{{0.071103, 0.008594, -0.005052},{0.071808, 0.008594, -0.003902},{
      0.071433, 0.010961, -0.003902},{0.070763, 0.010743, -0.005052}}],
    Polygon[{{0.071808, 0.008594, -0.003902},{0.072324, 0.008594, -0.002656},{
      0.071924, 0.011120, -0.002656},{0.071433, 0.010961, -0.003902}}],
    Polygon[{{0.072324, 0.008594, -0.002656},{0.072639, 0.008594, -0.001344},{
      0.072223, 0.011218, -0.001344},{0.071924, 0.011120, -0.002656}}],
    Polygon[{{0.072639, 0.008594, -0.001344},{0.072745, 0.008594, 0.000000},{
      0.072324, 0.011250, 0.000000},{0.072223, 0.011218, -0.001344}}],
    Polygon[{{0.072745, 0.008594, 0.000000},{0.072639, 0.008594, 0.001344},{
      0.072223, 0.011218, 0.001344},{0.072324, 0.011250, 0.000000}}],
    Polygon[{{0.072639, 0.008594, 0.001344},{0.072324, 0.008594, 0.002656},{
      0.071924, 0.011120, 0.002656},{0.072223, 0.011218, 0.001344}}],
    Polygon[{{0.072324, 0.008594, 0.002656},{0.071808, 0.008594, 0.003902},{
      0.071433, 0.010961, 0.003902},{0.071924, 0.011120, 0.002656}}],
    Polygon[{{0.071808, 0.008594, 0.003902},{0.071103, 0.008594, 0.005052},{
      0.070763, 0.010743, 0.005052},{0.071433, 0.010961, 0.003902}}],
    Polygon[{{0.071103, 0.008594, 0.005052},{0.070227, 0.008594, 0.006077},{
      0.069930, 0.010472, 0.006077},{0.070763, 0.010743, 0.005052}}],
    Polygon[{{0.070227, 0.008594, 0.006077},{0.069202, 0.008594, 0.006953},{
      0.068954, 0.010156, 0.006953},{0.069930, 0.010472, 0.006077}}],
    Polygon[{{0.069202, 0.008594, 0.006953},{0.068052, 0.008594, 0.007658},{
      0.067861, 0.009800, 0.007658},{0.068954, 0.010156, 0.006953}}],
    Polygon[{{0.068052, 0.008594, 0.007658},{0.066806, 0.008594, 0.008174},{
      0.066676, 0.009415, 0.008174},{0.067861, 0.009800, 0.007658}}],
    Polygon[{{0.066806, 0.008594, 0.008174},{0.065495, 0.008594, 0.008489},{
      0.065429, 0.009010, 0.008489},{0.066676, 0.009415, 0.008174}}],
    Polygon[{{0.065429, 0.009010, -0.008489},{0.066676, 0.009415, -0.008174},{
      0.066299, 0.010156, -0.008174},{0.065238, 0.009385, -0.008489}}],
    Polygon[{{0.066676, 0.009415, -0.008174},{0.067861, 0.009800, -0.007658},{
      0.067307, 0.010888, -0.007658},{0.066299, 0.010156, -0.008174}}],
    Polygon[{{0.067861, 0.009800, -0.007658},{0.068954, 0.010156, -0.006953},{
      0.068237, 0.011564, -0.006953},{0.067307, 0.010888, -0.007658}}],
    Polygon[{{0.068954, 0.010156, -0.006953},{0.069930, 0.010472, -0.006077},{
      0.069067, 0.012167, -0.006077},{0.068237, 0.011564, -0.006953}}],
    Polygon[{{0.069930, 0.010472, -0.006077},{0.070763, 0.010743, -0.005052},{
      0.069775, 0.012681, -0.005052},{0.069067, 0.012167, -0.006077}}],
    Polygon[{{0.070763, 0.010743, -0.005052},{0.071433, 0.010961, -0.003902},{
      0.070345, 0.013096, -0.003902},{0.069775, 0.012681, -0.005052}}],
    Polygon[{{0.071433, 0.010961, -0.003902},{0.071924, 0.011120, -0.002656},{
      0.070763, 0.013399, -0.002656},{0.070345, 0.013096, -0.003902}}],
    Polygon[{{0.071924, 0.011120, -0.002656},{0.072223, 0.011218, -0.001344},{
      0.071018, 0.013584, -0.001344},{0.070763, 0.013399, -0.002656}}],
    Polygon[{{0.072223, 0.011218, -0.001344},{0.072324, 0.011250, 0.000000},{
      0.071103, 0.013646, 0.000000},{0.071018, 0.013584, -0.001344}}],
    Polygon[{{0.072324, 0.011250, 0.000000},{0.072223, 0.011218, 0.001344},{
      0.071018, 0.013584, 0.001344},{0.071103, 0.013646, 0.000000}}],
    Polygon[{{0.072223, 0.011218, 0.001344},{0.071924, 0.011120, 0.002656},{
      0.070763, 0.013399, 0.002656},{0.071018, 0.013584, 0.001344}}],
    Polygon[{{0.071924, 0.011120, 0.002656},{0.071433, 0.010961, 0.003902},{
      0.070345, 0.013096, 0.003902},{0.070763, 0.013399, 0.002656}}],
    Polygon[{{0.071433, 0.010961, 0.003902},{0.070763, 0.010743, 0.005052},{
      0.069775, 0.012681, 0.005052},{0.070345, 0.013096, 0.003902}}],
    Polygon[{{0.070763, 0.010743, 0.005052},{0.069930, 0.010472, 0.006077},{
      0.069067, 0.012167, 0.006077},{0.069775, 0.012681, 0.005052}}],
    Polygon[{{0.069930, 0.010472, 0.006077},{0.068954, 0.010156, 0.006953},{
      0.068237, 0.011564, 0.006953},{0.069067, 0.012167, 0.006077}}],
    Polygon[{{0.068954, 0.010156, 0.006953},{0.067861, 0.009800, 0.007658},{
      0.067307, 0.010888, 0.007658},{0.068237, 0.011564, 0.006953}}],
    Polygon[{{0.067861, 0.009800, 0.007658},{0.066676, 0.009415, 0.008174},{
      0.066299, 0.010156, 0.008174},{0.067307, 0.010888, 0.007658}}],
    Polygon[{{0.066676, 0.009415, 0.008174},{0.065429, 0.009010, 0.008489},{
      0.065238, 0.009385, 0.008489},{0.066299, 0.010156, 0.008174}}],
    Polygon[{{0.065238, 0.009385, -0.008489},{0.066299, 0.010156, -0.008174},{
      0.065711, 0.010743, -0.008174},{0.064940, 0.009682, -0.008489}}],
    Polygon[{{0.066299, 0.010156, -0.008174},{0.067307, 0.010888, -0.007658},{
      0.066443, 0.011751, -0.007658},{0.065711, 0.010743, -0.008174}}],
    Polygon[{{0.067307, 0.010888, -0.007658},{0.068237, 0.011564, -0.006953},{
      0.067119, 0.012681, -0.006953},{0.066443, 0.011751, -0.007658}}],
    Polygon[{{0.068237, 0.011564, -0.006953},{0.069067, 0.012167, -0.006077},{
      0.067722, 0.013511, -0.006077},{0.067119, 0.012681, -0.006953}}],
    Polygon[{{0.069067, 0.012167, -0.006077},{0.069775, 0.012681, -0.005052},{
      0.068237, 0.014220, -0.005052},{0.067722, 0.013511, -0.006077}}],
    Polygon[{{0.069775, 0.012681, -0.005052},{0.070345, 0.013096, -0.003902},{
      0.068651, 0.014790, -0.003902},{0.068237, 0.014220, -0.005052}}],
    Polygon[{{0.070345, 0.013096, -0.003902},{0.070763, 0.013399, -0.002656},{
      0.068954, 0.015207, -0.002656},{0.068651, 0.014790, -0.003902}}],
    Polygon[{{0.070763, 0.013399, -0.002656},{0.071018, 0.013584, -0.001344},{
      0.069140, 0.015462, -0.001344},{0.068954, 0.015207, -0.002656}}],
    Polygon[{{0.071018, 0.013584, -0.001344},{0.071103, 0.013646, 0.000000},{
      0.069202, 0.015548, 0.000000},{0.069140, 0.015462, -0.001344}}],
    Polygon[{{0.071103, 0.013646, 0.000000},{0.071018, 0.013584, 0.001344},{
      0.069140, 0.015462, 0.001344},{0.069202, 0.015548, 0.000000}}],
    Polygon[{{0.071018, 0.013584, 0.001344},{0.070763, 0.013399, 0.002656},{
      0.068954, 0.015207, 0.002656},{0.069140, 0.015462, 0.001344}}],
    Polygon[{{0.070763, 0.013399, 0.002656},{0.070345, 0.013096, 0.003902},{
      0.068651, 0.014790, 0.003902},{0.068954, 0.015207, 0.002656}}],
    Polygon[{{0.070345, 0.013096, 0.003902},{0.069775, 0.012681, 0.005052},{
      0.068237, 0.014220, 0.005052},{0.068651, 0.014790, 0.003902}}],
    Polygon[{{0.069775, 0.012681, 0.005052},{0.069067, 0.012167, 0.006077},{
      0.067722, 0.013511, 0.006077},{0.068237, 0.014220, 0.005052}}],
    Polygon[{{0.069067, 0.012167, 0.006077},{0.068237, 0.011564, 0.006953},{
      0.067119, 0.012681, 0.006953},{0.067722, 0.013511, 0.006077}}],
    Polygon[{{0.068237, 0.011564, 0.006953},{0.067307, 0.010888, 0.007658},{
      0.066443, 0.011751, 0.007658},{0.067119, 0.012681, 0.006953}}],
    Polygon[{{0.067307, 0.010888, 0.007658},{0.066299, 0.010156, 0.008174},{
      0.065711, 0.010743, 0.008174},{0.066443, 0.011751, 0.007658}}],
    Polygon[{{0.066299, 0.010156, 0.008174},{0.065238, 0.009385, 0.008489},{
      0.064940, 0.009682, 0.008489},{0.065711, 0.010743, 0.008174}}],
    Polygon[{{0.064940, 0.009682, -0.008489},{0.065711, 0.010743, -0.008174},{
      0.064971, 0.011120, -0.008174},{0.064565, 0.009873, -0.008489}}],
    Polygon[{{0.065711, 0.010743, -0.008174},{0.066443, 0.011751, -0.007658},{
      0.065356, 0.012305, -0.007658},{0.064971, 0.011120, -0.008174}}],
    Polygon[{{0.066443, 0.011751, -0.007658},{0.067119, 0.012681, -0.006953},{
      0.065711, 0.013399, -0.006953},{0.065356, 0.012305, -0.007658}}],
    Polygon[{{0.067119, 0.012681, -0.006953},{0.067722, 0.013511, -0.006077},{
      0.066028, 0.014374, -0.006077},{0.065711, 0.013399, -0.006953}}],
    Polygon[{{0.067722, 0.013511, -0.006077},{0.068237, 0.014220, -0.005052},{
      0.066299, 0.015207, -0.005052},{0.066028, 0.014374, -0.006077}}],
    Polygon[{{0.068237, 0.014220, -0.005052},{0.068651, 0.014790, -0.003902},{
      0.066516, 0.015877, -0.003902},{0.066299, 0.015207, -0.005052}}],
    Polygon[{{0.068651, 0.014790, -0.003902},{0.068954, 0.015207, -0.002656},{
      0.066676, 0.016368, -0.002656},{0.066516, 0.015877, -0.003902}}],
    Polygon[{{0.068954, 0.015207, -0.002656},{0.069140, 0.015462, -0.001344},{
      0.066773, 0.016668, -0.001344},{0.066676, 0.016368, -0.002656}}],
    Polygon[{{0.069140, 0.015462, -0.001344},{0.069202, 0.015548, 0.000000},{
      0.066806, 0.016768, 0.000000},{0.066773, 0.016668, -0.001344}}],
    Polygon[{{0.069202, 0.015548, 0.000000},{0.069140, 0.015462, 0.001344},{
      0.066773, 0.016668, 0.001344},{0.066806, 0.016768, 0.000000}}],
    Polygon[{{0.069140, 0.015462, 0.001344},{0.068954, 0.015207, 0.002656},{
      0.066676, 0.016368, 0.002656},{0.066773, 0.016668, 0.001344}}],
    Polygon[{{0.068954, 0.015207, 0.002656},{0.068651, 0.014790, 0.003902},{
      0.066516, 0.015877, 0.003902},{0.066676, 0.016368, 0.002656}}],
    Polygon[{{0.068651, 0.014790, 0.003902},{0.068237, 0.014220, 0.005052},{
      0.066299, 0.015207, 0.005052},{0.066516, 0.015877, 0.003902}}],
    Polygon[{{0.068237, 0.014220, 0.005052},{0.067722, 0.013511, 0.006077},{
      0.066028, 0.014374, 0.006077},{0.066299, 0.015207, 0.005052}}],
    Polygon[{{0.067722, 0.013511, 0.006077},{0.067119, 0.012681, 0.006953},{
      0.065711, 0.013399, 0.006953},{0.066028, 0.014374, 0.006077}}],
    Polygon[{{0.067119, 0.012681, 0.006953},{0.066443, 0.011751, 0.007658},{
      0.065356, 0.012305, 0.007658},{0.065711, 0.013399, 0.006953}}],
    Polygon[{{0.066443, 0.011751, 0.007658},{0.065711, 0.010743, 0.008174},{
      0.064971, 0.011120, 0.008174},{0.065356, 0.012305, 0.007658}}],
    Polygon[{{0.065711, 0.010743, 0.008174},{0.064940, 0.009682, 0.008489},{
      0.064565, 0.009873, 0.008489},{0.064971, 0.011120, 0.008174}}],
    Polygon[{{0.064565, 0.009873, -0.008489},{0.064971, 0.011120, -0.008174},{
      0.064150, 0.011250, -0.008174},{0.064150, 0.009939, -0.008489}}],
    Polygon[{{0.064971, 0.011120, -0.008174},{0.065356, 0.012305, -0.007658},{
      0.064150, 0.012496, -0.007658},{0.064150, 0.011250, -0.008174}}],
    Polygon[{{0.065356, 0.012305, -0.007658},{0.065711, 0.013399, -0.006953},{
      0.064150, 0.013646, -0.006953},{0.064150, 0.012496, -0.007658}}],
    Polygon[{{0.065711, 0.013399, -0.006953},{0.066028, 0.014374, -0.006077},{
      0.064150, 0.014672, -0.006077},{0.064150, 0.013646, -0.006953}}],
    Polygon[{{0.066028, 0.014374, -0.006077},{0.066299, 0.015207, -0.005052},{
      0.064150, 0.015548, -0.005052},{0.064150, 0.014672, -0.006077}}],
    Polygon[{{0.066299, 0.015207, -0.005052},{0.066516, 0.015877, -0.003902},{
      0.064150, 0.016252, -0.003902},{0.064150, 0.015548, -0.005052}}],
    Polygon[{{0.066516, 0.015877, -0.003902},{0.066676, 0.016368, -0.002656},{
      0.064150, 0.016768, -0.002656},{0.064150, 0.016252, -0.003902}}],
    Polygon[{{0.066676, 0.016368, -0.002656},{0.066773, 0.016668, -0.001344},{
      0.064150, 0.017083, -0.001344},{0.064150, 0.016768, -0.002656}}],
    Polygon[{{0.066773, 0.016668, -0.001344},{0.066806, 0.016768, 0.000000},{
      0.064150, 0.017189, 0.000000},{0.064150, 0.017083, -0.001344}}],
    Polygon[{{0.066806, 0.016768, 0.000000},{0.066773, 0.016668, 0.001344},{
      0.064150, 0.017083, 0.001344},{0.064150, 0.017189, 0.000000}}],
    Polygon[{{0.066773, 0.016668, 0.001344},{0.066676, 0.016368, 0.002656},{
      0.064150, 0.016768, 0.002656},{0.064150, 0.017083, 0.001344}}],
    Polygon[{{0.066676, 0.016368, 0.002656},{0.066516, 0.015877, 0.003902},{
      0.064150, 0.016252, 0.003902},{0.064150, 0.016768, 0.002656}}],
    Polygon[{{0.066516, 0.015877, 0.003902},{0.066299, 0.015207, 0.005052},{
      0.064150, 0.015548, 0.005052},{0.064150, 0.016252, 0.003902}}],
    Polygon[{{0.066299, 0.015207, 0.005052},{0.066028, 0.014374, 0.006077},{
      0.064150, 0.014672, 0.006077},{0.064150, 0.015548, 0.005052}}],
    Polygon[{{0.066028, 0.014374, 0.006077},{0.065711, 0.013399, 0.006953},{
      0.064150, 0.013646, 0.006953},{0.064150, 0.014672, 0.006077}}],
    Polygon[{{0.065711, 0.013399, 0.006953},{0.065356, 0.012305, 0.007658},{
      0.064150, 0.012496, 0.007658},{0.064150, 0.013646, 0.006953}}],
    Polygon[{{0.065356, 0.012305, 0.007658},{0.064971, 0.011120, 0.008174},{
      0.064150, 0.011250, 0.008174},{0.064150, 0.012496, 0.007658}}],
    Polygon[{{0.064971, 0.011120, 0.008174},{0.064565, 0.009873, 0.008489},{
      0.064150, 0.009939, 0.008489},{0.064150, 0.011250, 0.008174}}],
    Polygon[{{0.064150, 0.009939, -0.008489},{0.064150, 0.011250, -0.008174},{
      0.063329, 0.011120, -0.008174},{0.063735, 0.009873, -0.008489}}],
    Polygon[{{0.064150, 0.011250, -0.008174},{0.064150, 0.012496, -0.007658},{
      0.062944, 0.012305, -0.007658},{0.063329, 0.011120, -0.008174}}],
    Polygon[{{0.064150, 0.012496, -0.007658},{0.064150, 0.013646, -0.006953},{
      0.062589, 0.013399, -0.006953},{0.062944, 0.012305, -0.007658}}],
    Polygon[{{0.064150, 0.013646, -0.006953},{0.064150, 0.014672, -0.006077},{
      0.062272, 0.014374, -0.006077},{0.062589, 0.013399, -0.006953}}],
    Polygon[{{0.064150, 0.014672, -0.006077},{0.064150, 0.015548, -0.005052},{
      0.062001, 0.015207, -0.005052},{0.062272, 0.014374, -0.006077}}],
    Polygon[{{0.064150, 0.015548, -0.005052},{0.064150, 0.016252, -0.003902},{
      0.061784, 0.015877, -0.003902},{0.062001, 0.015207, -0.005052}}],
    Polygon[{{0.064150, 0.016252, -0.003902},{0.064150, 0.016768, -0.002656},{
      0.061624, 0.016368, -0.002656},{0.061784, 0.015877, -0.003902}}],
    Polygon[{{0.064150, 0.016768, -0.002656},{0.064150, 0.017083, -0.001344},{
      0.061527, 0.016668, -0.001344},{0.061624, 0.016368, -0.002656}}],
    Polygon[{{0.064150, 0.017083, -0.001344},{0.064150, 0.017189, 0.000000},{
      0.061494, 0.016768, 0.000000},{0.061527, 0.016668, -0.001344}}],
    Polygon[{{0.064150, 0.017189, 0.000000},{0.064150, 0.017083, 0.001344},{
      0.061527, 0.016668, 0.001344},{0.061494, 0.016768, 0.000000}}],
    Polygon[{{0.064150, 0.017083, 0.001344},{0.064150, 0.016768, 0.002656},{
      0.061624, 0.016368, 0.002656},{0.061527, 0.016668, 0.001344}}],
    Polygon[{{0.064150, 0.016768, 0.002656},{0.064150, 0.016252, 0.003902},{
      0.061784, 0.015877, 0.003902},{0.061624, 0.016368, 0.002656}}],
    Polygon[{{0.064150, 0.016252, 0.003902},{0.064150, 0.015548, 0.005052},{
      0.062001, 0.015207, 0.005052},{0.061784, 0.015877, 0.003902}}],
    Polygon[{{0.064150, 0.015548, 0.005052},{0.064150, 0.014672, 0.006077},{
      0.062272, 0.014374, 0.006077},{0.062001, 0.015207, 0.005052}}],
    Polygon[{{0.064150, 0.014672, 0.006077},{0.064150, 0.013646, 0.006953},{
      0.062589, 0.013399, 0.006953},{0.062272, 0.014374, 0.006077}}],
    Polygon[{{0.064150, 0.013646, 0.006953},{0.064150, 0.012496, 0.007658},{
      0.062944, 0.012305, 0.007658},{0.062589, 0.013399, 0.006953}}],
    Polygon[{{0.064150, 0.012496, 0.007658},{0.064150, 0.011250, 0.008174},{
      0.063329, 0.011120, 0.008174},{0.062944, 0.012305, 0.007658}}],
    Polygon[{{0.064150, 0.011250, 0.008174},{0.064150, 0.009939, 0.008489},{
      0.063735, 0.009873, 0.008489},{0.063329, 0.011120, 0.008174}}],
    Polygon[{{0.063735, 0.009873, -0.008489},{0.063329, 0.011120, -0.008174},{
      0.062589, 0.010743, -0.008174},{0.063360, 0.009682, -0.008489}}],
    Polygon[{{0.063329, 0.011120, -0.008174},{0.062944, 0.012305, -0.007658},{
      0.061857, 0.011751, -0.007658},{0.062589, 0.010743, -0.008174}}],
    Polygon[{{0.062944, 0.012305, -0.007658},{0.062589, 0.013399, -0.006953},{
      0.061181, 0.012681, -0.006953},{0.061857, 0.011751, -0.007658}}],
    Polygon[{{0.062589, 0.013399, -0.006953},{0.062272, 0.014374, -0.006077},{
      0.060578, 0.013511, -0.006077},{0.061181, 0.012681, -0.006953}}],
    Polygon[{{0.062272, 0.014374, -0.006077},{0.062001, 0.015207, -0.005052},{
      0.060063, 0.014220, -0.005052},{0.060578, 0.013511, -0.006077}}],
    Polygon[{{0.062001, 0.015207, -0.005052},{0.061784, 0.015877, -0.003902},{
      0.059649, 0.014790, -0.003902},{0.060063, 0.014220, -0.005052}}],
    Polygon[{{0.061784, 0.015877, -0.003902},{0.061624, 0.016368, -0.002656},{
      0.059346, 0.015207, -0.002656},{0.059649, 0.014790, -0.003902}}],
    Polygon[{{0.061624, 0.016368, -0.002656},{0.061527, 0.016668, -0.001344},{
      0.059161, 0.015462, -0.001344},{0.059346, 0.015207, -0.002656}}],
    Polygon[{{0.061527, 0.016668, -0.001344},{0.061494, 0.016768, 0.000000},{
      0.059098, 0.015548, 0.000000},{0.059161, 0.015462, -0.001344}}],
    Polygon[{{0.061494, 0.016768, 0.000000},{0.061527, 0.016668, 0.001344},{
      0.059161, 0.015462, 0.001344},{0.059098, 0.015548, 0.000000}}],
    Polygon[{{0.061527, 0.016668, 0.001344},{0.061624, 0.016368, 0.002656},{
      0.059346, 0.015207, 0.002656},{0.059161, 0.015462, 0.001344}}],
    Polygon[{{0.061624, 0.016368, 0.002656},{0.061784, 0.015877, 0.003902},{
      0.059649, 0.014790, 0.003902},{0.059346, 0.015207, 0.002656}}],
    Polygon[{{0.061784, 0.015877, 0.003902},{0.062001, 0.015207, 0.005052},{
      0.060063, 0.014220, 0.005052},{0.059649, 0.014790, 0.003902}}],
    Polygon[{{0.062001, 0.015207, 0.005052},{0.062272, 0.014374, 0.006077},{
      0.060578, 0.013511, 0.006077},{0.060063, 0.014220, 0.005052}}],
    Polygon[{{0.062272, 0.014374, 0.006077},{0.062589, 0.013399, 0.006953},{
      0.061181, 0.012681, 0.006953},{0.060578, 0.013511, 0.006077}}],
    Polygon[{{0.062589, 0.013399, 0.006953},{0.062944, 0.012305, 0.007658},{
      0.061857, 0.011751, 0.007658},{0.061181, 0.012681, 0.006953}}],
    Polygon[{{0.062944, 0.012305, 0.007658},{0.063329, 0.011120, 0.008174},{
      0.062589, 0.010743, 0.008174},{0.061857, 0.011751, 0.007658}}],
    Polygon[{{0.063329, 0.011120, 0.008174},{0.063735, 0.009873, 0.008489},{
      0.063360, 0.009682, 0.008489},{0.062589, 0.010743, 0.008174}}],
    Polygon[{{0.063360, 0.009682, -0.008489},{0.062589, 0.010743, -0.008174},{
      0.062001, 0.010156, -0.008174},{0.063062, 0.009385, -0.008489}}],
    Polygon[{{0.062589, 0.010743, -0.008174},{0.061857, 0.011751, -0.007658},{
      0.060993, 0.010888, -0.007658},{0.062001, 0.010156, -0.008174}}],
    Polygon[{{0.061857, 0.011751, -0.007658},{0.061181, 0.012681, -0.006953},{
      0.060063, 0.011564, -0.006953},{0.060993, 0.010888, -0.007658}}],
    Polygon[{{0.061181, 0.012681, -0.006953},{0.060578, 0.013511, -0.006077},{
      0.059233, 0.012167, -0.006077},{0.060063, 0.011564, -0.006953}}],
    Polygon[{{0.060578, 0.013511, -0.006077},{0.060063, 0.014220, -0.005052},{
      0.058525, 0.012681, -0.005052},{0.059233, 0.012167, -0.006077}}],
    Polygon[{{0.060063, 0.014220, -0.005052},{0.059649, 0.014790, -0.003902},{
      0.057955, 0.013096, -0.003902},{0.058525, 0.012681, -0.005052}}],
    Polygon[{{0.059649, 0.014790, -0.003902},{0.059346, 0.015207, -0.002656},{
      0.057537, 0.013399, -0.002656},{0.057955, 0.013096, -0.003902}}],
    Polygon[{{0.059346, 0.015207, -0.002656},{0.059161, 0.015462, -0.001344},{
      0.057283, 0.013584, -0.001344},{0.057537, 0.013399, -0.002656}}],
    Polygon[{{0.059161, 0.015462, -0.001344},{0.059098, 0.015548, 0.000000},{
      0.057197, 0.013646, 0.000000},{0.057283, 0.013584, -0.001344}}],
    Polygon[{{0.059098, 0.015548, 0.000000},{0.059161, 0.015462, 0.001344},{
      0.057283, 0.013584, 0.001344},{0.057197, 0.013646, 0.000000}}],
    Polygon[{{0.059161, 0.015462, 0.001344},{0.059346, 0.015207, 0.002656},{
      0.057537, 0.013399, 0.002656},{0.057283, 0.013584, 0.001344}}],
    Polygon[{{0.059346, 0.015207, 0.002656},{0.059649, 0.014790, 0.003902},{
      0.057955, 0.013096, 0.003902},{0.057537, 0.013399, 0.002656}}],
    Polygon[{{0.059649, 0.014790, 0.003902},{0.060063, 0.014220, 0.005052},{
      0.058525, 0.012681, 0.005052},{0.057955, 0.013096, 0.003902}}],
    Polygon[{{0.060063, 0.014220, 0.005052},{0.060578, 0.013511, 0.006077},{
      0.059233, 0.012167, 0.006077},{0.058525, 0.012681, 0.005052}}],
    Polygon[{{0.060578, 0.013511, 0.006077},{0.061181, 0.012681, 0.006953},{
      0.060063, 0.011564, 0.006953},{0.059233, 0.012167, 0.006077}}],
    Polygon[{{0.061181, 0.012681, 0.006953},{0.061857, 0.011751, 0.007658},{
      0.060993, 0.010888, 0.007658},{0.060063, 0.011564, 0.006953}}],
    Polygon[{{0.061857, 0.011751, 0.007658},{0.062589, 0.010743, 0.008174},{
      0.062001, 0.010156, 0.008174},{0.060993, 0.010888, 0.007658}}],
    Polygon[{{0.062589, 0.010743, 0.008174},{0.063360, 0.009682, 0.008489},{
      0.063062, 0.009385, 0.008489},{0.062001, 0.010156, 0.008174}}],
    Polygon[{{0.063062, 0.009385, -0.008489},{0.062001, 0.010156, -0.008174},{
      0.061624, 0.009415, -0.008174},{0.062871, 0.009010, -0.008489}}],
    Polygon[{{0.062001, 0.010156, -0.008174},{0.060993, 0.010888, -0.007658},{
      0.060439, 0.009800, -0.007658},{0.061624, 0.009415, -0.008174}}],
    Polygon[{{0.060993, 0.010888, -0.007658},{0.060063, 0.011564, -0.006953},{
      0.059346, 0.010156, -0.006953},{0.060439, 0.009800, -0.007658}}],
    Polygon[{{0.060063, 0.011564, -0.006953},{0.059233, 0.012167, -0.006077},{
      0.058370, 0.010472, -0.006077},{0.059346, 0.010156, -0.006953}}],
    Polygon[{{0.059233, 0.012167, -0.006077},{0.058525, 0.012681, -0.005052},{
      0.057537, 0.010743, -0.005052},{0.058370, 0.010472, -0.006077}}],
    Polygon[{{0.058525, 0.012681, -0.005052},{0.057955, 0.013096, -0.003902},{
      0.056867, 0.010961, -0.003902},{0.057537, 0.010743, -0.005052}}],
    Polygon[{{0.057955, 0.013096, -0.003902},{0.057537, 0.013399, -0.002656},{
      0.056376, 0.011120, -0.002656},{0.056867, 0.010961, -0.003902}}],
    Polygon[{{0.057537, 0.013399, -0.002656},{0.057283, 0.013584, -0.001344},{
      0.056077, 0.011218, -0.001344},{0.056376, 0.011120, -0.002656}}],
    Polygon[{{0.057283, 0.013584, -0.001344},{0.057197, 0.013646, 0.000000},{
      0.055976, 0.011250, 0.000000},{0.056077, 0.011218, -0.001344}}],
    Polygon[{{0.057197, 0.013646, 0.000000},{0.057283, 0.013584, 0.001344},{
      0.056077, 0.011218, 0.001344},{0.055976, 0.011250, 0.000000}}],
    Polygon[{{0.057283, 0.013584, 0.001344},{0.057537, 0.013399, 0.002656},{
      0.056376, 0.011120, 0.002656},{0.056077, 0.011218, 0.001344}}],
    Polygon[{{0.057537, 0.013399, 0.002656},{0.057955, 0.013096, 0.003902},{
      0.056867, 0.010961, 0.003902},{0.056376, 0.011120, 0.002656}}],
    Polygon[{{0.057955, 0.013096, 0.003902},{0.058525, 0.012681, 0.005052},{
      0.057537, 0.010743, 0.005052},{0.056867, 0.010961, 0.003902}}],
    Polygon[{{0.058525, 0.012681, 0.005052},{0.059233, 0.012167, 0.006077},{
      0.058370, 0.010472, 0.006077},{0.057537, 0.010743, 0.005052}}],
    Polygon[{{0.059233, 0.012167, 0.006077},{0.060063, 0.011564, 0.006953},{
      0.059346, 0.010156, 0.006953},{0.058370, 0.010472, 0.006077}}],
    Polygon[{{0.060063, 0.011564, 0.006953},{0.060993, 0.010888, 0.007658},{
      0.060439, 0.009800, 0.007658},{0.059346, 0.010156, 0.006953}}],
    Polygon[{{0.060993, 0.010888, 0.007658},{0.062001, 0.010156, 0.008174},{
      0.061624, 0.009415, 0.008174},{0.060439, 0.009800, 0.007658}}],
    Polygon[{{0.062001, 0.010156, 0.008174},{0.063062, 0.009385, 0.008489},{
      0.062871, 0.009010, 0.008489},{0.061624, 0.009415, 0.008174}}],
    Polygon[{{0.062871, 0.009010, -0.008489},{0.061624, 0.009415, -0.008174},{
      0.061494, 0.008594, -0.008174},{0.062806, 0.008594, -0.008489}}],
    Polygon[{{0.061624, 0.009415, -0.008174},{0.060439, 0.009800, -0.007658},{
      0.060248, 0.008594, -0.007658},{0.061494, 0.008594, -0.008174}}],
    Polygon[{{0.060439, 0.009800, -0.007658},{0.059346, 0.010156, -0.006953},{
      0.059098, 0.008594, -0.006953},{0.060248, 0.008594, -0.007658}}],
    Polygon[{{0.059346, 0.010156, -0.006953},{0.058370, 0.010472, -0.006077},{
      0.058073, 0.008594, -0.006077},{0.059098, 0.008594, -0.006953}}],
    Polygon[{{0.058370, 0.010472, -0.006077},{0.057537, 0.010743, -0.005052},{
      0.057197, 0.008594, -0.005052},{0.058073, 0.008594, -0.006077}}],
    Polygon[{{0.057537, 0.010743, -0.005052},{0.056867, 0.010961, -0.003902},{
      0.056492, 0.008594, -0.003902},{0.057197, 0.008594, -0.005052}}],
    Polygon[{{0.056867, 0.010961, -0.003902},{0.056376, 0.011120, -0.002656},{
      0.055976, 0.008594, -0.002656},{0.056492, 0.008594, -0.003902}}],
    Polygon[{{0.056376, 0.011120, -0.002656},{0.056077, 0.011218, -0.001344},{
      0.055661, 0.008594, -0.001344},{0.055976, 0.008594, -0.002656}}],
    Polygon[{{0.056077, 0.011218, -0.001344},{0.055976, 0.011250, 0.000000},{
      0.055556, 0.008594, 0.000000},{0.055661, 0.008594, -0.001344}}],
    Polygon[{{0.055976, 0.011250, 0.000000},{0.056077, 0.011218, 0.001344},{
      0.055661, 0.008594, 0.001344},{0.055556, 0.008594, 0.000000}}],
    Polygon[{{0.056077, 0.011218, 0.001344},{0.056376, 0.011120, 0.002656},{
      0.055976, 0.008594, 0.002656},{0.055661, 0.008594, 0.001344}}],
    Polygon[{{0.056376, 0.011120, 0.002656},{0.056867, 0.010961, 0.003902},{
      0.056492, 0.008594, 0.003902},{0.055976, 0.008594, 0.002656}}],
    Polygon[{{0.056867, 0.010961, 0.003902},{0.057537, 0.010743, 0.005052},{
      0.057197, 0.008594, 0.005052},{0.056492, 0.008594, 0.003902}}],
    Polygon[{{0.057537, 0.010743, 0.005052},{0.058370, 0.010472, 0.006077},{
      0.058073, 0.008594, 0.006077},{0.057197, 0.008594, 0.005052}}],
    Polygon[{{0.058370, 0.010472, 0.006077},{0.059346, 0.010156, 0.006953},{
      0.059098, 0.008594, 0.006953},{0.058073, 0.008594, 0.006077}}],
    Polygon[{{0.059346, 0.010156, 0.006953},{0.060439, 0.009800, 0.007658},{
      0.060248, 0.008594, 0.007658},{0.059098, 0.008594, 0.006953}}],
    Polygon[{{0.060439, 0.009800, 0.007658},{0.061624, 0.009415, 0.008174},{
      0.061494, 0.008594, 0.008174},{0.060248, 0.008594, 0.007658}}],
    Polygon[{{0.061624, 0.009415, 0.008174},{0.062871, 0.009010, 0.008489},{
      0.062806, 0.008594, 0.008489},{0.061494, 0.008594, 0.008174}}],
    Polygon[{{0.062806, 0.008594, -0.008489},{0.061494, 0.008594, -0.008174},{
      0.061624, 0.007774, -0.008174},{0.062871, 0.008179, -0.008489}}],
    Polygon[{{0.061494, 0.008594, -0.008174},{0.060248, 0.008594, -0.007658},{
      0.060439, 0.007389, -0.007658},{0.061624, 0.007774, -0.008174}}],
    Polygon[{{0.060248, 0.008594, -0.007658},{0.059098, 0.008594, -0.006953},{
      0.059346, 0.007033, -0.006953},{0.060439, 0.007389, -0.007658}}],
    Polygon[{{0.059098, 0.008594, -0.006953},{0.058073, 0.008594, -0.006077},{
      0.058370, 0.006717, -0.006077},{0.059346, 0.007033, -0.006953}}],
    Polygon[{{0.058073, 0.008594, -0.006077},{0.057197, 0.008594, -0.005052},{
      0.057537, 0.006446, -0.005052},{0.058370, 0.006717, -0.006077}}],
    Polygon[{{0.057197, 0.008594, -0.005052},{0.056492, 0.008594, -0.003902},{
      0.056867, 0.006228, -0.003902},{0.057537, 0.006446, -0.005052}}],
    Polygon[{{0.056492, 0.008594, -0.003902},{0.055976, 0.008594, -0.002656},{
      0.056376, 0.006069, -0.002656},{0.056867, 0.006228, -0.003902}}],
    Polygon[{{0.055976, 0.008594, -0.002656},{0.055661, 0.008594, -0.001344},{
      0.056077, 0.005971, -0.001344},{0.056376, 0.006069, -0.002656}}],
    Polygon[{{0.055661, 0.008594, -0.001344},{0.055556, 0.008594, 0.000000},{
      0.055976, 0.005939, 0.000000},{0.056077, 0.005971, -0.001344}}],
    Polygon[{{0.055556, 0.008594, 0.000000},{0.055661, 0.008594, 0.001344},{
      0.056077, 0.005971, 0.001344},{0.055976, 0.005939, 0.000000}}],
    Polygon[{{0.055661, 0.008594, 0.001344},{0.055976, 0.008594, 0.002656},{
      0.056376, 0.006069, 0.002656},{0.056077, 0.005971, 0.001344}}],
    Polygon[{{0.055976, 0.008594, 0.002656},{0.056492, 0.008594, 0.003902},{
      0.056867, 0.006228, 0.003902},{0.056376, 0.006069, 0.002656}}],
    Polygon[{{0.056492, 0.008594, 0.003902},{0.057197, 0.008594, 0.005052},{
      0.057537, 0.006446, 0.005052},{0.056867, 0.006228, 0.003902}}],
    Polygon[{{0.057197, 0.008594, 0.005052},{0.058073, 0.008594, 0.006077},{
      0.058370, 0.006717, 0.006077},{0.057537, 0.006446, 0.005052}}],
    Polygon[{{0.058073, 0.008594, 0.006077},{0.059098, 0.008594, 0.006953},{
      0.059346, 0.007033, 0.006953},{0.058370, 0.006717, 0.006077}}],
    Polygon[{{0.059098, 0.008594, 0.006953},{0.060248, 0.008594, 0.007658},{
      0.060439, 0.007389, 0.007658},{0.059346, 0.007033, 0.006953}}],
    Polygon[{{0.060248, 0.008594, 0.007658},{0.061494, 0.008594, 0.008174},{
      0.061624, 0.007774, 0.008174},{0.060439, 0.007389, 0.007658}}],
    Polygon[{{0.061494, 0.008594, 0.008174},{0.062806, 0.008594, 0.008489},{
      0.062871, 0.008179, 0.008489},{0.061624, 0.007774, 0.008174}}],
    Polygon[{{0.062871, 0.008179, -0.008489},{0.061624, 0.007774, -0.008174},{
      0.062001, 0.007033, -0.008174},{0.063062, 0.007804, -0.008489}}],
    Polygon[{{0.061624, 0.007774, -0.008174},{0.060439, 0.007389, -0.007658},{
      0.060993, 0.006301, -0.007658},{0.062001, 0.007033, -0.008174}}],
    Polygon[{{0.060439, 0.007389, -0.007658},{0.059346, 0.007033, -0.006953},{
      0.060063, 0.005625, -0.006953},{0.060993, 0.006301, -0.007658}}],
    Polygon[{{0.059346, 0.007033, -0.006953},{0.058370, 0.006717, -0.006077},{
      0.059233, 0.005022, -0.006077},{0.060063, 0.005625, -0.006953}}],
    Polygon[{{0.058370, 0.006717, -0.006077},{0.057537, 0.006446, -0.005052},{
      0.058525, 0.004508, -0.005052},{0.059233, 0.005022, -0.006077}}],
    Polygon[{{0.057537, 0.006446, -0.005052},{0.056867, 0.006228, -0.003902},{
      0.057955, 0.004093, -0.003902},{0.058525, 0.004508, -0.005052}}],
    Polygon[{{0.056867, 0.006228, -0.003902},{0.056376, 0.006069, -0.002656},{
      0.057537, 0.003790, -0.002656},{0.057955, 0.004093, -0.003902}}],
    Polygon[{{0.056376, 0.006069, -0.002656},{0.056077, 0.005971, -0.001344},{
      0.057283, 0.003605, -0.001344},{0.057537, 0.003790, -0.002656}}],
    Polygon[{{0.056077, 0.005971, -0.001344},{0.055976, 0.005939, 0.000000},{
      0.057197, 0.003543, 0.000000},{0.057283, 0.003605, -0.001344}}],
    Polygon[{{0.055976, 0.005939, 0.000000},{0.056077, 0.005971, 0.001344},{
      0.057283, 0.003605, 0.001344},{0.057197, 0.003543, 0.000000}}],
    Polygon[{{0.056077, 0.005971, 0.001344},{0.056376, 0.006069, 0.002656},{
      0.057537, 0.003790, 0.002656},{0.057283, 0.003605, 0.001344}}],
    Polygon[{{0.056376, 0.006069, 0.002656},{0.056867, 0.006228, 0.003902},{
      0.057955, 0.004093, 0.003902},{0.057537, 0.003790, 0.002656}}],
    Polygon[{{0.056867, 0.006228, 0.003902},{0.057537, 0.006446, 0.005052},{
      0.058525, 0.004508, 0.005052},{0.057955, 0.004093, 0.003902}}],
    Polygon[{{0.057537, 0.006446, 0.005052},{0.058370, 0.006717, 0.006077},{
      0.059233, 0.005022, 0.006077},{0.058525, 0.004508, 0.005052}}],
    Polygon[{{0.058370, 0.006717, 0.006077},{0.059346, 0.007033, 0.006953},{
      0.060063, 0.005625, 0.006953},{0.059233, 0.005022, 0.006077}}],
    Polygon[{{0.059346, 0.007033, 0.006953},{0.060439, 0.007389, 0.007658},{
      0.060993, 0.006301, 0.007658},{0.060063, 0.005625, 0.006953}}],
    Polygon[{{0.060439, 0.007389, 0.007658},{0.061624, 0.007774, 0.008174},{
      0.062001, 0.007033, 0.008174},{0.060993, 0.006301, 0.007658}}],
    Polygon[{{0.061624, 0.007774, 0.008174},{0.062871, 0.008179, 0.008489},{
      0.063062, 0.007804, 0.008489},{0.062001, 0.007033, 0.008174}}],
    Polygon[{{0.063062, 0.007804, -0.008489},{0.062001, 0.007033, -0.008174},{
      0.062589, 0.006446, -0.008174},{0.063360, 0.007507, -0.008489}}],
    Polygon[{{0.062001, 0.007033, -0.008174},{0.060993, 0.006301, -0.007658},{
      0.061857, 0.005438, -0.007658},{0.062589, 0.006446, -0.008174}}],
    Polygon[{{0.060993, 0.006301, -0.007658},{0.060063, 0.005625, -0.006953},{
      0.061181, 0.004508, -0.006953},{0.061857, 0.005438, -0.007658}}],
    Polygon[{{0.060063, 0.005625, -0.006953},{0.059233, 0.005022, -0.006077},{
      0.060578, 0.003678, -0.006077},{0.061181, 0.004508, -0.006953}}],
    Polygon[{{0.059233, 0.005022, -0.006077},{0.058525, 0.004508, -0.005052},{
      0.060063, 0.002969, -0.005052},{0.060578, 0.003678, -0.006077}}],
    Polygon[{{0.058525, 0.004508, -0.005052},{0.057955, 0.004093, -0.003902},{
      0.059649, 0.002399, -0.003902},{0.060063, 0.002969, -0.005052}}],
    Polygon[{{0.057955, 0.004093, -0.003902},{0.057537, 0.003790, -0.002656},{
      0.059346, 0.001982, -0.002656},{0.059649, 0.002399, -0.003902}}],
    Polygon[{{0.057537, 0.003790, -0.002656},{0.057283, 0.003605, -0.001344},{
      0.059161, 0.001727, -0.001344},{0.059346, 0.001982, -0.002656}}],
    Polygon[{{0.057283, 0.003605, -0.001344},{0.057197, 0.003543, 0.000000},{
      0.059098, 0.001641, 0.000000},{0.059161, 0.001727, -0.001344}}],
    Polygon[{{0.057197, 0.003543, 0.000000},{0.057283, 0.003605, 0.001344},{
      0.059161, 0.001727, 0.001344},{0.059098, 0.001641, 0.000000}}],
    Polygon[{{0.057283, 0.003605, 0.001344},{0.057537, 0.003790, 0.002656},{
      0.059346, 0.001982, 0.002656},{0.059161, 0.001727, 0.001344}}],
    Polygon[{{0.057537, 0.003790, 0.002656},{0.057955, 0.004093, 0.003902},{
      0.059649, 0.002399, 0.003902},{0.059346, 0.001982, 0.002656}}],
    Polygon[{{0.057955, 0.004093, 0.003902},{0.058525, 0.004508, 0.005052},{
      0.060063, 0.002969, 0.005052},{0.059649, 0.002399, 0.003902}}],
    Polygon[{{0.058525, 0.004508, 0.005052},{0.059233, 0.005022, 0.006077},{
      0.060578, 0.003678, 0.006077},{0.060063, 0.002969, 0.005052}}],
    Polygon[{{0.059233, 0.005022, 0.006077},{0.060063, 0.005625, 0.006953},{
      0.061181, 0.004508, 0.006953},{0.060578, 0.003678, 0.006077}}],
    Polygon[{{0.060063, 0.005625, 0.006953},{0.060993, 0.006301, 0.007658},{
      0.061857, 0.005438, 0.007658},{0.061181, 0.004508, 0.006953}}],
    Polygon[{{0.060993, 0.006301, 0.007658},{0.062001, 0.007033, 0.008174},{
      0.062589, 0.006446, 0.008174},{0.061857, 0.005438, 0.007658}}],
    Polygon[{{0.062001, 0.007033, 0.008174},{0.063062, 0.007804, 0.008489},{
      0.063360, 0.007507, 0.008489},{0.062589, 0.006446, 0.008174}}],
    Polygon[{{0.063360, 0.007507, -0.008489},{0.062589, 0.006446, -0.008174},{
      0.063329, 0.006069, -0.008174},{0.063735, 0.007316, -0.008489}}],
    Polygon[{{0.062589, 0.006446, -0.008174},{0.061857, 0.005438, -0.007658},{
      0.062944, 0.004884, -0.007658},{0.063329, 0.006069, -0.008174}}],
    Polygon[{{0.061857, 0.005438, -0.007658},{0.061181, 0.004508, -0.006953},{
      0.062589, 0.003790, -0.006953},{0.062944, 0.004884, -0.007658}}],
    Polygon[{{0.061181, 0.004508, -0.006953},{0.060578, 0.003678, -0.006077},{
      0.062272, 0.002815, -0.006077},{0.062589, 0.003790, -0.006953}}],
    Polygon[{{0.060578, 0.003678, -0.006077},{0.060063, 0.002969, -0.005052},{
      0.062001, 0.001982, -0.005052},{0.062272, 0.002815, -0.006077}}],
    Polygon[{{0.060063, 0.002969, -0.005052},{0.059649, 0.002399, -0.003902},{
      0.061784, 0.001312, -0.003902},{0.062001, 0.001982, -0.005052}}],
    Polygon[{{0.059649, 0.002399, -0.003902},{0.059346, 0.001982, -0.002656},{
      0.061624, 0.000821, -0.002656},{0.061784, 0.001312, -0.003902}}],
    Polygon[{{0.059346, 0.001982, -0.002656},{0.059161, 0.001727, -0.001344},{
      0.061527, 0.000521, -0.001344},{0.061624, 0.000821, -0.002656}}],
    Polygon[{{0.059161, 0.001727, -0.001344},{0.059098, 0.001641, 0.000000},{
      0.061494, 0.000421, 0.000000},{0.061527, 0.000521, -0.001344}}],
    Polygon[{{0.059098, 0.001641, 0.000000},{0.059161, 0.001727, 0.001344},{
      0.061527, 0.000521, 0.001344},{0.061494, 0.000421, 0.000000}}],
    Polygon[{{0.059161, 0.001727, 0.001344},{0.059346, 0.001982, 0.002656},{
      0.061624, 0.000821, 0.002656},{0.061527, 0.000521, 0.001344}}],
    Polygon[{{0.059346, 0.001982, 0.002656},{0.059649, 0.002399, 0.003902},{
      0.061784, 0.001312, 0.003902},{0.061624, 0.000821, 0.002656}}],
    Polygon[{{0.059649, 0.002399, 0.003902},{0.060063, 0.002969, 0.005052},{
      0.062001, 0.001982, 0.005052},{0.061784, 0.001312, 0.003902}}],
    Polygon[{{0.060063, 0.002969, 0.005052},{0.060578, 0.003678, 0.006077},{
      0.062272, 0.002815, 0.006077},{0.062001, 0.001982, 0.005052}}],
    Polygon[{{0.060578, 0.003678, 0.006077},{0.061181, 0.004508, 0.006953},{
      0.062589, 0.003790, 0.006953},{0.062272, 0.002815, 0.006077}}],
    Polygon[{{0.061181, 0.004508, 0.006953},{0.061857, 0.005438, 0.007658},{
      0.062944, 0.004884, 0.007658},{0.062589, 0.003790, 0.006953}}],
    Polygon[{{0.061857, 0.005438, 0.007658},{0.062589, 0.006446, 0.008174},{
      0.063329, 0.006069, 0.008174},{0.062944, 0.004884, 0.007658}}],
    Polygon[{{0.062589, 0.006446, 0.008174},{0.063360, 0.007507, 0.008489},{
      0.063735, 0.007316, 0.008489},{0.063329, 0.006069, 0.008174}}],
    Polygon[{{0.063735, 0.007316, -0.008489},{0.063329, 0.006069, -0.008174},{
      0.064150, 0.005939, -0.008174},{0.064150, 0.007250, -0.008489}}],
    Polygon[{{0.063329, 0.006069, -0.008174},{0.062944, 0.004884, -0.007658},{
      0.064150, 0.004693, -0.007658},{0.064150, 0.005939, -0.008174}}],
    Polygon[{{0.062944, 0.004884, -0.007658},{0.062589, 0.003790, -0.006953},{
      0.064150, 0.003543, -0.006953},{0.064150, 0.004693, -0.007658}}],
    Polygon[{{0.062589, 0.003790, -0.006953},{0.062272, 0.002815, -0.006077},{
      0.064150, 0.002517, -0.006077},{0.064150, 0.003543, -0.006953}}],
    Polygon[{{0.062272, 0.002815, -0.006077},{0.062001, 0.001982, -0.005052},{
      0.064150, 0.001641, -0.005052},{0.064150, 0.002517, -0.006077}}],
    Polygon[{{0.062001, 0.001982, -0.005052},{0.061784, 0.001312, -0.003902},{
      0.064150, 0.000937, -0.003902},{0.064150, 0.001641, -0.005052}}],
    Polygon[{{0.061784, 0.001312, -0.003902},{0.061624, 0.000821, -0.002656},{
      0.064150, 0.000421, -0.002656},{0.064150, 0.000937, -0.003902}}],
    Polygon[{{0.061624, 0.000821, -0.002656},{0.061527, 0.000521, -0.001344},{
      0.064150, 0.000106, -0.001344},{0.064150, 0.000421, -0.002656}}],
    Polygon[{{0.061527, 0.000521, -0.001344},{0.061494, 0.000421, 0.000000},{
      0.064150, 0.000000, 0.000000},{0.064150, 0.000106, -0.001344}}],
    Polygon[{{0.061494, 0.000421, 0.000000},{0.061527, 0.000521, 0.001344},{
      0.064150, 0.000106, 0.001344},{0.064150, 0.000000, 0.000000}}],
    Polygon[{{0.061527, 0.000521, 0.001344},{0.061624, 0.000821, 0.002656},{
      0.064150, 0.000421, 0.002656},{0.064150, 0.000106, 0.001344}}],
    Polygon[{{0.061624, 0.000821, 0.002656},{0.061784, 0.001312, 0.003902},{
      0.064150, 0.000937, 0.003902},{0.064150, 0.000421, 0.002656}}],
    Polygon[{{0.061784, 0.001312, 0.003902},{0.062001, 0.001982, 0.005052},{
      0.064150, 0.001641, 0.005052},{0.064150, 0.000937, 0.003902}}],
    Polygon[{{0.062001, 0.001982, 0.005052},{0.062272, 0.002815, 0.006077},{
      0.064150, 0.002517, 0.006077},{0.064150, 0.001641, 0.005052}}],
    Polygon[{{0.062272, 0.002815, 0.006077},{0.062589, 0.003790, 0.006953},{
      0.064150, 0.003543, 0.006953},{0.064150, 0.002517, 0.006077}}],
    Polygon[{{0.062589, 0.003790, 0.006953},{0.062944, 0.004884, 0.007658},{
      0.064150, 0.004693, 0.007658},{0.064150, 0.003543, 0.006953}}],
    Polygon[{{0.062944, 0.004884, 0.007658},{0.063329, 0.006069, 0.008174},{
      0.064150, 0.005939, 0.008174},{0.064150, 0.004693, 0.007658}}],
    Polygon[{{0.063329, 0.006069, 0.008174},{0.063735, 0.007316, 0.008489},{
      0.064150, 0.007250, 0.008489},{0.064150, 0.005939, 0.008174}}],
    Polygon[{{0.064150, 0.007250, -0.008489},{0.064150, 0.005939, -0.008174},{
      0.064971, 0.006069, -0.008174},{0.064565, 0.007316, -0.008489}}],
    Polygon[{{0.064150, 0.005939, -0.008174},{0.064150, 0.004693, -0.007658},{
      0.065356, 0.004884, -0.007658},{0.064971, 0.006069, -0.008174}}],
    Polygon[{{0.064150, 0.004693, -0.007658},{0.064150, 0.003543, -0.006953},{
      0.065711, 0.003790, -0.006953},{0.065356, 0.004884, -0.007658}}],
    Polygon[{{0.064150, 0.003543, -0.006953},{0.064150, 0.002517, -0.006077},{
      0.066028, 0.002815, -0.006077},{0.065711, 0.003790, -0.006953}}],
    Polygon[{{0.064150, 0.002517, -0.006077},{0.064150, 0.001641, -0.005052},{
      0.066299, 0.001982, -0.005052},{0.066028, 0.002815, -0.006077}}],
    Polygon[{{0.064150, 0.001641, -0.005052},{0.064150, 0.000937, -0.003902},{
      0.066516, 0.001312, -0.003902},{0.066299, 0.001982, -0.005052}}],
    Polygon[{{0.064150, 0.000937, -0.003902},{0.064150, 0.000421, -0.002656},{
      0.066676, 0.000821, -0.002656},{0.066516, 0.001312, -0.003902}}],
    Polygon[{{0.064150, 0.000421, -0.002656},{0.064150, 0.000106, -0.001344},{
      0.066773, 0.000521, -0.001344},{0.066676, 0.000821, -0.002656}}],
    Polygon[{{0.064150, 0.000106, -0.001344},{0.064150, 0.000000, 0.000000},{
      0.066806, 0.000421, 0.000000},{0.066773, 0.000521, -0.001344}}],
    Polygon[{{0.064150, 0.000000, 0.000000},{0.064150, 0.000106, 0.001344},{
      0.066773, 0.000521, 0.001344},{0.066806, 0.000421, 0.000000}}],
    Polygon[{{0.064150, 0.000106, 0.001344},{0.064150, 0.000421, 0.002656},{
      0.066676, 0.000821, 0.002656},{0.066773, 0.000521, 0.001344}}],
    Polygon[{{0.064150, 0.000421, 0.002656},{0.064150, 0.000937, 0.003902},{
      0.066516, 0.001312, 0.003902},{0.066676, 0.000821, 0.002656}}],
    Polygon[{{0.064150, 0.000937, 0.003902},{0.064150, 0.001641, 0.005052},{
      0.066299, 0.001982, 0.005052},{0.066516, 0.001312, 0.003902}}],
    Polygon[{{0.064150, 0.001641, 0.005052},{0.064150, 0.002517, 0.006077},{
      0.066028, 0.002815, 0.006077},{0.066299, 0.001982, 0.005052}}],
    Polygon[{{0.064150, 0.002517, 0.006077},{0.064150, 0.003543, 0.006953},{
      0.065711, 0.003790, 0.006953},{0.066028, 0.002815, 0.006077}}],
    Polygon[{{0.064150, 0.003543, 0.006953},{0.064150, 0.004693, 0.007658},{
      0.065356, 0.004884, 0.007658},{0.065711, 0.003790, 0.006953}}],
    Polygon[{{0.064150, 0.004693, 0.007658},{0.064150, 0.005939, 0.008174},{
      0.064971, 0.006069, 0.008174},{0.065356, 0.004884, 0.007658}}],
    Polygon[{{0.064150, 0.005939, 0.008174},{0.064150, 0.007250, 0.008489},{
      0.064565, 0.007316, 0.008489},{0.064971, 0.006069, 0.008174}}],
    Polygon[{{0.064565, 0.007316, -0.008489},{0.064971, 0.006069, -0.008174},{
      0.065711, 0.006446, -0.008174},{0.064940, 0.007507, -0.008489}}],
    Polygon[{{0.064971, 0.006069, -0.008174},{0.065356, 0.004884, -0.007658},{
      0.066443, 0.005438, -0.007658},{0.065711, 0.006446, -0.008174}}],
    Polygon[{{0.065356, 0.004884, -0.007658},{0.065711, 0.003790, -0.006953},{
      0.067119, 0.004508, -0.006953},{0.066443, 0.005438, -0.007658}}],
    Polygon[{{0.065711, 0.003790, -0.006953},{0.066028, 0.002815, -0.006077},{
      0.067722, 0.003678, -0.006077},{0.067119, 0.004508, -0.006953}}],
    Polygon[{{0.066028, 0.002815, -0.006077},{0.066299, 0.001982, -0.005052},{
      0.068237, 0.002969, -0.005052},{0.067722, 0.003678, -0.006077}}],
    Polygon[{{0.066299, 0.001982, -0.005052},{0.066516, 0.001312, -0.003902},{
      0.068651, 0.002399, -0.003902},{0.068237, 0.002969, -0.005052}}],
    Polygon[{{0.066516, 0.001312, -0.003902},{0.066676, 0.000821, -0.002656},{
      0.068954, 0.001982, -0.002656},{0.068651, 0.002399, -0.003902}}],
    Polygon[{{0.066676, 0.000821, -0.002656},{0.066773, 0.000521, -0.001344},{
      0.069140, 0.001727, -0.001344},{0.068954, 0.001982, -0.002656}}],
    Polygon[{{0.066773, 0.000521, -0.001344},{0.066806, 0.000421, 0.000000},{
      0.069202, 0.001641, 0.000000},{0.069140, 0.001727, -0.001344}}],
    Polygon[{{0.066806, 0.000421, 0.000000},{0.066773, 0.000521, 0.001344},{
      0.069140, 0.001727, 0.001344},{0.069202, 0.001641, 0.000000}}],
    Polygon[{{0.066773, 0.000521, 0.001344},{0.066676, 0.000821, 0.002656},{
      0.068954, 0.001982, 0.002656},{0.069140, 0.001727, 0.001344}}],
    Polygon[{{0.066676, 0.000821, 0.002656},{0.066516, 0.001312, 0.003902},{
      0.068651, 0.002399, 0.003902},{0.068954, 0.001982, 0.002656}}],
    Polygon[{{0.066516, 0.001312, 0.003902},{0.066299, 0.001982, 0.005052},{
      0.068237, 0.002969, 0.005052},{0.068651, 0.002399, 0.003902}}],
    Polygon[{{0.066299, 0.001982, 0.005052},{0.066028, 0.002815, 0.006077},{
      0.067722, 0.003678, 0.006077},{0.068237, 0.002969, 0.005052}}],
    Polygon[{{0.066028, 0.002815, 0.006077},{0.065711, 0.003790, 0.006953},{
      0.067119, 0.004508, 0.006953},{0.067722, 0.003678, 0.006077}}],
    Polygon[{{0.065711, 0.003790, 0.006953},{0.065356, 0.004884, 0.007658},{
      0.066443, 0.005438, 0.007658},{0.067119, 0.004508, 0.006953}}],
    Polygon[{{0.065356, 0.004884, 0.007658},{0.064971, 0.006069, 0.008174},{
      0.065711, 0.006446, 0.008174},{0.066443, 0.005438, 0.007658}}],
    Polygon[{{0.064971, 0.006069, 0.008174},{0.064565, 0.007316, 0.008489},{
      0.064940, 0.007507, 0.008489},{0.065711, 0.006446, 0.008174}}],
    Polygon[{{0.064940, 0.007507, -0.008489},{0.065711, 0.006446, -0.008174},{
      0.066299, 0.007033, -0.008174},{0.065238, 0.007804, -0.008489}}],
    Polygon[{{0.065711, 0.006446, -0.008174},{0.066443, 0.005438, -0.007658},{
      0.067307, 0.006301, -0.007658},{0.066299, 0.007033, -0.008174}}],
    Polygon[{{0.066443, 0.005438, -0.007658},{0.067119, 0.004508, -0.006953},{
      0.068237, 0.005625, -0.006953},{0.067307, 0.006301, -0.007658}}],
    Polygon[{{0.067119, 0.004508, -0.006953},{0.067722, 0.003678, -0.006077},{
      0.069067, 0.005022, -0.006077},{0.068237, 0.005625, -0.006953}}],
    Polygon[{{0.067722, 0.003678, -0.006077},{0.068237, 0.002969, -0.005052},{
      0.069775, 0.004508, -0.005052},{0.069067, 0.005022, -0.006077}}],
    Polygon[{{0.068237, 0.002969, -0.005052},{0.068651, 0.002399, -0.003902},{
      0.070345, 0.004093, -0.003902},{0.069775, 0.004508, -0.005052}}],
    Polygon[{{0.068651, 0.002399, -0.003902},{0.068954, 0.001982, -0.002656},{
      0.070763, 0.003790, -0.002656},{0.070345, 0.004093, -0.003902}}],
    Polygon[{{0.068954, 0.001982, -0.002656},{0.069140, 0.001727, -0.001344},{
      0.071018, 0.003605, -0.001344},{0.070763, 0.003790, -0.002656}}],
    Polygon[{{0.069140, 0.001727, -0.001344},{0.069202, 0.001641, 0.000000},{
      0.071103, 0.003543, 0.000000},{0.071018, 0.003605, -0.001344}}],
    Polygon[{{0.069202, 0.001641, 0.000000},{0.069140, 0.001727, 0.001344},{
      0.071018, 0.003605, 0.001344},{0.071103, 0.003543, 0.000000}}],
    Polygon[{{0.069140, 0.001727, 0.001344},{0.068954, 0.001982, 0.002656},{
      0.070763, 0.003790, 0.002656},{0.071018, 0.003605, 0.001344}}],
    Polygon[{{0.068954, 0.001982, 0.002656},{0.068651, 0.002399, 0.003902},{
      0.070345, 0.004093, 0.003902},{0.070763, 0.003790, 0.002656}}],
    Polygon[{{0.068651, 0.002399, 0.003902},{0.068237, 0.002969, 0.005052},{
      0.069775, 0.004508, 0.005052},{0.070345, 0.004093, 0.003902}}],
    Polygon[{{0.068237, 0.002969, 0.005052},{0.067722, 0.003678, 0.006077},{
      0.069067, 0.005022, 0.006077},{0.069775, 0.004508, 0.005052}}],
    Polygon[{{0.067722, 0.003678, 0.006077},{0.067119, 0.004508, 0.006953},{
      0.068237, 0.005625, 0.006953},{0.069067, 0.005022, 0.006077}}],
    Polygon[{{0.067119, 0.004508, 0.006953},{0.066443, 0.005438, 0.007658},{
      0.067307, 0.006301, 0.007658},{0.068237, 0.005625, 0.006953}}],
    Polygon[{{0.066443, 0.005438, 0.007658},{0.065711, 0.006446, 0.008174},{
      0.066299, 0.007033, 0.008174},{0.067307, 0.006301, 0.007658}}],
    Polygon[{{0.065711, 0.006446, 0.008174},{0.064940, 0.007507, 0.008489},{
      0.065238, 0.007804, 0.008489},{0.066299, 0.007033, 0.008174}}],
    Polygon[{{0.065238, 0.007804, -0.008489},{0.066299, 0.007033, -0.008174},{
      0.066676, 0.007774, -0.008174},{0.065429, 0.008179, -0.008489}}],
    Polygon[{{0.066299, 0.007033, -0.008174},{0.067307, 0.006301, -0.007658},{
      0.067861, 0.007389, -0.007658},{0.066676, 0.007774, -0.008174}}],
    Polygon[{{0.067307, 0.006301, -0.007658},{0.068237, 0.005625, -0.006953},{
      0.068954, 0.007033, -0.006953},{0.067861, 0.007389, -0.007658}}],
    Polygon[{{0.068237, 0.005625, -0.006953},{0.069067, 0.005022, -0.006077},{
      0.069930, 0.006717, -0.006077},{0.068954, 0.007033, -0.006953}}],
    Polygon[{{0.069067, 0.005022, -0.006077},{0.069775, 0.004508, -0.005052},{
      0.070763, 0.006446, -0.005052},{0.069930, 0.006717, -0.006077}}],
    Polygon[{{0.069775, 0.004508, -0.005052},{0.070345, 0.004093, -0.003902},{
      0.071433, 0.006228, -0.003902},{0.070763, 0.006446, -0.005052}}],
    Polygon[{{0.070345, 0.004093, -0.003902},{0.070763, 0.003790, -0.002656},{
      0.071924, 0.006069, -0.002656},{0.071433, 0.006228, -0.003902}}],
    Polygon[{{0.070763, 0.003790, -0.002656},{0.071018, 0.003605, -0.001344},{
      0.072223, 0.005971, -0.001344},{0.071924, 0.006069, -0.002656}}],
    Polygon[{{0.071018, 0.003605, -0.001344},{0.071103, 0.003543, 0.000000},{
      0.072324, 0.005939, 0.000000},{0.072223, 0.005971, -0.001344}}],
    Polygon[{{0.071103, 0.003543, 0.000000},{0.071018, 0.003605, 0.001344},{
      0.072223, 0.005971, 0.001344},{0.072324, 0.005939, 0.000000}}],
    Polygon[{{0.071018, 0.003605, 0.001344},{0.070763, 0.003790, 0.002656},{
      0.071924, 0.006069, 0.002656},{0.072223, 0.005971, 0.001344}}],
    Polygon[{{0.070763, 0.003790, 0.002656},{0.070345, 0.004093, 0.003902},{
      0.071433, 0.006228, 0.003902},{0.071924, 0.006069, 0.002656}}],
    Polygon[{{0.070345, 0.004093, 0.003902},{0.069775, 0.004508, 0.005052},{
      0.070763, 0.006446, 0.005052},{0.071433, 0.006228, 0.003902}}],
    Polygon[{{0.069775, 0.004508, 0.005052},{0.069067, 0.005022, 0.006077},{
      0.069930, 0.006717, 0.006077},{0.070763, 0.006446, 0.005052}}],
    Polygon[{{0.069067, 0.005022, 0.006077},{0.068237, 0.005625, 0.006953},{
      0.068954, 0.007033, 0.006953},{0.069930, 0.006717, 0.006077}}],
    Polygon[{{0.068237, 0.005625, 0.006953},{0.067307, 0.006301, 0.007658},{
      0.067861, 0.007389, 0.007658},{0.068954, 0.007033, 0.006953}}],
    Polygon[{{0.067307, 0.006301, 0.007658},{0.066299, 0.007033, 0.008174},{
      0.066676, 0.007774, 0.008174},{0.067861, 0.007389, 0.007658}}],
    Polygon[{{0.066299, 0.007033, 0.008174},{0.065238, 0.007804, 0.008489},{
      0.065429, 0.008179, 0.008489},{0.066676, 0.007774, 0.008174}}],
    Polygon[{{0.065429, 0.008179, -0.008489},{0.066676, 0.007774, -0.008174},{
      0.066806, 0.008594, -0.008174},{0.065495, 0.008594, -0.008489}}],
    Polygon[{{0.066676, 0.007774, -0.008174},{0.067861, 0.007389, -0.007658},{
      0.068052, 0.008594, -0.007658},{0.066806, 0.008594, -0.008174}}],
    Polygon[{{0.067861, 0.007389, -0.007658},{0.068954, 0.007033, -0.006953},{
      0.069202, 0.008594, -0.006953},{0.068052, 0.008594, -0.007658}}],
    Polygon[{{0.068954, 0.007033, -0.006953},{0.069930, 0.006717, -0.006077},{
      0.070227, 0.008594, -0.006077},{0.069202, 0.008594, -0.006953}}],
    Polygon[{{0.069930, 0.006717, -0.006077},{0.070763, 0.006446, -0.005052},{
      0.071103, 0.008594, -0.005052},{0.070227, 0.008594, -0.006077}}],
    Polygon[{{0.070763, 0.006446, -0.005052},{0.071433, 0.006228, -0.003902},{
      0.071808, 0.008594, -0.003902},{0.071103, 0.008594, -0.005052}}],
    Polygon[{{0.071433, 0.006228, -0.003902},{0.071924, 0.006069, -0.002656},{
      0.072324, 0.008594, -0.002656},{0.071808, 0.008594, -0.003902}}],
    Polygon[{{0.071924, 0.006069, -0.002656},{0.072223, 0.005971, -0.001344},{
      0.072639, 0.008594, -0.001344},{0.072324, 0.008594, -0.002656}}],
    Polygon[{{0.072223, 0.005971, -0.001344},{0.072324, 0.005939, 0.000000},{
      0.072745, 0.008594, 0.000000},{0.072639, 0.008594, -0.001344}}],
    Polygon[{{0.072324, 0.005939, 0.000000},{0.072223, 0.005971, 0.001344},{
      0.072639, 0.008594, 0.001344},{0.072745, 0.008594, 0.000000}}],
    Polygon[{{0.072223, 0.005971, 0.001344},{0.071924, 0.006069, 0.002656},{
      0.072324, 0.008594, 0.002656},{0.072639, 0.008594, 0.001344}}],
    Polygon[{{0.071924, 0.006069, 0.002656},{0.071433, 0.006228, 0.003902},{
      0.071808, 0.008594, 0.003902},{0.072324, 0.008594, 0.002656}}],
    Polygon[{{0.071433, 0.006228, 0.003902},{0.070763, 0.006446, 0.005052},{
      0.071103, 0.008594, 0.005052},{0.071808, 0.008594, 0.003902}}],
    Polygon[{{0.070763, 0.006446, 0.005052},{0.069930, 0.006717, 0.006077},{
      0.070227, 0.008594, 0.006077},{0.071103, 0.008594, 0.005052}}],
    Polygon[{{0.069930, 0.006717, 0.006077},{0.068954, 0.007033, 0.006953},{
      0.069202, 0.008594, 0.006953},{0.070227, 0.008594, 0.006077}}],
    Polygon[{{0.068954, 0.007033, 0.006953},{0.067861, 0.007389, 0.007658},{
      0.068052, 0.008594, 0.007658},{0.069202, 0.008594, 0.006953}}],
    Polygon[{{0.067861, 0.007389, 0.007658},{0.066676, 0.007774, 0.008174},{
      0.066806, 0.008594, 0.008174},{0.068052, 0.008594, 0.007658}}],
    Polygon[{{0.066676, 0.007774, 0.008174},{0.065429, 0.008179, 0.008489},{
      0.065495, 0.008594, 0.008489},{0.066806, 0.008594, 0.008174}}],
    Polygon[{{0.040863, 0.051258, -0.008489},{0.042174, 0.051258, -0.008174},{
      0.042044, 0.052079, -0.008174},{0.040797, 0.051674, -0.008489}}],
    Polygon[{{0.042174, 0.051258, -0.008174},{0.043420, 0.051258, -0.007658},{
      0.043229, 0.052464, -0.007658},{0.042044, 0.052079, -0.008174}}],
    Polygon[{{0.043420, 0.051258, -0.007658},{0.044570, 0.051258, -0.006953},{
      0.044323, 0.052819, -0.006953},{0.043229, 0.052464, -0.007658}}],
    Polygon[{{0.044570, 0.051258, -0.006953},{0.045595, 0.051258, -0.006077},{
      0.045298, 0.053136, -0.006077},{0.044323, 0.052819, -0.006953}}],
    Polygon[{{0.045595, 0.051258, -0.006077},{0.046471, 0.051258, -0.005052},{
      0.046131, 0.053407, -0.005052},{0.045298, 0.053136, -0.006077}}],
    Polygon[{{0.046471, 0.051258, -0.005052},{0.047176, 0.051258, -0.003902},{
      0.046801, 0.053625, -0.003902},{0.046131, 0.053407, -0.005052}}],
    Polygon[{{0.047176, 0.051258, -0.003902},{0.047692, 0.051258, -0.002656},{
      0.047292, 0.053784, -0.002656},{0.046801, 0.053625, -0.003902}}],
    Polygon[{{0.047692, 0.051258, -0.002656},{0.048007, 0.051258, -0.001344},{
      0.047591, 0.053881, -0.001344},{0.047292, 0.053784, -0.002656}}],
    Polygon[{{0.048007, 0.051258, -0.001344},{0.048113, 0.051258, 0.000000},{
      0.047692, 0.053914, 0.000000},{0.047591, 0.053881, -0.001344}}],
    Polygon[{{0.048113, 0.051258, 0.000000},{0.048007, 0.051258, 0.001344},{
      0.047591, 0.053881, 0.001344},{0.047692, 0.053914, 0.000000}}],
    Polygon[{{0.048007, 0.051258, 0.001344},{0.047692, 0.051258, 0.002656},{
      0.047292, 0.053784, 0.002656},{0.047591, 0.053881, 0.001344}}],
    Polygon[{{0.047692, 0.051258, 0.002656},{0.047176, 0.051258, 0.003902},{
      0.046801, 0.053625, 0.003902},{0.047292, 0.053784, 0.002656}}],
    Polygon[{{0.047176, 0.051258, 0.003902},{0.046471, 0.051258, 0.005052},{
      0.046131, 0.053407, 0.005052},{0.046801, 0.053625, 0.003902}}],
    Polygon[{{0.046471, 0.051258, 0.005052},{0.045595, 0.051258, 0.006077},{
      0.045298, 0.053136, 0.006077},{0.046131, 0.053407, 0.005052}}],
    Polygon[{{0.045595, 0.051258, 0.006077},{0.044570, 0.051258, 0.006953},{
      0.044323, 0.052819, 0.006953},{0.045298, 0.053136, 0.006077}}],
    Polygon[{{0.044570, 0.051258, 0.006953},{0.043420, 0.051258, 0.007658},{
      0.043229, 0.052464, 0.007658},{0.044323, 0.052819, 0.006953}}],
    Polygon[{{0.043420, 0.051258, 0.007658},{0.042174, 0.051258, 0.008174},{
      0.042044, 0.052079, 0.008174},{0.043229, 0.052464, 0.007658}}],
    Polygon[{{0.042174, 0.051258, 0.008174},{0.040863, 0.051258, 0.008489},{
      0.040797, 0.051674, 0.008489},{0.042044, 0.052079, 0.008174}}],
    Polygon[{{0.040797, 0.051674, -0.008489},{0.042044, 0.052079, -0.008174},{
      0.041667, 0.052819, -0.008174},{0.040606, 0.052049, -0.008489}}],
    Polygon[{{0.042044, 0.052079, -0.008174},{0.043229, 0.052464, -0.007658},{
      0.042675, 0.053552, -0.007658},{0.041667, 0.052819, -0.008174}}],
    Polygon[{{0.043229, 0.052464, -0.007658},{0.044323, 0.052819, -0.006953},{
      0.043605, 0.054228, -0.006953},{0.042675, 0.053552, -0.007658}}],
    Polygon[{{0.044323, 0.052819, -0.006953},{0.045298, 0.053136, -0.006077},{
      0.044435, 0.054830, -0.006077},{0.043605, 0.054228, -0.006953}}],
    Polygon[{{0.045298, 0.053136, -0.006077},{0.046131, 0.053407, -0.005052},{
      0.045143, 0.055345, -0.005052},{0.044435, 0.054830, -0.006077}}],
    Polygon[{{0.046131, 0.053407, -0.005052},{0.046801, 0.053625, -0.003902},{
      0.045713, 0.055759, -0.003902},{0.045143, 0.055345, -0.005052}}],
    Polygon[{{0.046801, 0.053625, -0.003902},{0.047292, 0.053784, -0.002656},{
      0.046131, 0.056063, -0.002656},{0.045713, 0.055759, -0.003902}}],
    Polygon[{{0.047292, 0.053784, -0.002656},{0.047591, 0.053881, -0.001344},{
      0.046386, 0.056248, -0.001344},{0.046131, 0.056063, -0.002656}}],
    Polygon[{{0.047591, 0.053881, -0.001344},{0.047692, 0.053914, 0.000000},{
      0.046471, 0.056310, 0.000000},{0.046386, 0.056248, -0.001344}}],
    Polygon[{{0.047692, 0.053914, 0.000000},{0.047591, 0.053881, 0.001344},{
      0.046386, 0.056248, 0.001344},{0.046471, 0.056310, 0.000000}}],
    Polygon[{{0.047591, 0.053881, 0.001344},{0.047292, 0.053784, 0.002656},{
      0.046131, 0.056063, 0.002656},{0.046386, 0.056248, 0.001344}}],
    Polygon[{{0.047292, 0.053784, 0.002656},{0.046801, 0.053625, 0.003902},{
      0.045713, 0.055759, 0.003902},{0.046131, 0.056063, 0.002656}}],
    Polygon[{{0.046801, 0.053625, 0.003902},{0.046131, 0.053407, 0.005052},{
      0.045143, 0.055345, 0.005052},{0.045713, 0.055759, 0.003902}}],
    Polygon[{{0.046131, 0.053407, 0.005052},{0.045298, 0.053136, 0.006077},{
      0.044435, 0.054830, 0.006077},{0.045143, 0.055345, 0.005052}}],
    Polygon[{{0.045298, 0.053136, 0.006077},{0.044323, 0.052819, 0.006953},{
      0.043605, 0.054228, 0.006953},{0.044435, 0.054830, 0.006077}}],
    Polygon[{{0.044323, 0.052819, 0.006953},{0.043229, 0.052464, 0.007658},{
      0.042675, 0.053552, 0.007658},{0.043605, 0.054228, 0.006953}}],
    Polygon[{{0.043229, 0.052464, 0.007658},{0.042044, 0.052079, 0.008174},{
      0.041667, 0.052819, 0.008174},{0.042675, 0.053552, 0.007658}}],
    Polygon[{{0.042044, 0.052079, 0.008174},{0.040797, 0.051674, 0.008489},{
      0.040606, 0.052049, 0.008489},{0.041667, 0.052819, 0.008174}}],
    Polygon[{{0.040606, 0.052049, -0.008489},{0.041667, 0.052819, -0.008174},{
      0.041079, 0.053407, -0.008174},{0.040308, 0.052346, -0.008489}}],
    Polygon[{{0.041667, 0.052819, -0.008174},{0.042675, 0.053552, -0.007658},{
      0.041811, 0.054415, -0.007658},{0.041079, 0.053407, -0.008174}}],
    Polygon[{{0.042675, 0.053552, -0.007658},{0.043605, 0.054228, -0.006953},{
      0.042487, 0.055345, -0.006953},{0.041811, 0.054415, -0.007658}}],
    Polygon[{{0.043605, 0.054228, -0.006953},{0.044435, 0.054830, -0.006077},{
      0.043090, 0.056175, -0.006077},{0.042487, 0.055345, -0.006953}}],
    Polygon[{{0.044435, 0.054830, -0.006077},{0.045143, 0.055345, -0.005052},{
      0.043605, 0.056883, -0.005052},{0.043090, 0.056175, -0.006077}}],
    Polygon[{{0.045143, 0.055345, -0.005052},{0.045713, 0.055759, -0.003902},{
      0.044019, 0.057454, -0.003902},{0.043605, 0.056883, -0.005052}}],
    Polygon[{{0.045713, 0.055759, -0.003902},{0.046131, 0.056063, -0.002656},{
      0.044323, 0.057871, -0.002656},{0.044019, 0.057454, -0.003902}}],
    Polygon[{{0.046131, 0.056063, -0.002656},{0.046386, 0.056248, -0.001344},{
      0.044508, 0.058126, -0.001344},{0.044323, 0.057871, -0.002656}}],
    Polygon[{{0.046386, 0.056248, -0.001344},{0.046471, 0.056310, 0.000000},{
      0.044570, 0.058211, 0.000000},{0.044508, 0.058126, -0.001344}}],
    Polygon[{{0.046471, 0.056310, 0.000000},{0.046386, 0.056248, 0.001344},{
      0.044508, 0.058126, 0.001344},{0.044570, 0.058211, 0.000000}}],
    Polygon[{{0.046386, 0.056248, 0.001344},{0.046131, 0.056063, 0.002656},{
      0.044323, 0.057871, 0.002656},{0.044508, 0.058126, 0.001344}}],
    Polygon[{{0.046131, 0.056063, 0.002656},{0.045713, 0.055759, 0.003902},{
      0.044019, 0.057454, 0.003902},{0.044323, 0.057871, 0.002656}}],
    Polygon[{{0.045713, 0.055759, 0.003902},{0.045143, 0.055345, 0.005052},{
      0.043605, 0.056883, 0.005052},{0.044019, 0.057454, 0.003902}}],
    Polygon[{{0.045143, 0.055345, 0.005052},{0.044435, 0.054830, 0.006077},{
      0.043090, 0.056175, 0.006077},{0.043605, 0.056883, 0.005052}}],
    Polygon[{{0.044435, 0.054830, 0.006077},{0.043605, 0.054228, 0.006953},{
      0.042487, 0.055345, 0.006953},{0.043090, 0.056175, 0.006077}}],
    Polygon[{{0.043605, 0.054228, 0.006953},{0.042675, 0.053552, 0.007658},{
      0.041811, 0.054415, 0.007658},{0.042487, 0.055345, 0.006953}}],
    Polygon[{{0.042675, 0.053552, 0.007658},{0.041667, 0.052819, 0.008174},{
      0.041079, 0.053407, 0.008174},{0.041811, 0.054415, 0.007658}}],
    Polygon[{{0.041667, 0.052819, 0.008174},{0.040606, 0.052049, 0.008489},{
      0.040308, 0.052346, 0.008489},{0.041079, 0.053407, 0.008174}}],
    Polygon[{{0.040308, 0.052346, -0.008489},{0.041079, 0.053407, -0.008174},{
      0.040339, 0.053784, -0.008174},{0.039934, 0.052537, -0.008489}}],
    Polygon[{{0.041079, 0.053407, -0.008174},{0.041811, 0.054415, -0.007658},{
      0.040724, 0.054969, -0.007658},{0.040339, 0.053784, -0.008174}}],
    Polygon[{{0.041811, 0.054415, -0.007658},{0.042487, 0.055345, -0.006953},{
      0.041079, 0.056063, -0.006953},{0.040724, 0.054969, -0.007658}}],
    Polygon[{{0.042487, 0.055345, -0.006953},{0.043090, 0.056175, -0.006077},{
      0.041396, 0.057038, -0.006077},{0.041079, 0.056063, -0.006953}}],
    Polygon[{{0.043090, 0.056175, -0.006077},{0.043605, 0.056883, -0.005052},{
      0.041667, 0.057871, -0.005052},{0.041396, 0.057038, -0.006077}}],
    Polygon[{{0.043605, 0.056883, -0.005052},{0.044019, 0.057454, -0.003902},{
      0.041884, 0.058541, -0.003902},{0.041667, 0.057871, -0.005052}}],
    Polygon[{{0.044019, 0.057454, -0.003902},{0.044323, 0.057871, -0.002656},{
      0.042044, 0.059032, -0.002656},{0.041884, 0.058541, -0.003902}}],
    Polygon[{{0.044323, 0.057871, -0.002656},{0.044508, 0.058126, -0.001344},{
      0.042141, 0.059332, -0.001344},{0.042044, 0.059032, -0.002656}}],
    Polygon[{{0.044508, 0.058126, -0.001344},{0.044570, 0.058211, 0.000000},{
      0.042174, 0.059432, 0.000000},{0.042141, 0.059332, -0.001344}}],
    Polygon[{{0.044570, 0.058211, 0.000000},{0.044508, 0.058126, 0.001344},{
      0.042141, 0.059332, 0.001344},{0.042174, 0.059432, 0.000000}}],
    Polygon[{{0.044508, 0.058126, 0.001344},{0.044323, 0.057871, 0.002656},{
      0.042044, 0.059032, 0.002656},{0.042141, 0.059332, 0.001344}}],
    Polygon[{{0.044323, 0.057871, 0.002656},{0.044019, 0.057454, 0.003902},{
      0.041884, 0.058541, 0.003902},{0.042044, 0.059032, 0.002656}}],
    Polygon[{{0.044019, 0.057454, 0.003902},{0.043605, 0.056883, 0.005052},{
      0.041667, 0.057871, 0.005052},{0.041884, 0.058541, 0.003902}}],
    Polygon[{{0.043605, 0.056883, 0.005052},{0.043090, 0.056175, 0.006077},{
      0.041396, 0.057038, 0.006077},{0.041667, 0.057871, 0.005052}}],
    Polygon[{{0.043090, 0.056175, 0.006077},{0.042487, 0.055345, 0.006953},{
      0.041079, 0.056063, 0.006953},{0.041396, 0.057038, 0.006077}}],
    Polygon[{{0.042487, 0.055345, 0.006953},{0.041811, 0.054415, 0.007658},{
      0.040724, 0.054969, 0.007658},{0.041079, 0.056063, 0.006953}}],
    Polygon[{{0.041811, 0.054415, 0.007658},{0.041079, 0.053407, 0.008174},{
      0.040339, 0.053784, 0.008174},{0.040724, 0.054969, 0.007658}}],
    Polygon[{{0.041079, 0.053407, 0.008174},{0.040308, 0.052346, 0.008489},{
      0.039934, 0.052537, 0.008489},{0.040339, 0.053784, 0.008174}}],
    Polygon[{{0.039934, 0.052537, -0.008489},{0.040339, 0.053784, -0.008174},{
      0.039518, 0.053914, -0.008174},{0.039518, 0.052603, -0.008489}}],
    Polygon[{{0.040339, 0.053784, -0.008174},{0.040724, 0.054969, -0.007658},{
      0.039518, 0.055160, -0.007658},{0.039518, 0.053914, -0.008174}}],
    Polygon[{{0.040724, 0.054969, -0.007658},{0.041079, 0.056063, -0.006953},{
      0.039518, 0.056310, -0.006953},{0.039518, 0.055160, -0.007658}}],
    Polygon[{{0.041079, 0.056063, -0.006953},{0.041396, 0.057038, -0.006077},{
      0.039518, 0.057336, -0.006077},{0.039518, 0.056310, -0.006953}}],
    Polygon[{{0.041396, 0.057038, -0.006077},{0.041667, 0.057871, -0.005052},{
      0.039518, 0.058211, -0.005052},{0.039518, 0.057336, -0.006077}}],
    Polygon[{{0.041667, 0.057871, -0.005052},{0.041884, 0.058541, -0.003902},{
      0.039518, 0.058916, -0.003902},{0.039518, 0.058211, -0.005052}}],
    Polygon[{{0.041884, 0.058541, -0.003902},{0.042044, 0.059032, -0.002656},{
      0.039518, 0.059432, -0.002656},{0.039518, 0.058916, -0.003902}}],
    Polygon[{{0.042044, 0.059032, -0.002656},{0.042141, 0.059332, -0.001344},{
      0.039518, 0.059747, -0.001344},{0.039518, 0.059432, -0.002656}}],
    Polygon[{{0.042141, 0.059332, -0.001344},{0.042174, 0.059432, 0.000000},{
      0.039518, 0.059853, 0.000000},{0.039518, 0.059747, -0.001344}}],
    Polygon[{{0.042174, 0.059432, 0.000000},{0.042141, 0.059332, 0.001344},{
      0.039518, 0.059747, 0.001344},{0.039518, 0.059853, 0.000000}}],
    Polygon[{{0.042141, 0.059332, 0.001344},{0.042044, 0.059032, 0.002656},{
      0.039518, 0.059432, 0.002656},{0.039518, 0.059747, 0.001344}}],
    Polygon[{{0.042044, 0.059032, 0.002656},{0.041884, 0.058541, 0.003902},{
      0.039518, 0.058916, 0.003902},{0.039518, 0.059432, 0.002656}}],
    Polygon[{{0.041884, 0.058541, 0.003902},{0.041667, 0.057871, 0.005052},{
      0.039518, 0.058211, 0.005052},{0.039518, 0.058916, 0.003902}}],
    Polygon[{{0.041667, 0.057871, 0.005052},{0.041396, 0.057038, 0.006077},{
      0.039518, 0.057336, 0.006077},{0.039518, 0.058211, 0.005052}}],
    Polygon[{{0.041396, 0.057038, 0.006077},{0.041079, 0.056063, 0.006953},{
      0.039518, 0.056310, 0.006953},{0.039518, 0.057336, 0.006077}}],
    Polygon[{{0.041079, 0.056063, 0.006953},{0.040724, 0.054969, 0.007658},{
      0.039518, 0.055160, 0.007658},{0.039518, 0.056310, 0.006953}}],
    Polygon[{{0.040724, 0.054969, 0.007658},{0.040339, 0.053784, 0.008174},{
      0.039518, 0.053914, 0.008174},{0.039518, 0.055160, 0.007658}}],
    Polygon[{{0.040339, 0.053784, 0.008174},{0.039934, 0.052537, 0.008489},{
      0.039518, 0.052603, 0.008489},{0.039518, 0.053914, 0.008174}}],
    Polygon[{{0.039518, 0.052603, -0.008489},{0.039518, 0.053914, -0.008174},{
      0.038697, 0.053784, -0.008174},{0.039103, 0.052537, -0.008489}}],
    Polygon[{{0.039518, 0.053914, -0.008174},{0.039518, 0.055160, -0.007658},{
      0.038312, 0.054969, -0.007658},{0.038697, 0.053784, -0.008174}}],
    Polygon[{{0.039518, 0.055160, -0.007658},{0.039518, 0.056310, -0.006953},{
      0.037957, 0.056063, -0.006953},{0.038312, 0.054969, -0.007658}}],
    Polygon[{{0.039518, 0.056310, -0.006953},{0.039518, 0.057336, -0.006077},{
      0.037640, 0.057038, -0.006077},{0.037957, 0.056063, -0.006953}}],
    Polygon[{{0.039518, 0.057336, -0.006077},{0.039518, 0.058211, -0.005052},{
      0.037369, 0.057871, -0.005052},{0.037640, 0.057038, -0.006077}}],
    Polygon[{{0.039518, 0.058211, -0.005052},{0.039518, 0.058916, -0.003902},{
      0.037152, 0.058541, -0.003902},{0.037369, 0.057871, -0.005052}}],
    Polygon[{{0.039518, 0.058916, -0.003902},{0.039518, 0.059432, -0.002656},{
      0.036992, 0.059032, -0.002656},{0.037152, 0.058541, -0.003902}}],
    Polygon[{{0.039518, 0.059432, -0.002656},{0.039518, 0.059747, -0.001344},{
      0.036895, 0.059332, -0.001344},{0.036992, 0.059032, -0.002656}}],
    Polygon[{{0.039518, 0.059747, -0.001344},{0.039518, 0.059853, 0.000000},{
      0.036862, 0.059432, 0.000000},{0.036895, 0.059332, -0.001344}}],
    Polygon[{{0.039518, 0.059853, 0.000000},{0.039518, 0.059747, 0.001344},{
      0.036895, 0.059332, 0.001344},{0.036862, 0.059432, 0.000000}}],
    Polygon[{{0.039518, 0.059747, 0.001344},{0.039518, 0.059432, 0.002656},{
      0.036992, 0.059032, 0.002656},{0.036895, 0.059332, 0.001344}}],
    Polygon[{{0.039518, 0.059432, 0.002656},{0.039518, 0.058916, 0.003902},{
      0.037152, 0.058541, 0.003902},{0.036992, 0.059032, 0.002656}}],
    Polygon[{{0.039518, 0.058916, 0.003902},{0.039518, 0.058211, 0.005052},{
      0.037369, 0.057871, 0.005052},{0.037152, 0.058541, 0.003902}}],
    Polygon[{{0.039518, 0.058211, 0.005052},{0.039518, 0.057336, 0.006077},{
      0.037640, 0.057038, 0.006077},{0.037369, 0.057871, 0.005052}}],
    Polygon[{{0.039518, 0.057336, 0.006077},{0.039518, 0.056310, 0.006953},{
      0.037957, 0.056063, 0.006953},{0.037640, 0.057038, 0.006077}}],
    Polygon[{{0.039518, 0.056310, 0.006953},{0.039518, 0.055160, 0.007658},{
      0.038312, 0.054969, 0.007658},{0.037957, 0.056063, 0.006953}}],
    Polygon[{{0.039518, 0.055160, 0.007658},{0.039518, 0.053914, 0.008174},{
      0.038697, 0.053784, 0.008174},{0.038312, 0.054969, 0.007658}}],
    Polygon[{{0.039518, 0.053914, 0.008174},{0.039518, 0.052603, 0.008489},{
      0.039103, 0.052537, 0.008489},{0.038697, 0.053784, 0.008174}}],
    Polygon[{{0.039103, 0.052537, -0.008489},{0.038697, 0.053784, -0.008174},{
      0.037957, 0.053407, -0.008174},{0.038728, 0.052346, -0.008489}}],
    Polygon[{{0.038697, 0.053784, -0.008174},{0.038312, 0.054969, -0.007658},{
      0.037225, 0.054415, -0.007658},{0.037957, 0.053407, -0.008174}}],
    Polygon[{{0.038312, 0.054969, -0.007658},{0.037957, 0.056063, -0.006953},{
      0.036549, 0.055345, -0.006953},{0.037225, 0.054415, -0.007658}}],
    Polygon[{{0.037957, 0.056063, -0.006953},{0.037640, 0.057038, -0.006077},{
      0.035946, 0.056175, -0.006077},{0.036549, 0.055345, -0.006953}}],
    Polygon[{{0.037640, 0.057038, -0.006077},{0.037369, 0.057871, -0.005052},{
      0.035431, 0.056883, -0.005052},{0.035946, 0.056175, -0.006077}}],
    Polygon[{{0.037369, 0.057871, -0.005052},{0.037152, 0.058541, -0.003902},{
      0.035017, 0.057454, -0.003902},{0.035431, 0.056883, -0.005052}}],
    Polygon[{{0.037152, 0.058541, -0.003902},{0.036992, 0.059032, -0.002656},{
      0.034714, 0.057871, -0.002656},{0.035017, 0.057454, -0.003902}}],
    Polygon[{{0.036992, 0.059032, -0.002656},{0.036895, 0.059332, -0.001344},{
      0.034529, 0.058126, -0.001344},{0.034714, 0.057871, -0.002656}}],
    Polygon[{{0.036895, 0.059332, -0.001344},{0.036862, 0.059432, 0.000000},{
      0.034466, 0.058211, 0.000000},{0.034529, 0.058126, -0.001344}}],
    Polygon[{{0.036862, 0.059432, 0.000000},{0.036895, 0.059332, 0.001344},{
      0.034529, 0.058126, 0.001344},{0.034466, 0.058211, 0.000000}}],
    Polygon[{{0.036895, 0.059332, 0.001344},{0.036992, 0.059032, 0.002656},{
      0.034714, 0.057871, 0.002656},{0.034529, 0.058126, 0.001344}}],
    Polygon[{{0.036992, 0.059032, 0.002656},{0.037152, 0.058541, 0.003902},{
      0.035017, 0.057454, 0.003902},{0.034714, 0.057871, 0.002656}}],
    Polygon[{{0.037152, 0.058541, 0.003902},{0.037369, 0.057871, 0.005052},{
      0.035431, 0.056883, 0.005052},{0.035017, 0.057454, 0.003902}}],
    Polygon[{{0.037369, 0.057871, 0.005052},{0.037640, 0.057038, 0.006077},{
      0.035946, 0.056175, 0.006077},{0.035431, 0.056883, 0.005052}}],
    Polygon[{{0.037640, 0.057038, 0.006077},{0.037957, 0.056063, 0.006953},{
      0.036549, 0.055345, 0.006953},{0.035946, 0.056175, 0.006077}}],
    Polygon[{{0.037957, 0.056063, 0.006953},{0.038312, 0.054969, 0.007658},{
      0.037225, 0.054415, 0.007658},{0.036549, 0.055345, 0.006953}}],
    Polygon[{{0.038312, 0.054969, 0.007658},{0.038697, 0.053784, 0.008174},{
      0.037957, 0.053407, 0.008174},{0.037225, 0.054415, 0.007658}}],
    Polygon[{{0.038697, 0.053784, 0.008174},{0.039103, 0.052537, 0.008489},{
      0.038728, 0.052346, 0.008489},{0.037957, 0.053407, 0.008174}}],
    Polygon[{{0.038728, 0.052346, -0.008489},{0.037957, 0.053407, -0.008174},{
      0.037369, 0.052819, -0.008174},{0.038430, 0.052049, -0.008489}}],
    Polygon[{{0.037957, 0.053407, -0.008174},{0.037225, 0.054415, -0.007658},{
      0.036361, 0.053552, -0.007658},{0.037369, 0.052819, -0.008174}}],
    Polygon[{{0.037225, 0.054415, -0.007658},{0.036549, 0.055345, -0.006953},{
      0.035431, 0.054228, -0.006953},{0.036361, 0.053552, -0.007658}}],
    Polygon[{{0.036549, 0.055345, -0.006953},{0.035946, 0.056175, -0.006077},{
      0.034601, 0.054830, -0.006077},{0.035431, 0.054228, -0.006953}}],
    Polygon[{{0.035946, 0.056175, -0.006077},{0.035431, 0.056883, -0.005052},{
      0.033893, 0.055345, -0.005052},{0.034601, 0.054830, -0.006077}}],
    Polygon[{{0.035431, 0.056883, -0.005052},{0.035017, 0.057454, -0.003902},{
      0.033323, 0.055759, -0.003902},{0.033893, 0.055345, -0.005052}}],
    Polygon[{{0.035017, 0.057454, -0.003902},{0.034714, 0.057871, -0.002656},{
      0.032905, 0.056063, -0.002656},{0.033323, 0.055759, -0.003902}}],
    Polygon[{{0.034714, 0.057871, -0.002656},{0.034529, 0.058126, -0.001344},{
      0.032651, 0.056248, -0.001344},{0.032905, 0.056063, -0.002656}}],
    Polygon[{{0.034529, 0.058126, -0.001344},{0.034466, 0.058211, 0.000000},{
      0.032565, 0.056310, 0.000000},{0.032651, 0.056248, -0.001344}}],
    Polygon[{{0.034466, 0.058211, 0.000000},{0.034529, 0.058126, 0.001344},{
      0.032651, 0.056248, 0.001344},{0.032565, 0.056310, 0.000000}}],
    Polygon[{{0.034529, 0.058126, 0.001344},{0.034714, 0.057871, 0.002656},{
      0.032905, 0.056063, 0.002656},{0.032651, 0.056248, 0.001344}}],
    Polygon[{{0.034714, 0.057871, 0.002656},{0.035017, 0.057454, 0.003902},{
      0.033323, 0.055759, 0.003902},{0.032905, 0.056063, 0.002656}}],
    Polygon[{{0.035017, 0.057454, 0.003902},{0.035431, 0.056883, 0.005052},{
      0.033893, 0.055345, 0.005052},{0.033323, 0.055759, 0.003902}}],
    Polygon[{{0.035431, 0.056883, 0.005052},{0.035946, 0.056175, 0.006077},{
      0.034601, 0.054830, 0.006077},{0.033893, 0.055345, 0.005052}}],
    Polygon[{{0.035946, 0.056175, 0.006077},{0.036549, 0.055345, 0.006953},{
      0.035431, 0.054228, 0.006953},{0.034601, 0.054830, 0.006077}}],
    Polygon[{{0.036549, 0.055345, 0.006953},{0.037225, 0.054415, 0.007658},{
      0.036361, 0.053552, 0.007658},{0.035431, 0.054228, 0.006953}}],
    Polygon[{{0.037225, 0.054415, 0.007658},{0.037957, 0.053407, 0.008174},{
      0.037369, 0.052819, 0.008174},{0.036361, 0.053552, 0.007658}}],
    Polygon[{{0.037957, 0.053407, 0.008174},{0.038728, 0.052346, 0.008489},{
      0.038430, 0.052049, 0.008489},{0.037369, 0.052819, 0.008174}}],
    Polygon[{{0.038430, 0.052049, -0.008489},{0.037369, 0.052819, -0.008174},{
      0.036992, 0.052079, -0.008174},{0.038239, 0.051674, -0.008489}}],
    Polygon[{{0.037369, 0.052819, -0.008174},{0.036361, 0.053552, -0.007658},{
      0.035807, 0.052464, -0.007658},{0.036992, 0.052079, -0.008174}}],
    Polygon[{{0.036361, 0.053552, -0.007658},{0.035431, 0.054228, -0.006953},{
      0.034714, 0.052819, -0.006953},{0.035807, 0.052464, -0.007658}}],
    Polygon[{{0.035431, 0.054228, -0.006953},{0.034601, 0.054830, -0.006077},{
      0.033738, 0.053136, -0.006077},{0.034714, 0.052819, -0.006953}}],
    Polygon[{{0.034601, 0.054830, -0.006077},{0.033893, 0.055345, -0.005052},{
      0.032905, 0.053407, -0.005052},{0.033738, 0.053136, -0.006077}}],
    Polygon[{{0.033893, 0.055345, -0.005052},{0.033323, 0.055759, -0.003902},{
      0.032235, 0.053625, -0.003902},{0.032905, 0.053407, -0.005052}}],
    Polygon[{{0.033323, 0.055759, -0.003902},{0.032905, 0.056063, -0.002656},{
      0.031744, 0.053784, -0.002656},{0.032235, 0.053625, -0.003902}}],
    Polygon[{{0.032905, 0.056063, -0.002656},{0.032651, 0.056248, -0.001344},{
      0.031445, 0.053881, -0.001344},{0.031744, 0.053784, -0.002656}}],
    Polygon[{{0.032651, 0.056248, -0.001344},{0.032565, 0.056310, 0.000000},{
      0.031344, 0.053914, 0.000000},{0.031445, 0.053881, -0.001344}}],
    Polygon[{{0.032565, 0.056310, 0.000000},{0.032651, 0.056248, 0.001344},{
      0.031445, 0.053881, 0.001344},{0.031344, 0.053914, 0.000000}}],
    Polygon[{{0.032651, 0.056248, 0.001344},{0.032905, 0.056063, 0.002656},{
      0.031744, 0.053784, 0.002656},{0.031445, 0.053881, 0.001344}}],
    Polygon[{{0.032905, 0.056063, 0.002656},{0.033323, 0.055759, 0.003902},{
      0.032235, 0.053625, 0.003902},{0.031744, 0.053784, 0.002656}}],
    Polygon[{{0.033323, 0.055759, 0.003902},{0.033893, 0.055345, 0.005052},{
      0.032905, 0.053407, 0.005052},{0.032235, 0.053625, 0.003902}}],
    Polygon[{{0.033893, 0.055345, 0.005052},{0.034601, 0.054830, 0.006077},{
      0.033738, 0.053136, 0.006077},{0.032905, 0.053407, 0.005052}}],
    Polygon[{{0.034601, 0.054830, 0.006077},{0.035431, 0.054228, 0.006953},{
      0.034714, 0.052819, 0.006953},{0.033738, 0.053136, 0.006077}}],
    Polygon[{{0.035431, 0.054228, 0.006953},{0.036361, 0.053552, 0.007658},{
      0.035807, 0.052464, 0.007658},{0.034714, 0.052819, 0.006953}}],
    Polygon[{{0.036361, 0.053552, 0.007658},{0.037369, 0.052819, 0.008174},{
      0.036992, 0.052079, 0.008174},{0.035807, 0.052464, 0.007658}}],
    Polygon[{{0.037369, 0.052819, 0.008174},{0.038430, 0.052049, 0.008489},{
      0.038239, 0.051674, 0.008489},{0.036992, 0.052079, 0.008174}}],
    Polygon[{{0.038239, 0.051674, -0.008489},{0.036992, 0.052079, -0.008174},{
      0.036862, 0.051258, -0.008174},{0.038174, 0.051258, -0.008489}}],
    Polygon[{{0.036992, 0.052079, -0.008174},{0.035807, 0.052464, -0.007658},{
      0.035616, 0.051258, -0.007658},{0.036862, 0.051258, -0.008174}}],
    Polygon[{{0.035807, 0.052464, -0.007658},{0.034714, 0.052819, -0.006953},{
      0.034466, 0.051258, -0.006953},{0.035616, 0.051258, -0.007658}}],
    Polygon[{{0.034714, 0.052819, -0.006953},{0.033738, 0.053136, -0.006077},{
      0.033441, 0.051258, -0.006077},{0.034466, 0.051258, -0.006953}}],
    Polygon[{{0.033738, 0.053136, -0.006077},{0.032905, 0.053407, -0.005052},{
      0.032565, 0.051258, -0.005052},{0.033441, 0.051258, -0.006077}}],
    Polygon[{{0.032905, 0.053407, -0.005052},{0.032235, 0.053625, -0.003902},{
      0.031860, 0.051258, -0.003902},{0.032565, 0.051258, -0.005052}}],
    Polygon[{{0.032235, 0.053625, -0.003902},{0.031744, 0.053784, -0.002656},{
      0.031344, 0.051258, -0.002656},{0.031860, 0.051258, -0.003902}}],
    Polygon[{{0.031744, 0.053784, -0.002656},{0.031445, 0.053881, -0.001344},{
      0.031029, 0.051258, -0.001344},{0.031344, 0.051258, -0.002656}}],
    Polygon[{{0.031445, 0.053881, -0.001344},{0.031344, 0.053914, 0.000000},{
      0.030924, 0.051258, 0.000000},{0.031029, 0.051258, -0.001344}}],
    Polygon[{{0.031344, 0.053914, 0.000000},{0.031445, 0.053881, 0.001344},{
      0.031029, 0.051258, 0.001344},{0.030924, 0.051258, 0.000000}}],
    Polygon[{{0.031445, 0.053881, 0.001344},{0.031744, 0.053784, 0.002656},{
      0.031344, 0.051258, 0.002656},{0.031029, 0.051258, 0.001344}}],
    Polygon[{{0.031744, 0.053784, 0.002656},{0.032235, 0.053625, 0.003902},{
      0.031860, 0.051258, 0.003902},{0.031344, 0.051258, 0.002656}}],
    Polygon[{{0.032235, 0.053625, 0.003902},{0.032905, 0.053407, 0.005052},{
      0.032565, 0.051258, 0.005052},{0.031860, 0.051258, 0.003902}}],
    Polygon[{{0.032905, 0.053407, 0.005052},{0.033738, 0.053136, 0.006077},{
      0.033441, 0.051258, 0.006077},{0.032565, 0.051258, 0.005052}}],
    Polygon[{{0.033738, 0.053136, 0.006077},{0.034714, 0.052819, 0.006953},{
      0.034466, 0.051258, 0.006953},{0.033441, 0.051258, 0.006077}}],
    Polygon[{{0.034714, 0.052819, 0.006953},{0.035807, 0.052464, 0.007658},{
      0.035616, 0.051258, 0.007658},{0.034466, 0.051258, 0.006953}}],
    Polygon[{{0.035807, 0.052464, 0.007658},{0.036992, 0.052079, 0.008174},{
      0.036862, 0.051258, 0.008174},{0.035616, 0.051258, 0.007658}}],
    Polygon[{{0.036992, 0.052079, 0.008174},{0.038239, 0.051674, 0.008489},{
      0.038174, 0.051258, 0.008489},{0.036862, 0.051258, 0.008174}}],
    Polygon[{{0.038174, 0.051258, -0.008489},{0.036862, 0.051258, -0.008174},{
      0.036992, 0.050438, -0.008174},{0.038239, 0.050843, -0.008489}}],
    Polygon[{{0.036862, 0.051258, -0.008174},{0.035616, 0.051258, -0.007658},{
      0.035807, 0.050053, -0.007658},{0.036992, 0.050438, -0.008174}}],
    Polygon[{{0.035616, 0.051258, -0.007658},{0.034466, 0.051258, -0.006953},{
      0.034714, 0.049697, -0.006953},{0.035807, 0.050053, -0.007658}}],
    Polygon[{{0.034466, 0.051258, -0.006953},{0.033441, 0.051258, -0.006077},{
      0.033738, 0.049380, -0.006077},{0.034714, 0.049697, -0.006953}}],
    Polygon[{{0.033441, 0.051258, -0.006077},{0.032565, 0.051258, -0.005052},{
      0.032905, 0.049110, -0.005052},{0.033738, 0.049380, -0.006077}}],
    Polygon[{{0.032565, 0.051258, -0.005052},{0.031860, 0.051258, -0.003902},{
      0.032235, 0.048892, -0.003902},{0.032905, 0.049110, -0.005052}}],
    Polygon[{{0.031860, 0.051258, -0.003902},{0.031344, 0.051258, -0.002656},{
      0.031744, 0.048732, -0.002656},{0.032235, 0.048892, -0.003902}}],
    Polygon[{{0.031344, 0.051258, -0.002656},{0.031029, 0.051258, -0.001344},{
      0.031445, 0.048635, -0.001344},{0.031744, 0.048732, -0.002656}}],
    Polygon[{{0.031029, 0.051258, -0.001344},{0.030924, 0.051258, 0.000000},{
      0.031344, 0.048602, 0.000000},{0.031445, 0.048635, -0.001344}}],
    Polygon[{{0.030924, 0.051258, 0.000000},{0.031029, 0.051258, 0.001344},{
      0.031445, 0.048635, 0.001344},{0.031344, 0.048602, 0.000000}}],
    Polygon[{{0.031029, 0.051258, 0.001344},{0.031344, 0.051258, 0.002656},{
      0.031744, 0.048732, 0.002656},{0.031445, 0.048635, 0.001344}}],
    Polygon[{{0.031344, 0.051258, 0.002656},{0.031860, 0.051258, 0.003902},{
      0.032235, 0.048892, 0.003902},{0.031744, 0.048732, 0.002656}}],
    Polygon[{{0.031860, 0.051258, 0.003902},{0.032565, 0.051258, 0.005052},{
      0.032905, 0.049110, 0.005052},{0.032235, 0.048892, 0.003902}}],
    Polygon[{{0.032565, 0.051258, 0.005052},{0.033441, 0.051258, 0.006077},{
      0.033738, 0.049380, 0.006077},{0.032905, 0.049110, 0.005052}}],
    Polygon[{{0.033441, 0.051258, 0.006077},{0.034466, 0.051258, 0.006953},{
      0.034714, 0.049697, 0.006953},{0.033738, 0.049380, 0.006077}}],
    Polygon[{{0.034466, 0.051258, 0.006953},{0.035616, 0.051258, 0.007658},{
      0.035807, 0.050053, 0.007658},{0.034714, 0.049697, 0.006953}}],
    Polygon[{{0.035616, 0.051258, 0.007658},{0.036862, 0.051258, 0.008174},{
      0.036992, 0.050438, 0.008174},{0.035807, 0.050053, 0.007658}}],
    Polygon[{{0.036862, 0.051258, 0.008174},{0.038174, 0.051258, 0.008489},{
      0.038239, 0.050843, 0.008489},{0.036992, 0.050438, 0.008174}}],
    Polygon[{{0.038239, 0.050843, -0.008489},{0.036992, 0.050438, -0.008174},{
      0.037369, 0.049697, -0.008174},{0.038430, 0.050468, -0.008489}}],
    Polygon[{{0.036992, 0.050438, -0.008174},{0.035807, 0.050053, -0.007658},{
      0.036361, 0.048965, -0.007658},{0.037369, 0.049697, -0.008174}}],
    Polygon[{{0.035807, 0.050053, -0.007658},{0.034714, 0.049697, -0.006953},{
      0.035431, 0.048289, -0.006953},{0.036361, 0.048965, -0.007658}}],
    Polygon[{{0.034714, 0.049697, -0.006953},{0.033738, 0.049380, -0.006077},{
      0.034601, 0.047686, -0.006077},{0.035431, 0.048289, -0.006953}}],
    Polygon[{{0.033738, 0.049380, -0.006077},{0.032905, 0.049110, -0.005052},{
      0.033893, 0.047171, -0.005052},{0.034601, 0.047686, -0.006077}}],
    Polygon[{{0.032905, 0.049110, -0.005052},{0.032235, 0.048892, -0.003902},{
      0.033323, 0.046757, -0.003902},{0.033893, 0.047171, -0.005052}}],
    Polygon[{{0.032235, 0.048892, -0.003902},{0.031744, 0.048732, -0.002656},{
      0.032905, 0.046454, -0.002656},{0.033323, 0.046757, -0.003902}}],
    Polygon[{{0.031744, 0.048732, -0.002656},{0.031445, 0.048635, -0.001344},{
      0.032651, 0.046269, -0.001344},{0.032905, 0.046454, -0.002656}}],
    Polygon[{{0.031445, 0.048635, -0.001344},{0.031344, 0.048602, 0.000000},{
      0.032565, 0.046207, 0.000000},{0.032651, 0.046269, -0.001344}}],
    Polygon[{{0.031344, 0.048602, 0.000000},{0.031445, 0.048635, 0.001344},{
      0.032651, 0.046269, 0.001344},{0.032565, 0.046207, 0.000000}}],
    Polygon[{{0.031445, 0.048635, 0.001344},{0.031744, 0.048732, 0.002656},{
      0.032905, 0.046454, 0.002656},{0.032651, 0.046269, 0.001344}}],
    Polygon[{{0.031744, 0.048732, 0.002656},{0.032235, 0.048892, 0.003902},{
      0.033323, 0.046757, 0.003902},{0.032905, 0.046454, 0.002656}}],
    Polygon[{{0.032235, 0.048892, 0.003902},{0.032905, 0.049110, 0.005052},{
      0.033893, 0.047171, 0.005052},{0.033323, 0.046757, 0.003902}}],
    Polygon[{{0.032905, 0.049110, 0.005052},{0.033738, 0.049380, 0.006077},{
      0.034601, 0.047686, 0.006077},{0.033893, 0.047171, 0.005052}}],
    Polygon[{{0.033738, 0.049380, 0.006077},{0.034714, 0.049697, 0.006953},{
      0.035431, 0.048289, 0.006953},{0.034601, 0.047686, 0.006077}}],
    Polygon[{{0.034714, 0.049697, 0.006953},{0.035807, 0.050053, 0.007658},{
      0.036361, 0.048965, 0.007658},{0.035431, 0.048289, 0.006953}}],
    Polygon[{{0.035807, 0.050053, 0.007658},{0.036992, 0.050438, 0.008174},{
      0.037369, 0.049697, 0.008174},{0.036361, 0.048965, 0.007658}}],
    Polygon[{{0.036992, 0.050438, 0.008174},{0.038239, 0.050843, 0.008489},{
      0.038430, 0.050468, 0.008489},{0.037369, 0.049697, 0.008174}}],
    Polygon[{{0.038430, 0.050468, -0.008489},{0.037369, 0.049697, -0.008174},{
      0.037957, 0.049110, -0.008174},{0.038728, 0.050171, -0.008489}}],
    Polygon[{{0.037369, 0.049697, -0.008174},{0.036361, 0.048965, -0.007658},{
      0.037225, 0.048102, -0.007658},{0.037957, 0.049110, -0.008174}}],
    Polygon[{{0.036361, 0.048965, -0.007658},{0.035431, 0.048289, -0.006953},{
      0.036549, 0.047171, -0.006953},{0.037225, 0.048102, -0.007658}}],
    Polygon[{{0.035431, 0.048289, -0.006953},{0.034601, 0.047686, -0.006077},{
      0.035946, 0.046342, -0.006077},{0.036549, 0.047171, -0.006953}}],
    Polygon[{{0.034601, 0.047686, -0.006077},{0.033893, 0.047171, -0.005052},{
      0.035431, 0.045633, -0.005052},{0.035946, 0.046342, -0.006077}}],
    Polygon[{{0.033893, 0.047171, -0.005052},{0.033323, 0.046757, -0.003902},{
      0.035017, 0.045063, -0.003902},{0.035431, 0.045633, -0.005052}}],
    Polygon[{{0.033323, 0.046757, -0.003902},{0.032905, 0.046454, -0.002656},{
      0.034714, 0.044646, -0.002656},{0.035017, 0.045063, -0.003902}}],
    Polygon[{{0.032905, 0.046454, -0.002656},{0.032651, 0.046269, -0.001344},{
      0.034529, 0.044391, -0.001344},{0.034714, 0.044646, -0.002656}}],
    Polygon[{{0.032651, 0.046269, -0.001344},{0.032565, 0.046207, 0.000000},{
      0.034466, 0.044305, 0.000000},{0.034529, 0.044391, -0.001344}}],
    Polygon[{{0.032565, 0.046207, 0.000000},{0.032651, 0.046269, 0.001344},{
      0.034529, 0.044391, 0.001344},{0.034466, 0.044305, 0.000000}}],
    Polygon[{{0.032651, 0.046269, 0.001344},{0.032905, 0.046454, 0.002656},{
      0.034714, 0.044646, 0.002656},{0.034529, 0.044391, 0.001344}}],
    Polygon[{{0.032905, 0.046454, 0.002656},{0.033323, 0.046757, 0.003902},{
      0.035017, 0.045063, 0.003902},{0.034714, 0.044646, 0.002656}}],
    Polygon[{{0.033323, 0.046757, 0.003902},{0.033893, 0.047171, 0.005052},{
      0.035431, 0.045633, 0.005052},{0.035017, 0.045063, 0.003902}}],
    Polygon[{{0.033893, 0.047171, 0.005052},{0.034601, 0.047686, 0.006077},{
      0.035946, 0.046342, 0.006077},{0.035431, 0.045633, 0.005052}}],
    Polygon[{{0.034601, 0.047686, 0.006077},{0.035431, 0.048289, 0.006953},{
      0.036549, 0.047171, 0.006953},{0.035946, 0.046342, 0.006077}}],
    Polygon[{{0.035431, 0.048289, 0.006953},{0.036361, 0.048965, 0.007658},{
      0.037225, 0.048102, 0.007658},{0.036549, 0.047171, 0.006953}}],
    Polygon[{{0.036361, 0.048965, 0.007658},{0.037369, 0.049697, 0.008174},{
      0.037957, 0.049110, 0.008174},{0.037225, 0.048102, 0.007658}}],
    Polygon[{{0.037369, 0.049697, 0.008174},{0.038430, 0.050468, 0.008489},{
      0.038728, 0.050171, 0.008489},{0.037957, 0.049110, 0.008174}}],
    Polygon[{{0.038728, 0.050171, -0.008489},{0.037957, 0.049110, -0.008174},{
      0.038697, 0.048732, -0.008174},{0.039103, 0.049980, -0.008489}}],
    Polygon[{{0.037957, 0.049110, -0.008174},{0.037225, 0.048102, -0.007658},{
      0.038312, 0.047547, -0.007658},{0.038697, 0.048732, -0.008174}}],
    Polygon[{{0.037225, 0.048102, -0.007658},{0.036549, 0.047171, -0.006953},{
      0.037957, 0.046454, -0.006953},{0.038312, 0.047547, -0.007658}}],
    Polygon[{{0.036549, 0.047171, -0.006953},{0.035946, 0.046342, -0.006077},{
      0.037640, 0.045479, -0.006077},{0.037957, 0.046454, -0.006953}}],
    Polygon[{{0.035946, 0.046342, -0.006077},{0.035431, 0.045633, -0.005052},{
      0.037369, 0.044646, -0.005052},{0.037640, 0.045479, -0.006077}}],
    Polygon[{{0.035431, 0.045633, -0.005052},{0.035017, 0.045063, -0.003902},{
      0.037152, 0.043975, -0.003902},{0.037369, 0.044646, -0.005052}}],
    Polygon[{{0.035017, 0.045063, -0.003902},{0.034714, 0.044646, -0.002656},{
      0.036992, 0.043485, -0.002656},{0.037152, 0.043975, -0.003902}}],
    Polygon[{{0.034714, 0.044646, -0.002656},{0.034529, 0.044391, -0.001344},{
      0.036895, 0.043185, -0.001344},{0.036992, 0.043485, -0.002656}}],
    Polygon[{{0.034529, 0.044391, -0.001344},{0.034466, 0.044305, 0.000000},{
      0.036862, 0.043084, 0.000000},{0.036895, 0.043185, -0.001344}}],
    Polygon[{{0.034466, 0.044305, 0.000000},{0.034529, 0.044391, 0.001344},{
      0.036895, 0.043185, 0.001344},{0.036862, 0.043084, 0.000000}}],
    Polygon[{{0.034529, 0.044391, 0.001344},{0.034714, 0.044646, 0.002656},{
      0.036992, 0.043485, 0.002656},{0.036895, 0.043185, 0.001344}}],
    Polygon[{{0.034714, 0.044646, 0.002656},{0.035017, 0.045063, 0.003902},{
      0.037152, 0.043975, 0.003902},{0.036992, 0.043485, 0.002656}}],
    Polygon[{{0.035017, 0.045063, 0.003902},{0.035431, 0.045633, 0.005052},{
      0.037369, 0.044646, 0.005052},{0.037152, 0.043975, 0.003902}}],
    Polygon[{{0.035431, 0.045633, 0.005052},{0.035946, 0.046342, 0.006077},{
      0.037640, 0.045479, 0.006077},{0.037369, 0.044646, 0.005052}}],
    Polygon[{{0.035946, 0.046342, 0.006077},{0.036549, 0.047171, 0.006953},{
      0.037957, 0.046454, 0.006953},{0.037640, 0.045479, 0.006077}}],
    Polygon[{{0.036549, 0.047171, 0.006953},{0.037225, 0.048102, 0.007658},{
      0.038312, 0.047547, 0.007658},{0.037957, 0.046454, 0.006953}}],
    Polygon[{{0.037225, 0.048102, 0.007658},{0.037957, 0.049110, 0.008174},{
      0.038697, 0.048732, 0.008174},{0.038312, 0.047547, 0.007658}}],
    Polygon[{{0.037957, 0.049110, 0.008174},{0.038728, 0.050171, 0.008489},{
      0.039103, 0.049980, 0.008489},{0.038697, 0.048732, 0.008174}}],
    Polygon[{{0.039103, 0.049980, -0.008489},{0.038697, 0.048732, -0.008174},{
      0.039518, 0.048602, -0.008174},{0.039518, 0.049914, -0.008489}}],
    Polygon[{{0.038697, 0.048732, -0.008174},{0.038312, 0.047547, -0.007658},{
      0.039518, 0.047357, -0.007658},{0.039518, 0.048602, -0.008174}}],
    Polygon[{{0.038312, 0.047547, -0.007658},{0.037957, 0.046454, -0.006953},{
      0.039518, 0.046207, -0.006953},{0.039518, 0.047357, -0.007658}}],
    Polygon[{{0.037957, 0.046454, -0.006953},{0.037640, 0.045479, -0.006077},{
      0.039518, 0.045181, -0.006077},{0.039518, 0.046207, -0.006953}}],
    Polygon[{{0.037640, 0.045479, -0.006077},{0.037369, 0.044646, -0.005052},{
      0.039518, 0.044305, -0.005052},{0.039518, 0.045181, -0.006077}}],
    Polygon[{{0.037369, 0.044646, -0.005052},{0.037152, 0.043975, -0.003902},{
      0.039518, 0.043601, -0.003902},{0.039518, 0.044305, -0.005052}}],
    Polygon[{{0.037152, 0.043975, -0.003902},{0.036992, 0.043485, -0.002656},{
      0.039518, 0.043084, -0.002656},{0.039518, 0.043601, -0.003902}}],
    Polygon[{{0.036992, 0.043485, -0.002656},{0.036895, 0.043185, -0.001344},{
      0.039518, 0.042770, -0.001344},{0.039518, 0.043084, -0.002656}}],
    Polygon[{{0.036895, 0.043185, -0.001344},{0.036862, 0.043084, 0.000000},{
      0.039518, 0.042664, 0.000000},{0.039518, 0.042770, -0.001344}}],
    Polygon[{{0.036862, 0.043084, 0.000000},{0.036895, 0.043185, 0.001344},{
      0.039518, 0.042770, 0.001344},{0.039518, 0.042664, 0.000000}}],
    Polygon[{{0.036895, 0.043185, 0.001344},{0.036992, 0.043485, 0.002656},{
      0.039518, 0.043084, 0.002656},{0.039518, 0.042770, 0.001344}}],
    Polygon[{{0.036992, 0.043485, 0.002656},{0.037152, 0.043975, 0.003902},{
      0.039518, 0.043601, 0.003902},{0.039518, 0.043084, 0.002656}}],
    Polygon[{{0.037152, 0.043975, 0.003902},{0.037369, 0.044646, 0.005052},{
      0.039518, 0.044305, 0.005052},{0.039518, 0.043601, 0.003902}}],
    Polygon[{{0.037369, 0.044646, 0.005052},{0.037640, 0.045479, 0.006077},{
      0.039518, 0.045181, 0.006077},{0.039518, 0.044305, 0.005052}}],
    Polygon[{{0.037640, 0.045479, 0.006077},{0.037957, 0.046454, 0.006953},{
      0.039518, 0.046207, 0.006953},{0.039518, 0.045181, 0.006077}}],
    Polygon[{{0.037957, 0.046454, 0.006953},{0.038312, 0.047547, 0.007658},{
      0.039518, 0.047357, 0.007658},{0.039518, 0.046207, 0.006953}}],
    Polygon[{{0.038312, 0.047547, 0.007658},{0.038697, 0.048732, 0.008174},{
      0.039518, 0.048602, 0.008174},{0.039518, 0.047357, 0.007658}}],
    Polygon[{{0.038697, 0.048732, 0.008174},{0.039103, 0.049980, 0.008489},{
      0.039518, 0.049914, 0.008489},{0.039518, 0.048602, 0.008174}}],
    Polygon[{{0.039518, 0.049914, -0.008489},{0.039518, 0.048602, -0.008174},{
      0.040339, 0.048732, -0.008174},{0.039934, 0.049980, -0.008489}}],
    Polygon[{{0.039518, 0.048602, -0.008174},{0.039518, 0.047357, -0.007658},{
      0.040724, 0.047547, -0.007658},{0.040339, 0.048732, -0.008174}}],
    Polygon[{{0.039518, 0.047357, -0.007658},{0.039518, 0.046207, -0.006953},{
      0.041079, 0.046454, -0.006953},{0.040724, 0.047547, -0.007658}}],
    Polygon[{{0.039518, 0.046207, -0.006953},{0.039518, 0.045181, -0.006077},{
      0.041396, 0.045479, -0.006077},{0.041079, 0.046454, -0.006953}}],
    Polygon[{{0.039518, 0.045181, -0.006077},{0.039518, 0.044305, -0.005052},{
      0.041667, 0.044646, -0.005052},{0.041396, 0.045479, -0.006077}}],
    Polygon[{{0.039518, 0.044305, -0.005052},{0.039518, 0.043601, -0.003902},{
      0.041884, 0.043975, -0.003902},{0.041667, 0.044646, -0.005052}}],
    Polygon[{{0.039518, 0.043601, -0.003902},{0.039518, 0.043084, -0.002656},{
      0.042044, 0.043485, -0.002656},{0.041884, 0.043975, -0.003902}}],
    Polygon[{{0.039518, 0.043084, -0.002656},{0.039518, 0.042770, -0.001344},{
      0.042141, 0.043185, -0.001344},{0.042044, 0.043485, -0.002656}}],
    Polygon[{{0.039518, 0.042770, -0.001344},{0.039518, 0.042664, 0.000000},{
      0.042174, 0.043084, 0.000000},{0.042141, 0.043185, -0.001344}}],
    Polygon[{{0.039518, 0.042664, 0.000000},{0.039518, 0.042770, 0.001344},{
      0.042141, 0.043185, 0.001344},{0.042174, 0.043084, 0.000000}}],
    Polygon[{{0.039518, 0.042770, 0.001344},{0.039518, 0.043084, 0.002656},{
      0.042044, 0.043485, 0.002656},{0.042141, 0.043185, 0.001344}}],
    Polygon[{{0.039518, 0.043084, 0.002656},{0.039518, 0.043601, 0.003902},{
      0.041884, 0.043975, 0.003902},{0.042044, 0.043485, 0.002656}}],
    Polygon[{{0.039518, 0.043601, 0.003902},{0.039518, 0.044305, 0.005052},{
      0.041667, 0.044646, 0.005052},{0.041884, 0.043975, 0.003902}}],
    Polygon[{{0.039518, 0.044305, 0.005052},{0.039518, 0.045181, 0.006077},{
      0.041396, 0.045479, 0.006077},{0.041667, 0.044646, 0.005052}}],
    Polygon[{{0.039518, 0.045181, 0.006077},{0.039518, 0.046207, 0.006953},{
      0.041079, 0.046454, 0.006953},{0.041396, 0.045479, 0.006077}}],
    Polygon[{{0.039518, 0.046207, 0.006953},{0.039518, 0.047357, 0.007658},{
      0.040724, 0.047547, 0.007658},{0.041079, 0.046454, 0.006953}}],
    Polygon[{{0.039518, 0.047357, 0.007658},{0.039518, 0.048602, 0.008174},{
      0.040339, 0.048732, 0.008174},{0.040724, 0.047547, 0.007658}}],
    Polygon[{{0.039518, 0.048602, 0.008174},{0.039518, 0.049914, 0.008489},{
      0.039934, 0.049980, 0.008489},{0.040339, 0.048732, 0.008174}}],
    Polygon[{{0.039934, 0.049980, -0.008489},{0.040339, 0.048732, -0.008174},{
      0.041079, 0.049110, -0.008174},{0.040308, 0.050171, -0.008489}}],
    Polygon[{{0.040339, 0.048732, -0.008174},{0.040724, 0.047547, -0.007658},{
      0.041811, 0.048102, -0.007658},{0.041079, 0.049110, -0.008174}}],
    Polygon[{{0.040724, 0.047547, -0.007658},{0.041079, 0.046454, -0.006953},{
      0.042487, 0.047171, -0.006953},{0.041811, 0.048102, -0.007658}}],
    Polygon[{{0.041079, 0.046454, -0.006953},{0.041396, 0.045479, -0.006077},{
      0.043090, 0.046342, -0.006077},{0.042487, 0.047171, -0.006953}}],
    Polygon[{{0.041396, 0.045479, -0.006077},{0.041667, 0.044646, -0.005052},{
      0.043605, 0.045633, -0.005052},{0.043090, 0.046342, -0.006077}}],
    Polygon[{{0.041667, 0.044646, -0.005052},{0.041884, 0.043975, -0.003902},{
      0.044019, 0.045063, -0.003902},{0.043605, 0.045633, -0.005052}}],
    Polygon[{{0.041884, 0.043975, -0.003902},{0.042044, 0.043485, -0.002656},{
      0.044323, 0.044646, -0.002656},{0.044019, 0.045063, -0.003902}}],
    Polygon[{{0.042044, 0.043485, -0.002656},{0.042141, 0.043185, -0.001344},{
      0.044508, 0.044391, -0.001344},{0.044323, 0.044646, -0.002656}}],
    Polygon[{{0.042141, 0.043185, -0.001344},{0.042174, 0.043084, 0.000000},{
      0.044570, 0.044305, 0.000000},{0.044508, 0.044391, -0.001344}}],
    Polygon[{{0.042174, 0.043084, 0.000000},{0.042141, 0.043185, 0.001344},{
      0.044508, 0.044391, 0.001344},{0.044570, 0.044305, 0.000000}}],
    Polygon[{{0.042141, 0.043185, 0.001344},{0.042044, 0.043485, 0.002656},{
      0.044323, 0.044646, 0.002656},{0.044508, 0.044391, 0.001344}}],
    Polygon[{{0.042044, 0.043485, 0.002656},{0.041884, 0.043975, 0.003902},{
      0.044019, 0.045063, 0.003902},{0.044323, 0.044646, 0.002656}}],
    Polygon[{{0.041884, 0.043975, 0.003902},{0.041667, 0.044646, 0.005052},{
      0.043605, 0.045633, 0.005052},{0.044019, 0.045063, 0.003902}}],
    Polygon[{{0.041667, 0.044646, 0.005052},{0.041396, 0.045479, 0.006077},{
      0.043090, 0.046342, 0.006077},{0.043605, 0.045633, 0.005052}}],
    Polygon[{{0.041396, 0.045479, 0.006077},{0.041079, 0.046454, 0.006953},{
      0.042487, 0.047171, 0.006953},{0.043090, 0.046342, 0.006077}}],
    Polygon[{{0.041079, 0.046454, 0.006953},{0.040724, 0.047547, 0.007658},{
      0.041811, 0.048102, 0.007658},{0.042487, 0.047171, 0.006953}}],
    Polygon[{{0.040724, 0.047547, 0.007658},{0.040339, 0.048732, 0.008174},{
      0.041079, 0.049110, 0.008174},{0.041811, 0.048102, 0.007658}}],
    Polygon[{{0.040339, 0.048732, 0.008174},{0.039934, 0.049980, 0.008489},{
      0.040308, 0.050171, 0.008489},{0.041079, 0.049110, 0.008174}}],
    Polygon[{{0.040308, 0.050171, -0.008489},{0.041079, 0.049110, -0.008174},{
      0.041667, 0.049697, -0.008174},{0.040606, 0.050468, -0.008489}}],
    Polygon[{{0.041079, 0.049110, -0.008174},{0.041811, 0.048102, -0.007658},{
      0.042675, 0.048965, -0.007658},{0.041667, 0.049697, -0.008174}}],
    Polygon[{{0.041811, 0.048102, -0.007658},{0.042487, 0.047171, -0.006953},{
      0.043605, 0.048289, -0.006953},{0.042675, 0.048965, -0.007658}}],
    Polygon[{{0.042487, 0.047171, -0.006953},{0.043090, 0.046342, -0.006077},{
      0.044435, 0.047686, -0.006077},{0.043605, 0.048289, -0.006953}}],
    Polygon[{{0.043090, 0.046342, -0.006077},{0.043605, 0.045633, -0.005052},{
      0.045143, 0.047171, -0.005052},{0.044435, 0.047686, -0.006077}}],
    Polygon[{{0.043605, 0.045633, -0.005052},{0.044019, 0.045063, -0.003902},{
      0.045713, 0.046757, -0.003902},{0.045143, 0.047171, -0.005052}}],
    Polygon[{{0.044019, 0.045063, -0.003902},{0.044323, 0.044646, -0.002656},{
      0.046131, 0.046454, -0.002656},{0.045713, 0.046757, -0.003902}}],
    Polygon[{{0.044323, 0.044646, -0.002656},{0.044508, 0.044391, -0.001344},{
      0.046386, 0.046269, -0.001344},{0.046131, 0.046454, -0.002656}}],
    Polygon[{{0.044508, 0.044391, -0.001344},{0.044570, 0.044305, 0.000000},{
      0.046471, 0.046207, 0.000000},{0.046386, 0.046269, -0.001344}}],
    Polygon[{{0.044570, 0.044305, 0.000000},{0.044508, 0.044391, 0.001344},{
      0.046386, 0.046269, 0.001344},{0.046471, 0.046207, 0.000000}}],
    Polygon[{{0.044508, 0.044391, 0.001344},{0.044323, 0.044646, 0.002656},{
      0.046131, 0.046454, 0.002656},{0.046386, 0.046269, 0.001344}}],
    Polygon[{{0.044323, 0.044646, 0.002656},{0.044019, 0.045063, 0.003902},{
      0.045713, 0.046757, 0.003902},{0.046131, 0.046454, 0.002656}}],
    Polygon[{{0.044019, 0.045063, 0.003902},{0.043605, 0.045633, 0.005052},{
      0.045143, 0.047171, 0.005052},{0.045713, 0.046757, 0.003902}}],
    Polygon[{{0.043605, 0.045633, 0.005052},{0.043090, 0.046342, 0.006077},{
      0.044435, 0.047686, 0.006077},{0.045143, 0.047171, 0.005052}}],
    Polygon[{{0.043090, 0.046342, 0.006077},{0.042487, 0.047171, 0.006953},{
      0.043605, 0.048289, 0.006953},{0.044435, 0.047686, 0.006077}}],
    Polygon[{{0.042487, 0.047171, 0.006953},{0.041811, 0.048102, 0.007658},{
      0.042675, 0.048965, 0.007658},{0.043605, 0.048289, 0.006953}}],
    Polygon[{{0.041811, 0.048102, 0.007658},{0.041079, 0.049110, 0.008174},{
      0.041667, 0.049697, 0.008174},{0.042675, 0.048965, 0.007658}}],
    Polygon[{{0.041079, 0.049110, 0.008174},{0.040308, 0.050171, 0.008489},{
      0.040606, 0.050468, 0.008489},{0.041667, 0.049697, 0.008174}}],
    Polygon[{{0.040606, 0.050468, -0.008489},{0.041667, 0.049697, -0.008174},{
      0.042044, 0.050438, -0.008174},{0.040797, 0.050843, -0.008489}}],
    Polygon[{{0.041667, 0.049697, -0.008174},{0.042675, 0.048965, -0.007658},{
      0.043229, 0.050053, -0.007658},{0.042044, 0.050438, -0.008174}}],
    Polygon[{{0.042675, 0.048965, -0.007658},{0.043605, 0.048289, -0.006953},{
      0.044323, 0.049697, -0.006953},{0.043229, 0.050053, -0.007658}}],
    Polygon[{{0.043605, 0.048289, -0.006953},{0.044435, 0.047686, -0.006077},{
      0.045298, 0.049380, -0.006077},{0.044323, 0.049697, -0.006953}}],
    Polygon[{{0.044435, 0.047686, -0.006077},{0.045143, 0.047171, -0.005052},{
      0.046131, 0.049110, -0.005052},{0.045298, 0.049380, -0.006077}}],
    Polygon[{{0.045143, 0.047171, -0.005052},{0.045713, 0.046757, -0.003902},{
      0.046801, 0.048892, -0.003902},{0.046131, 0.049110, -0.005052}}],
    Polygon[{{0.045713, 0.046757, -0.003902},{0.046131, 0.046454, -0.002656},{
      0.047292, 0.048732, -0.002656},{0.046801, 0.048892, -0.003902}}],
    Polygon[{{0.046131, 0.046454, -0.002656},{0.046386, 0.046269, -0.001344},{
      0.047591, 0.048635, -0.001344},{0.047292, 0.048732, -0.002656}}],
    Polygon[{{0.046386, 0.046269, -0.001344},{0.046471, 0.046207, 0.000000},{
      0.047692, 0.048602, 0.000000},{0.047591, 0.048635, -0.001344}}],
    Polygon[{{0.046471, 0.046207, 0.000000},{0.046386, 0.046269, 0.001344},{
      0.047591, 0.048635, 0.001344},{0.047692, 0.048602, 0.000000}}],
    Polygon[{{0.046386, 0.046269, 0.001344},{0.046131, 0.046454, 0.002656},{
      0.047292, 0.048732, 0.002656},{0.047591, 0.048635, 0.001344}}],
    Polygon[{{0.046131, 0.046454, 0.002656},{0.045713, 0.046757, 0.003902},{
      0.046801, 0.048892, 0.003902},{0.047292, 0.048732, 0.002656}}],
    Polygon[{{0.045713, 0.046757, 0.003902},{0.045143, 0.047171, 0.005052},{
      0.046131, 0.049110, 0.005052},{0.046801, 0.048892, 0.003902}}],
    Polygon[{{0.045143, 0.047171, 0.005052},{0.044435, 0.047686, 0.006077},{
      0.045298, 0.049380, 0.006077},{0.046131, 0.049110, 0.005052}}],
    Polygon[{{0.044435, 0.047686, 0.006077},{0.043605, 0.048289, 0.006953},{
      0.044323, 0.049697, 0.006953},{0.045298, 0.049380, 0.006077}}],
    Polygon[{{0.043605, 0.048289, 0.006953},{0.042675, 0.048965, 0.007658},{
      0.043229, 0.050053, 0.007658},{0.044323, 0.049697, 0.006953}}],
    Polygon[{{0.042675, 0.048965, 0.007658},{0.041667, 0.049697, 0.008174},{
      0.042044, 0.050438, 0.008174},{0.043229, 0.050053, 0.007658}}],
    Polygon[{{0.041667, 0.049697, 0.008174},{0.040606, 0.050468, 0.008489},{
      0.040797, 0.050843, 0.008489},{0.042044, 0.050438, 0.008174}}],
    Polygon[{{0.040797, 0.050843, -0.008489},{0.042044, 0.050438, -0.008174},{
      0.042174, 0.051258, -0.008174},{0.040863, 0.051258, -0.008489}}],
    Polygon[{{0.042044, 0.050438, -0.008174},{0.043229, 0.050053, -0.007658},{
      0.043420, 0.051258, -0.007658},{0.042174, 0.051258, -0.008174}}],
    Polygon[{{0.043229, 0.050053, -0.007658},{0.044323, 0.049697, -0.006953},{
      0.044570, 0.051258, -0.006953},{0.043420, 0.051258, -0.007658}}],
    Polygon[{{0.044323, 0.049697, -0.006953},{0.045298, 0.049380, -0.006077},{
      0.045595, 0.051258, -0.006077},{0.044570, 0.051258, -0.006953}}],
    Polygon[{{0.045298, 0.049380, -0.006077},{0.046131, 0.049110, -0.005052},{
      0.046471, 0.051258, -0.005052},{0.045595, 0.051258, -0.006077}}],
    Polygon[{{0.046131, 0.049110, -0.005052},{0.046801, 0.048892, -0.003902},{
      0.047176, 0.051258, -0.003902},{0.046471, 0.051258, -0.005052}}],
    Polygon[{{0.046801, 0.048892, -0.003902},{0.047292, 0.048732, -0.002656},{
      0.047692, 0.051258, -0.002656},{0.047176, 0.051258, -0.003902}}],
    Polygon[{{0.047292, 0.048732, -0.002656},{0.047591, 0.048635, -0.001344},{
      0.048007, 0.051258, -0.001344},{0.047692, 0.051258, -0.002656}}],
    Polygon[{{0.047591, 0.048635, -0.001344},{0.047692, 0.048602, 0.000000},{
      0.048113, 0.051258, 0.000000},{0.048007, 0.051258, -0.001344}}],
    Polygon[{{0.047692, 0.048602, 0.000000},{0.047591, 0.048635, 0.001344},{
      0.048007, 0.051258, 0.001344},{0.048113, 0.051258, 0.000000}}],
    Polygon[{{0.047591, 0.048635, 0.001344},{0.047292, 0.048732, 0.002656},{
      0.047692, 0.051258, 0.002656},{0.048007, 0.051258, 0.001344}}],
    Polygon[{{0.047292, 0.048732, 0.002656},{0.046801, 0.048892, 0.003902},{
      0.047176, 0.051258, 0.003902},{0.047692, 0.051258, 0.002656}}],
    Polygon[{{0.046801, 0.048892, 0.003902},{0.046131, 0.049110, 0.005052},{
      0.046471, 0.051258, 0.005052},{0.047176, 0.051258, 0.003902}}],
    Polygon[{{0.046131, 0.049110, 0.005052},{0.045298, 0.049380, 0.006077},{
      0.045595, 0.051258, 0.006077},{0.046471, 0.051258, 0.005052}}],
    Polygon[{{0.045298, 0.049380, 0.006077},{0.044323, 0.049697, 0.006953},{
      0.044570, 0.051258, 0.006953},{0.045595, 0.051258, 0.006077}}],
    Polygon[{{0.044323, 0.049697, 0.006953},{0.043229, 0.050053, 0.007658},{
      0.043420, 0.051258, 0.007658},{0.044570, 0.051258, 0.006953}}],
    Polygon[{{0.043229, 0.050053, 0.007658},{0.042044, 0.050438, 0.008174},{
      0.042174, 0.051258, 0.008174},{0.043420, 0.051258, 0.007658}}],
    Polygon[{{0.042044, 0.050438, 0.008174},{0.040797, 0.050843, 0.008489},{
      0.040863, 0.051258, 0.008489},{0.042174, 0.051258, 0.008174}}],
    Polygon[{{0.196484, 0.025783, -0.025466},{0.200418, 0.025783, -0.024521},{
      0.200028, 0.028246, -0.024521},{0.196286, 0.027030, -0.025466}}],
    Polygon[{{0.200418, 0.025783, -0.024521},{0.204156, 0.025783, -0.022973},{
      0.203583, 0.029401, -0.022973},{0.200028, 0.028246, -0.024521}}],
    Polygon[{{0.204156, 0.025783, -0.022973},{0.207605, 0.025783, -0.020859},{
      0.206863, 0.030467, -0.020859},{0.203583, 0.029401, -0.022973}}],
    Polygon[{{0.207605, 0.025783, -0.020859},{0.210682, 0.025783, -0.018232},{
      0.209789, 0.031417, -0.018232},{0.206863, 0.030467, -0.020859}}],
    Polygon[{{0.210682, 0.025783, -0.018232},{0.213309, 0.025783, -0.015155},{
      0.212288, 0.032229, -0.015155},{0.209789, 0.031417, -0.018232}}],
    Polygon[{{0.213309, 0.025783, -0.015155},{0.215423, 0.025783, -0.011705},{
      0.214299, 0.032883, -0.011705},{0.212288, 0.032229, -0.015155}}],
    Polygon[{{0.215423, 0.025783, -0.011705},{0.216972, 0.025783, -0.007968},{
      0.215771, 0.033361, -0.007968},{0.214299, 0.032883, -0.011705}}],
    Polygon[{{0.216972, 0.025783, -0.007968},{0.217916, 0.025783, -0.004033},{
      0.216670, 0.033653, -0.004033},{0.215771, 0.033361, -0.007968}}],
    Polygon[{{0.217916, 0.025783, -0.004033},{0.218234, 0.025783, 0.000000},{
      0.216972, 0.033751, 0.000000},{0.216670, 0.033653, -0.004033}}],
    Polygon[{{0.218234, 0.025783, 0.000000},{0.217916, 0.025783, 0.004033},{
      0.216670, 0.033653, 0.004033},{0.216972, 0.033751, 0.000000}}],
    Polygon[{{0.217916, 0.025783, 0.004033},{0.216972, 0.025783, 0.007968},{
      0.215771, 0.033361, 0.007968},{0.216670, 0.033653, 0.004033}}],
    Polygon[{{0.216972, 0.025783, 0.007968},{0.215423, 0.025783, 0.011705},{
      0.214299, 0.032883, 0.011705},{0.215771, 0.033361, 0.007968}}],
    Polygon[{{0.215423, 0.025783, 0.011705},{0.213309, 0.025783, 0.015155},{
      0.212288, 0.032229, 0.015155},{0.214299, 0.032883, 0.011705}}],
    Polygon[{{0.213309, 0.025783, 0.015155},{0.210682, 0.025783, 0.018232},{
      0.209789, 0.031417, 0.018232},{0.212288, 0.032229, 0.015155}}],
    Polygon[{{0.210682, 0.025783, 0.018232},{0.207605, 0.025783, 0.020859},{
      0.206863, 0.030467, 0.020859},{0.209789, 0.031417, 0.018232}}],
    Polygon[{{0.207605, 0.025783, 0.020859},{0.204156, 0.025783, 0.022973},{
      0.203583, 0.029401, 0.022973},{0.206863, 0.030467, 0.020859}}],
    Polygon[{{0.204156, 0.025783, 0.022973},{0.200418, 0.025783, 0.024521},{
      0.200028, 0.028246, 0.024521},{0.203583, 0.029401, 0.022973}}],
    Polygon[{{0.200418, 0.025783, 0.024521},{0.196484, 0.025783, 0.025466},{
      0.196286, 0.027030, 0.025466},{0.200028, 0.028246, 0.024521}}],
    Polygon[{{0.196286, 0.027030, -0.025466},{0.200028, 0.028246, -0.024521},{
      0.198896, 0.030467, -0.024521},{0.195713, 0.028154, -0.025466}}],
    Polygon[{{0.200028, 0.028246, -0.024521},{0.203583, 0.029401, -0.022973},{
      0.201920, 0.032664, -0.022973},{0.198896, 0.030467, -0.024521}}],
    Polygon[{{0.203583, 0.029401, -0.022973},{0.206863, 0.030467, -0.020859},{
      0.204711, 0.034691, -0.020859},{0.201920, 0.032664, -0.022973}}],
    Polygon[{{0.206863, 0.030467, -0.020859},{0.209789, 0.031417, -0.018232},{
      0.207200, 0.036500, -0.018232},{0.204711, 0.034691, -0.020859}}],
    Polygon[{{0.209789, 0.031417, -0.018232},{0.212288, 0.032229, -0.015155},{
      0.209326, 0.038044, -0.015155},{0.207200, 0.036500, -0.018232}}],
    Polygon[{{0.212288, 0.032229, -0.015155},{0.214299, 0.032883, -0.011705},{
      0.211036, 0.039287, -0.011705},{0.209326, 0.038044, -0.015155}}],
    Polygon[{{0.214299, 0.032883, -0.011705},{0.215771, 0.033361, -0.007968},{
      0.212288, 0.040197, -0.007968},{0.211036, 0.039287, -0.011705}}],
    Polygon[{{0.215771, 0.033361, -0.007968},{0.216670, 0.033653, -0.004033},{
      0.213053, 0.040752, -0.004033},{0.212288, 0.040197, -0.007968}}],
    Polygon[{{0.216670, 0.033653, -0.004033},{0.216972, 0.033751, 0.000000},{
      0.213309, 0.040939, 0.000000},{0.213053, 0.040752, -0.004033}}],
    Polygon[{{0.216972, 0.033751, 0.000000},{0.216670, 0.033653, 0.004033},{
      0.213053, 0.040752, 0.004033},{0.213309, 0.040939, 0.000000}}],
    Polygon[{{0.216670, 0.033653, 0.004033},{0.215771, 0.033361, 0.007968},{
      0.212288, 0.040197, 0.007968},{0.213053, 0.040752, 0.004033}}],
    Polygon[{{0.215771, 0.033361, 0.007968},{0.214299, 0.032883, 0.011705},{
      0.211036, 0.039287, 0.011705},{0.212288, 0.040197, 0.007968}}],
    Polygon[{{0.214299, 0.032883, 0.011705},{0.212288, 0.032229, 0.015155},{
      0.209326, 0.038044, 0.015155},{0.211036, 0.039287, 0.011705}}],
    Polygon[{{0.212288, 0.032229, 0.015155},{0.209789, 0.031417, 0.018232},{
      0.207200, 0.036500, 0.018232},{0.209326, 0.038044, 0.015155}}],
    Polygon[{{0.209789, 0.031417, 0.018232},{0.206863, 0.030467, 0.020859},{
      0.204711, 0.034691, 0.020859},{0.207200, 0.036500, 0.018232}}],
    Polygon[{{0.206863, 0.030467, 0.020859},{0.203583, 0.029401, 0.022973},{
      0.201920, 0.032664, 0.022973},{0.204711, 0.034691, 0.020859}}],
    Polygon[{{0.203583, 0.029401, 0.022973},{0.200028, 0.028246, 0.024521},{
      0.198896, 0.030467, 0.024521},{0.201920, 0.032664, 0.022973}}],
    Polygon[{{0.200028, 0.028246, 0.024521},{0.196286, 0.027030, 0.025466},{
      0.195713, 0.028154, 0.025466},{0.198896, 0.030467, 0.024521}}],
    Polygon[{{0.195713, 0.028154, -0.025466},{0.198896, 0.030467, -0.024521},{
      0.197133, 0.032229, -0.024521},{0.194821, 0.029047, -0.025466}}],
    Polygon[{{0.198896, 0.030467, -0.024521},{0.201920, 0.032664, -0.022973},{
      0.199330, 0.035253, -0.022973},{0.197133, 0.032229, -0.024521}}],
    Polygon[{{0.201920, 0.032664, -0.022973},{0.204711, 0.034691, -0.020859},{
      0.201358, 0.038044, -0.020859},{0.199330, 0.035253, -0.022973}}],
    Polygon[{{0.204711, 0.034691, -0.020859},{0.207200, 0.036500, -0.018232},{
      0.203166, 0.040533, -0.018232},{0.201358, 0.038044, -0.020859}}],
    Polygon[{{0.207200, 0.036500, -0.018232},{0.209326, 0.038044, -0.015155},{
      0.204711, 0.042659, -0.015155},{0.203166, 0.040533, -0.018232}}],
    Polygon[{{0.209326, 0.038044, -0.015155},{0.211036, 0.039287, -0.011705},{
      0.205953, 0.044369, -0.011705},{0.204711, 0.042659, -0.015155}}],
    Polygon[{{0.211036, 0.039287, -0.011705},{0.212288, 0.040197, -0.007968},{
      0.206863, 0.045622, -0.007968},{0.205953, 0.044369, -0.011705}}],
    Polygon[{{0.212288, 0.040197, -0.007968},{0.213053, 0.040752, -0.004033},{
      0.207419, 0.046386, -0.004033},{0.206863, 0.045622, -0.007968}}],
    Polygon[{{0.213053, 0.040752, -0.004033},{0.213309, 0.040939, 0.000000},{
      0.207605, 0.046643, 0.000000},{0.207419, 0.046386, -0.004033}}],
    Polygon[{{0.213309, 0.040939, 0.000000},{0.213053, 0.040752, 0.004033},{
      0.207419, 0.046386, 0.004033},{0.207605, 0.046643, 0.000000}}],
    Polygon[{{0.213053, 0.040752, 0.004033},{0.212288, 0.040197, 0.007968},{
      0.206863, 0.045622, 0.007968},{0.207419, 0.046386, 0.004033}}],
    Polygon[{{0.212288, 0.040197, 0.007968},{0.211036, 0.039287, 0.011705},{
      0.205953, 0.044369, 0.011705},{0.206863, 0.045622, 0.007968}}],
    Polygon[{{0.211036, 0.039287, 0.011705},{0.209326, 0.038044, 0.015155},{
      0.204711, 0.042659, 0.015155},{0.205953, 0.044369, 0.011705}}],
    Polygon[{{0.209326, 0.038044, 0.015155},{0.207200, 0.036500, 0.018232},{
      0.203166, 0.040533, 0.018232},{0.204711, 0.042659, 0.015155}}],
    Polygon[{{0.207200, 0.036500, 0.018232},{0.204711, 0.034691, 0.020859},{
      0.201358, 0.038044, 0.020859},{0.203166, 0.040533, 0.018232}}],
    Polygon[{{0.204711, 0.034691, 0.020859},{0.201920, 0.032664, 0.022973},{
      0.199330, 0.035253, 0.022973},{0.201358, 0.038044, 0.020859}}],
    Polygon[{{0.201920, 0.032664, 0.022973},{0.198896, 0.030467, 0.024521},{
      0.197133, 0.032229, 0.024521},{0.199330, 0.035253, 0.022973}}],
    Polygon[{{0.198896, 0.030467, 0.024521},{0.195713, 0.028154, 0.025466},{
      0.194821, 0.029047, 0.025466},{0.197133, 0.032229, 0.024521}}],
    Polygon[{{0.194821, 0.029047, -0.025466},{0.197133, 0.032229, -0.024521},{
      0.194912, 0.033361, -0.024521},{0.193696, 0.029619, -0.025466}}],
    Polygon[{{0.197133, 0.032229, -0.024521},{0.199330, 0.035253, -0.022973},{
      0.196067, 0.036916, -0.022973},{0.194912, 0.033361, -0.024521}}],
    Polygon[{{0.199330, 0.035253, -0.022973},{0.201358, 0.038044, -0.020859},{
      0.197133, 0.040197, -0.020859},{0.196067, 0.036916, -0.022973}}],
    Polygon[{{0.201358, 0.038044, -0.020859},{0.203166, 0.040533, -0.018232},{
      0.198084, 0.043123, -0.018232},{0.197133, 0.040197, -0.020859}}],
    Polygon[{{0.203166, 0.040533, -0.018232},{0.204711, 0.042659, -0.015155},{
      0.198896, 0.045622, -0.015155},{0.198084, 0.043123, -0.018232}}],
    Polygon[{{0.204711, 0.042659, -0.015155},{0.205953, 0.044369, -0.011705},{
      0.199549, 0.047632, -0.011705},{0.198896, 0.045622, -0.015155}}],
    Polygon[{{0.205953, 0.044369, -0.011705},{0.206863, 0.045622, -0.007968},{
      0.200028, 0.049105, -0.007968},{0.199549, 0.047632, -0.011705}}],
    Polygon[{{0.206863, 0.045622, -0.007968},{0.207419, 0.046386, -0.004033},{
      0.200320, 0.050003, -0.004033},{0.200028, 0.049105, -0.007968}}],
    Polygon[{{0.207419, 0.046386, -0.004033},{0.207605, 0.046643, 0.000000},{
      0.200418, 0.050305, 0.000000},{0.200320, 0.050003, -0.004033}}],
    Polygon[{{0.207605, 0.046643, 0.000000},{0.207419, 0.046386, 0.004033},{
      0.200320, 0.050003, 0.004033},{0.200418, 0.050305, 0.000000}}],
    Polygon[{{0.207419, 0.046386, 0.004033},{0.206863, 0.045622, 0.007968},{
      0.200028, 0.049105, 0.007968},{0.200320, 0.050003, 0.004033}}],
    Polygon[{{0.206863, 0.045622, 0.007968},{0.205953, 0.044369, 0.011705},{
      0.199549, 0.047632, 0.011705},{0.200028, 0.049105, 0.007968}}],
    Polygon[{{0.205953, 0.044369, 0.011705},{0.204711, 0.042659, 0.015155},{
      0.198896, 0.045622, 0.015155},{0.199549, 0.047632, 0.011705}}],
    Polygon[{{0.204711, 0.042659, 0.015155},{0.203166, 0.040533, 0.018232},{
      0.198084, 0.043123, 0.018232},{0.198896, 0.045622, 0.015155}}],
    Polygon[{{0.203166, 0.040533, 0.018232},{0.201358, 0.038044, 0.020859},{
      0.197133, 0.040197, 0.020859},{0.198084, 0.043123, 0.018232}}],
    Polygon[{{0.201358, 0.038044, 0.020859},{0.199330, 0.035253, 0.022973},{
      0.196067, 0.036916, 0.022973},{0.197133, 0.040197, 0.020859}}],
    Polygon[{{0.199330, 0.035253, 0.022973},{0.197133, 0.032229, 0.024521},{
      0.194912, 0.033361, 0.024521},{0.196067, 0.036916, 0.022973}}],
    Polygon[{{0.197133, 0.032229, 0.024521},{0.194821, 0.029047, 0.025466},{
      0.193696, 0.029619, 0.025466},{0.194912, 0.033361, 0.024521}}],
    Polygon[{{0.193696, 0.029619, -0.025466},{0.194912, 0.033361, -0.024521},{
      0.192450, 0.033751, -0.024521},{0.192450, 0.029817, -0.025466}}],
    Polygon[{{0.194912, 0.033361, -0.024521},{0.196067, 0.036916, -0.022973},{
      0.192450, 0.037489, -0.022973},{0.192450, 0.033751, -0.024521}}],
    Polygon[{{0.196067, 0.036916, -0.022973},{0.197133, 0.040197, -0.020859},{
      0.192450, 0.040939, -0.020859},{0.192450, 0.037489, -0.022973}}],
    Polygon[{{0.197133, 0.040197, -0.020859},{0.198084, 0.043123, -0.018232},{
      0.192450, 0.044015, -0.018232},{0.192450, 0.040939, -0.020859}}],
    Polygon[{{0.198084, 0.043123, -0.018232},{0.198896, 0.045622, -0.015155},{
      0.192450, 0.046643, -0.015155},{0.192450, 0.044015, -0.018232}}],
    Polygon[{{0.198896, 0.045622, -0.015155},{0.199549, 0.047632, -0.011705},{
      0.192450, 0.048757, -0.011705},{0.192450, 0.046643, -0.015155}}],
    Polygon[{{0.199549, 0.047632, -0.011705},{0.200028, 0.049105, -0.007968},{
      0.192450, 0.050305, -0.007968},{0.192450, 0.048757, -0.011705}}],
    Polygon[{{0.200028, 0.049105, -0.007968},{0.200320, 0.050003, -0.004033},{
      0.192450, 0.051249, -0.004033},{0.192450, 0.050305, -0.007968}}],
    Polygon[{{0.200320, 0.050003, -0.004033},{0.200418, 0.050305, 0.000000},{
      0.192450, 0.051567, 0.000000},{0.192450, 0.051249, -0.004033}}],
    Polygon[{{0.200418, 0.050305, 0.000000},{0.200320, 0.050003, 0.004033},{
      0.192450, 0.051249, 0.004033},{0.192450, 0.051567, 0.000000}}],
    Polygon[{{0.200320, 0.050003, 0.004033},{0.200028, 0.049105, 0.007968},{
      0.192450, 0.050305, 0.007968},{0.192450, 0.051249, 0.004033}}],
    Polygon[{{0.200028, 0.049105, 0.007968},{0.199549, 0.047632, 0.011705},{
      0.192450, 0.048757, 0.011705},{0.192450, 0.050305, 0.007968}}],
    Polygon[{{0.199549, 0.047632, 0.011705},{0.198896, 0.045622, 0.015155},{
      0.192450, 0.046643, 0.015155},{0.192450, 0.048757, 0.011705}}],
    Polygon[{{0.198896, 0.045622, 0.015155},{0.198084, 0.043123, 0.018232},{
      0.192450, 0.044015, 0.018232},{0.192450, 0.046643, 0.015155}}],
    Polygon[{{0.198084, 0.043123, 0.018232},{0.197133, 0.040197, 0.020859},{
      0.192450, 0.040939, 0.020859},{0.192450, 0.044015, 0.018232}}],
    Polygon[{{0.197133, 0.040197, 0.020859},{0.196067, 0.036916, 0.022973},{
      0.192450, 0.037489, 0.022973},{0.192450, 0.040939, 0.020859}}],
    Polygon[{{0.196067, 0.036916, 0.022973},{0.194912, 0.033361, 0.024521},{
      0.192450, 0.033751, 0.024521},{0.192450, 0.037489, 0.022973}}],
    Polygon[{{0.194912, 0.033361, 0.024521},{0.193696, 0.029619, 0.025466},{
      0.192450, 0.029817, 0.025466},{0.192450, 0.033751, 0.024521}}],
    Polygon[{{0.192450, 0.029817, -0.025466},{0.192450, 0.033751, -0.024521},{
      0.189988, 0.033361, -0.024521},{0.191204, 0.029619, -0.025466}}],
    Polygon[{{0.192450, 0.033751, -0.024521},{0.192450, 0.037489, -0.022973},{
      0.188833, 0.036916, -0.022973},{0.189988, 0.033361, -0.024521}}],
    Polygon[{{0.192450, 0.037489, -0.022973},{0.192450, 0.040939, -0.020859},{
      0.187767, 0.040197, -0.020859},{0.188833, 0.036916, -0.022973}}],
    Polygon[{{0.192450, 0.040939, -0.020859},{0.192450, 0.044015, -0.018232},{
      0.186816, 0.043123, -0.018232},{0.187767, 0.040197, -0.020859}}],
    Polygon[{{0.192450, 0.044015, -0.018232},{0.192450, 0.046643, -0.015155},{
      0.186004, 0.045622, -0.015155},{0.186816, 0.043123, -0.018232}}],
    Polygon[{{0.192450, 0.046643, -0.015155},{0.192450, 0.048757, -0.011705},{
      0.185351, 0.047632, -0.011705},{0.186004, 0.045622, -0.015155}}],
    Polygon[{{0.192450, 0.048757, -0.011705},{0.192450, 0.050305, -0.007968},{
      0.184873, 0.049105, -0.007968},{0.185351, 0.047632, -0.011705}}],
    Polygon[{{0.192450, 0.050305, -0.007968},{0.192450, 0.051249, -0.004033},{
      0.184581, 0.050003, -0.004033},{0.184873, 0.049105, -0.007968}}],
    Polygon[{{0.192450, 0.051249, -0.004033},{0.192450, 0.051567, 0.000000},{
      0.184483, 0.050305, 0.000000},{0.184581, 0.050003, -0.004033}}],
    Polygon[{{0.192450, 0.051567, 0.000000},{0.192450, 0.051249, 0.004033},{
      0.184581, 0.050003, 0.004033},{0.184483, 0.050305, 0.000000}}],
    Polygon[{{0.192450, 0.051249, 0.004033},{0.192450, 0.050305, 0.007968},{
      0.184873, 0.049105, 0.007968},{0.184581, 0.050003, 0.004033}}],
    Polygon[{{0.192450, 0.050305, 0.007968},{0.192450, 0.048757, 0.011705},{
      0.185351, 0.047632, 0.011705},{0.184873, 0.049105, 0.007968}}],
    Polygon[{{0.192450, 0.048757, 0.011705},{0.192450, 0.046643, 0.015155},{
      0.186004, 0.045622, 0.015155},{0.185351, 0.047632, 0.011705}}],
    Polygon[{{0.192450, 0.046643, 0.015155},{0.192450, 0.044015, 0.018232},{
      0.186816, 0.043123, 0.018232},{0.186004, 0.045622, 0.015155}}],
    Polygon[{{0.192450, 0.044015, 0.018232},{0.192450, 0.040939, 0.020859},{
      0.187767, 0.040197, 0.020859},{0.186816, 0.043123, 0.018232}}],
    Polygon[{{0.192450, 0.040939, 0.020859},{0.192450, 0.037489, 0.022973},{
      0.188833, 0.036916, 0.022973},{0.187767, 0.040197, 0.020859}}],
    Polygon[{{0.192450, 0.037489, 0.022973},{0.192450, 0.033751, 0.024521},{
      0.189988, 0.033361, 0.024521},{0.188833, 0.036916, 0.022973}}],
    Polygon[{{0.192450, 0.033751, 0.024521},{0.192450, 0.029817, 0.025466},{
      0.191204, 0.029619, 0.025466},{0.189988, 0.033361, 0.024521}}],
    Polygon[{{0.191204, 0.029619, -0.025466},{0.189988, 0.033361, -0.024521},{
      0.187767, 0.032229, -0.024521},{0.190079, 0.029047, -0.025466}}],
    Polygon[{{0.189988, 0.033361, -0.024521},{0.188833, 0.036916, -0.022973},{
      0.185570, 0.035253, -0.022973},{0.187767, 0.032229, -0.024521}}],
    Polygon[{{0.188833, 0.036916, -0.022973},{0.187767, 0.040197, -0.020859},{
      0.183542, 0.038044, -0.020859},{0.185570, 0.035253, -0.022973}}],
    Polygon[{{0.187767, 0.040197, -0.020859},{0.186816, 0.043123, -0.018232},{
      0.181734, 0.040533, -0.018232},{0.183542, 0.038044, -0.020859}}],
    Polygon[{{0.186816, 0.043123, -0.018232},{0.186004, 0.045622, -0.015155},{
      0.180189, 0.042659, -0.015155},{0.181734, 0.040533, -0.018232}}],
    Polygon[{{0.186004, 0.045622, -0.015155},{0.185351, 0.047632, -0.011705},{
      0.178947, 0.044369, -0.011705},{0.180189, 0.042659, -0.015155}}],
    Polygon[{{0.185351, 0.047632, -0.011705},{0.184873, 0.049105, -0.007968},{
      0.178037, 0.045622, -0.007968},{0.178947, 0.044369, -0.011705}}],
    Polygon[{{0.184873, 0.049105, -0.007968},{0.184581, 0.050003, -0.004033},{
      0.177482, 0.046386, -0.004033},{0.178037, 0.045622, -0.007968}}],
    Polygon[{{0.184581, 0.050003, -0.004033},{0.184483, 0.050305, 0.000000},{
      0.177295, 0.046643, 0.000000},{0.177482, 0.046386, -0.004033}}],
    Polygon[{{0.184483, 0.050305, 0.000000},{0.184581, 0.050003, 0.004033},{
      0.177482, 0.046386, 0.004033},{0.177295, 0.046643, 0.000000}}],
    Polygon[{{0.184581, 0.050003, 0.004033},{0.184873, 0.049105, 0.007968},{
      0.178037, 0.045622, 0.007968},{0.177482, 0.046386, 0.004033}}],
    Polygon[{{0.184873, 0.049105, 0.007968},{0.185351, 0.047632, 0.011705},{
      0.178947, 0.044369, 0.011705},{0.178037, 0.045622, 0.007968}}],
    Polygon[{{0.185351, 0.047632, 0.011705},{0.186004, 0.045622, 0.015155},{
      0.180189, 0.042659, 0.015155},{0.178947, 0.044369, 0.011705}}],
    Polygon[{{0.186004, 0.045622, 0.015155},{0.186816, 0.043123, 0.018232},{
      0.181734, 0.040533, 0.018232},{0.180189, 0.042659, 0.015155}}],
    Polygon[{{0.186816, 0.043123, 0.018232},{0.187767, 0.040197, 0.020859},{
      0.183542, 0.038044, 0.020859},{0.181734, 0.040533, 0.018232}}],
    Polygon[{{0.187767, 0.040197, 0.020859},{0.188833, 0.036916, 0.022973},{
      0.185570, 0.035253, 0.022973},{0.183542, 0.038044, 0.020859}}],
    Polygon[{{0.188833, 0.036916, 0.022973},{0.189988, 0.033361, 0.024521},{
      0.187767, 0.032229, 0.024521},{0.185570, 0.035253, 0.022973}}],
    Polygon[{{0.189988, 0.033361, 0.024521},{0.191204, 0.029619, 0.025466},{
      0.190079, 0.029047, 0.025466},{0.187767, 0.032229, 0.024521}}],
    Polygon[{{0.190079, 0.029047, -0.025466},{0.187767, 0.032229, -0.024521},{
      0.186004, 0.030467, -0.024521},{0.189187, 0.028154, -0.025466}}],
    Polygon[{{0.187767, 0.032229, -0.024521},{0.185570, 0.035253, -0.022973},{
      0.182980, 0.032664, -0.022973},{0.186004, 0.030467, -0.024521}}],
    Polygon[{{0.185570, 0.035253, -0.022973},{0.183542, 0.038044, -0.020859},{
      0.180189, 0.034691, -0.020859},{0.182980, 0.032664, -0.022973}}],
    Polygon[{{0.183542, 0.038044, -0.020859},{0.181734, 0.040533, -0.018232},{
      0.177700, 0.036500, -0.018232},{0.180189, 0.034691, -0.020859}}],
    Polygon[{{0.181734, 0.040533, -0.018232},{0.180189, 0.042659, -0.015155},{
      0.175575, 0.038044, -0.015155},{0.177700, 0.036500, -0.018232}}],
    Polygon[{{0.180189, 0.042659, -0.015155},{0.178947, 0.044369, -0.011705},{
      0.173864, 0.039287, -0.011705},{0.175575, 0.038044, -0.015155}}],
    Polygon[{{0.178947, 0.044369, -0.011705},{0.178037, 0.045622, -0.007968},{
      0.172612, 0.040197, -0.007968},{0.173864, 0.039287, -0.011705}}],
    Polygon[{{0.178037, 0.045622, -0.007968},{0.177482, 0.046386, -0.004033},{
      0.171848, 0.040752, -0.004033},{0.172612, 0.040197, -0.007968}}],
    Polygon[{{0.177482, 0.046386, -0.004033},{0.177295, 0.046643, 0.000000},{
      0.171591, 0.040939, 0.000000},{0.171848, 0.040752, -0.004033}}],
    Polygon[{{0.177295, 0.046643, 0.000000},{0.177482, 0.046386, 0.004033},{
      0.171848, 0.040752, 0.004033},{0.171591, 0.040939, 0.000000}}],
    Polygon[{{0.177482, 0.046386, 0.004033},{0.178037, 0.045622, 0.007968},{
      0.172612, 0.040197, 0.007968},{0.171848, 0.040752, 0.004033}}],
    Polygon[{{0.178037, 0.045622, 0.007968},{0.178947, 0.044369, 0.011705},{
      0.173864, 0.039287, 0.011705},{0.172612, 0.040197, 0.007968}}],
    Polygon[{{0.178947, 0.044369, 0.011705},{0.180189, 0.042659, 0.015155},{
      0.175575, 0.038044, 0.015155},{0.173864, 0.039287, 0.011705}}],
    Polygon[{{0.180189, 0.042659, 0.015155},{0.181734, 0.040533, 0.018232},{
      0.177700, 0.036500, 0.018232},{0.175575, 0.038044, 0.015155}}],
    Polygon[{{0.181734, 0.040533, 0.018232},{0.183542, 0.038044, 0.020859},{
      0.180189, 0.034691, 0.020859},{0.177700, 0.036500, 0.018232}}],
    Polygon[{{0.183542, 0.038044, 0.020859},{0.185570, 0.035253, 0.022973},{
      0.182980, 0.032664, 0.022973},{0.180189, 0.034691, 0.020859}}],
    Polygon[{{0.185570, 0.035253, 0.022973},{0.187767, 0.032229, 0.024521},{
      0.186004, 0.030467, 0.024521},{0.182980, 0.032664, 0.022973}}],
    Polygon[{{0.187767, 0.032229, 0.024521},{0.190079, 0.029047, 0.025466},{
      0.189187, 0.028154, 0.025466},{0.186004, 0.030467, 0.024521}}],
    Polygon[{{0.189187, 0.028154, -0.025466},{0.186004, 0.030467, -0.024521},{
      0.184873, 0.028246, -0.024521},{0.188614, 0.027030, -0.025466}}],
    Polygon[{{0.186004, 0.030467, -0.024521},{0.182980, 0.032664, -0.022973},{
      0.181318, 0.029401, -0.022973},{0.184873, 0.028246, -0.024521}}],
    Polygon[{{0.182980, 0.032664, -0.022973},{0.180189, 0.034691, -0.020859},{
      0.178037, 0.030467, -0.020859},{0.181318, 0.029401, -0.022973}}],
    Polygon[{{0.180189, 0.034691, -0.020859},{0.177700, 0.036500, -0.018232},{
      0.175111, 0.031417, -0.018232},{0.178037, 0.030467, -0.020859}}],
    Polygon[{{0.177700, 0.036500, -0.018232},{0.175575, 0.038044, -0.015155},{
      0.172612, 0.032229, -0.015155},{0.175111, 0.031417, -0.018232}}],
    Polygon[{{0.175575, 0.038044, -0.015155},{0.173864, 0.039287, -0.011705},{
      0.170601, 0.032883, -0.011705},{0.172612, 0.032229, -0.015155}}],
    Polygon[{{0.173864, 0.039287, -0.011705},{0.172612, 0.040197, -0.007968},{
      0.169129, 0.033361, -0.007968},{0.170601, 0.032883, -0.011705}}],
    Polygon[{{0.172612, 0.040197, -0.007968},{0.171848, 0.040752, -0.004033},{
      0.168231, 0.033653, -0.004033},{0.169129, 0.033361, -0.007968}}],
    Polygon[{{0.171848, 0.040752, -0.004033},{0.171591, 0.040939, 0.000000},{
      0.167929, 0.033751, 0.000000},{0.168231, 0.033653, -0.004033}}],
    Polygon[{{0.171591, 0.040939, 0.000000},{0.171848, 0.040752, 0.004033},{
      0.168231, 0.033653, 0.004033},{0.167929, 0.033751, 0.000000}}],
    Polygon[{{0.171848, 0.040752, 0.004033},{0.172612, 0.040197, 0.007968},{
      0.169129, 0.033361, 0.007968},{0.168231, 0.033653, 0.004033}}],
    Polygon[{{0.172612, 0.040197, 0.007968},{0.173864, 0.039287, 0.011705},{
      0.170601, 0.032883, 0.011705},{0.169129, 0.033361, 0.007968}}],
    Polygon[{{0.173864, 0.039287, 0.011705},{0.175575, 0.038044, 0.015155},{
      0.172612, 0.032229, 0.015155},{0.170601, 0.032883, 0.011705}}],
    Polygon[{{0.175575, 0.038044, 0.015155},{0.177700, 0.036500, 0.018232},{
      0.175111, 0.031417, 0.018232},{0.172612, 0.032229, 0.015155}}],
    Polygon[{{0.177700, 0.036500, 0.018232},{0.180189, 0.034691, 0.020859},{
      0.178037, 0.030467, 0.020859},{0.175111, 0.031417, 0.018232}}],
    Polygon[{{0.180189, 0.034691, 0.020859},{0.182980, 0.032664, 0.022973},{
      0.181318, 0.029401, 0.022973},{0.178037, 0.030467, 0.020859}}],
    Polygon[{{0.182980, 0.032664, 0.022973},{0.186004, 0.030467, 0.024521},{
      0.184873, 0.028246, 0.024521},{0.181318, 0.029401, 0.022973}}],
    Polygon[{{0.186004, 0.030467, 0.024521},{0.189187, 0.028154, 0.025466},{
      0.188614, 0.027030, 0.025466},{0.184873, 0.028246, 0.024521}}],
    Polygon[{{0.188614, 0.027030, -0.025466},{0.184873, 0.028246, -0.024521},{
      0.184483, 0.025783, -0.024521},{0.188417, 0.025783, -0.025466}}],
    Polygon[{{0.184873, 0.028246, -0.024521},{0.181318, 0.029401, -0.022973},{
      0.180745, 0.025783, -0.022973},{0.184483, 0.025783, -0.024521}}],
    Polygon[{{0.181318, 0.029401, -0.022973},{0.178037, 0.030467, -0.020859},{
      0.177295, 0.025783, -0.020859},{0.180745, 0.025783, -0.022973}}],
    Polygon[{{0.178037, 0.030467, -0.020859},{0.175111, 0.031417, -0.018232},{
      0.174218, 0.025783, -0.018232},{0.177295, 0.025783, -0.020859}}],
    Polygon[{{0.175111, 0.031417, -0.018232},{0.172612, 0.032229, -0.015155},{
      0.171591, 0.025783, -0.015155},{0.174218, 0.025783, -0.018232}}],
    Polygon[{{0.172612, 0.032229, -0.015155},{0.170601, 0.032883, -0.011705},{
      0.169477, 0.025783, -0.011705},{0.171591, 0.025783, -0.015155}}],
    Polygon[{{0.170601, 0.032883, -0.011705},{0.169129, 0.033361, -0.007968},{
      0.167929, 0.025783, -0.007968},{0.169477, 0.025783, -0.011705}}],
    Polygon[{{0.169129, 0.033361, -0.007968},{0.168231, 0.033653, -0.004033},{
      0.166984, 0.025783, -0.004033},{0.167929, 0.025783, -0.007968}}],
    Polygon[{{0.168231, 0.033653, -0.004033},{0.167929, 0.033751, 0.000000},{
      0.166667, 0.025783, 0.000000},{0.166984, 0.025783, -0.004033}}],
    Polygon[{{0.167929, 0.033751, 0.000000},{0.168231, 0.033653, 0.004033},{
      0.166984, 0.025783, 0.004033},{0.166667, 0.025783, 0.000000}}],
    Polygon[{{0.168231, 0.033653, 0.004033},{0.169129, 0.033361, 0.007968},{
      0.167929, 0.025783, 0.007968},{0.166984, 0.025783, 0.004033}}],
    Polygon[{{0.169129, 0.033361, 0.007968},{0.170601, 0.032883, 0.011705},{
      0.169477, 0.025783, 0.011705},{0.167929, 0.025783, 0.007968}}],
    Polygon[{{0.170601, 0.032883, 0.011705},{0.172612, 0.032229, 0.015155},{
      0.171591, 0.025783, 0.015155},{0.169477, 0.025783, 0.011705}}],
    Polygon[{{0.172612, 0.032229, 0.015155},{0.175111, 0.031417, 0.018232},{
      0.174218, 0.025783, 0.018232},{0.171591, 0.025783, 0.015155}}],
    Polygon[{{0.175111, 0.031417, 0.018232},{0.178037, 0.030467, 0.020859},{
      0.177295, 0.025783, 0.020859},{0.174218, 0.025783, 0.018232}}],
    Polygon[{{0.178037, 0.030467, 0.020859},{0.181318, 0.029401, 0.022973},{
      0.180745, 0.025783, 0.022973},{0.177295, 0.025783, 0.020859}}],
    Polygon[{{0.181318, 0.029401, 0.022973},{0.184873, 0.028246, 0.024521},{
      0.184483, 0.025783, 0.024521},{0.180745, 0.025783, 0.022973}}],
    Polygon[{{0.184873, 0.028246, 0.024521},{0.188614, 0.027030, 0.025466},{
      0.188417, 0.025783, 0.025466},{0.184483, 0.025783, 0.024521}}],
    Polygon[{{0.188417, 0.025783, -0.025466},{0.184483, 0.025783, -0.024521},{
      0.184873, 0.023321, -0.024521},{0.188614, 0.024537, -0.025466}}],
    Polygon[{{0.184483, 0.025783, -0.024521},{0.180745, 0.025783, -0.022973},{
      0.181318, 0.022166, -0.022973},{0.184873, 0.023321, -0.024521}}],
    Polygon[{{0.180745, 0.025783, -0.022973},{0.177295, 0.025783, -0.020859},{
      0.178037, 0.021100, -0.020859},{0.181318, 0.022166, -0.022973}}],
    Polygon[{{0.177295, 0.025783, -0.020859},{0.174218, 0.025783, -0.018232},{
      0.175111, 0.020150, -0.018232},{0.178037, 0.021100, -0.020859}}],
    Polygon[{{0.174218, 0.025783, -0.018232},{0.171591, 0.025783, -0.015155},{
      0.172612, 0.019338, -0.015155},{0.175111, 0.020150, -0.018232}}],
    Polygon[{{0.171591, 0.025783, -0.015155},{0.169477, 0.025783, -0.011705},{
      0.170601, 0.018684, -0.011705},{0.172612, 0.019338, -0.015155}}],
    Polygon[{{0.169477, 0.025783, -0.011705},{0.167929, 0.025783, -0.007968},{
      0.169129, 0.018206, -0.007968},{0.170601, 0.018684, -0.011705}}],
    Polygon[{{0.167929, 0.025783, -0.007968},{0.166984, 0.025783, -0.004033},{
      0.168231, 0.017914, -0.004033},{0.169129, 0.018206, -0.007968}}],
    Polygon[{{0.166984, 0.025783, -0.004033},{0.166667, 0.025783, 0.000000},{
      0.167929, 0.017816, 0.000000},{0.168231, 0.017914, -0.004033}}],
    Polygon[{{0.166667, 0.025783, 0.000000},{0.166984, 0.025783, 0.004033},{
      0.168231, 0.017914, 0.004033},{0.167929, 0.017816, 0.000000}}],
    Polygon[{{0.166984, 0.025783, 0.004033},{0.167929, 0.025783, 0.007968},{
      0.169129, 0.018206, 0.007968},{0.168231, 0.017914, 0.004033}}],
    Polygon[{{0.167929, 0.025783, 0.007968},{0.169477, 0.025783, 0.011705},{
      0.170601, 0.018684, 0.011705},{0.169129, 0.018206, 0.007968}}],
    Polygon[{{0.169477, 0.025783, 0.011705},{0.171591, 0.025783, 0.015155},{
      0.172612, 0.019338, 0.015155},{0.170601, 0.018684, 0.011705}}],
    Polygon[{{0.171591, 0.025783, 0.015155},{0.174218, 0.025783, 0.018232},{
      0.175111, 0.020150, 0.018232},{0.172612, 0.019338, 0.015155}}],
    Polygon[{{0.174218, 0.025783, 0.018232},{0.177295, 0.025783, 0.020859},{
      0.178037, 0.021100, 0.020859},{0.175111, 0.020150, 0.018232}}],
    Polygon[{{0.177295, 0.025783, 0.020859},{0.180745, 0.025783, 0.022973},{
      0.181318, 0.022166, 0.022973},{0.178037, 0.021100, 0.020859}}],
    Polygon[{{0.180745, 0.025783, 0.022973},{0.184483, 0.025783, 0.024521},{
      0.184873, 0.023321, 0.024521},{0.181318, 0.022166, 0.022973}}],
    Polygon[{{0.184483, 0.025783, 0.024521},{0.188417, 0.025783, 0.025466},{
      0.188614, 0.024537, 0.025466},{0.184873, 0.023321, 0.024521}}],
    Polygon[{{0.188614, 0.024537, -0.025466},{0.184873, 0.023321, -0.024521},{
      0.186004, 0.021100, -0.024521},{0.189187, 0.023413, -0.025466}}],
    Polygon[{{0.184873, 0.023321, -0.024521},{0.181318, 0.022166, -0.022973},{
      0.182980, 0.018903, -0.022973},{0.186004, 0.021100, -0.024521}}],
    Polygon[{{0.181318, 0.022166, -0.022973},{0.178037, 0.021100, -0.020859},{
      0.180189, 0.016875, -0.020859},{0.182980, 0.018903, -0.022973}}],
    Polygon[{{0.178037, 0.021100, -0.020859},{0.175111, 0.020150, -0.018232},{
      0.177700, 0.015067, -0.018232},{0.180189, 0.016875, -0.020859}}],
    Polygon[{{0.175111, 0.020150, -0.018232},{0.172612, 0.019338, -0.015155},{
      0.175575, 0.013523, -0.015155},{0.177700, 0.015067, -0.018232}}],
    Polygon[{{0.172612, 0.019338, -0.015155},{0.170601, 0.018684, -0.011705},{
      0.173864, 0.012280, -0.011705},{0.175575, 0.013523, -0.015155}}],
    Polygon[{{0.170601, 0.018684, -0.011705},{0.169129, 0.018206, -0.007968},{
      0.172612, 0.011370, -0.007968},{0.173864, 0.012280, -0.011705}}],
    Polygon[{{0.169129, 0.018206, -0.007968},{0.168231, 0.017914, -0.004033},{
      0.171848, 0.010815, -0.004033},{0.172612, 0.011370, -0.007968}}],
    Polygon[{{0.168231, 0.017914, -0.004033},{0.167929, 0.017816, 0.000000},{
      0.171591, 0.010628, 0.000000},{0.171848, 0.010815, -0.004033}}],
    Polygon[{{0.167929, 0.017816, 0.000000},{0.168231, 0.017914, 0.004033},{
      0.171848, 0.010815, 0.004033},{0.171591, 0.010628, 0.000000}}],
    Polygon[{{0.168231, 0.017914, 0.004033},{0.169129, 0.018206, 0.007968},{
      0.172612, 0.011370, 0.007968},{0.171848, 0.010815, 0.004033}}],
    Polygon[{{0.169129, 0.018206, 0.007968},{0.170601, 0.018684, 0.011705},{
      0.173864, 0.012280, 0.011705},{0.172612, 0.011370, 0.007968}}],
    Polygon[{{0.170601, 0.018684, 0.011705},{0.172612, 0.019338, 0.015155},{
      0.175575, 0.013523, 0.015155},{0.173864, 0.012280, 0.011705}}],
    Polygon[{{0.172612, 0.019338, 0.015155},{0.175111, 0.020150, 0.018232},{
      0.177700, 0.015067, 0.018232},{0.175575, 0.013523, 0.015155}}],
    Polygon[{{0.175111, 0.020150, 0.018232},{0.178037, 0.021100, 0.020859},{
      0.180189, 0.016875, 0.020859},{0.177700, 0.015067, 0.018232}}],
    Polygon[{{0.178037, 0.021100, 0.020859},{0.181318, 0.022166, 0.022973},{
      0.182980, 0.018903, 0.022973},{0.180189, 0.016875, 0.020859}}],
    Polygon[{{0.181318, 0.022166, 0.022973},{0.184873, 0.023321, 0.024521},{
      0.186004, 0.021100, 0.024521},{0.182980, 0.018903, 0.022973}}],
    Polygon[{{0.184873, 0.023321, 0.024521},{0.188614, 0.024537, 0.025466},{
      0.189187, 0.023413, 0.025466},{0.186004, 0.021100, 0.024521}}],
    Polygon[{{0.189187, 0.023413, -0.025466},{0.186004, 0.021100, -0.024521},{
      0.187767, 0.019338, -0.024521},{0.190079, 0.022520, -0.025466}}],
    Polygon[{{0.186004, 0.021100, -0.024521},{0.182980, 0.018903, -0.022973},{
      0.185570, 0.016314, -0.022973},{0.187767, 0.019338, -0.024521}}],
    Polygon[{{0.182980, 0.018903, -0.022973},{0.180189, 0.016875, -0.020859},{
      0.183542, 0.013523, -0.020859},{0.185570, 0.016314, -0.022973}}],
    Polygon[{{0.180189, 0.016875, -0.020859},{0.177700, 0.015067, -0.018232},{
      0.181734, 0.011034, -0.018232},{0.183542, 0.013523, -0.020859}}],
    Polygon[{{0.177700, 0.015067, -0.018232},{0.175575, 0.013523, -0.015155},{
      0.180189, 0.008908, -0.015155},{0.181734, 0.011034, -0.018232}}],
    Polygon[{{0.175575, 0.013523, -0.015155},{0.173864, 0.012280, -0.011705},{
      0.178947, 0.007198, -0.011705},{0.180189, 0.008908, -0.015155}}],
    Polygon[{{0.173864, 0.012280, -0.011705},{0.172612, 0.011370, -0.007968},{
      0.178037, 0.005945, -0.007968},{0.178947, 0.007198, -0.011705}}],
    Polygon[{{0.172612, 0.011370, -0.007968},{0.171848, 0.010815, -0.004033},{
      0.177482, 0.005181, -0.004033},{0.178037, 0.005945, -0.007968}}],
    Polygon[{{0.171848, 0.010815, -0.004033},{0.171591, 0.010628, 0.000000},{
      0.177295, 0.004924, 0.000000},{0.177482, 0.005181, -0.004033}}],
    Polygon[{{0.171591, 0.010628, 0.000000},{0.171848, 0.010815, 0.004033},{
      0.177482, 0.005181, 0.004033},{0.177295, 0.004924, 0.000000}}],
    Polygon[{{0.171848, 0.010815, 0.004033},{0.172612, 0.011370, 0.007968},{
      0.178037, 0.005945, 0.007968},{0.177482, 0.005181, 0.004033}}],
    Polygon[{{0.172612, 0.011370, 0.007968},{0.173864, 0.012280, 0.011705},{
      0.178947, 0.007198, 0.011705},{0.178037, 0.005945, 0.007968}}],
    Polygon[{{0.173864, 0.012280, 0.011705},{0.175575, 0.013523, 0.015155},{
      0.180189, 0.008908, 0.015155},{0.178947, 0.007198, 0.011705}}],
    Polygon[{{0.175575, 0.013523, 0.015155},{0.177700, 0.015067, 0.018232},{
      0.181734, 0.011034, 0.018232},{0.180189, 0.008908, 0.015155}}],
    Polygon[{{0.177700, 0.015067, 0.018232},{0.180189, 0.016875, 0.020859},{
      0.183542, 0.013523, 0.020859},{0.181734, 0.011034, 0.018232}}],
    Polygon[{{0.180189, 0.016875, 0.020859},{0.182980, 0.018903, 0.022973},{
      0.185570, 0.016314, 0.022973},{0.183542, 0.013523, 0.020859}}],
    Polygon[{{0.182980, 0.018903, 0.022973},{0.186004, 0.021100, 0.024521},{
      0.187767, 0.019338, 0.024521},{0.185570, 0.016314, 0.022973}}],
    Polygon[{{0.186004, 0.021100, 0.024521},{0.189187, 0.023413, 0.025466},{
      0.190079, 0.022520, 0.025466},{0.187767, 0.019338, 0.024521}}],
    Polygon[{{0.190079, 0.022520, -0.025466},{0.187767, 0.019338, -0.024521},{
      0.189988, 0.018206, -0.024521},{0.191204, 0.021947, -0.025466}}],
    Polygon[{{0.187767, 0.019338, -0.024521},{0.185570, 0.016314, -0.022973},{
      0.188833, 0.014651, -0.022973},{0.189988, 0.018206, -0.024521}}],
    Polygon[{{0.185570, 0.016314, -0.022973},{0.183542, 0.013523, -0.020859},{
      0.187767, 0.011370, -0.020859},{0.188833, 0.014651, -0.022973}}],
    Polygon[{{0.183542, 0.013523, -0.020859},{0.181734, 0.011034, -0.018232},{
      0.186816, 0.008444, -0.018232},{0.187767, 0.011370, -0.020859}}],
    Polygon[{{0.181734, 0.011034, -0.018232},{0.180189, 0.008908, -0.015155},{
      0.186004, 0.005945, -0.015155},{0.186816, 0.008444, -0.018232}}],
    Polygon[{{0.180189, 0.008908, -0.015155},{0.178947, 0.007198, -0.011705},{
      0.185351, 0.003935, -0.011705},{0.186004, 0.005945, -0.015155}}],
    Polygon[{{0.178947, 0.007198, -0.011705},{0.178037, 0.005945, -0.007968},{
      0.184873, 0.002462, -0.007968},{0.185351, 0.003935, -0.011705}}],
    Polygon[{{0.178037, 0.005945, -0.007968},{0.177482, 0.005181, -0.004033},{
      0.184581, 0.001564, -0.004033},{0.184873, 0.002462, -0.007968}}],
    Polygon[{{0.177482, 0.005181, -0.004033},{0.177295, 0.004924, 0.000000},{
      0.184483, 0.001262, 0.000000},{0.184581, 0.001564, -0.004033}}],
    Polygon[{{0.177295, 0.004924, 0.000000},{0.177482, 0.005181, 0.004033},{
      0.184581, 0.001564, 0.004033},{0.184483, 0.001262, 0.000000}}],
    Polygon[{{0.177482, 0.005181, 0.004033},{0.178037, 0.005945, 0.007968},{
      0.184873, 0.002462, 0.007968},{0.184581, 0.001564, 0.004033}}],
    Polygon[{{0.178037, 0.005945, 0.007968},{0.178947, 0.007198, 0.011705},{
      0.185351, 0.003935, 0.011705},{0.184873, 0.002462, 0.007968}}],
    Polygon[{{0.178947, 0.007198, 0.011705},{0.180189, 0.008908, 0.015155},{
      0.186004, 0.005945, 0.015155},{0.185351, 0.003935, 0.011705}}],
    Polygon[{{0.180189, 0.008908, 0.015155},{0.181734, 0.011034, 0.018232},{
      0.186816, 0.008444, 0.018232},{0.186004, 0.005945, 0.015155}}],
    Polygon[{{0.181734, 0.011034, 0.018232},{0.183542, 0.013523, 0.020859},{
      0.187767, 0.011370, 0.020859},{0.186816, 0.008444, 0.018232}}],
    Polygon[{{0.183542, 0.013523, 0.020859},{0.185570, 0.016314, 0.022973},{
      0.188833, 0.014651, 0.022973},{0.187767, 0.011370, 0.020859}}],
    Polygon[{{0.185570, 0.016314, 0.022973},{0.187767, 0.019338, 0.024521},{
      0.189988, 0.018206, 0.024521},{0.188833, 0.014651, 0.022973}}],
    Polygon[{{0.187767, 0.019338, 0.024521},{0.190079, 0.022520, 0.025466},{
      0.191204, 0.021947, 0.025466},{0.189988, 0.018206, 0.024521}}],
    Polygon[{{0.191204, 0.021947, -0.025466},{0.189988, 0.018206, -0.024521},{
      0.192450, 0.017816, -0.024521},{0.192450, 0.021750, -0.025466}}],
    Polygon[{{0.189988, 0.018206, -0.024521},{0.188833, 0.014651, -0.022973},{
      0.192450, 0.014078, -0.022973},{0.192450, 0.017816, -0.024521}}],
    Polygon[{{0.188833, 0.014651, -0.022973},{0.187767, 0.011370, -0.020859},{
      0.192450, 0.010628, -0.020859},{0.192450, 0.014078, -0.022973}}],
    Polygon[{{0.187767, 0.011370, -0.020859},{0.186816, 0.008444, -0.018232},{
      0.192450, 0.007552, -0.018232},{0.192450, 0.010628, -0.020859}}],
    Polygon[{{0.186816, 0.008444, -0.018232},{0.186004, 0.005945, -0.015155},{
      0.192450, 0.004924, -0.015155},{0.192450, 0.007552, -0.018232}}],
    Polygon[{{0.186004, 0.005945, -0.015155},{0.185351, 0.003935, -0.011705},{
      0.192450, 0.002810, -0.011705},{0.192450, 0.004924, -0.015155}}],
    Polygon[{{0.185351, 0.003935, -0.011705},{0.184873, 0.002462, -0.007968},{
      0.192450, 0.001262, -0.007968},{0.192450, 0.002810, -0.011705}}],
    Polygon[{{0.184873, 0.002462, -0.007968},{0.184581, 0.001564, -0.004033},{
      0.192450, 0.000317, -0.004033},{0.192450, 0.001262, -0.007968}}],
    Polygon[{{0.184581, 0.001564, -0.004033},{0.184483, 0.001262, 0.000000},{
      0.192450, 0.000000, 0.000000},{0.192450, 0.000317, -0.004033}}],
    Polygon[{{0.184483, 0.001262, 0.000000},{0.184581, 0.001564, 0.004033},{
      0.192450, 0.000317, 0.004033},{0.192450, 0.000000, 0.000000}}],
    Polygon[{{0.184581, 0.001564, 0.004033},{0.184873, 0.002462, 0.007968},{
      0.192450, 0.001262, 0.007968},{0.192450, 0.000317, 0.004033}}],
    Polygon[{{0.184873, 0.002462, 0.007968},{0.185351, 0.003935, 0.011705},{
      0.192450, 0.002810, 0.011705},{0.192450, 0.001262, 0.007968}}],
    Polygon[{{0.185351, 0.003935, 0.011705},{0.186004, 0.005945, 0.015155},{
      0.192450, 0.004924, 0.015155},{0.192450, 0.002810, 0.011705}}],
    Polygon[{{0.186004, 0.005945, 0.015155},{0.186816, 0.008444, 0.018232},{
      0.192450, 0.007552, 0.018232},{0.192450, 0.004924, 0.015155}}],
    Polygon[{{0.186816, 0.008444, 0.018232},{0.187767, 0.011370, 0.020859},{
      0.192450, 0.010628, 0.020859},{0.192450, 0.007552, 0.018232}}],
    Polygon[{{0.187767, 0.011370, 0.020859},{0.188833, 0.014651, 0.022973},{
      0.192450, 0.014078, 0.022973},{0.192450, 0.010628, 0.020859}}],
    Polygon[{{0.188833, 0.014651, 0.022973},{0.189988, 0.018206, 0.024521},{
      0.192450, 0.017816, 0.024521},{0.192450, 0.014078, 0.022973}}],
    Polygon[{{0.189988, 0.018206, 0.024521},{0.191204, 0.021947, 0.025466},{
      0.192450, 0.021750, 0.025466},{0.192450, 0.017816, 0.024521}}],
    Polygon[{{0.192450, 0.021750, -0.025466},{0.192450, 0.017816, -0.024521},{
      0.194912, 0.018206, -0.024521},{0.193696, 0.021947, -0.025466}}],
    Polygon[{{0.192450, 0.017816, -0.024521},{0.192450, 0.014078, -0.022973},{
      0.196067, 0.014651, -0.022973},{0.194912, 0.018206, -0.024521}}],
    Polygon[{{0.192450, 0.014078, -0.022973},{0.192450, 0.010628, -0.020859},{
      0.197133, 0.011370, -0.020859},{0.196067, 0.014651, -0.022973}}],
    Polygon[{{0.192450, 0.010628, -0.020859},{0.192450, 0.007552, -0.018232},{
      0.198084, 0.008444, -0.018232},{0.197133, 0.011370, -0.020859}}],
    Polygon[{{0.192450, 0.007552, -0.018232},{0.192450, 0.004924, -0.015155},{
      0.198896, 0.005945, -0.015155},{0.198084, 0.008444, -0.018232}}],
    Polygon[{{0.192450, 0.004924, -0.015155},{0.192450, 0.002810, -0.011705},{
      0.199549, 0.003935, -0.011705},{0.198896, 0.005945, -0.015155}}],
    Polygon[{{0.192450, 0.002810, -0.011705},{0.192450, 0.001262, -0.007968},{
      0.200028, 0.002462, -0.007968},{0.199549, 0.003935, -0.011705}}],
    Polygon[{{0.192450, 0.001262, -0.007968},{0.192450, 0.000317, -0.004033},{
      0.200320, 0.001564, -0.004033},{0.200028, 0.002462, -0.007968}}],
    Polygon[{{0.192450, 0.000317, -0.004033},{0.192450, 0.000000, 0.000000},{
      0.200418, 0.001262, 0.000000},{0.200320, 0.001564, -0.004033}}],
    Polygon[{{0.192450, 0.000000, 0.000000},{0.192450, 0.000317, 0.004033},{
      0.200320, 0.001564, 0.004033},{0.200418, 0.001262, 0.000000}}],
    Polygon[{{0.192450, 0.000317, 0.004033},{0.192450, 0.001262, 0.007968},{
      0.200028, 0.002462, 0.007968},{0.200320, 0.001564, 0.004033}}],
    Polygon[{{0.192450, 0.001262, 0.007968},{0.192450, 0.002810, 0.011705},{
      0.199549, 0.003935, 0.011705},{0.200028, 0.002462, 0.007968}}],
    Polygon[{{0.192450, 0.002810, 0.011705},{0.192450, 0.004924, 0.015155},{
      0.198896, 0.005945, 0.015155},{0.199549, 0.003935, 0.011705}}],
    Polygon[{{0.192450, 0.004924, 0.015155},{0.192450, 0.007552, 0.018232},{
      0.198084, 0.008444, 0.018232},{0.198896, 0.005945, 0.015155}}],
    Polygon[{{0.192450, 0.007552, 0.018232},{0.192450, 0.010628, 0.020859},{
      0.197133, 0.011370, 0.020859},{0.198084, 0.008444, 0.018232}}],
    Polygon[{{0.192450, 0.010628, 0.020859},{0.192450, 0.014078, 0.022973},{
      0.196067, 0.014651, 0.022973},{0.197133, 0.011370, 0.020859}}],
    Polygon[{{0.192450, 0.014078, 0.022973},{0.192450, 0.017816, 0.024521},{
      0.194912, 0.018206, 0.024521},{0.196067, 0.014651, 0.022973}}],
    Polygon[{{0.192450, 0.017816, 0.024521},{0.192450, 0.021750, 0.025466},{
      0.193696, 0.021947, 0.025466},{0.194912, 0.018206, 0.024521}}],
    Polygon[{{0.193696, 0.021947, -0.025466},{0.194912, 0.018206, -0.024521},{
      0.197133, 0.019338, -0.024521},{0.194821, 0.022520, -0.025466}}],
    Polygon[{{0.194912, 0.018206, -0.024521},{0.196067, 0.014651, -0.022973},{
      0.199330, 0.016314, -0.022973},{0.197133, 0.019338, -0.024521}}],
    Polygon[{{0.196067, 0.014651, -0.022973},{0.197133, 0.011370, -0.020859},{
      0.201358, 0.013523, -0.020859},{0.199330, 0.016314, -0.022973}}],
    Polygon[{{0.197133, 0.011370, -0.020859},{0.198084, 0.008444, -0.018232},{
      0.203166, 0.011034, -0.018232},{0.201358, 0.013523, -0.020859}}],
    Polygon[{{0.198084, 0.008444, -0.018232},{0.198896, 0.005945, -0.015155},{
      0.204711, 0.008908, -0.015155},{0.203166, 0.011034, -0.018232}}],
    Polygon[{{0.198896, 0.005945, -0.015155},{0.199549, 0.003935, -0.011705},{
      0.205953, 0.007198, -0.011705},{0.204711, 0.008908, -0.015155}}],
    Polygon[{{0.199549, 0.003935, -0.011705},{0.200028, 0.002462, -0.007968},{
      0.206863, 0.005945, -0.007968},{0.205953, 0.007198, -0.011705}}],
    Polygon[{{0.200028, 0.002462, -0.007968},{0.200320, 0.001564, -0.004033},{
      0.207419, 0.005181, -0.004033},{0.206863, 0.005945, -0.007968}}],
    Polygon[{{0.200320, 0.001564, -0.004033},{0.200418, 0.001262, 0.000000},{
      0.207605, 0.004924, 0.000000},{0.207419, 0.005181, -0.004033}}],
    Polygon[{{0.200418, 0.001262, 0.000000},{0.200320, 0.001564, 0.004033},{
      0.207419, 0.005181, 0.004033},{0.207605, 0.004924, 0.000000}}],
    Polygon[{{0.200320, 0.001564, 0.004033},{0.200028, 0.002462, 0.007968},{
      0.206863, 0.005945, 0.007968},{0.207419, 0.005181, 0.004033}}],
    Polygon[{{0.200028, 0.002462, 0.007968},{0.199549, 0.003935, 0.011705},{
      0.205953, 0.007198, 0.011705},{0.206863, 0.005945, 0.007968}}],
    Polygon[{{0.199549, 0.003935, 0.011705},{0.198896, 0.005945, 0.015155},{
      0.204711, 0.008908, 0.015155},{0.205953, 0.007198, 0.011705}}],
    Polygon[{{0.198896, 0.005945, 0.015155},{0.198084, 0.008444, 0.018232},{
      0.203166, 0.011034, 0.018232},{0.204711, 0.008908, 0.015155}}],
    Polygon[{{0.198084, 0.008444, 0.018232},{0.197133, 0.011370, 0.020859},{
      0.201358, 0.013523, 0.020859},{0.203166, 0.011034, 0.018232}}],
    Polygon[{{0.197133, 0.011370, 0.020859},{0.196067, 0.014651, 0.022973},{
      0.199330, 0.016314, 0.022973},{0.201358, 0.013523, 0.020859}}],
    Polygon[{{0.196067, 0.014651, 0.022973},{0.194912, 0.018206, 0.024521},{
      0.197133, 0.019338, 0.024521},{0.199330, 0.016314, 0.022973}}],
    Polygon[{{0.194912, 0.018206, 0.024521},{0.193696, 0.021947, 0.025466},{
      0.194821, 0.022520, 0.025466},{0.197133, 0.019338, 0.024521}}],
    Polygon[{{0.194821, 0.022520, -0.025466},{0.197133, 0.019338, -0.024521},{
      0.198896, 0.021100, -0.024521},{0.195713, 0.023413, -0.025466}}],
    Polygon[{{0.197133, 0.019338, -0.024521},{0.199330, 0.016314, -0.022973},{
      0.201920, 0.018903, -0.022973},{0.198896, 0.021100, -0.024521}}],
    Polygon[{{0.199330, 0.016314, -0.022973},{0.201358, 0.013523, -0.020859},{
      0.204711, 0.016875, -0.020859},{0.201920, 0.018903, -0.022973}}],
    Polygon[{{0.201358, 0.013523, -0.020859},{0.203166, 0.011034, -0.018232},{
      0.207200, 0.015067, -0.018232},{0.204711, 0.016875, -0.020859}}],
    Polygon[{{0.203166, 0.011034, -0.018232},{0.204711, 0.008908, -0.015155},{
      0.209326, 0.013523, -0.015155},{0.207200, 0.015067, -0.018232}}],
    Polygon[{{0.204711, 0.008908, -0.015155},{0.205953, 0.007198, -0.011705},{
      0.211036, 0.012280, -0.011705},{0.209326, 0.013523, -0.015155}}],
    Polygon[{{0.205953, 0.007198, -0.011705},{0.206863, 0.005945, -0.007968},{
      0.212288, 0.011370, -0.007968},{0.211036, 0.012280, -0.011705}}],
    Polygon[{{0.206863, 0.005945, -0.007968},{0.207419, 0.005181, -0.004033},{
      0.213053, 0.010815, -0.004033},{0.212288, 0.011370, -0.007968}}],
    Polygon[{{0.207419, 0.005181, -0.004033},{0.207605, 0.004924, 0.000000},{
      0.213309, 0.010628, 0.000000},{0.213053, 0.010815, -0.004033}}],
    Polygon[{{0.207605, 0.004924, 0.000000},{0.207419, 0.005181, 0.004033},{
      0.213053, 0.010815, 0.004033},{0.213309, 0.010628, 0.000000}}],
    Polygon[{{0.207419, 0.005181, 0.004033},{0.206863, 0.005945, 0.007968},{
      0.212288, 0.011370, 0.007968},{0.213053, 0.010815, 0.004033}}],
    Polygon[{{0.206863, 0.005945, 0.007968},{0.205953, 0.007198, 0.011705},{
      0.211036, 0.012280, 0.011705},{0.212288, 0.011370, 0.007968}}],
    Polygon[{{0.205953, 0.007198, 0.011705},{0.204711, 0.008908, 0.015155},{
      0.209326, 0.013523, 0.015155},{0.211036, 0.012280, 0.011705}}],
    Polygon[{{0.204711, 0.008908, 0.015155},{0.203166, 0.011034, 0.018232},{
      0.207200, 0.015067, 0.018232},{0.209326, 0.013523, 0.015155}}],
    Polygon[{{0.203166, 0.011034, 0.018232},{0.201358, 0.013523, 0.020859},{
      0.204711, 0.016875, 0.020859},{0.207200, 0.015067, 0.018232}}],
    Polygon[{{0.201358, 0.013523, 0.020859},{0.199330, 0.016314, 0.022973},{
      0.201920, 0.018903, 0.022973},{0.204711, 0.016875, 0.020859}}],
    Polygon[{{0.199330, 0.016314, 0.022973},{0.197133, 0.019338, 0.024521},{
      0.198896, 0.021100, 0.024521},{0.201920, 0.018903, 0.022973}}],
    Polygon[{{0.197133, 0.019338, 0.024521},{0.194821, 0.022520, 0.025466},{
      0.195713, 0.023413, 0.025466},{0.198896, 0.021100, 0.024521}}],
    Polygon[{{0.195713, 0.023413, -0.025466},{0.198896, 0.021100, -0.024521},{
      0.200028, 0.023321, -0.024521},{0.196286, 0.024537, -0.025466}}],
    Polygon[{{0.198896, 0.021100, -0.024521},{0.201920, 0.018903, -0.022973},{
      0.203583, 0.022166, -0.022973},{0.200028, 0.023321, -0.024521}}],
    Polygon[{{0.201920, 0.018903, -0.022973},{0.204711, 0.016875, -0.020859},{
      0.206863, 0.021100, -0.020859},{0.203583, 0.022166, -0.022973}}],
    Polygon[{{0.204711, 0.016875, -0.020859},{0.207200, 0.015067, -0.018232},{
      0.209789, 0.020150, -0.018232},{0.206863, 0.021100, -0.020859}}],
    Polygon[{{0.207200, 0.015067, -0.018232},{0.209326, 0.013523, -0.015155},{
      0.212288, 0.019338, -0.015155},{0.209789, 0.020150, -0.018232}}],
    Polygon[{{0.209326, 0.013523, -0.015155},{0.211036, 0.012280, -0.011705},{
      0.214299, 0.018684, -0.011705},{0.212288, 0.019338, -0.015155}}],
    Polygon[{{0.211036, 0.012280, -0.011705},{0.212288, 0.011370, -0.007968},{
      0.215771, 0.018206, -0.007968},{0.214299, 0.018684, -0.011705}}],
    Polygon[{{0.212288, 0.011370, -0.007968},{0.213053, 0.010815, -0.004033},{
      0.216670, 0.017914, -0.004033},{0.215771, 0.018206, -0.007968}}],
    Polygon[{{0.213053, 0.010815, -0.004033},{0.213309, 0.010628, 0.000000},{
      0.216972, 0.017816, 0.000000},{0.216670, 0.017914, -0.004033}}],
    Polygon[{{0.213309, 0.010628, 0.000000},{0.213053, 0.010815, 0.004033},{
      0.216670, 0.017914, 0.004033},{0.216972, 0.017816, 0.000000}}],
    Polygon[{{0.213053, 0.010815, 0.004033},{0.212288, 0.011370, 0.007968},{
      0.215771, 0.018206, 0.007968},{0.216670, 0.017914, 0.004033}}],
    Polygon[{{0.212288, 0.011370, 0.007968},{0.211036, 0.012280, 0.011705},{
      0.214299, 0.018684, 0.011705},{0.215771, 0.018206, 0.007968}}],
    Polygon[{{0.211036, 0.012280, 0.011705},{0.209326, 0.013523, 0.015155},{
      0.212288, 0.019338, 0.015155},{0.214299, 0.018684, 0.011705}}],
    Polygon[{{0.209326, 0.013523, 0.015155},{0.207200, 0.015067, 0.018232},{
      0.209789, 0.020150, 0.018232},{0.212288, 0.019338, 0.015155}}],
    Polygon[{{0.207200, 0.015067, 0.018232},{0.204711, 0.016875, 0.020859},{
      0.206863, 0.021100, 0.020859},{0.209789, 0.020150, 0.018232}}],
    Polygon[{{0.204711, 0.016875, 0.020859},{0.201920, 0.018903, 0.022973},{
      0.203583, 0.022166, 0.022973},{0.206863, 0.021100, 0.020859}}],
    Polygon[{{0.201920, 0.018903, 0.022973},{0.198896, 0.021100, 0.024521},{
      0.200028, 0.023321, 0.024521},{0.203583, 0.022166, 0.022973}}],
    Polygon[{{0.198896, 0.021100, 0.024521},{0.195713, 0.023413, 0.025466},{
      0.196286, 0.024537, 0.025466},{0.200028, 0.023321, 0.024521}}],
    Polygon[{{0.196286, 0.024537, -0.025466},{0.200028, 0.023321, -0.024521},{
      0.200418, 0.025783, -0.024521},{0.196484, 0.025783, -0.025466}}],
    Polygon[{{0.200028, 0.023321, -0.024521},{0.203583, 0.022166, -0.022973},{
      0.204156, 0.025783, -0.022973},{0.200418, 0.025783, -0.024521}}],
    Polygon[{{0.203583, 0.022166, -0.022973},{0.206863, 0.021100, -0.020859},{
      0.207605, 0.025783, -0.020859},{0.204156, 0.025783, -0.022973}}],
    Polygon[{{0.206863, 0.021100, -0.020859},{0.209789, 0.020150, -0.018232},{
      0.210682, 0.025783, -0.018232},{0.207605, 0.025783, -0.020859}}],
    Polygon[{{0.209789, 0.020150, -0.018232},{0.212288, 0.019338, -0.015155},{
      0.213309, 0.025783, -0.015155},{0.210682, 0.025783, -0.018232}}],
    Polygon[{{0.212288, 0.019338, -0.015155},{0.214299, 0.018684, -0.011705},{
      0.215423, 0.025783, -0.011705},{0.213309, 0.025783, -0.015155}}],
    Polygon[{{0.214299, 0.018684, -0.011705},{0.215771, 0.018206, -0.007968},{
      0.216972, 0.025783, -0.007968},{0.215423, 0.025783, -0.011705}}],
    Polygon[{{0.215771, 0.018206, -0.007968},{0.216670, 0.017914, -0.004033},{
      0.217916, 0.025783, -0.004033},{0.216972, 0.025783, -0.007968}}],
    Polygon[{{0.216670, 0.017914, -0.004033},{0.216972, 0.017816, 0.000000},{
      0.218234, 0.025783, 0.000000},{0.217916, 0.025783, -0.004033}}],
    Polygon[{{0.216972, 0.017816, 0.000000},{0.216670, 0.017914, 0.004033},{
      0.217916, 0.025783, 0.004033},{0.218234, 0.025783, 0.000000}}],
    Polygon[{{0.216670, 0.017914, 0.004033},{0.215771, 0.018206, 0.007968},{
      0.216972, 0.025783, 0.007968},{0.217916, 0.025783, 0.004033}}],
    Polygon[{{0.215771, 0.018206, 0.007968},{0.214299, 0.018684, 0.011705},{
      0.215423, 0.025783, 0.011705},{0.216972, 0.025783, 0.007968}}],
    Polygon[{{0.214299, 0.018684, 0.011705},{0.212288, 0.019338, 0.015155},{
      0.213309, 0.025783, 0.015155},{0.215423, 0.025783, 0.011705}}],
    Polygon[{{0.212288, 0.019338, 0.015155},{0.209789, 0.020150, 0.018232},{
      0.210682, 0.025783, 0.018232},{0.213309, 0.025783, 0.015155}}],
    Polygon[{{0.209789, 0.020150, 0.018232},{0.206863, 0.021100, 0.020859},{
      0.207605, 0.025783, 0.020859},{0.210682, 0.025783, 0.018232}}],
    Polygon[{{0.206863, 0.021100, 0.020859},{0.203583, 0.022166, 0.022973},{
      0.204156, 0.025783, 0.022973},{0.207605, 0.025783, 0.020859}}],
    Polygon[{{0.203583, 0.022166, 0.022973},{0.200028, 0.023321, 0.024521},{
      0.200418, 0.025783, 0.024521},{0.204156, 0.025783, 0.022973}}],
    Polygon[{{0.200028, 0.023321, 0.024521},{0.196286, 0.024537, 0.025466},{
      0.196484, 0.025783, 0.025466},{0.200418, 0.025783, 0.024521}}],
    Polygon[{{0.232361, 0.013817, -0.013647},{0.234469, 0.013817, -0.013141},{
      0.234260, 0.015137, -0.013141},{0.232255, 0.014485, -0.013647}}],
    Polygon[{{0.234469, 0.013817, -0.013141},{0.236473, 0.013817, -0.012311},{
      0.236166, 0.015756, -0.012311},{0.234260, 0.015137, -0.013141}}],
    Polygon[{{0.236473, 0.013817, -0.012311},{0.238321, 0.013817, -0.011178},{
      0.237924, 0.016327, -0.011178},{0.236166, 0.015756, -0.012311}}],
    Polygon[{{0.238321, 0.013817, -0.011178},{0.239970, 0.013817, -0.009770},{
      0.239492, 0.016836, -0.009770},{0.237924, 0.016327, -0.011178}}],
    Polygon[{{0.239970, 0.013817, -0.009770},{0.241378, 0.013817, -0.008122},{
      0.240831, 0.017272, -0.008122},{0.239492, 0.016836, -0.009770}}],
    Polygon[{{0.241378, 0.013817, -0.008122},{0.242511, 0.013817, -0.006273},{
      0.241908, 0.017622, -0.006273},{0.240831, 0.017272, -0.008122}}],
    Polygon[{{0.242511, 0.013817, -0.006273},{0.243341, 0.013817, -0.004270},{
      0.242698, 0.017878, -0.004270},{0.241908, 0.017622, -0.006273}}],
    Polygon[{{0.243341, 0.013817, -0.004270},{0.243847, 0.013817, -0.002162},{
      0.243179, 0.018035, -0.002162},{0.242698, 0.017878, -0.004270}}],
    Polygon[{{0.243847, 0.013817, -0.002162},{0.244017, 0.013817, 0.000000},{
      0.243341, 0.018087, 0.000000},{0.243179, 0.018035, -0.002162}}],
    Polygon[{{0.244017, 0.013817, 0.000000},{0.243847, 0.013817, 0.002162},{
      0.243179, 0.018035, 0.002162},{0.243341, 0.018087, 0.000000}}],
    Polygon[{{0.243847, 0.013817, 0.002162},{0.243341, 0.013817, 0.004270},{
      0.242698, 0.017878, 0.004270},{0.243179, 0.018035, 0.002162}}],
    Polygon[{{0.243341, 0.013817, 0.004270},{0.242511, 0.013817, 0.006273},{
      0.241908, 0.017622, 0.006273},{0.242698, 0.017878, 0.004270}}],
    Polygon[{{0.242511, 0.013817, 0.006273},{0.241378, 0.013817, 0.008122},{
      0.240831, 0.017272, 0.008122},{0.241908, 0.017622, 0.006273}}],
    Polygon[{{0.241378, 0.013817, 0.008122},{0.239970, 0.013817, 0.009770},{
      0.239492, 0.016836, 0.009770},{0.240831, 0.017272, 0.008122}}],
    Polygon[{{0.239970, 0.013817, 0.009770},{0.238321, 0.013817, 0.011178},{
      0.237924, 0.016327, 0.011178},{0.239492, 0.016836, 0.009770}}],
    Polygon[{{0.238321, 0.013817, 0.011178},{0.236473, 0.013817, 0.012311},{
      0.236166, 0.015756, 0.012311},{0.237924, 0.016327, 0.011178}}],
    Polygon[{{0.236473, 0.013817, 0.012311},{0.234469, 0.013817, 0.013141},{
      0.234260, 0.015137, 0.013141},{0.236166, 0.015756, 0.012311}}],
    Polygon[{{0.234469, 0.013817, 0.013141},{0.232361, 0.013817, 0.013647},{
      0.232255, 0.014485, 0.013647},{0.234260, 0.015137, 0.013141}}],
    Polygon[{{0.232255, 0.014485, -0.013647},{0.234260, 0.015137, -0.013141},{
      0.233654, 0.016327, -0.013141},{0.231948, 0.015088, -0.013647}}],
    Polygon[{{0.234260, 0.015137, -0.013141},{0.236166, 0.015756, -0.012311},{
      0.235275, 0.017504, -0.012311},{0.233654, 0.016327, -0.013141}}],
    Polygon[{{0.236166, 0.015756, -0.012311},{0.237924, 0.016327, -0.011178},{
      0.236770, 0.018591, -0.011178},{0.235275, 0.017504, -0.012311}}],
    Polygon[{{0.237924, 0.016327, -0.011178},{0.239492, 0.016836, -0.009770},{
      0.238104, 0.019560, -0.009770},{0.236770, 0.018591, -0.011178}}],
    Polygon[{{0.239492, 0.016836, -0.009770},{0.240831, 0.017272, -0.008122},{
      0.239243, 0.020388, -0.008122},{0.238104, 0.019560, -0.009770}}],
    Polygon[{{0.240831, 0.017272, -0.008122},{0.241908, 0.017622, -0.006273},{
      0.240160, 0.021054, -0.006273},{0.239243, 0.020388, -0.008122}}],
    Polygon[{{0.241908, 0.017622, -0.006273},{0.242698, 0.017878, -0.004270},{
      0.240831, 0.021541, -0.004270},{0.240160, 0.021054, -0.006273}}],
    Polygon[{{0.242698, 0.017878, -0.004270},{0.243179, 0.018035, -0.002162},{
      0.241240, 0.021839, -0.002162},{0.240831, 0.021541, -0.004270}}],
    Polygon[{{0.243179, 0.018035, -0.002162},{0.243341, 0.018087, 0.000000},{
      0.241378, 0.021939, 0.000000},{0.241240, 0.021839, -0.002162}}],
    Polygon[{{0.243341, 0.018087, 0.000000},{0.243179, 0.018035, 0.002162},{
      0.241240, 0.021839, 0.002162},{0.241378, 0.021939, 0.000000}}],
    Polygon[{{0.243179, 0.018035, 0.002162},{0.242698, 0.017878, 0.004270},{
      0.240831, 0.021541, 0.004270},{0.241240, 0.021839, 0.002162}}],
    Polygon[{{0.242698, 0.017878, 0.004270},{0.241908, 0.017622, 0.006273},{
      0.240160, 0.021054, 0.006273},{0.240831, 0.021541, 0.004270}}],
    Polygon[{{0.241908, 0.017622, 0.006273},{0.240831, 0.017272, 0.008122},{
      0.239243, 0.020388, 0.008122},{0.240160, 0.021054, 0.006273}}],
    Polygon[{{0.240831, 0.017272, 0.008122},{0.239492, 0.016836, 0.009770},{
      0.238104, 0.019560, 0.009770},{0.239243, 0.020388, 0.008122}}],
    Polygon[{{0.239492, 0.016836, 0.009770},{0.237924, 0.016327, 0.011178},{
      0.236770, 0.018591, 0.011178},{0.238104, 0.019560, 0.009770}}],
    Polygon[{{0.237924, 0.016327, 0.011178},{0.236166, 0.015756, 0.012311},{
      0.235275, 0.017504, 0.012311},{0.236770, 0.018591, 0.011178}}],
    Polygon[{{0.236166, 0.015756, 0.012311},{0.234260, 0.015137, 0.013141},{
      0.233654, 0.016327, 0.013141},{0.235275, 0.017504, 0.012311}}],
    Polygon[{{0.234260, 0.015137, 0.013141},{0.232255, 0.014485, 0.013647},{
      0.231948, 0.015088, 0.013647},{0.233654, 0.016327, 0.013141}}],
    Polygon[{{0.231948, 0.015088, -0.013647},{0.233654, 0.016327, -0.013141},{
      0.232709, 0.017272, -0.013141},{0.231470, 0.015566, -0.013647}}],
    Polygon[{{0.233654, 0.016327, -0.013141},{0.235275, 0.017504, -0.012311},{
      0.233887, 0.018892, -0.012311},{0.232709, 0.017272, -0.013141}}],
    Polygon[{{0.235275, 0.017504, -0.012311},{0.236770, 0.018591, -0.011178},{
      0.234973, 0.020388, -0.011178},{0.233887, 0.018892, -0.012311}}],
    Polygon[{{0.236770, 0.018591, -0.011178},{0.238104, 0.019560, -0.009770},{
      0.235942, 0.021722, -0.009770},{0.234973, 0.020388, -0.011178}}],
    Polygon[{{0.238104, 0.019560, -0.009770},{0.239243, 0.020388, -0.008122},{
      0.236770, 0.022861, -0.008122},{0.235942, 0.021722, -0.009770}}],
    Polygon[{{0.239243, 0.020388, -0.008122},{0.240160, 0.021054, -0.006273},{
      0.237436, 0.023777, -0.006273},{0.236770, 0.022861, -0.008122}}],
    Polygon[{{0.240160, 0.021054, -0.006273},{0.240831, 0.021541, -0.004270},{
      0.237924, 0.024449, -0.004270},{0.237436, 0.023777, -0.006273}}],
    Polygon[{{0.240831, 0.021541, -0.004270},{0.241240, 0.021839, -0.002162},{
      0.238221, 0.024858, -0.002162},{0.237924, 0.024449, -0.004270}}],
    Polygon[{{0.241240, 0.021839, -0.002162},{0.241378, 0.021939, 0.000000},{
      0.238321, 0.024996, 0.000000},{0.238221, 0.024858, -0.002162}}],
    Polygon[{{0.241378, 0.021939, 0.000000},{0.241240, 0.021839, 0.002162},{
      0.238221, 0.024858, 0.002162},{0.238321, 0.024996, 0.000000}}],
    Polygon[{{0.241240, 0.021839, 0.002162},{0.240831, 0.021541, 0.004270},{
      0.237924, 0.024449, 0.004270},{0.238221, 0.024858, 0.002162}}],
    Polygon[{{0.240831, 0.021541, 0.004270},{0.240160, 0.021054, 0.006273},{
      0.237436, 0.023777, 0.006273},{0.237924, 0.024449, 0.004270}}],
    Polygon[{{0.240160, 0.021054, 0.006273},{0.239243, 0.020388, 0.008122},{
      0.236770, 0.022861, 0.008122},{0.237436, 0.023777, 0.006273}}],
    Polygon[{{0.239243, 0.020388, 0.008122},{0.238104, 0.019560, 0.009770},{
      0.235942, 0.021722, 0.009770},{0.236770, 0.022861, 0.008122}}],
    Polygon[{{0.238104, 0.019560, 0.009770},{0.236770, 0.018591, 0.011178},{
      0.234973, 0.020388, 0.011178},{0.235942, 0.021722, 0.009770}}],
    Polygon[{{0.236770, 0.018591, 0.011178},{0.235275, 0.017504, 0.012311},{
      0.233887, 0.018892, 0.012311},{0.234973, 0.020388, 0.011178}}],
    Polygon[{{0.235275, 0.017504, 0.012311},{0.233654, 0.016327, 0.013141},{
      0.232709, 0.017272, 0.013141},{0.233887, 0.018892, 0.012311}}],
    Polygon[{{0.233654, 0.016327, 0.013141},{0.231948, 0.015088, 0.013647},{
      0.231470, 0.015566, 0.013647},{0.232709, 0.017272, 0.013141}}],
    Polygon[{{0.231470, 0.015566, -0.013647},{0.232709, 0.017272, -0.013141},{
      0.231519, 0.017878, -0.013141},{0.230868, 0.015873, -0.013647}}],
    Polygon[{{0.232709, 0.017272, -0.013141},{0.233887, 0.018892, -0.012311},{
      0.232138, 0.019783, -0.012311},{0.231519, 0.017878, -0.013141}}],
    Polygon[{{0.233887, 0.018892, -0.012311},{0.234973, 0.020388, -0.011178},{
      0.232709, 0.021541, -0.011178},{0.232138, 0.019783, -0.012311}}],
    Polygon[{{0.234973, 0.020388, -0.011178},{0.235942, 0.021722, -0.009770},{
      0.233219, 0.023109, -0.009770},{0.232709, 0.021541, -0.011178}}],
    Polygon[{{0.235942, 0.021722, -0.009770},{0.236770, 0.022861, -0.008122},{
      0.233654, 0.024449, -0.008122},{0.233219, 0.023109, -0.009770}}],
    Polygon[{{0.236770, 0.022861, -0.008122},{0.237436, 0.023777, -0.006273},{
      0.234004, 0.025526, -0.006273},{0.233654, 0.024449, -0.008122}}],
    Polygon[{{0.237436, 0.023777, -0.006273},{0.237924, 0.024449, -0.004270},{
      0.234260, 0.026315, -0.004270},{0.234004, 0.025526, -0.006273}}],
    Polygon[{{0.237924, 0.024449, -0.004270},{0.238221, 0.024858, -0.002162},{
      0.234417, 0.026797, -0.002162},{0.234260, 0.026315, -0.004270}}],
    Polygon[{{0.238221, 0.024858, -0.002162},{0.238321, 0.024996, 0.000000},{
      0.234469, 0.026958, 0.000000},{0.234417, 0.026797, -0.002162}}],
    Polygon[{{0.238321, 0.024996, 0.000000},{0.238221, 0.024858, 0.002162},{
      0.234417, 0.026797, 0.002162},{0.234469, 0.026958, 0.000000}}],
    Polygon[{{0.238221, 0.024858, 0.002162},{0.237924, 0.024449, 0.004270},{
      0.234260, 0.026315, 0.004270},{0.234417, 0.026797, 0.002162}}],
    Polygon[{{0.237924, 0.024449, 0.004270},{0.237436, 0.023777, 0.006273},{
      0.234004, 0.025526, 0.006273},{0.234260, 0.026315, 0.004270}}],
    Polygon[{{0.237436, 0.023777, 0.006273},{0.236770, 0.022861, 0.008122},{
      0.233654, 0.024449, 0.008122},{0.234004, 0.025526, 0.006273}}],
    Polygon[{{0.236770, 0.022861, 0.008122},{0.235942, 0.021722, 0.009770},{
      0.233219, 0.023109, 0.009770},{0.233654, 0.024449, 0.008122}}],
    Polygon[{{0.235942, 0.021722, 0.009770},{0.234973, 0.020388, 0.011178},{
      0.232709, 0.021541, 0.011178},{0.233219, 0.023109, 0.009770}}],
    Polygon[{{0.234973, 0.020388, 0.011178},{0.233887, 0.018892, 0.012311},{
      0.232138, 0.019783, 0.012311},{0.232709, 0.021541, 0.011178}}],
    Polygon[{{0.233887, 0.018892, 0.012311},{0.232709, 0.017272, 0.013141},{
      0.231519, 0.017878, 0.013141},{0.232138, 0.019783, 0.012311}}],
    Polygon[{{0.232709, 0.017272, 0.013141},{0.231470, 0.015566, 0.013647},{
      0.230868, 0.015873, 0.013647},{0.231519, 0.017878, 0.013141}}],
    Polygon[{{0.230868, 0.015873, -0.013647},{0.231519, 0.017878, -0.013141},{
      0.230200, 0.018087, -0.013141},{0.230200, 0.015979, -0.013647}}],
    Polygon[{{0.231519, 0.017878, -0.013141},{0.232138, 0.019783, -0.012311},{
      0.230200, 0.020090, -0.012311},{0.230200, 0.018087, -0.013141}}],
    Polygon[{{0.232138, 0.019783, -0.012311},{0.232709, 0.021541, -0.011178},{
      0.230200, 0.021939, -0.011178},{0.230200, 0.020090, -0.012311}}],
    Polygon[{{0.232709, 0.021541, -0.011178},{0.233219, 0.023109, -0.009770},{
      0.230200, 0.023588, -0.009770},{0.230200, 0.021939, -0.011178}}],
    Polygon[{{0.233219, 0.023109, -0.009770},{0.233654, 0.024449, -0.008122},{
      0.230200, 0.024996, -0.008122},{0.230200, 0.023588, -0.009770}}],
    Polygon[{{0.233654, 0.024449, -0.008122},{0.234004, 0.025526, -0.006273},{
      0.230200, 0.026129, -0.006273},{0.230200, 0.024996, -0.008122}}],
    Polygon[{{0.234004, 0.025526, -0.006273},{0.234260, 0.026315, -0.004270},{
      0.230200, 0.026958, -0.004270},{0.230200, 0.026129, -0.006273}}],
    Polygon[{{0.234260, 0.026315, -0.004270},{0.234417, 0.026797, -0.002162},{
      0.230200, 0.027464, -0.002162},{0.230200, 0.026958, -0.004270}}],
    Polygon[{{0.234417, 0.026797, -0.002162},{0.234469, 0.026958, 0.000000},{
      0.230200, 0.027635, 0.000000},{0.230200, 0.027464, -0.002162}}],
    Polygon[{{0.234469, 0.026958, 0.000000},{0.234417, 0.026797, 0.002162},{
      0.230200, 0.027464, 0.002162},{0.230200, 0.027635, 0.000000}}],
    Polygon[{{0.234417, 0.026797, 0.002162},{0.234260, 0.026315, 0.004270},{
      0.230200, 0.026958, 0.004270},{0.230200, 0.027464, 0.002162}}],
    Polygon[{{0.234260, 0.026315, 0.004270},{0.234004, 0.025526, 0.006273},{
      0.230200, 0.026129, 0.006273},{0.230200, 0.026958, 0.004270}}],
    Polygon[{{0.234004, 0.025526, 0.006273},{0.233654, 0.024449, 0.008122},{
      0.230200, 0.024996, 0.008122},{0.230200, 0.026129, 0.006273}}],
    Polygon[{{0.233654, 0.024449, 0.008122},{0.233219, 0.023109, 0.009770},{
      0.230200, 0.023588, 0.009770},{0.230200, 0.024996, 0.008122}}],
    Polygon[{{0.233219, 0.023109, 0.009770},{0.232709, 0.021541, 0.011178},{
      0.230200, 0.021939, 0.011178},{0.230200, 0.023588, 0.009770}}],
    Polygon[{{0.232709, 0.021541, 0.011178},{0.232138, 0.019783, 0.012311},{
      0.230200, 0.020090, 0.012311},{0.230200, 0.021939, 0.011178}}],
    Polygon[{{0.232138, 0.019783, 0.012311},{0.231519, 0.017878, 0.013141},{
      0.230200, 0.018087, 0.013141},{0.230200, 0.020090, 0.012311}}],
    Polygon[{{0.231519, 0.017878, 0.013141},{0.230868, 0.015873, 0.013647},{
      0.230200, 0.015979, 0.013647},{0.230200, 0.018087, 0.013141}}],
    Polygon[{{0.230200, 0.015979, -0.013647},{0.230200, 0.018087, -0.013141},{
      0.228880, 0.017878, -0.013141},{0.229532, 0.015873, -0.013647}}],
    Polygon[{{0.230200, 0.018087, -0.013141},{0.230200, 0.020090, -0.012311},{
      0.228261, 0.019783, -0.012311},{0.228880, 0.017878, -0.013141}}],
    Polygon[{{0.230200, 0.020090, -0.012311},{0.230200, 0.021939, -0.011178},{
      0.227690, 0.021541, -0.011178},{0.228261, 0.019783, -0.012311}}],
    Polygon[{{0.230200, 0.021939, -0.011178},{0.230200, 0.023588, -0.009770},{
      0.227180, 0.023109, -0.009770},{0.227690, 0.021541, -0.011178}}],
    Polygon[{{0.230200, 0.023588, -0.009770},{0.230200, 0.024996, -0.008122},{
      0.226745, 0.024449, -0.008122},{0.227180, 0.023109, -0.009770}}],
    Polygon[{{0.230200, 0.024996, -0.008122},{0.230200, 0.026129, -0.006273},{
      0.226395, 0.025526, -0.006273},{0.226745, 0.024449, -0.008122}}],
    Polygon[{{0.230200, 0.026129, -0.006273},{0.230200, 0.026958, -0.004270},{
      0.226139, 0.026315, -0.004270},{0.226395, 0.025526, -0.006273}}],
    Polygon[{{0.230200, 0.026958, -0.004270},{0.230200, 0.027464, -0.002162},{
      0.225982, 0.026797, -0.002162},{0.226139, 0.026315, -0.004270}}],
    Polygon[{{0.230200, 0.027464, -0.002162},{0.230200, 0.027635, 0.000000},{
      0.225930, 0.026958, 0.000000},{0.225982, 0.026797, -0.002162}}],
    Polygon[{{0.230200, 0.027635, 0.000000},{0.230200, 0.027464, 0.002162},{
      0.225982, 0.026797, 0.002162},{0.225930, 0.026958, 0.000000}}],
    Polygon[{{0.230200, 0.027464, 0.002162},{0.230200, 0.026958, 0.004270},{
      0.226139, 0.026315, 0.004270},{0.225982, 0.026797, 0.002162}}],
    Polygon[{{0.230200, 0.026958, 0.004270},{0.230200, 0.026129, 0.006273},{
      0.226395, 0.025526, 0.006273},{0.226139, 0.026315, 0.004270}}],
    Polygon[{{0.230200, 0.026129, 0.006273},{0.230200, 0.024996, 0.008122},{
      0.226745, 0.024449, 0.008122},{0.226395, 0.025526, 0.006273}}],
    Polygon[{{0.230200, 0.024996, 0.008122},{0.230200, 0.023588, 0.009770},{
      0.227180, 0.023109, 0.009770},{0.226745, 0.024449, 0.008122}}],
    Polygon[{{0.230200, 0.023588, 0.009770},{0.230200, 0.021939, 0.011178},{
      0.227690, 0.021541, 0.011178},{0.227180, 0.023109, 0.009770}}],
    Polygon[{{0.230200, 0.021939, 0.011178},{0.230200, 0.020090, 0.012311},{
      0.228261, 0.019783, 0.012311},{0.227690, 0.021541, 0.011178}}],
    Polygon[{{0.230200, 0.020090, 0.012311},{0.230200, 0.018087, 0.013141},{
      0.228880, 0.017878, 0.013141},{0.228261, 0.019783, 0.012311}}],
    Polygon[{{0.230200, 0.018087, 0.013141},{0.230200, 0.015979, 0.013647},{
      0.229532, 0.015873, 0.013647},{0.228880, 0.017878, 0.013141}}],
    Polygon[{{0.229532, 0.015873, -0.013647},{0.228880, 0.017878, -0.013141},{
      0.227690, 0.017272, -0.013141},{0.228929, 0.015566, -0.013647}}],
    Polygon[{{0.228880, 0.017878, -0.013141},{0.228261, 0.019783, -0.012311},{
      0.226513, 0.018892, -0.012311},{0.227690, 0.017272, -0.013141}}],
    Polygon[{{0.228261, 0.019783, -0.012311},{0.227690, 0.021541, -0.011178},{
      0.225426, 0.020388, -0.011178},{0.226513, 0.018892, -0.012311}}],
    Polygon[{{0.227690, 0.021541, -0.011178},{0.227180, 0.023109, -0.009770},{
      0.224457, 0.021722, -0.009770},{0.225426, 0.020388, -0.011178}}],
    Polygon[{{0.227180, 0.023109, -0.009770},{0.226745, 0.024449, -0.008122},{
      0.223629, 0.022861, -0.008122},{0.224457, 0.021722, -0.009770}}],
    Polygon[{{0.226745, 0.024449, -0.008122},{0.226395, 0.025526, -0.006273},{
      0.222963, 0.023777, -0.006273},{0.223629, 0.022861, -0.008122}}],
    Polygon[{{0.226395, 0.025526, -0.006273},{0.226139, 0.026315, -0.004270},{
      0.222476, 0.024449, -0.004270},{0.222963, 0.023777, -0.006273}}],
    Polygon[{{0.226139, 0.026315, -0.004270},{0.225982, 0.026797, -0.002162},{
      0.222178, 0.024858, -0.002162},{0.222476, 0.024449, -0.004270}}],
    Polygon[{{0.225982, 0.026797, -0.002162},{0.225930, 0.026958, 0.000000},{
      0.222078, 0.024996, 0.000000},{0.222178, 0.024858, -0.002162}}],
    Polygon[{{0.225930, 0.026958, 0.000000},{0.225982, 0.026797, 0.002162},{
      0.222178, 0.024858, 0.002162},{0.222078, 0.024996, 0.000000}}],
    Polygon[{{0.225982, 0.026797, 0.002162},{0.226139, 0.026315, 0.004270},{
      0.222476, 0.024449, 0.004270},{0.222178, 0.024858, 0.002162}}],
    Polygon[{{0.226139, 0.026315, 0.004270},{0.226395, 0.025526, 0.006273},{
      0.222963, 0.023777, 0.006273},{0.222476, 0.024449, 0.004270}}],
    Polygon[{{0.226395, 0.025526, 0.006273},{0.226745, 0.024449, 0.008122},{
      0.223629, 0.022861, 0.008122},{0.222963, 0.023777, 0.006273}}],
    Polygon[{{0.226745, 0.024449, 0.008122},{0.227180, 0.023109, 0.009770},{
      0.224457, 0.021722, 0.009770},{0.223629, 0.022861, 0.008122}}],
    Polygon[{{0.227180, 0.023109, 0.009770},{0.227690, 0.021541, 0.011178},{
      0.225426, 0.020388, 0.011178},{0.224457, 0.021722, 0.009770}}],
    Polygon[{{0.227690, 0.021541, 0.011178},{0.228261, 0.019783, 0.012311},{
      0.226513, 0.018892, 0.012311},{0.225426, 0.020388, 0.011178}}],
    Polygon[{{0.228261, 0.019783, 0.012311},{0.228880, 0.017878, 0.013141},{
      0.227690, 0.017272, 0.013141},{0.226513, 0.018892, 0.012311}}],
    Polygon[{{0.228880, 0.017878, 0.013141},{0.229532, 0.015873, 0.013647},{
      0.228929, 0.015566, 0.013647},{0.227690, 0.017272, 0.013141}}],
    Polygon[{{0.228929, 0.015566, -0.013647},{0.227690, 0.017272, -0.013141},{
      0.226745, 0.016327, -0.013141},{0.228451, 0.015088, -0.013647}}],
    Polygon[{{0.227690, 0.017272, -0.013141},{0.226513, 0.018892, -0.012311},{
      0.225125, 0.017504, -0.012311},{0.226745, 0.016327, -0.013141}}],
    Polygon[{{0.226513, 0.018892, -0.012311},{0.225426, 0.020388, -0.011178},{
      0.223629, 0.018591, -0.011178},{0.225125, 0.017504, -0.012311}}],
    Polygon[{{0.225426, 0.020388, -0.011178},{0.224457, 0.021722, -0.009770},{
      0.222295, 0.019560, -0.009770},{0.223629, 0.018591, -0.011178}}],
    Polygon[{{0.224457, 0.021722, -0.009770},{0.223629, 0.022861, -0.008122},{
      0.221156, 0.020388, -0.008122},{0.222295, 0.019560, -0.009770}}],
    Polygon[{{0.223629, 0.022861, -0.008122},{0.222963, 0.023777, -0.006273},{
      0.220240, 0.021054, -0.006273},{0.221156, 0.020388, -0.008122}}],
    Polygon[{{0.222963, 0.023777, -0.006273},{0.222476, 0.024449, -0.004270},{
      0.219568, 0.021541, -0.004270},{0.220240, 0.021054, -0.006273}}],
    Polygon[{{0.222476, 0.024449, -0.004270},{0.222178, 0.024858, -0.002162},{
      0.219159, 0.021839, -0.002162},{0.219568, 0.021541, -0.004270}}],
    Polygon[{{0.222178, 0.024858, -0.002162},{0.222078, 0.024996, 0.000000},{
      0.219021, 0.021939, 0.000000},{0.219159, 0.021839, -0.002162}}],
    Polygon[{{0.222078, 0.024996, 0.000000},{0.222178, 0.024858, 0.002162},{
      0.219159, 0.021839, 0.002162},{0.219021, 0.021939, 0.000000}}],
    Polygon[{{0.222178, 0.024858, 0.002162},{0.222476, 0.024449, 0.004270},{
      0.219568, 0.021541, 0.004270},{0.219159, 0.021839, 0.002162}}],
    Polygon[{{0.222476, 0.024449, 0.004270},{0.222963, 0.023777, 0.006273},{
      0.220240, 0.021054, 0.006273},{0.219568, 0.021541, 0.004270}}],
    Polygon[{{0.222963, 0.023777, 0.006273},{0.223629, 0.022861, 0.008122},{
      0.221156, 0.020388, 0.008122},{0.220240, 0.021054, 0.006273}}],
    Polygon[{{0.223629, 0.022861, 0.008122},{0.224457, 0.021722, 0.009770},{
      0.222295, 0.019560, 0.009770},{0.221156, 0.020388, 0.008122}}],
    Polygon[{{0.224457, 0.021722, 0.009770},{0.225426, 0.020388, 0.011178},{
      0.223629, 0.018591, 0.011178},{0.222295, 0.019560, 0.009770}}],
    Polygon[{{0.225426, 0.020388, 0.011178},{0.226513, 0.018892, 0.012311},{
      0.225125, 0.017504, 0.012311},{0.223629, 0.018591, 0.011178}}],
    Polygon[{{0.226513, 0.018892, 0.012311},{0.227690, 0.017272, 0.013141},{
      0.226745, 0.016327, 0.013141},{0.225125, 0.017504, 0.012311}}],
    Polygon[{{0.227690, 0.017272, 0.013141},{0.228929, 0.015566, 0.013647},{
      0.228451, 0.015088, 0.013647},{0.226745, 0.016327, 0.013141}}],
    Polygon[{{0.228451, 0.015088, -0.013647},{0.226745, 0.016327, -0.013141},{
      0.226139, 0.015137, -0.013141},{0.228144, 0.014485, -0.013647}}],
    Polygon[{{0.226745, 0.016327, -0.013141},{0.225125, 0.017504, -0.012311},{
      0.224234, 0.015756, -0.012311},{0.226139, 0.015137, -0.013141}}],
    Polygon[{{0.225125, 0.017504, -0.012311},{0.223629, 0.018591, -0.011178},{
      0.222476, 0.016327, -0.011178},{0.224234, 0.015756, -0.012311}}],
    Polygon[{{0.223629, 0.018591, -0.011178},{0.222295, 0.019560, -0.009770},{
      0.220908, 0.016836, -0.009770},{0.222476, 0.016327, -0.011178}}],
    Polygon[{{0.222295, 0.019560, -0.009770},{0.221156, 0.020388, -0.008122},{
      0.219568, 0.017272, -0.008122},{0.220908, 0.016836, -0.009770}}],
    Polygon[{{0.221156, 0.020388, -0.008122},{0.220240, 0.021054, -0.006273},{
      0.218491, 0.017622, -0.006273},{0.219568, 0.017272, -0.008122}}],
    Polygon[{{0.220240, 0.021054, -0.006273},{0.219568, 0.021541, -0.004270},{
      0.217702, 0.017878, -0.004270},{0.218491, 0.017622, -0.006273}}],
    Polygon[{{0.219568, 0.021541, -0.004270},{0.219159, 0.021839, -0.002162},{
      0.217220, 0.018035, -0.002162},{0.217702, 0.017878, -0.004270}}],
    Polygon[{{0.219159, 0.021839, -0.002162},{0.219021, 0.021939, 0.000000},{
      0.217059, 0.018087, 0.000000},{0.217220, 0.018035, -0.002162}}],
    Polygon[{{0.219021, 0.021939, 0.000000},{0.219159, 0.021839, 0.002162},{
      0.217220, 0.018035, 0.002162},{0.217059, 0.018087, 0.000000}}],
    Polygon[{{0.219159, 0.021839, 0.002162},{0.219568, 0.021541, 0.004270},{
      0.217702, 0.017878, 0.004270},{0.217220, 0.018035, 0.002162}}],
    Polygon[{{0.219568, 0.021541, 0.004270},{0.220240, 0.021054, 0.006273},{
      0.218491, 0.017622, 0.006273},{0.217702, 0.017878, 0.004270}}],
    Polygon[{{0.220240, 0.021054, 0.006273},{0.221156, 0.020388, 0.008122},{
      0.219568, 0.017272, 0.008122},{0.218491, 0.017622, 0.006273}}],
    Polygon[{{0.221156, 0.020388, 0.008122},{0.222295, 0.019560, 0.009770},{
      0.220908, 0.016836, 0.009770},{0.219568, 0.017272, 0.008122}}],
    Polygon[{{0.222295, 0.019560, 0.009770},{0.223629, 0.018591, 0.011178},{
      0.222476, 0.016327, 0.011178},{0.220908, 0.016836, 0.009770}}],
    Polygon[{{0.223629, 0.018591, 0.011178},{0.225125, 0.017504, 0.012311},{
      0.224234, 0.015756, 0.012311},{0.222476, 0.016327, 0.011178}}],
    Polygon[{{0.225125, 0.017504, 0.012311},{0.226745, 0.016327, 0.013141},{
      0.226139, 0.015137, 0.013141},{0.224234, 0.015756, 0.012311}}],
    Polygon[{{0.226745, 0.016327, 0.013141},{0.228451, 0.015088, 0.013647},{
      0.228144, 0.014485, 0.013647},{0.226139, 0.015137, 0.013141}}],
    Polygon[{{0.228144, 0.014485, -0.013647},{0.226139, 0.015137, -0.013141},{
      0.225930, 0.013817, -0.013141},{0.228038, 0.013817, -0.013647}}],
    Polygon[{{0.226139, 0.015137, -0.013141},{0.224234, 0.015756, -0.012311},{
      0.223927, 0.013817, -0.012311},{0.225930, 0.013817, -0.013141}}],
    Polygon[{{0.224234, 0.015756, -0.012311},{0.222476, 0.016327, -0.011178},{
      0.222078, 0.013817, -0.011178},{0.223927, 0.013817, -0.012311}}],
    Polygon[{{0.222476, 0.016327, -0.011178},{0.220908, 0.016836, -0.009770},{
      0.220429, 0.013817, -0.009770},{0.222078, 0.013817, -0.011178}}],
    Polygon[{{0.220908, 0.016836, -0.009770},{0.219568, 0.017272, -0.008122},{
      0.219021, 0.013817, -0.008122},{0.220429, 0.013817, -0.009770}}],
    Polygon[{{0.219568, 0.017272, -0.008122},{0.218491, 0.017622, -0.006273},{
      0.217888, 0.013817, -0.006273},{0.219021, 0.013817, -0.008122}}],
    Polygon[{{0.218491, 0.017622, -0.006273},{0.217702, 0.017878, -0.004270},{
      0.217059, 0.013817, -0.004270},{0.217888, 0.013817, -0.006273}}],
    Polygon[{{0.217702, 0.017878, -0.004270},{0.217220, 0.018035, -0.002162},{
      0.216552, 0.013817, -0.002162},{0.217059, 0.013817, -0.004270}}],
    Polygon[{{0.217220, 0.018035, -0.002162},{0.217059, 0.018087, 0.000000},{
      0.216382, 0.013817, 0.000000},{0.216552, 0.013817, -0.002162}}],
    Polygon[{{0.217059, 0.018087, 0.000000},{0.217220, 0.018035, 0.002162},{
      0.216552, 0.013817, 0.002162},{0.216382, 0.013817, 0.000000}}],
    Polygon[{{0.217220, 0.018035, 0.002162},{0.217702, 0.017878, 0.004270},{
      0.217059, 0.013817, 0.004270},{0.216552, 0.013817, 0.002162}}],
    Polygon[{{0.217702, 0.017878, 0.004270},{0.218491, 0.017622, 0.006273},{
      0.217888, 0.013817, 0.006273},{0.217059, 0.013817, 0.004270}}],
    Polygon[{{0.218491, 0.017622, 0.006273},{0.219568, 0.017272, 0.008122},{
      0.219021, 0.013817, 0.008122},{0.217888, 0.013817, 0.006273}}],
    Polygon[{{0.219568, 0.017272, 0.008122},{0.220908, 0.016836, 0.009770},{
      0.220429, 0.013817, 0.009770},{0.219021, 0.013817, 0.008122}}],
    Polygon[{{0.220908, 0.016836, 0.009770},{0.222476, 0.016327, 0.011178},{
      0.222078, 0.013817, 0.011178},{0.220429, 0.013817, 0.009770}}],
    Polygon[{{0.222476, 0.016327, 0.011178},{0.224234, 0.015756, 0.012311},{
      0.223927, 0.013817, 0.012311},{0.222078, 0.013817, 0.011178}}],
    Polygon[{{0.224234, 0.015756, 0.012311},{0.226139, 0.015137, 0.013141},{
      0.225930, 0.013817, 0.013141},{0.223927, 0.013817, 0.012311}}],
    Polygon[{{0.226139, 0.015137, 0.013141},{0.228144, 0.014485, 0.013647},{
      0.228038, 0.013817, 0.013647},{0.225930, 0.013817, 0.013141}}],
    Polygon[{{0.228038, 0.013817, -0.013647},{0.225930, 0.013817, -0.013141},{
      0.226139, 0.012498, -0.013141},{0.228144, 0.013149, -0.013647}}],
    Polygon[{{0.225930, 0.013817, -0.013141},{0.223927, 0.013817, -0.012311},{
      0.224234, 0.011879, -0.012311},{0.226139, 0.012498, -0.013141}}],
    Polygon[{{0.223927, 0.013817, -0.012311},{0.222078, 0.013817, -0.011178},{
      0.222476, 0.011308, -0.011178},{0.224234, 0.011879, -0.012311}}],
    Polygon[{{0.222078, 0.013817, -0.011178},{0.220429, 0.013817, -0.009770},{
      0.220908, 0.010798, -0.009770},{0.222476, 0.011308, -0.011178}}],
    Polygon[{{0.220429, 0.013817, -0.009770},{0.219021, 0.013817, -0.008122},{
      0.219568, 0.010363, -0.008122},{0.220908, 0.010798, -0.009770}}],
    Polygon[{{0.219021, 0.013817, -0.008122},{0.217888, 0.013817, -0.006273},{
      0.218491, 0.010013, -0.006273},{0.219568, 0.010363, -0.008122}}],
    Polygon[{{0.217888, 0.013817, -0.006273},{0.217059, 0.013817, -0.004270},{
      0.217702, 0.009756, -0.004270},{0.218491, 0.010013, -0.006273}}],
    Polygon[{{0.217059, 0.013817, -0.004270},{0.216552, 0.013817, -0.002162},{
      0.217220, 0.009600, -0.002162},{0.217702, 0.009756, -0.004270}}],
    Polygon[{{0.216552, 0.013817, -0.002162},{0.216382, 0.013817, 0.000000},{
      0.217059, 0.009548, 0.000000},{0.217220, 0.009600, -0.002162}}],
    Polygon[{{0.216382, 0.013817, 0.000000},{0.216552, 0.013817, 0.002162},{
      0.217220, 0.009600, 0.002162},{0.217059, 0.009548, 0.000000}}],
    Polygon[{{0.216552, 0.013817, 0.002162},{0.217059, 0.013817, 0.004270},{
      0.217702, 0.009756, 0.004270},{0.217220, 0.009600, 0.002162}}],
    Polygon[{{0.217059, 0.013817, 0.004270},{0.217888, 0.013817, 0.006273},{
      0.218491, 0.010013, 0.006273},{0.217702, 0.009756, 0.004270}}],
    Polygon[{{0.217888, 0.013817, 0.006273},{0.219021, 0.013817, 0.008122},{
      0.219568, 0.010363, 0.008122},{0.218491, 0.010013, 0.006273}}],
    Polygon[{{0.219021, 0.013817, 0.008122},{0.220429, 0.013817, 0.009770},{
      0.220908, 0.010798, 0.009770},{0.219568, 0.010363, 0.008122}}],
    Polygon[{{0.220429, 0.013817, 0.009770},{0.222078, 0.013817, 0.011178},{
      0.222476, 0.011308, 0.011178},{0.220908, 0.010798, 0.009770}}],
    Polygon[{{0.222078, 0.013817, 0.011178},{0.223927, 0.013817, 0.012311},{
      0.224234, 0.011879, 0.012311},{0.222476, 0.011308, 0.011178}}],
    Polygon[{{0.223927, 0.013817, 0.012311},{0.225930, 0.013817, 0.013141},{
      0.226139, 0.012498, 0.013141},{0.224234, 0.011879, 0.012311}}],
    Polygon[{{0.225930, 0.013817, 0.013141},{0.228038, 0.013817, 0.013647},{
      0.228144, 0.013149, 0.013647},{0.226139, 0.012498, 0.013141}}],
    Polygon[{{0.228144, 0.013149, -0.013647},{0.226139, 0.012498, -0.013141},{
      0.226745, 0.011308, -0.013141},{0.228451, 0.012547, -0.013647}}],
    Polygon[{{0.226139, 0.012498, -0.013141},{0.224234, 0.011879, -0.012311},{
      0.225125, 0.010130, -0.012311},{0.226745, 0.011308, -0.013141}}],
    Polygon[{{0.224234, 0.011879, -0.012311},{0.222476, 0.011308, -0.011178},{
      0.223629, 0.009044, -0.011178},{0.225125, 0.010130, -0.012311}}],
    Polygon[{{0.222476, 0.011308, -0.011178},{0.220908, 0.010798, -0.009770},{
      0.222295, 0.008074, -0.009770},{0.223629, 0.009044, -0.011178}}],
    Polygon[{{0.220908, 0.010798, -0.009770},{0.219568, 0.010363, -0.008122},{
      0.221156, 0.007247, -0.008122},{0.222295, 0.008074, -0.009770}}],
    Polygon[{{0.219568, 0.010363, -0.008122},{0.218491, 0.010013, -0.006273},{
      0.220240, 0.006581, -0.006273},{0.221156, 0.007247, -0.008122}}],
    Polygon[{{0.218491, 0.010013, -0.006273},{0.217702, 0.009756, -0.004270},{
      0.219568, 0.006093, -0.004270},{0.220240, 0.006581, -0.006273}}],
    Polygon[{{0.217702, 0.009756, -0.004270},{0.217220, 0.009600, -0.002162},{
      0.219159, 0.005796, -0.002162},{0.219568, 0.006093, -0.004270}}],
    Polygon[{{0.217220, 0.009600, -0.002162},{0.217059, 0.009548, 0.000000},{
      0.219021, 0.005696, 0.000000},{0.219159, 0.005796, -0.002162}}],
    Polygon[{{0.217059, 0.009548, 0.000000},{0.217220, 0.009600, 0.002162},{
      0.219159, 0.005796, 0.002162},{0.219021, 0.005696, 0.000000}}],
    Polygon[{{0.217220, 0.009600, 0.002162},{0.217702, 0.009756, 0.004270},{
      0.219568, 0.006093, 0.004270},{0.219159, 0.005796, 0.002162}}],
    Polygon[{{0.217702, 0.009756, 0.004270},{0.218491, 0.010013, 0.006273},{
      0.220240, 0.006581, 0.006273},{0.219568, 0.006093, 0.004270}}],
    Polygon[{{0.218491, 0.010013, 0.006273},{0.219568, 0.010363, 0.008122},{
      0.221156, 0.007247, 0.008122},{0.220240, 0.006581, 0.006273}}],
    Polygon[{{0.219568, 0.010363, 0.008122},{0.220908, 0.010798, 0.009770},{
      0.222295, 0.008074, 0.009770},{0.221156, 0.007247, 0.008122}}],
    Polygon[{{0.220908, 0.010798, 0.009770},{0.222476, 0.011308, 0.011178},{
      0.223629, 0.009044, 0.011178},{0.222295, 0.008074, 0.009770}}],
    Polygon[{{0.222476, 0.011308, 0.011178},{0.224234, 0.011879, 0.012311},{
      0.225125, 0.010130, 0.012311},{0.223629, 0.009044, 0.011178}}],
    Polygon[{{0.224234, 0.011879, 0.012311},{0.226139, 0.012498, 0.013141},{
      0.226745, 0.011308, 0.013141},{0.225125, 0.010130, 0.012311}}],
    Polygon[{{0.226139, 0.012498, 0.013141},{0.228144, 0.013149, 0.013647},{
      0.228451, 0.012547, 0.013647},{0.226745, 0.011308, 0.013141}}],
    Polygon[{{0.228451, 0.012547, -0.013647},{0.226745, 0.011308, -0.013141},{
      0.227690, 0.010363, -0.013141},{0.228929, 0.012069, -0.013647}}],
    Polygon[{{0.226745, 0.011308, -0.013141},{0.225125, 0.010130, -0.012311},{
      0.226513, 0.008742, -0.012311},{0.227690, 0.010363, -0.013141}}],
    Polygon[{{0.225125, 0.010130, -0.012311},{0.223629, 0.009044, -0.011178},{
      0.225426, 0.007247, -0.011178},{0.226513, 0.008742, -0.012311}}],
    Polygon[{{0.223629, 0.009044, -0.011178},{0.222295, 0.008074, -0.009770},{
      0.224457, 0.005913, -0.009770},{0.225426, 0.007247, -0.011178}}],
    Polygon[{{0.222295, 0.008074, -0.009770},{0.221156, 0.007247, -0.008122},{
      0.223629, 0.004774, -0.008122},{0.224457, 0.005913, -0.009770}}],
    Polygon[{{0.221156, 0.007247, -0.008122},{0.220240, 0.006581, -0.006273},{
      0.222963, 0.003857, -0.006273},{0.223629, 0.004774, -0.008122}}],
    Polygon[{{0.220240, 0.006581, -0.006273},{0.219568, 0.006093, -0.004270},{
      0.222476, 0.003186, -0.004270},{0.222963, 0.003857, -0.006273}}],
    Polygon[{{0.219568, 0.006093, -0.004270},{0.219159, 0.005796, -0.002162},{
      0.222178, 0.002776, -0.002162},{0.222476, 0.003186, -0.004270}}],
    Polygon[{{0.219159, 0.005796, -0.002162},{0.219021, 0.005696, 0.000000},{
      0.222078, 0.002639, 0.000000},{0.222178, 0.002776, -0.002162}}],
    Polygon[{{0.219021, 0.005696, 0.000000},{0.219159, 0.005796, 0.002162},{
      0.222178, 0.002776, 0.002162},{0.222078, 0.002639, 0.000000}}],
    Polygon[{{0.219159, 0.005796, 0.002162},{0.219568, 0.006093, 0.004270},{
      0.222476, 0.003186, 0.004270},{0.222178, 0.002776, 0.002162}}],
    Polygon[{{0.219568, 0.006093, 0.004270},{0.220240, 0.006581, 0.006273},{
      0.222963, 0.003857, 0.006273},{0.222476, 0.003186, 0.004270}}],
    Polygon[{{0.220240, 0.006581, 0.006273},{0.221156, 0.007247, 0.008122},{
      0.223629, 0.004774, 0.008122},{0.222963, 0.003857, 0.006273}}],
    Polygon[{{0.221156, 0.007247, 0.008122},{0.222295, 0.008074, 0.009770},{
      0.224457, 0.005913, 0.009770},{0.223629, 0.004774, 0.008122}}],
    Polygon[{{0.222295, 0.008074, 0.009770},{0.223629, 0.009044, 0.011178},{
      0.225426, 0.007247, 0.011178},{0.224457, 0.005913, 0.009770}}],
    Polygon[{{0.223629, 0.009044, 0.011178},{0.225125, 0.010130, 0.012311},{
      0.226513, 0.008742, 0.012311},{0.225426, 0.007247, 0.011178}}],
    Polygon[{{0.225125, 0.010130, 0.012311},{0.226745, 0.011308, 0.013141},{
      0.227690, 0.010363, 0.013141},{0.226513, 0.008742, 0.012311}}],
    Polygon[{{0.226745, 0.011308, 0.013141},{0.228451, 0.012547, 0.013647},{
      0.228929, 0.012069, 0.013647},{0.227690, 0.010363, 0.013141}}],
    Polygon[{{0.228929, 0.012069, -0.013647},{0.227690, 0.010363, -0.013141},{
      0.228880, 0.009756, -0.013141},{0.229532, 0.011762, -0.013647}}],
    Polygon[{{0.227690, 0.010363, -0.013141},{0.226513, 0.008742, -0.012311},{
      0.228261, 0.007851, -0.012311},{0.228880, 0.009756, -0.013141}}],
    Polygon[{{0.226513, 0.008742, -0.012311},{0.225426, 0.007247, -0.011178},{
      0.227690, 0.006093, -0.011178},{0.228261, 0.007851, -0.012311}}],
    Polygon[{{0.225426, 0.007247, -0.011178},{0.224457, 0.005913, -0.009770},{
      0.227180, 0.004525, -0.009770},{0.227690, 0.006093, -0.011178}}],
    Polygon[{{0.224457, 0.005913, -0.009770},{0.223629, 0.004774, -0.008122},{
      0.226745, 0.003186, -0.008122},{0.227180, 0.004525, -0.009770}}],
    Polygon[{{0.223629, 0.004774, -0.008122},{0.222963, 0.003857, -0.006273},{
      0.226395, 0.002109, -0.006273},{0.226745, 0.003186, -0.008122}}],
    Polygon[{{0.222963, 0.003857, -0.006273},{0.222476, 0.003186, -0.004270},{
      0.226139, 0.001319, -0.004270},{0.226395, 0.002109, -0.006273}}],
    Polygon[{{0.222476, 0.003186, -0.004270},{0.222178, 0.002776, -0.002162},{
      0.225982, 0.000838, -0.002162},{0.226139, 0.001319, -0.004270}}],
    Polygon[{{0.222178, 0.002776, -0.002162},{0.222078, 0.002639, 0.000000},{
      0.225930, 0.000676, 0.000000},{0.225982, 0.000838, -0.002162}}],
    Polygon[{{0.222078, 0.002639, 0.000000},{0.222178, 0.002776, 0.002162},{
      0.225982, 0.000838, 0.002162},{0.225930, 0.000676, 0.000000}}],
    Polygon[{{0.222178, 0.002776, 0.002162},{0.222476, 0.003186, 0.004270},{
      0.226139, 0.001319, 0.004270},{0.225982, 0.000838, 0.002162}}],
    Polygon[{{0.222476, 0.003186, 0.004270},{0.222963, 0.003857, 0.006273},{
      0.226395, 0.002109, 0.006273},{0.226139, 0.001319, 0.004270}}],
    Polygon[{{0.222963, 0.003857, 0.006273},{0.223629, 0.004774, 0.008122},{
      0.226745, 0.003186, 0.008122},{0.226395, 0.002109, 0.006273}}],
    Polygon[{{0.223629, 0.004774, 0.008122},{0.224457, 0.005913, 0.009770},{
      0.227180, 0.004525, 0.009770},{0.226745, 0.003186, 0.008122}}],
    Polygon[{{0.224457, 0.005913, 0.009770},{0.225426, 0.007247, 0.011178},{
      0.227690, 0.006093, 0.011178},{0.227180, 0.004525, 0.009770}}],
    Polygon[{{0.225426, 0.007247, 0.011178},{0.226513, 0.008742, 0.012311},{
      0.228261, 0.007851, 0.012311},{0.227690, 0.006093, 0.011178}}],
    Polygon[{{0.226513, 0.008742, 0.012311},{0.227690, 0.010363, 0.013141},{
      0.228880, 0.009756, 0.013141},{0.228261, 0.007851, 0.012311}}],
    Polygon[{{0.227690, 0.010363, 0.013141},{0.228929, 0.012069, 0.013647},{
      0.229532, 0.011762, 0.013647},{0.228880, 0.009756, 0.013141}}],
    Polygon[{{0.229532, 0.011762, -0.013647},{0.228880, 0.009756, -0.013141},{
      0.230200, 0.009548, -0.013141},{0.230200, 0.011656, -0.013647}}],
    Polygon[{{0.228880, 0.009756, -0.013141},{0.228261, 0.007851, -0.012311},{
      0.230200, 0.007544, -0.012311},{0.230200, 0.009548, -0.013141}}],
    Polygon[{{0.228261, 0.007851, -0.012311},{0.227690, 0.006093, -0.011178},{
      0.230200, 0.005696, -0.011178},{0.230200, 0.007544, -0.012311}}],
    Polygon[{{0.227690, 0.006093, -0.011178},{0.227180, 0.004525, -0.009770},{
      0.230200, 0.004047, -0.009770},{0.230200, 0.005696, -0.011178}}],
    Polygon[{{0.227180, 0.004525, -0.009770},{0.226745, 0.003186, -0.008122},{
      0.230200, 0.002639, -0.008122},{0.230200, 0.004047, -0.009770}}],
    Polygon[{{0.226745, 0.003186, -0.008122},{0.226395, 0.002109, -0.006273},{
      0.230200, 0.001506, -0.006273},{0.230200, 0.002639, -0.008122}}],
    Polygon[{{0.226395, 0.002109, -0.006273},{0.226139, 0.001319, -0.004270},{
      0.230200, 0.000676, -0.004270},{0.230200, 0.001506, -0.006273}}],
    Polygon[{{0.226139, 0.001319, -0.004270},{0.225982, 0.000838, -0.002162},{
      0.230200, 0.000170, -0.002162},{0.230200, 0.000676, -0.004270}}],
    Polygon[{{0.225982, 0.000838, -0.002162},{0.225930, 0.000676, 0.000000},{
      0.230200, 0.000000, 0.000000},{0.230200, 0.000170, -0.002162}}],
    Polygon[{{0.225930, 0.000676, 0.000000},{0.225982, 0.000838, 0.002162},{
      0.230200, 0.000170, 0.002162},{0.230200, 0.000000, 0.000000}}],
    Polygon[{{0.225982, 0.000838, 0.002162},{0.226139, 0.001319, 0.004270},{
      0.230200, 0.000676, 0.004270},{0.230200, 0.000170, 0.002162}}],
    Polygon[{{0.226139, 0.001319, 0.004270},{0.226395, 0.002109, 0.006273},{
      0.230200, 0.001506, 0.006273},{0.230200, 0.000676, 0.004270}}],
    Polygon[{{0.226395, 0.002109, 0.006273},{0.226745, 0.003186, 0.008122},{
      0.230200, 0.002639, 0.008122},{0.230200, 0.001506, 0.006273}}],
    Polygon[{{0.226745, 0.003186, 0.008122},{0.227180, 0.004525, 0.009770},{
      0.230200, 0.004047, 0.009770},{0.230200, 0.002639, 0.008122}}],
    Polygon[{{0.227180, 0.004525, 0.009770},{0.227690, 0.006093, 0.011178},{
      0.230200, 0.005696, 0.011178},{0.230200, 0.004047, 0.009770}}],
    Polygon[{{0.227690, 0.006093, 0.011178},{0.228261, 0.007851, 0.012311},{
      0.230200, 0.007544, 0.012311},{0.230200, 0.005696, 0.011178}}],
    Polygon[{{0.228261, 0.007851, 0.012311},{0.228880, 0.009756, 0.013141},{
      0.230200, 0.009548, 0.013141},{0.230200, 0.007544, 0.012311}}],
    Polygon[{{0.228880, 0.009756, 0.013141},{0.229532, 0.011762, 0.013647},{
      0.230200, 0.011656, 0.013647},{0.230200, 0.009548, 0.013141}}],
    Polygon[{{0.230200, 0.011656, -0.013647},{0.230200, 0.009548, -0.013141},{
      0.231519, 0.009756, -0.013141},{0.230868, 0.011762, -0.013647}}],
    Polygon[{{0.230200, 0.009548, -0.013141},{0.230200, 0.007544, -0.012311},{
      0.232138, 0.007851, -0.012311},{0.231519, 0.009756, -0.013141}}],
    Polygon[{{0.230200, 0.007544, -0.012311},{0.230200, 0.005696, -0.011178},{
      0.232709, 0.006093, -0.011178},{0.232138, 0.007851, -0.012311}}],
    Polygon[{{0.230200, 0.005696, -0.011178},{0.230200, 0.004047, -0.009770},{
      0.233219, 0.004525, -0.009770},{0.232709, 0.006093, -0.011178}}],
    Polygon[{{0.230200, 0.004047, -0.009770},{0.230200, 0.002639, -0.008122},{
      0.233654, 0.003186, -0.008122},{0.233219, 0.004525, -0.009770}}],
    Polygon[{{0.230200, 0.002639, -0.008122},{0.230200, 0.001506, -0.006273},{
      0.234004, 0.002109, -0.006273},{0.233654, 0.003186, -0.008122}}],
    Polygon[{{0.230200, 0.001506, -0.006273},{0.230200, 0.000676, -0.004270},{
      0.234260, 0.001319, -0.004270},{0.234004, 0.002109, -0.006273}}],
    Polygon[{{0.230200, 0.000676, -0.004270},{0.230200, 0.000170, -0.002162},{
      0.234417, 0.000838, -0.002162},{0.234260, 0.001319, -0.004270}}],
    Polygon[{{0.230200, 0.000170, -0.002162},{0.230200, 0.000000, 0.000000},{
      0.234469, 0.000676, 0.000000},{0.234417, 0.000838, -0.002162}}],
    Polygon[{{0.230200, 0.000000, 0.000000},{0.230200, 0.000170, 0.002162},{
      0.234417, 0.000838, 0.002162},{0.234469, 0.000676, 0.000000}}],
    Polygon[{{0.230200, 0.000170, 0.002162},{0.230200, 0.000676, 0.004270},{
      0.234260, 0.001319, 0.004270},{0.234417, 0.000838, 0.002162}}],
    Polygon[{{0.230200, 0.000676, 0.004270},{0.230200, 0.001506, 0.006273},{
      0.234004, 0.002109, 0.006273},{0.234260, 0.001319, 0.004270}}],
    Polygon[{{0.230200, 0.001506, 0.006273},{0.230200, 0.002639, 0.008122},{
      0.233654, 0.003186, 0.008122},{0.234004, 0.002109, 0.006273}}],
    Polygon[{{0.230200, 0.002639, 0.008122},{0.230200, 0.004047, 0.009770},{
      0.233219, 0.004525, 0.009770},{0.233654, 0.003186, 0.008122}}],
    Polygon[{{0.230200, 0.004047, 0.009770},{0.230200, 0.005696, 0.011178},{
      0.232709, 0.006093, 0.011178},{0.233219, 0.004525, 0.009770}}],
    Polygon[{{0.230200, 0.005696, 0.011178},{0.230200, 0.007544, 0.012311},{
      0.232138, 0.007851, 0.012311},{0.232709, 0.006093, 0.011178}}],
    Polygon[{{0.230200, 0.007544, 0.012311},{0.230200, 0.009548, 0.013141},{
      0.231519, 0.009756, 0.013141},{0.232138, 0.007851, 0.012311}}],
    Polygon[{{0.230200, 0.009548, 0.013141},{0.230200, 0.011656, 0.013647},{
      0.230868, 0.011762, 0.013647},{0.231519, 0.009756, 0.013141}}],
    Polygon[{{0.230868, 0.011762, -0.013647},{0.231519, 0.009756, -0.013141},{
      0.232709, 0.010363, -0.013141},{0.231470, 0.012069, -0.013647}}],
    Polygon[{{0.231519, 0.009756, -0.013141},{0.232138, 0.007851, -0.012311},{
      0.233887, 0.008742, -0.012311},{0.232709, 0.010363, -0.013141}}],
    Polygon[{{0.232138, 0.007851, -0.012311},{0.232709, 0.006093, -0.011178},{
      0.234973, 0.007247, -0.011178},{0.233887, 0.008742, -0.012311}}],
    Polygon[{{0.232709, 0.006093, -0.011178},{0.233219, 0.004525, -0.009770},{
      0.235942, 0.005913, -0.009770},{0.234973, 0.007247, -0.011178}}],
    Polygon[{{0.233219, 0.004525, -0.009770},{0.233654, 0.003186, -0.008122},{
      0.236770, 0.004774, -0.008122},{0.235942, 0.005913, -0.009770}}],
    Polygon[{{0.233654, 0.003186, -0.008122},{0.234004, 0.002109, -0.006273},{
      0.237436, 0.003857, -0.006273},{0.236770, 0.004774, -0.008122}}],
    Polygon[{{0.234004, 0.002109, -0.006273},{0.234260, 0.001319, -0.004270},{
      0.237924, 0.003186, -0.004270},{0.237436, 0.003857, -0.006273}}],
    Polygon[{{0.234260, 0.001319, -0.004270},{0.234417, 0.000838, -0.002162},{
      0.238221, 0.002776, -0.002162},{0.237924, 0.003186, -0.004270}}],
    Polygon[{{0.234417, 0.000838, -0.002162},{0.234469, 0.000676, 0.000000},{
      0.238321, 0.002639, 0.000000},{0.238221, 0.002776, -0.002162}}],
    Polygon[{{0.234469, 0.000676, 0.000000},{0.234417, 0.000838, 0.002162},{
      0.238221, 0.002776, 0.002162},{0.238321, 0.002639, 0.000000}}],
    Polygon[{{0.234417, 0.000838, 0.002162},{0.234260, 0.001319, 0.004270},{
      0.237924, 0.003186, 0.004270},{0.238221, 0.002776, 0.002162}}],
    Polygon[{{0.234260, 0.001319, 0.004270},{0.234004, 0.002109, 0.006273},{
      0.237436, 0.003857, 0.006273},{0.237924, 0.003186, 0.004270}}],
    Polygon[{{0.234004, 0.002109, 0.006273},{0.233654, 0.003186, 0.008122},{
      0.236770, 0.004774, 0.008122},{0.237436, 0.003857, 0.006273}}],
    Polygon[{{0.233654, 0.003186, 0.008122},{0.233219, 0.004525, 0.009770},{
      0.235942, 0.005913, 0.009770},{0.236770, 0.004774, 0.008122}}],
    Polygon[{{0.233219, 0.004525, 0.009770},{0.232709, 0.006093, 0.011178},{
      0.234973, 0.007247, 0.011178},{0.235942, 0.005913, 0.009770}}],
    Polygon[{{0.232709, 0.006093, 0.011178},{0.232138, 0.007851, 0.012311},{
      0.233887, 0.008742, 0.012311},{0.234973, 0.007247, 0.011178}}],
    Polygon[{{0.232138, 0.007851, 0.012311},{0.231519, 0.009756, 0.013141},{
      0.232709, 0.010363, 0.013141},{0.233887, 0.008742, 0.012311}}],
    Polygon[{{0.231519, 0.009756, 0.013141},{0.230868, 0.011762, 0.013647},{
      0.231470, 0.012069, 0.013647},{0.232709, 0.010363, 0.013141}}],
    Polygon[{{0.231470, 0.012069, -0.013647},{0.232709, 0.010363, -0.013141},{
      0.233654, 0.011308, -0.013141},{0.231948, 0.012547, -0.013647}}],
    Polygon[{{0.232709, 0.010363, -0.013141},{0.233887, 0.008742, -0.012311},{
      0.235275, 0.010130, -0.012311},{0.233654, 0.011308, -0.013141}}],
    Polygon[{{0.233887, 0.008742, -0.012311},{0.234973, 0.007247, -0.011178},{
      0.236770, 0.009044, -0.011178},{0.235275, 0.010130, -0.012311}}],
    Polygon[{{0.234973, 0.007247, -0.011178},{0.235942, 0.005913, -0.009770},{
      0.238104, 0.008074, -0.009770},{0.236770, 0.009044, -0.011178}}],
    Polygon[{{0.235942, 0.005913, -0.009770},{0.236770, 0.004774, -0.008122},{
      0.239243, 0.007247, -0.008122},{0.238104, 0.008074, -0.009770}}],
    Polygon[{{0.236770, 0.004774, -0.008122},{0.237436, 0.003857, -0.006273},{
      0.240160, 0.006581, -0.006273},{0.239243, 0.007247, -0.008122}}],
    Polygon[{{0.237436, 0.003857, -0.006273},{0.237924, 0.003186, -0.004270},{
      0.240831, 0.006093, -0.004270},{0.240160, 0.006581, -0.006273}}],
    Polygon[{{0.237924, 0.003186, -0.004270},{0.238221, 0.002776, -0.002162},{
      0.241240, 0.005796, -0.002162},{0.240831, 0.006093, -0.004270}}],
    Polygon[{{0.238221, 0.002776, -0.002162},{0.238321, 0.002639, 0.000000},{
      0.241378, 0.005696, 0.000000},{0.241240, 0.005796, -0.002162}}],
    Polygon[{{0.238321, 0.002639, 0.000000},{0.238221, 0.002776, 0.002162},{
      0.241240, 0.005796, 0.002162},{0.241378, 0.005696, 0.000000}}],
    Polygon[{{0.238221, 0.002776, 0.002162},{0.237924, 0.003186, 0.004270},{
      0.240831, 0.006093, 0.004270},{0.241240, 0.005796, 0.002162}}],
    Polygon[{{0.237924, 0.003186, 0.004270},{0.237436, 0.003857, 0.006273},{
      0.240160, 0.006581, 0.006273},{0.240831, 0.006093, 0.004270}}],
    Polygon[{{0.237436, 0.003857, 0.006273},{0.236770, 0.004774, 0.008122},{
      0.239243, 0.007247, 0.008122},{0.240160, 0.006581, 0.006273}}],
    Polygon[{{0.236770, 0.004774, 0.008122},{0.235942, 0.005913, 0.009770},{
      0.238104, 0.008074, 0.009770},{0.239243, 0.007247, 0.008122}}],
    Polygon[{{0.235942, 0.005913, 0.009770},{0.234973, 0.007247, 0.011178},{
      0.236770, 0.009044, 0.011178},{0.238104, 0.008074, 0.009770}}],
    Polygon[{{0.234973, 0.007247, 0.011178},{0.233887, 0.008742, 0.012311},{
      0.235275, 0.010130, 0.012311},{0.236770, 0.009044, 0.011178}}],
    Polygon[{{0.233887, 0.008742, 0.012311},{0.232709, 0.010363, 0.013141},{
      0.233654, 0.011308, 0.013141},{0.235275, 0.010130, 0.012311}}],
    Polygon[{{0.232709, 0.010363, 0.013141},{0.231470, 0.012069, 0.013647},{
      0.231948, 0.012547, 0.013647},{0.233654, 0.011308, 0.013141}}],
    Polygon[{{0.231948, 0.012547, -0.013647},{0.233654, 0.011308, -0.013141},{
      0.234260, 0.012498, -0.013141},{0.232255, 0.013149, -0.013647}}],
    Polygon[{{0.233654, 0.011308, -0.013141},{0.235275, 0.010130, -0.012311},{
      0.236166, 0.011879, -0.012311},{0.234260, 0.012498, -0.013141}}],
    Polygon[{{0.235275, 0.010130, -0.012311},{0.236770, 0.009044, -0.011178},{
      0.237924, 0.011308, -0.011178},{0.236166, 0.011879, -0.012311}}],
    Polygon[{{0.236770, 0.009044, -0.011178},{0.238104, 0.008074, -0.009770},{
      0.239492, 0.010798, -0.009770},{0.237924, 0.011308, -0.011178}}],
    Polygon[{{0.238104, 0.008074, -0.009770},{0.239243, 0.007247, -0.008122},{
      0.240831, 0.010363, -0.008122},{0.239492, 0.010798, -0.009770}}],
    Polygon[{{0.239243, 0.007247, -0.008122},{0.240160, 0.006581, -0.006273},{
      0.241908, 0.010013, -0.006273},{0.240831, 0.010363, -0.008122}}],
    Polygon[{{0.240160, 0.006581, -0.006273},{0.240831, 0.006093, -0.004270},{
      0.242698, 0.009756, -0.004270},{0.241908, 0.010013, -0.006273}}],
    Polygon[{{0.240831, 0.006093, -0.004270},{0.241240, 0.005796, -0.002162},{
      0.243179, 0.009600, -0.002162},{0.242698, 0.009756, -0.004270}}],
    Polygon[{{0.241240, 0.005796, -0.002162},{0.241378, 0.005696, 0.000000},{
      0.243341, 0.009548, 0.000000},{0.243179, 0.009600, -0.002162}}],
    Polygon[{{0.241378, 0.005696, 0.000000},{0.241240, 0.005796, 0.002162},{
      0.243179, 0.009600, 0.002162},{0.243341, 0.009548, 0.000000}}],
    Polygon[{{0.241240, 0.005796, 0.002162},{0.240831, 0.006093, 0.004270},{
      0.242698, 0.009756, 0.004270},{0.243179, 0.009600, 0.002162}}],
    Polygon[{{0.240831, 0.006093, 0.004270},{0.240160, 0.006581, 0.006273},{
      0.241908, 0.010013, 0.006273},{0.242698, 0.009756, 0.004270}}],
    Polygon[{{0.240160, 0.006581, 0.006273},{0.239243, 0.007247, 0.008122},{
      0.240831, 0.010363, 0.008122},{0.241908, 0.010013, 0.006273}}],
    Polygon[{{0.239243, 0.007247, 0.008122},{0.238104, 0.008074, 0.009770},{
      0.239492, 0.010798, 0.009770},{0.240831, 0.010363, 0.008122}}],
    Polygon[{{0.238104, 0.008074, 0.009770},{0.236770, 0.009044, 0.011178},{
      0.237924, 0.011308, 0.011178},{0.239492, 0.010798, 0.009770}}],
    Polygon[{{0.236770, 0.009044, 0.011178},{0.235275, 0.010130, 0.012311},{
      0.236166, 0.011879, 0.012311},{0.237924, 0.011308, 0.011178}}],
    Polygon[{{0.235275, 0.010130, 0.012311},{0.233654, 0.011308, 0.013141},{
      0.234260, 0.012498, 0.013141},{0.236166, 0.011879, 0.012311}}],
    Polygon[{{0.233654, 0.011308, 0.013141},{0.231948, 0.012547, 0.013647},{
      0.232255, 0.013149, 0.013647},{0.234260, 0.012498, 0.013141}}],
    Polygon[{{0.232255, 0.013149, -0.013647},{0.234260, 0.012498, -0.013141},{
      0.234469, 0.013817, -0.013141},{0.232361, 0.013817, -0.013647}}],
    Polygon[{{0.234260, 0.012498, -0.013141},{0.236166, 0.011879, -0.012311},{
      0.236473, 0.013817, -0.012311},{0.234469, 0.013817, -0.013141}}],
    Polygon[{{0.236166, 0.011879, -0.012311},{0.237924, 0.011308, -0.011178},{
      0.238321, 0.013817, -0.011178},{0.236473, 0.013817, -0.012311}}],
    Polygon[{{0.237924, 0.011308, -0.011178},{0.239492, 0.010798, -0.009770},{
      0.239970, 0.013817, -0.009770},{0.238321, 0.013817, -0.011178}}],
    Polygon[{{0.239492, 0.010798, -0.009770},{0.240831, 0.010363, -0.008122},{
      0.241378, 0.013817, -0.008122},{0.239970, 0.013817, -0.009770}}],
    Polygon[{{0.240831, 0.010363, -0.008122},{0.241908, 0.010013, -0.006273},{
      0.242511, 0.013817, -0.006273},{0.241378, 0.013817, -0.008122}}],
    Polygon[{{0.241908, 0.010013, -0.006273},{0.242698, 0.009756, -0.004270},{
      0.243341, 0.013817, -0.004270},{0.242511, 0.013817, -0.006273}}],
    Polygon[{{0.242698, 0.009756, -0.004270},{0.243179, 0.009600, -0.002162},{
      0.243847, 0.013817, -0.002162},{0.243341, 0.013817, -0.004270}}],
    Polygon[{{0.243179, 0.009600, -0.002162},{0.243341, 0.009548, 0.000000},{
      0.244017, 0.013817, 0.000000},{0.243847, 0.013817, -0.002162}}],
    Polygon[{{0.243341, 0.009548, 0.000000},{0.243179, 0.009600, 0.002162},{
      0.243847, 0.013817, 0.002162},{0.244017, 0.013817, 0.000000}}],
    Polygon[{{0.243179, 0.009600, 0.002162},{0.242698, 0.009756, 0.004270},{
      0.243341, 0.013817, 0.004270},{0.243847, 0.013817, 0.002162}}],
    Polygon[{{0.242698, 0.009756, 0.004270},{0.241908, 0.010013, 0.006273},{
      0.242511, 0.013817, 0.006273},{0.243341, 0.013817, 0.004270}}],
    Polygon[{{0.241908, 0.010013, 0.006273},{0.240831, 0.010363, 0.008122},{
      0.241378, 0.013817, 0.008122},{0.242511, 0.013817, 0.006273}}],
    Polygon[{{0.240831, 0.010363, 0.008122},{0.239492, 0.010798, 0.009770},{
      0.239970, 0.013817, 0.009770},{0.241378, 0.013817, 0.008122}}],
    Polygon[{{0.239492, 0.010798, 0.009770},{0.237924, 0.011308, 0.011178},{
      0.238321, 0.013817, 0.011178},{0.239970, 0.013817, 0.009770}}],
    Polygon[{{0.237924, 0.011308, 0.011178},{0.236166, 0.011879, 0.012311},{
      0.236473, 0.013817, 0.012311},{0.238321, 0.013817, 0.011178}}],
    Polygon[{{0.236166, 0.011879, 0.012311},{0.234260, 0.012498, 0.013141},{
      0.234469, 0.013817, 0.013141},{0.236473, 0.013817, 0.012311}}],
    Polygon[{{0.234260, 0.012498, 0.013141},{0.232255, 0.013149, 0.013647},{
      0.232361, 0.013817, 0.013647},{0.234469, 0.013817, 0.013141}}],
    Polygon[{{0.162402, 0.009657, -0.009538},{0.163875, 0.009657, -0.009185},{
      0.163729, 0.010579, -0.009185},{0.162328, 0.010124, -0.009538}}],
    Polygon[{{0.163875, 0.009657, -0.009185},{0.165275, 0.009657, -0.008605},{
      0.165061, 0.011012, -0.008605},{0.163729, 0.010579, -0.009185}}],
    Polygon[{{0.165275, 0.009657, -0.008605},{0.166567, 0.009657, -0.007813},{
      0.166289, 0.011411, -0.007813},{0.165061, 0.011012, -0.008605}}],
    Polygon[{{0.166567, 0.009657, -0.007813},{0.167720, 0.009657, -0.006829},{
      0.167385, 0.011767, -0.006829},{0.166289, 0.011411, -0.007813}}],
    Polygon[{{0.167720, 0.009657, -0.006829},{0.168704, 0.009657, -0.005676},{
      0.168321, 0.012071, -0.005676},{0.167385, 0.011767, -0.006829}}],
    Polygon[{{0.168704, 0.009657, -0.005676},{0.169496, 0.009657, -0.004384},{
      0.169074, 0.012316, -0.004384},{0.168321, 0.012071, -0.005676}}],
    Polygon[{{0.169496, 0.009657, -0.004384},{0.170075, 0.009657, -0.002984},{
      0.169626, 0.012495, -0.002984},{0.169074, 0.012316, -0.004384}}],
    Polygon[{{0.170075, 0.009657, -0.002984},{0.170429, 0.009657, -0.001511},{
      0.169962, 0.012605, -0.001511},{0.169626, 0.012495, -0.002984}}],
    Polygon[{{0.170429, 0.009657, -0.001511},{0.170548, 0.009657, 0.000000},{
      0.170075, 0.012641, 0.000000},{0.169962, 0.012605, -0.001511}}],
    Polygon[{{0.170548, 0.009657, 0.000000},{0.170429, 0.009657, 0.001511},{
      0.169962, 0.012605, 0.001511},{0.170075, 0.012641, 0.000000}}],
    Polygon[{{0.170429, 0.009657, 0.001511},{0.170075, 0.009657, 0.002984},{
      0.169626, 0.012495, 0.002984},{0.169962, 0.012605, 0.001511}}],
    Polygon[{{0.170075, 0.009657, 0.002984},{0.169496, 0.009657, 0.004384},{
      0.169074, 0.012316, 0.004384},{0.169626, 0.012495, 0.002984}}],
    Polygon[{{0.169496, 0.009657, 0.004384},{0.168704, 0.009657, 0.005676},{
      0.168321, 0.012071, 0.005676},{0.169074, 0.012316, 0.004384}}],
    Polygon[{{0.168704, 0.009657, 0.005676},{0.167720, 0.009657, 0.006829},{
      0.167385, 0.011767, 0.006829},{0.168321, 0.012071, 0.005676}}],
    Polygon[{{0.167720, 0.009657, 0.006829},{0.166567, 0.009657, 0.007813},{
      0.166289, 0.011411, 0.007813},{0.167385, 0.011767, 0.006829}}],
    Polygon[{{0.166567, 0.009657, 0.007813},{0.165275, 0.009657, 0.008605},{
      0.165061, 0.011012, 0.008605},{0.166289, 0.011411, 0.007813}}],
    Polygon[{{0.165275, 0.009657, 0.008605},{0.163875, 0.009657, 0.009185},{
      0.163729, 0.010579, 0.009185},{0.165061, 0.011012, 0.008605}}],
    Polygon[{{0.163875, 0.009657, 0.009185},{0.162402, 0.009657, 0.009538},{
      0.162328, 0.010124, 0.009538},{0.163729, 0.010579, 0.009185}}],
    Polygon[{{0.162328, 0.010124, -0.009538},{0.163729, 0.010579, -0.009185},{
      0.163305, 0.011411, -0.009185},{0.162113, 0.010545, -0.009538}}],
    Polygon[{{0.163729, 0.010579, -0.009185},{0.165061, 0.011012, -0.008605},{
      0.164438, 0.012234, -0.008605},{0.163305, 0.011411, -0.009185}}],
    Polygon[{{0.165061, 0.011012, -0.008605},{0.166289, 0.011411, -0.007813},{
      0.165483, 0.012994, -0.007813},{0.164438, 0.012234, -0.008605}}],
    Polygon[{{0.166289, 0.011411, -0.007813},{0.167385, 0.011767, -0.006829},{
      0.166415, 0.013671, -0.006829},{0.165483, 0.012994, -0.007813}}],
    Polygon[{{0.167385, 0.011767, -0.006829},{0.168321, 0.012071, -0.005676},{
      0.167212, 0.014249, -0.005676},{0.166415, 0.013671, -0.006829}}],
    Polygon[{{0.168321, 0.012071, -0.005676},{0.169074, 0.012316, -0.004384},{
      0.167852, 0.014715, -0.004384},{0.167212, 0.014249, -0.005676}}],
    Polygon[{{0.169074, 0.012316, -0.004384},{0.169626, 0.012495, -0.002984},{
      0.168321, 0.015056, -0.002984},{0.167852, 0.014715, -0.004384}}],
    Polygon[{{0.169626, 0.012495, -0.002984},{0.169962, 0.012605, -0.001511},{
      0.168608, 0.015264, -0.001511},{0.168321, 0.015056, -0.002984}}],
    Polygon[{{0.169962, 0.012605, -0.001511},{0.170075, 0.012641, 0.000000},{
      0.168704, 0.015334, 0.000000},{0.168608, 0.015264, -0.001511}}],
    Polygon[{{0.170075, 0.012641, 0.000000},{0.169962, 0.012605, 0.001511},{
      0.168608, 0.015264, 0.001511},{0.168704, 0.015334, 0.000000}}],
    Polygon[{{0.169962, 0.012605, 0.001511},{0.169626, 0.012495, 0.002984},{
      0.168321, 0.015056, 0.002984},{0.168608, 0.015264, 0.001511}}],
    Polygon[{{0.169626, 0.012495, 0.002984},{0.169074, 0.012316, 0.004384},{
      0.167852, 0.014715, 0.004384},{0.168321, 0.015056, 0.002984}}],
    Polygon[{{0.169074, 0.012316, 0.004384},{0.168321, 0.012071, 0.005676},{
      0.167212, 0.014249, 0.005676},{0.167852, 0.014715, 0.004384}}],
    Polygon[{{0.168321, 0.012071, 0.005676},{0.167385, 0.011767, 0.006829},{
      0.166415, 0.013671, 0.006829},{0.167212, 0.014249, 0.005676}}],
    Polygon[{{0.167385, 0.011767, 0.006829},{0.166289, 0.011411, 0.007813},{
      0.165483, 0.012994, 0.007813},{0.166415, 0.013671, 0.006829}}],
    Polygon[{{0.166289, 0.011411, 0.007813},{0.165061, 0.011012, 0.008605},{
      0.164438, 0.012234, 0.008605},{0.165483, 0.012994, 0.007813}}],
    Polygon[{{0.165061, 0.011012, 0.008605},{0.163729, 0.010579, 0.009185},{
      0.163305, 0.011411, 0.009185},{0.164438, 0.012234, 0.008605}}],
    Polygon[{{0.163729, 0.010579, 0.009185},{0.162328, 0.010124, 0.009538},{
      0.162113, 0.010545, 0.009538},{0.163305, 0.011411, 0.009185}}],
    Polygon[{{0.162113, 0.010545, -0.009538},{0.163305, 0.011411, -0.009185},{
      0.162645, 0.012071, -0.009185},{0.161779, 0.010879, -0.009538}}],
    Polygon[{{0.163305, 0.011411, -0.009185},{0.164438, 0.012234, -0.008605},{
      0.163468, 0.013204, -0.008605},{0.162645, 0.012071, -0.009185}}],
    Polygon[{{0.164438, 0.012234, -0.008605},{0.165483, 0.012994, -0.007813},{
      0.164227, 0.014249, -0.007813},{0.163468, 0.013204, -0.008605}}],
    Polygon[{{0.165483, 0.012994, -0.007813},{0.166415, 0.013671, -0.006829},{
      0.164905, 0.015182, -0.006829},{0.164227, 0.014249, -0.007813}}],
    Polygon[{{0.166415, 0.013671, -0.006829},{0.167212, 0.014249, -0.005676},{
      0.165483, 0.015978, -0.005676},{0.164905, 0.015182, -0.006829}}],
    Polygon[{{0.167212, 0.014249, -0.005676},{0.167852, 0.014715, -0.004384},{
      0.165949, 0.016618, -0.004384},{0.165483, 0.015978, -0.005676}}],
    Polygon[{{0.167852, 0.014715, -0.004384},{0.168321, 0.015056, -0.002984},{
      0.166289, 0.017088, -0.002984},{0.165949, 0.016618, -0.004384}}],
    Polygon[{{0.168321, 0.015056, -0.002984},{0.168608, 0.015264, -0.001511},{
      0.166497, 0.017374, -0.001511},{0.166289, 0.017088, -0.002984}}],
    Polygon[{{0.168608, 0.015264, -0.001511},{0.168704, 0.015334, 0.000000},{
      0.166567, 0.017470, 0.000000},{0.166497, 0.017374, -0.001511}}],
    Polygon[{{0.168704, 0.015334, 0.000000},{0.168608, 0.015264, 0.001511},{
      0.166497, 0.017374, 0.001511},{0.166567, 0.017470, 0.000000}}],
    Polygon[{{0.168608, 0.015264, 0.001511},{0.168321, 0.015056, 0.002984},{
      0.166289, 0.017088, 0.002984},{0.166497, 0.017374, 0.001511}}],
    Polygon[{{0.168321, 0.015056, 0.002984},{0.167852, 0.014715, 0.004384},{
      0.165949, 0.016618, 0.004384},{0.166289, 0.017088, 0.002984}}],
    Polygon[{{0.167852, 0.014715, 0.004384},{0.167212, 0.014249, 0.005676},{
      0.165483, 0.015978, 0.005676},{0.165949, 0.016618, 0.004384}}],
    Polygon[{{0.167212, 0.014249, 0.005676},{0.166415, 0.013671, 0.006829},{
      0.164905, 0.015182, 0.006829},{0.165483, 0.015978, 0.005676}}],
    Polygon[{{0.166415, 0.013671, 0.006829},{0.165483, 0.012994, 0.007813},{
      0.164227, 0.014249, 0.007813},{0.164905, 0.015182, 0.006829}}],
    Polygon[{{0.165483, 0.012994, 0.007813},{0.164438, 0.012234, 0.008605},{
      0.163468, 0.013204, 0.008605},{0.164227, 0.014249, 0.007813}}],
    Polygon[{{0.164438, 0.012234, 0.008605},{0.163305, 0.011411, 0.009185},{
      0.162645, 0.012071, 0.009185},{0.163468, 0.013204, 0.008605}}],
    Polygon[{{0.163305, 0.011411, 0.009185},{0.162113, 0.010545, 0.009538},{
      0.161779, 0.010879, 0.009538},{0.162645, 0.012071, 0.009185}}],
    Polygon[{{0.161779, 0.010879, -0.009538},{0.162645, 0.012071, -0.009185},{
      0.161813, 0.012495, -0.009185},{0.161358, 0.011094, -0.009538}}],
    Polygon[{{0.162645, 0.012071, -0.009185},{0.163468, 0.013204, -0.008605},{
      0.162246, 0.013827, -0.008605},{0.161813, 0.012495, -0.009185}}],
    Polygon[{{0.163468, 0.013204, -0.008605},{0.164227, 0.014249, -0.007813},{
      0.162645, 0.015056, -0.007813},{0.162246, 0.013827, -0.008605}}],
    Polygon[{{0.164227, 0.014249, -0.007813},{0.164905, 0.015182, -0.006829},{
      0.163001, 0.016152, -0.006829},{0.162645, 0.015056, -0.007813}}],
    Polygon[{{0.164905, 0.015182, -0.006829},{0.165483, 0.015978, -0.005676},{
      0.163305, 0.017088, -0.005676},{0.163001, 0.016152, -0.006829}}],
    Polygon[{{0.165483, 0.015978, -0.005676},{0.165949, 0.016618, -0.004384},{
      0.163550, 0.017841, -0.004384},{0.163305, 0.017088, -0.005676}}],
    Polygon[{{0.165949, 0.016618, -0.004384},{0.166289, 0.017088, -0.002984},{
      0.163729, 0.018392, -0.002984},{0.163550, 0.017841, -0.004384}}],
    Polygon[{{0.166289, 0.017088, -0.002984},{0.166497, 0.017374, -0.001511},{
      0.163838, 0.018729, -0.001511},{0.163729, 0.018392, -0.002984}}],
    Polygon[{{0.166497, 0.017374, -0.001511},{0.166567, 0.017470, 0.000000},{
      0.163875, 0.018842, 0.000000},{0.163838, 0.018729, -0.001511}}],
    Polygon[{{0.166567, 0.017470, 0.000000},{0.166497, 0.017374, 0.001511},{
      0.163838, 0.018729, 0.001511},{0.163875, 0.018842, 0.000000}}],
    Polygon[{{0.166497, 0.017374, 0.001511},{0.166289, 0.017088, 0.002984},{
      0.163729, 0.018392, 0.002984},{0.163838, 0.018729, 0.001511}}],
    Polygon[{{0.166289, 0.017088, 0.002984},{0.165949, 0.016618, 0.004384},{
      0.163550, 0.017841, 0.004384},{0.163729, 0.018392, 0.002984}}],
    Polygon[{{0.165949, 0.016618, 0.004384},{0.165483, 0.015978, 0.005676},{
      0.163305, 0.017088, 0.005676},{0.163550, 0.017841, 0.004384}}],
    Polygon[{{0.165483, 0.015978, 0.005676},{0.164905, 0.015182, 0.006829},{
      0.163001, 0.016152, 0.006829},{0.163305, 0.017088, 0.005676}}],
    Polygon[{{0.164905, 0.015182, 0.006829},{0.164227, 0.014249, 0.007813},{
      0.162645, 0.015056, 0.007813},{0.163001, 0.016152, 0.006829}}],
    Polygon[{{0.164227, 0.014249, 0.007813},{0.163468, 0.013204, 0.008605},{
      0.162246, 0.013827, 0.008605},{0.162645, 0.015056, 0.007813}}],
    Polygon[{{0.163468, 0.013204, 0.008605},{0.162645, 0.012071, 0.009185},{
      0.161813, 0.012495, 0.009185},{0.162246, 0.013827, 0.008605}}],
    Polygon[{{0.162645, 0.012071, 0.009185},{0.161779, 0.010879, 0.009538},{
      0.161358, 0.011094, 0.009538},{0.161813, 0.012495, 0.009185}}],
    Polygon[{{0.161358, 0.011094, -0.009538},{0.161813, 0.012495, -0.009185},{
      0.160891, 0.012641, -0.009185},{0.160891, 0.011168, -0.009538}}],
    Polygon[{{0.161813, 0.012495, -0.009185},{0.162246, 0.013827, -0.008605},{
      0.160891, 0.014041, -0.008605},{0.160891, 0.012641, -0.009185}}],
    Polygon[{{0.162246, 0.013827, -0.008605},{0.162645, 0.015056, -0.007813},{
      0.160891, 0.015334, -0.007813},{0.160891, 0.014041, -0.008605}}],
    Polygon[{{0.162645, 0.015056, -0.007813},{0.163001, 0.016152, -0.006829},{
      0.160891, 0.016486, -0.006829},{0.160891, 0.015334, -0.007813}}],
    Polygon[{{0.163001, 0.016152, -0.006829},{0.163305, 0.017088, -0.005676},{
      0.160891, 0.017470, -0.005676},{0.160891, 0.016486, -0.006829}}],
    Polygon[{{0.163305, 0.017088, -0.005676},{0.163550, 0.017841, -0.004384},{
      0.160891, 0.018262, -0.004384},{0.160891, 0.017470, -0.005676}}],
    Polygon[{{0.163550, 0.017841, -0.004384},{0.163729, 0.018392, -0.002984},{
      0.160891, 0.018842, -0.002984},{0.160891, 0.018262, -0.004384}}],
    Polygon[{{0.163729, 0.018392, -0.002984},{0.163838, 0.018729, -0.001511},{
      0.160891, 0.019195, -0.001511},{0.160891, 0.018842, -0.002984}}],
    Polygon[{{0.163838, 0.018729, -0.001511},{0.163875, 0.018842, 0.000000},{
      0.160891, 0.019314, 0.000000},{0.160891, 0.019195, -0.001511}}],
    Polygon[{{0.163875, 0.018842, 0.000000},{0.163838, 0.018729, 0.001511},{
      0.160891, 0.019195, 0.001511},{0.160891, 0.019314, 0.000000}}],
    Polygon[{{0.163838, 0.018729, 0.001511},{0.163729, 0.018392, 0.002984},{
      0.160891, 0.018842, 0.002984},{0.160891, 0.019195, 0.001511}}],
    Polygon[{{0.163729, 0.018392, 0.002984},{0.163550, 0.017841, 0.004384},{
      0.160891, 0.018262, 0.004384},{0.160891, 0.018842, 0.002984}}],
    Polygon[{{0.163550, 0.017841, 0.004384},{0.163305, 0.017088, 0.005676},{
      0.160891, 0.017470, 0.005676},{0.160891, 0.018262, 0.004384}}],
    Polygon[{{0.163305, 0.017088, 0.005676},{0.163001, 0.016152, 0.006829},{
      0.160891, 0.016486, 0.006829},{0.160891, 0.017470, 0.005676}}],
    Polygon[{{0.163001, 0.016152, 0.006829},{0.162645, 0.015056, 0.007813},{
      0.160891, 0.015334, 0.007813},{0.160891, 0.016486, 0.006829}}],
    Polygon[{{0.162645, 0.015056, 0.007813},{0.162246, 0.013827, 0.008605},{
      0.160891, 0.014041, 0.008605},{0.160891, 0.015334, 0.007813}}],
    Polygon[{{0.162246, 0.013827, 0.008605},{0.161813, 0.012495, 0.009185},{
      0.160891, 0.012641, 0.009185},{0.160891, 0.014041, 0.008605}}],
    Polygon[{{0.161813, 0.012495, 0.009185},{0.161358, 0.011094, 0.009538},{
      0.160891, 0.011168, 0.009538},{0.160891, 0.012641, 0.009185}}],
    Polygon[{{0.160891, 0.011168, -0.009538},{0.160891, 0.012641, -0.009185},{
      0.159969, 0.012495, -0.009185},{0.160424, 0.011094, -0.009538}}],
    Polygon[{{0.160891, 0.012641, -0.009185},{0.160891, 0.014041, -0.008605},{
      0.159536, 0.013827, -0.008605},{0.159969, 0.012495, -0.009185}}],
    Polygon[{{0.160891, 0.014041, -0.008605},{0.160891, 0.015334, -0.007813},{
      0.159137, 0.015056, -0.007813},{0.159536, 0.013827, -0.008605}}],
    Polygon[{{0.160891, 0.015334, -0.007813},{0.160891, 0.016486, -0.006829},{
      0.158781, 0.016152, -0.006829},{0.159137, 0.015056, -0.007813}}],
    Polygon[{{0.160891, 0.016486, -0.006829},{0.160891, 0.017470, -0.005676},{
      0.158477, 0.017088, -0.005676},{0.158781, 0.016152, -0.006829}}],
    Polygon[{{0.160891, 0.017470, -0.005676},{0.160891, 0.018262, -0.004384},{
      0.158232, 0.017841, -0.004384},{0.158477, 0.017088, -0.005676}}],
    Polygon[{{0.160891, 0.018262, -0.004384},{0.160891, 0.018842, -0.002984},{
      0.158053, 0.018392, -0.002984},{0.158232, 0.017841, -0.004384}}],
    Polygon[{{0.160891, 0.018842, -0.002984},{0.160891, 0.019195, -0.001511},{
      0.157943, 0.018729, -0.001511},{0.158053, 0.018392, -0.002984}}],
    Polygon[{{0.160891, 0.019195, -0.001511},{0.160891, 0.019314, 0.000000},{
      0.157907, 0.018842, 0.000000},{0.157943, 0.018729, -0.001511}}],
    Polygon[{{0.160891, 0.019314, 0.000000},{0.160891, 0.019195, 0.001511},{
      0.157943, 0.018729, 0.001511},{0.157907, 0.018842, 0.000000}}],
    Polygon[{{0.160891, 0.019195, 0.001511},{0.160891, 0.018842, 0.002984},{
      0.158053, 0.018392, 0.002984},{0.157943, 0.018729, 0.001511}}],
    Polygon[{{0.160891, 0.018842, 0.002984},{0.160891, 0.018262, 0.004384},{
      0.158232, 0.017841, 0.004384},{0.158053, 0.018392, 0.002984}}],
    Polygon[{{0.160891, 0.018262, 0.004384},{0.160891, 0.017470, 0.005676},{
      0.158477, 0.017088, 0.005676},{0.158232, 0.017841, 0.004384}}],
    Polygon[{{0.160891, 0.017470, 0.005676},{0.160891, 0.016486, 0.006829},{
      0.158781, 0.016152, 0.006829},{0.158477, 0.017088, 0.005676}}],
    Polygon[{{0.160891, 0.016486, 0.006829},{0.160891, 0.015334, 0.007813},{
      0.159137, 0.015056, 0.007813},{0.158781, 0.016152, 0.006829}}],
    Polygon[{{0.160891, 0.015334, 0.007813},{0.160891, 0.014041, 0.008605},{
      0.159536, 0.013827, 0.008605},{0.159137, 0.015056, 0.007813}}],
    Polygon[{{0.160891, 0.014041, 0.008605},{0.160891, 0.012641, 0.009185},{
      0.159969, 0.012495, 0.009185},{0.159536, 0.013827, 0.008605}}],
    Polygon[{{0.160891, 0.012641, 0.009185},{0.160891, 0.011168, 0.009538},{
      0.160424, 0.011094, 0.009538},{0.159969, 0.012495, 0.009185}}],
    Polygon[{{0.160424, 0.011094, -0.009538},{0.159969, 0.012495, -0.009185},{
      0.159137, 0.012071, -0.009185},{0.160003, 0.010879, -0.009538}}],
    Polygon[{{0.159969, 0.012495, -0.009185},{0.159536, 0.013827, -0.008605},{
      0.158314, 0.013204, -0.008605},{0.159137, 0.012071, -0.009185}}],
    Polygon[{{0.159536, 0.013827, -0.008605},{0.159137, 0.015056, -0.007813},{
      0.157554, 0.014249, -0.007813},{0.158314, 0.013204, -0.008605}}],
    Polygon[{{0.159137, 0.015056, -0.007813},{0.158781, 0.016152, -0.006829},{
      0.156877, 0.015182, -0.006829},{0.157554, 0.014249, -0.007813}}],
    Polygon[{{0.158781, 0.016152, -0.006829},{0.158477, 0.017088, -0.005676},{
      0.156299, 0.015978, -0.005676},{0.156877, 0.015182, -0.006829}}],
    Polygon[{{0.158477, 0.017088, -0.005676},{0.158232, 0.017841, -0.004384},{
      0.155833, 0.016618, -0.004384},{0.156299, 0.015978, -0.005676}}],
    Polygon[{{0.158232, 0.017841, -0.004384},{0.158053, 0.018392, -0.002984},{
      0.155492, 0.017088, -0.002984},{0.155833, 0.016618, -0.004384}}],
    Polygon[{{0.158053, 0.018392, -0.002984},{0.157943, 0.018729, -0.001511},{
      0.155284, 0.017374, -0.001511},{0.155492, 0.017088, -0.002984}}],
    Polygon[{{0.157943, 0.018729, -0.001511},{0.157907, 0.018842, 0.000000},{
      0.155215, 0.017470, 0.000000},{0.155284, 0.017374, -0.001511}}],
    Polygon[{{0.157907, 0.018842, 0.000000},{0.157943, 0.018729, 0.001511},{
      0.155284, 0.017374, 0.001511},{0.155215, 0.017470, 0.000000}}],
    Polygon[{{0.157943, 0.018729, 0.001511},{0.158053, 0.018392, 0.002984},{
      0.155492, 0.017088, 0.002984},{0.155284, 0.017374, 0.001511}}],
    Polygon[{{0.158053, 0.018392, 0.002984},{0.158232, 0.017841, 0.004384},{
      0.155833, 0.016618, 0.004384},{0.155492, 0.017088, 0.002984}}],
    Polygon[{{0.158232, 0.017841, 0.004384},{0.158477, 0.017088, 0.005676},{
      0.156299, 0.015978, 0.005676},{0.155833, 0.016618, 0.004384}}],
    Polygon[{{0.158477, 0.017088, 0.005676},{0.158781, 0.016152, 0.006829},{
      0.156877, 0.015182, 0.006829},{0.156299, 0.015978, 0.005676}}],
    Polygon[{{0.158781, 0.016152, 0.006829},{0.159137, 0.015056, 0.007813},{
      0.157554, 0.014249, 0.007813},{0.156877, 0.015182, 0.006829}}],
    Polygon[{{0.159137, 0.015056, 0.007813},{0.159536, 0.013827, 0.008605},{
      0.158314, 0.013204, 0.008605},{0.157554, 0.014249, 0.007813}}],
    Polygon[{{0.159536, 0.013827, 0.008605},{0.159969, 0.012495, 0.009185},{
      0.159137, 0.012071, 0.009185},{0.158314, 0.013204, 0.008605}}],
    Polygon[{{0.159969, 0.012495, 0.009185},{0.160424, 0.011094, 0.009538},{
      0.160003, 0.010879, 0.009538},{0.159137, 0.012071, 0.009185}}],
    Polygon[{{0.160003, 0.010879, -0.009538},{0.159137, 0.012071, -0.009185},{
      0.158477, 0.011411, -0.009185},{0.159669, 0.010545, -0.009538}}],
    Polygon[{{0.159137, 0.012071, -0.009185},{0.158314, 0.013204, -0.008605},{
      0.157344, 0.012234, -0.008605},{0.158477, 0.011411, -0.009185}}],
    Polygon[{{0.158314, 0.013204, -0.008605},{0.157554, 0.014249, -0.007813},{
      0.156299, 0.012994, -0.007813},{0.157344, 0.012234, -0.008605}}],
    Polygon[{{0.157554, 0.014249, -0.007813},{0.156877, 0.015182, -0.006829},{
      0.155366, 0.013671, -0.006829},{0.156299, 0.012994, -0.007813}}],
    Polygon[{{0.156877, 0.015182, -0.006829},{0.156299, 0.015978, -0.005676},{
      0.154570, 0.014249, -0.005676},{0.155366, 0.013671, -0.006829}}],
    Polygon[{{0.156299, 0.015978, -0.005676},{0.155833, 0.016618, -0.004384},{
      0.153930, 0.014715, -0.004384},{0.154570, 0.014249, -0.005676}}],
    Polygon[{{0.155833, 0.016618, -0.004384},{0.155492, 0.017088, -0.002984},{
      0.153461, 0.015056, -0.002984},{0.153930, 0.014715, -0.004384}}],
    Polygon[{{0.155492, 0.017088, -0.002984},{0.155284, 0.017374, -0.001511},{
      0.153174, 0.015264, -0.001511},{0.153461, 0.015056, -0.002984}}],
    Polygon[{{0.155284, 0.017374, -0.001511},{0.155215, 0.017470, 0.000000},{
      0.153078, 0.015334, 0.000000},{0.153174, 0.015264, -0.001511}}],
    Polygon[{{0.155215, 0.017470, 0.000000},{0.155284, 0.017374, 0.001511},{
      0.153174, 0.015264, 0.001511},{0.153078, 0.015334, 0.000000}}],
    Polygon[{{0.155284, 0.017374, 0.001511},{0.155492, 0.017088, 0.002984},{
      0.153461, 0.015056, 0.002984},{0.153174, 0.015264, 0.001511}}],
    Polygon[{{0.155492, 0.017088, 0.002984},{0.155833, 0.016618, 0.004384},{
      0.153930, 0.014715, 0.004384},{0.153461, 0.015056, 0.002984}}],
    Polygon[{{0.155833, 0.016618, 0.004384},{0.156299, 0.015978, 0.005676},{
      0.154570, 0.014249, 0.005676},{0.153930, 0.014715, 0.004384}}],
    Polygon[{{0.156299, 0.015978, 0.005676},{0.156877, 0.015182, 0.006829},{
      0.155366, 0.013671, 0.006829},{0.154570, 0.014249, 0.005676}}],
    Polygon[{{0.156877, 0.015182, 0.006829},{0.157554, 0.014249, 0.007813},{
      0.156299, 0.012994, 0.007813},{0.155366, 0.013671, 0.006829}}],
    Polygon[{{0.157554, 0.014249, 0.007813},{0.158314, 0.013204, 0.008605},{
      0.157344, 0.012234, 0.008605},{0.156299, 0.012994, 0.007813}}],
    Polygon[{{0.158314, 0.013204, 0.008605},{0.159137, 0.012071, 0.009185},{
      0.158477, 0.011411, 0.009185},{0.157344, 0.012234, 0.008605}}],
    Polygon[{{0.159137, 0.012071, 0.009185},{0.160003, 0.010879, 0.009538},{
      0.159669, 0.010545, 0.009538},{0.158477, 0.011411, 0.009185}}],
    Polygon[{{0.159669, 0.010545, -0.009538},{0.158477, 0.011411, -0.009185},{
      0.158053, 0.010579, -0.009185},{0.159454, 0.010124, -0.009538}}],
    Polygon[{{0.158477, 0.011411, -0.009185},{0.157344, 0.012234, -0.008605},{
      0.156721, 0.011012, -0.008605},{0.158053, 0.010579, -0.009185}}],
    Polygon[{{0.157344, 0.012234, -0.008605},{0.156299, 0.012994, -0.007813},{
      0.155492, 0.011411, -0.007813},{0.156721, 0.011012, -0.008605}}],
    Polygon[{{0.156299, 0.012994, -0.007813},{0.155366, 0.013671, -0.006829},{
      0.154397, 0.011767, -0.006829},{0.155492, 0.011411, -0.007813}}],
    Polygon[{{0.155366, 0.013671, -0.006829},{0.154570, 0.014249, -0.005676},{
      0.153461, 0.012071, -0.005676},{0.154397, 0.011767, -0.006829}}],
    Polygon[{{0.154570, 0.014249, -0.005676},{0.153930, 0.014715, -0.004384},{
      0.152707, 0.012316, -0.004384},{0.153461, 0.012071, -0.005676}}],
    Polygon[{{0.153930, 0.014715, -0.004384},{0.153461, 0.015056, -0.002984},{
      0.152156, 0.012495, -0.002984},{0.152707, 0.012316, -0.004384}}],
    Polygon[{{0.153461, 0.015056, -0.002984},{0.153174, 0.015264, -0.001511},{
      0.151819, 0.012605, -0.001511},{0.152156, 0.012495, -0.002984}}],
    Polygon[{{0.153174, 0.015264, -0.001511},{0.153078, 0.015334, 0.000000},{
      0.151706, 0.012641, 0.000000},{0.151819, 0.012605, -0.001511}}],
    Polygon[{{0.153078, 0.015334, 0.000000},{0.153174, 0.015264, 0.001511},{
      0.151819, 0.012605, 0.001511},{0.151706, 0.012641, 0.000000}}],
    Polygon[{{0.153174, 0.015264, 0.001511},{0.153461, 0.015056, 0.002984},{
      0.152156, 0.012495, 0.002984},{0.151819, 0.012605, 0.001511}}],
    Polygon[{{0.153461, 0.015056, 0.002984},{0.153930, 0.014715, 0.004384},{
      0.152707, 0.012316, 0.004384},{0.152156, 0.012495, 0.002984}}],
    Polygon[{{0.153930, 0.014715, 0.004384},{0.154570, 0.014249, 0.005676},{
      0.153461, 0.012071, 0.005676},{0.152707, 0.012316, 0.004384}}],
    Polygon[{{0.154570, 0.014249, 0.005676},{0.155366, 0.013671, 0.006829},{
      0.154397, 0.011767, 0.006829},{0.153461, 0.012071, 0.005676}}],
    Polygon[{{0.155366, 0.013671, 0.006829},{0.156299, 0.012994, 0.007813},{
      0.155492, 0.011411, 0.007813},{0.154397, 0.011767, 0.006829}}],
    Polygon[{{0.156299, 0.012994, 0.007813},{0.157344, 0.012234, 0.008605},{
      0.156721, 0.011012, 0.008605},{0.155492, 0.011411, 0.007813}}],
    Polygon[{{0.157344, 0.012234, 0.008605},{0.158477, 0.011411, 0.009185},{
      0.158053, 0.010579, 0.009185},{0.156721, 0.011012, 0.008605}}],
    Polygon[{{0.158477, 0.011411, 0.009185},{0.159669, 0.010545, 0.009538},{
      0.159454, 0.010124, 0.009538},{0.158053, 0.010579, 0.009185}}],
    Polygon[{{0.159454, 0.010124, -0.009538},{0.158053, 0.010579, -0.009185},{
      0.157907, 0.009657, -0.009185},{0.159380, 0.009657, -0.009538}}],
    Polygon[{{0.158053, 0.010579, -0.009185},{0.156721, 0.011012, -0.008605},{
      0.156507, 0.009657, -0.008605},{0.157907, 0.009657, -0.009185}}],
    Polygon[{{0.156721, 0.011012, -0.008605},{0.155492, 0.011411, -0.007813},{
      0.155215, 0.009657, -0.007813},{0.156507, 0.009657, -0.008605}}],
    Polygon[{{0.155492, 0.011411, -0.007813},{0.154397, 0.011767, -0.006829},{
      0.154062, 0.009657, -0.006829},{0.155215, 0.009657, -0.007813}}],
    Polygon[{{0.154397, 0.011767, -0.006829},{0.153461, 0.012071, -0.005676},{
      0.153078, 0.009657, -0.005676},{0.154062, 0.009657, -0.006829}}],
    Polygon[{{0.153461, 0.012071, -0.005676},{0.152707, 0.012316, -0.004384},{
      0.152286, 0.009657, -0.004384},{0.153078, 0.009657, -0.005676}}],
    Polygon[{{0.152707, 0.012316, -0.004384},{0.152156, 0.012495, -0.002984},{
      0.151706, 0.009657, -0.002984},{0.152286, 0.009657, -0.004384}}],
    Polygon[{{0.152156, 0.012495, -0.002984},{0.151819, 0.012605, -0.001511},{
      0.151353, 0.009657, -0.001511},{0.151706, 0.009657, -0.002984}}],
    Polygon[{{0.151819, 0.012605, -0.001511},{0.151706, 0.012641, 0.000000},{
      0.151234, 0.009657, 0.000000},{0.151353, 0.009657, -0.001511}}],
    Polygon[{{0.151706, 0.012641, 0.000000},{0.151819, 0.012605, 0.001511},{
      0.151353, 0.009657, 0.001511},{0.151234, 0.009657, 0.000000}}],
    Polygon[{{0.151819, 0.012605, 0.001511},{0.152156, 0.012495, 0.002984},{
      0.151706, 0.009657, 0.002984},{0.151353, 0.009657, 0.001511}}],
    Polygon[{{0.152156, 0.012495, 0.002984},{0.152707, 0.012316, 0.004384},{
      0.152286, 0.009657, 0.004384},{0.151706, 0.009657, 0.002984}}],
    Polygon[{{0.152707, 0.012316, 0.004384},{0.153461, 0.012071, 0.005676},{
      0.153078, 0.009657, 0.005676},{0.152286, 0.009657, 0.004384}}],
    Polygon[{{0.153461, 0.012071, 0.005676},{0.154397, 0.011767, 0.006829},{
      0.154062, 0.009657, 0.006829},{0.153078, 0.009657, 0.005676}}],
    Polygon[{{0.154397, 0.011767, 0.006829},{0.155492, 0.011411, 0.007813},{
      0.155215, 0.009657, 0.007813},{0.154062, 0.009657, 0.006829}}],
    Polygon[{{0.155492, 0.011411, 0.007813},{0.156721, 0.011012, 0.008605},{
      0.156507, 0.009657, 0.008605},{0.155215, 0.009657, 0.007813}}],
    Polygon[{{0.156721, 0.011012, 0.008605},{0.158053, 0.010579, 0.009185},{
      0.157907, 0.009657, 0.009185},{0.156507, 0.009657, 0.008605}}],
    Polygon[{{0.158053, 0.010579, 0.009185},{0.159454, 0.010124, 0.009538},{
      0.159380, 0.009657, 0.009538},{0.157907, 0.009657, 0.009185}}],
    Polygon[{{0.159380, 0.009657, -0.009538},{0.157907, 0.009657, -0.009185},{
      0.158053, 0.008735, -0.009185},{0.159454, 0.009190, -0.009538}}],
    Polygon[{{0.157907, 0.009657, -0.009185},{0.156507, 0.009657, -0.008605},{
      0.156721, 0.008302, -0.008605},{0.158053, 0.008735, -0.009185}}],
    Polygon[{{0.156507, 0.009657, -0.008605},{0.155215, 0.009657, -0.007813},{
      0.155492, 0.007903, -0.007813},{0.156721, 0.008302, -0.008605}}],
    Polygon[{{0.155215, 0.009657, -0.007813},{0.154062, 0.009657, -0.006829},{
      0.154397, 0.007547, -0.006829},{0.155492, 0.007903, -0.007813}}],
    Polygon[{{0.154062, 0.009657, -0.006829},{0.153078, 0.009657, -0.005676},{
      0.153461, 0.007243, -0.005676},{0.154397, 0.007547, -0.006829}}],
    Polygon[{{0.153078, 0.009657, -0.005676},{0.152286, 0.009657, -0.004384},{
      0.152707, 0.006998, -0.004384},{0.153461, 0.007243, -0.005676}}],
    Polygon[{{0.152286, 0.009657, -0.004384},{0.151706, 0.009657, -0.002984},{
      0.152156, 0.006819, -0.002984},{0.152707, 0.006998, -0.004384}}],
    Polygon[{{0.151706, 0.009657, -0.002984},{0.151353, 0.009657, -0.001511},{
      0.151819, 0.006710, -0.001511},{0.152156, 0.006819, -0.002984}}],
    Polygon[{{0.151353, 0.009657, -0.001511},{0.151234, 0.009657, 0.000000},{
      0.151706, 0.006673, 0.000000},{0.151819, 0.006710, -0.001511}}],
    Polygon[{{0.151234, 0.009657, 0.000000},{0.151353, 0.009657, 0.001511},{
      0.151819, 0.006710, 0.001511},{0.151706, 0.006673, 0.000000}}],
    Polygon[{{0.151353, 0.009657, 0.001511},{0.151706, 0.009657, 0.002984},{
      0.152156, 0.006819, 0.002984},{0.151819, 0.006710, 0.001511}}],
    Polygon[{{0.151706, 0.009657, 0.002984},{0.152286, 0.009657, 0.004384},{
      0.152707, 0.006998, 0.004384},{0.152156, 0.006819, 0.002984}}],
    Polygon[{{0.152286, 0.009657, 0.004384},{0.153078, 0.009657, 0.005676},{
      0.153461, 0.007243, 0.005676},{0.152707, 0.006998, 0.004384}}],
    Polygon[{{0.153078, 0.009657, 0.005676},{0.154062, 0.009657, 0.006829},{
      0.154397, 0.007547, 0.006829},{0.153461, 0.007243, 0.005676}}],
    Polygon[{{0.154062, 0.009657, 0.006829},{0.155215, 0.009657, 0.007813},{
      0.155492, 0.007903, 0.007813},{0.154397, 0.007547, 0.006829}}],
    Polygon[{{0.155215, 0.009657, 0.007813},{0.156507, 0.009657, 0.008605},{
      0.156721, 0.008302, 0.008605},{0.155492, 0.007903, 0.007813}}],
    Polygon[{{0.156507, 0.009657, 0.008605},{0.157907, 0.009657, 0.009185},{
      0.158053, 0.008735, 0.009185},{0.156721, 0.008302, 0.008605}}],
    Polygon[{{0.157907, 0.009657, 0.009185},{0.159380, 0.009657, 0.009538},{
      0.159454, 0.009190, 0.009538},{0.158053, 0.008735, 0.009185}}],
    Polygon[{{0.159454, 0.009190, -0.009538},{0.158053, 0.008735, -0.009185},{
      0.158477, 0.007903, -0.009185},{0.159669, 0.008769, -0.009538}}],
    Polygon[{{0.158053, 0.008735, -0.009185},{0.156721, 0.008302, -0.008605},{
      0.157344, 0.007080, -0.008605},{0.158477, 0.007903, -0.009185}}],
    Polygon[{{0.156721, 0.008302, -0.008605},{0.155492, 0.007903, -0.007813},{
      0.156299, 0.006321, -0.007813},{0.157344, 0.007080, -0.008605}}],
    Polygon[{{0.155492, 0.007903, -0.007813},{0.154397, 0.007547, -0.006829},{
      0.155366, 0.005643, -0.006829},{0.156299, 0.006321, -0.007813}}],
    Polygon[{{0.154397, 0.007547, -0.006829},{0.153461, 0.007243, -0.005676},{
      0.154570, 0.005065, -0.005676},{0.155366, 0.005643, -0.006829}}],
    Polygon[{{0.153461, 0.007243, -0.005676},{0.152707, 0.006998, -0.004384},{
      0.153930, 0.004600, -0.004384},{0.154570, 0.005065, -0.005676}}],
    Polygon[{{0.152707, 0.006998, -0.004384},{0.152156, 0.006819, -0.002984},{
      0.153461, 0.004259, -0.002984},{0.153930, 0.004600, -0.004384}}],
    Polygon[{{0.152156, 0.006819, -0.002984},{0.151819, 0.006710, -0.001511},{
      0.153174, 0.004051, -0.001511},{0.153461, 0.004259, -0.002984}}],
    Polygon[{{0.151819, 0.006710, -0.001511},{0.151706, 0.006673, 0.000000},{
      0.153078, 0.003981, 0.000000},{0.153174, 0.004051, -0.001511}}],
    Polygon[{{0.151706, 0.006673, 0.000000},{0.151819, 0.006710, 0.001511},{
      0.153174, 0.004051, 0.001511},{0.153078, 0.003981, 0.000000}}],
    Polygon[{{0.151819, 0.006710, 0.001511},{0.152156, 0.006819, 0.002984},{
      0.153461, 0.004259, 0.002984},{0.153174, 0.004051, 0.001511}}],
    Polygon[{{0.152156, 0.006819, 0.002984},{0.152707, 0.006998, 0.004384},{
      0.153930, 0.004600, 0.004384},{0.153461, 0.004259, 0.002984}}],
    Polygon[{{0.152707, 0.006998, 0.004384},{0.153461, 0.007243, 0.005676},{
      0.154570, 0.005065, 0.005676},{0.153930, 0.004600, 0.004384}}],
    Polygon[{{0.153461, 0.007243, 0.005676},{0.154397, 0.007547, 0.006829},{
      0.155366, 0.005643, 0.006829},{0.154570, 0.005065, 0.005676}}],
    Polygon[{{0.154397, 0.007547, 0.006829},{0.155492, 0.007903, 0.007813},{
      0.156299, 0.006321, 0.007813},{0.155366, 0.005643, 0.006829}}],
    Polygon[{{0.155492, 0.007903, 0.007813},{0.156721, 0.008302, 0.008605},{
      0.157344, 0.007080, 0.008605},{0.156299, 0.006321, 0.007813}}],
    Polygon[{{0.156721, 0.008302, 0.008605},{0.158053, 0.008735, 0.009185},{
      0.158477, 0.007903, 0.009185},{0.157344, 0.007080, 0.008605}}],
    Polygon[{{0.158053, 0.008735, 0.009185},{0.159454, 0.009190, 0.009538},{
      0.159669, 0.008769, 0.009538},{0.158477, 0.007903, 0.009185}}],
    Polygon[{{0.159669, 0.008769, -0.009538},{0.158477, 0.007903, -0.009185},{
      0.159137, 0.007243, -0.009185},{0.160003, 0.008435, -0.009538}}],
    Polygon[{{0.158477, 0.007903, -0.009185},{0.157344, 0.007080, -0.008605},{
      0.158314, 0.006110, -0.008605},{0.159137, 0.007243, -0.009185}}],
    Polygon[{{0.157344, 0.007080, -0.008605},{0.156299, 0.006321, -0.007813},{
      0.157554, 0.005065, -0.007813},{0.158314, 0.006110, -0.008605}}],
    Polygon[{{0.156299, 0.006321, -0.007813},{0.155366, 0.005643, -0.006829},{
      0.156877, 0.004133, -0.006829},{0.157554, 0.005065, -0.007813}}],
    Polygon[{{0.155366, 0.005643, -0.006829},{0.154570, 0.005065, -0.005676},{
      0.156299, 0.003336, -0.005676},{0.156877, 0.004133, -0.006829}}],
    Polygon[{{0.154570, 0.005065, -0.005676},{0.153930, 0.004600, -0.004384},{
      0.155833, 0.002696, -0.004384},{0.156299, 0.003336, -0.005676}}],
    Polygon[{{0.153930, 0.004600, -0.004384},{0.153461, 0.004259, -0.002984},{
      0.155492, 0.002227, -0.002984},{0.155833, 0.002696, -0.004384}}],
    Polygon[{{0.153461, 0.004259, -0.002984},{0.153174, 0.004051, -0.001511},{
      0.155284, 0.001941, -0.001511},{0.155492, 0.002227, -0.002984}}],
    Polygon[{{0.153174, 0.004051, -0.001511},{0.153078, 0.003981, 0.000000},{
      0.155215, 0.001844, 0.000000},{0.155284, 0.001941, -0.001511}}],
    Polygon[{{0.153078, 0.003981, 0.000000},{0.153174, 0.004051, 0.001511},{
      0.155284, 0.001941, 0.001511},{0.155215, 0.001844, 0.000000}}],
    Polygon[{{0.153174, 0.004051, 0.001511},{0.153461, 0.004259, 0.002984},{
      0.155492, 0.002227, 0.002984},{0.155284, 0.001941, 0.001511}}],
    Polygon[{{0.153461, 0.004259, 0.002984},{0.153930, 0.004600, 0.004384},{
      0.155833, 0.002696, 0.004384},{0.155492, 0.002227, 0.002984}}],
    Polygon[{{0.153930, 0.004600, 0.004384},{0.154570, 0.005065, 0.005676},{
      0.156299, 0.003336, 0.005676},{0.155833, 0.002696, 0.004384}}],
    Polygon[{{0.154570, 0.005065, 0.005676},{0.155366, 0.005643, 0.006829},{
      0.156877, 0.004133, 0.006829},{0.156299, 0.003336, 0.005676}}],
    Polygon[{{0.155366, 0.005643, 0.006829},{0.156299, 0.006321, 0.007813},{
      0.157554, 0.005065, 0.007813},{0.156877, 0.004133, 0.006829}}],
    Polygon[{{0.156299, 0.006321, 0.007813},{0.157344, 0.007080, 0.008605},{
      0.158314, 0.006110, 0.008605},{0.157554, 0.005065, 0.007813}}],
    Polygon[{{0.157344, 0.007080, 0.008605},{0.158477, 0.007903, 0.009185},{
      0.159137, 0.007243, 0.009185},{0.158314, 0.006110, 0.008605}}],
    Polygon[{{0.158477, 0.007903, 0.009185},{0.159669, 0.008769, 0.009538},{
      0.160003, 0.008435, 0.009538},{0.159137, 0.007243, 0.009185}}],
    Polygon[{{0.160003, 0.008435, -0.009538},{0.159137, 0.007243, -0.009185},{
      0.159969, 0.006819, -0.009185},{0.160424, 0.008220, -0.009538}}],
    Polygon[{{0.159137, 0.007243, -0.009185},{0.158314, 0.006110, -0.008605},{
      0.159536, 0.005487, -0.008605},{0.159969, 0.006819, -0.009185}}],
    Polygon[{{0.158314, 0.006110, -0.008605},{0.157554, 0.005065, -0.007813},{
      0.159137, 0.004259, -0.007813},{0.159536, 0.005487, -0.008605}}],
    Polygon[{{0.157554, 0.005065, -0.007813},{0.156877, 0.004133, -0.006829},{
      0.158781, 0.003163, -0.006829},{0.159137, 0.004259, -0.007813}}],
    Polygon[{{0.156877, 0.004133, -0.006829},{0.156299, 0.003336, -0.005676},{
      0.158477, 0.002227, -0.005676},{0.158781, 0.003163, -0.006829}}],
    Polygon[{{0.156299, 0.003336, -0.005676},{0.155833, 0.002696, -0.004384},{
      0.158232, 0.001474, -0.004384},{0.158477, 0.002227, -0.005676}}],
    Polygon[{{0.155833, 0.002696, -0.004384},{0.155492, 0.002227, -0.002984},{
      0.158053, 0.000922, -0.002984},{0.158232, 0.001474, -0.004384}}],
    Polygon[{{0.155492, 0.002227, -0.002984},{0.155284, 0.001941, -0.001511},{
      0.157943, 0.000586, -0.001511},{0.158053, 0.000922, -0.002984}}],
    Polygon[{{0.155284, 0.001941, -0.001511},{0.155215, 0.001844, 0.000000},{
      0.157907, 0.000473, 0.000000},{0.157943, 0.000586, -0.001511}}],
    Polygon[{{0.155215, 0.001844, 0.000000},{0.155284, 0.001941, 0.001511},{
      0.157943, 0.000586, 0.001511},{0.157907, 0.000473, 0.000000}}],
    Polygon[{{0.155284, 0.001941, 0.001511},{0.155492, 0.002227, 0.002984},{
      0.158053, 0.000922, 0.002984},{0.157943, 0.000586, 0.001511}}],
    Polygon[{{0.155492, 0.002227, 0.002984},{0.155833, 0.002696, 0.004384},{
      0.158232, 0.001474, 0.004384},{0.158053, 0.000922, 0.002984}}],
    Polygon[{{0.155833, 0.002696, 0.004384},{0.156299, 0.003336, 0.005676},{
      0.158477, 0.002227, 0.005676},{0.158232, 0.001474, 0.004384}}],
    Polygon[{{0.156299, 0.003336, 0.005676},{0.156877, 0.004133, 0.006829},{
      0.158781, 0.003163, 0.006829},{0.158477, 0.002227, 0.005676}}],
    Polygon[{{0.156877, 0.004133, 0.006829},{0.157554, 0.005065, 0.007813},{
      0.159137, 0.004259, 0.007813},{0.158781, 0.003163, 0.006829}}],
    Polygon[{{0.157554, 0.005065, 0.007813},{0.158314, 0.006110, 0.008605},{
      0.159536, 0.005487, 0.008605},{0.159137, 0.004259, 0.007813}}],
    Polygon[{{0.158314, 0.006110, 0.008605},{0.159137, 0.007243, 0.009185},{
      0.159969, 0.006819, 0.009185},{0.159536, 0.005487, 0.008605}}],
    Polygon[{{0.159137, 0.007243, 0.009185},{0.160003, 0.008435, 0.009538},{
      0.160424, 0.008220, 0.009538},{0.159969, 0.006819, 0.009185}}],
    Polygon[{{0.160424, 0.008220, -0.009538},{0.159969, 0.006819, -0.009185},{
      0.160891, 0.006673, -0.009185},{0.160891, 0.008146, -0.009538}}],
    Polygon[{{0.159969, 0.006819, -0.009185},{0.159536, 0.005487, -0.008605},{
      0.160891, 0.005273, -0.008605},{0.160891, 0.006673, -0.009185}}],
    Polygon[{{0.159536, 0.005487, -0.008605},{0.159137, 0.004259, -0.007813},{
      0.160891, 0.003981, -0.007813},{0.160891, 0.005273, -0.008605}}],
    Polygon[{{0.159137, 0.004259, -0.007813},{0.158781, 0.003163, -0.006829},{
      0.160891, 0.002829, -0.006829},{0.160891, 0.003981, -0.007813}}],
    Polygon[{{0.158781, 0.003163, -0.006829},{0.158477, 0.002227, -0.005676},{
      0.160891, 0.001844, -0.005676},{0.160891, 0.002829, -0.006829}}],
    Polygon[{{0.158477, 0.002227, -0.005676},{0.158232, 0.001474, -0.004384},{
      0.160891, 0.001053, -0.004384},{0.160891, 0.001844, -0.005676}}],
    Polygon[{{0.158232, 0.001474, -0.004384},{0.158053, 0.000922, -0.002984},{
      0.160891, 0.000473, -0.002984},{0.160891, 0.001053, -0.004384}}],
    Polygon[{{0.158053, 0.000922, -0.002984},{0.157943, 0.000586, -0.001511},{
      0.160891, 0.000119, -0.001511},{0.160891, 0.000473, -0.002984}}],
    Polygon[{{0.157943, 0.000586, -0.001511},{0.157907, 0.000473, 0.000000},{
      0.160891, 0.000000, 0.000000},{0.160891, 0.000119, -0.001511}}],
    Polygon[{{0.157907, 0.000473, 0.000000},{0.157943, 0.000586, 0.001511},{
      0.160891, 0.000119, 0.001511},{0.160891, 0.000000, 0.000000}}],
    Polygon[{{0.157943, 0.000586, 0.001511},{0.158053, 0.000922, 0.002984},{
      0.160891, 0.000473, 0.002984},{0.160891, 0.000119, 0.001511}}],
    Polygon[{{0.158053, 0.000922, 0.002984},{0.158232, 0.001474, 0.004384},{
      0.160891, 0.001053, 0.004384},{0.160891, 0.000473, 0.002984}}],
    Polygon[{{0.158232, 0.001474, 0.004384},{0.158477, 0.002227, 0.005676},{
      0.160891, 0.001844, 0.005676},{0.160891, 0.001053, 0.004384}}],
    Polygon[{{0.158477, 0.002227, 0.005676},{0.158781, 0.003163, 0.006829},{
      0.160891, 0.002829, 0.006829},{0.160891, 0.001844, 0.005676}}],
    Polygon[{{0.158781, 0.003163, 0.006829},{0.159137, 0.004259, 0.007813},{
      0.160891, 0.003981, 0.007813},{0.160891, 0.002829, 0.006829}}],
    Polygon[{{0.159137, 0.004259, 0.007813},{0.159536, 0.005487, 0.008605},{
      0.160891, 0.005273, 0.008605},{0.160891, 0.003981, 0.007813}}],
    Polygon[{{0.159536, 0.005487, 0.008605},{0.159969, 0.006819, 0.009185},{
      0.160891, 0.006673, 0.009185},{0.160891, 0.005273, 0.008605}}],
    Polygon[{{0.159969, 0.006819, 0.009185},{0.160424, 0.008220, 0.009538},{
      0.160891, 0.008146, 0.009538},{0.160891, 0.006673, 0.009185}}],
    Polygon[{{0.160891, 0.008146, -0.009538},{0.160891, 0.006673, -0.009185},{
      0.161813, 0.006819, -0.009185},{0.161358, 0.008220, -0.009538}}],
    Polygon[{{0.160891, 0.006673, -0.009185},{0.160891, 0.005273, -0.008605},{
      0.162246, 0.005487, -0.008605},{0.161813, 0.006819, -0.009185}}],
    Polygon[{{0.160891, 0.005273, -0.008605},{0.160891, 0.003981, -0.007813},{
      0.162645, 0.004259, -0.007813},{0.162246, 0.005487, -0.008605}}],
    Polygon[{{0.160891, 0.003981, -0.007813},{0.160891, 0.002829, -0.006829},{
      0.163001, 0.003163, -0.006829},{0.162645, 0.004259, -0.007813}}],
    Polygon[{{0.160891, 0.002829, -0.006829},{0.160891, 0.001844, -0.005676},{
      0.163305, 0.002227, -0.005676},{0.163001, 0.003163, -0.006829}}],
    Polygon[{{0.160891, 0.001844, -0.005676},{0.160891, 0.001053, -0.004384},{
      0.163550, 0.001474, -0.004384},{0.163305, 0.002227, -0.005676}}],
    Polygon[{{0.160891, 0.001053, -0.004384},{0.160891, 0.000473, -0.002984},{
      0.163729, 0.000922, -0.002984},{0.163550, 0.001474, -0.004384}}],
    Polygon[{{0.160891, 0.000473, -0.002984},{0.160891, 0.000119, -0.001511},{
      0.163838, 0.000586, -0.001511},{0.163729, 0.000922, -0.002984}}],
    Polygon[{{0.160891, 0.000119, -0.001511},{0.160891, 0.000000, 0.000000},{
      0.163875, 0.000473, 0.000000},{0.163838, 0.000586, -0.001511}}],
    Polygon[{{0.160891, 0.000000, 0.000000},{0.160891, 0.000119, 0.001511},{
      0.163838, 0.000586, 0.001511},{0.163875, 0.000473, 0.000000}}],
    Polygon[{{0.160891, 0.000119, 0.001511},{0.160891, 0.000473, 0.002984},{
      0.163729, 0.000922, 0.002984},{0.163838, 0.000586, 0.001511}}],
    Polygon[{{0.160891, 0.000473, 0.002984},{0.160891, 0.001053, 0.004384},{
      0.163550, 0.001474, 0.004384},{0.163729, 0.000922, 0.002984}}],
    Polygon[{{0.160891, 0.001053, 0.004384},{0.160891, 0.001844, 0.005676},{
      0.163305, 0.002227, 0.005676},{0.163550, 0.001474, 0.004384}}],
    Polygon[{{0.160891, 0.001844, 0.005676},{0.160891, 0.002829, 0.006829},{
      0.163001, 0.003163, 0.006829},{0.163305, 0.002227, 0.005676}}],
    Polygon[{{0.160891, 0.002829, 0.006829},{0.160891, 0.003981, 0.007813},{
      0.162645, 0.004259, 0.007813},{0.163001, 0.003163, 0.006829}}],
    Polygon[{{0.160891, 0.003981, 0.007813},{0.160891, 0.005273, 0.008605},{
      0.162246, 0.005487, 0.008605},{0.162645, 0.004259, 0.007813}}],
    Polygon[{{0.160891, 0.005273, 0.008605},{0.160891, 0.006673, 0.009185},{
      0.161813, 0.006819, 0.009185},{0.162246, 0.005487, 0.008605}}],
    Polygon[{{0.160891, 0.006673, 0.009185},{0.160891, 0.008146, 0.009538},{
      0.161358, 0.008220, 0.009538},{0.161813, 0.006819, 0.009185}}],
    Polygon[{{0.161358, 0.008220, -0.009538},{0.161813, 0.006819, -0.009185},{
      0.162645, 0.007243, -0.009185},{0.161779, 0.008435, -0.009538}}],
    Polygon[{{0.161813, 0.006819, -0.009185},{0.162246, 0.005487, -0.008605},{
      0.163468, 0.006110, -0.008605},{0.162645, 0.007243, -0.009185}}],
    Polygon[{{0.162246, 0.005487, -0.008605},{0.162645, 0.004259, -0.007813},{
      0.164227, 0.005065, -0.007813},{0.163468, 0.006110, -0.008605}}],
    Polygon[{{0.162645, 0.004259, -0.007813},{0.163001, 0.003163, -0.006829},{
      0.164905, 0.004133, -0.006829},{0.164227, 0.005065, -0.007813}}],
    Polygon[{{0.163001, 0.003163, -0.006829},{0.163305, 0.002227, -0.005676},{
      0.165483, 0.003336, -0.005676},{0.164905, 0.004133, -0.006829}}],
    Polygon[{{0.163305, 0.002227, -0.005676},{0.163550, 0.001474, -0.004384},{
      0.165949, 0.002696, -0.004384},{0.165483, 0.003336, -0.005676}}],
    Polygon[{{0.163550, 0.001474, -0.004384},{0.163729, 0.000922, -0.002984},{
      0.166289, 0.002227, -0.002984},{0.165949, 0.002696, -0.004384}}],
    Polygon[{{0.163729, 0.000922, -0.002984},{0.163838, 0.000586, -0.001511},{
      0.166497, 0.001941, -0.001511},{0.166289, 0.002227, -0.002984}}],
    Polygon[{{0.163838, 0.000586, -0.001511},{0.163875, 0.000473, 0.000000},{
      0.166567, 0.001844, 0.000000},{0.166497, 0.001941, -0.001511}}],
    Polygon[{{0.163875, 0.000473, 0.000000},{0.163838, 0.000586, 0.001511},{
      0.166497, 0.001941, 0.001511},{0.166567, 0.001844, 0.000000}}],
    Polygon[{{0.163838, 0.000586, 0.001511},{0.163729, 0.000922, 0.002984},{
      0.166289, 0.002227, 0.002984},{0.166497, 0.001941, 0.001511}}],
    Polygon[{{0.163729, 0.000922, 0.002984},{0.163550, 0.001474, 0.004384},{
      0.165949, 0.002696, 0.004384},{0.166289, 0.002227, 0.002984}}],
    Polygon[{{0.163550, 0.001474, 0.004384},{0.163305, 0.002227, 0.005676},{
      0.165483, 0.003336, 0.005676},{0.165949, 0.002696, 0.004384}}],
    Polygon[{{0.163305, 0.002227, 0.005676},{0.163001, 0.003163, 0.006829},{
      0.164905, 0.004133, 0.006829},{0.165483, 0.003336, 0.005676}}],
    Polygon[{{0.163001, 0.003163, 0.006829},{0.162645, 0.004259, 0.007813},{
      0.164227, 0.005065, 0.007813},{0.164905, 0.004133, 0.006829}}],
    Polygon[{{0.162645, 0.004259, 0.007813},{0.162246, 0.005487, 0.008605},{
      0.163468, 0.006110, 0.008605},{0.164227, 0.005065, 0.007813}}],
    Polygon[{{0.162246, 0.005487, 0.008605},{0.161813, 0.006819, 0.009185},{
      0.162645, 0.007243, 0.009185},{0.163468, 0.006110, 0.008605}}],
    Polygon[{{0.161813, 0.006819, 0.009185},{0.161358, 0.008220, 0.009538},{
      0.161779, 0.008435, 0.009538},{0.162645, 0.007243, 0.009185}}],
    Polygon[{{0.161779, 0.008435, -0.009538},{0.162645, 0.007243, -0.009185},{
      0.163305, 0.007903, -0.009185},{0.162113, 0.008769, -0.009538}}],
    Polygon[{{0.162645, 0.007243, -0.009185},{0.163468, 0.006110, -0.008605},{
      0.164438, 0.007080, -0.008605},{0.163305, 0.007903, -0.009185}}],
    Polygon[{{0.163468, 0.006110, -0.008605},{0.164227, 0.005065, -0.007813},{
      0.165483, 0.006321, -0.007813},{0.164438, 0.007080, -0.008605}}],
    Polygon[{{0.164227, 0.005065, -0.007813},{0.164905, 0.004133, -0.006829},{
      0.166415, 0.005643, -0.006829},{0.165483, 0.006321, -0.007813}}],
    Polygon[{{0.164905, 0.004133, -0.006829},{0.165483, 0.003336, -0.005676},{
      0.167212, 0.005065, -0.005676},{0.166415, 0.005643, -0.006829}}],
    Polygon[{{0.165483, 0.003336, -0.005676},{0.165949, 0.002696, -0.004384},{
      0.167852, 0.004600, -0.004384},{0.167212, 0.005065, -0.005676}}],
    Polygon[{{0.165949, 0.002696, -0.004384},{0.166289, 0.002227, -0.002984},{
      0.168321, 0.004259, -0.002984},{0.167852, 0.004600, -0.004384}}],
    Polygon[{{0.166289, 0.002227, -0.002984},{0.166497, 0.001941, -0.001511},{
      0.168608, 0.004051, -0.001511},{0.168321, 0.004259, -0.002984}}],
    Polygon[{{0.166497, 0.001941, -0.001511},{0.166567, 0.001844, 0.000000},{
      0.168704, 0.003981, 0.000000},{0.168608, 0.004051, -0.001511}}],
    Polygon[{{0.166567, 0.001844, 0.000000},{0.166497, 0.001941, 0.001511},{
      0.168608, 0.004051, 0.001511},{0.168704, 0.003981, 0.000000}}],
    Polygon[{{0.166497, 0.001941, 0.001511},{0.166289, 0.002227, 0.002984},{
      0.168321, 0.004259, 0.002984},{0.168608, 0.004051, 0.001511}}],
    Polygon[{{0.166289, 0.002227, 0.002984},{0.165949, 0.002696, 0.004384},{
      0.167852, 0.004600, 0.004384},{0.168321, 0.004259, 0.002984}}],
    Polygon[{{0.165949, 0.002696, 0.004384},{0.165483, 0.003336, 0.005676},{
      0.167212, 0.005065, 0.005676},{0.167852, 0.004600, 0.004384}}],
    Polygon[{{0.165483, 0.003336, 0.005676},{0.164905, 0.004133, 0.006829},{
      0.166415, 0.005643, 0.006829},{0.167212, 0.005065, 0.005676}}],
    Polygon[{{0.164905, 0.004133, 0.006829},{0.164227, 0.005065, 0.007813},{
      0.165483, 0.006321, 0.007813},{0.166415, 0.005643, 0.006829}}],
    Polygon[{{0.164227, 0.005065, 0.007813},{0.163468, 0.006110, 0.008605},{
      0.164438, 0.007080, 0.008605},{0.165483, 0.006321, 0.007813}}],
    Polygon[{{0.163468, 0.006110, 0.008605},{0.162645, 0.007243, 0.009185},{
      0.163305, 0.007903, 0.009185},{0.164438, 0.007080, 0.008605}}],
    Polygon[{{0.162645, 0.007243, 0.009185},{0.161779, 0.008435, 0.009538},{
      0.162113, 0.008769, 0.009538},{0.163305, 0.007903, 0.009185}}],
    Polygon[{{0.162113, 0.008769, -0.009538},{0.163305, 0.007903, -0.009185},{
      0.163729, 0.008735, -0.009185},{0.162328, 0.009190, -0.009538}}],
    Polygon[{{0.163305, 0.007903, -0.009185},{0.164438, 0.007080, -0.008605},{
      0.165061, 0.008302, -0.008605},{0.163729, 0.008735, -0.009185}}],
    Polygon[{{0.164438, 0.007080, -0.008605},{0.165483, 0.006321, -0.007813},{
      0.166289, 0.007903, -0.007813},{0.165061, 0.008302, -0.008605}}],
    Polygon[{{0.165483, 0.006321, -0.007813},{0.166415, 0.005643, -0.006829},{
      0.167385, 0.007547, -0.006829},{0.166289, 0.007903, -0.007813}}],
    Polygon[{{0.166415, 0.005643, -0.006829},{0.167212, 0.005065, -0.005676},{
      0.168321, 0.007243, -0.005676},{0.167385, 0.007547, -0.006829}}],
    Polygon[{{0.167212, 0.005065, -0.005676},{0.167852, 0.004600, -0.004384},{
      0.169074, 0.006998, -0.004384},{0.168321, 0.007243, -0.005676}}],
    Polygon[{{0.167852, 0.004600, -0.004384},{0.168321, 0.004259, -0.002984},{
      0.169626, 0.006819, -0.002984},{0.169074, 0.006998, -0.004384}}],
    Polygon[{{0.168321, 0.004259, -0.002984},{0.168608, 0.004051, -0.001511},{
      0.169962, 0.006710, -0.001511},{0.169626, 0.006819, -0.002984}}],
    Polygon[{{0.168608, 0.004051, -0.001511},{0.168704, 0.003981, 0.000000},{
      0.170075, 0.006673, 0.000000},{0.169962, 0.006710, -0.001511}}],
    Polygon[{{0.168704, 0.003981, 0.000000},{0.168608, 0.004051, 0.001511},{
      0.169962, 0.006710, 0.001511},{0.170075, 0.006673, 0.000000}}],
    Polygon[{{0.168608, 0.004051, 0.001511},{0.168321, 0.004259, 0.002984},{
      0.169626, 0.006819, 0.002984},{0.169962, 0.006710, 0.001511}}],
    Polygon[{{0.168321, 0.004259, 0.002984},{0.167852, 0.004600, 0.004384},{
      0.169074, 0.006998, 0.004384},{0.169626, 0.006819, 0.002984}}],
    Polygon[{{0.167852, 0.004600, 0.004384},{0.167212, 0.005065, 0.005676},{
      0.168321, 0.007243, 0.005676},{0.169074, 0.006998, 0.004384}}],
    Polygon[{{0.167212, 0.005065, 0.005676},{0.166415, 0.005643, 0.006829},{
      0.167385, 0.007547, 0.006829},{0.168321, 0.007243, 0.005676}}],
    Polygon[{{0.166415, 0.005643, 0.006829},{0.165483, 0.006321, 0.007813},{
      0.166289, 0.007903, 0.007813},{0.167385, 0.007547, 0.006829}}],
    Polygon[{{0.165483, 0.006321, 0.007813},{0.164438, 0.007080, 0.008605},{
      0.165061, 0.008302, 0.008605},{0.166289, 0.007903, 0.007813}}],
    Polygon[{{0.164438, 0.007080, 0.008605},{0.163305, 0.007903, 0.009185},{
      0.163729, 0.008735, 0.009185},{0.165061, 0.008302, 0.008605}}],
    Polygon[{{0.163305, 0.007903, 0.009185},{0.162113, 0.008769, 0.009538},{
      0.162328, 0.009190, 0.009538},{0.163729, 0.008735, 0.009185}}],
    Polygon[{{0.162328, 0.009190, -0.009538},{0.163729, 0.008735, -0.009185},{
      0.163875, 0.009657, -0.009185},{0.162402, 0.009657, -0.009538}}],
    Polygon[{{0.163729, 0.008735, -0.009185},{0.165061, 0.008302, -0.008605},{
      0.165275, 0.009657, -0.008605},{0.163875, 0.009657, -0.009185}}],
    Polygon[{{0.165061, 0.008302, -0.008605},{0.166289, 0.007903, -0.007813},{
      0.166567, 0.009657, -0.007813},{0.165275, 0.009657, -0.008605}}],
    Polygon[{{0.166289, 0.007903, -0.007813},{0.167385, 0.007547, -0.006829},{
      0.167720, 0.009657, -0.006829},{0.166567, 0.009657, -0.007813}}],
    Polygon[{{0.167385, 0.007547, -0.006829},{0.168321, 0.007243, -0.005676},{
      0.168704, 0.009657, -0.005676},{0.167720, 0.009657, -0.006829}}],
    Polygon[{{0.168321, 0.007243, -0.005676},{0.169074, 0.006998, -0.004384},{
      0.169496, 0.009657, -0.004384},{0.168704, 0.009657, -0.005676}}],
    Polygon[{{0.169074, 0.006998, -0.004384},{0.169626, 0.006819, -0.002984},{
      0.170075, 0.009657, -0.002984},{0.169496, 0.009657, -0.004384}}],
    Polygon[{{0.169626, 0.006819, -0.002984},{0.169962, 0.006710, -0.001511},{
      0.170429, 0.009657, -0.001511},{0.170075, 0.009657, -0.002984}}],
    Polygon[{{0.169962, 0.006710, -0.001511},{0.170075, 0.006673, 0.000000},{
      0.170548, 0.009657, 0.000000},{0.170429, 0.009657, -0.001511}}],
    Polygon[{{0.170075, 0.006673, 0.000000},{0.169962, 0.006710, 0.001511},{
      0.170429, 0.009657, 0.001511},{0.170548, 0.009657, 0.000000}}],
    Polygon[{{0.169962, 0.006710, 0.001511},{0.169626, 0.006819, 0.002984},{
      0.170075, 0.009657, 0.002984},{0.170429, 0.009657, 0.001511}}],
    Polygon[{{0.169626, 0.006819, 0.002984},{0.169074, 0.006998, 0.004384},{
      0.169496, 0.009657, 0.004384},{0.170075, 0.009657, 0.002984}}],
    Polygon[{{0.169074, 0.006998, 0.004384},{0.168321, 0.007243, 0.005676},{
      0.168704, 0.009657, 0.005676},{0.169496, 0.009657, 0.004384}}],
    Polygon[{{0.168321, 0.007243, 0.005676},{0.167385, 0.007547, 0.006829},{
      0.167720, 0.009657, 0.006829},{0.168704, 0.009657, 0.005676}}],
    Polygon[{{0.167385, 0.007547, 0.006829},{0.166289, 0.007903, 0.007813},{
      0.166567, 0.009657, 0.007813},{0.167720, 0.009657, 0.006829}}],
    Polygon[{{0.166289, 0.007903, 0.007813},{0.165061, 0.008302, 0.008605},{
      0.165275, 0.009657, 0.008605},{0.166567, 0.009657, 0.007813}}],
    Polygon[{{0.165061, 0.008302, 0.008605},{0.163729, 0.008735, 0.009185},{
      0.163875, 0.009657, 0.009185},{0.165275, 0.009657, 0.008605}}],
    Polygon[{{0.163729, 0.008735, 0.009185},{0.162328, 0.009190, 0.009538},{
      0.162402, 0.009657, 0.009538},{0.163875, 0.009657, 0.009185}}],
    Polygon[{{0.184767, 0.058755, -0.008290},{0.186048, 0.058755, -0.007983},{
      0.185921, 0.059557, -0.007983},{0.184703, 0.059161, -0.008290}}],
    Polygon[{{0.186048, 0.058755, -0.007983},{0.187264, 0.058755, -0.007479},{
      0.187078, 0.059933, -0.007479},{0.185921, 0.059557, -0.007983}}],
    Polygon[{{0.187264, 0.058755, -0.007479},{0.188387, 0.058755, -0.006791},{
      0.188146, 0.060280, -0.006791},{0.187078, 0.059933, -0.007479}}],
    Polygon[{{0.188387, 0.058755, -0.006791},{0.189389, 0.058755, -0.005935},{
      0.189099, 0.060589, -0.005935},{0.188146, 0.060280, -0.006791}}],
    Polygon[{{0.189389, 0.058755, -0.005935},{0.190244, 0.058755, -0.004934},{
      0.189912, 0.060854, -0.004934},{0.189099, 0.060589, -0.005935}}],
    Polygon[{{0.190244, 0.058755, -0.004934},{0.190933, 0.058755, -0.003811},{
      0.190567, 0.061066, -0.003811},{0.189912, 0.060854, -0.004934}}],
    Polygon[{{0.190933, 0.058755, -0.003811},{0.191437, 0.058755, -0.002594},{
      0.191046, 0.061222, -0.002594},{0.190567, 0.061066, -0.003811}}],
    Polygon[{{0.191437, 0.058755, -0.002594},{0.191744, 0.058755, -0.001313},{
      0.191338, 0.061317, -0.001313},{0.191046, 0.061222, -0.002594}}],
    Polygon[{{0.191744, 0.058755, -0.001313},{0.191847, 0.058755, 0.000000},{
      0.191437, 0.061349, 0.000000},{0.191338, 0.061317, -0.001313}}],
    Polygon[{{0.191847, 0.058755, 0.000000},{0.191744, 0.058755, 0.001313},{
      0.191338, 0.061317, 0.001313},{0.191437, 0.061349, 0.000000}}],
    Polygon[{{0.191744, 0.058755, 0.001313},{0.191437, 0.058755, 0.002594},{
      0.191046, 0.061222, 0.002594},{0.191338, 0.061317, 0.001313}}],
    Polygon[{{0.191437, 0.058755, 0.002594},{0.190933, 0.058755, 0.003811},{
      0.190567, 0.061066, 0.003811},{0.191046, 0.061222, 0.002594}}],
    Polygon[{{0.190933, 0.058755, 0.003811},{0.190244, 0.058755, 0.004934},{
      0.189912, 0.060854, 0.004934},{0.190567, 0.061066, 0.003811}}],
    Polygon[{{0.190244, 0.058755, 0.004934},{0.189389, 0.058755, 0.005935},{
      0.189099, 0.060589, 0.005935},{0.189912, 0.060854, 0.004934}}],
    Polygon[{{0.189389, 0.058755, 0.005935},{0.188387, 0.058755, 0.006791},{
      0.188146, 0.060280, 0.006791},{0.189099, 0.060589, 0.005935}}],
    Polygon[{{0.188387, 0.058755, 0.006791},{0.187264, 0.058755, 0.007479},{
      0.187078, 0.059933, 0.007479},{0.188146, 0.060280, 0.006791}}],
    Polygon[{{0.187264, 0.058755, 0.007479},{0.186048, 0.058755, 0.007983},{
      0.185921, 0.059557, 0.007983},{0.187078, 0.059933, 0.007479}}],
    Polygon[{{0.186048, 0.058755, 0.007983},{0.184767, 0.058755, 0.008290},{
      0.184703, 0.059161, 0.008290},{0.185921, 0.059557, 0.007983}}],
    Polygon[{{0.184703, 0.059161, -0.008290},{0.185921, 0.059557, -0.007983},{
      0.185552, 0.060280, -0.007983},{0.184516, 0.059527, -0.008290}}],
    Polygon[{{0.185921, 0.059557, -0.007983},{0.187078, 0.059933, -0.007479},{
      0.186537, 0.060995, -0.007479},{0.185552, 0.060280, -0.007983}}],
    Polygon[{{0.187078, 0.059933, -0.007479},{0.188146, 0.060280, -0.006791},{
      0.187445, 0.061655, -0.006791},{0.186537, 0.060995, -0.007479}}],
    Polygon[{{0.188146, 0.060280, -0.006791},{0.189099, 0.060589, -0.005935},{
      0.188256, 0.062244, -0.005935},{0.187445, 0.061655, -0.006791}}],
    Polygon[{{0.189099, 0.060589, -0.005935},{0.189912, 0.060854, -0.004934},{
      0.188948, 0.062747, -0.004934},{0.188256, 0.062244, -0.005935}}],
    Polygon[{{0.189912, 0.060854, -0.004934},{0.190567, 0.061066, -0.003811},{
      0.189504, 0.063151, -0.003811},{0.188948, 0.062747, -0.004934}}],
    Polygon[{{0.190567, 0.061066, -0.003811},{0.191046, 0.061222, -0.002594},{
      0.189912, 0.063447, -0.002594},{0.189504, 0.063151, -0.003811}}],
    Polygon[{{0.191046, 0.061222, -0.002594},{0.191338, 0.061317, -0.001313},{
      0.190161, 0.063628, -0.001313},{0.189912, 0.063447, -0.002594}}],
    Polygon[{{0.191338, 0.061317, -0.001313},{0.191437, 0.061349, 0.000000},{
      0.190244, 0.063689, 0.000000},{0.190161, 0.063628, -0.001313}}],
    Polygon[{{0.191437, 0.061349, 0.000000},{0.191338, 0.061317, 0.001313},{
      0.190161, 0.063628, 0.001313},{0.190244, 0.063689, 0.000000}}],
    Polygon[{{0.191338, 0.061317, 0.001313},{0.191046, 0.061222, 0.002594},{
      0.189912, 0.063447, 0.002594},{0.190161, 0.063628, 0.001313}}],
    Polygon[{{0.191046, 0.061222, 0.002594},{0.190567, 0.061066, 0.003811},{
      0.189504, 0.063151, 0.003811},{0.189912, 0.063447, 0.002594}}],
    Polygon[{{0.190567, 0.061066, 0.003811},{0.189912, 0.060854, 0.004934},{
      0.188948, 0.062747, 0.004934},{0.189504, 0.063151, 0.003811}}],
    Polygon[{{0.189912, 0.060854, 0.004934},{0.189099, 0.060589, 0.005935},{
      0.188256, 0.062244, 0.005935},{0.188948, 0.062747, 0.004934}}],
    Polygon[{{0.189099, 0.060589, 0.005935},{0.188146, 0.060280, 0.006791},{
      0.187445, 0.061655, 0.006791},{0.188256, 0.062244, 0.005935}}],
    Polygon[{{0.188146, 0.060280, 0.006791},{0.187078, 0.059933, 0.007479},{
      0.186537, 0.060995, 0.007479},{0.187445, 0.061655, 0.006791}}],
    Polygon[{{0.187078, 0.059933, 0.007479},{0.185921, 0.059557, 0.007983},{
      0.185552, 0.060280, 0.007983},{0.186537, 0.060995, 0.007479}}],
    Polygon[{{0.185921, 0.059557, 0.007983},{0.184703, 0.059161, 0.008290},{
      0.184516, 0.059527, 0.008290},{0.185552, 0.060280, 0.007983}}],
    Polygon[{{0.184516, 0.059527, -0.008290},{0.185552, 0.060280, -0.007983},{
      0.184978, 0.060854, -0.007983},{0.184226, 0.059817, -0.008290}}],
    Polygon[{{0.185552, 0.060280, -0.007983},{0.186537, 0.060995, -0.007479},{
      0.185694, 0.061838, -0.007479},{0.184978, 0.060854, -0.007983}}],
    Polygon[{{0.186537, 0.060995, -0.007479},{0.187445, 0.061655, -0.006791},{
      0.186354, 0.062747, -0.006791},{0.185694, 0.061838, -0.007479}}],
    Polygon[{{0.187445, 0.061655, -0.006791},{0.188256, 0.062244, -0.005935},{
      0.186942, 0.063557, -0.005935},{0.186354, 0.062747, -0.006791}}],
    Polygon[{{0.188256, 0.062244, -0.005935},{0.188948, 0.062747, -0.004934},{
      0.187445, 0.064249, -0.004934},{0.186942, 0.063557, -0.005935}}],
    Polygon[{{0.188948, 0.062747, -0.004934},{0.189504, 0.063151, -0.003811},{
      0.187850, 0.064806, -0.003811},{0.187445, 0.064249, -0.004934}}],
    Polygon[{{0.189504, 0.063151, -0.003811},{0.189912, 0.063447, -0.002594},{
      0.188146, 0.065213, -0.002594},{0.187850, 0.064806, -0.003811}}],
    Polygon[{{0.189912, 0.063447, -0.002594},{0.190161, 0.063628, -0.001313},{
      0.188327, 0.065462, -0.001313},{0.188146, 0.065213, -0.002594}}],
    Polygon[{{0.190161, 0.063628, -0.001313},{0.190244, 0.063689, 0.000000},{
      0.188387, 0.065546, 0.000000},{0.188327, 0.065462, -0.001313}}],
    Polygon[{{0.190244, 0.063689, 0.000000},{0.190161, 0.063628, 0.001313},{
      0.188327, 0.065462, 0.001313},{0.188387, 0.065546, 0.000000}}],
    Polygon[{{0.190161, 0.063628, 0.001313},{0.189912, 0.063447, 0.002594},{
      0.188146, 0.065213, 0.002594},{0.188327, 0.065462, 0.001313}}],
    Polygon[{{0.189912, 0.063447, 0.002594},{0.189504, 0.063151, 0.003811},{
      0.187850, 0.064806, 0.003811},{0.188146, 0.065213, 0.002594}}],
    Polygon[{{0.189504, 0.063151, 0.003811},{0.188948, 0.062747, 0.004934},{
      0.187445, 0.064249, 0.004934},{0.187850, 0.064806, 0.003811}}],
    Polygon[{{0.188948, 0.062747, 0.004934},{0.188256, 0.062244, 0.005935},{
      0.186942, 0.063557, 0.005935},{0.187445, 0.064249, 0.004934}}],
    Polygon[{{0.188256, 0.062244, 0.005935},{0.187445, 0.061655, 0.006791},{
      0.186354, 0.062747, 0.006791},{0.186942, 0.063557, 0.005935}}],
    Polygon[{{0.187445, 0.061655, 0.006791},{0.186537, 0.060995, 0.007479},{
      0.185694, 0.061838, 0.007479},{0.186354, 0.062747, 0.006791}}],
    Polygon[{{0.186537, 0.060995, 0.007479},{0.185552, 0.060280, 0.007983},{
      0.184978, 0.060854, 0.007983},{0.185694, 0.061838, 0.007479}}],
    Polygon[{{0.185552, 0.060280, 0.007983},{0.184516, 0.059527, 0.008290},{
      0.184226, 0.059817, 0.008290},{0.184978, 0.060854, 0.007983}}],
    Polygon[{{0.184226, 0.059817, -0.008290},{0.184978, 0.060854, -0.007983},{
      0.184255, 0.061222, -0.007983},{0.183860, 0.060004, -0.008290}}],
    Polygon[{{0.184978, 0.060854, -0.007983},{0.185694, 0.061838, -0.007479},{
      0.184631, 0.062379, -0.007479},{0.184255, 0.061222, -0.007983}}],
    Polygon[{{0.185694, 0.061838, -0.007479},{0.186354, 0.062747, -0.006791},{
      0.184978, 0.063447, -0.006791},{0.184631, 0.062379, -0.007479}}],
    Polygon[{{0.186354, 0.062747, -0.006791},{0.186942, 0.063557, -0.005935},{
      0.185288, 0.064400, -0.005935},{0.184978, 0.063447, -0.006791}}],
    Polygon[{{0.186942, 0.063557, -0.005935},{0.187445, 0.064249, -0.004934},{
      0.185552, 0.065213, -0.004934},{0.185288, 0.064400, -0.005935}}],
    Polygon[{{0.187445, 0.064249, -0.004934},{0.187850, 0.064806, -0.003811},{
      0.185765, 0.065868, -0.003811},{0.185552, 0.065213, -0.004934}}],
    Polygon[{{0.187850, 0.064806, -0.003811},{0.188146, 0.065213, -0.002594},{
      0.185921, 0.066347, -0.002594},{0.185765, 0.065868, -0.003811}}],
    Polygon[{{0.188146, 0.065213, -0.002594},{0.188327, 0.065462, -0.001313},{
      0.186016, 0.066640, -0.001313},{0.185921, 0.066347, -0.002594}}],
    Polygon[{{0.188327, 0.065462, -0.001313},{0.188387, 0.065546, 0.000000},{
      0.186048, 0.066738, 0.000000},{0.186016, 0.066640, -0.001313}}],
    Polygon[{{0.188387, 0.065546, 0.000000},{0.188327, 0.065462, 0.001313},{
      0.186016, 0.066640, 0.001313},{0.186048, 0.066738, 0.000000}}],
    Polygon[{{0.188327, 0.065462, 0.001313},{0.188146, 0.065213, 0.002594},{
      0.185921, 0.066347, 0.002594},{0.186016, 0.066640, 0.001313}}],
    Polygon[{{0.188146, 0.065213, 0.002594},{0.187850, 0.064806, 0.003811},{
      0.185765, 0.065868, 0.003811},{0.185921, 0.066347, 0.002594}}],
    Polygon[{{0.187850, 0.064806, 0.003811},{0.187445, 0.064249, 0.004934},{
      0.185552, 0.065213, 0.004934},{0.185765, 0.065868, 0.003811}}],
    Polygon[{{0.187445, 0.064249, 0.004934},{0.186942, 0.063557, 0.005935},{
      0.185288, 0.064400, 0.005935},{0.185552, 0.065213, 0.004934}}],
    Polygon[{{0.186942, 0.063557, 0.005935},{0.186354, 0.062747, 0.006791},{
      0.184978, 0.063447, 0.006791},{0.185288, 0.064400, 0.005935}}],
    Polygon[{{0.186354, 0.062747, 0.006791},{0.185694, 0.061838, 0.007479},{
      0.184631, 0.062379, 0.007479},{0.184978, 0.063447, 0.006791}}],
    Polygon[{{0.185694, 0.061838, 0.007479},{0.184978, 0.060854, 0.007983},{
      0.184255, 0.061222, 0.007983},{0.184631, 0.062379, 0.007479}}],
    Polygon[{{0.184978, 0.060854, 0.007983},{0.184226, 0.059817, 0.008290},{
      0.183860, 0.060004, 0.008290},{0.184255, 0.061222, 0.007983}}],
    Polygon[{{0.183860, 0.060004, -0.008290},{0.184255, 0.061222, -0.007983},{
      0.183454, 0.061349, -0.007983},{0.183454, 0.060068, -0.008290}}],
    Polygon[{{0.184255, 0.061222, -0.007983},{0.184631, 0.062379, -0.007479},{
      0.183454, 0.062566, -0.007479},{0.183454, 0.061349, -0.007983}}],
    Polygon[{{0.184631, 0.062379, -0.007479},{0.184978, 0.063447, -0.006791},{
      0.183454, 0.063689, -0.006791},{0.183454, 0.062566, -0.007479}}],
    Polygon[{{0.184978, 0.063447, -0.006791},{0.185288, 0.064400, -0.005935},{
      0.183454, 0.064690, -0.005935},{0.183454, 0.063689, -0.006791}}],
    Polygon[{{0.185288, 0.064400, -0.005935},{0.185552, 0.065213, -0.004934},{
      0.183454, 0.065546, -0.004934},{0.183454, 0.064690, -0.005935}}],
    Polygon[{{0.185552, 0.065213, -0.004934},{0.185765, 0.065868, -0.003811},{
      0.183454, 0.066234, -0.003811},{0.183454, 0.065546, -0.004934}}],
    Polygon[{{0.185765, 0.065868, -0.003811},{0.185921, 0.066347, -0.002594},{
      0.183454, 0.066738, -0.002594},{0.183454, 0.066234, -0.003811}}],
    Polygon[{{0.185921, 0.066347, -0.002594},{0.186016, 0.066640, -0.001313},{
      0.183454, 0.067045, -0.001313},{0.183454, 0.066738, -0.002594}}],
    Polygon[{{0.186016, 0.066640, -0.001313},{0.186048, 0.066738, 0.000000},{
      0.183454, 0.067149, 0.000000},{0.183454, 0.067045, -0.001313}}],
    Polygon[{{0.186048, 0.066738, 0.000000},{0.186016, 0.066640, 0.001313},{
      0.183454, 0.067045, 0.001313},{0.183454, 0.067149, 0.000000}}],
    Polygon[{{0.186016, 0.066640, 0.001313},{0.185921, 0.066347, 0.002594},{
      0.183454, 0.066738, 0.002594},{0.183454, 0.067045, 0.001313}}],
    Polygon[{{0.185921, 0.066347, 0.002594},{0.185765, 0.065868, 0.003811},{
      0.183454, 0.066234, 0.003811},{0.183454, 0.066738, 0.002594}}],
    Polygon[{{0.185765, 0.065868, 0.003811},{0.185552, 0.065213, 0.004934},{
      0.183454, 0.065546, 0.004934},{0.183454, 0.066234, 0.003811}}],
    Polygon[{{0.185552, 0.065213, 0.004934},{0.185288, 0.064400, 0.005935},{
      0.183454, 0.064690, 0.005935},{0.183454, 0.065546, 0.004934}}],
    Polygon[{{0.185288, 0.064400, 0.005935},{0.184978, 0.063447, 0.006791},{
      0.183454, 0.063689, 0.006791},{0.183454, 0.064690, 0.005935}}],
    Polygon[{{0.184978, 0.063447, 0.006791},{0.184631, 0.062379, 0.007479},{
      0.183454, 0.062566, 0.007479},{0.183454, 0.063689, 0.006791}}],
    Polygon[{{0.184631, 0.062379, 0.007479},{0.184255, 0.061222, 0.007983},{
      0.183454, 0.061349, 0.007983},{0.183454, 0.062566, 0.007479}}],
    Polygon[{{0.184255, 0.061222, 0.007983},{0.183860, 0.060004, 0.008290},{
      0.183454, 0.060068, 0.008290},{0.183454, 0.061349, 0.007983}}],
    Polygon[{{0.183454, 0.060068, -0.008290},{0.183454, 0.061349, -0.007983},{
      0.182652, 0.061222, -0.007983},{0.183048, 0.060004, -0.008290}}],
    Polygon[{{0.183454, 0.061349, -0.007983},{0.183454, 0.062566, -0.007479},{
      0.182276, 0.062379, -0.007479},{0.182652, 0.061222, -0.007983}}],
    Polygon[{{0.183454, 0.062566, -0.007479},{0.183454, 0.063689, -0.006791},{
      0.181929, 0.063447, -0.006791},{0.182276, 0.062379, -0.007479}}],
    Polygon[{{0.183454, 0.063689, -0.006791},{0.183454, 0.064690, -0.005935},{
      0.181620, 0.064400, -0.005935},{0.181929, 0.063447, -0.006791}}],
    Polygon[{{0.183454, 0.064690, -0.005935},{0.183454, 0.065546, -0.004934},{
      0.181355, 0.065213, -0.004934},{0.181620, 0.064400, -0.005935}}],
    Polygon[{{0.183454, 0.065546, -0.004934},{0.183454, 0.066234, -0.003811},{
      0.181143, 0.065868, -0.003811},{0.181355, 0.065213, -0.004934}}],
    Polygon[{{0.183454, 0.066234, -0.003811},{0.183454, 0.066738, -0.002594},{
      0.180987, 0.066347, -0.002594},{0.181143, 0.065868, -0.003811}}],
    Polygon[{{0.183454, 0.066738, -0.002594},{0.183454, 0.067045, -0.001313},{
      0.180892, 0.066640, -0.001313},{0.180987, 0.066347, -0.002594}}],
    Polygon[{{0.183454, 0.067045, -0.001313},{0.183454, 0.067149, 0.000000},{
      0.180860, 0.066738, 0.000000},{0.180892, 0.066640, -0.001313}}],
    Polygon[{{0.183454, 0.067149, 0.000000},{0.183454, 0.067045, 0.001313},{
      0.180892, 0.066640, 0.001313},{0.180860, 0.066738, 0.000000}}],
    Polygon[{{0.183454, 0.067045, 0.001313},{0.183454, 0.066738, 0.002594},{
      0.180987, 0.066347, 0.002594},{0.180892, 0.066640, 0.001313}}],
    Polygon[{{0.183454, 0.066738, 0.002594},{0.183454, 0.066234, 0.003811},{
      0.181143, 0.065868, 0.003811},{0.180987, 0.066347, 0.002594}}],
    Polygon[{{0.183454, 0.066234, 0.003811},{0.183454, 0.065546, 0.004934},{
      0.181355, 0.065213, 0.004934},{0.181143, 0.065868, 0.003811}}],
    Polygon[{{0.183454, 0.065546, 0.004934},{0.183454, 0.064690, 0.005935},{
      0.181620, 0.064400, 0.005935},{0.181355, 0.065213, 0.004934}}],
    Polygon[{{0.183454, 0.064690, 0.005935},{0.183454, 0.063689, 0.006791},{
      0.181929, 0.063447, 0.006791},{0.181620, 0.064400, 0.005935}}],
    Polygon[{{0.183454, 0.063689, 0.006791},{0.183454, 0.062566, 0.007479},{
      0.182276, 0.062379, 0.007479},{0.181929, 0.063447, 0.006791}}],
    Polygon[{{0.183454, 0.062566, 0.007479},{0.183454, 0.061349, 0.007983},{
      0.182652, 0.061222, 0.007983},{0.182276, 0.062379, 0.007479}}],
    Polygon[{{0.183454, 0.061349, 0.007983},{0.183454, 0.060068, 0.008290},{
      0.183048, 0.060004, 0.008290},{0.182652, 0.061222, 0.007983}}],
    Polygon[{{0.183048, 0.060004, -0.008290},{0.182652, 0.061222, -0.007983},{
      0.181929, 0.060854, -0.007983},{0.182682, 0.059817, -0.008290}}],
    Polygon[{{0.182652, 0.061222, -0.007983},{0.182276, 0.062379, -0.007479},{
      0.181214, 0.061838, -0.007479},{0.181929, 0.060854, -0.007983}}],
    Polygon[{{0.182276, 0.062379, -0.007479},{0.181929, 0.063447, -0.006791},{
      0.180554, 0.062747, -0.006791},{0.181214, 0.061838, -0.007479}}],
    Polygon[{{0.181929, 0.063447, -0.006791},{0.181620, 0.064400, -0.005935},{
      0.179965, 0.063557, -0.005935},{0.180554, 0.062747, -0.006791}}],
    Polygon[{{0.181620, 0.064400, -0.005935},{0.181355, 0.065213, -0.004934},{
      0.179462, 0.064249, -0.004934},{0.179965, 0.063557, -0.005935}}],
    Polygon[{{0.181355, 0.065213, -0.004934},{0.181143, 0.065868, -0.003811},{
      0.179058, 0.064806, -0.003811},{0.179462, 0.064249, -0.004934}}],
    Polygon[{{0.181143, 0.065868, -0.003811},{0.180987, 0.066347, -0.002594},{
      0.178762, 0.065213, -0.002594},{0.179058, 0.064806, -0.003811}}],
    Polygon[{{0.180987, 0.066347, -0.002594},{0.180892, 0.066640, -0.001313},{
      0.178581, 0.065462, -0.001313},{0.178762, 0.065213, -0.002594}}],
    Polygon[{{0.180892, 0.066640, -0.001313},{0.180860, 0.066738, 0.000000},{
      0.178520, 0.065546, 0.000000},{0.178581, 0.065462, -0.001313}}],
    Polygon[{{0.180860, 0.066738, 0.000000},{0.180892, 0.066640, 0.001313},{
      0.178581, 0.065462, 0.001313},{0.178520, 0.065546, 0.000000}}],
    Polygon[{{0.180892, 0.066640, 0.001313},{0.180987, 0.066347, 0.002594},{
      0.178762, 0.065213, 0.002594},{0.178581, 0.065462, 0.001313}}],
    Polygon[{{0.180987, 0.066347, 0.002594},{0.181143, 0.065868, 0.003811},{
      0.179058, 0.064806, 0.003811},{0.178762, 0.065213, 0.002594}}],
    Polygon[{{0.181143, 0.065868, 0.003811},{0.181355, 0.065213, 0.004934},{
      0.179462, 0.064249, 0.004934},{0.179058, 0.064806, 0.003811}}],
    Polygon[{{0.181355, 0.065213, 0.004934},{0.181620, 0.064400, 0.005935},{
      0.179965, 0.063557, 0.005935},{0.179462, 0.064249, 0.004934}}],
    Polygon[{{0.181620, 0.064400, 0.005935},{0.181929, 0.063447, 0.006791},{
      0.180554, 0.062747, 0.006791},{0.179965, 0.063557, 0.005935}}],
    Polygon[{{0.181929, 0.063447, 0.006791},{0.182276, 0.062379, 0.007479},{
      0.181214, 0.061838, 0.007479},{0.180554, 0.062747, 0.006791}}],
    Polygon[{{0.182276, 0.062379, 0.007479},{0.182652, 0.061222, 0.007983},{
      0.181929, 0.060854, 0.007983},{0.181214, 0.061838, 0.007479}}],
    Polygon[{{0.182652, 0.061222, 0.007983},{0.183048, 0.060004, 0.008290},{
      0.182682, 0.059817, 0.008290},{0.181929, 0.060854, 0.007983}}],
    Polygon[{{0.182682, 0.059817, -0.008290},{0.181929, 0.060854, -0.007983},{
      0.181355, 0.060280, -0.007983},{0.182392, 0.059527, -0.008290}}],
    Polygon[{{0.181929, 0.060854, -0.007983},{0.181214, 0.061838, -0.007479},{
      0.180371, 0.060995, -0.007479},{0.181355, 0.060280, -0.007983}}],
    Polygon[{{0.181214, 0.061838, -0.007479},{0.180554, 0.062747, -0.006791},{
      0.179462, 0.061655, -0.006791},{0.180371, 0.060995, -0.007479}}],
    Polygon[{{0.180554, 0.062747, -0.006791},{0.179965, 0.063557, -0.005935},{
      0.178652, 0.062244, -0.005935},{0.179462, 0.061655, -0.006791}}],
    Polygon[{{0.179965, 0.063557, -0.005935},{0.179462, 0.064249, -0.004934},{
      0.177960, 0.062747, -0.004934},{0.178652, 0.062244, -0.005935}}],
    Polygon[{{0.179462, 0.064249, -0.004934},{0.179058, 0.064806, -0.003811},{
      0.177403, 0.063151, -0.003811},{0.177960, 0.062747, -0.004934}}],
    Polygon[{{0.179058, 0.064806, -0.003811},{0.178762, 0.065213, -0.002594},{
      0.176996, 0.063447, -0.002594},{0.177403, 0.063151, -0.003811}}],
    Polygon[{{0.178762, 0.065213, -0.002594},{0.178581, 0.065462, -0.001313},{
      0.176747, 0.063628, -0.001313},{0.176996, 0.063447, -0.002594}}],
    Polygon[{{0.178581, 0.065462, -0.001313},{0.178520, 0.065546, 0.000000},{
      0.176663, 0.063689, 0.000000},{0.176747, 0.063628, -0.001313}}],
    Polygon[{{0.178520, 0.065546, 0.000000},{0.178581, 0.065462, 0.001313},{
      0.176747, 0.063628, 0.001313},{0.176663, 0.063689, 0.000000}}],
    Polygon[{{0.178581, 0.065462, 0.001313},{0.178762, 0.065213, 0.002594},{
      0.176996, 0.063447, 0.002594},{0.176747, 0.063628, 0.001313}}],
    Polygon[{{0.178762, 0.065213, 0.002594},{0.179058, 0.064806, 0.003811},{
      0.177403, 0.063151, 0.003811},{0.176996, 0.063447, 0.002594}}],
    Polygon[{{0.179058, 0.064806, 0.003811},{0.179462, 0.064249, 0.004934},{
      0.177960, 0.062747, 0.004934},{0.177403, 0.063151, 0.003811}}],
    Polygon[{{0.179462, 0.064249, 0.004934},{0.179965, 0.063557, 0.005935},{
      0.178652, 0.062244, 0.005935},{0.177960, 0.062747, 0.004934}}],
    Polygon[{{0.179965, 0.063557, 0.005935},{0.180554, 0.062747, 0.006791},{
      0.179462, 0.061655, 0.006791},{0.178652, 0.062244, 0.005935}}],
    Polygon[{{0.180554, 0.062747, 0.006791},{0.181214, 0.061838, 0.007479},{
      0.180371, 0.060995, 0.007479},{0.179462, 0.061655, 0.006791}}],
    Polygon[{{0.181214, 0.061838, 0.007479},{0.181929, 0.060854, 0.007983},{
      0.181355, 0.060280, 0.007983},{0.180371, 0.060995, 0.007479}}],
    Polygon[{{0.181929, 0.060854, 0.007983},{0.182682, 0.059817, 0.008290},{
      0.182392, 0.059527, 0.008290},{0.181355, 0.060280, 0.007983}}],
    Polygon[{{0.182392, 0.059527, -0.008290},{0.181355, 0.060280, -0.007983},{
      0.180987, 0.059557, -0.007983},{0.182205, 0.059161, -0.008290}}],
    Polygon[{{0.181355, 0.060280, -0.007983},{0.180371, 0.060995, -0.007479},{
      0.179830, 0.059933, -0.007479},{0.180987, 0.059557, -0.007983}}],
    Polygon[{{0.180371, 0.060995, -0.007479},{0.179462, 0.061655, -0.006791},{
      0.178762, 0.060280, -0.006791},{0.179830, 0.059933, -0.007479}}],
    Polygon[{{0.179462, 0.061655, -0.006791},{0.178652, 0.062244, -0.005935},{
      0.177809, 0.060589, -0.005935},{0.178762, 0.060280, -0.006791}}],
    Polygon[{{0.178652, 0.062244, -0.005935},{0.177960, 0.062747, -0.004934},{
      0.176996, 0.060854, -0.004934},{0.177809, 0.060589, -0.005935}}],
    Polygon[{{0.177960, 0.062747, -0.004934},{0.177403, 0.063151, -0.003811},{
      0.176341, 0.061066, -0.003811},{0.176996, 0.060854, -0.004934}}],
    Polygon[{{0.177403, 0.063151, -0.003811},{0.176996, 0.063447, -0.002594},{
      0.175862, 0.061222, -0.002594},{0.176341, 0.061066, -0.003811}}],
    Polygon[{{0.176996, 0.063447, -0.002594},{0.176747, 0.063628, -0.001313},{
      0.175569, 0.061317, -0.001313},{0.175862, 0.061222, -0.002594}}],
    Polygon[{{0.176747, 0.063628, -0.001313},{0.176663, 0.063689, 0.000000},{
      0.175471, 0.061349, 0.000000},{0.175569, 0.061317, -0.001313}}],
    Polygon[{{0.176663, 0.063689, 0.000000},{0.176747, 0.063628, 0.001313},{
      0.175569, 0.061317, 0.001313},{0.175471, 0.061349, 0.000000}}],
    Polygon[{{0.176747, 0.063628, 0.001313},{0.176996, 0.063447, 0.002594},{
      0.175862, 0.061222, 0.002594},{0.175569, 0.061317, 0.001313}}],
    Polygon[{{0.176996, 0.063447, 0.002594},{0.177403, 0.063151, 0.003811},{
      0.176341, 0.061066, 0.003811},{0.175862, 0.061222, 0.002594}}],
    Polygon[{{0.177403, 0.063151, 0.003811},{0.177960, 0.062747, 0.004934},{
      0.176996, 0.060854, 0.004934},{0.176341, 0.061066, 0.003811}}],
    Polygon[{{0.177960, 0.062747, 0.004934},{0.178652, 0.062244, 0.005935},{
      0.177809, 0.060589, 0.005935},{0.176996, 0.060854, 0.004934}}],
    Polygon[{{0.178652, 0.062244, 0.005935},{0.179462, 0.061655, 0.006791},{
      0.178762, 0.060280, 0.006791},{0.177809, 0.060589, 0.005935}}],
    Polygon[{{0.179462, 0.061655, 0.006791},{0.180371, 0.060995, 0.007479},{
      0.179830, 0.059933, 0.007479},{0.178762, 0.060280, 0.006791}}],
    Polygon[{{0.180371, 0.060995, 0.007479},{0.181355, 0.060280, 0.007983},{
      0.180987, 0.059557, 0.007983},{0.179830, 0.059933, 0.007479}}],
    Polygon[{{0.181355, 0.060280, 0.007983},{0.182392, 0.059527, 0.008290},{
      0.182205, 0.059161, 0.008290},{0.180987, 0.059557, 0.007983}}],
    Polygon[{{0.182205, 0.059161, -0.008290},{0.180987, 0.059557, -0.007983},{
      0.180860, 0.058755, -0.007983},{0.182141, 0.058755, -0.008290}}],
    Polygon[{{0.180987, 0.059557, -0.007983},{0.179830, 0.059933, -0.007479},{
      0.179643, 0.058755, -0.007479},{0.180860, 0.058755, -0.007983}}],
    Polygon[{{0.179830, 0.059933, -0.007479},{0.178762, 0.060280, -0.006791},{
      0.178520, 0.058755, -0.006791},{0.179643, 0.058755, -0.007479}}],
    Polygon[{{0.178762, 0.060280, -0.006791},{0.177809, 0.060589, -0.005935},{
      0.177519, 0.058755, -0.005935},{0.178520, 0.058755, -0.006791}}],
    Polygon[{{0.177809, 0.060589, -0.005935},{0.176996, 0.060854, -0.004934},{
      0.176663, 0.058755, -0.004934},{0.177519, 0.058755, -0.005935}}],
    Polygon[{{0.176996, 0.060854, -0.004934},{0.176341, 0.061066, -0.003811},{
      0.175975, 0.058755, -0.003811},{0.176663, 0.058755, -0.004934}}],
    Polygon[{{0.176341, 0.061066, -0.003811},{0.175862, 0.061222, -0.002594},{
      0.175471, 0.058755, -0.002594},{0.175975, 0.058755, -0.003811}}],
    Polygon[{{0.175862, 0.061222, -0.002594},{0.175569, 0.061317, -0.001313},{
      0.175164, 0.058755, -0.001313},{0.175471, 0.058755, -0.002594}}],
    Polygon[{{0.175569, 0.061317, -0.001313},{0.175471, 0.061349, 0.000000},{
      0.175060, 0.058755, 0.000000},{0.175164, 0.058755, -0.001313}}],
    Polygon[{{0.175471, 0.061349, 0.000000},{0.175569, 0.061317, 0.001313},{
      0.175164, 0.058755, 0.001313},{0.175060, 0.058755, 0.000000}}],
    Polygon[{{0.175569, 0.061317, 0.001313},{0.175862, 0.061222, 0.002594},{
      0.175471, 0.058755, 0.002594},{0.175164, 0.058755, 0.001313}}],
    Polygon[{{0.175862, 0.061222, 0.002594},{0.176341, 0.061066, 0.003811},{
      0.175975, 0.058755, 0.003811},{0.175471, 0.058755, 0.002594}}],
    Polygon[{{0.176341, 0.061066, 0.003811},{0.176996, 0.060854, 0.004934},{
      0.176663, 0.058755, 0.004934},{0.175975, 0.058755, 0.003811}}],
    Polygon[{{0.176996, 0.060854, 0.004934},{0.177809, 0.060589, 0.005935},{
      0.177519, 0.058755, 0.005935},{0.176663, 0.058755, 0.004934}}],
    Polygon[{{0.177809, 0.060589, 0.005935},{0.178762, 0.060280, 0.006791},{
      0.178520, 0.058755, 0.006791},{0.177519, 0.058755, 0.005935}}],
    Polygon[{{0.178762, 0.060280, 0.006791},{0.179830, 0.059933, 0.007479},{
      0.179643, 0.058755, 0.007479},{0.178520, 0.058755, 0.006791}}],
    Polygon[{{0.179830, 0.059933, 0.007479},{0.180987, 0.059557, 0.007983},{
      0.180860, 0.058755, 0.007983},{0.179643, 0.058755, 0.007479}}],
    Polygon[{{0.180987, 0.059557, 0.007983},{0.182205, 0.059161, 0.008290},{
      0.182141, 0.058755, 0.008290},{0.180860, 0.058755, 0.007983}}],
    Polygon[{{0.182141, 0.058755, -0.008290},{0.180860, 0.058755, -0.007983},{
      0.180987, 0.057954, -0.007983},{0.182205, 0.058349, -0.008290}}],
    Polygon[{{0.180860, 0.058755, -0.007983},{0.179643, 0.058755, -0.007479},{
      0.179830, 0.057578, -0.007479},{0.180987, 0.057954, -0.007983}}],
    Polygon[{{0.179643, 0.058755, -0.007479},{0.178520, 0.058755, -0.006791},{
      0.178762, 0.057231, -0.006791},{0.179830, 0.057578, -0.007479}}],
    Polygon[{{0.178520, 0.058755, -0.006791},{0.177519, 0.058755, -0.005935},{
      0.177809, 0.056921, -0.005935},{0.178762, 0.057231, -0.006791}}],
    Polygon[{{0.177519, 0.058755, -0.005935},{0.176663, 0.058755, -0.004934},{
      0.176996, 0.056657, -0.004934},{0.177809, 0.056921, -0.005935}}],
    Polygon[{{0.176663, 0.058755, -0.004934},{0.175975, 0.058755, -0.003811},{
      0.176341, 0.056444, -0.003811},{0.176996, 0.056657, -0.004934}}],
    Polygon[{{0.175975, 0.058755, -0.003811},{0.175471, 0.058755, -0.002594},{
      0.175862, 0.056288, -0.002594},{0.176341, 0.056444, -0.003811}}],
    Polygon[{{0.175471, 0.058755, -0.002594},{0.175164, 0.058755, -0.001313},{
      0.175569, 0.056193, -0.001313},{0.175862, 0.056288, -0.002594}}],
    Polygon[{{0.175164, 0.058755, -0.001313},{0.175060, 0.058755, 0.000000},{
      0.175471, 0.056161, 0.000000},{0.175569, 0.056193, -0.001313}}],
    Polygon[{{0.175060, 0.058755, 0.000000},{0.175164, 0.058755, 0.001313},{
      0.175569, 0.056193, 0.001313},{0.175471, 0.056161, 0.000000}}],
    Polygon[{{0.175164, 0.058755, 0.001313},{0.175471, 0.058755, 0.002594},{
      0.175862, 0.056288, 0.002594},{0.175569, 0.056193, 0.001313}}],
    Polygon[{{0.175471, 0.058755, 0.002594},{0.175975, 0.058755, 0.003811},{
      0.176341, 0.056444, 0.003811},{0.175862, 0.056288, 0.002594}}],
    Polygon[{{0.175975, 0.058755, 0.003811},{0.176663, 0.058755, 0.004934},{
      0.176996, 0.056657, 0.004934},{0.176341, 0.056444, 0.003811}}],
    Polygon[{{0.176663, 0.058755, 0.004934},{0.177519, 0.058755, 0.005935},{
      0.177809, 0.056921, 0.005935},{0.176996, 0.056657, 0.004934}}],
    Polygon[{{0.177519, 0.058755, 0.005935},{0.178520, 0.058755, 0.006791},{
      0.178762, 0.057231, 0.006791},{0.177809, 0.056921, 0.005935}}],
    Polygon[{{0.178520, 0.058755, 0.006791},{0.179643, 0.058755, 0.007479},{
      0.179830, 0.057578, 0.007479},{0.178762, 0.057231, 0.006791}}],
    Polygon[{{0.179643, 0.058755, 0.007479},{0.180860, 0.058755, 0.007983},{
      0.180987, 0.057954, 0.007983},{0.179830, 0.057578, 0.007479}}],
    Polygon[{{0.180860, 0.058755, 0.007983},{0.182141, 0.058755, 0.008290},{
      0.182205, 0.058349, 0.008290},{0.180987, 0.057954, 0.007983}}],
    Polygon[{{0.182205, 0.058349, -0.008290},{0.180987, 0.057954, -0.007983},{
      0.181355, 0.057231, -0.007983},{0.182392, 0.057983, -0.008290}}],
    Polygon[{{0.180987, 0.057954, -0.007983},{0.179830, 0.057578, -0.007479},{
      0.180371, 0.056515, -0.007479},{0.181355, 0.057231, -0.007983}}],
    Polygon[{{0.179830, 0.057578, -0.007479},{0.178762, 0.057231, -0.006791},{
      0.179462, 0.055855, -0.006791},{0.180371, 0.056515, -0.007479}}],
    Polygon[{{0.178762, 0.057231, -0.006791},{0.177809, 0.056921, -0.005935},{
      0.178652, 0.055267, -0.005935},{0.179462, 0.055855, -0.006791}}],
    Polygon[{{0.177809, 0.056921, -0.005935},{0.176996, 0.056657, -0.004934},{
      0.177960, 0.054764, -0.004934},{0.178652, 0.055267, -0.005935}}],
    Polygon[{{0.176996, 0.056657, -0.004934},{0.176341, 0.056444, -0.003811},{
      0.177403, 0.054359, -0.003811},{0.177960, 0.054764, -0.004934}}],
    Polygon[{{0.176341, 0.056444, -0.003811},{0.175862, 0.056288, -0.002594},{
      0.176996, 0.054063, -0.002594},{0.177403, 0.054359, -0.003811}}],
    Polygon[{{0.175862, 0.056288, -0.002594},{0.175569, 0.056193, -0.001313},{
      0.176747, 0.053882, -0.001313},{0.176996, 0.054063, -0.002594}}],
    Polygon[{{0.175569, 0.056193, -0.001313},{0.175471, 0.056161, 0.000000},{
      0.176663, 0.053822, 0.000000},{0.176747, 0.053882, -0.001313}}],
    Polygon[{{0.175471, 0.056161, 0.000000},{0.175569, 0.056193, 0.001313},{
      0.176747, 0.053882, 0.001313},{0.176663, 0.053822, 0.000000}}],
    Polygon[{{0.175569, 0.056193, 0.001313},{0.175862, 0.056288, 0.002594},{
      0.176996, 0.054063, 0.002594},{0.176747, 0.053882, 0.001313}}],
    Polygon[{{0.175862, 0.056288, 0.002594},{0.176341, 0.056444, 0.003811},{
      0.177403, 0.054359, 0.003811},{0.176996, 0.054063, 0.002594}}],
    Polygon[{{0.176341, 0.056444, 0.003811},{0.176996, 0.056657, 0.004934},{
      0.177960, 0.054764, 0.004934},{0.177403, 0.054359, 0.003811}}],
    Polygon[{{0.176996, 0.056657, 0.004934},{0.177809, 0.056921, 0.005935},{
      0.178652, 0.055267, 0.005935},{0.177960, 0.054764, 0.004934}}],
    Polygon[{{0.177809, 0.056921, 0.005935},{0.178762, 0.057231, 0.006791},{
      0.179462, 0.055855, 0.006791},{0.178652, 0.055267, 0.005935}}],
    Polygon[{{0.178762, 0.057231, 0.006791},{0.179830, 0.057578, 0.007479},{
      0.180371, 0.056515, 0.007479},{0.179462, 0.055855, 0.006791}}],
    Polygon[{{0.179830, 0.057578, 0.007479},{0.180987, 0.057954, 0.007983},{
      0.181355, 0.057231, 0.007983},{0.180371, 0.056515, 0.007479}}],
    Polygon[{{0.180987, 0.057954, 0.007983},{0.182205, 0.058349, 0.008290},{
      0.182392, 0.057983, 0.008290},{0.181355, 0.057231, 0.007983}}],
    Polygon[{{0.182392, 0.057983, -0.008290},{0.181355, 0.057231, -0.007983},{
      0.181929, 0.056657, -0.007983},{0.182682, 0.057693, -0.008290}}],
    Polygon[{{0.181355, 0.057231, -0.007983},{0.180371, 0.056515, -0.007479},{
      0.181214, 0.055672, -0.007479},{0.181929, 0.056657, -0.007983}}],
    Polygon[{{0.180371, 0.056515, -0.007479},{0.179462, 0.055855, -0.006791},{
      0.180554, 0.054764, -0.006791},{0.181214, 0.055672, -0.007479}}],
    Polygon[{{0.179462, 0.055855, -0.006791},{0.178652, 0.055267, -0.005935},{
      0.179965, 0.053954, -0.005935},{0.180554, 0.054764, -0.006791}}],
    Polygon[{{0.178652, 0.055267, -0.005935},{0.177960, 0.054764, -0.004934},{
      0.179462, 0.053261, -0.004934},{0.179965, 0.053954, -0.005935}}],
    Polygon[{{0.177960, 0.054764, -0.004934},{0.177403, 0.054359, -0.003811},{
      0.179058, 0.052705, -0.003811},{0.179462, 0.053261, -0.004934}}],
    Polygon[{{0.177403, 0.054359, -0.003811},{0.176996, 0.054063, -0.002594},{
      0.178762, 0.052297, -0.002594},{0.179058, 0.052705, -0.003811}}],
    Polygon[{{0.176996, 0.054063, -0.002594},{0.176747, 0.053882, -0.001313},{
      0.178581, 0.052048, -0.001313},{0.178762, 0.052297, -0.002594}}],
    Polygon[{{0.176747, 0.053882, -0.001313},{0.176663, 0.053822, 0.000000},{
      0.178520, 0.051965, 0.000000},{0.178581, 0.052048, -0.001313}}],
    Polygon[{{0.176663, 0.053822, 0.000000},{0.176747, 0.053882, 0.001313},{
      0.178581, 0.052048, 0.001313},{0.178520, 0.051965, 0.000000}}],
    Polygon[{{0.176747, 0.053882, 0.001313},{0.176996, 0.054063, 0.002594},{
      0.178762, 0.052297, 0.002594},{0.178581, 0.052048, 0.001313}}],
    Polygon[{{0.176996, 0.054063, 0.002594},{0.177403, 0.054359, 0.003811},{
      0.179058, 0.052705, 0.003811},{0.178762, 0.052297, 0.002594}}],
    Polygon[{{0.177403, 0.054359, 0.003811},{0.177960, 0.054764, 0.004934},{
      0.179462, 0.053261, 0.004934},{0.179058, 0.052705, 0.003811}}],
    Polygon[{{0.177960, 0.054764, 0.004934},{0.178652, 0.055267, 0.005935},{
      0.179965, 0.053954, 0.005935},{0.179462, 0.053261, 0.004934}}],
    Polygon[{{0.178652, 0.055267, 0.005935},{0.179462, 0.055855, 0.006791},{
      0.180554, 0.054764, 0.006791},{0.179965, 0.053954, 0.005935}}],
    Polygon[{{0.179462, 0.055855, 0.006791},{0.180371, 0.056515, 0.007479},{
      0.181214, 0.055672, 0.007479},{0.180554, 0.054764, 0.006791}}],
    Polygon[{{0.180371, 0.056515, 0.007479},{0.181355, 0.057231, 0.007983},{
      0.181929, 0.056657, 0.007983},{0.181214, 0.055672, 0.007479}}],
    Polygon[{{0.181355, 0.057231, 0.007983},{0.182392, 0.057983, 0.008290},{
      0.182682, 0.057693, 0.008290},{0.181929, 0.056657, 0.007983}}],
    Polygon[{{0.182682, 0.057693, -0.008290},{0.181929, 0.056657, -0.007983},{
      0.182652, 0.056288, -0.007983},{0.183048, 0.057506, -0.008290}}],
    Polygon[{{0.181929, 0.056657, -0.007983},{0.181214, 0.055672, -0.007479},{
      0.182276, 0.055131, -0.007479},{0.182652, 0.056288, -0.007983}}],
    Polygon[{{0.181214, 0.055672, -0.007479},{0.180554, 0.054764, -0.006791},{
      0.181929, 0.054063, -0.006791},{0.182276, 0.055131, -0.007479}}],
    Polygon[{{0.180554, 0.054764, -0.006791},{0.179965, 0.053954, -0.005935},{
      0.181620, 0.053110, -0.005935},{0.181929, 0.054063, -0.006791}}],
    Polygon[{{0.179965, 0.053954, -0.005935},{0.179462, 0.053261, -0.004934},{
      0.181355, 0.052297, -0.004934},{0.181620, 0.053110, -0.005935}}],
    Polygon[{{0.179462, 0.053261, -0.004934},{0.179058, 0.052705, -0.003811},{
      0.181143, 0.051642, -0.003811},{0.181355, 0.052297, -0.004934}}],
    Polygon[{{0.179058, 0.052705, -0.003811},{0.178762, 0.052297, -0.002594},{
      0.180987, 0.051163, -0.002594},{0.181143, 0.051642, -0.003811}}],
    Polygon[{{0.178762, 0.052297, -0.002594},{0.178581, 0.052048, -0.001313},{
      0.180892, 0.050871, -0.001313},{0.180987, 0.051163, -0.002594}}],
    Polygon[{{0.178581, 0.052048, -0.001313},{0.178520, 0.051965, 0.000000},{
      0.180860, 0.050772, 0.000000},{0.180892, 0.050871, -0.001313}}],
    Polygon[{{0.178520, 0.051965, 0.000000},{0.178581, 0.052048, 0.001313},{
      0.180892, 0.050871, 0.001313},{0.180860, 0.050772, 0.000000}}],
    Polygon[{{0.178581, 0.052048, 0.001313},{0.178762, 0.052297, 0.002594},{
      0.180987, 0.051163, 0.002594},{0.180892, 0.050871, 0.001313}}],
    Polygon[{{0.178762, 0.052297, 0.002594},{0.179058, 0.052705, 0.003811},{
      0.181143, 0.051642, 0.003811},{0.180987, 0.051163, 0.002594}}],
    Polygon[{{0.179058, 0.052705, 0.003811},{0.179462, 0.053261, 0.004934},{
      0.181355, 0.052297, 0.004934},{0.181143, 0.051642, 0.003811}}],
    Polygon[{{0.179462, 0.053261, 0.004934},{0.179965, 0.053954, 0.005935},{
      0.181620, 0.053110, 0.005935},{0.181355, 0.052297, 0.004934}}],
    Polygon[{{0.179965, 0.053954, 0.005935},{0.180554, 0.054764, 0.006791},{
      0.181929, 0.054063, 0.006791},{0.181620, 0.053110, 0.005935}}],
    Polygon[{{0.180554, 0.054764, 0.006791},{0.181214, 0.055672, 0.007479},{
      0.182276, 0.055131, 0.007479},{0.181929, 0.054063, 0.006791}}],
    Polygon[{{0.181214, 0.055672, 0.007479},{0.181929, 0.056657, 0.007983},{
      0.182652, 0.056288, 0.007983},{0.182276, 0.055131, 0.007479}}],
    Polygon[{{0.181929, 0.056657, 0.007983},{0.182682, 0.057693, 0.008290},{
      0.183048, 0.057506, 0.008290},{0.182652, 0.056288, 0.007983}}],
    Polygon[{{0.183048, 0.057506, -0.008290},{0.182652, 0.056288, -0.007983},{
      0.183454, 0.056161, -0.007983},{0.183454, 0.057442, -0.008290}}],
    Polygon[{{0.182652, 0.056288, -0.007983},{0.182276, 0.055131, -0.007479},{
      0.183454, 0.054945, -0.007479},{0.183454, 0.056161, -0.007983}}],
    Polygon[{{0.182276, 0.055131, -0.007479},{0.181929, 0.054063, -0.006791},{
      0.183454, 0.053822, -0.006791},{0.183454, 0.054945, -0.007479}}],
    Polygon[{{0.181929, 0.054063, -0.006791},{0.181620, 0.053110, -0.005935},{
      0.183454, 0.052820, -0.005935},{0.183454, 0.053822, -0.006791}}],
    Polygon[{{0.181620, 0.053110, -0.005935},{0.181355, 0.052297, -0.004934},{
      0.183454, 0.051965, -0.004934},{0.183454, 0.052820, -0.005935}}],
    Polygon[{{0.181355, 0.052297, -0.004934},{0.181143, 0.051642, -0.003811},{
      0.183454, 0.051276, -0.003811},{0.183454, 0.051965, -0.004934}}],
    Polygon[{{0.181143, 0.051642, -0.003811},{0.180987, 0.051163, -0.002594},{
      0.183454, 0.050772, -0.002594},{0.183454, 0.051276, -0.003811}}],
    Polygon[{{0.180987, 0.051163, -0.002594},{0.180892, 0.050871, -0.001313},{
      0.183454, 0.050465, -0.001313},{0.183454, 0.050772, -0.002594}}],
    Polygon[{{0.180892, 0.050871, -0.001313},{0.180860, 0.050772, 0.000000},{
      0.183454, 0.050362, 0.000000},{0.183454, 0.050465, -0.001313}}],
    Polygon[{{0.180860, 0.050772, 0.000000},{0.180892, 0.050871, 0.001313},{
      0.183454, 0.050465, 0.001313},{0.183454, 0.050362, 0.000000}}],
    Polygon[{{0.180892, 0.050871, 0.001313},{0.180987, 0.051163, 0.002594},{
      0.183454, 0.050772, 0.002594},{0.183454, 0.050465, 0.001313}}],
    Polygon[{{0.180987, 0.051163, 0.002594},{0.181143, 0.051642, 0.003811},{
      0.183454, 0.051276, 0.003811},{0.183454, 0.050772, 0.002594}}],
    Polygon[{{0.181143, 0.051642, 0.003811},{0.181355, 0.052297, 0.004934},{
      0.183454, 0.051965, 0.004934},{0.183454, 0.051276, 0.003811}}],
    Polygon[{{0.181355, 0.052297, 0.004934},{0.181620, 0.053110, 0.005935},{
      0.183454, 0.052820, 0.005935},{0.183454, 0.051965, 0.004934}}],
    Polygon[{{0.181620, 0.053110, 0.005935},{0.181929, 0.054063, 0.006791},{
      0.183454, 0.053822, 0.006791},{0.183454, 0.052820, 0.005935}}],
    Polygon[{{0.181929, 0.054063, 0.006791},{0.182276, 0.055131, 0.007479},{
      0.183454, 0.054945, 0.007479},{0.183454, 0.053822, 0.006791}}],
    Polygon[{{0.182276, 0.055131, 0.007479},{0.182652, 0.056288, 0.007983},{
      0.183454, 0.056161, 0.007983},{0.183454, 0.054945, 0.007479}}],
    Polygon[{{0.182652, 0.056288, 0.007983},{0.183048, 0.057506, 0.008290},{
      0.183454, 0.057442, 0.008290},{0.183454, 0.056161, 0.007983}}],
    Polygon[{{0.183454, 0.057442, -0.008290},{0.183454, 0.056161, -0.007983},{
      0.184255, 0.056288, -0.007983},{0.183860, 0.057506, -0.008290}}],
    Polygon[{{0.183454, 0.056161, -0.007983},{0.183454, 0.054945, -0.007479},{
      0.184631, 0.055131, -0.007479},{0.184255, 0.056288, -0.007983}}],
    Polygon[{{0.183454, 0.054945, -0.007479},{0.183454, 0.053822, -0.006791},{
      0.184978, 0.054063, -0.006791},{0.184631, 0.055131, -0.007479}}],
    Polygon[{{0.183454, 0.053822, -0.006791},{0.183454, 0.052820, -0.005935},{
      0.185288, 0.053110, -0.005935},{0.184978, 0.054063, -0.006791}}],
    Polygon[{{0.183454, 0.052820, -0.005935},{0.183454, 0.051965, -0.004934},{
      0.185552, 0.052297, -0.004934},{0.185288, 0.053110, -0.005935}}],
    Polygon[{{0.183454, 0.051965, -0.004934},{0.183454, 0.051276, -0.003811},{
      0.185765, 0.051642, -0.003811},{0.185552, 0.052297, -0.004934}}],
    Polygon[{{0.183454, 0.051276, -0.003811},{0.183454, 0.050772, -0.002594},{
      0.185921, 0.051163, -0.002594},{0.185765, 0.051642, -0.003811}}],
    Polygon[{{0.183454, 0.050772, -0.002594},{0.183454, 0.050465, -0.001313},{
      0.186016, 0.050871, -0.001313},{0.185921, 0.051163, -0.002594}}],
    Polygon[{{0.183454, 0.050465, -0.001313},{0.183454, 0.050362, 0.000000},{
      0.186048, 0.050772, 0.000000},{0.186016, 0.050871, -0.001313}}],
    Polygon[{{0.183454, 0.050362, 0.000000},{0.183454, 0.050465, 0.001313},{
      0.186016, 0.050871, 0.001313},{0.186048, 0.050772, 0.000000}}],
    Polygon[{{0.183454, 0.050465, 0.001313},{0.183454, 0.050772, 0.002594},{
      0.185921, 0.051163, 0.002594},{0.186016, 0.050871, 0.001313}}],
    Polygon[{{0.183454, 0.050772, 0.002594},{0.183454, 0.051276, 0.003811},{
      0.185765, 0.051642, 0.003811},{0.185921, 0.051163, 0.002594}}],
    Polygon[{{0.183454, 0.051276, 0.003811},{0.183454, 0.051965, 0.004934},{
      0.185552, 0.052297, 0.004934},{0.185765, 0.051642, 0.003811}}],
    Polygon[{{0.183454, 0.051965, 0.004934},{0.183454, 0.052820, 0.005935},{
      0.185288, 0.053110, 0.005935},{0.185552, 0.052297, 0.004934}}],
    Polygon[{{0.183454, 0.052820, 0.005935},{0.183454, 0.053822, 0.006791},{
      0.184978, 0.054063, 0.006791},{0.185288, 0.053110, 0.005935}}],
    Polygon[{{0.183454, 0.053822, 0.006791},{0.183454, 0.054945, 0.007479},{
      0.184631, 0.055131, 0.007479},{0.184978, 0.054063, 0.006791}}],
    Polygon[{{0.183454, 0.054945, 0.007479},{0.183454, 0.056161, 0.007983},{
      0.184255, 0.056288, 0.007983},{0.184631, 0.055131, 0.007479}}],
    Polygon[{{0.183454, 0.056161, 0.007983},{0.183454, 0.057442, 0.008290},{
      0.183860, 0.057506, 0.008290},{0.184255, 0.056288, 0.007983}}],
    Polygon[{{0.183860, 0.057506, -0.008290},{0.184255, 0.056288, -0.007983},{
      0.184978, 0.056657, -0.007983},{0.184226, 0.057693, -0.008290}}],
    Polygon[{{0.184255, 0.056288, -0.007983},{0.184631, 0.055131, -0.007479},{
      0.185694, 0.055672, -0.007479},{0.184978, 0.056657, -0.007983}}],
    Polygon[{{0.184631, 0.055131, -0.007479},{0.184978, 0.054063, -0.006791},{
      0.186354, 0.054764, -0.006791},{0.185694, 0.055672, -0.007479}}],
    Polygon[{{0.184978, 0.054063, -0.006791},{0.185288, 0.053110, -0.005935},{
      0.186942, 0.053954, -0.005935},{0.186354, 0.054764, -0.006791}}],
    Polygon[{{0.185288, 0.053110, -0.005935},{0.185552, 0.052297, -0.004934},{
      0.187445, 0.053261, -0.004934},{0.186942, 0.053954, -0.005935}}],
    Polygon[{{0.185552, 0.052297, -0.004934},{0.185765, 0.051642, -0.003811},{
      0.187850, 0.052705, -0.003811},{0.187445, 0.053261, -0.004934}}],
    Polygon[{{0.185765, 0.051642, -0.003811},{0.185921, 0.051163, -0.002594},{
      0.188146, 0.052297, -0.002594},{0.187850, 0.052705, -0.003811}}],
    Polygon[{{0.185921, 0.051163, -0.002594},{0.186016, 0.050871, -0.001313},{
      0.188327, 0.052048, -0.001313},{0.188146, 0.052297, -0.002594}}],
    Polygon[{{0.186016, 0.050871, -0.001313},{0.186048, 0.050772, 0.000000},{
      0.188387, 0.051965, 0.000000},{0.188327, 0.052048, -0.001313}}],
    Polygon[{{0.186048, 0.050772, 0.000000},{0.186016, 0.050871, 0.001313},{
      0.188327, 0.052048, 0.001313},{0.188387, 0.051965, 0.000000}}],
    Polygon[{{0.186016, 0.050871, 0.001313},{0.185921, 0.051163, 0.002594},{
      0.188146, 0.052297, 0.002594},{0.188327, 0.052048, 0.001313}}],
    Polygon[{{0.185921, 0.051163, 0.002594},{0.185765, 0.051642, 0.003811},{
      0.187850, 0.052705, 0.003811},{0.188146, 0.052297, 0.002594}}],
    Polygon[{{0.185765, 0.051642, 0.003811},{0.185552, 0.052297, 0.004934},{
      0.187445, 0.053261, 0.004934},{0.187850, 0.052705, 0.003811}}],
    Polygon[{{0.185552, 0.052297, 0.004934},{0.185288, 0.053110, 0.005935},{
      0.186942, 0.053954, 0.005935},{0.187445, 0.053261, 0.004934}}],
    Polygon[{{0.185288, 0.053110, 0.005935},{0.184978, 0.054063, 0.006791},{
      0.186354, 0.054764, 0.006791},{0.186942, 0.053954, 0.005935}}],
    Polygon[{{0.184978, 0.054063, 0.006791},{0.184631, 0.055131, 0.007479},{
      0.185694, 0.055672, 0.007479},{0.186354, 0.054764, 0.006791}}],
    Polygon[{{0.184631, 0.055131, 0.007479},{0.184255, 0.056288, 0.007983},{
      0.184978, 0.056657, 0.007983},{0.185694, 0.055672, 0.007479}}],
    Polygon[{{0.184255, 0.056288, 0.007983},{0.183860, 0.057506, 0.008290},{
      0.184226, 0.057693, 0.008290},{0.184978, 0.056657, 0.007983}}],
    Polygon[{{0.184226, 0.057693, -0.008290},{0.184978, 0.056657, -0.007983},{
      0.185552, 0.057231, -0.007983},{0.184516, 0.057983, -0.008290}}],
    Polygon[{{0.184978, 0.056657, -0.007983},{0.185694, 0.055672, -0.007479},{
      0.186537, 0.056515, -0.007479},{0.185552, 0.057231, -0.007983}}],
    Polygon[{{0.185694, 0.055672, -0.007479},{0.186354, 0.054764, -0.006791},{
      0.187445, 0.055855, -0.006791},{0.186537, 0.056515, -0.007479}}],
    Polygon[{{0.186354, 0.054764, -0.006791},{0.186942, 0.053954, -0.005935},{
      0.188256, 0.055267, -0.005935},{0.187445, 0.055855, -0.006791}}],
    Polygon[{{0.186942, 0.053954, -0.005935},{0.187445, 0.053261, -0.004934},{
      0.188948, 0.054764, -0.004934},{0.188256, 0.055267, -0.005935}}],
    Polygon[{{0.187445, 0.053261, -0.004934},{0.187850, 0.052705, -0.003811},{
      0.189504, 0.054359, -0.003811},{0.188948, 0.054764, -0.004934}}],
    Polygon[{{0.187850, 0.052705, -0.003811},{0.188146, 0.052297, -0.002594},{
      0.189912, 0.054063, -0.002594},{0.189504, 0.054359, -0.003811}}],
    Polygon[{{0.188146, 0.052297, -0.002594},{0.188327, 0.052048, -0.001313},{
      0.190161, 0.053882, -0.001313},{0.189912, 0.054063, -0.002594}}],
    Polygon[{{0.188327, 0.052048, -0.001313},{0.188387, 0.051965, 0.000000},{
      0.190244, 0.053822, 0.000000},{0.190161, 0.053882, -0.001313}}],
    Polygon[{{0.188387, 0.051965, 0.000000},{0.188327, 0.052048, 0.001313},{
      0.190161, 0.053882, 0.001313},{0.190244, 0.053822, 0.000000}}],
    Polygon[{{0.188327, 0.052048, 0.001313},{0.188146, 0.052297, 0.002594},{
      0.189912, 0.054063, 0.002594},{0.190161, 0.053882, 0.001313}}],
    Polygon[{{0.188146, 0.052297, 0.002594},{0.187850, 0.052705, 0.003811},{
      0.189504, 0.054359, 0.003811},{0.189912, 0.054063, 0.002594}}],
    Polygon[{{0.187850, 0.052705, 0.003811},{0.187445, 0.053261, 0.004934},{
      0.188948, 0.054764, 0.004934},{0.189504, 0.054359, 0.003811}}],
    Polygon[{{0.187445, 0.053261, 0.004934},{0.186942, 0.053954, 0.005935},{
      0.188256, 0.055267, 0.005935},{0.188948, 0.054764, 0.004934}}],
    Polygon[{{0.186942, 0.053954, 0.005935},{0.186354, 0.054764, 0.006791},{
      0.187445, 0.055855, 0.006791},{0.188256, 0.055267, 0.005935}}],
    Polygon[{{0.186354, 0.054764, 0.006791},{0.185694, 0.055672, 0.007479},{
      0.186537, 0.056515, 0.007479},{0.187445, 0.055855, 0.006791}}],
    Polygon[{{0.185694, 0.055672, 0.007479},{0.184978, 0.056657, 0.007983},{
      0.185552, 0.057231, 0.007983},{0.186537, 0.056515, 0.007479}}],
    Polygon[{{0.184978, 0.056657, 0.007983},{0.184226, 0.057693, 0.008290},{
      0.184516, 0.057983, 0.008290},{0.185552, 0.057231, 0.007983}}],
    Polygon[{{0.184516, 0.057983, -0.008290},{0.185552, 0.057231, -0.007983},{
      0.185921, 0.057954, -0.007983},{0.184703, 0.058349, -0.008290}}],
    Polygon[{{0.185552, 0.057231, -0.007983},{0.186537, 0.056515, -0.007479},{
      0.187078, 0.057578, -0.007479},{0.185921, 0.057954, -0.007983}}],
    Polygon[{{0.186537, 0.056515, -0.007479},{0.187445, 0.055855, -0.006791},{
      0.188146, 0.057231, -0.006791},{0.187078, 0.057578, -0.007479}}],
    Polygon[{{0.187445, 0.055855, -0.006791},{0.188256, 0.055267, -0.005935},{
      0.189099, 0.056921, -0.005935},{0.188146, 0.057231, -0.006791}}],
    Polygon[{{0.188256, 0.055267, -0.005935},{0.188948, 0.054764, -0.004934},{
      0.189912, 0.056657, -0.004934},{0.189099, 0.056921, -0.005935}}],
    Polygon[{{0.188948, 0.054764, -0.004934},{0.189504, 0.054359, -0.003811},{
      0.190567, 0.056444, -0.003811},{0.189912, 0.056657, -0.004934}}],
    Polygon[{{0.189504, 0.054359, -0.003811},{0.189912, 0.054063, -0.002594},{
      0.191046, 0.056288, -0.002594},{0.190567, 0.056444, -0.003811}}],
    Polygon[{{0.189912, 0.054063, -0.002594},{0.190161, 0.053882, -0.001313},{
      0.191338, 0.056193, -0.001313},{0.191046, 0.056288, -0.002594}}],
    Polygon[{{0.190161, 0.053882, -0.001313},{0.190244, 0.053822, 0.000000},{
      0.191437, 0.056161, 0.000000},{0.191338, 0.056193, -0.001313}}],
    Polygon[{{0.190244, 0.053822, 0.000000},{0.190161, 0.053882, 0.001313},{
      0.191338, 0.056193, 0.001313},{0.191437, 0.056161, 0.000000}}],
    Polygon[{{0.190161, 0.053882, 0.001313},{0.189912, 0.054063, 0.002594},{
      0.191046, 0.056288, 0.002594},{0.191338, 0.056193, 0.001313}}],
    Polygon[{{0.189912, 0.054063, 0.002594},{0.189504, 0.054359, 0.003811},{
      0.190567, 0.056444, 0.003811},{0.191046, 0.056288, 0.002594}}],
    Polygon[{{0.189504, 0.054359, 0.003811},{0.188948, 0.054764, 0.004934},{
      0.189912, 0.056657, 0.004934},{0.190567, 0.056444, 0.003811}}],
    Polygon[{{0.188948, 0.054764, 0.004934},{0.188256, 0.055267, 0.005935},{
      0.189099, 0.056921, 0.005935},{0.189912, 0.056657, 0.004934}}],
    Polygon[{{0.188256, 0.055267, 0.005935},{0.187445, 0.055855, 0.006791},{
      0.188146, 0.057231, 0.006791},{0.189099, 0.056921, 0.005935}}],
    Polygon[{{0.187445, 0.055855, 0.006791},{0.186537, 0.056515, 0.007479},{
      0.187078, 0.057578, 0.007479},{0.188146, 0.057231, 0.006791}}],
    Polygon[{{0.186537, 0.056515, 0.007479},{0.185552, 0.057231, 0.007983},{
      0.185921, 0.057954, 0.007983},{0.187078, 0.057578, 0.007479}}],
    Polygon[{{0.185552, 0.057231, 0.007983},{0.184516, 0.057983, 0.008290},{
      0.184703, 0.058349, 0.008290},{0.185921, 0.057954, 0.007983}}],
    Polygon[{{0.184703, 0.058349, -0.008290},{0.185921, 0.057954, -0.007983},{
      0.186048, 0.058755, -0.007983},{0.184767, 0.058755, -0.008290}}],
    Polygon[{{0.185921, 0.057954, -0.007983},{0.187078, 0.057578, -0.007479},{
      0.187264, 0.058755, -0.007479},{0.186048, 0.058755, -0.007983}}],
    Polygon[{{0.187078, 0.057578, -0.007479},{0.188146, 0.057231, -0.006791},{
      0.188387, 0.058755, -0.006791},{0.187264, 0.058755, -0.007479}}],
    Polygon[{{0.188146, 0.057231, -0.006791},{0.189099, 0.056921, -0.005935},{
      0.189389, 0.058755, -0.005935},{0.188387, 0.058755, -0.006791}}],
    Polygon[{{0.189099, 0.056921, -0.005935},{0.189912, 0.056657, -0.004934},{
      0.190244, 0.058755, -0.004934},{0.189389, 0.058755, -0.005935}}],
    Polygon[{{0.189912, 0.056657, -0.004934},{0.190567, 0.056444, -0.003811},{
      0.190933, 0.058755, -0.003811},{0.190244, 0.058755, -0.004934}}],
    Polygon[{{0.190567, 0.056444, -0.003811},{0.191046, 0.056288, -0.002594},{
      0.191437, 0.058755, -0.002594},{0.190933, 0.058755, -0.003811}}],
    Polygon[{{0.191046, 0.056288, -0.002594},{0.191338, 0.056193, -0.001313},{
      0.191744, 0.058755, -0.001313},{0.191437, 0.058755, -0.002594}}],
    Polygon[{{0.191338, 0.056193, -0.001313},{0.191437, 0.056161, 0.000000},{
      0.191847, 0.058755, 0.000000},{0.191744, 0.058755, -0.001313}}],
    Polygon[{{0.191437, 0.056161, 0.000000},{0.191338, 0.056193, 0.001313},{
      0.191744, 0.058755, 0.001313},{0.191847, 0.058755, 0.000000}}],
    Polygon[{{0.191338, 0.056193, 0.001313},{0.191046, 0.056288, 0.002594},{
      0.191437, 0.058755, 0.002594},{0.191744, 0.058755, 0.001313}}],
    Polygon[{{0.191046, 0.056288, 0.002594},{0.190567, 0.056444, 0.003811},{
      0.190933, 0.058755, 0.003811},{0.191437, 0.058755, 0.002594}}],
    Polygon[{{0.190567, 0.056444, 0.003811},{0.189912, 0.056657, 0.004934},{
      0.190244, 0.058755, 0.004934},{0.190933, 0.058755, 0.003811}}],
    Polygon[{{0.189912, 0.056657, 0.004934},{0.189099, 0.056921, 0.005935},{
      0.189389, 0.058755, 0.005935},{0.190244, 0.058755, 0.004934}}],
    Polygon[{{0.189099, 0.056921, 0.005935},{0.188146, 0.057231, 0.006791},{
      0.188387, 0.058755, 0.006791},{0.189389, 0.058755, 0.005935}}],
    Polygon[{{0.188146, 0.057231, 0.006791},{0.187078, 0.057578, 0.007479},{
      0.187264, 0.058755, 0.007479},{0.188387, 0.058755, 0.006791}}],
    Polygon[{{0.187078, 0.057578, 0.007479},{0.185921, 0.057954, 0.007983},{
      0.186048, 0.058755, 0.007983},{0.187264, 0.058755, 0.007479}}],
    Polygon[{{0.185921, 0.057954, 0.007983},{0.184703, 0.058349, 0.008290},{
      0.184767, 0.058755, 0.008290},{0.186048, 0.058755, 0.007983}}],
    Polygon[{{0.122588, 0.153775, -0.025466},{0.126522, 0.153775, -0.024521},{
      0.126132, 0.156237, -0.024521},{0.122390, 0.155021, -0.025466}}],
    Polygon[{{0.126522, 0.153775, -0.024521},{0.130260, 0.153775, -0.022973},{
      0.129687, 0.157392, -0.022973},{0.126132, 0.156237, -0.024521}}],
    Polygon[{{0.130260, 0.153775, -0.022973},{0.133709, 0.153775, -0.020859},{
      0.132968, 0.158458, -0.020859},{0.129687, 0.157392, -0.022973}}],
    Polygon[{{0.133709, 0.153775, -0.020859},{0.136786, 0.153775, -0.018232},{
      0.135893, 0.159409, -0.018232},{0.132968, 0.158458, -0.020859}}],
    Polygon[{{0.136786, 0.153775, -0.018232},{0.139413, 0.153775, -0.015155},{
      0.138392, 0.160221, -0.015155},{0.135893, 0.159409, -0.018232}}],
    Polygon[{{0.139413, 0.153775, -0.015155},{0.141527, 0.153775, -0.011705},{
      0.140403, 0.160874, -0.011705},{0.138392, 0.160221, -0.015155}}],
    Polygon[{{0.141527, 0.153775, -0.011705},{0.143076, 0.153775, -0.007968},{
      0.141875, 0.161353, -0.007968},{0.140403, 0.160874, -0.011705}}],
    Polygon[{{0.143076, 0.153775, -0.007968},{0.144020, 0.153775, -0.004033},{
      0.142774, 0.161644, -0.004033},{0.141875, 0.161353, -0.007968}}],
    Polygon[{{0.144020, 0.153775, -0.004033},{0.144338, 0.153775, 0.000000},{
      0.143076, 0.161742, 0.000000},{0.142774, 0.161644, -0.004033}}],
    Polygon[{{0.144338, 0.153775, 0.000000},{0.144020, 0.153775, 0.004033},{
      0.142774, 0.161644, 0.004033},{0.143076, 0.161742, 0.000000}}],
    Polygon[{{0.144020, 0.153775, 0.004033},{0.143076, 0.153775, 0.007968},{
      0.141875, 0.161353, 0.007968},{0.142774, 0.161644, 0.004033}}],
    Polygon[{{0.143076, 0.153775, 0.007968},{0.141527, 0.153775, 0.011705},{
      0.140403, 0.160874, 0.011705},{0.141875, 0.161353, 0.007968}}],
    Polygon[{{0.141527, 0.153775, 0.011705},{0.139413, 0.153775, 0.015155},{
      0.138392, 0.160221, 0.015155},{0.140403, 0.160874, 0.011705}}],
    Polygon[{{0.139413, 0.153775, 0.015155},{0.136786, 0.153775, 0.018232},{
      0.135893, 0.159409, 0.018232},{0.138392, 0.160221, 0.015155}}],
    Polygon[{{0.136786, 0.153775, 0.018232},{0.133709, 0.153775, 0.020859},{
      0.132968, 0.158458, 0.020859},{0.135893, 0.159409, 0.018232}}],
    Polygon[{{0.133709, 0.153775, 0.020859},{0.130260, 0.153775, 0.022973},{
      0.129687, 0.157392, 0.022973},{0.132968, 0.158458, 0.020859}}],
    Polygon[{{0.130260, 0.153775, 0.022973},{0.126522, 0.153775, 0.024521},{
      0.126132, 0.156237, 0.024521},{0.129687, 0.157392, 0.022973}}],
    Polygon[{{0.126522, 0.153775, 0.024521},{0.122588, 0.153775, 0.025466},{
      0.122390, 0.155021, 0.025466},{0.126132, 0.156237, 0.024521}}],
    Polygon[{{0.122390, 0.155021, -0.025466},{0.126132, 0.156237, -0.024521},{
      0.125000, 0.158458, -0.024521},{0.121817, 0.156146, -0.025466}}],
    Polygon[{{0.126132, 0.156237, -0.024521},{0.129687, 0.157392, -0.022973},{
      0.128024, 0.160655, -0.022973},{0.125000, 0.158458, -0.024521}}],
    Polygon[{{0.129687, 0.157392, -0.022973},{0.132968, 0.158458, -0.020859},{
      0.130815, 0.162683, -0.020859},{0.128024, 0.160655, -0.022973}}],
    Polygon[{{0.132968, 0.158458, -0.020859},{0.135893, 0.159409, -0.018232},{
      0.133304, 0.164491, -0.018232},{0.130815, 0.162683, -0.020859}}],
    Polygon[{{0.135893, 0.159409, -0.018232},{0.138392, 0.160221, -0.015155},{
      0.135430, 0.166036, -0.015155},{0.133304, 0.164491, -0.018232}}],
    Polygon[{{0.138392, 0.160221, -0.015155},{0.140403, 0.160874, -0.011705},{
      0.137140, 0.167278, -0.011705},{0.135430, 0.166036, -0.015155}}],
    Polygon[{{0.140403, 0.160874, -0.011705},{0.141875, 0.161353, -0.007968},{
      0.138392, 0.168188, -0.007968},{0.137140, 0.167278, -0.011705}}],
    Polygon[{{0.141875, 0.161353, -0.007968},{0.142774, 0.161644, -0.004033},{
      0.139157, 0.168743, -0.004033},{0.138392, 0.168188, -0.007968}}],
    Polygon[{{0.142774, 0.161644, -0.004033},{0.143076, 0.161742, 0.000000},{
      0.139413, 0.168930, 0.000000},{0.139157, 0.168743, -0.004033}}],
    Polygon[{{0.143076, 0.161742, 0.000000},{0.142774, 0.161644, 0.004033},{
      0.139157, 0.168743, 0.004033},{0.139413, 0.168930, 0.000000}}],
    Polygon[{{0.142774, 0.161644, 0.004033},{0.141875, 0.161353, 0.007968},{
      0.138392, 0.168188, 0.007968},{0.139157, 0.168743, 0.004033}}],
    Polygon[{{0.141875, 0.161353, 0.007968},{0.140403, 0.160874, 0.011705},{
      0.137140, 0.167278, 0.011705},{0.138392, 0.168188, 0.007968}}],
    Polygon[{{0.140403, 0.160874, 0.011705},{0.138392, 0.160221, 0.015155},{
      0.135430, 0.166036, 0.015155},{0.137140, 0.167278, 0.011705}}],
    Polygon[{{0.138392, 0.160221, 0.015155},{0.135893, 0.159409, 0.018232},{
      0.133304, 0.164491, 0.018232},{0.135430, 0.166036, 0.015155}}],
    Polygon[{{0.135893, 0.159409, 0.018232},{0.132968, 0.158458, 0.020859},{
      0.130815, 0.162683, 0.020859},{0.133304, 0.164491, 0.018232}}],
    Polygon[{{0.132968, 0.158458, 0.020859},{0.129687, 0.157392, 0.022973},{
      0.128024, 0.160655, 0.022973},{0.130815, 0.162683, 0.020859}}],
    Polygon[{{0.129687, 0.157392, 0.022973},{0.126132, 0.156237, 0.024521},{
      0.125000, 0.158458, 0.024521},{0.128024, 0.160655, 0.022973}}],
    Polygon[{{0.126132, 0.156237, 0.024521},{0.122390, 0.155021, 0.025466},{
      0.121817, 0.156146, 0.025466},{0.125000, 0.158458, 0.024521}}],
    Polygon[{{0.121817, 0.156146, -0.025466},{0.125000, 0.158458, -0.024521},{
      0.123237, 0.160221, -0.024521},{0.120925, 0.157038, -0.025466}}],
    Polygon[{{0.125000, 0.158458, -0.024521},{0.128024, 0.160655, -0.022973},{
      0.125434, 0.163245, -0.022973},{0.123237, 0.160221, -0.024521}}],
    Polygon[{{0.128024, 0.160655, -0.022973},{0.130815, 0.162683, -0.020859},{
      0.127462, 0.166036, -0.020859},{0.125434, 0.163245, -0.022973}}],
    Polygon[{{0.130815, 0.162683, -0.020859},{0.133304, 0.164491, -0.018232},{
      0.129270, 0.168525, -0.018232},{0.127462, 0.166036, -0.020859}}],
    Polygon[{{0.133304, 0.164491, -0.018232},{0.135430, 0.166036, -0.015155},{
      0.130815, 0.170650, -0.015155},{0.129270, 0.168525, -0.018232}}],
    Polygon[{{0.135430, 0.166036, -0.015155},{0.137140, 0.167278, -0.011705},{
      0.132057, 0.172361, -0.011705},{0.130815, 0.170650, -0.015155}}],
    Polygon[{{0.137140, 0.167278, -0.011705},{0.138392, 0.168188, -0.007968},{
      0.132968, 0.173613, -0.007968},{0.132057, 0.172361, -0.011705}}],
    Polygon[{{0.138392, 0.168188, -0.007968},{0.139157, 0.168743, -0.004033},{
      0.133523, 0.174377, -0.004033},{0.132968, 0.173613, -0.007968}}],
    Polygon[{{0.139157, 0.168743, -0.004033},{0.139413, 0.168930, 0.000000},{
      0.133709, 0.174634, 0.000000},{0.133523, 0.174377, -0.004033}}],
    Polygon[{{0.139413, 0.168930, 0.000000},{0.139157, 0.168743, 0.004033},{
      0.133523, 0.174377, 0.004033},{0.133709, 0.174634, 0.000000}}],
    Polygon[{{0.139157, 0.168743, 0.004033},{0.138392, 0.168188, 0.007968},{
      0.132968, 0.173613, 0.007968},{0.133523, 0.174377, 0.004033}}],
    Polygon[{{0.138392, 0.168188, 0.007968},{0.137140, 0.167278, 0.011705},{
      0.132057, 0.172361, 0.011705},{0.132968, 0.173613, 0.007968}}],
    Polygon[{{0.137140, 0.167278, 0.011705},{0.135430, 0.166036, 0.015155},{
      0.130815, 0.170650, 0.015155},{0.132057, 0.172361, 0.011705}}],
    Polygon[{{0.135430, 0.166036, 0.015155},{0.133304, 0.164491, 0.018232},{
      0.129270, 0.168525, 0.018232},{0.130815, 0.170650, 0.015155}}],
    Polygon[{{0.133304, 0.164491, 0.018232},{0.130815, 0.162683, 0.020859},{
      0.127462, 0.166036, 0.020859},{0.129270, 0.168525, 0.018232}}],
    Polygon[{{0.130815, 0.162683, 0.020859},{0.128024, 0.160655, 0.022973},{
      0.125434, 0.163245, 0.022973},{0.127462, 0.166036, 0.020859}}],
    Polygon[{{0.128024, 0.160655, 0.022973},{0.125000, 0.158458, 0.024521},{
      0.123237, 0.160221, 0.024521},{0.125434, 0.163245, 0.022973}}],
    Polygon[{{0.125000, 0.158458, 0.024521},{0.121817, 0.156146, 0.025466},{
      0.120925, 0.157038, 0.025466},{0.123237, 0.160221, 0.024521}}],
    Polygon[{{0.120925, 0.157038, -0.025466},{0.123237, 0.160221, -0.024521},{
      0.121016, 0.161353, -0.024521},{0.119801, 0.157611, -0.025466}}],
    Polygon[{{0.123237, 0.160221, -0.024521},{0.125434, 0.163245, -0.022973},{
      0.122171, 0.164907, -0.022973},{0.121016, 0.161353, -0.024521}}],
    Polygon[{{0.125434, 0.163245, -0.022973},{0.127462, 0.166036, -0.020859},{
      0.123237, 0.168188, -0.020859},{0.122171, 0.164907, -0.022973}}],
    Polygon[{{0.127462, 0.166036, -0.020859},{0.129270, 0.168525, -0.018232},{
      0.124188, 0.171114, -0.018232},{0.123237, 0.168188, -0.020859}}],
    Polygon[{{0.129270, 0.168525, -0.018232},{0.130815, 0.170650, -0.015155},{
      0.125000, 0.173613, -0.015155},{0.124188, 0.171114, -0.018232}}],
    Polygon[{{0.130815, 0.170650, -0.015155},{0.132057, 0.172361, -0.011705},{
      0.125653, 0.175624, -0.011705},{0.125000, 0.173613, -0.015155}}],
    Polygon[{{0.132057, 0.172361, -0.011705},{0.132968, 0.173613, -0.007968},{
      0.126132, 0.177096, -0.007968},{0.125653, 0.175624, -0.011705}}],
    Polygon[{{0.132968, 0.173613, -0.007968},{0.133523, 0.174377, -0.004033},{
      0.126424, 0.177995, -0.004033},{0.126132, 0.177096, -0.007968}}],
    Polygon[{{0.133523, 0.174377, -0.004033},{0.133709, 0.174634, 0.000000},{
      0.126522, 0.178296, 0.000000},{0.126424, 0.177995, -0.004033}}],
    Polygon[{{0.133709, 0.174634, 0.000000},{0.133523, 0.174377, 0.004033},{
      0.126424, 0.177995, 0.004033},{0.126522, 0.178296, 0.000000}}],
    Polygon[{{0.133523, 0.174377, 0.004033},{0.132968, 0.173613, 0.007968},{
      0.126132, 0.177096, 0.007968},{0.126424, 0.177995, 0.004033}}],
    Polygon[{{0.132968, 0.173613, 0.007968},{0.132057, 0.172361, 0.011705},{
      0.125653, 0.175624, 0.011705},{0.126132, 0.177096, 0.007968}}],
    Polygon[{{0.132057, 0.172361, 0.011705},{0.130815, 0.170650, 0.015155},{
      0.125000, 0.173613, 0.015155},{0.125653, 0.175624, 0.011705}}],
    Polygon[{{0.130815, 0.170650, 0.015155},{0.129270, 0.168525, 0.018232},{
      0.124188, 0.171114, 0.018232},{0.125000, 0.173613, 0.015155}}],
    Polygon[{{0.129270, 0.168525, 0.018232},{0.127462, 0.166036, 0.020859},{
      0.123237, 0.168188, 0.020859},{0.124188, 0.171114, 0.018232}}],
    Polygon[{{0.127462, 0.166036, 0.020859},{0.125434, 0.163245, 0.022973},{
      0.122171, 0.164907, 0.022973},{0.123237, 0.168188, 0.020859}}],
    Polygon[{{0.125434, 0.163245, 0.022973},{0.123237, 0.160221, 0.024521},{
      0.121016, 0.161353, 0.024521},{0.122171, 0.164907, 0.022973}}],
    Polygon[{{0.123237, 0.160221, 0.024521},{0.120925, 0.157038, 0.025466},{
      0.119801, 0.157611, 0.025466},{0.121016, 0.161353, 0.024521}}],
    Polygon[{{0.119801, 0.157611, -0.025466},{0.121016, 0.161353, -0.024521},{
      0.118554, 0.161742, -0.024521},{0.118554, 0.157808, -0.025466}}],
    Polygon[{{0.121016, 0.161353, -0.024521},{0.122171, 0.164907, -0.022973},{
      0.118554, 0.165480, -0.022973},{0.118554, 0.161742, -0.024521}}],
    Polygon[{{0.122171, 0.164907, -0.022973},{0.123237, 0.168188, -0.020859},{
      0.118554, 0.168930, -0.020859},{0.118554, 0.165480, -0.022973}}],
    Polygon[{{0.123237, 0.168188, -0.020859},{0.124188, 0.171114, -0.018232},{
      0.118554, 0.172007, -0.018232},{0.118554, 0.168930, -0.020859}}],
    Polygon[{{0.124188, 0.171114, -0.018232},{0.125000, 0.173613, -0.015155},{
      0.118554, 0.174634, -0.015155},{0.118554, 0.172007, -0.018232}}],
    Polygon[{{0.125000, 0.173613, -0.015155},{0.125653, 0.175624, -0.011705},{
      0.118554, 0.176748, -0.011705},{0.118554, 0.174634, -0.015155}}],
    Polygon[{{0.125653, 0.175624, -0.011705},{0.126132, 0.177096, -0.007968},{
      0.118554, 0.178296, -0.007968},{0.118554, 0.176748, -0.011705}}],
    Polygon[{{0.126132, 0.177096, -0.007968},{0.126424, 0.177995, -0.004033},{
      0.118554, 0.179241, -0.004033},{0.118554, 0.178296, -0.007968}}],
    Polygon[{{0.126424, 0.177995, -0.004033},{0.126522, 0.178296, 0.000000},{
      0.118554, 0.179558, 0.000000},{0.118554, 0.179241, -0.004033}}],
    Polygon[{{0.126522, 0.178296, 0.000000},{0.126424, 0.177995, 0.004033},{
      0.118554, 0.179241, 0.004033},{0.118554, 0.179558, 0.000000}}],
    Polygon[{{0.126424, 0.177995, 0.004033},{0.126132, 0.177096, 0.007968},{
      0.118554, 0.178296, 0.007968},{0.118554, 0.179241, 0.004033}}],
    Polygon[{{0.126132, 0.177096, 0.007968},{0.125653, 0.175624, 0.011705},{
      0.118554, 0.176748, 0.011705},{0.118554, 0.178296, 0.007968}}],
    Polygon[{{0.125653, 0.175624, 0.011705},{0.125000, 0.173613, 0.015155},{
      0.118554, 0.174634, 0.015155},{0.118554, 0.176748, 0.011705}}],
    Polygon[{{0.125000, 0.173613, 0.015155},{0.124188, 0.171114, 0.018232},{
      0.118554, 0.172007, 0.018232},{0.118554, 0.174634, 0.015155}}],
    Polygon[{{0.124188, 0.171114, 0.018232},{0.123237, 0.168188, 0.020859},{
      0.118554, 0.168930, 0.020859},{0.118554, 0.172007, 0.018232}}],
    Polygon[{{0.123237, 0.168188, 0.020859},{0.122171, 0.164907, 0.022973},{
      0.118554, 0.165480, 0.022973},{0.118554, 0.168930, 0.020859}}],
    Polygon[{{0.122171, 0.164907, 0.022973},{0.121016, 0.161353, 0.024521},{
      0.118554, 0.161742, 0.024521},{0.118554, 0.165480, 0.022973}}],
    Polygon[{{0.121016, 0.161353, 0.024521},{0.119801, 0.157611, 0.025466},{
      0.118554, 0.157808, 0.025466},{0.118554, 0.161742, 0.024521}}],
    Polygon[{{0.118554, 0.157808, -0.025466},{0.118554, 0.161742, -0.024521},{
      0.116092, 0.161353, -0.024521},{0.117308, 0.157611, -0.025466}}],
    Polygon[{{0.118554, 0.161742, -0.024521},{0.118554, 0.165480, -0.022973},{
      0.114937, 0.164907, -0.022973},{0.116092, 0.161353, -0.024521}}],
    Polygon[{{0.118554, 0.165480, -0.022973},{0.118554, 0.168930, -0.020859},{
      0.113871, 0.168188, -0.020859},{0.114937, 0.164907, -0.022973}}],
    Polygon[{{0.118554, 0.168930, -0.020859},{0.118554, 0.172007, -0.018232},{
      0.112920, 0.171114, -0.018232},{0.113871, 0.168188, -0.020859}}],
    Polygon[{{0.118554, 0.172007, -0.018232},{0.118554, 0.174634, -0.015155},{
      0.112108, 0.173613, -0.015155},{0.112920, 0.171114, -0.018232}}],
    Polygon[{{0.118554, 0.174634, -0.015155},{0.118554, 0.176748, -0.011705},{
      0.111455, 0.175624, -0.011705},{0.112108, 0.173613, -0.015155}}],
    Polygon[{{0.118554, 0.176748, -0.011705},{0.118554, 0.178296, -0.007968},{
      0.110977, 0.177096, -0.007968},{0.111455, 0.175624, -0.011705}}],
    Polygon[{{0.118554, 0.178296, -0.007968},{0.118554, 0.179241, -0.004033},{
      0.110685, 0.177995, -0.004033},{0.110977, 0.177096, -0.007968}}],
    Polygon[{{0.118554, 0.179241, -0.004033},{0.118554, 0.179558, 0.000000},{
      0.110587, 0.178296, 0.000000},{0.110685, 0.177995, -0.004033}}],
    Polygon[{{0.118554, 0.179558, 0.000000},{0.118554, 0.179241, 0.004033},{
      0.110685, 0.177995, 0.004033},{0.110587, 0.178296, 0.000000}}],
    Polygon[{{0.118554, 0.179241, 0.004033},{0.118554, 0.178296, 0.007968},{
      0.110977, 0.177096, 0.007968},{0.110685, 0.177995, 0.004033}}],
    Polygon[{{0.118554, 0.178296, 0.007968},{0.118554, 0.176748, 0.011705},{
      0.111455, 0.175624, 0.011705},{0.110977, 0.177096, 0.007968}}],
    Polygon[{{0.118554, 0.176748, 0.011705},{0.118554, 0.174634, 0.015155},{
      0.112108, 0.173613, 0.015155},{0.111455, 0.175624, 0.011705}}],
    Polygon[{{0.118554, 0.174634, 0.015155},{0.118554, 0.172007, 0.018232},{
      0.112920, 0.171114, 0.018232},{0.112108, 0.173613, 0.015155}}],
    Polygon[{{0.118554, 0.172007, 0.018232},{0.118554, 0.168930, 0.020859},{
      0.113871, 0.168188, 0.020859},{0.112920, 0.171114, 0.018232}}],
    Polygon[{{0.118554, 0.168930, 0.020859},{0.118554, 0.165480, 0.022973},{
      0.114937, 0.164907, 0.022973},{0.113871, 0.168188, 0.020859}}],
    Polygon[{{0.118554, 0.165480, 0.022973},{0.118554, 0.161742, 0.024521},{
      0.116092, 0.161353, 0.024521},{0.114937, 0.164907, 0.022973}}],
    Polygon[{{0.118554, 0.161742, 0.024521},{0.118554, 0.157808, 0.025466},{
      0.117308, 0.157611, 0.025466},{0.116092, 0.161353, 0.024521}}],
    Polygon[{{0.117308, 0.157611, -0.025466},{0.116092, 0.161353, -0.024521},{
      0.113871, 0.160221, -0.024521},{0.116183, 0.157038, -0.025466}}],
    Polygon[{{0.116092, 0.161353, -0.024521},{0.114937, 0.164907, -0.022973},{
      0.111674, 0.163245, -0.022973},{0.113871, 0.160221, -0.024521}}],
    Polygon[{{0.114937, 0.164907, -0.022973},{0.113871, 0.168188, -0.020859},{
      0.109646, 0.166036, -0.020859},{0.111674, 0.163245, -0.022973}}],
    Polygon[{{0.113871, 0.168188, -0.020859},{0.112920, 0.171114, -0.018232},{
      0.107838, 0.168525, -0.018232},{0.109646, 0.166036, -0.020859}}],
    Polygon[{{0.112920, 0.171114, -0.018232},{0.112108, 0.173613, -0.015155},{
      0.106293, 0.170650, -0.015155},{0.107838, 0.168525, -0.018232}}],
    Polygon[{{0.112108, 0.173613, -0.015155},{0.111455, 0.175624, -0.011705},{
      0.105051, 0.172361, -0.011705},{0.106293, 0.170650, -0.015155}}],
    Polygon[{{0.111455, 0.175624, -0.011705},{0.110977, 0.177096, -0.007968},{
      0.104141, 0.173613, -0.007968},{0.105051, 0.172361, -0.011705}}],
    Polygon[{{0.110977, 0.177096, -0.007968},{0.110685, 0.177995, -0.004033},{
      0.103586, 0.174377, -0.004033},{0.104141, 0.173613, -0.007968}}],
    Polygon[{{0.110685, 0.177995, -0.004033},{0.110587, 0.178296, 0.000000},{
      0.103399, 0.174634, 0.000000},{0.103586, 0.174377, -0.004033}}],
    Polygon[{{0.110587, 0.178296, 0.000000},{0.110685, 0.177995, 0.004033},{
      0.103586, 0.174377, 0.004033},{0.103399, 0.174634, 0.000000}}],
    Polygon[{{0.110685, 0.177995, 0.004033},{0.110977, 0.177096, 0.007968},{
      0.104141, 0.173613, 0.007968},{0.103586, 0.174377, 0.004033}}],
    Polygon[{{0.110977, 0.177096, 0.007968},{0.111455, 0.175624, 0.011705},{
      0.105051, 0.172361, 0.011705},{0.104141, 0.173613, 0.007968}}],
    Polygon[{{0.111455, 0.175624, 0.011705},{0.112108, 0.173613, 0.015155},{
      0.106293, 0.170650, 0.015155},{0.105051, 0.172361, 0.011705}}],
    Polygon[{{0.112108, 0.173613, 0.015155},{0.112920, 0.171114, 0.018232},{
      0.107838, 0.168525, 0.018232},{0.106293, 0.170650, 0.015155}}],
    Polygon[{{0.112920, 0.171114, 0.018232},{0.113871, 0.168188, 0.020859},{
      0.109646, 0.166036, 0.020859},{0.107838, 0.168525, 0.018232}}],
    Polygon[{{0.113871, 0.168188, 0.020859},{0.114937, 0.164907, 0.022973},{
      0.111674, 0.163245, 0.022973},{0.109646, 0.166036, 0.020859}}],
    Polygon[{{0.114937, 0.164907, 0.022973},{0.116092, 0.161353, 0.024521},{
      0.113871, 0.160221, 0.024521},{0.111674, 0.163245, 0.022973}}],
    Polygon[{{0.116092, 0.161353, 0.024521},{0.117308, 0.157611, 0.025466},{
      0.116183, 0.157038, 0.025466},{0.113871, 0.160221, 0.024521}}],
    Polygon[{{0.116183, 0.157038, -0.025466},{0.113871, 0.160221, -0.024521},{
      0.112108, 0.158458, -0.024521},{0.115291, 0.156146, -0.025466}}],
    Polygon[{{0.113871, 0.160221, -0.024521},{0.111674, 0.163245, -0.022973},{
      0.109084, 0.160655, -0.022973},{0.112108, 0.158458, -0.024521}}],
    Polygon[{{0.111674, 0.163245, -0.022973},{0.109646, 0.166036, -0.020859},{
      0.106293, 0.162683, -0.020859},{0.109084, 0.160655, -0.022973}}],
    Polygon[{{0.109646, 0.166036, -0.020859},{0.107838, 0.168525, -0.018232},{
      0.103804, 0.164491, -0.018232},{0.106293, 0.162683, -0.020859}}],
    Polygon[{{0.107838, 0.168525, -0.018232},{0.106293, 0.170650, -0.015155},{
      0.101679, 0.166036, -0.015155},{0.103804, 0.164491, -0.018232}}],
    Polygon[{{0.106293, 0.170650, -0.015155},{0.105051, 0.172361, -0.011705},{
      0.099968, 0.167278, -0.011705},{0.101679, 0.166036, -0.015155}}],
    Polygon[{{0.105051, 0.172361, -0.011705},{0.104141, 0.173613, -0.007968},{
      0.098716, 0.168188, -0.007968},{0.099968, 0.167278, -0.011705}}],
    Polygon[{{0.104141, 0.173613, -0.007968},{0.103586, 0.174377, -0.004033},{
      0.097952, 0.168743, -0.004033},{0.098716, 0.168188, -0.007968}}],
    Polygon[{{0.103586, 0.174377, -0.004033},{0.103399, 0.174634, 0.000000},{
      0.097695, 0.168930, 0.000000},{0.097952, 0.168743, -0.004033}}],
    Polygon[{{0.103399, 0.174634, 0.000000},{0.103586, 0.174377, 0.004033},{
      0.097952, 0.168743, 0.004033},{0.097695, 0.168930, 0.000000}}],
    Polygon[{{0.103586, 0.174377, 0.004033},{0.104141, 0.173613, 0.007968},{
      0.098716, 0.168188, 0.007968},{0.097952, 0.168743, 0.004033}}],
    Polygon[{{0.104141, 0.173613, 0.007968},{0.105051, 0.172361, 0.011705},{
      0.099968, 0.167278, 0.011705},{0.098716, 0.168188, 0.007968}}],
    Polygon[{{0.105051, 0.172361, 0.011705},{0.106293, 0.170650, 0.015155},{
      0.101679, 0.166036, 0.015155},{0.099968, 0.167278, 0.011705}}],
    Polygon[{{0.106293, 0.170650, 0.015155},{0.107838, 0.168525, 0.018232},{
      0.103804, 0.164491, 0.018232},{0.101679, 0.166036, 0.015155}}],
    Polygon[{{0.107838, 0.168525, 0.018232},{0.109646, 0.166036, 0.020859},{
      0.106293, 0.162683, 0.020859},{0.103804, 0.164491, 0.018232}}],
    Polygon[{{0.109646, 0.166036, 0.020859},{0.111674, 0.163245, 0.022973},{
      0.109084, 0.160655, 0.022973},{0.106293, 0.162683, 0.020859}}],
    Polygon[{{0.111674, 0.163245, 0.022973},{0.113871, 0.160221, 0.024521},{
      0.112108, 0.158458, 0.024521},{0.109084, 0.160655, 0.022973}}],
    Polygon[{{0.113871, 0.160221, 0.024521},{0.116183, 0.157038, 0.025466},{
      0.115291, 0.156146, 0.025466},{0.112108, 0.158458, 0.024521}}],
    Polygon[{{0.115291, 0.156146, -0.025466},{0.112108, 0.158458, -0.024521},{
      0.110977, 0.156237, -0.024521},{0.114718, 0.155021, -0.025466}}],
    Polygon[{{0.112108, 0.158458, -0.024521},{0.109084, 0.160655, -0.022973},{
      0.107422, 0.157392, -0.022973},{0.110977, 0.156237, -0.024521}}],
    Polygon[{{0.109084, 0.160655, -0.022973},{0.106293, 0.162683, -0.020859},{
      0.104141, 0.158458, -0.020859},{0.107422, 0.157392, -0.022973}}],
    Polygon[{{0.106293, 0.162683, -0.020859},{0.103804, 0.164491, -0.018232},{
      0.101215, 0.159409, -0.018232},{0.104141, 0.158458, -0.020859}}],
    Polygon[{{0.103804, 0.164491, -0.018232},{0.101679, 0.166036, -0.015155},{
      0.098716, 0.160221, -0.015155},{0.101215, 0.159409, -0.018232}}],
    Polygon[{{0.101679, 0.166036, -0.015155},{0.099968, 0.167278, -0.011705},{
      0.096705, 0.160874, -0.011705},{0.098716, 0.160221, -0.015155}}],
    Polygon[{{0.099968, 0.167278, -0.011705},{0.098716, 0.168188, -0.007968},{
      0.095233, 0.161353, -0.007968},{0.096705, 0.160874, -0.011705}}],
    Polygon[{{0.098716, 0.168188, -0.007968},{0.097952, 0.168743, -0.004033},{
      0.094335, 0.161644, -0.004033},{0.095233, 0.161353, -0.007968}}],
    Polygon[{{0.097952, 0.168743, -0.004033},{0.097695, 0.168930, 0.000000},{
      0.094033, 0.161742, 0.000000},{0.094335, 0.161644, -0.004033}}],
    Polygon[{{0.097695, 0.168930, 0.000000},{0.097952, 0.168743, 0.004033},{
      0.094335, 0.161644, 0.004033},{0.094033, 0.161742, 0.000000}}],
    Polygon[{{0.097952, 0.168743, 0.004033},{0.098716, 0.168188, 0.007968},{
      0.095233, 0.161353, 0.007968},{0.094335, 0.161644, 0.004033}}],
    Polygon[{{0.098716, 0.168188, 0.007968},{0.099968, 0.167278, 0.011705},{
      0.096705, 0.160874, 0.011705},{0.095233, 0.161353, 0.007968}}],
    Polygon[{{0.099968, 0.167278, 0.011705},{0.101679, 0.166036, 0.015155},{
      0.098716, 0.160221, 0.015155},{0.096705, 0.160874, 0.011705}}],
    Polygon[{{0.101679, 0.166036, 0.015155},{0.103804, 0.164491, 0.018232},{
      0.101215, 0.159409, 0.018232},{0.098716, 0.160221, 0.015155}}],
    Polygon[{{0.103804, 0.164491, 0.018232},{0.106293, 0.162683, 0.020859},{
      0.104141, 0.158458, 0.020859},{0.101215, 0.159409, 0.018232}}],
    Polygon[{{0.106293, 0.162683, 0.020859},{0.109084, 0.160655, 0.022973},{
      0.107422, 0.157392, 0.022973},{0.104141, 0.158458, 0.020859}}],
    Polygon[{{0.109084, 0.160655, 0.022973},{0.112108, 0.158458, 0.024521},{
      0.110977, 0.156237, 0.024521},{0.107422, 0.157392, 0.022973}}],
    Polygon[{{0.112108, 0.158458, 0.024521},{0.115291, 0.156146, 0.025466},{
      0.114718, 0.155021, 0.025466},{0.110977, 0.156237, 0.024521}}],
    Polygon[{{0.114718, 0.155021, -0.025466},{0.110977, 0.156237, -0.024521},{
      0.110587, 0.153775, -0.024521},{0.114521, 0.153775, -0.025466}}],
    Polygon[{{0.110977, 0.156237, -0.024521},{0.107422, 0.157392, -0.022973},{
      0.106849, 0.153775, -0.022973},{0.110587, 0.153775, -0.024521}}],
    Polygon[{{0.107422, 0.157392, -0.022973},{0.104141, 0.158458, -0.020859},{
      0.103399, 0.153775, -0.020859},{0.106849, 0.153775, -0.022973}}],
    Polygon[{{0.104141, 0.158458, -0.020859},{0.101215, 0.159409, -0.018232},{
      0.100323, 0.153775, -0.018232},{0.103399, 0.153775, -0.020859}}],
    Polygon[{{0.101215, 0.159409, -0.018232},{0.098716, 0.160221, -0.015155},{
      0.097695, 0.153775, -0.015155},{0.100323, 0.153775, -0.018232}}],
    Polygon[{{0.098716, 0.160221, -0.015155},{0.096705, 0.160874, -0.011705},{
      0.095581, 0.153775, -0.011705},{0.097695, 0.153775, -0.015155}}],
    Polygon[{{0.096705, 0.160874, -0.011705},{0.095233, 0.161353, -0.007968},{
      0.094033, 0.153775, -0.007968},{0.095581, 0.153775, -0.011705}}],
    Polygon[{{0.095233, 0.161353, -0.007968},{0.094335, 0.161644, -0.004033},{
      0.093088, 0.153775, -0.004033},{0.094033, 0.153775, -0.007968}}],
    Polygon[{{0.094335, 0.161644, -0.004033},{0.094033, 0.161742, 0.000000},{
      0.092771, 0.153775, 0.000000},{0.093088, 0.153775, -0.004033}}],
    Polygon[{{0.094033, 0.161742, 0.000000},{0.094335, 0.161644, 0.004033},{
      0.093088, 0.153775, 0.004033},{0.092771, 0.153775, 0.000000}}],
    Polygon[{{0.094335, 0.161644, 0.004033},{0.095233, 0.161353, 0.007968},{
      0.094033, 0.153775, 0.007968},{0.093088, 0.153775, 0.004033}}],
    Polygon[{{0.095233, 0.161353, 0.007968},{0.096705, 0.160874, 0.011705},{
      0.095581, 0.153775, 0.011705},{0.094033, 0.153775, 0.007968}}],
    Polygon[{{0.096705, 0.160874, 0.011705},{0.098716, 0.160221, 0.015155},{
      0.097695, 0.153775, 0.015155},{0.095581, 0.153775, 0.011705}}],
    Polygon[{{0.098716, 0.160221, 0.015155},{0.101215, 0.159409, 0.018232},{
      0.100323, 0.153775, 0.018232},{0.097695, 0.153775, 0.015155}}],
    Polygon[{{0.101215, 0.159409, 0.018232},{0.104141, 0.158458, 0.020859},{
      0.103399, 0.153775, 0.020859},{0.100323, 0.153775, 0.018232}}],
    Polygon[{{0.104141, 0.158458, 0.020859},{0.107422, 0.157392, 0.022973},{
      0.106849, 0.153775, 0.022973},{0.103399, 0.153775, 0.020859}}],
    Polygon[{{0.107422, 0.157392, 0.022973},{0.110977, 0.156237, 0.024521},{
      0.110587, 0.153775, 0.024521},{0.106849, 0.153775, 0.022973}}],
    Polygon[{{0.110977, 0.156237, 0.024521},{0.114718, 0.155021, 0.025466},{
      0.114521, 0.153775, 0.025466},{0.110587, 0.153775, 0.024521}}],
    Polygon[{{0.114521, 0.153775, -0.025466},{0.110587, 0.153775, -0.024521},{
      0.110977, 0.151313, -0.024521},{0.114718, 0.152529, -0.025466}}],
    Polygon[{{0.110587, 0.153775, -0.024521},{0.106849, 0.153775, -0.022973},{
      0.107422, 0.150158, -0.022973},{0.110977, 0.151313, -0.024521}}],
    Polygon[{{0.106849, 0.153775, -0.022973},{0.103399, 0.153775, -0.020859},{
      0.104141, 0.149092, -0.020859},{0.107422, 0.150158, -0.022973}}],
    Polygon[{{0.103399, 0.153775, -0.020859},{0.100323, 0.153775, -0.018232},{
      0.101215, 0.148141, -0.018232},{0.104141, 0.149092, -0.020859}}],
    Polygon[{{0.100323, 0.153775, -0.018232},{0.097695, 0.153775, -0.015155},{
      0.098716, 0.147329, -0.015155},{0.101215, 0.148141, -0.018232}}],
    Polygon[{{0.097695, 0.153775, -0.015155},{0.095581, 0.153775, -0.011705},{
      0.096705, 0.146676, -0.011705},{0.098716, 0.147329, -0.015155}}],
    Polygon[{{0.095581, 0.153775, -0.011705},{0.094033, 0.153775, -0.007968},{
      0.095233, 0.146197, -0.007968},{0.096705, 0.146676, -0.011705}}],
    Polygon[{{0.094033, 0.153775, -0.007968},{0.093088, 0.153775, -0.004033},{
      0.094335, 0.145906, -0.004033},{0.095233, 0.146197, -0.007968}}],
    Polygon[{{0.093088, 0.153775, -0.004033},{0.092771, 0.153775, 0.000000},{
      0.094033, 0.145807, 0.000000},{0.094335, 0.145906, -0.004033}}],
    Polygon[{{0.092771, 0.153775, 0.000000},{0.093088, 0.153775, 0.004033},{
      0.094335, 0.145906, 0.004033},{0.094033, 0.145807, 0.000000}}],
    Polygon[{{0.093088, 0.153775, 0.004033},{0.094033, 0.153775, 0.007968},{
      0.095233, 0.146197, 0.007968},{0.094335, 0.145906, 0.004033}}],
    Polygon[{{0.094033, 0.153775, 0.007968},{0.095581, 0.153775, 0.011705},{
      0.096705, 0.146676, 0.011705},{0.095233, 0.146197, 0.007968}}],
    Polygon[{{0.095581, 0.153775, 0.011705},{0.097695, 0.153775, 0.015155},{
      0.098716, 0.147329, 0.015155},{0.096705, 0.146676, 0.011705}}],
    Polygon[{{0.097695, 0.153775, 0.015155},{0.100323, 0.153775, 0.018232},{
      0.101215, 0.148141, 0.018232},{0.098716, 0.147329, 0.015155}}],
    Polygon[{{0.100323, 0.153775, 0.018232},{0.103399, 0.153775, 0.020859},{
      0.104141, 0.149092, 0.020859},{0.101215, 0.148141, 0.018232}}],
    Polygon[{{0.103399, 0.153775, 0.020859},{0.106849, 0.153775, 0.022973},{
      0.107422, 0.150158, 0.022973},{0.104141, 0.149092, 0.020859}}],
    Polygon[{{0.106849, 0.153775, 0.022973},{0.110587, 0.153775, 0.024521},{
      0.110977, 0.151313, 0.024521},{0.107422, 0.150158, 0.022973}}],
    Polygon[{{0.110587, 0.153775, 0.024521},{0.114521, 0.153775, 0.025466},{
      0.114718, 0.152529, 0.025466},{0.110977, 0.151313, 0.024521}}],
    Polygon[{{0.114718, 0.152529, -0.025466},{0.110977, 0.151313, -0.024521},{
      0.112108, 0.149092, -0.024521},{0.115291, 0.151404, -0.025466}}],
    Polygon[{{0.110977, 0.151313, -0.024521},{0.107422, 0.150158, -0.022973},{
      0.109084, 0.146895, -0.022973},{0.112108, 0.149092, -0.024521}}],
    Polygon[{{0.107422, 0.150158, -0.022973},{0.104141, 0.149092, -0.020859},{
      0.106293, 0.144867, -0.020859},{0.109084, 0.146895, -0.022973}}],
    Polygon[{{0.104141, 0.149092, -0.020859},{0.101215, 0.148141, -0.018232},{
      0.103804, 0.143059, -0.018232},{0.106293, 0.144867, -0.020859}}],
    Polygon[{{0.101215, 0.148141, -0.018232},{0.098716, 0.147329, -0.015155},{
      0.101679, 0.141514, -0.015155},{0.103804, 0.143059, -0.018232}}],
    Polygon[{{0.098716, 0.147329, -0.015155},{0.096705, 0.146676, -0.011705},{
      0.099968, 0.140272, -0.011705},{0.101679, 0.141514, -0.015155}}],
    Polygon[{{0.096705, 0.146676, -0.011705},{0.095233, 0.146197, -0.007968},{
      0.098716, 0.139362, -0.007968},{0.099968, 0.140272, -0.011705}}],
    Polygon[{{0.095233, 0.146197, -0.007968},{0.094335, 0.145906, -0.004033},{
      0.097952, 0.138806, -0.004033},{0.098716, 0.139362, -0.007968}}],
    Polygon[{{0.094335, 0.145906, -0.004033},{0.094033, 0.145807, 0.000000},{
      0.097695, 0.138620, 0.000000},{0.097952, 0.138806, -0.004033}}],
    Polygon[{{0.094033, 0.145807, 0.000000},{0.094335, 0.145906, 0.004033},{
      0.097952, 0.138806, 0.004033},{0.097695, 0.138620, 0.000000}}],
    Polygon[{{0.094335, 0.145906, 0.004033},{0.095233, 0.146197, 0.007968},{
      0.098716, 0.139362, 0.007968},{0.097952, 0.138806, 0.004033}}],
    Polygon[{{0.095233, 0.146197, 0.007968},{0.096705, 0.146676, 0.011705},{
      0.099968, 0.140272, 0.011705},{0.098716, 0.139362, 0.007968}}],
    Polygon[{{0.096705, 0.146676, 0.011705},{0.098716, 0.147329, 0.015155},{
      0.101679, 0.141514, 0.015155},{0.099968, 0.140272, 0.011705}}],
    Polygon[{{0.098716, 0.147329, 0.015155},{0.101215, 0.148141, 0.018232},{
      0.103804, 0.143059, 0.018232},{0.101679, 0.141514, 0.015155}}],
    Polygon[{{0.101215, 0.148141, 0.018232},{0.104141, 0.149092, 0.020859},{
      0.106293, 0.144867, 0.020859},{0.103804, 0.143059, 0.018232}}],
    Polygon[{{0.104141, 0.149092, 0.020859},{0.107422, 0.150158, 0.022973},{
      0.109084, 0.146895, 0.022973},{0.106293, 0.144867, 0.020859}}],
    Polygon[{{0.107422, 0.150158, 0.022973},{0.110977, 0.151313, 0.024521},{
      0.112108, 0.149092, 0.024521},{0.109084, 0.146895, 0.022973}}],
    Polygon[{{0.110977, 0.151313, 0.024521},{0.114718, 0.152529, 0.025466},{
      0.115291, 0.151404, 0.025466},{0.112108, 0.149092, 0.024521}}],
    Polygon[{{0.115291, 0.151404, -0.025466},{0.112108, 0.149092, -0.024521},{
      0.113871, 0.147329, -0.024521},{0.116183, 0.150512, -0.025466}}],
    Polygon[{{0.112108, 0.149092, -0.024521},{0.109084, 0.146895, -0.022973},{
      0.111674, 0.144305, -0.022973},{0.113871, 0.147329, -0.024521}}],
    Polygon[{{0.109084, 0.146895, -0.022973},{0.106293, 0.144867, -0.020859},{
      0.109646, 0.141514, -0.020859},{0.111674, 0.144305, -0.022973}}],
    Polygon[{{0.106293, 0.144867, -0.020859},{0.103804, 0.143059, -0.018232},{
      0.107838, 0.139025, -0.018232},{0.109646, 0.141514, -0.020859}}],
    Polygon[{{0.103804, 0.143059, -0.018232},{0.101679, 0.141514, -0.015155},{
      0.106293, 0.136899, -0.015155},{0.107838, 0.139025, -0.018232}}],
    Polygon[{{0.101679, 0.141514, -0.015155},{0.099968, 0.140272, -0.011705},{
      0.105051, 0.135189, -0.011705},{0.106293, 0.136899, -0.015155}}],
    Polygon[{{0.099968, 0.140272, -0.011705},{0.098716, 0.139362, -0.007968},{
      0.104141, 0.133937, -0.007968},{0.105051, 0.135189, -0.011705}}],
    Polygon[{{0.098716, 0.139362, -0.007968},{0.097952, 0.138806, -0.004033},{
      0.103586, 0.133173, -0.004033},{0.104141, 0.133937, -0.007968}}],
    Polygon[{{0.097952, 0.138806, -0.004033},{0.097695, 0.138620, 0.000000},{
      0.103399, 0.132916, 0.000000},{0.103586, 0.133173, -0.004033}}],
    Polygon[{{0.097695, 0.138620, 0.000000},{0.097952, 0.138806, 0.004033},{
      0.103586, 0.133173, 0.004033},{0.103399, 0.132916, 0.000000}}],
    Polygon[{{0.097952, 0.138806, 0.004033},{0.098716, 0.139362, 0.007968},{
      0.104141, 0.133937, 0.007968},{0.103586, 0.133173, 0.004033}}],
    Polygon[{{0.098716, 0.139362, 0.007968},{0.099968, 0.140272, 0.011705},{
      0.105051, 0.135189, 0.011705},{0.104141, 0.133937, 0.007968}}],
    Polygon[{{0.099968, 0.140272, 0.011705},{0.101679, 0.141514, 0.015155},{
      0.106293, 0.136899, 0.015155},{0.105051, 0.135189, 0.011705}}],
    Polygon[{{0.101679, 0.141514, 0.015155},{0.103804, 0.143059, 0.018232},{
      0.107838, 0.139025, 0.018232},{0.106293, 0.136899, 0.015155}}],
    Polygon[{{0.103804, 0.143059, 0.018232},{0.106293, 0.144867, 0.020859},{
      0.109646, 0.141514, 0.020859},{0.107838, 0.139025, 0.018232}}],
    Polygon[{{0.106293, 0.144867, 0.020859},{0.109084, 0.146895, 0.022973},{
      0.111674, 0.144305, 0.022973},{0.109646, 0.141514, 0.020859}}],
    Polygon[{{0.109084, 0.146895, 0.022973},{0.112108, 0.149092, 0.024521},{
      0.113871, 0.147329, 0.024521},{0.111674, 0.144305, 0.022973}}],
    Polygon[{{0.112108, 0.149092, 0.024521},{0.115291, 0.151404, 0.025466},{
      0.116183, 0.150512, 0.025466},{0.113871, 0.147329, 0.024521}}],
    Polygon[{{0.116183, 0.150512, -0.025466},{0.113871, 0.147329, -0.024521},{
      0.116092, 0.146197, -0.024521},{0.117308, 0.149939, -0.025466}}],
    Polygon[{{0.113871, 0.147329, -0.024521},{0.111674, 0.144305, -0.022973},{
      0.114937, 0.142642, -0.022973},{0.116092, 0.146197, -0.024521}}],
    Polygon[{{0.111674, 0.144305, -0.022973},{0.109646, 0.141514, -0.020859},{
      0.113871, 0.139362, -0.020859},{0.114937, 0.142642, -0.022973}}],
    Polygon[{{0.109646, 0.141514, -0.020859},{0.107838, 0.139025, -0.018232},{
      0.112920, 0.136436, -0.018232},{0.113871, 0.139362, -0.020859}}],
    Polygon[{{0.107838, 0.139025, -0.018232},{0.106293, 0.136899, -0.015155},{
      0.112108, 0.133937, -0.015155},{0.112920, 0.136436, -0.018232}}],
    Polygon[{{0.106293, 0.136899, -0.015155},{0.105051, 0.135189, -0.011705},{
      0.111455, 0.131926, -0.011705},{0.112108, 0.133937, -0.015155}}],
    Polygon[{{0.105051, 0.135189, -0.011705},{0.104141, 0.133937, -0.007968},{
      0.110977, 0.130454, -0.007968},{0.111455, 0.131926, -0.011705}}],
    Polygon[{{0.104141, 0.133937, -0.007968},{0.103586, 0.133173, -0.004033},{
      0.110685, 0.129555, -0.004033},{0.110977, 0.130454, -0.007968}}],
    Polygon[{{0.103586, 0.133173, -0.004033},{0.103399, 0.132916, 0.000000},{
      0.110587, 0.129253, 0.000000},{0.110685, 0.129555, -0.004033}}],
    Polygon[{{0.103399, 0.132916, 0.000000},{0.103586, 0.133173, 0.004033},{
      0.110685, 0.129555, 0.004033},{0.110587, 0.129253, 0.000000}}],
    Polygon[{{0.103586, 0.133173, 0.004033},{0.104141, 0.133937, 0.007968},{
      0.110977, 0.130454, 0.007968},{0.110685, 0.129555, 0.004033}}],
    Polygon[{{0.104141, 0.133937, 0.007968},{0.105051, 0.135189, 0.011705},{
      0.111455, 0.131926, 0.011705},{0.110977, 0.130454, 0.007968}}],
    Polygon[{{0.105051, 0.135189, 0.011705},{0.106293, 0.136899, 0.015155},{
      0.112108, 0.133937, 0.015155},{0.111455, 0.131926, 0.011705}}],
    Polygon[{{0.106293, 0.136899, 0.015155},{0.107838, 0.139025, 0.018232},{
      0.112920, 0.136436, 0.018232},{0.112108, 0.133937, 0.015155}}],
    Polygon[{{0.107838, 0.139025, 0.018232},{0.109646, 0.141514, 0.020859},{
      0.113871, 0.139362, 0.020859},{0.112920, 0.136436, 0.018232}}],
    Polygon[{{0.109646, 0.141514, 0.020859},{0.111674, 0.144305, 0.022973},{
      0.114937, 0.142642, 0.022973},{0.113871, 0.139362, 0.020859}}],
    Polygon[{{0.111674, 0.144305, 0.022973},{0.113871, 0.147329, 0.024521},{
      0.116092, 0.146197, 0.024521},{0.114937, 0.142642, 0.022973}}],
    Polygon[{{0.113871, 0.147329, 0.024521},{0.116183, 0.150512, 0.025466},{
      0.117308, 0.149939, 0.025466},{0.116092, 0.146197, 0.024521}}],
    Polygon[{{0.117308, 0.149939, -0.025466},{0.116092, 0.146197, -0.024521},{
      0.118554, 0.145807, -0.024521},{0.118554, 0.149742, -0.025466}}],
    Polygon[{{0.116092, 0.146197, -0.024521},{0.114937, 0.142642, -0.022973},{
      0.118554, 0.142070, -0.022973},{0.118554, 0.145807, -0.024521}}],
    Polygon[{{0.114937, 0.142642, -0.022973},{0.113871, 0.139362, -0.020859},{
      0.118554, 0.138620, -0.020859},{0.118554, 0.142070, -0.022973}}],
    Polygon[{{0.113871, 0.139362, -0.020859},{0.112920, 0.136436, -0.018232},{
      0.118554, 0.135543, -0.018232},{0.118554, 0.138620, -0.020859}}],
    Polygon[{{0.112920, 0.136436, -0.018232},{0.112108, 0.133937, -0.015155},{
      0.118554, 0.132916, -0.015155},{0.118554, 0.135543, -0.018232}}],
    Polygon[{{0.112108, 0.133937, -0.015155},{0.111455, 0.131926, -0.011705},{
      0.118554, 0.130802, -0.011705},{0.118554, 0.132916, -0.015155}}],
    Polygon[{{0.111455, 0.131926, -0.011705},{0.110977, 0.130454, -0.007968},{
      0.118554, 0.129253, -0.007968},{0.118554, 0.130802, -0.011705}}],
    Polygon[{{0.110977, 0.130454, -0.007968},{0.110685, 0.129555, -0.004033},{
      0.118554, 0.128309, -0.004033},{0.118554, 0.129253, -0.007968}}],
    Polygon[{{0.110685, 0.129555, -0.004033},{0.110587, 0.129253, 0.000000},{
      0.118554, 0.127992, 0.000000},{0.118554, 0.128309, -0.004033}}],
    Polygon[{{0.110587, 0.129253, 0.000000},{0.110685, 0.129555, 0.004033},{
      0.118554, 0.128309, 0.004033},{0.118554, 0.127992, 0.000000}}],
    Polygon[{{0.110685, 0.129555, 0.004033},{0.110977, 0.130454, 0.007968},{
      0.118554, 0.129253, 0.007968},{0.118554, 0.128309, 0.004033}}],
    Polygon[{{0.110977, 0.130454, 0.007968},{0.111455, 0.131926, 0.011705},{
      0.118554, 0.130802, 0.011705},{0.118554, 0.129253, 0.007968}}],
    Polygon[{{0.111455, 0.131926, 0.011705},{0.112108, 0.133937, 0.015155},{
      0.118554, 0.132916, 0.015155},{0.118554, 0.130802, 0.011705}}],
    Polygon[{{0.112108, 0.133937, 0.015155},{0.112920, 0.136436, 0.018232},{
      0.118554, 0.135543, 0.018232},{0.118554, 0.132916, 0.015155}}],
    Polygon[{{0.112920, 0.136436, 0.018232},{0.113871, 0.139362, 0.020859},{
      0.118554, 0.138620, 0.020859},{0.118554, 0.135543, 0.018232}}],
    Polygon[{{0.113871, 0.139362, 0.020859},{0.114937, 0.142642, 0.022973},{
      0.118554, 0.142070, 0.022973},{0.118554, 0.138620, 0.020859}}],
    Polygon[{{0.114937, 0.142642, 0.022973},{0.116092, 0.146197, 0.024521},{
      0.118554, 0.145807, 0.024521},{0.118554, 0.142070, 0.022973}}],
    Polygon[{{0.116092, 0.146197, 0.024521},{0.117308, 0.149939, 0.025466},{
      0.118554, 0.149742, 0.025466},{0.118554, 0.145807, 0.024521}}],
    Polygon[{{0.118554, 0.149742, -0.025466},{0.118554, 0.145807, -0.024521},{
      0.121016, 0.146197, -0.024521},{0.119801, 0.149939, -0.025466}}],
    Polygon[{{0.118554, 0.145807, -0.024521},{0.118554, 0.142070, -0.022973},{
      0.122171, 0.142642, -0.022973},{0.121016, 0.146197, -0.024521}}],
    Polygon[{{0.118554, 0.142070, -0.022973},{0.118554, 0.138620, -0.020859},{
      0.123237, 0.139362, -0.020859},{0.122171, 0.142642, -0.022973}}],
    Polygon[{{0.118554, 0.138620, -0.020859},{0.118554, 0.135543, -0.018232},{
      0.124188, 0.136436, -0.018232},{0.123237, 0.139362, -0.020859}}],
    Polygon[{{0.118554, 0.135543, -0.018232},{0.118554, 0.132916, -0.015155},{
      0.125000, 0.133937, -0.015155},{0.124188, 0.136436, -0.018232}}],
    Polygon[{{0.118554, 0.132916, -0.015155},{0.118554, 0.130802, -0.011705},{
      0.125653, 0.131926, -0.011705},{0.125000, 0.133937, -0.015155}}],
    Polygon[{{0.118554, 0.130802, -0.011705},{0.118554, 0.129253, -0.007968},{
      0.126132, 0.130454, -0.007968},{0.125653, 0.131926, -0.011705}}],
    Polygon[{{0.118554, 0.129253, -0.007968},{0.118554, 0.128309, -0.004033},{
      0.126424, 0.129555, -0.004033},{0.126132, 0.130454, -0.007968}}],
    Polygon[{{0.118554, 0.128309, -0.004033},{0.118554, 0.127992, 0.000000},{
      0.126522, 0.129253, 0.000000},{0.126424, 0.129555, -0.004033}}],
    Polygon[{{0.118554, 0.127992, 0.000000},{0.118554, 0.128309, 0.004033},{
      0.126424, 0.129555, 0.004033},{0.126522, 0.129253, 0.000000}}],
    Polygon[{{0.118554, 0.128309, 0.004033},{0.118554, 0.129253, 0.007968},{
      0.126132, 0.130454, 0.007968},{0.126424, 0.129555, 0.004033}}],
    Polygon[{{0.118554, 0.129253, 0.007968},{0.118554, 0.130802, 0.011705},{
      0.125653, 0.131926, 0.011705},{0.126132, 0.130454, 0.007968}}],
    Polygon[{{0.118554, 0.130802, 0.011705},{0.118554, 0.132916, 0.015155},{
      0.125000, 0.133937, 0.015155},{0.125653, 0.131926, 0.011705}}],
    Polygon[{{0.118554, 0.132916, 0.015155},{0.118554, 0.135543, 0.018232},{
      0.124188, 0.136436, 0.018232},{0.125000, 0.133937, 0.015155}}],
    Polygon[{{0.118554, 0.135543, 0.018232},{0.118554, 0.138620, 0.020859},{
      0.123237, 0.139362, 0.020859},{0.124188, 0.136436, 0.018232}}],
    Polygon[{{0.118554, 0.138620, 0.020859},{0.118554, 0.142070, 0.022973},{
      0.122171, 0.142642, 0.022973},{0.123237, 0.139362, 0.020859}}],
    Polygon[{{0.118554, 0.142070, 0.022973},{0.118554, 0.145807, 0.024521},{
      0.121016, 0.146197, 0.024521},{0.122171, 0.142642, 0.022973}}],
    Polygon[{{0.118554, 0.145807, 0.024521},{0.118554, 0.149742, 0.025466},{
      0.119801, 0.149939, 0.025466},{0.121016, 0.146197, 0.024521}}],
    Polygon[{{0.119801, 0.149939, -0.025466},{0.121016, 0.146197, -0.024521},{
      0.123237, 0.147329, -0.024521},{0.120925, 0.150512, -0.025466}}],
    Polygon[{{0.121016, 0.146197, -0.024521},{0.122171, 0.142642, -0.022973},{
      0.125434, 0.144305, -0.022973},{0.123237, 0.147329, -0.024521}}],
    Polygon[{{0.122171, 0.142642, -0.022973},{0.123237, 0.139362, -0.020859},{
      0.127462, 0.141514, -0.020859},{0.125434, 0.144305, -0.022973}}],
    Polygon[{{0.123237, 0.139362, -0.020859},{0.124188, 0.136436, -0.018232},{
      0.129270, 0.139025, -0.018232},{0.127462, 0.141514, -0.020859}}],
    Polygon[{{0.124188, 0.136436, -0.018232},{0.125000, 0.133937, -0.015155},{
      0.130815, 0.136899, -0.015155},{0.129270, 0.139025, -0.018232}}],
    Polygon[{{0.125000, 0.133937, -0.015155},{0.125653, 0.131926, -0.011705},{
      0.132057, 0.135189, -0.011705},{0.130815, 0.136899, -0.015155}}],
    Polygon[{{0.125653, 0.131926, -0.011705},{0.126132, 0.130454, -0.007968},{
      0.132968, 0.133937, -0.007968},{0.132057, 0.135189, -0.011705}}],
    Polygon[{{0.126132, 0.130454, -0.007968},{0.126424, 0.129555, -0.004033},{
      0.133523, 0.133173, -0.004033},{0.132968, 0.133937, -0.007968}}],
    Polygon[{{0.126424, 0.129555, -0.004033},{0.126522, 0.129253, 0.000000},{
      0.133709, 0.132916, 0.000000},{0.133523, 0.133173, -0.004033}}],
    Polygon[{{0.126522, 0.129253, 0.000000},{0.126424, 0.129555, 0.004033},{
      0.133523, 0.133173, 0.004033},{0.133709, 0.132916, 0.000000}}],
    Polygon[{{0.126424, 0.129555, 0.004033},{0.126132, 0.130454, 0.007968},{
      0.132968, 0.133937, 0.007968},{0.133523, 0.133173, 0.004033}}],
    Polygon[{{0.126132, 0.130454, 0.007968},{0.125653, 0.131926, 0.011705},{
      0.132057, 0.135189, 0.011705},{0.132968, 0.133937, 0.007968}}],
    Polygon[{{0.125653, 0.131926, 0.011705},{0.125000, 0.133937, 0.015155},{
      0.130815, 0.136899, 0.015155},{0.132057, 0.135189, 0.011705}}],
    Polygon[{{0.125000, 0.133937, 0.015155},{0.124188, 0.136436, 0.018232},{
      0.129270, 0.139025, 0.018232},{0.130815, 0.136899, 0.015155}}],
    Polygon[{{0.124188, 0.136436, 0.018232},{0.123237, 0.139362, 0.020859},{
      0.127462, 0.141514, 0.020859},{0.129270, 0.139025, 0.018232}}],
    Polygon[{{0.123237, 0.139362, 0.020859},{0.122171, 0.142642, 0.022973},{
      0.125434, 0.144305, 0.022973},{0.127462, 0.141514, 0.020859}}],
    Polygon[{{0.122171, 0.142642, 0.022973},{0.121016, 0.146197, 0.024521},{
      0.123237, 0.147329, 0.024521},{0.125434, 0.144305, 0.022973}}],
    Polygon[{{0.121016, 0.146197, 0.024521},{0.119801, 0.149939, 0.025466},{
      0.120925, 0.150512, 0.025466},{0.123237, 0.147329, 0.024521}}],
    Polygon[{{0.120925, 0.150512, -0.025466},{0.123237, 0.147329, -0.024521},{
      0.125000, 0.149092, -0.024521},{0.121817, 0.151404, -0.025466}}],
    Polygon[{{0.123237, 0.147329, -0.024521},{0.125434, 0.144305, -0.022973},{
      0.128024, 0.146895, -0.022973},{0.125000, 0.149092, -0.024521}}],
    Polygon[{{0.125434, 0.144305, -0.022973},{0.127462, 0.141514, -0.020859},{
      0.130815, 0.144867, -0.020859},{0.128024, 0.146895, -0.022973}}],
    Polygon[{{0.127462, 0.141514, -0.020859},{0.129270, 0.139025, -0.018232},{
      0.133304, 0.143059, -0.018232},{0.130815, 0.144867, -0.020859}}],
    Polygon[{{0.129270, 0.139025, -0.018232},{0.130815, 0.136899, -0.015155},{
      0.135430, 0.141514, -0.015155},{0.133304, 0.143059, -0.018232}}],
    Polygon[{{0.130815, 0.136899, -0.015155},{0.132057, 0.135189, -0.011705},{
      0.137140, 0.140272, -0.011705},{0.135430, 0.141514, -0.015155}}],
    Polygon[{{0.132057, 0.135189, -0.011705},{0.132968, 0.133937, -0.007968},{
      0.138392, 0.139362, -0.007968},{0.137140, 0.140272, -0.011705}}],
    Polygon[{{0.132968, 0.133937, -0.007968},{0.133523, 0.133173, -0.004033},{
      0.139157, 0.138806, -0.004033},{0.138392, 0.139362, -0.007968}}],
    Polygon[{{0.133523, 0.133173, -0.004033},{0.133709, 0.132916, 0.000000},{
      0.139413, 0.138620, 0.000000},{0.139157, 0.138806, -0.004033}}],
    Polygon[{{0.133709, 0.132916, 0.000000},{0.133523, 0.133173, 0.004033},{
      0.139157, 0.138806, 0.004033},{0.139413, 0.138620, 0.000000}}],
    Polygon[{{0.133523, 0.133173, 0.004033},{0.132968, 0.133937, 0.007968},{
      0.138392, 0.139362, 0.007968},{0.139157, 0.138806, 0.004033}}],
    Polygon[{{0.132968, 0.133937, 0.007968},{0.132057, 0.135189, 0.011705},{
      0.137140, 0.140272, 0.011705},{0.138392, 0.139362, 0.007968}}],
    Polygon[{{0.132057, 0.135189, 0.011705},{0.130815, 0.136899, 0.015155},{
      0.135430, 0.141514, 0.015155},{0.137140, 0.140272, 0.011705}}],
    Polygon[{{0.130815, 0.136899, 0.015155},{0.129270, 0.139025, 0.018232},{
      0.133304, 0.143059, 0.018232},{0.135430, 0.141514, 0.015155}}],
    Polygon[{{0.129270, 0.139025, 0.018232},{0.127462, 0.141514, 0.020859},{
      0.130815, 0.144867, 0.020859},{0.133304, 0.143059, 0.018232}}],
    Polygon[{{0.127462, 0.141514, 0.020859},{0.125434, 0.144305, 0.022973},{
      0.128024, 0.146895, 0.022973},{0.130815, 0.144867, 0.020859}}],
    Polygon[{{0.125434, 0.144305, 0.022973},{0.123237, 0.147329, 0.024521},{
      0.125000, 0.149092, 0.024521},{0.128024, 0.146895, 0.022973}}],
    Polygon[{{0.123237, 0.147329, 0.024521},{0.120925, 0.150512, 0.025466},{
      0.121817, 0.151404, 0.025466},{0.125000, 0.149092, 0.024521}}],
    Polygon[{{0.121817, 0.151404, -0.025466},{0.125000, 0.149092, -0.024521},{
      0.126132, 0.151313, -0.024521},{0.122390, 0.152529, -0.025466}}],
    Polygon[{{0.125000, 0.149092, -0.024521},{0.128024, 0.146895, -0.022973},{
      0.129687, 0.150158, -0.022973},{0.126132, 0.151313, -0.024521}}],
    Polygon[{{0.128024, 0.146895, -0.022973},{0.130815, 0.144867, -0.020859},{
      0.132968, 0.149092, -0.020859},{0.129687, 0.150158, -0.022973}}],
    Polygon[{{0.130815, 0.144867, -0.020859},{0.133304, 0.143059, -0.018232},{
      0.135893, 0.148141, -0.018232},{0.132968, 0.149092, -0.020859}}],
    Polygon[{{0.133304, 0.143059, -0.018232},{0.135430, 0.141514, -0.015155},{
      0.138392, 0.147329, -0.015155},{0.135893, 0.148141, -0.018232}}],
    Polygon[{{0.135430, 0.141514, -0.015155},{0.137140, 0.140272, -0.011705},{
      0.140403, 0.146676, -0.011705},{0.138392, 0.147329, -0.015155}}],
    Polygon[{{0.137140, 0.140272, -0.011705},{0.138392, 0.139362, -0.007968},{
      0.141875, 0.146197, -0.007968},{0.140403, 0.146676, -0.011705}}],
    Polygon[{{0.138392, 0.139362, -0.007968},{0.139157, 0.138806, -0.004033},{
      0.142774, 0.145906, -0.004033},{0.141875, 0.146197, -0.007968}}],
    Polygon[{{0.139157, 0.138806, -0.004033},{0.139413, 0.138620, 0.000000},{
      0.143076, 0.145807, 0.000000},{0.142774, 0.145906, -0.004033}}],
    Polygon[{{0.139413, 0.138620, 0.000000},{0.139157, 0.138806, 0.004033},{
      0.142774, 0.145906, 0.004033},{0.143076, 0.145807, 0.000000}}],
    Polygon[{{0.139157, 0.138806, 0.004033},{0.138392, 0.139362, 0.007968},{
      0.141875, 0.146197, 0.007968},{0.142774, 0.145906, 0.004033}}],
    Polygon[{{0.138392, 0.139362, 0.007968},{0.137140, 0.140272, 0.011705},{
      0.140403, 0.146676, 0.011705},{0.141875, 0.146197, 0.007968}}],
    Polygon[{{0.137140, 0.140272, 0.011705},{0.135430, 0.141514, 0.015155},{
      0.138392, 0.147329, 0.015155},{0.140403, 0.146676, 0.011705}}],
    Polygon[{{0.135430, 0.141514, 0.015155},{0.133304, 0.143059, 0.018232},{
      0.135893, 0.148141, 0.018232},{0.138392, 0.147329, 0.015155}}],
    Polygon[{{0.133304, 0.143059, 0.018232},{0.130815, 0.144867, 0.020859},{
      0.132968, 0.149092, 0.020859},{0.135893, 0.148141, 0.018232}}],
    Polygon[{{0.130815, 0.144867, 0.020859},{0.128024, 0.146895, 0.022973},{
      0.129687, 0.150158, 0.022973},{0.132968, 0.149092, 0.020859}}],
    Polygon[{{0.128024, 0.146895, 0.022973},{0.125000, 0.149092, 0.024521},{
      0.126132, 0.151313, 0.024521},{0.129687, 0.150158, 0.022973}}],
    Polygon[{{0.125000, 0.149092, 0.024521},{0.121817, 0.151404, 0.025466},{
      0.122390, 0.152529, 0.025466},{0.126132, 0.151313, 0.024521}}],
    Polygon[{{0.122390, 0.152529, -0.025466},{0.126132, 0.151313, -0.024521},{
      0.126522, 0.153775, -0.024521},{0.122588, 0.153775, -0.025466}}],
    Polygon[{{0.126132, 0.151313, -0.024521},{0.129687, 0.150158, -0.022973},{
      0.130260, 0.153775, -0.022973},{0.126522, 0.153775, -0.024521}}],
    Polygon[{{0.129687, 0.150158, -0.022973},{0.132968, 0.149092, -0.020859},{
      0.133709, 0.153775, -0.020859},{0.130260, 0.153775, -0.022973}}],
    Polygon[{{0.132968, 0.149092, -0.020859},{0.135893, 0.148141, -0.018232},{
      0.136786, 0.153775, -0.018232},{0.133709, 0.153775, -0.020859}}],
    Polygon[{{0.135893, 0.148141, -0.018232},{0.138392, 0.147329, -0.015155},{
      0.139413, 0.153775, -0.015155},{0.136786, 0.153775, -0.018232}}],
    Polygon[{{0.138392, 0.147329, -0.015155},{0.140403, 0.146676, -0.011705},{
      0.141527, 0.153775, -0.011705},{0.139413, 0.153775, -0.015155}}],
    Polygon[{{0.140403, 0.146676, -0.011705},{0.141875, 0.146197, -0.007968},{
      0.143076, 0.153775, -0.007968},{0.141527, 0.153775, -0.011705}}],
    Polygon[{{0.141875, 0.146197, -0.007968},{0.142774, 0.145906, -0.004033},{
      0.144020, 0.153775, -0.004033},{0.143076, 0.153775, -0.007968}}],
    Polygon[{{0.142774, 0.145906, -0.004033},{0.143076, 0.145807, 0.000000},{
      0.144338, 0.153775, 0.000000},{0.144020, 0.153775, -0.004033}}],
    Polygon[{{0.143076, 0.145807, 0.000000},{0.142774, 0.145906, 0.004033},{
      0.144020, 0.153775, 0.004033},{0.144338, 0.153775, 0.000000}}],
    Polygon[{{0.142774, 0.145906, 0.004033},{0.141875, 0.146197, 0.007968},{
      0.143076, 0.153775, 0.007968},{0.144020, 0.153775, 0.004033}}],
    Polygon[{{0.141875, 0.146197, 0.007968},{0.140403, 0.146676, 0.011705},{
      0.141527, 0.153775, 0.011705},{0.143076, 0.153775, 0.007968}}],
    Polygon[{{0.140403, 0.146676, 0.011705},{0.138392, 0.147329, 0.015155},{
      0.139413, 0.153775, 0.015155},{0.141527, 0.153775, 0.011705}}],
    Polygon[{{0.138392, 0.147329, 0.015155},{0.135893, 0.148141, 0.018232},{
      0.136786, 0.153775, 0.018232},{0.139413, 0.153775, 0.015155}}],
    Polygon[{{0.135893, 0.148141, 0.018232},{0.132968, 0.149092, 0.020859},{
      0.133709, 0.153775, 0.020859},{0.136786, 0.153775, 0.018232}}],
    Polygon[{{0.132968, 0.149092, 0.020859},{0.129687, 0.150158, 0.022973},{
      0.130260, 0.153775, 0.022973},{0.133709, 0.153775, 0.020859}}],
    Polygon[{{0.129687, 0.150158, 0.022973},{0.126132, 0.151313, 0.024521},{
      0.126522, 0.153775, 0.024521},{0.130260, 0.153775, 0.022973}}],
    Polygon[{{0.126132, 0.151313, 0.024521},{0.122390, 0.152529, 0.025466},{
      0.122588, 0.153775, 0.025466},{0.126522, 0.153775, 0.024521}}],
    Polygon[{{0.129227, 0.192450, -0.013647},{0.131336, 0.192450, -0.013141},{
      0.131127, 0.193770, -0.013141},{0.129122, 0.193118, -0.013647}}],
    Polygon[{{0.131336, 0.192450, -0.013141},{0.133339, 0.192450, -0.012311},{
      0.133032, 0.194389, -0.012311},{0.131127, 0.193770, -0.013141}}],
    Polygon[{{0.133339, 0.192450, -0.012311},{0.135188, 0.192450, -0.011178},{
      0.134790, 0.194960, -0.011178},{0.133032, 0.194389, -0.012311}}],
    Polygon[{{0.135188, 0.192450, -0.011178},{0.136836, 0.192450, -0.009770},{
      0.136358, 0.195469, -0.009770},{0.134790, 0.194960, -0.011178}}],
    Polygon[{{0.136836, 0.192450, -0.009770},{0.138244, 0.192450, -0.008122},{
      0.137697, 0.195904, -0.008122},{0.136358, 0.195469, -0.009770}}],
    Polygon[{{0.138244, 0.192450, -0.008122},{0.139377, 0.192450, -0.006273},{
      0.138775, 0.196254, -0.006273},{0.137697, 0.195904, -0.008122}}],
    Polygon[{{0.139377, 0.192450, -0.006273},{0.140207, 0.192450, -0.004270},{
      0.139564, 0.196511, -0.004270},{0.138775, 0.196254, -0.006273}}],
    Polygon[{{0.140207, 0.192450, -0.004270},{0.140713, 0.192450, -0.002162},{
      0.140045, 0.196667, -0.002162},{0.139564, 0.196511, -0.004270}}],
    Polygon[{{0.140713, 0.192450, -0.002162},{0.140883, 0.192450, 0.000000},{
      0.140207, 0.196720, 0.000000},{0.140045, 0.196667, -0.002162}}],
    Polygon[{{0.140883, 0.192450, 0.000000},{0.140713, 0.192450, 0.002162},{
      0.140045, 0.196667, 0.002162},{0.140207, 0.196720, 0.000000}}],
    Polygon[{{0.140713, 0.192450, 0.002162},{0.140207, 0.192450, 0.004270},{
      0.139564, 0.196511, 0.004270},{0.140045, 0.196667, 0.002162}}],
    Polygon[{{0.140207, 0.192450, 0.004270},{0.139377, 0.192450, 0.006273},{
      0.138775, 0.196254, 0.006273},{0.139564, 0.196511, 0.004270}}],
    Polygon[{{0.139377, 0.192450, 0.006273},{0.138244, 0.192450, 0.008122},{
      0.137697, 0.195904, 0.008122},{0.138775, 0.196254, 0.006273}}],
    Polygon[{{0.138244, 0.192450, 0.008122},{0.136836, 0.192450, 0.009770},{
      0.136358, 0.195469, 0.009770},{0.137697, 0.195904, 0.008122}}],
    Polygon[{{0.136836, 0.192450, 0.009770},{0.135188, 0.192450, 0.011178},{
      0.134790, 0.194960, 0.011178},{0.136358, 0.195469, 0.009770}}],
    Polygon[{{0.135188, 0.192450, 0.011178},{0.133339, 0.192450, 0.012311},{
      0.133032, 0.194389, 0.012311},{0.134790, 0.194960, 0.011178}}],
    Polygon[{{0.133339, 0.192450, 0.012311},{0.131336, 0.192450, 0.013141},{
      0.131127, 0.193770, 0.013141},{0.133032, 0.194389, 0.012311}}],
    Polygon[{{0.131336, 0.192450, 0.013141},{0.129227, 0.192450, 0.013647},{
      0.129122, 0.193118, 0.013647},{0.131127, 0.193770, 0.013141}}],
    Polygon[{{0.129122, 0.193118, -0.013647},{0.131127, 0.193770, -0.013141},{
      0.130520, 0.194960, -0.013141},{0.128815, 0.193721, -0.013647}}],
    Polygon[{{0.131127, 0.193770, -0.013141},{0.133032, 0.194389, -0.012311},{
      0.132141, 0.196137, -0.012311},{0.130520, 0.194960, -0.013141}}],
    Polygon[{{0.133032, 0.194389, -0.012311},{0.134790, 0.194960, -0.011178},{
      0.133636, 0.197224, -0.011178},{0.132141, 0.196137, -0.012311}}],
    Polygon[{{0.134790, 0.194960, -0.011178},{0.136358, 0.195469, -0.009770},{
      0.134970, 0.198193, -0.009770},{0.133636, 0.197224, -0.011178}}],
    Polygon[{{0.136358, 0.195469, -0.009770},{0.137697, 0.195904, -0.008122},{
      0.136109, 0.199021, -0.008122},{0.134970, 0.198193, -0.009770}}],
    Polygon[{{0.137697, 0.195904, -0.008122},{0.138775, 0.196254, -0.006273},{
      0.137026, 0.199686, -0.006273},{0.136109, 0.199021, -0.008122}}],
    Polygon[{{0.138775, 0.196254, -0.006273},{0.139564, 0.196511, -0.004270},{
      0.137697, 0.200174, -0.004270},{0.137026, 0.199686, -0.006273}}],
    Polygon[{{0.139564, 0.196511, -0.004270},{0.140045, 0.196667, -0.002162},{
      0.138107, 0.200472, -0.002162},{0.137697, 0.200174, -0.004270}}],
    Polygon[{{0.140045, 0.196667, -0.002162},{0.140207, 0.196720, 0.000000},{
      0.138244, 0.200572, 0.000000},{0.138107, 0.200472, -0.002162}}],
    Polygon[{{0.140207, 0.196720, 0.000000},{0.140045, 0.196667, 0.002162},{
      0.138107, 0.200472, 0.002162},{0.138244, 0.200572, 0.000000}}],
    Polygon[{{0.140045, 0.196667, 0.002162},{0.139564, 0.196511, 0.004270},{
      0.137697, 0.200174, 0.004270},{0.138107, 0.200472, 0.002162}}],
    Polygon[{{0.139564, 0.196511, 0.004270},{0.138775, 0.196254, 0.006273},{
      0.137026, 0.199686, 0.006273},{0.137697, 0.200174, 0.004270}}],
    Polygon[{{0.138775, 0.196254, 0.006273},{0.137697, 0.195904, 0.008122},{
      0.136109, 0.199021, 0.008122},{0.137026, 0.199686, 0.006273}}],
    Polygon[{{0.137697, 0.195904, 0.008122},{0.136358, 0.195469, 0.009770},{
      0.134970, 0.198193, 0.009770},{0.136109, 0.199021, 0.008122}}],
    Polygon[{{0.136358, 0.195469, 0.009770},{0.134790, 0.194960, 0.011178},{
      0.133636, 0.197224, 0.011178},{0.134970, 0.198193, 0.009770}}],
    Polygon[{{0.134790, 0.194960, 0.011178},{0.133032, 0.194389, 0.012311},{
      0.132141, 0.196137, 0.012311},{0.133636, 0.197224, 0.011178}}],
    Polygon[{{0.133032, 0.194389, 0.012311},{0.131127, 0.193770, 0.013141},{
      0.130520, 0.194960, 0.013141},{0.132141, 0.196137, 0.012311}}],
    Polygon[{{0.131127, 0.193770, 0.013141},{0.129122, 0.193118, 0.013647},{
      0.128815, 0.193721, 0.013647},{0.130520, 0.194960, 0.013141}}],
    Polygon[{{0.128815, 0.193721, -0.013647},{0.130520, 0.194960, -0.013141},{
      0.129576, 0.195904, -0.013141},{0.128336, 0.194199, -0.013647}}],
    Polygon[{{0.130520, 0.194960, -0.013141},{0.132141, 0.196137, -0.012311},{
      0.130753, 0.197525, -0.012311},{0.129576, 0.195904, -0.013141}}],
    Polygon[{{0.132141, 0.196137, -0.012311},{0.133636, 0.197224, -0.011178},{
      0.131840, 0.199021, -0.011178},{0.130753, 0.197525, -0.012311}}],
    Polygon[{{0.133636, 0.197224, -0.011178},{0.134970, 0.198193, -0.009770},{
      0.132809, 0.200354, -0.009770},{0.131840, 0.199021, -0.011178}}],
    Polygon[{{0.134970, 0.198193, -0.009770},{0.136109, 0.199021, -0.008122},{
      0.133636, 0.201494, -0.008122},{0.132809, 0.200354, -0.009770}}],
    Polygon[{{0.136109, 0.199021, -0.008122},{0.137026, 0.199686, -0.006273},{
      0.134302, 0.202410, -0.006273},{0.133636, 0.201494, -0.008122}}],
    Polygon[{{0.137026, 0.199686, -0.006273},{0.137697, 0.200174, -0.004270},{
      0.134790, 0.203081, -0.004270},{0.134302, 0.202410, -0.006273}}],
    Polygon[{{0.137697, 0.200174, -0.004270},{0.138107, 0.200472, -0.002162},{
      0.135088, 0.203491, -0.002162},{0.134790, 0.203081, -0.004270}}],
    Polygon[{{0.138107, 0.200472, -0.002162},{0.138244, 0.200572, 0.000000},{
      0.135188, 0.203629, 0.000000},{0.135088, 0.203491, -0.002162}}],
    Polygon[{{0.138244, 0.200572, 0.000000},{0.138107, 0.200472, 0.002162},{
      0.135088, 0.203491, 0.002162},{0.135188, 0.203629, 0.000000}}],
    Polygon[{{0.138107, 0.200472, 0.002162},{0.137697, 0.200174, 0.004270},{
      0.134790, 0.203081, 0.004270},{0.135088, 0.203491, 0.002162}}],
    Polygon[{{0.137697, 0.200174, 0.004270},{0.137026, 0.199686, 0.006273},{
      0.134302, 0.202410, 0.006273},{0.134790, 0.203081, 0.004270}}],
    Polygon[{{0.137026, 0.199686, 0.006273},{0.136109, 0.199021, 0.008122},{
      0.133636, 0.201494, 0.008122},{0.134302, 0.202410, 0.006273}}],
    Polygon[{{0.136109, 0.199021, 0.008122},{0.134970, 0.198193, 0.009770},{
      0.132809, 0.200354, 0.009770},{0.133636, 0.201494, 0.008122}}],
    Polygon[{{0.134970, 0.198193, 0.009770},{0.133636, 0.197224, 0.011178},{
      0.131840, 0.199021, 0.011178},{0.132809, 0.200354, 0.009770}}],
    Polygon[{{0.133636, 0.197224, 0.011178},{0.132141, 0.196137, 0.012311},{
      0.130753, 0.197525, 0.012311},{0.131840, 0.199021, 0.011178}}],
    Polygon[{{0.132141, 0.196137, 0.012311},{0.130520, 0.194960, 0.013141},{
      0.129576, 0.195904, 0.013141},{0.130753, 0.197525, 0.012311}}],
    Polygon[{{0.130520, 0.194960, 0.013141},{0.128815, 0.193721, 0.013647},{
      0.128336, 0.194199, 0.013647},{0.129576, 0.195904, 0.013141}}],
    Polygon[{{0.128336, 0.194199, -0.013647},{0.129576, 0.195904, -0.013141},{
      0.128385, 0.196511, -0.013141},{0.127734, 0.194506, -0.013647}}],
    Polygon[{{0.129576, 0.195904, -0.013141},{0.130753, 0.197525, -0.012311},{
      0.129004, 0.198416, -0.012311},{0.128385, 0.196511, -0.013141}}],
    Polygon[{{0.130753, 0.197525, -0.012311},{0.131840, 0.199021, -0.011178},{
      0.129576, 0.200174, -0.011178},{0.129004, 0.198416, -0.012311}}],
    Polygon[{{0.131840, 0.199021, -0.011178},{0.132809, 0.200354, -0.009770},{
      0.130085, 0.201742, -0.009770},{0.129576, 0.200174, -0.011178}}],
    Polygon[{{0.132809, 0.200354, -0.009770},{0.133636, 0.201494, -0.008122},{
      0.130520, 0.203081, -0.008122},{0.130085, 0.201742, -0.009770}}],
    Polygon[{{0.133636, 0.201494, -0.008122},{0.134302, 0.202410, -0.006273},{
      0.130870, 0.204159, -0.006273},{0.130520, 0.203081, -0.008122}}],
    Polygon[{{0.134302, 0.202410, -0.006273},{0.134790, 0.203081, -0.004270},{
      0.131127, 0.204948, -0.004270},{0.130870, 0.204159, -0.006273}}],
    Polygon[{{0.134790, 0.203081, -0.004270},{0.135088, 0.203491, -0.002162},{
      0.131283, 0.205429, -0.002162},{0.131127, 0.204948, -0.004270}}],
    Polygon[{{0.135088, 0.203491, -0.002162},{0.135188, 0.203629, 0.000000},{
      0.131336, 0.205591, 0.000000},{0.131283, 0.205429, -0.002162}}],
    Polygon[{{0.135188, 0.203629, 0.000000},{0.135088, 0.203491, 0.002162},{
      0.131283, 0.205429, 0.002162},{0.131336, 0.205591, 0.000000}}],
    Polygon[{{0.135088, 0.203491, 0.002162},{0.134790, 0.203081, 0.004270},{
      0.131127, 0.204948, 0.004270},{0.131283, 0.205429, 0.002162}}],
    Polygon[{{0.134790, 0.203081, 0.004270},{0.134302, 0.202410, 0.006273},{
      0.130870, 0.204159, 0.006273},{0.131127, 0.204948, 0.004270}}],
    Polygon[{{0.134302, 0.202410, 0.006273},{0.133636, 0.201494, 0.008122},{
      0.130520, 0.203081, 0.008122},{0.130870, 0.204159, 0.006273}}],
    Polygon[{{0.133636, 0.201494, 0.008122},{0.132809, 0.200354, 0.009770},{
      0.130085, 0.201742, 0.009770},{0.130520, 0.203081, 0.008122}}],
    Polygon[{{0.132809, 0.200354, 0.009770},{0.131840, 0.199021, 0.011178},{
      0.129576, 0.200174, 0.011178},{0.130085, 0.201742, 0.009770}}],
    Polygon[{{0.131840, 0.199021, 0.011178},{0.130753, 0.197525, 0.012311},{
      0.129004, 0.198416, 0.012311},{0.129576, 0.200174, 0.011178}}],
    Polygon[{{0.130753, 0.197525, 0.012311},{0.129576, 0.195904, 0.013141},{
      0.128385, 0.196511, 0.013141},{0.129004, 0.198416, 0.012311}}],
    Polygon[{{0.129576, 0.195904, 0.013141},{0.128336, 0.194199, 0.013647},{
      0.127734, 0.194506, 0.013647},{0.128385, 0.196511, 0.013141}}],
    Polygon[{{0.127734, 0.194506, -0.013647},{0.128385, 0.196511, -0.013141},{
      0.127066, 0.196720, -0.013141},{0.127066, 0.194612, -0.013647}}],
    Polygon[{{0.128385, 0.196511, -0.013141},{0.129004, 0.198416, -0.012311},{
      0.127066, 0.198723, -0.012311},{0.127066, 0.196720, -0.013141}}],
    Polygon[{{0.129004, 0.198416, -0.012311},{0.129576, 0.200174, -0.011178},{
      0.127066, 0.200572, -0.011178},{0.127066, 0.198723, -0.012311}}],
    Polygon[{{0.129576, 0.200174, -0.011178},{0.130085, 0.201742, -0.009770},{
      0.127066, 0.202220, -0.009770},{0.127066, 0.200572, -0.011178}}],
    Polygon[{{0.130085, 0.201742, -0.009770},{0.130520, 0.203081, -0.008122},{
      0.127066, 0.203629, -0.008122},{0.127066, 0.202220, -0.009770}}],
    Polygon[{{0.130520, 0.203081, -0.008122},{0.130870, 0.204159, -0.006273},{
      0.127066, 0.204761, -0.006273},{0.127066, 0.203629, -0.008122}}],
    Polygon[{{0.130870, 0.204159, -0.006273},{0.131127, 0.204948, -0.004270},{
      0.127066, 0.205591, -0.004270},{0.127066, 0.204761, -0.006273}}],
    Polygon[{{0.131127, 0.204948, -0.004270},{0.131283, 0.205429, -0.002162},{
      0.127066, 0.206097, -0.002162},{0.127066, 0.205591, -0.004270}}],
    Polygon[{{0.131283, 0.205429, -0.002162},{0.131336, 0.205591, 0.000000},{
      0.127066, 0.206267, 0.000000},{0.127066, 0.206097, -0.002162}}],
    Polygon[{{0.131336, 0.205591, 0.000000},{0.131283, 0.205429, 0.002162},{
      0.127066, 0.206097, 0.002162},{0.127066, 0.206267, 0.000000}}],
    Polygon[{{0.131283, 0.205429, 0.002162},{0.131127, 0.204948, 0.004270},{
      0.127066, 0.205591, 0.004270},{0.127066, 0.206097, 0.002162}}],
    Polygon[{{0.131127, 0.204948, 0.004270},{0.130870, 0.204159, 0.006273},{
      0.127066, 0.204761, 0.006273},{0.127066, 0.205591, 0.004270}}],
    Polygon[{{0.130870, 0.204159, 0.006273},{0.130520, 0.203081, 0.008122},{
      0.127066, 0.203629, 0.008122},{0.127066, 0.204761, 0.006273}}],
    Polygon[{{0.130520, 0.203081, 0.008122},{0.130085, 0.201742, 0.009770},{
      0.127066, 0.202220, 0.009770},{0.127066, 0.203629, 0.008122}}],
    Polygon[{{0.130085, 0.201742, 0.009770},{0.129576, 0.200174, 0.011178},{
      0.127066, 0.200572, 0.011178},{0.127066, 0.202220, 0.009770}}],
    Polygon[{{0.129576, 0.200174, 0.011178},{0.129004, 0.198416, 0.012311},{
      0.127066, 0.198723, 0.012311},{0.127066, 0.200572, 0.011178}}],
    Polygon[{{0.129004, 0.198416, 0.012311},{0.128385, 0.196511, 0.013141},{
      0.127066, 0.196720, 0.013141},{0.127066, 0.198723, 0.012311}}],
    Polygon[{{0.128385, 0.196511, 0.013141},{0.127734, 0.194506, 0.013647},{
      0.127066, 0.194612, 0.013647},{0.127066, 0.196720, 0.013141}}],
    Polygon[{{0.127066, 0.194612, -0.013647},{0.127066, 0.196720, -0.013141},{
      0.125747, 0.196511, -0.013141},{0.126398, 0.194506, -0.013647}}],
    Polygon[{{0.127066, 0.196720, -0.013141},{0.127066, 0.198723, -0.012311},{
      0.125128, 0.198416, -0.012311},{0.125747, 0.196511, -0.013141}}],
    Polygon[{{0.127066, 0.198723, -0.012311},{0.127066, 0.200572, -0.011178},{
      0.124556, 0.200174, -0.011178},{0.125128, 0.198416, -0.012311}}],
    Polygon[{{0.127066, 0.200572, -0.011178},{0.127066, 0.202220, -0.009770},{
      0.124047, 0.201742, -0.009770},{0.124556, 0.200174, -0.011178}}],
    Polygon[{{0.127066, 0.202220, -0.009770},{0.127066, 0.203629, -0.008122},{
      0.123612, 0.203081, -0.008122},{0.124047, 0.201742, -0.009770}}],
    Polygon[{{0.127066, 0.203629, -0.008122},{0.127066, 0.204761, -0.006273},{
      0.123262, 0.204159, -0.006273},{0.123612, 0.203081, -0.008122}}],
    Polygon[{{0.127066, 0.204761, -0.006273},{0.127066, 0.205591, -0.004270},{
      0.123005, 0.204948, -0.004270},{0.123262, 0.204159, -0.006273}}],
    Polygon[{{0.127066, 0.205591, -0.004270},{0.127066, 0.206097, -0.002162},{
      0.122849, 0.205429, -0.002162},{0.123005, 0.204948, -0.004270}}],
    Polygon[{{0.127066, 0.206097, -0.002162},{0.127066, 0.206267, 0.000000},{
      0.122796, 0.205591, 0.000000},{0.122849, 0.205429, -0.002162}}],
    Polygon[{{0.127066, 0.206267, 0.000000},{0.127066, 0.206097, 0.002162},{
      0.122849, 0.205429, 0.002162},{0.122796, 0.205591, 0.000000}}],
    Polygon[{{0.127066, 0.206097, 0.002162},{0.127066, 0.205591, 0.004270},{
      0.123005, 0.204948, 0.004270},{0.122849, 0.205429, 0.002162}}],
    Polygon[{{0.127066, 0.205591, 0.004270},{0.127066, 0.204761, 0.006273},{
      0.123262, 0.204159, 0.006273},{0.123005, 0.204948, 0.004270}}],
    Polygon[{{0.127066, 0.204761, 0.006273},{0.127066, 0.203629, 0.008122},{
      0.123612, 0.203081, 0.008122},{0.123262, 0.204159, 0.006273}}],
    Polygon[{{0.127066, 0.203629, 0.008122},{0.127066, 0.202220, 0.009770},{
      0.124047, 0.201742, 0.009770},{0.123612, 0.203081, 0.008122}}],
    Polygon[{{0.127066, 0.202220, 0.009770},{0.127066, 0.200572, 0.011178},{
      0.124556, 0.200174, 0.011178},{0.124047, 0.201742, 0.009770}}],
    Polygon[{{0.127066, 0.200572, 0.011178},{0.127066, 0.198723, 0.012311},{
      0.125128, 0.198416, 0.012311},{0.124556, 0.200174, 0.011178}}],
    Polygon[{{0.127066, 0.198723, 0.012311},{0.127066, 0.196720, 0.013141},{
      0.125747, 0.196511, 0.013141},{0.125128, 0.198416, 0.012311}}],
    Polygon[{{0.127066, 0.196720, 0.013141},{0.127066, 0.194612, 0.013647},{
      0.126398, 0.194506, 0.013647},{0.125747, 0.196511, 0.013141}}],
    Polygon[{{0.126398, 0.194506, -0.013647},{0.125747, 0.196511, -0.013141},{
      0.124556, 0.195904, -0.013141},{0.125795, 0.194199, -0.013647}}],
    Polygon[{{0.125747, 0.196511, -0.013141},{0.125128, 0.198416, -0.012311},{
      0.123379, 0.197525, -0.012311},{0.124556, 0.195904, -0.013141}}],
    Polygon[{{0.125128, 0.198416, -0.012311},{0.124556, 0.200174, -0.011178},{
      0.122292, 0.199021, -0.011178},{0.123379, 0.197525, -0.012311}}],
    Polygon[{{0.124556, 0.200174, -0.011178},{0.124047, 0.201742, -0.009770},{
      0.121323, 0.200354, -0.009770},{0.122292, 0.199021, -0.011178}}],
    Polygon[{{0.124047, 0.201742, -0.009770},{0.123612, 0.203081, -0.008122},{
      0.120495, 0.201494, -0.008122},{0.121323, 0.200354, -0.009770}}],
    Polygon[{{0.123612, 0.203081, -0.008122},{0.123262, 0.204159, -0.006273},{
      0.119830, 0.202410, -0.006273},{0.120495, 0.201494, -0.008122}}],
    Polygon[{{0.123262, 0.204159, -0.006273},{0.123005, 0.204948, -0.004270},{
      0.119342, 0.203081, -0.004270},{0.119830, 0.202410, -0.006273}}],
    Polygon[{{0.123005, 0.204948, -0.004270},{0.122849, 0.205429, -0.002162},{
      0.119044, 0.203491, -0.002162},{0.119342, 0.203081, -0.004270}}],
    Polygon[{{0.122849, 0.205429, -0.002162},{0.122796, 0.205591, 0.000000},{
      0.118944, 0.203629, 0.000000},{0.119044, 0.203491, -0.002162}}],
    Polygon[{{0.122796, 0.205591, 0.000000},{0.122849, 0.205429, 0.002162},{
      0.119044, 0.203491, 0.002162},{0.118944, 0.203629, 0.000000}}],
    Polygon[{{0.122849, 0.205429, 0.002162},{0.123005, 0.204948, 0.004270},{
      0.119342, 0.203081, 0.004270},{0.119044, 0.203491, 0.002162}}],
    Polygon[{{0.123005, 0.204948, 0.004270},{0.123262, 0.204159, 0.006273},{
      0.119830, 0.202410, 0.006273},{0.119342, 0.203081, 0.004270}}],
    Polygon[{{0.123262, 0.204159, 0.006273},{0.123612, 0.203081, 0.008122},{
      0.120495, 0.201494, 0.008122},{0.119830, 0.202410, 0.006273}}],
    Polygon[{{0.123612, 0.203081, 0.008122},{0.124047, 0.201742, 0.009770},{
      0.121323, 0.200354, 0.009770},{0.120495, 0.201494, 0.008122}}],
    Polygon[{{0.124047, 0.201742, 0.009770},{0.124556, 0.200174, 0.011178},{
      0.122292, 0.199021, 0.011178},{0.121323, 0.200354, 0.009770}}],
    Polygon[{{0.124556, 0.200174, 0.011178},{0.125128, 0.198416, 0.012311},{
      0.123379, 0.197525, 0.012311},{0.122292, 0.199021, 0.011178}}],
    Polygon[{{0.125128, 0.198416, 0.012311},{0.125747, 0.196511, 0.013141},{
      0.124556, 0.195904, 0.013141},{0.123379, 0.197525, 0.012311}}],
    Polygon[{{0.125747, 0.196511, 0.013141},{0.126398, 0.194506, 0.013647},{
      0.125795, 0.194199, 0.013647},{0.124556, 0.195904, 0.013141}}],
    Polygon[{{0.125795, 0.194199, -0.013647},{0.124556, 0.195904, -0.013141},{
      0.123612, 0.194960, -0.013141},{0.125317, 0.193721, -0.013647}}],
    Polygon[{{0.124556, 0.195904, -0.013141},{0.123379, 0.197525, -0.012311},{
      0.121991, 0.196137, -0.012311},{0.123612, 0.194960, -0.013141}}],
    Polygon[{{0.123379, 0.197525, -0.012311},{0.122292, 0.199021, -0.011178},{
      0.120495, 0.197224, -0.011178},{0.121991, 0.196137, -0.012311}}],
    Polygon[{{0.122292, 0.199021, -0.011178},{0.121323, 0.200354, -0.009770},{
      0.119162, 0.198193, -0.009770},{0.120495, 0.197224, -0.011178}}],
    Polygon[{{0.121323, 0.200354, -0.009770},{0.120495, 0.201494, -0.008122},{
      0.118022, 0.199021, -0.008122},{0.119162, 0.198193, -0.009770}}],
    Polygon[{{0.120495, 0.201494, -0.008122},{0.119830, 0.202410, -0.006273},{
      0.117106, 0.199686, -0.006273},{0.118022, 0.199021, -0.008122}}],
    Polygon[{{0.119830, 0.202410, -0.006273},{0.119342, 0.203081, -0.004270},{
      0.116435, 0.200174, -0.004270},{0.117106, 0.199686, -0.006273}}],
    Polygon[{{0.119342, 0.203081, -0.004270},{0.119044, 0.203491, -0.002162},{
      0.116025, 0.200472, -0.002162},{0.116435, 0.200174, -0.004270}}],
    Polygon[{{0.119044, 0.203491, -0.002162},{0.118944, 0.203629, 0.000000},{
      0.115888, 0.200572, 0.000000},{0.116025, 0.200472, -0.002162}}],
    Polygon[{{0.118944, 0.203629, 0.000000},{0.119044, 0.203491, 0.002162},{
      0.116025, 0.200472, 0.002162},{0.115888, 0.200572, 0.000000}}],
    Polygon[{{0.119044, 0.203491, 0.002162},{0.119342, 0.203081, 0.004270},{
      0.116435, 0.200174, 0.004270},{0.116025, 0.200472, 0.002162}}],
    Polygon[{{0.119342, 0.203081, 0.004270},{0.119830, 0.202410, 0.006273},{
      0.117106, 0.199686, 0.006273},{0.116435, 0.200174, 0.004270}}],
    Polygon[{{0.119830, 0.202410, 0.006273},{0.120495, 0.201494, 0.008122},{
      0.118022, 0.199021, 0.008122},{0.117106, 0.199686, 0.006273}}],
    Polygon[{{0.120495, 0.201494, 0.008122},{0.121323, 0.200354, 0.009770},{
      0.119162, 0.198193, 0.009770},{0.118022, 0.199021, 0.008122}}],
    Polygon[{{0.121323, 0.200354, 0.009770},{0.122292, 0.199021, 0.011178},{
      0.120495, 0.197224, 0.011178},{0.119162, 0.198193, 0.009770}}],
    Polygon[{{0.122292, 0.199021, 0.011178},{0.123379, 0.197525, 0.012311},{
      0.121991, 0.196137, 0.012311},{0.120495, 0.197224, 0.011178}}],
    Polygon[{{0.123379, 0.197525, 0.012311},{0.124556, 0.195904, 0.013141},{
      0.123612, 0.194960, 0.013141},{0.121991, 0.196137, 0.012311}}],
    Polygon[{{0.124556, 0.195904, 0.013141},{0.125795, 0.194199, 0.013647},{
      0.125317, 0.193721, 0.013647},{0.123612, 0.194960, 0.013141}}],
    Polygon[{{0.125317, 0.193721, -0.013647},{0.123612, 0.194960, -0.013141},{
      0.123005, 0.193770, -0.013141},{0.125010, 0.193118, -0.013647}}],
    Polygon[{{0.123612, 0.194960, -0.013141},{0.121991, 0.196137, -0.012311},{
      0.121100, 0.194389, -0.012311},{0.123005, 0.193770, -0.013141}}],
    Polygon[{{0.121991, 0.196137, -0.012311},{0.120495, 0.197224, -0.011178},{
      0.119342, 0.194960, -0.011178},{0.121100, 0.194389, -0.012311}}],
    Polygon[{{0.120495, 0.197224, -0.011178},{0.119162, 0.198193, -0.009770},{
      0.117774, 0.195469, -0.009770},{0.119342, 0.194960, -0.011178}}],
    Polygon[{{0.119162, 0.198193, -0.009770},{0.118022, 0.199021, -0.008122},{
      0.116435, 0.195904, -0.008122},{0.117774, 0.195469, -0.009770}}],
    Polygon[{{0.118022, 0.199021, -0.008122},{0.117106, 0.199686, -0.006273},{
      0.115357, 0.196254, -0.006273},{0.116435, 0.195904, -0.008122}}],
    Polygon[{{0.117106, 0.199686, -0.006273},{0.116435, 0.200174, -0.004270},{
      0.114568, 0.196511, -0.004270},{0.115357, 0.196254, -0.006273}}],
    Polygon[{{0.116435, 0.200174, -0.004270},{0.116025, 0.200472, -0.002162},{
      0.114087, 0.196667, -0.002162},{0.114568, 0.196511, -0.004270}}],
    Polygon[{{0.116025, 0.200472, -0.002162},{0.115888, 0.200572, 0.000000},{
      0.113925, 0.196720, 0.000000},{0.114087, 0.196667, -0.002162}}],
    Polygon[{{0.115888, 0.200572, 0.000000},{0.116025, 0.200472, 0.002162},{
      0.114087, 0.196667, 0.002162},{0.113925, 0.196720, 0.000000}}],
    Polygon[{{0.116025, 0.200472, 0.002162},{0.116435, 0.200174, 0.004270},{
      0.114568, 0.196511, 0.004270},{0.114087, 0.196667, 0.002162}}],
    Polygon[{{0.116435, 0.200174, 0.004270},{0.117106, 0.199686, 0.006273},{
      0.115357, 0.196254, 0.006273},{0.114568, 0.196511, 0.004270}}],
    Polygon[{{0.117106, 0.199686, 0.006273},{0.118022, 0.199021, 0.008122},{
      0.116435, 0.195904, 0.008122},{0.115357, 0.196254, 0.006273}}],
    Polygon[{{0.118022, 0.199021, 0.008122},{0.119162, 0.198193, 0.009770},{
      0.117774, 0.195469, 0.009770},{0.116435, 0.195904, 0.008122}}],
    Polygon[{{0.119162, 0.198193, 0.009770},{0.120495, 0.197224, 0.011178},{
      0.119342, 0.194960, 0.011178},{0.117774, 0.195469, 0.009770}}],
    Polygon[{{0.120495, 0.197224, 0.011178},{0.121991, 0.196137, 0.012311},{
      0.121100, 0.194389, 0.012311},{0.119342, 0.194960, 0.011178}}],
    Polygon[{{0.121991, 0.196137, 0.012311},{0.123612, 0.194960, 0.013141},{
      0.123005, 0.193770, 0.013141},{0.121100, 0.194389, 0.012311}}],
    Polygon[{{0.123612, 0.194960, 0.013141},{0.125317, 0.193721, 0.013647},{
      0.125010, 0.193118, 0.013647},{0.123005, 0.193770, 0.013141}}],
    Polygon[{{0.125010, 0.193118, -0.013647},{0.123005, 0.193770, -0.013141},{
      0.122796, 0.192450, -0.013141},{0.124904, 0.192450, -0.013647}}],
    Polygon[{{0.123005, 0.193770, -0.013141},{0.121100, 0.194389, -0.012311},{
      0.120793, 0.192450, -0.012311},{0.122796, 0.192450, -0.013141}}],
    Polygon[{{0.121100, 0.194389, -0.012311},{0.119342, 0.194960, -0.011178},{
      0.118944, 0.192450, -0.011178},{0.120793, 0.192450, -0.012311}}],
    Polygon[{{0.119342, 0.194960, -0.011178},{0.117774, 0.195469, -0.009770},{
      0.117296, 0.192450, -0.009770},{0.118944, 0.192450, -0.011178}}],
    Polygon[{{0.117774, 0.195469, -0.009770},{0.116435, 0.195904, -0.008122},{
      0.115888, 0.192450, -0.008122},{0.117296, 0.192450, -0.009770}}],
    Polygon[{{0.116435, 0.195904, -0.008122},{0.115357, 0.196254, -0.006273},{
      0.114755, 0.192450, -0.006273},{0.115888, 0.192450, -0.008122}}],
    Polygon[{{0.115357, 0.196254, -0.006273},{0.114568, 0.196511, -0.004270},{
      0.113925, 0.192450, -0.004270},{0.114755, 0.192450, -0.006273}}],
    Polygon[{{0.114568, 0.196511, -0.004270},{0.114087, 0.196667, -0.002162},{
      0.113419, 0.192450, -0.002162},{0.113925, 0.192450, -0.004270}}],
    Polygon[{{0.114087, 0.196667, -0.002162},{0.113925, 0.196720, 0.000000},{
      0.113249, 0.192450, 0.000000},{0.113419, 0.192450, -0.002162}}],
    Polygon[{{0.113925, 0.196720, 0.000000},{0.114087, 0.196667, 0.002162},{
      0.113419, 0.192450, 0.002162},{0.113249, 0.192450, 0.000000}}],
    Polygon[{{0.114087, 0.196667, 0.002162},{0.114568, 0.196511, 0.004270},{
      0.113925, 0.192450, 0.004270},{0.113419, 0.192450, 0.002162}}],
    Polygon[{{0.114568, 0.196511, 0.004270},{0.115357, 0.196254, 0.006273},{
      0.114755, 0.192450, 0.006273},{0.113925, 0.192450, 0.004270}}],
    Polygon[{{0.115357, 0.196254, 0.006273},{0.116435, 0.195904, 0.008122},{
      0.115888, 0.192450, 0.008122},{0.114755, 0.192450, 0.006273}}],
    Polygon[{{0.116435, 0.195904, 0.008122},{0.117774, 0.195469, 0.009770},{
      0.117296, 0.192450, 0.009770},{0.115888, 0.192450, 0.008122}}],
    Polygon[{{0.117774, 0.195469, 0.009770},{0.119342, 0.194960, 0.011178},{
      0.118944, 0.192450, 0.011178},{0.117296, 0.192450, 0.009770}}],
    Polygon[{{0.119342, 0.194960, 0.011178},{0.121100, 0.194389, 0.012311},{
      0.120793, 0.192450, 0.012311},{0.118944, 0.192450, 0.011178}}],
    Polygon[{{0.121100, 0.194389, 0.012311},{0.123005, 0.193770, 0.013141},{
      0.122796, 0.192450, 0.013141},{0.120793, 0.192450, 0.012311}}],
    Polygon[{{0.123005, 0.193770, 0.013141},{0.125010, 0.193118, 0.013647},{
      0.124904, 0.192450, 0.013647},{0.122796, 0.192450, 0.013141}}],
    Polygon[{{0.124904, 0.192450, -0.013647},{0.122796, 0.192450, -0.013141},{
      0.123005, 0.191131, -0.013141},{0.125010, 0.191782, -0.013647}}],
    Polygon[{{0.122796, 0.192450, -0.013141},{0.120793, 0.192450, -0.012311},{
      0.121100, 0.190512, -0.012311},{0.123005, 0.191131, -0.013141}}],
    Polygon[{{0.120793, 0.192450, -0.012311},{0.118944, 0.192450, -0.011178},{
      0.119342, 0.189940, -0.011178},{0.121100, 0.190512, -0.012311}}],
    Polygon[{{0.118944, 0.192450, -0.011178},{0.117296, 0.192450, -0.009770},{
      0.117774, 0.189431, -0.009770},{0.119342, 0.189940, -0.011178}}],
    Polygon[{{0.117296, 0.192450, -0.009770},{0.115888, 0.192450, -0.008122},{
      0.116435, 0.188996, -0.008122},{0.117774, 0.189431, -0.009770}}],
    Polygon[{{0.115888, 0.192450, -0.008122},{0.114755, 0.192450, -0.006273},{
      0.115357, 0.188646, -0.006273},{0.116435, 0.188996, -0.008122}}],
    Polygon[{{0.114755, 0.192450, -0.006273},{0.113925, 0.192450, -0.004270},{
      0.114568, 0.188389, -0.004270},{0.115357, 0.188646, -0.006273}}],
    Polygon[{{0.113925, 0.192450, -0.004270},{0.113419, 0.192450, -0.002162},{
      0.114087, 0.188233, -0.002162},{0.114568, 0.188389, -0.004270}}],
    Polygon[{{0.113419, 0.192450, -0.002162},{0.113249, 0.192450, 0.000000},{
      0.113925, 0.188180, 0.000000},{0.114087, 0.188233, -0.002162}}],
    Polygon[{{0.113249, 0.192450, 0.000000},{0.113419, 0.192450, 0.002162},{
      0.114087, 0.188233, 0.002162},{0.113925, 0.188180, 0.000000}}],
    Polygon[{{0.113419, 0.192450, 0.002162},{0.113925, 0.192450, 0.004270},{
      0.114568, 0.188389, 0.004270},{0.114087, 0.188233, 0.002162}}],
    Polygon[{{0.113925, 0.192450, 0.004270},{0.114755, 0.192450, 0.006273},{
      0.115357, 0.188646, 0.006273},{0.114568, 0.188389, 0.004270}}],
    Polygon[{{0.114755, 0.192450, 0.006273},{0.115888, 0.192450, 0.008122},{
      0.116435, 0.188996, 0.008122},{0.115357, 0.188646, 0.006273}}],
    Polygon[{{0.115888, 0.192450, 0.008122},{0.117296, 0.192450, 0.009770},{
      0.117774, 0.189431, 0.009770},{0.116435, 0.188996, 0.008122}}],
    Polygon[{{0.117296, 0.192450, 0.009770},{0.118944, 0.192450, 0.011178},{
      0.119342, 0.189940, 0.011178},{0.117774, 0.189431, 0.009770}}],
    Polygon[{{0.118944, 0.192450, 0.011178},{0.120793, 0.192450, 0.012311},{
      0.121100, 0.190512, 0.012311},{0.119342, 0.189940, 0.011178}}],
    Polygon[{{0.120793, 0.192450, 0.012311},{0.122796, 0.192450, 0.013141},{
      0.123005, 0.191131, 0.013141},{0.121100, 0.190512, 0.012311}}],
    Polygon[{{0.122796, 0.192450, 0.013141},{0.124904, 0.192450, 0.013647},{
      0.125010, 0.191782, 0.013647},{0.123005, 0.191131, 0.013141}}],
    Polygon[{{0.125010, 0.191782, -0.013647},{0.123005, 0.191131, -0.013141},{
      0.123612, 0.189940, -0.013141},{0.125317, 0.191180, -0.013647}}],
    Polygon[{{0.123005, 0.191131, -0.013141},{0.121100, 0.190512, -0.012311},{
      0.121991, 0.188763, -0.012311},{0.123612, 0.189940, -0.013141}}],
    Polygon[{{0.121100, 0.190512, -0.012311},{0.119342, 0.189940, -0.011178},{
      0.120495, 0.187676, -0.011178},{0.121991, 0.188763, -0.012311}}],
    Polygon[{{0.119342, 0.189940, -0.011178},{0.117774, 0.189431, -0.009770},{
      0.119162, 0.186707, -0.009770},{0.120495, 0.187676, -0.011178}}],
    Polygon[{{0.117774, 0.189431, -0.009770},{0.116435, 0.188996, -0.008122},{
      0.118022, 0.185880, -0.008122},{0.119162, 0.186707, -0.009770}}],
    Polygon[{{0.116435, 0.188996, -0.008122},{0.115357, 0.188646, -0.006273},{
      0.117106, 0.185214, -0.006273},{0.118022, 0.185880, -0.008122}}],
    Polygon[{{0.115357, 0.188646, -0.006273},{0.114568, 0.188389, -0.004270},{
      0.116435, 0.184726, -0.004270},{0.117106, 0.185214, -0.006273}}],
    Polygon[{{0.114568, 0.188389, -0.004270},{0.114087, 0.188233, -0.002162},{
      0.116025, 0.184428, -0.002162},{0.116435, 0.184726, -0.004270}}],
    Polygon[{{0.114087, 0.188233, -0.002162},{0.113925, 0.188180, 0.000000},{
      0.115888, 0.184328, 0.000000},{0.116025, 0.184428, -0.002162}}],
    Polygon[{{0.113925, 0.188180, 0.000000},{0.114087, 0.188233, 0.002162},{
      0.116025, 0.184428, 0.002162},{0.115888, 0.184328, 0.000000}}],
    Polygon[{{0.114087, 0.188233, 0.002162},{0.114568, 0.188389, 0.004270},{
      0.116435, 0.184726, 0.004270},{0.116025, 0.184428, 0.002162}}],
    Polygon[{{0.114568, 0.188389, 0.004270},{0.115357, 0.188646, 0.006273},{
      0.117106, 0.185214, 0.006273},{0.116435, 0.184726, 0.004270}}],
    Polygon[{{0.115357, 0.188646, 0.006273},{0.116435, 0.188996, 0.008122},{
      0.118022, 0.185880, 0.008122},{0.117106, 0.185214, 0.006273}}],
    Polygon[{{0.116435, 0.188996, 0.008122},{0.117774, 0.189431, 0.009770},{
      0.119162, 0.186707, 0.009770},{0.118022, 0.185880, 0.008122}}],
    Polygon[{{0.117774, 0.189431, 0.009770},{0.119342, 0.189940, 0.011178},{
      0.120495, 0.187676, 0.011178},{0.119162, 0.186707, 0.009770}}],
    Polygon[{{0.119342, 0.189940, 0.011178},{0.121100, 0.190512, 0.012311},{
      0.121991, 0.188763, 0.012311},{0.120495, 0.187676, 0.011178}}],
    Polygon[{{0.121100, 0.190512, 0.012311},{0.123005, 0.191131, 0.013141},{
      0.123612, 0.189940, 0.013141},{0.121991, 0.188763, 0.012311}}],
    Polygon[{{0.123005, 0.191131, 0.013141},{0.125010, 0.191782, 0.013647},{
      0.125317, 0.191180, 0.013647},{0.123612, 0.189940, 0.013141}}],
    Polygon[{{0.125317, 0.191180, -0.013647},{0.123612, 0.189940, -0.013141},{
      0.124556, 0.188996, -0.013141},{0.125795, 0.190701, -0.013647}}],
    Polygon[{{0.123612, 0.189940, -0.013141},{0.121991, 0.188763, -0.012311},{
      0.123379, 0.187375, -0.012311},{0.124556, 0.188996, -0.013141}}],
    Polygon[{{0.121991, 0.188763, -0.012311},{0.120495, 0.187676, -0.011178},{
      0.122292, 0.185880, -0.011178},{0.123379, 0.187375, -0.012311}}],
    Polygon[{{0.120495, 0.187676, -0.011178},{0.119162, 0.186707, -0.009770},{
      0.121323, 0.184546, -0.009770},{0.122292, 0.185880, -0.011178}}],
    Polygon[{{0.119162, 0.186707, -0.009770},{0.118022, 0.185880, -0.008122},{
      0.120495, 0.183407, -0.008122},{0.121323, 0.184546, -0.009770}}],
    Polygon[{{0.118022, 0.185880, -0.008122},{0.117106, 0.185214, -0.006273},{
      0.119830, 0.182490, -0.006273},{0.120495, 0.183407, -0.008122}}],
    Polygon[{{0.117106, 0.185214, -0.006273},{0.116435, 0.184726, -0.004270},{
      0.119342, 0.181819, -0.004270},{0.119830, 0.182490, -0.006273}}],
    Polygon[{{0.116435, 0.184726, -0.004270},{0.116025, 0.184428, -0.002162},{
      0.119044, 0.181409, -0.002162},{0.119342, 0.181819, -0.004270}}],
    Polygon[{{0.116025, 0.184428, -0.002162},{0.115888, 0.184328, 0.000000},{
      0.118944, 0.181272, 0.000000},{0.119044, 0.181409, -0.002162}}],
    Polygon[{{0.115888, 0.184328, 0.000000},{0.116025, 0.184428, 0.002162},{
      0.119044, 0.181409, 0.002162},{0.118944, 0.181272, 0.000000}}],
    Polygon[{{0.116025, 0.184428, 0.002162},{0.116435, 0.184726, 0.004270},{
      0.119342, 0.181819, 0.004270},{0.119044, 0.181409, 0.002162}}],
    Polygon[{{0.116435, 0.184726, 0.004270},{0.117106, 0.185214, 0.006273},{
      0.119830, 0.182490, 0.006273},{0.119342, 0.181819, 0.004270}}],
    Polygon[{{0.117106, 0.185214, 0.006273},{0.118022, 0.185880, 0.008122},{
      0.120495, 0.183407, 0.008122},{0.119830, 0.182490, 0.006273}}],
    Polygon[{{0.118022, 0.185880, 0.008122},{0.119162, 0.186707, 0.009770},{
      0.121323, 0.184546, 0.009770},{0.120495, 0.183407, 0.008122}}],
    Polygon[{{0.119162, 0.186707, 0.009770},{0.120495, 0.187676, 0.011178},{
      0.122292, 0.185880, 0.011178},{0.121323, 0.184546, 0.009770}}],
    Polygon[{{0.120495, 0.187676, 0.011178},{0.121991, 0.188763, 0.012311},{
      0.123379, 0.187375, 0.012311},{0.122292, 0.185880, 0.011178}}],
    Polygon[{{0.121991, 0.188763, 0.012311},{0.123612, 0.189940, 0.013141},{
      0.124556, 0.188996, 0.013141},{0.123379, 0.187375, 0.012311}}],
    Polygon[{{0.123612, 0.189940, 0.013141},{0.125317, 0.191180, 0.013647},{
      0.125795, 0.190701, 0.013647},{0.124556, 0.188996, 0.013141}}],
    Polygon[{{0.125795, 0.190701, -0.013647},{0.124556, 0.188996, -0.013141},{
      0.125747, 0.188389, -0.013141},{0.126398, 0.190394, -0.013647}}],
    Polygon[{{0.124556, 0.188996, -0.013141},{0.123379, 0.187375, -0.012311},{
      0.125128, 0.186484, -0.012311},{0.125747, 0.188389, -0.013141}}],
    Polygon[{{0.123379, 0.187375, -0.012311},{0.122292, 0.185880, -0.011178},{
      0.124556, 0.184726, -0.011178},{0.125128, 0.186484, -0.012311}}],
    Polygon[{{0.122292, 0.185880, -0.011178},{0.121323, 0.184546, -0.009770},{
      0.124047, 0.183158, -0.009770},{0.124556, 0.184726, -0.011178}}],
    Polygon[{{0.121323, 0.184546, -0.009770},{0.120495, 0.183407, -0.008122},{
      0.123612, 0.181819, -0.008122},{0.124047, 0.183158, -0.009770}}],
    Polygon[{{0.120495, 0.183407, -0.008122},{0.119830, 0.182490, -0.006273},{
      0.123262, 0.180741, -0.006273},{0.123612, 0.181819, -0.008122}}],
    Polygon[{{0.119830, 0.182490, -0.006273},{0.119342, 0.181819, -0.004270},{
      0.123005, 0.179952, -0.004270},{0.123262, 0.180741, -0.006273}}],
    Polygon[{{0.119342, 0.181819, -0.004270},{0.119044, 0.181409, -0.002162},{
      0.122849, 0.179471, -0.002162},{0.123005, 0.179952, -0.004270}}],
    Polygon[{{0.119044, 0.181409, -0.002162},{0.118944, 0.181272, 0.000000},{
      0.122796, 0.179309, 0.000000},{0.122849, 0.179471, -0.002162}}],
    Polygon[{{0.118944, 0.181272, 0.000000},{0.119044, 0.181409, 0.002162},{
      0.122849, 0.179471, 0.002162},{0.122796, 0.179309, 0.000000}}],
    Polygon[{{0.119044, 0.181409, 0.002162},{0.119342, 0.181819, 0.004270},{
      0.123005, 0.179952, 0.004270},{0.122849, 0.179471, 0.002162}}],
    Polygon[{{0.119342, 0.181819, 0.004270},{0.119830, 0.182490, 0.006273},{
      0.123262, 0.180741, 0.006273},{0.123005, 0.179952, 0.004270}}],
    Polygon[{{0.119830, 0.182490, 0.006273},{0.120495, 0.183407, 0.008122},{
      0.123612, 0.181819, 0.008122},{0.123262, 0.180741, 0.006273}}],
    Polygon[{{0.120495, 0.183407, 0.008122},{0.121323, 0.184546, 0.009770},{
      0.124047, 0.183158, 0.009770},{0.123612, 0.181819, 0.008122}}],
    Polygon[{{0.121323, 0.184546, 0.009770},{0.122292, 0.185880, 0.011178},{
      0.124556, 0.184726, 0.011178},{0.124047, 0.183158, 0.009770}}],
    Polygon[{{0.122292, 0.185880, 0.011178},{0.123379, 0.187375, 0.012311},{
      0.125128, 0.186484, 0.012311},{0.124556, 0.184726, 0.011178}}],
    Polygon[{{0.123379, 0.187375, 0.012311},{0.124556, 0.188996, 0.013141},{
      0.125747, 0.188389, 0.013141},{0.125128, 0.186484, 0.012311}}],
    Polygon[{{0.124556, 0.188996, 0.013141},{0.125795, 0.190701, 0.013647},{
      0.126398, 0.190394, 0.013647},{0.125747, 0.188389, 0.013141}}],
    Polygon[{{0.126398, 0.190394, -0.013647},{0.125747, 0.188389, -0.013141},{
      0.127066, 0.188180, -0.013141},{0.127066, 0.190289, -0.013647}}],
    Polygon[{{0.125747, 0.188389, -0.013141},{0.125128, 0.186484, -0.012311},{
      0.127066, 0.186177, -0.012311},{0.127066, 0.188180, -0.013141}}],
    Polygon[{{0.125128, 0.186484, -0.012311},{0.124556, 0.184726, -0.011178},{
      0.127066, 0.184328, -0.011178},{0.127066, 0.186177, -0.012311}}],
    Polygon[{{0.124556, 0.184726, -0.011178},{0.124047, 0.183158, -0.009770},{
      0.127066, 0.182680, -0.009770},{0.127066, 0.184328, -0.011178}}],
    Polygon[{{0.124047, 0.183158, -0.009770},{0.123612, 0.181819, -0.008122},{
      0.127066, 0.181272, -0.008122},{0.127066, 0.182680, -0.009770}}],
    Polygon[{{0.123612, 0.181819, -0.008122},{0.123262, 0.180741, -0.006273},{
      0.127066, 0.180139, -0.006273},{0.127066, 0.181272, -0.008122}}],
    Polygon[{{0.123262, 0.180741, -0.006273},{0.123005, 0.179952, -0.004270},{
      0.127066, 0.179309, -0.004270},{0.127066, 0.180139, -0.006273}}],
    Polygon[{{0.123005, 0.179952, -0.004270},{0.122849, 0.179471, -0.002162},{
      0.127066, 0.178803, -0.002162},{0.127066, 0.179309, -0.004270}}],
    Polygon[{{0.122849, 0.179471, -0.002162},{0.122796, 0.179309, 0.000000},{
      0.127066, 0.178633, 0.000000},{0.127066, 0.178803, -0.002162}}],
    Polygon[{{0.122796, 0.179309, 0.000000},{0.122849, 0.179471, 0.002162},{
      0.127066, 0.178803, 0.002162},{0.127066, 0.178633, 0.000000}}],
    Polygon[{{0.122849, 0.179471, 0.002162},{0.123005, 0.179952, 0.004270},{
      0.127066, 0.179309, 0.004270},{0.127066, 0.178803, 0.002162}}],
    Polygon[{{0.123005, 0.179952, 0.004270},{0.123262, 0.180741, 0.006273},{
      0.127066, 0.180139, 0.006273},{0.127066, 0.179309, 0.004270}}],
    Polygon[{{0.123262, 0.180741, 0.006273},{0.123612, 0.181819, 0.008122},{
      0.127066, 0.181272, 0.008122},{0.127066, 0.180139, 0.006273}}],
    Polygon[{{0.123612, 0.181819, 0.008122},{0.124047, 0.183158, 0.009770},{
      0.127066, 0.182680, 0.009770},{0.127066, 0.181272, 0.008122}}],
    Polygon[{{0.124047, 0.183158, 0.009770},{0.124556, 0.184726, 0.011178},{
      0.127066, 0.184328, 0.011178},{0.127066, 0.182680, 0.009770}}],
    Polygon[{{0.124556, 0.184726, 0.011178},{0.125128, 0.186484, 0.012311},{
      0.127066, 0.186177, 0.012311},{0.127066, 0.184328, 0.011178}}],
    Polygon[{{0.125128, 0.186484, 0.012311},{0.125747, 0.188389, 0.013141},{
      0.127066, 0.188180, 0.013141},{0.127066, 0.186177, 0.012311}}],
    Polygon[{{0.125747, 0.188389, 0.013141},{0.126398, 0.190394, 0.013647},{
      0.127066, 0.190289, 0.013647},{0.127066, 0.188180, 0.013141}}],
    Polygon[{{0.127066, 0.190289, -0.013647},{0.127066, 0.188180, -0.013141},{
      0.128385, 0.188389, -0.013141},{0.127734, 0.190394, -0.013647}}],
    Polygon[{{0.127066, 0.188180, -0.013141},{0.127066, 0.186177, -0.012311},{
      0.129004, 0.186484, -0.012311},{0.128385, 0.188389, -0.013141}}],
    Polygon[{{0.127066, 0.186177, -0.012311},{0.127066, 0.184328, -0.011178},{
      0.129576, 0.184726, -0.011178},{0.129004, 0.186484, -0.012311}}],
    Polygon[{{0.127066, 0.184328, -0.011178},{0.127066, 0.182680, -0.009770},{
      0.130085, 0.183158, -0.009770},{0.129576, 0.184726, -0.011178}}],
    Polygon[{{0.127066, 0.182680, -0.009770},{0.127066, 0.181272, -0.008122},{
      0.130520, 0.181819, -0.008122},{0.130085, 0.183158, -0.009770}}],
    Polygon[{{0.127066, 0.181272, -0.008122},{0.127066, 0.180139, -0.006273},{
      0.130870, 0.180741, -0.006273},{0.130520, 0.181819, -0.008122}}],
    Polygon[{{0.127066, 0.180139, -0.006273},{0.127066, 0.179309, -0.004270},{
      0.131127, 0.179952, -0.004270},{0.130870, 0.180741, -0.006273}}],
    Polygon[{{0.127066, 0.179309, -0.004270},{0.127066, 0.178803, -0.002162},{
      0.131283, 0.179471, -0.002162},{0.131127, 0.179952, -0.004270}}],
    Polygon[{{0.127066, 0.178803, -0.002162},{0.127066, 0.178633, 0.000000},{
      0.131336, 0.179309, 0.000000},{0.131283, 0.179471, -0.002162}}],
    Polygon[{{0.127066, 0.178633, 0.000000},{0.127066, 0.178803, 0.002162},{
      0.131283, 0.179471, 0.002162},{0.131336, 0.179309, 0.000000}}],
    Polygon[{{0.127066, 0.178803, 0.002162},{0.127066, 0.179309, 0.004270},{
      0.131127, 0.179952, 0.004270},{0.131283, 0.179471, 0.002162}}],
    Polygon[{{0.127066, 0.179309, 0.004270},{0.127066, 0.180139, 0.006273},{
      0.130870, 0.180741, 0.006273},{0.131127, 0.179952, 0.004270}}],
    Polygon[{{0.127066, 0.180139, 0.006273},{0.127066, 0.181272, 0.008122},{
      0.130520, 0.181819, 0.008122},{0.130870, 0.180741, 0.006273}}],
    Polygon[{{0.127066, 0.181272, 0.008122},{0.127066, 0.182680, 0.009770},{
      0.130085, 0.183158, 0.009770},{0.130520, 0.181819, 0.008122}}],
    Polygon[{{0.127066, 0.182680, 0.009770},{0.127066, 0.184328, 0.011178},{
      0.129576, 0.184726, 0.011178},{0.130085, 0.183158, 0.009770}}],
    Polygon[{{0.127066, 0.184328, 0.011178},{0.127066, 0.186177, 0.012311},{
      0.129004, 0.186484, 0.012311},{0.129576, 0.184726, 0.011178}}],
    Polygon[{{0.127066, 0.186177, 0.012311},{0.127066, 0.188180, 0.013141},{
      0.128385, 0.188389, 0.013141},{0.129004, 0.186484, 0.012311}}],
    Polygon[{{0.127066, 0.188180, 0.013141},{0.127066, 0.190289, 0.013647},{
      0.127734, 0.190394, 0.013647},{0.128385, 0.188389, 0.013141}}],
    Polygon[{{0.127734, 0.190394, -0.013647},{0.128385, 0.188389, -0.013141},{
      0.129576, 0.188996, -0.013141},{0.128336, 0.190701, -0.013647}}],
    Polygon[{{0.128385, 0.188389, -0.013141},{0.129004, 0.186484, -0.012311},{
      0.130753, 0.187375, -0.012311},{0.129576, 0.188996, -0.013141}}],
    Polygon[{{0.129004, 0.186484, -0.012311},{0.129576, 0.184726, -0.011178},{
      0.131840, 0.185880, -0.011178},{0.130753, 0.187375, -0.012311}}],
    Polygon[{{0.129576, 0.184726, -0.011178},{0.130085, 0.183158, -0.009770},{
      0.132809, 0.184546, -0.009770},{0.131840, 0.185880, -0.011178}}],
    Polygon[{{0.130085, 0.183158, -0.009770},{0.130520, 0.181819, -0.008122},{
      0.133636, 0.183407, -0.008122},{0.132809, 0.184546, -0.009770}}],
    Polygon[{{0.130520, 0.181819, -0.008122},{0.130870, 0.180741, -0.006273},{
      0.134302, 0.182490, -0.006273},{0.133636, 0.183407, -0.008122}}],
    Polygon[{{0.130870, 0.180741, -0.006273},{0.131127, 0.179952, -0.004270},{
      0.134790, 0.181819, -0.004270},{0.134302, 0.182490, -0.006273}}],
    Polygon[{{0.131127, 0.179952, -0.004270},{0.131283, 0.179471, -0.002162},{
      0.135088, 0.181409, -0.002162},{0.134790, 0.181819, -0.004270}}],
    Polygon[{{0.131283, 0.179471, -0.002162},{0.131336, 0.179309, 0.000000},{
      0.135188, 0.181272, 0.000000},{0.135088, 0.181409, -0.002162}}],
    Polygon[{{0.131336, 0.179309, 0.000000},{0.131283, 0.179471, 0.002162},{
      0.135088, 0.181409, 0.002162},{0.135188, 0.181272, 0.000000}}],
    Polygon[{{0.131283, 0.179471, 0.002162},{0.131127, 0.179952, 0.004270},{
      0.134790, 0.181819, 0.004270},{0.135088, 0.181409, 0.002162}}],
    Polygon[{{0.131127, 0.179952, 0.004270},{0.130870, 0.180741, 0.006273},{
      0.134302, 0.182490, 0.006273},{0.134790, 0.181819, 0.004270}}],
    Polygon[{{0.130870, 0.180741, 0.006273},{0.130520, 0.181819, 0.008122},{
      0.133636, 0.183407, 0.008122},{0.134302, 0.182490, 0.006273}}],
    Polygon[{{0.130520, 0.181819, 0.008122},{0.130085, 0.183158, 0.009770},{
      0.132809, 0.184546, 0.009770},{0.133636, 0.183407, 0.008122}}],
    Polygon[{{0.130085, 0.183158, 0.009770},{0.129576, 0.184726, 0.011178},{
      0.131840, 0.185880, 0.011178},{0.132809, 0.184546, 0.009770}}],
    Polygon[{{0.129576, 0.184726, 0.011178},{0.129004, 0.186484, 0.012311},{
      0.130753, 0.187375, 0.012311},{0.131840, 0.185880, 0.011178}}],
    Polygon[{{0.129004, 0.186484, 0.012311},{0.128385, 0.188389, 0.013141},{
      0.129576, 0.188996, 0.013141},{0.130753, 0.187375, 0.012311}}],
    Polygon[{{0.128385, 0.188389, 0.013141},{0.127734, 0.190394, 0.013647},{
      0.128336, 0.190701, 0.013647},{0.129576, 0.188996, 0.013141}}],
    Polygon[{{0.128336, 0.190701, -0.013647},{0.129576, 0.188996, -0.013141},{
      0.130520, 0.189940, -0.013141},{0.128815, 0.191180, -0.013647}}],
    Polygon[{{0.129576, 0.188996, -0.013141},{0.130753, 0.187375, -0.012311},{
      0.132141, 0.188763, -0.012311},{0.130520, 0.189940, -0.013141}}],
    Polygon[{{0.130753, 0.187375, -0.012311},{0.131840, 0.185880, -0.011178},{
      0.133636, 0.187676, -0.011178},{0.132141, 0.188763, -0.012311}}],
    Polygon[{{0.131840, 0.185880, -0.011178},{0.132809, 0.184546, -0.009770},{
      0.134970, 0.186707, -0.009770},{0.133636, 0.187676, -0.011178}}],
    Polygon[{{0.132809, 0.184546, -0.009770},{0.133636, 0.183407, -0.008122},{
      0.136109, 0.185880, -0.008122},{0.134970, 0.186707, -0.009770}}],
    Polygon[{{0.133636, 0.183407, -0.008122},{0.134302, 0.182490, -0.006273},{
      0.137026, 0.185214, -0.006273},{0.136109, 0.185880, -0.008122}}],
    Polygon[{{0.134302, 0.182490, -0.006273},{0.134790, 0.181819, -0.004270},{
      0.137697, 0.184726, -0.004270},{0.137026, 0.185214, -0.006273}}],
    Polygon[{{0.134790, 0.181819, -0.004270},{0.135088, 0.181409, -0.002162},{
      0.138107, 0.184428, -0.002162},{0.137697, 0.184726, -0.004270}}],
    Polygon[{{0.135088, 0.181409, -0.002162},{0.135188, 0.181272, 0.000000},{
      0.138244, 0.184328, 0.000000},{0.138107, 0.184428, -0.002162}}],
    Polygon[{{0.135188, 0.181272, 0.000000},{0.135088, 0.181409, 0.002162},{
      0.138107, 0.184428, 0.002162},{0.138244, 0.184328, 0.000000}}],
    Polygon[{{0.135088, 0.181409, 0.002162},{0.134790, 0.181819, 0.004270},{
      0.137697, 0.184726, 0.004270},{0.138107, 0.184428, 0.002162}}],
    Polygon[{{0.134790, 0.181819, 0.004270},{0.134302, 0.182490, 0.006273},{
      0.137026, 0.185214, 0.006273},{0.137697, 0.184726, 0.004270}}],
    Polygon[{{0.134302, 0.182490, 0.006273},{0.133636, 0.183407, 0.008122},{
      0.136109, 0.185880, 0.008122},{0.137026, 0.185214, 0.006273}}],
    Polygon[{{0.133636, 0.183407, 0.008122},{0.132809, 0.184546, 0.009770},{
      0.134970, 0.186707, 0.009770},{0.136109, 0.185880, 0.008122}}],
    Polygon[{{0.132809, 0.184546, 0.009770},{0.131840, 0.185880, 0.011178},{
      0.133636, 0.187676, 0.011178},{0.134970, 0.186707, 0.009770}}],
    Polygon[{{0.131840, 0.185880, 0.011178},{0.130753, 0.187375, 0.012311},{
      0.132141, 0.188763, 0.012311},{0.133636, 0.187676, 0.011178}}],
    Polygon[{{0.130753, 0.187375, 0.012311},{0.129576, 0.188996, 0.013141},{
      0.130520, 0.189940, 0.013141},{0.132141, 0.188763, 0.012311}}],
    Polygon[{{0.129576, 0.188996, 0.013141},{0.128336, 0.190701, 0.013647},{
      0.128815, 0.191180, 0.013647},{0.130520, 0.189940, 0.013141}}],
    Polygon[{{0.128815, 0.191180, -0.013647},{0.130520, 0.189940, -0.013141},{
      0.131127, 0.191131, -0.013141},{0.129122, 0.191782, -0.013647}}],
    Polygon[{{0.130520, 0.189940, -0.013141},{0.132141, 0.188763, -0.012311},{
      0.133032, 0.190512, -0.012311},{0.131127, 0.191131, -0.013141}}],
    Polygon[{{0.132141, 0.188763, -0.012311},{0.133636, 0.187676, -0.011178},{
      0.134790, 0.189940, -0.011178},{0.133032, 0.190512, -0.012311}}],
    Polygon[{{0.133636, 0.187676, -0.011178},{0.134970, 0.186707, -0.009770},{
      0.136358, 0.189431, -0.009770},{0.134790, 0.189940, -0.011178}}],
    Polygon[{{0.134970, 0.186707, -0.009770},{0.136109, 0.185880, -0.008122},{
      0.137697, 0.188996, -0.008122},{0.136358, 0.189431, -0.009770}}],
    Polygon[{{0.136109, 0.185880, -0.008122},{0.137026, 0.185214, -0.006273},{
      0.138775, 0.188646, -0.006273},{0.137697, 0.188996, -0.008122}}],
    Polygon[{{0.137026, 0.185214, -0.006273},{0.137697, 0.184726, -0.004270},{
      0.139564, 0.188389, -0.004270},{0.138775, 0.188646, -0.006273}}],
    Polygon[{{0.137697, 0.184726, -0.004270},{0.138107, 0.184428, -0.002162},{
      0.140045, 0.188233, -0.002162},{0.139564, 0.188389, -0.004270}}],
    Polygon[{{0.138107, 0.184428, -0.002162},{0.138244, 0.184328, 0.000000},{
      0.140207, 0.188180, 0.000000},{0.140045, 0.188233, -0.002162}}],
    Polygon[{{0.138244, 0.184328, 0.000000},{0.138107, 0.184428, 0.002162},{
      0.140045, 0.188233, 0.002162},{0.140207, 0.188180, 0.000000}}],
    Polygon[{{0.138107, 0.184428, 0.002162},{0.137697, 0.184726, 0.004270},{
      0.139564, 0.188389, 0.004270},{0.140045, 0.188233, 0.002162}}],
    Polygon[{{0.137697, 0.184726, 0.004270},{0.137026, 0.185214, 0.006273},{
      0.138775, 0.188646, 0.006273},{0.139564, 0.188389, 0.004270}}],
    Polygon[{{0.137026, 0.185214, 0.006273},{0.136109, 0.185880, 0.008122},{
      0.137697, 0.188996, 0.008122},{0.138775, 0.188646, 0.006273}}],
    Polygon[{{0.136109, 0.185880, 0.008122},{0.134970, 0.186707, 0.009770},{
      0.136358, 0.189431, 0.009770},{0.137697, 0.188996, 0.008122}}],
    Polygon[{{0.134970, 0.186707, 0.009770},{0.133636, 0.187676, 0.011178},{
      0.134790, 0.189940, 0.011178},{0.136358, 0.189431, 0.009770}}],
    Polygon[{{0.133636, 0.187676, 0.011178},{0.132141, 0.188763, 0.012311},{
      0.133032, 0.190512, 0.012311},{0.134790, 0.189940, 0.011178}}],
    Polygon[{{0.132141, 0.188763, 0.012311},{0.130520, 0.189940, 0.013141},{
      0.131127, 0.191131, 0.013141},{0.133032, 0.190512, 0.012311}}],
    Polygon[{{0.130520, 0.189940, 0.013141},{0.128815, 0.191180, 0.013647},{
      0.129122, 0.191782, 0.013647},{0.131127, 0.191131, 0.013141}}],
    Polygon[{{0.129122, 0.191782, -0.013647},{0.131127, 0.191131, -0.013141},{
      0.131336, 0.192450, -0.013141},{0.129227, 0.192450, -0.013647}}],
    Polygon[{{0.131127, 0.191131, -0.013141},{0.133032, 0.190512, -0.012311},{
      0.133339, 0.192450, -0.012311},{0.131336, 0.192450, -0.013141}}],
    Polygon[{{0.133032, 0.190512, -0.012311},{0.134790, 0.189940, -0.011178},{
      0.135188, 0.192450, -0.011178},{0.133339, 0.192450, -0.012311}}],
    Polygon[{{0.134790, 0.189940, -0.011178},{0.136358, 0.189431, -0.009770},{
      0.136836, 0.192450, -0.009770},{0.135188, 0.192450, -0.011178}}],
    Polygon[{{0.136358, 0.189431, -0.009770},{0.137697, 0.188996, -0.008122},{
      0.138244, 0.192450, -0.008122},{0.136836, 0.192450, -0.009770}}],
    Polygon[{{0.137697, 0.188996, -0.008122},{0.138775, 0.188646, -0.006273},{
      0.139377, 0.192450, -0.006273},{0.138244, 0.192450, -0.008122}}],
    Polygon[{{0.138775, 0.188646, -0.006273},{0.139564, 0.188389, -0.004270},{
      0.140207, 0.192450, -0.004270},{0.139377, 0.192450, -0.006273}}],
    Polygon[{{0.139564, 0.188389, -0.004270},{0.140045, 0.188233, -0.002162},{
      0.140713, 0.192450, -0.002162},{0.140207, 0.192450, -0.004270}}],
    Polygon[{{0.140045, 0.188233, -0.002162},{0.140207, 0.188180, 0.000000},{
      0.140883, 0.192450, 0.000000},{0.140713, 0.192450, -0.002162}}],
    Polygon[{{0.140207, 0.188180, 0.000000},{0.140045, 0.188233, 0.002162},{
      0.140713, 0.192450, 0.002162},{0.140883, 0.192450, 0.000000}}],
    Polygon[{{0.140045, 0.188233, 0.002162},{0.139564, 0.188389, 0.004270},{
      0.140207, 0.192450, 0.004270},{0.140713, 0.192450, 0.002162}}],
    Polygon[{{0.139564, 0.188389, 0.004270},{0.138775, 0.188646, 0.006273},{
      0.139377, 0.192450, 0.006273},{0.140207, 0.192450, 0.004270}}],
    Polygon[{{0.138775, 0.188646, 0.006273},{0.137697, 0.188996, 0.008122},{
      0.138244, 0.192450, 0.008122},{0.139377, 0.192450, 0.006273}}],
    Polygon[{{0.137697, 0.188996, 0.008122},{0.136358, 0.189431, 0.009770},{
      0.136836, 0.192450, 0.009770},{0.138244, 0.192450, 0.008122}}],
    Polygon[{{0.136358, 0.189431, 0.009770},{0.134790, 0.189940, 0.011178},{
      0.135188, 0.192450, 0.011178},{0.136836, 0.192450, 0.009770}}],
    Polygon[{{0.134790, 0.189940, 0.011178},{0.133032, 0.190512, 0.012311},{
      0.133339, 0.192450, 0.012311},{0.135188, 0.192450, 0.011178}}],
    Polygon[{{0.133032, 0.190512, 0.012311},{0.131127, 0.191131, 0.013141},{
      0.131336, 0.192450, 0.013141},{0.133339, 0.192450, 0.012311}}],
    Polygon[{{0.131127, 0.191131, 0.013141},{0.129122, 0.191782, 0.013647},{
      0.129227, 0.192450, 0.013647},{0.131336, 0.192450, 0.013141}}],
    Polygon[{{0.090320, 0.134507, -0.009538},{0.091793, 0.134507, -0.009185},{
      0.091647, 0.135429, -0.009185},{0.090246, 0.134974, -0.009538}}],
    Polygon[{{0.091793, 0.134507, -0.009185},{0.093193, 0.134507, -0.008605},{
      0.092979, 0.135862, -0.008605},{0.091647, 0.135429, -0.009185}}],
    Polygon[{{0.093193, 0.134507, -0.008605},{0.094485, 0.134507, -0.007813},{
      0.094207, 0.136261, -0.007813},{0.092979, 0.135862, -0.008605}}],
    Polygon[{{0.094485, 0.134507, -0.007813},{0.095637, 0.134507, -0.006829},{
      0.095303, 0.136617, -0.006829},{0.094207, 0.136261, -0.007813}}],
    Polygon[{{0.095637, 0.134507, -0.006829},{0.096622, 0.134507, -0.005676},{
      0.096239, 0.136921, -0.005676},{0.095303, 0.136617, -0.006829}}],
    Polygon[{{0.096622, 0.134507, -0.005676},{0.097413, 0.134507, -0.004384},{
      0.096992, 0.137166, -0.004384},{0.096239, 0.136921, -0.005676}}],
    Polygon[{{0.097413, 0.134507, -0.004384},{0.097993, 0.134507, -0.002984},{
      0.097544, 0.137345, -0.002984},{0.096992, 0.137166, -0.004384}}],
    Polygon[{{0.097993, 0.134507, -0.002984},{0.098347, 0.134507, -0.001511},{
      0.097880, 0.137455, -0.001511},{0.097544, 0.137345, -0.002984}}],
    Polygon[{{0.098347, 0.134507, -0.001511},{0.098466, 0.134507, 0.000000},{
      0.097993, 0.137491, 0.000000},{0.097880, 0.137455, -0.001511}}],
    Polygon[{{0.098466, 0.134507, 0.000000},{0.098347, 0.134507, 0.001511},{
      0.097880, 0.137455, 0.001511},{0.097993, 0.137491, 0.000000}}],
    Polygon[{{0.098347, 0.134507, 0.001511},{0.097993, 0.134507, 0.002984},{
      0.097544, 0.137345, 0.002984},{0.097880, 0.137455, 0.001511}}],
    Polygon[{{0.097993, 0.134507, 0.002984},{0.097413, 0.134507, 0.004384},{
      0.096992, 0.137166, 0.004384},{0.097544, 0.137345, 0.002984}}],
    Polygon[{{0.097413, 0.134507, 0.004384},{0.096622, 0.134507, 0.005676},{
      0.096239, 0.136921, 0.005676},{0.096992, 0.137166, 0.004384}}],
    Polygon[{{0.096622, 0.134507, 0.005676},{0.095637, 0.134507, 0.006829},{
      0.095303, 0.136617, 0.006829},{0.096239, 0.136921, 0.005676}}],
    Polygon[{{0.095637, 0.134507, 0.006829},{0.094485, 0.134507, 0.007813},{
      0.094207, 0.136261, 0.007813},{0.095303, 0.136617, 0.006829}}],
    Polygon[{{0.094485, 0.134507, 0.007813},{0.093193, 0.134507, 0.008605},{
      0.092979, 0.135862, 0.008605},{0.094207, 0.136261, 0.007813}}],
    Polygon[{{0.093193, 0.134507, 0.008605},{0.091793, 0.134507, 0.009185},{
      0.091647, 0.135429, 0.009185},{0.092979, 0.135862, 0.008605}}],
    Polygon[{{0.091793, 0.134507, 0.009185},{0.090320, 0.134507, 0.009538},{
      0.090246, 0.134974, 0.009538},{0.091647, 0.135429, 0.009185}}],
    Polygon[{{0.090246, 0.134974, -0.009538},{0.091647, 0.135429, -0.009185},{
      0.091223, 0.136261, -0.009185},{0.090031, 0.135395, -0.009538}}],
    Polygon[{{0.091647, 0.135429, -0.009185},{0.092979, 0.135862, -0.008605},{
      0.092356, 0.137084, -0.008605},{0.091223, 0.136261, -0.009185}}],
    Polygon[{{0.092979, 0.135862, -0.008605},{0.094207, 0.136261, -0.007813},{
      0.093401, 0.137844, -0.007813},{0.092356, 0.137084, -0.008605}}],
    Polygon[{{0.094207, 0.136261, -0.007813},{0.095303, 0.136617, -0.006829},{
      0.094333, 0.138521, -0.006829},{0.093401, 0.137844, -0.007813}}],
    Polygon[{{0.095303, 0.136617, -0.006829},{0.096239, 0.136921, -0.005676},{
      0.095130, 0.139099, -0.005676},{0.094333, 0.138521, -0.006829}}],
    Polygon[{{0.096239, 0.136921, -0.005676},{0.096992, 0.137166, -0.004384},{
      0.095770, 0.139565, -0.004384},{0.095130, 0.139099, -0.005676}}],
    Polygon[{{0.096992, 0.137166, -0.004384},{0.097544, 0.137345, -0.002984},{
      0.096239, 0.139906, -0.002984},{0.095770, 0.139565, -0.004384}}],
    Polygon[{{0.097544, 0.137345, -0.002984},{0.097880, 0.137455, -0.001511},{
      0.096525, 0.140114, -0.001511},{0.096239, 0.139906, -0.002984}}],
    Polygon[{{0.097880, 0.137455, -0.001511},{0.097993, 0.137491, 0.000000},{
      0.096622, 0.140183, 0.000000},{0.096525, 0.140114, -0.001511}}],
    Polygon[{{0.097993, 0.137491, 0.000000},{0.097880, 0.137455, 0.001511},{
      0.096525, 0.140114, 0.001511},{0.096622, 0.140183, 0.000000}}],
    Polygon[{{0.097880, 0.137455, 0.001511},{0.097544, 0.137345, 0.002984},{
      0.096239, 0.139906, 0.002984},{0.096525, 0.140114, 0.001511}}],
    Polygon[{{0.097544, 0.137345, 0.002984},{0.096992, 0.137166, 0.004384},{
      0.095770, 0.139565, 0.004384},{0.096239, 0.139906, 0.002984}}],
    Polygon[{{0.096992, 0.137166, 0.004384},{0.096239, 0.136921, 0.005676},{
      0.095130, 0.139099, 0.005676},{0.095770, 0.139565, 0.004384}}],
    Polygon[{{0.096239, 0.136921, 0.005676},{0.095303, 0.136617, 0.006829},{
      0.094333, 0.138521, 0.006829},{0.095130, 0.139099, 0.005676}}],
    Polygon[{{0.095303, 0.136617, 0.006829},{0.094207, 0.136261, 0.007813},{
      0.093401, 0.137844, 0.007813},{0.094333, 0.138521, 0.006829}}],
    Polygon[{{0.094207, 0.136261, 0.007813},{0.092979, 0.135862, 0.008605},{
      0.092356, 0.137084, 0.008605},{0.093401, 0.137844, 0.007813}}],
    Polygon[{{0.092979, 0.135862, 0.008605},{0.091647, 0.135429, 0.009185},{
      0.091223, 0.136261, 0.009185},{0.092356, 0.137084, 0.008605}}],
    Polygon[{{0.091647, 0.135429, 0.009185},{0.090246, 0.134974, 0.009538},{
      0.090031, 0.135395, 0.009538},{0.091223, 0.136261, 0.009185}}],
    Polygon[{{0.090031, 0.135395, -0.009538},{0.091223, 0.136261, -0.009185},{
      0.090563, 0.136921, -0.009185},{0.089697, 0.135729, -0.009538}}],
    Polygon[{{0.091223, 0.136261, -0.009185},{0.092356, 0.137084, -0.008605},{
      0.091386, 0.138054, -0.008605},{0.090563, 0.136921, -0.009185}}],
    Polygon[{{0.092356, 0.137084, -0.008605},{0.093401, 0.137844, -0.007813},{
      0.092145, 0.139099, -0.007813},{0.091386, 0.138054, -0.008605}}],
    Polygon[{{0.093401, 0.137844, -0.007813},{0.094333, 0.138521, -0.006829},{
      0.092823, 0.140032, -0.006829},{0.092145, 0.139099, -0.007813}}],
    Polygon[{{0.094333, 0.138521, -0.006829},{0.095130, 0.139099, -0.005676},{
      0.093401, 0.140828, -0.005676},{0.092823, 0.140032, -0.006829}}],
    Polygon[{{0.095130, 0.139099, -0.005676},{0.095770, 0.139565, -0.004384},{
      0.093866, 0.141468, -0.004384},{0.093401, 0.140828, -0.005676}}],
    Polygon[{{0.095770, 0.139565, -0.004384},{0.096239, 0.139906, -0.002984},{
      0.094207, 0.141937, -0.002984},{0.093866, 0.141468, -0.004384}}],
    Polygon[{{0.096239, 0.139906, -0.002984},{0.096525, 0.140114, -0.001511},{
      0.094415, 0.142224, -0.001511},{0.094207, 0.141937, -0.002984}}],
    Polygon[{{0.096525, 0.140114, -0.001511},{0.096622, 0.140183, 0.000000},{
      0.094485, 0.142320, 0.000000},{0.094415, 0.142224, -0.001511}}],
    Polygon[{{0.096622, 0.140183, 0.000000},{0.096525, 0.140114, 0.001511},{
      0.094415, 0.142224, 0.001511},{0.094485, 0.142320, 0.000000}}],
    Polygon[{{0.096525, 0.140114, 0.001511},{0.096239, 0.139906, 0.002984},{
      0.094207, 0.141937, 0.002984},{0.094415, 0.142224, 0.001511}}],
    Polygon[{{0.096239, 0.139906, 0.002984},{0.095770, 0.139565, 0.004384},{
      0.093866, 0.141468, 0.004384},{0.094207, 0.141937, 0.002984}}],
    Polygon[{{0.095770, 0.139565, 0.004384},{0.095130, 0.139099, 0.005676},{
      0.093401, 0.140828, 0.005676},{0.093866, 0.141468, 0.004384}}],
    Polygon[{{0.095130, 0.139099, 0.005676},{0.094333, 0.138521, 0.006829},{
      0.092823, 0.140032, 0.006829},{0.093401, 0.140828, 0.005676}}],
    Polygon[{{0.094333, 0.138521, 0.006829},{0.093401, 0.137844, 0.007813},{
      0.092145, 0.139099, 0.007813},{0.092823, 0.140032, 0.006829}}],
    Polygon[{{0.093401, 0.137844, 0.007813},{0.092356, 0.137084, 0.008605},{
      0.091386, 0.138054, 0.008605},{0.092145, 0.139099, 0.007813}}],
    Polygon[{{0.092356, 0.137084, 0.008605},{0.091223, 0.136261, 0.009185},{
      0.090563, 0.136921, 0.009185},{0.091386, 0.138054, 0.008605}}],
    Polygon[{{0.091223, 0.136261, 0.009185},{0.090031, 0.135395, 0.009538},{
      0.089697, 0.135729, 0.009538},{0.090563, 0.136921, 0.009185}}],
    Polygon[{{0.089697, 0.135729, -0.009538},{0.090563, 0.136921, -0.009185},{
      0.089731, 0.137345, -0.009185},{0.089276, 0.135944, -0.009538}}],
    Polygon[{{0.090563, 0.136921, -0.009185},{0.091386, 0.138054, -0.008605},{
      0.090164, 0.138677, -0.008605},{0.089731, 0.137345, -0.009185}}],
    Polygon[{{0.091386, 0.138054, -0.008605},{0.092145, 0.139099, -0.007813},{
      0.090563, 0.139906, -0.007813},{0.090164, 0.138677, -0.008605}}],
    Polygon[{{0.092145, 0.139099, -0.007813},{0.092823, 0.140032, -0.006829},{
      0.090919, 0.141001, -0.006829},{0.090563, 0.139906, -0.007813}}],
    Polygon[{{0.092823, 0.140032, -0.006829},{0.093401, 0.140828, -0.005676},{
      0.091223, 0.141937, -0.005676},{0.090919, 0.141001, -0.006829}}],
    Polygon[{{0.093401, 0.140828, -0.005676},{0.093866, 0.141468, -0.004384},{
      0.091468, 0.142691, -0.004384},{0.091223, 0.141937, -0.005676}}],
    Polygon[{{0.093866, 0.141468, -0.004384},{0.094207, 0.141937, -0.002984},{
      0.091647, 0.143242, -0.002984},{0.091468, 0.142691, -0.004384}}],
    Polygon[{{0.094207, 0.141937, -0.002984},{0.094415, 0.142224, -0.001511},{
      0.091756, 0.143578, -0.001511},{0.091647, 0.143242, -0.002984}}],
    Polygon[{{0.094415, 0.142224, -0.001511},{0.094485, 0.142320, 0.000000},{
      0.091793, 0.143692, 0.000000},{0.091756, 0.143578, -0.001511}}],
    Polygon[{{0.094485, 0.142320, 0.000000},{0.094415, 0.142224, 0.001511},{
      0.091756, 0.143578, 0.001511},{0.091793, 0.143692, 0.000000}}],
    Polygon[{{0.094415, 0.142224, 0.001511},{0.094207, 0.141937, 0.002984},{
      0.091647, 0.143242, 0.002984},{0.091756, 0.143578, 0.001511}}],
    Polygon[{{0.094207, 0.141937, 0.002984},{0.093866, 0.141468, 0.004384},{
      0.091468, 0.142691, 0.004384},{0.091647, 0.143242, 0.002984}}],
    Polygon[{{0.093866, 0.141468, 0.004384},{0.093401, 0.140828, 0.005676},{
      0.091223, 0.141937, 0.005676},{0.091468, 0.142691, 0.004384}}],
    Polygon[{{0.093401, 0.140828, 0.005676},{0.092823, 0.140032, 0.006829},{
      0.090919, 0.141001, 0.006829},{0.091223, 0.141937, 0.005676}}],
    Polygon[{{0.092823, 0.140032, 0.006829},{0.092145, 0.139099, 0.007813},{
      0.090563, 0.139906, 0.007813},{0.090919, 0.141001, 0.006829}}],
    Polygon[{{0.092145, 0.139099, 0.007813},{0.091386, 0.138054, 0.008605},{
      0.090164, 0.138677, 0.008605},{0.090563, 0.139906, 0.007813}}],
    Polygon[{{0.091386, 0.138054, 0.008605},{0.090563, 0.136921, 0.009185},{
      0.089731, 0.137345, 0.009185},{0.090164, 0.138677, 0.008605}}],
    Polygon[{{0.090563, 0.136921, 0.009185},{0.089697, 0.135729, 0.009538},{
      0.089276, 0.135944, 0.009538},{0.089731, 0.137345, 0.009185}}],
    Polygon[{{0.089276, 0.135944, -0.009538},{0.089731, 0.137345, -0.009185},{
      0.088809, 0.137491, -0.009185},{0.088809, 0.136018, -0.009538}}],
    Polygon[{{0.089731, 0.137345, -0.009185},{0.090164, 0.138677, -0.008605},{
      0.088809, 0.138891, -0.008605},{0.088809, 0.137491, -0.009185}}],
    Polygon[{{0.090164, 0.138677, -0.008605},{0.090563, 0.139906, -0.007813},{
      0.088809, 0.140183, -0.007813},{0.088809, 0.138891, -0.008605}}],
    Polygon[{{0.090563, 0.139906, -0.007813},{0.090919, 0.141001, -0.006829},{
      0.088809, 0.141336, -0.006829},{0.088809, 0.140183, -0.007813}}],
    Polygon[{{0.090919, 0.141001, -0.006829},{0.091223, 0.141937, -0.005676},{
      0.088809, 0.142320, -0.005676},{0.088809, 0.141336, -0.006829}}],
    Polygon[{{0.091223, 0.141937, -0.005676},{0.091468, 0.142691, -0.004384},{
      0.088809, 0.143112, -0.004384},{0.088809, 0.142320, -0.005676}}],
    Polygon[{{0.091468, 0.142691, -0.004384},{0.091647, 0.143242, -0.002984},{
      0.088809, 0.143692, -0.002984},{0.088809, 0.143112, -0.004384}}],
    Polygon[{{0.091647, 0.143242, -0.002984},{0.091756, 0.143578, -0.001511},{
      0.088809, 0.144045, -0.001511},{0.088809, 0.143692, -0.002984}}],
    Polygon[{{0.091756, 0.143578, -0.001511},{0.091793, 0.143692, 0.000000},{
      0.088809, 0.144164, 0.000000},{0.088809, 0.144045, -0.001511}}],
    Polygon[{{0.091793, 0.143692, 0.000000},{0.091756, 0.143578, 0.001511},{
      0.088809, 0.144045, 0.001511},{0.088809, 0.144164, 0.000000}}],
    Polygon[{{0.091756, 0.143578, 0.001511},{0.091647, 0.143242, 0.002984},{
      0.088809, 0.143692, 0.002984},{0.088809, 0.144045, 0.001511}}],
    Polygon[{{0.091647, 0.143242, 0.002984},{0.091468, 0.142691, 0.004384},{
      0.088809, 0.143112, 0.004384},{0.088809, 0.143692, 0.002984}}],
    Polygon[{{0.091468, 0.142691, 0.004384},{0.091223, 0.141937, 0.005676},{
      0.088809, 0.142320, 0.005676},{0.088809, 0.143112, 0.004384}}],
    Polygon[{{0.091223, 0.141937, 0.005676},{0.090919, 0.141001, 0.006829},{
      0.088809, 0.141336, 0.006829},{0.088809, 0.142320, 0.005676}}],
    Polygon[{{0.090919, 0.141001, 0.006829},{0.090563, 0.139906, 0.007813},{
      0.088809, 0.140183, 0.007813},{0.088809, 0.141336, 0.006829}}],
    Polygon[{{0.090563, 0.139906, 0.007813},{0.090164, 0.138677, 0.008605},{
      0.088809, 0.138891, 0.008605},{0.088809, 0.140183, 0.007813}}],
    Polygon[{{0.090164, 0.138677, 0.008605},{0.089731, 0.137345, 0.009185},{
      0.088809, 0.137491, 0.009185},{0.088809, 0.138891, 0.008605}}],
    Polygon[{{0.089731, 0.137345, 0.009185},{0.089276, 0.135944, 0.009538},{
      0.088809, 0.136018, 0.009538},{0.088809, 0.137491, 0.009185}}],
    Polygon[{{0.088809, 0.136018, -0.009538},{0.088809, 0.137491, -0.009185},{
      0.087887, 0.137345, -0.009185},{0.088342, 0.135944, -0.009538}}],
    Polygon[{{0.088809, 0.137491, -0.009185},{0.088809, 0.138891, -0.008605},{
      0.087454, 0.138677, -0.008605},{0.087887, 0.137345, -0.009185}}],
    Polygon[{{0.088809, 0.138891, -0.008605},{0.088809, 0.140183, -0.007813},{
      0.087055, 0.139906, -0.007813},{0.087454, 0.138677, -0.008605}}],
    Polygon[{{0.088809, 0.140183, -0.007813},{0.088809, 0.141336, -0.006829},{
      0.086699, 0.141001, -0.006829},{0.087055, 0.139906, -0.007813}}],
    Polygon[{{0.088809, 0.141336, -0.006829},{0.088809, 0.142320, -0.005676},{
      0.086395, 0.141937, -0.005676},{0.086699, 0.141001, -0.006829}}],
    Polygon[{{0.088809, 0.142320, -0.005676},{0.088809, 0.143112, -0.004384},{
      0.086150, 0.142691, -0.004384},{0.086395, 0.141937, -0.005676}}],
    Polygon[{{0.088809, 0.143112, -0.004384},{0.088809, 0.143692, -0.002984},{
      0.085971, 0.143242, -0.002984},{0.086150, 0.142691, -0.004384}}],
    Polygon[{{0.088809, 0.143692, -0.002984},{0.088809, 0.144045, -0.001511},{
      0.085861, 0.143578, -0.001511},{0.085971, 0.143242, -0.002984}}],
    Polygon[{{0.088809, 0.144045, -0.001511},{0.088809, 0.144164, 0.000000},{
      0.085825, 0.143692, 0.000000},{0.085861, 0.143578, -0.001511}}],
    Polygon[{{0.088809, 0.144164, 0.000000},{0.088809, 0.144045, 0.001511},{
      0.085861, 0.143578, 0.001511},{0.085825, 0.143692, 0.000000}}],
    Polygon[{{0.088809, 0.144045, 0.001511},{0.088809, 0.143692, 0.002984},{
      0.085971, 0.143242, 0.002984},{0.085861, 0.143578, 0.001511}}],
    Polygon[{{0.088809, 0.143692, 0.002984},{0.088809, 0.143112, 0.004384},{
      0.086150, 0.142691, 0.004384},{0.085971, 0.143242, 0.002984}}],
    Polygon[{{0.088809, 0.143112, 0.004384},{0.088809, 0.142320, 0.005676},{
      0.086395, 0.141937, 0.005676},{0.086150, 0.142691, 0.004384}}],
    Polygon[{{0.088809, 0.142320, 0.005676},{0.088809, 0.141336, 0.006829},{
      0.086699, 0.141001, 0.006829},{0.086395, 0.141937, 0.005676}}],
    Polygon[{{0.088809, 0.141336, 0.006829},{0.088809, 0.140183, 0.007813},{
      0.087055, 0.139906, 0.007813},{0.086699, 0.141001, 0.006829}}],
    Polygon[{{0.088809, 0.140183, 0.007813},{0.088809, 0.138891, 0.008605},{
      0.087454, 0.138677, 0.008605},{0.087055, 0.139906, 0.007813}}],
    Polygon[{{0.088809, 0.138891, 0.008605},{0.088809, 0.137491, 0.009185},{
      0.087887, 0.137345, 0.009185},{0.087454, 0.138677, 0.008605}}],
    Polygon[{{0.088809, 0.137491, 0.009185},{0.088809, 0.136018, 0.009538},{
      0.088342, 0.135944, 0.009538},{0.087887, 0.137345, 0.009185}}],
    Polygon[{{0.088342, 0.135944, -0.009538},{0.087887, 0.137345, -0.009185},{
      0.087055, 0.136921, -0.009185},{0.087921, 0.135729, -0.009538}}],
    Polygon[{{0.087887, 0.137345, -0.009185},{0.087454, 0.138677, -0.008605},{
      0.086232, 0.138054, -0.008605},{0.087055, 0.136921, -0.009185}}],
    Polygon[{{0.087454, 0.138677, -0.008605},{0.087055, 0.139906, -0.007813},{
      0.085472, 0.139099, -0.007813},{0.086232, 0.138054, -0.008605}}],
    Polygon[{{0.087055, 0.139906, -0.007813},{0.086699, 0.141001, -0.006829},{
      0.084795, 0.140032, -0.006829},{0.085472, 0.139099, -0.007813}}],
    Polygon[{{0.086699, 0.141001, -0.006829},{0.086395, 0.141937, -0.005676},{
      0.084217, 0.140828, -0.005676},{0.084795, 0.140032, -0.006829}}],
    Polygon[{{0.086395, 0.141937, -0.005676},{0.086150, 0.142691, -0.004384},{
      0.083751, 0.141468, -0.004384},{0.084217, 0.140828, -0.005676}}],
    Polygon[{{0.086150, 0.142691, -0.004384},{0.085971, 0.143242, -0.002984},{
      0.083410, 0.141937, -0.002984},{0.083751, 0.141468, -0.004384}}],
    Polygon[{{0.085971, 0.143242, -0.002984},{0.085861, 0.143578, -0.001511},{
      0.083202, 0.142224, -0.001511},{0.083410, 0.141937, -0.002984}}],
    Polygon[{{0.085861, 0.143578, -0.001511},{0.085825, 0.143692, 0.000000},{
      0.083132, 0.142320, 0.000000},{0.083202, 0.142224, -0.001511}}],
    Polygon[{{0.085825, 0.143692, 0.000000},{0.085861, 0.143578, 0.001511},{
      0.083202, 0.142224, 0.001511},{0.083132, 0.142320, 0.000000}}],
    Polygon[{{0.085861, 0.143578, 0.001511},{0.085971, 0.143242, 0.002984},{
      0.083410, 0.141937, 0.002984},{0.083202, 0.142224, 0.001511}}],
    Polygon[{{0.085971, 0.143242, 0.002984},{0.086150, 0.142691, 0.004384},{
      0.083751, 0.141468, 0.004384},{0.083410, 0.141937, 0.002984}}],
    Polygon[{{0.086150, 0.142691, 0.004384},{0.086395, 0.141937, 0.005676},{
      0.084217, 0.140828, 0.005676},{0.083751, 0.141468, 0.004384}}],
    Polygon[{{0.086395, 0.141937, 0.005676},{0.086699, 0.141001, 0.006829},{
      0.084795, 0.140032, 0.006829},{0.084217, 0.140828, 0.005676}}],
    Polygon[{{0.086699, 0.141001, 0.006829},{0.087055, 0.139906, 0.007813},{
      0.085472, 0.139099, 0.007813},{0.084795, 0.140032, 0.006829}}],
    Polygon[{{0.087055, 0.139906, 0.007813},{0.087454, 0.138677, 0.008605},{
      0.086232, 0.138054, 0.008605},{0.085472, 0.139099, 0.007813}}],
    Polygon[{{0.087454, 0.138677, 0.008605},{0.087887, 0.137345, 0.009185},{
      0.087055, 0.136921, 0.009185},{0.086232, 0.138054, 0.008605}}],
    Polygon[{{0.087887, 0.137345, 0.009185},{0.088342, 0.135944, 0.009538},{
      0.087921, 0.135729, 0.009538},{0.087055, 0.136921, 0.009185}}],
    Polygon[{{0.087921, 0.135729, -0.009538},{0.087055, 0.136921, -0.009185},{
      0.086395, 0.136261, -0.009185},{0.087587, 0.135395, -0.009538}}],
    Polygon[{{0.087055, 0.136921, -0.009185},{0.086232, 0.138054, -0.008605},{
      0.085262, 0.137084, -0.008605},{0.086395, 0.136261, -0.009185}}],
    Polygon[{{0.086232, 0.138054, -0.008605},{0.085472, 0.139099, -0.007813},{
      0.084217, 0.137844, -0.007813},{0.085262, 0.137084, -0.008605}}],
    Polygon[{{0.085472, 0.139099, -0.007813},{0.084795, 0.140032, -0.006829},{
      0.083284, 0.138521, -0.006829},{0.084217, 0.137844, -0.007813}}],
    Polygon[{{0.084795, 0.140032, -0.006829},{0.084217, 0.140828, -0.005676},{
      0.082488, 0.139099, -0.005676},{0.083284, 0.138521, -0.006829}}],
    Polygon[{{0.084217, 0.140828, -0.005676},{0.083751, 0.141468, -0.004384},{
      0.081848, 0.139565, -0.004384},{0.082488, 0.139099, -0.005676}}],
    Polygon[{{0.083751, 0.141468, -0.004384},{0.083410, 0.141937, -0.002984},{
      0.081378, 0.139906, -0.002984},{0.081848, 0.139565, -0.004384}}],
    Polygon[{{0.083410, 0.141937, -0.002984},{0.083202, 0.142224, -0.001511},{
      0.081092, 0.140114, -0.001511},{0.081378, 0.139906, -0.002984}}],
    Polygon[{{0.083202, 0.142224, -0.001511},{0.083132, 0.142320, 0.000000},{
      0.080996, 0.140183, 0.000000},{0.081092, 0.140114, -0.001511}}],
    Polygon[{{0.083132, 0.142320, 0.000000},{0.083202, 0.142224, 0.001511},{
      0.081092, 0.140114, 0.001511},{0.080996, 0.140183, 0.000000}}],
    Polygon[{{0.083202, 0.142224, 0.001511},{0.083410, 0.141937, 0.002984},{
      0.081378, 0.139906, 0.002984},{0.081092, 0.140114, 0.001511}}],
    Polygon[{{0.083410, 0.141937, 0.002984},{0.083751, 0.141468, 0.004384},{
      0.081848, 0.139565, 0.004384},{0.081378, 0.139906, 0.002984}}],
    Polygon[{{0.083751, 0.141468, 0.004384},{0.084217, 0.140828, 0.005676},{
      0.082488, 0.139099, 0.005676},{0.081848, 0.139565, 0.004384}}],
    Polygon[{{0.084217, 0.140828, 0.005676},{0.084795, 0.140032, 0.006829},{
      0.083284, 0.138521, 0.006829},{0.082488, 0.139099, 0.005676}}],
    Polygon[{{0.084795, 0.140032, 0.006829},{0.085472, 0.139099, 0.007813},{
      0.084217, 0.137844, 0.007813},{0.083284, 0.138521, 0.006829}}],
    Polygon[{{0.085472, 0.139099, 0.007813},{0.086232, 0.138054, 0.008605},{
      0.085262, 0.137084, 0.008605},{0.084217, 0.137844, 0.007813}}],
    Polygon[{{0.086232, 0.138054, 0.008605},{0.087055, 0.136921, 0.009185},{
      0.086395, 0.136261, 0.009185},{0.085262, 0.137084, 0.008605}}],
    Polygon[{{0.087055, 0.136921, 0.009185},{0.087921, 0.135729, 0.009538},{
      0.087587, 0.135395, 0.009538},{0.086395, 0.136261, 0.009185}}],
    Polygon[{{0.087587, 0.135395, -0.009538},{0.086395, 0.136261, -0.009185},{
      0.085971, 0.135429, -0.009185},{0.087372, 0.134974, -0.009538}}],
    Polygon[{{0.086395, 0.136261, -0.009185},{0.085262, 0.137084, -0.008605},{
      0.084639, 0.135862, -0.008605},{0.085971, 0.135429, -0.009185}}],
    Polygon[{{0.085262, 0.137084, -0.008605},{0.084217, 0.137844, -0.007813},{
      0.083410, 0.136261, -0.007813},{0.084639, 0.135862, -0.008605}}],
    Polygon[{{0.084217, 0.137844, -0.007813},{0.083284, 0.138521, -0.006829},{
      0.082314, 0.136617, -0.006829},{0.083410, 0.136261, -0.007813}}],
    Polygon[{{0.083284, 0.138521, -0.006829},{0.082488, 0.139099, -0.005676},{
      0.081378, 0.136921, -0.005676},{0.082314, 0.136617, -0.006829}}],
    Polygon[{{0.082488, 0.139099, -0.005676},{0.081848, 0.139565, -0.004384},{
      0.080625, 0.137166, -0.004384},{0.081378, 0.136921, -0.005676}}],
    Polygon[{{0.081848, 0.139565, -0.004384},{0.081378, 0.139906, -0.002984},{
      0.080074, 0.137345, -0.002984},{0.080625, 0.137166, -0.004384}}],
    Polygon[{{0.081378, 0.139906, -0.002984},{0.081092, 0.140114, -0.001511},{
      0.079737, 0.137455, -0.001511},{0.080074, 0.137345, -0.002984}}],
    Polygon[{{0.081092, 0.140114, -0.001511},{0.080996, 0.140183, 0.000000},{
      0.079624, 0.137491, 0.000000},{0.079737, 0.137455, -0.001511}}],
    Polygon[{{0.080996, 0.140183, 0.000000},{0.081092, 0.140114, 0.001511},{
      0.079737, 0.137455, 0.001511},{0.079624, 0.137491, 0.000000}}],
    Polygon[{{0.081092, 0.140114, 0.001511},{0.081378, 0.139906, 0.002984},{
      0.080074, 0.137345, 0.002984},{0.079737, 0.137455, 0.001511}}],
    Polygon[{{0.081378, 0.139906, 0.002984},{0.081848, 0.139565, 0.004384},{
      0.080625, 0.137166, 0.004384},{0.080074, 0.137345, 0.002984}}],
    Polygon[{{0.081848, 0.139565, 0.004384},{0.082488, 0.139099, 0.005676},{
      0.081378, 0.136921, 0.005676},{0.080625, 0.137166, 0.004384}}],
    Polygon[{{0.082488, 0.139099, 0.005676},{0.083284, 0.138521, 0.006829},{
      0.082314, 0.136617, 0.006829},{0.081378, 0.136921, 0.005676}}],
    Polygon[{{0.083284, 0.138521, 0.006829},{0.084217, 0.137844, 0.007813},{
      0.083410, 0.136261, 0.007813},{0.082314, 0.136617, 0.006829}}],
    Polygon[{{0.084217, 0.137844, 0.007813},{0.085262, 0.137084, 0.008605},{
      0.084639, 0.135862, 0.008605},{0.083410, 0.136261, 0.007813}}],
    Polygon[{{0.085262, 0.137084, 0.008605},{0.086395, 0.136261, 0.009185},{
      0.085971, 0.135429, 0.009185},{0.084639, 0.135862, 0.008605}}],
    Polygon[{{0.086395, 0.136261, 0.009185},{0.087587, 0.135395, 0.009538},{
      0.087372, 0.134974, 0.009538},{0.085971, 0.135429, 0.009185}}],
    Polygon[{{0.087372, 0.134974, -0.009538},{0.085971, 0.135429, -0.009185},{
      0.085825, 0.134507, -0.009185},{0.087298, 0.134507, -0.009538}}],
    Polygon[{{0.085971, 0.135429, -0.009185},{0.084639, 0.135862, -0.008605},{
      0.084425, 0.134507, -0.008605},{0.085825, 0.134507, -0.009185}}],
    Polygon[{{0.084639, 0.135862, -0.008605},{0.083410, 0.136261, -0.007813},{
      0.083132, 0.134507, -0.007813},{0.084425, 0.134507, -0.008605}}],
    Polygon[{{0.083410, 0.136261, -0.007813},{0.082314, 0.136617, -0.006829},{
      0.081980, 0.134507, -0.006829},{0.083132, 0.134507, -0.007813}}],
    Polygon[{{0.082314, 0.136617, -0.006829},{0.081378, 0.136921, -0.005676},{
      0.080996, 0.134507, -0.005676},{0.081980, 0.134507, -0.006829}}],
    Polygon[{{0.081378, 0.136921, -0.005676},{0.080625, 0.137166, -0.004384},{
      0.080204, 0.134507, -0.004384},{0.080996, 0.134507, -0.005676}}],
    Polygon[{{0.080625, 0.137166, -0.004384},{0.080074, 0.137345, -0.002984},{
      0.079624, 0.134507, -0.002984},{0.080204, 0.134507, -0.004384}}],
    Polygon[{{0.080074, 0.137345, -0.002984},{0.079737, 0.137455, -0.001511},{
      0.079271, 0.134507, -0.001511},{0.079624, 0.134507, -0.002984}}],
    Polygon[{{0.079737, 0.137455, -0.001511},{0.079624, 0.137491, 0.000000},{
      0.079152, 0.134507, 0.000000},{0.079271, 0.134507, -0.001511}}],
    Polygon[{{0.079624, 0.137491, 0.000000},{0.079737, 0.137455, 0.001511},{
      0.079271, 0.134507, 0.001511},{0.079152, 0.134507, 0.000000}}],
    Polygon[{{0.079737, 0.137455, 0.001511},{0.080074, 0.137345, 0.002984},{
      0.079624, 0.134507, 0.002984},{0.079271, 0.134507, 0.001511}}],
    Polygon[{{0.080074, 0.137345, 0.002984},{0.080625, 0.137166, 0.004384},{
      0.080204, 0.134507, 0.004384},{0.079624, 0.134507, 0.002984}}],
    Polygon[{{0.080625, 0.137166, 0.004384},{0.081378, 0.136921, 0.005676},{
      0.080996, 0.134507, 0.005676},{0.080204, 0.134507, 0.004384}}],
    Polygon[{{0.081378, 0.136921, 0.005676},{0.082314, 0.136617, 0.006829},{
      0.081980, 0.134507, 0.006829},{0.080996, 0.134507, 0.005676}}],
    Polygon[{{0.082314, 0.136617, 0.006829},{0.083410, 0.136261, 0.007813},{
      0.083132, 0.134507, 0.007813},{0.081980, 0.134507, 0.006829}}],
    Polygon[{{0.083410, 0.136261, 0.007813},{0.084639, 0.135862, 0.008605},{
      0.084425, 0.134507, 0.008605},{0.083132, 0.134507, 0.007813}}],
    Polygon[{{0.084639, 0.135862, 0.008605},{0.085971, 0.135429, 0.009185},{
      0.085825, 0.134507, 0.009185},{0.084425, 0.134507, 0.008605}}],
    Polygon[{{0.085971, 0.135429, 0.009185},{0.087372, 0.134974, 0.009538},{
      0.087298, 0.134507, 0.009538},{0.085825, 0.134507, 0.009185}}],
    Polygon[{{0.087298, 0.134507, -0.009538},{0.085825, 0.134507, -0.009185},{
      0.085971, 0.133585, -0.009185},{0.087372, 0.134040, -0.009538}}],
    Polygon[{{0.085825, 0.134507, -0.009185},{0.084425, 0.134507, -0.008605},{
      0.084639, 0.133152, -0.008605},{0.085971, 0.133585, -0.009185}}],
    Polygon[{{0.084425, 0.134507, -0.008605},{0.083132, 0.134507, -0.007813},{
      0.083410, 0.132753, -0.007813},{0.084639, 0.133152, -0.008605}}],
    Polygon[{{0.083132, 0.134507, -0.007813},{0.081980, 0.134507, -0.006829},{
      0.082314, 0.132397, -0.006829},{0.083410, 0.132753, -0.007813}}],
    Polygon[{{0.081980, 0.134507, -0.006829},{0.080996, 0.134507, -0.005676},{
      0.081378, 0.132093, -0.005676},{0.082314, 0.132397, -0.006829}}],
    Polygon[{{0.080996, 0.134507, -0.005676},{0.080204, 0.134507, -0.004384},{
      0.080625, 0.131848, -0.004384},{0.081378, 0.132093, -0.005676}}],
    Polygon[{{0.080204, 0.134507, -0.004384},{0.079624, 0.134507, -0.002984},{
      0.080074, 0.131669, -0.002984},{0.080625, 0.131848, -0.004384}}],
    Polygon[{{0.079624, 0.134507, -0.002984},{0.079271, 0.134507, -0.001511},{
      0.079737, 0.131560, -0.001511},{0.080074, 0.131669, -0.002984}}],
    Polygon[{{0.079271, 0.134507, -0.001511},{0.079152, 0.134507, 0.000000},{
      0.079624, 0.131523, 0.000000},{0.079737, 0.131560, -0.001511}}],
    Polygon[{{0.079152, 0.134507, 0.000000},{0.079271, 0.134507, 0.001511},{
      0.079737, 0.131560, 0.001511},{0.079624, 0.131523, 0.000000}}],
    Polygon[{{0.079271, 0.134507, 0.001511},{0.079624, 0.134507, 0.002984},{
      0.080074, 0.131669, 0.002984},{0.079737, 0.131560, 0.001511}}],
    Polygon[{{0.079624, 0.134507, 0.002984},{0.080204, 0.134507, 0.004384},{
      0.080625, 0.131848, 0.004384},{0.080074, 0.131669, 0.002984}}],
    Polygon[{{0.080204, 0.134507, 0.004384},{0.080996, 0.134507, 0.005676},{
      0.081378, 0.132093, 0.005676},{0.080625, 0.131848, 0.004384}}],
    Polygon[{{0.080996, 0.134507, 0.005676},{0.081980, 0.134507, 0.006829},{
      0.082314, 0.132397, 0.006829},{0.081378, 0.132093, 0.005676}}],
    Polygon[{{0.081980, 0.134507, 0.006829},{0.083132, 0.134507, 0.007813},{
      0.083410, 0.132753, 0.007813},{0.082314, 0.132397, 0.006829}}],
    Polygon[{{0.083132, 0.134507, 0.007813},{0.084425, 0.134507, 0.008605},{
      0.084639, 0.133152, 0.008605},{0.083410, 0.132753, 0.007813}}],
    Polygon[{{0.084425, 0.134507, 0.008605},{0.085825, 0.134507, 0.009185},{
      0.085971, 0.133585, 0.009185},{0.084639, 0.133152, 0.008605}}],
    Polygon[{{0.085825, 0.134507, 0.009185},{0.087298, 0.134507, 0.009538},{
      0.087372, 0.134040, 0.009538},{0.085971, 0.133585, 0.009185}}],
    Polygon[{{0.087372, 0.134040, -0.009538},{0.085971, 0.133585, -0.009185},{
      0.086395, 0.132753, -0.009185},{0.087587, 0.133619, -0.009538}}],
    Polygon[{{0.085971, 0.133585, -0.009185},{0.084639, 0.133152, -0.008605},{
      0.085262, 0.131930, -0.008605},{0.086395, 0.132753, -0.009185}}],
    Polygon[{{0.084639, 0.133152, -0.008605},{0.083410, 0.132753, -0.007813},{
      0.084217, 0.131171, -0.007813},{0.085262, 0.131930, -0.008605}}],
    Polygon[{{0.083410, 0.132753, -0.007813},{0.082314, 0.132397, -0.006829},{
      0.083284, 0.130493, -0.006829},{0.084217, 0.131171, -0.007813}}],
    Polygon[{{0.082314, 0.132397, -0.006829},{0.081378, 0.132093, -0.005676},{
      0.082488, 0.129915, -0.005676},{0.083284, 0.130493, -0.006829}}],
    Polygon[{{0.081378, 0.132093, -0.005676},{0.080625, 0.131848, -0.004384},{
      0.081848, 0.129449, -0.004384},{0.082488, 0.129915, -0.005676}}],
    Polygon[{{0.080625, 0.131848, -0.004384},{0.080074, 0.131669, -0.002984},{
      0.081378, 0.129109, -0.002984},{0.081848, 0.129449, -0.004384}}],
    Polygon[{{0.080074, 0.131669, -0.002984},{0.079737, 0.131560, -0.001511},{
      0.081092, 0.128901, -0.001511},{0.081378, 0.129109, -0.002984}}],
    Polygon[{{0.079737, 0.131560, -0.001511},{0.079624, 0.131523, 0.000000},{
      0.080996, 0.128831, 0.000000},{0.081092, 0.128901, -0.001511}}],
    Polygon[{{0.079624, 0.131523, 0.000000},{0.079737, 0.131560, 0.001511},{
      0.081092, 0.128901, 0.001511},{0.080996, 0.128831, 0.000000}}],
    Polygon[{{0.079737, 0.131560, 0.001511},{0.080074, 0.131669, 0.002984},{
      0.081378, 0.129109, 0.002984},{0.081092, 0.128901, 0.001511}}],
    Polygon[{{0.080074, 0.131669, 0.002984},{0.080625, 0.131848, 0.004384},{
      0.081848, 0.129449, 0.004384},{0.081378, 0.129109, 0.002984}}],
    Polygon[{{0.080625, 0.131848, 0.004384},{0.081378, 0.132093, 0.005676},{
      0.082488, 0.129915, 0.005676},{0.081848, 0.129449, 0.004384}}],
    Polygon[{{0.081378, 0.132093, 0.005676},{0.082314, 0.132397, 0.006829},{
      0.083284, 0.130493, 0.006829},{0.082488, 0.129915, 0.005676}}],
    Polygon[{{0.082314, 0.132397, 0.006829},{0.083410, 0.132753, 0.007813},{
      0.084217, 0.131171, 0.007813},{0.083284, 0.130493, 0.006829}}],
    Polygon[{{0.083410, 0.132753, 0.007813},{0.084639, 0.133152, 0.008605},{
      0.085262, 0.131930, 0.008605},{0.084217, 0.131171, 0.007813}}],
    Polygon[{{0.084639, 0.133152, 0.008605},{0.085971, 0.133585, 0.009185},{
      0.086395, 0.132753, 0.009185},{0.085262, 0.131930, 0.008605}}],
    Polygon[{{0.085971, 0.133585, 0.009185},{0.087372, 0.134040, 0.009538},{
      0.087587, 0.133619, 0.009538},{0.086395, 0.132753, 0.009185}}],
    Polygon[{{0.087587, 0.133619, -0.009538},{0.086395, 0.132753, -0.009185},{
      0.087055, 0.132093, -0.009185},{0.087921, 0.133285, -0.009538}}],
    Polygon[{{0.086395, 0.132753, -0.009185},{0.085262, 0.131930, -0.008605},{
      0.086232, 0.130960, -0.008605},{0.087055, 0.132093, -0.009185}}],
    Polygon[{{0.085262, 0.131930, -0.008605},{0.084217, 0.131171, -0.007813},{
      0.085472, 0.129915, -0.007813},{0.086232, 0.130960, -0.008605}}],
    Polygon[{{0.084217, 0.131171, -0.007813},{0.083284, 0.130493, -0.006829},{
      0.084795, 0.128983, -0.006829},{0.085472, 0.129915, -0.007813}}],
    Polygon[{{0.083284, 0.130493, -0.006829},{0.082488, 0.129915, -0.005676},{
      0.084217, 0.128186, -0.005676},{0.084795, 0.128983, -0.006829}}],
    Polygon[{{0.082488, 0.129915, -0.005676},{0.081848, 0.129449, -0.004384},{
      0.083751, 0.127546, -0.004384},{0.084217, 0.128186, -0.005676}}],
    Polygon[{{0.081848, 0.129449, -0.004384},{0.081378, 0.129109, -0.002984},{
      0.083410, 0.127077, -0.002984},{0.083751, 0.127546, -0.004384}}],
    Polygon[{{0.081378, 0.129109, -0.002984},{0.081092, 0.128901, -0.001511},{
      0.083202, 0.126790, -0.001511},{0.083410, 0.127077, -0.002984}}],
    Polygon[{{0.081092, 0.128901, -0.001511},{0.080996, 0.128831, 0.000000},{
      0.083132, 0.126694, 0.000000},{0.083202, 0.126790, -0.001511}}],
    Polygon[{{0.080996, 0.128831, 0.000000},{0.081092, 0.128901, 0.001511},{
      0.083202, 0.126790, 0.001511},{0.083132, 0.126694, 0.000000}}],
    Polygon[{{0.081092, 0.128901, 0.001511},{0.081378, 0.129109, 0.002984},{
      0.083410, 0.127077, 0.002984},{0.083202, 0.126790, 0.001511}}],
    Polygon[{{0.081378, 0.129109, 0.002984},{0.081848, 0.129449, 0.004384},{
      0.083751, 0.127546, 0.004384},{0.083410, 0.127077, 0.002984}}],
    Polygon[{{0.081848, 0.129449, 0.004384},{0.082488, 0.129915, 0.005676},{
      0.084217, 0.128186, 0.005676},{0.083751, 0.127546, 0.004384}}],
    Polygon[{{0.082488, 0.129915, 0.005676},{0.083284, 0.130493, 0.006829},{
      0.084795, 0.128983, 0.006829},{0.084217, 0.128186, 0.005676}}],
    Polygon[{{0.083284, 0.130493, 0.006829},{0.084217, 0.131171, 0.007813},{
      0.085472, 0.129915, 0.007813},{0.084795, 0.128983, 0.006829}}],
    Polygon[{{0.084217, 0.131171, 0.007813},{0.085262, 0.131930, 0.008605},{
      0.086232, 0.130960, 0.008605},{0.085472, 0.129915, 0.007813}}],
    Polygon[{{0.085262, 0.131930, 0.008605},{0.086395, 0.132753, 0.009185},{
      0.087055, 0.132093, 0.009185},{0.086232, 0.130960, 0.008605}}],
    Polygon[{{0.086395, 0.132753, 0.009185},{0.087587, 0.133619, 0.009538},{
      0.087921, 0.133285, 0.009538},{0.087055, 0.132093, 0.009185}}],
    Polygon[{{0.087921, 0.133285, -0.009538},{0.087055, 0.132093, -0.009185},{
      0.087887, 0.131669, -0.009185},{0.088342, 0.133070, -0.009538}}],
    Polygon[{{0.087055, 0.132093, -0.009185},{0.086232, 0.130960, -0.008605},{
      0.087454, 0.130337, -0.008605},{0.087887, 0.131669, -0.009185}}],
    Polygon[{{0.086232, 0.130960, -0.008605},{0.085472, 0.129915, -0.007813},{
      0.087055, 0.129109, -0.007813},{0.087454, 0.130337, -0.008605}}],
    Polygon[{{0.085472, 0.129915, -0.007813},{0.084795, 0.128983, -0.006829},{
      0.086699, 0.128013, -0.006829},{0.087055, 0.129109, -0.007813}}],
    Polygon[{{0.084795, 0.128983, -0.006829},{0.084217, 0.128186, -0.005676},{
      0.086395, 0.127077, -0.005676},{0.086699, 0.128013, -0.006829}}],
    Polygon[{{0.084217, 0.128186, -0.005676},{0.083751, 0.127546, -0.004384},{
      0.086150, 0.126324, -0.004384},{0.086395, 0.127077, -0.005676}}],
    Polygon[{{0.083751, 0.127546, -0.004384},{0.083410, 0.127077, -0.002984},{
      0.085971, 0.125772, -0.002984},{0.086150, 0.126324, -0.004384}}],
    Polygon[{{0.083410, 0.127077, -0.002984},{0.083202, 0.126790, -0.001511},{
      0.085861, 0.125436, -0.001511},{0.085971, 0.125772, -0.002984}}],
    Polygon[{{0.083202, 0.126790, -0.001511},{0.083132, 0.126694, 0.000000},{
      0.085825, 0.125323, 0.000000},{0.085861, 0.125436, -0.001511}}],
    Polygon[{{0.083132, 0.126694, 0.000000},{0.083202, 0.126790, 0.001511},{
      0.085861, 0.125436, 0.001511},{0.085825, 0.125323, 0.000000}}],
    Polygon[{{0.083202, 0.126790, 0.001511},{0.083410, 0.127077, 0.002984},{
      0.085971, 0.125772, 0.002984},{0.085861, 0.125436, 0.001511}}],
    Polygon[{{0.083410, 0.127077, 0.002984},{0.083751, 0.127546, 0.004384},{
      0.086150, 0.126324, 0.004384},{0.085971, 0.125772, 0.002984}}],
    Polygon[{{0.083751, 0.127546, 0.004384},{0.084217, 0.128186, 0.005676},{
      0.086395, 0.127077, 0.005676},{0.086150, 0.126324, 0.004384}}],
    Polygon[{{0.084217, 0.128186, 0.005676},{0.084795, 0.128983, 0.006829},{
      0.086699, 0.128013, 0.006829},{0.086395, 0.127077, 0.005676}}],
    Polygon[{{0.084795, 0.128983, 0.006829},{0.085472, 0.129915, 0.007813},{
      0.087055, 0.129109, 0.007813},{0.086699, 0.128013, 0.006829}}],
    Polygon[{{0.085472, 0.129915, 0.007813},{0.086232, 0.130960, 0.008605},{
      0.087454, 0.130337, 0.008605},{0.087055, 0.129109, 0.007813}}],
    Polygon[{{0.086232, 0.130960, 0.008605},{0.087055, 0.132093, 0.009185},{
      0.087887, 0.131669, 0.009185},{0.087454, 0.130337, 0.008605}}],
    Polygon[{{0.087055, 0.132093, 0.009185},{0.087921, 0.133285, 0.009538},{
      0.088342, 0.133070, 0.009538},{0.087887, 0.131669, 0.009185}}],
    Polygon[{{0.088342, 0.133070, -0.009538},{0.087887, 0.131669, -0.009185},{
      0.088809, 0.131523, -0.009185},{0.088809, 0.132996, -0.009538}}],
    Polygon[{{0.087887, 0.131669, -0.009185},{0.087454, 0.130337, -0.008605},{
      0.088809, 0.130123, -0.008605},{0.088809, 0.131523, -0.009185}}],
    Polygon[{{0.087454, 0.130337, -0.008605},{0.087055, 0.129109, -0.007813},{
      0.088809, 0.128831, -0.007813},{0.088809, 0.130123, -0.008605}}],
    Polygon[{{0.087055, 0.129109, -0.007813},{0.086699, 0.128013, -0.006829},{
      0.088809, 0.127678, -0.006829},{0.088809, 0.128831, -0.007813}}],
    Polygon[{{0.086699, 0.128013, -0.006829},{0.086395, 0.127077, -0.005676},{
      0.088809, 0.126694, -0.005676},{0.088809, 0.127678, -0.006829}}],
    Polygon[{{0.086395, 0.127077, -0.005676},{0.086150, 0.126324, -0.004384},{
      0.088809, 0.125902, -0.004384},{0.088809, 0.126694, -0.005676}}],
    Polygon[{{0.086150, 0.126324, -0.004384},{0.085971, 0.125772, -0.002984},{
      0.088809, 0.125323, -0.002984},{0.088809, 0.125902, -0.004384}}],
    Polygon[{{0.085971, 0.125772, -0.002984},{0.085861, 0.125436, -0.001511},{
      0.088809, 0.124969, -0.001511},{0.088809, 0.125323, -0.002984}}],
    Polygon[{{0.085861, 0.125436, -0.001511},{0.085825, 0.125323, 0.000000},{
      0.088809, 0.124850, 0.000000},{0.088809, 0.124969, -0.001511}}],
    Polygon[{{0.085825, 0.125323, 0.000000},{0.085861, 0.125436, 0.001511},{
      0.088809, 0.124969, 0.001511},{0.088809, 0.124850, 0.000000}}],
    Polygon[{{0.085861, 0.125436, 0.001511},{0.085971, 0.125772, 0.002984},{
      0.088809, 0.125323, 0.002984},{0.088809, 0.124969, 0.001511}}],
    Polygon[{{0.085971, 0.125772, 0.002984},{0.086150, 0.126324, 0.004384},{
      0.088809, 0.125902, 0.004384},{0.088809, 0.125323, 0.002984}}],
    Polygon[{{0.086150, 0.126324, 0.004384},{0.086395, 0.127077, 0.005676},{
      0.088809, 0.126694, 0.005676},{0.088809, 0.125902, 0.004384}}],
    Polygon[{{0.086395, 0.127077, 0.005676},{0.086699, 0.128013, 0.006829},{
      0.088809, 0.127678, 0.006829},{0.088809, 0.126694, 0.005676}}],
    Polygon[{{0.086699, 0.128013, 0.006829},{0.087055, 0.129109, 0.007813},{
      0.088809, 0.128831, 0.007813},{0.088809, 0.127678, 0.006829}}],
    Polygon[{{0.087055, 0.129109, 0.007813},{0.087454, 0.130337, 0.008605},{
      0.088809, 0.130123, 0.008605},{0.088809, 0.128831, 0.007813}}],
    Polygon[{{0.087454, 0.130337, 0.008605},{0.087887, 0.131669, 0.009185},{
      0.088809, 0.131523, 0.009185},{0.088809, 0.130123, 0.008605}}],
    Polygon[{{0.087887, 0.131669, 0.009185},{0.088342, 0.133070, 0.009538},{
      0.088809, 0.132996, 0.009538},{0.088809, 0.131523, 0.009185}}],
    Polygon[{{0.088809, 0.132996, -0.009538},{0.088809, 0.131523, -0.009185},{
      0.089731, 0.131669, -0.009185},{0.089276, 0.133070, -0.009538}}],
    Polygon[{{0.088809, 0.131523, -0.009185},{0.088809, 0.130123, -0.008605},{
      0.090164, 0.130337, -0.008605},{0.089731, 0.131669, -0.009185}}],
    Polygon[{{0.088809, 0.130123, -0.008605},{0.088809, 0.128831, -0.007813},{
      0.090563, 0.129109, -0.007813},{0.090164, 0.130337, -0.008605}}],
    Polygon[{{0.088809, 0.128831, -0.007813},{0.088809, 0.127678, -0.006829},{
      0.090919, 0.128013, -0.006829},{0.090563, 0.129109, -0.007813}}],
    Polygon[{{0.088809, 0.127678, -0.006829},{0.088809, 0.126694, -0.005676},{
      0.091223, 0.127077, -0.005676},{0.090919, 0.128013, -0.006829}}],
    Polygon[{{0.088809, 0.126694, -0.005676},{0.088809, 0.125902, -0.004384},{
      0.091468, 0.126324, -0.004384},{0.091223, 0.127077, -0.005676}}],
    Polygon[{{0.088809, 0.125902, -0.004384},{0.088809, 0.125323, -0.002984},{
      0.091647, 0.125772, -0.002984},{0.091468, 0.126324, -0.004384}}],
    Polygon[{{0.088809, 0.125323, -0.002984},{0.088809, 0.124969, -0.001511},{
      0.091756, 0.125436, -0.001511},{0.091647, 0.125772, -0.002984}}],
    Polygon[{{0.088809, 0.124969, -0.001511},{0.088809, 0.124850, 0.000000},{
      0.091793, 0.125323, 0.000000},{0.091756, 0.125436, -0.001511}}],
    Polygon[{{0.088809, 0.124850, 0.000000},{0.088809, 0.124969, 0.001511},{
      0.091756, 0.125436, 0.001511},{0.091793, 0.125323, 0.000000}}],
    Polygon[{{0.088809, 0.124969, 0.001511},{0.088809, 0.125323, 0.002984},{
      0.091647, 0.125772, 0.002984},{0.091756, 0.125436, 0.001511}}],
    Polygon[{{0.088809, 0.125323, 0.002984},{0.088809, 0.125902, 0.004384},{
      0.091468, 0.126324, 0.004384},{0.091647, 0.125772, 0.002984}}],
    Polygon[{{0.088809, 0.125902, 0.004384},{0.088809, 0.126694, 0.005676},{
      0.091223, 0.127077, 0.005676},{0.091468, 0.126324, 0.004384}}],
    Polygon[{{0.088809, 0.126694, 0.005676},{0.088809, 0.127678, 0.006829},{
      0.090919, 0.128013, 0.006829},{0.091223, 0.127077, 0.005676}}],
    Polygon[{{0.088809, 0.127678, 0.006829},{0.088809, 0.128831, 0.007813},{
      0.090563, 0.129109, 0.007813},{0.090919, 0.128013, 0.006829}}],
    Polygon[{{0.088809, 0.128831, 0.007813},{0.088809, 0.130123, 0.008605},{
      0.090164, 0.130337, 0.008605},{0.090563, 0.129109, 0.007813}}],
    Polygon[{{0.088809, 0.130123, 0.008605},{0.088809, 0.131523, 0.009185},{
      0.089731, 0.131669, 0.009185},{0.090164, 0.130337, 0.008605}}],
    Polygon[{{0.088809, 0.131523, 0.009185},{0.088809, 0.132996, 0.009538},{
      0.089276, 0.133070, 0.009538},{0.089731, 0.131669, 0.009185}}],
    Polygon[{{0.089276, 0.133070, -0.009538},{0.089731, 0.131669, -0.009185},{
      0.090563, 0.132093, -0.009185},{0.089697, 0.133285, -0.009538}}],
    Polygon[{{0.089731, 0.131669, -0.009185},{0.090164, 0.130337, -0.008605},{
      0.091386, 0.130960, -0.008605},{0.090563, 0.132093, -0.009185}}],
    Polygon[{{0.090164, 0.130337, -0.008605},{0.090563, 0.129109, -0.007813},{
      0.092145, 0.129915, -0.007813},{0.091386, 0.130960, -0.008605}}],
    Polygon[{{0.090563, 0.129109, -0.007813},{0.090919, 0.128013, -0.006829},{
      0.092823, 0.128983, -0.006829},{0.092145, 0.129915, -0.007813}}],
    Polygon[{{0.090919, 0.128013, -0.006829},{0.091223, 0.127077, -0.005676},{
      0.093401, 0.128186, -0.005676},{0.092823, 0.128983, -0.006829}}],
    Polygon[{{0.091223, 0.127077, -0.005676},{0.091468, 0.126324, -0.004384},{
      0.093866, 0.127546, -0.004384},{0.093401, 0.128186, -0.005676}}],
    Polygon[{{0.091468, 0.126324, -0.004384},{0.091647, 0.125772, -0.002984},{
      0.094207, 0.127077, -0.002984},{0.093866, 0.127546, -0.004384}}],
    Polygon[{{0.091647, 0.125772, -0.002984},{0.091756, 0.125436, -0.001511},{
      0.094415, 0.126790, -0.001511},{0.094207, 0.127077, -0.002984}}],
    Polygon[{{0.091756, 0.125436, -0.001511},{0.091793, 0.125323, 0.000000},{
      0.094485, 0.126694, 0.000000},{0.094415, 0.126790, -0.001511}}],
    Polygon[{{0.091793, 0.125323, 0.000000},{0.091756, 0.125436, 0.001511},{
      0.094415, 0.126790, 0.001511},{0.094485, 0.126694, 0.000000}}],
    Polygon[{{0.091756, 0.125436, 0.001511},{0.091647, 0.125772, 0.002984},{
      0.094207, 0.127077, 0.002984},{0.094415, 0.126790, 0.001511}}],
    Polygon[{{0.091647, 0.125772, 0.002984},{0.091468, 0.126324, 0.004384},{
      0.093866, 0.127546, 0.004384},{0.094207, 0.127077, 0.002984}}],
    Polygon[{{0.091468, 0.126324, 0.004384},{0.091223, 0.127077, 0.005676},{
      0.093401, 0.128186, 0.005676},{0.093866, 0.127546, 0.004384}}],
    Polygon[{{0.091223, 0.127077, 0.005676},{0.090919, 0.128013, 0.006829},{
      0.092823, 0.128983, 0.006829},{0.093401, 0.128186, 0.005676}}],
    Polygon[{{0.090919, 0.128013, 0.006829},{0.090563, 0.129109, 0.007813},{
      0.092145, 0.129915, 0.007813},{0.092823, 0.128983, 0.006829}}],
    Polygon[{{0.090563, 0.129109, 0.007813},{0.090164, 0.130337, 0.008605},{
      0.091386, 0.130960, 0.008605},{0.092145, 0.129915, 0.007813}}],
    Polygon[{{0.090164, 0.130337, 0.008605},{0.089731, 0.131669, 0.009185},{
      0.090563, 0.132093, 0.009185},{0.091386, 0.130960, 0.008605}}],
    Polygon[{{0.089731, 0.131669, 0.009185},{0.089276, 0.133070, 0.009538},{
      0.089697, 0.133285, 0.009538},{0.090563, 0.132093, 0.009185}}],
    Polygon[{{0.089697, 0.133285, -0.009538},{0.090563, 0.132093, -0.009185},{
      0.091223, 0.132753, -0.009185},{0.090031, 0.133619, -0.009538}}],
    Polygon[{{0.090563, 0.132093, -0.009185},{0.091386, 0.130960, -0.008605},{
      0.092356, 0.131930, -0.008605},{0.091223, 0.132753, -0.009185}}],
    Polygon[{{0.091386, 0.130960, -0.008605},{0.092145, 0.129915, -0.007813},{
      0.093401, 0.131171, -0.007813},{0.092356, 0.131930, -0.008605}}],
    Polygon[{{0.092145, 0.129915, -0.007813},{0.092823, 0.128983, -0.006829},{
      0.094333, 0.130493, -0.006829},{0.093401, 0.131171, -0.007813}}],
    Polygon[{{0.092823, 0.128983, -0.006829},{0.093401, 0.128186, -0.005676},{
      0.095130, 0.129915, -0.005676},{0.094333, 0.130493, -0.006829}}],
    Polygon[{{0.093401, 0.128186, -0.005676},{0.093866, 0.127546, -0.004384},{
      0.095770, 0.129449, -0.004384},{0.095130, 0.129915, -0.005676}}],
    Polygon[{{0.093866, 0.127546, -0.004384},{0.094207, 0.127077, -0.002984},{
      0.096239, 0.129109, -0.002984},{0.095770, 0.129449, -0.004384}}],
    Polygon[{{0.094207, 0.127077, -0.002984},{0.094415, 0.126790, -0.001511},{
      0.096525, 0.128901, -0.001511},{0.096239, 0.129109, -0.002984}}],
    Polygon[{{0.094415, 0.126790, -0.001511},{0.094485, 0.126694, 0.000000},{
      0.096622, 0.128831, 0.000000},{0.096525, 0.128901, -0.001511}}],
    Polygon[{{0.094485, 0.126694, 0.000000},{0.094415, 0.126790, 0.001511},{
      0.096525, 0.128901, 0.001511},{0.096622, 0.128831, 0.000000}}],
    Polygon[{{0.094415, 0.126790, 0.001511},{0.094207, 0.127077, 0.002984},{
      0.096239, 0.129109, 0.002984},{0.096525, 0.128901, 0.001511}}],
    Polygon[{{0.094207, 0.127077, 0.002984},{0.093866, 0.127546, 0.004384},{
      0.095770, 0.129449, 0.004384},{0.096239, 0.129109, 0.002984}}],
    Polygon[{{0.093866, 0.127546, 0.004384},{0.093401, 0.128186, 0.005676},{
      0.095130, 0.129915, 0.005676},{0.095770, 0.129449, 0.004384}}],
    Polygon[{{0.093401, 0.128186, 0.005676},{0.092823, 0.128983, 0.006829},{
      0.094333, 0.130493, 0.006829},{0.095130, 0.129915, 0.005676}}],
    Polygon[{{0.092823, 0.128983, 0.006829},{0.092145, 0.129915, 0.007813},{
      0.093401, 0.131171, 0.007813},{0.094333, 0.130493, 0.006829}}],
    Polygon[{{0.092145, 0.129915, 0.007813},{0.091386, 0.130960, 0.008605},{
      0.092356, 0.131930, 0.008605},{0.093401, 0.131171, 0.007813}}],
    Polygon[{{0.091386, 0.130960, 0.008605},{0.090563, 0.132093, 0.009185},{
      0.091223, 0.132753, 0.009185},{0.092356, 0.131930, 0.008605}}],
    Polygon[{{0.090563, 0.132093, 0.009185},{0.089697, 0.133285, 0.009538},{
      0.090031, 0.133619, 0.009538},{0.091223, 0.132753, 0.009185}}],
    Polygon[{{0.090031, 0.133619, -0.009538},{0.091223, 0.132753, -0.009185},{
      0.091647, 0.133585, -0.009185},{0.090246, 0.134040, -0.009538}}],
    Polygon[{{0.091223, 0.132753, -0.009185},{0.092356, 0.131930, -0.008605},{
      0.092979, 0.133152, -0.008605},{0.091647, 0.133585, -0.009185}}],
    Polygon[{{0.092356, 0.131930, -0.008605},{0.093401, 0.131171, -0.007813},{
      0.094207, 0.132753, -0.007813},{0.092979, 0.133152, -0.008605}}],
    Polygon[{{0.093401, 0.131171, -0.007813},{0.094333, 0.130493, -0.006829},{
      0.095303, 0.132397, -0.006829},{0.094207, 0.132753, -0.007813}}],
    Polygon[{{0.094333, 0.130493, -0.006829},{0.095130, 0.129915, -0.005676},{
      0.096239, 0.132093, -0.005676},{0.095303, 0.132397, -0.006829}}],
    Polygon[{{0.095130, 0.129915, -0.005676},{0.095770, 0.129449, -0.004384},{
      0.096992, 0.131848, -0.004384},{0.096239, 0.132093, -0.005676}}],
    Polygon[{{0.095770, 0.129449, -0.004384},{0.096239, 0.129109, -0.002984},{
      0.097544, 0.131669, -0.002984},{0.096992, 0.131848, -0.004384}}],
    Polygon[{{0.096239, 0.129109, -0.002984},{0.096525, 0.128901, -0.001511},{
      0.097880, 0.131560, -0.001511},{0.097544, 0.131669, -0.002984}}],
    Polygon[{{0.096525, 0.128901, -0.001511},{0.096622, 0.128831, 0.000000},{
      0.097993, 0.131523, 0.000000},{0.097880, 0.131560, -0.001511}}],
    Polygon[{{0.096622, 0.128831, 0.000000},{0.096525, 0.128901, 0.001511},{
      0.097880, 0.131560, 0.001511},{0.097993, 0.131523, 0.000000}}],
    Polygon[{{0.096525, 0.128901, 0.001511},{0.096239, 0.129109, 0.002984},{
      0.097544, 0.131669, 0.002984},{0.097880, 0.131560, 0.001511}}],
    Polygon[{{0.096239, 0.129109, 0.002984},{0.095770, 0.129449, 0.004384},{
      0.096992, 0.131848, 0.004384},{0.097544, 0.131669, 0.002984}}],
    Polygon[{{0.095770, 0.129449, 0.004384},{0.095130, 0.129915, 0.005676},{
      0.096239, 0.132093, 0.005676},{0.096992, 0.131848, 0.004384}}],
    Polygon[{{0.095130, 0.129915, 0.005676},{0.094333, 0.130493, 0.006829},{
      0.095303, 0.132397, 0.006829},{0.096239, 0.132093, 0.005676}}],
    Polygon[{{0.094333, 0.130493, 0.006829},{0.093401, 0.131171, 0.007813},{
      0.094207, 0.132753, 0.007813},{0.095303, 0.132397, 0.006829}}],
    Polygon[{{0.093401, 0.131171, 0.007813},{0.092356, 0.131930, 0.008605},{
      0.092979, 0.133152, 0.008605},{0.094207, 0.132753, 0.007813}}],
    Polygon[{{0.092356, 0.131930, 0.008605},{0.091223, 0.132753, 0.009185},{
      0.091647, 0.133585, 0.009185},{0.092979, 0.133152, 0.008605}}],
    Polygon[{{0.091223, 0.132753, 0.009185},{0.090031, 0.133619, 0.009538},{
      0.090246, 0.134040, 0.009538},{0.091647, 0.133585, 0.009185}}],
    Polygon[{{0.090246, 0.134040, -0.009538},{0.091647, 0.133585, -0.009185},{
      0.091793, 0.134507, -0.009185},{0.090320, 0.134507, -0.009538}}],
    Polygon[{{0.091647, 0.133585, -0.009185},{0.092979, 0.133152, -0.008605},{
      0.093193, 0.134507, -0.008605},{0.091793, 0.134507, -0.009185}}],
    Polygon[{{0.092979, 0.133152, -0.008605},{0.094207, 0.132753, -0.007813},{
      0.094485, 0.134507, -0.007813},{0.093193, 0.134507, -0.008605}}],
    Polygon[{{0.094207, 0.132753, -0.007813},{0.095303, 0.132397, -0.006829},{
      0.095637, 0.134507, -0.006829},{0.094485, 0.134507, -0.007813}}],
    Polygon[{{0.095303, 0.132397, -0.006829},{0.096239, 0.132093, -0.005676},{
      0.096622, 0.134507, -0.005676},{0.095637, 0.134507, -0.006829}}],
    Polygon[{{0.096239, 0.132093, -0.005676},{0.096992, 0.131848, -0.004384},{
      0.097413, 0.134507, -0.004384},{0.096622, 0.134507, -0.005676}}],
    Polygon[{{0.096992, 0.131848, -0.004384},{0.097544, 0.131669, -0.002984},{
      0.097993, 0.134507, -0.002984},{0.097413, 0.134507, -0.004384}}],
    Polygon[{{0.097544, 0.131669, -0.002984},{0.097880, 0.131560, -0.001511},{
      0.098347, 0.134507, -0.001511},{0.097993, 0.134507, -0.002984}}],
    Polygon[{{0.097880, 0.131560, -0.001511},{0.097993, 0.131523, 0.000000},{
      0.098466, 0.134507, 0.000000},{0.098347, 0.134507, -0.001511}}],
    Polygon[{{0.097993, 0.131523, 0.000000},{0.097880, 0.131560, 0.001511},{
      0.098347, 0.134507, 0.001511},{0.098466, 0.134507, 0.000000}}],
    Polygon[{{0.097880, 0.131560, 0.001511},{0.097544, 0.131669, 0.002984},{
      0.097993, 0.134507, 0.002984},{0.098347, 0.134507, 0.001511}}],
    Polygon[{{0.097544, 0.131669, 0.002984},{0.096992, 0.131848, 0.004384},{
      0.097413, 0.134507, 0.004384},{0.097993, 0.134507, 0.002984}}],
    Polygon[{{0.096992, 0.131848, 0.004384},{0.096239, 0.132093, 0.005676},{
      0.096622, 0.134507, 0.005676},{0.097413, 0.134507, 0.004384}}],
    Polygon[{{0.096239, 0.132093, 0.005676},{0.095303, 0.132397, 0.006829},{
      0.095637, 0.134507, 0.006829},{0.096622, 0.134507, 0.005676}}],
    Polygon[{{0.095303, 0.132397, 0.006829},{0.094207, 0.132753, 0.007813},{
      0.094485, 0.134507, 0.007813},{0.095637, 0.134507, 0.006829}}],
    Polygon[{{0.094207, 0.132753, 0.007813},{0.092979, 0.133152, 0.008605},{
      0.093193, 0.134507, 0.008605},{0.094485, 0.134507, 0.007813}}],
    Polygon[{{0.092979, 0.133152, 0.008605},{0.091647, 0.133585, 0.009185},{
      0.091793, 0.134507, 0.009185},{0.093193, 0.134507, 0.008605}}],
    Polygon[{{0.091647, 0.133585, 0.009185},{0.090246, 0.134040, 0.009538},{
      0.090320, 0.134507, 0.009538},{0.091793, 0.134507, 0.009185}}],
    Polygon[{{0.143923, 0.129498, -0.008290},{0.145204, 0.129498, -0.007983},{
      0.145077, 0.130300, -0.007983},{0.143859, 0.129904, -0.008290}}],
    Polygon[{{0.145204, 0.129498, -0.007983},{0.146421, 0.129498, -0.007479},{
      0.146235, 0.130676, -0.007479},{0.145077, 0.130300, -0.007983}}],
    Polygon[{{0.146421, 0.129498, -0.007479},{0.147544, 0.129498, -0.006791},{
      0.147303, 0.131023, -0.006791},{0.146235, 0.130676, -0.007479}}],
    Polygon[{{0.147544, 0.129498, -0.006791},{0.148546, 0.129498, -0.005935},{
      0.148255, 0.131332, -0.005935},{0.147303, 0.131023, -0.006791}}],
    Polygon[{{0.148546, 0.129498, -0.005935},{0.149401, 0.129498, -0.004934},{
      0.149069, 0.131597, -0.004934},{0.148255, 0.131332, -0.005935}}],
    Polygon[{{0.149401, 0.129498, -0.004934},{0.150089, 0.129498, -0.003811},{
      0.149723, 0.131809, -0.003811},{0.149069, 0.131597, -0.004934}}],
    Polygon[{{0.150089, 0.129498, -0.003811},{0.150593, 0.129498, -0.002594},{
      0.150202, 0.131965, -0.002594},{0.149723, 0.131809, -0.003811}}],
    Polygon[{{0.150593, 0.129498, -0.002594},{0.150901, 0.129498, -0.001313},{
      0.150495, 0.132060, -0.001313},{0.150202, 0.131965, -0.002594}}],
    Polygon[{{0.150901, 0.129498, -0.001313},{0.151004, 0.129498, 0.000000},{
      0.150593, 0.132092, 0.000000},{0.150495, 0.132060, -0.001313}}],
    Polygon[{{0.151004, 0.129498, 0.000000},{0.150901, 0.129498, 0.001313},{
      0.150495, 0.132060, 0.001313},{0.150593, 0.132092, 0.000000}}],
    Polygon[{{0.150901, 0.129498, 0.001313},{0.150593, 0.129498, 0.002594},{
      0.150202, 0.131965, 0.002594},{0.150495, 0.132060, 0.001313}}],
    Polygon[{{0.150593, 0.129498, 0.002594},{0.150089, 0.129498, 0.003811},{
      0.149723, 0.131809, 0.003811},{0.150202, 0.131965, 0.002594}}],
    Polygon[{{0.150089, 0.129498, 0.003811},{0.149401, 0.129498, 0.004934},{
      0.149069, 0.131597, 0.004934},{0.149723, 0.131809, 0.003811}}],
    Polygon[{{0.149401, 0.129498, 0.004934},{0.148546, 0.129498, 0.005935},{
      0.148255, 0.131332, 0.005935},{0.149069, 0.131597, 0.004934}}],
    Polygon[{{0.148546, 0.129498, 0.005935},{0.147544, 0.129498, 0.006791},{
      0.147303, 0.131023, 0.006791},{0.148255, 0.131332, 0.005935}}],
    Polygon[{{0.147544, 0.129498, 0.006791},{0.146421, 0.129498, 0.007479},{
      0.146235, 0.130676, 0.007479},{0.147303, 0.131023, 0.006791}}],
    Polygon[{{0.146421, 0.129498, 0.007479},{0.145204, 0.129498, 0.007983},{
      0.145077, 0.130300, 0.007983},{0.146235, 0.130676, 0.007479}}],
    Polygon[{{0.145204, 0.129498, 0.007983},{0.143923, 0.129498, 0.008290},{
      0.143859, 0.129904, 0.008290},{0.145077, 0.130300, 0.007983}}],
    Polygon[{{0.143859, 0.129904, -0.008290},{0.145077, 0.130300, -0.007983},{
      0.144709, 0.131023, -0.007983},{0.143673, 0.130270, -0.008290}}],
    Polygon[{{0.145077, 0.130300, -0.007983},{0.146235, 0.130676, -0.007479},{
      0.145693, 0.131738, -0.007479},{0.144709, 0.131023, -0.007983}}],
    Polygon[{{0.146235, 0.130676, -0.007479},{0.147303, 0.131023, -0.006791},{
      0.146602, 0.132398, -0.006791},{0.145693, 0.131738, -0.007479}}],
    Polygon[{{0.147303, 0.131023, -0.006791},{0.148255, 0.131332, -0.005935},{
      0.147412, 0.132987, -0.005935},{0.146602, 0.132398, -0.006791}}],
    Polygon[{{0.148255, 0.131332, -0.005935},{0.149069, 0.131597, -0.004934},{
      0.148104, 0.133490, -0.004934},{0.147412, 0.132987, -0.005935}}],
    Polygon[{{0.149069, 0.131597, -0.004934},{0.149723, 0.131809, -0.003811},{
      0.148661, 0.133894, -0.003811},{0.148104, 0.133490, -0.004934}}],
    Polygon[{{0.149723, 0.131809, -0.003811},{0.150202, 0.131965, -0.002594},{
      0.149069, 0.134190, -0.002594},{0.148661, 0.133894, -0.003811}}],
    Polygon[{{0.150202, 0.131965, -0.002594},{0.150495, 0.132060, -0.001313},{
      0.149317, 0.134371, -0.001313},{0.149069, 0.134190, -0.002594}}],
    Polygon[{{0.150495, 0.132060, -0.001313},{0.150593, 0.132092, 0.000000},{
      0.149401, 0.134432, 0.000000},{0.149317, 0.134371, -0.001313}}],
    Polygon[{{0.150593, 0.132092, 0.000000},{0.150495, 0.132060, 0.001313},{
      0.149317, 0.134371, 0.001313},{0.149401, 0.134432, 0.000000}}],
    Polygon[{{0.150495, 0.132060, 0.001313},{0.150202, 0.131965, 0.002594},{
      0.149069, 0.134190, 0.002594},{0.149317, 0.134371, 0.001313}}],
    Polygon[{{0.150202, 0.131965, 0.002594},{0.149723, 0.131809, 0.003811},{
      0.148661, 0.133894, 0.003811},{0.149069, 0.134190, 0.002594}}],
    Polygon[{{0.149723, 0.131809, 0.003811},{0.149069, 0.131597, 0.004934},{
      0.148104, 0.133490, 0.004934},{0.148661, 0.133894, 0.003811}}],
    Polygon[{{0.149069, 0.131597, 0.004934},{0.148255, 0.131332, 0.005935},{
      0.147412, 0.132987, 0.005935},{0.148104, 0.133490, 0.004934}}],
    Polygon[{{0.148255, 0.131332, 0.005935},{0.147303, 0.131023, 0.006791},{
      0.146602, 0.132398, 0.006791},{0.147412, 0.132987, 0.005935}}],
    Polygon[{{0.147303, 0.131023, 0.006791},{0.146235, 0.130676, 0.007479},{
      0.145693, 0.131738, 0.007479},{0.146602, 0.132398, 0.006791}}],
    Polygon[{{0.146235, 0.130676, 0.007479},{0.145077, 0.130300, 0.007983},{
      0.144709, 0.131023, 0.007983},{0.145693, 0.131738, 0.007479}}],
    Polygon[{{0.145077, 0.130300, 0.007983},{0.143859, 0.129904, 0.008290},{
      0.143673, 0.130270, 0.008290},{0.144709, 0.131023, 0.007983}}],
    Polygon[{{0.143673, 0.130270, -0.008290},{0.144709, 0.131023, -0.007983},{
      0.144135, 0.131597, -0.007983},{0.143382, 0.130560, -0.008290}}],
    Polygon[{{0.144709, 0.131023, -0.007983},{0.145693, 0.131738, -0.007479},{
      0.144850, 0.132581, -0.007479},{0.144135, 0.131597, -0.007983}}],
    Polygon[{{0.145693, 0.131738, -0.007479},{0.146602, 0.132398, -0.006791},{
      0.145510, 0.133490, -0.006791},{0.144850, 0.132581, -0.007479}}],
    Polygon[{{0.146602, 0.132398, -0.006791},{0.147412, 0.132987, -0.005935},{
      0.146099, 0.134300, -0.005935},{0.145510, 0.133490, -0.006791}}],
    Polygon[{{0.147412, 0.132987, -0.005935},{0.148104, 0.133490, -0.004934},{
      0.146602, 0.134992, -0.004934},{0.146099, 0.134300, -0.005935}}],
    Polygon[{{0.148104, 0.133490, -0.004934},{0.148661, 0.133894, -0.003811},{
      0.147006, 0.135549, -0.003811},{0.146602, 0.134992, -0.004934}}],
    Polygon[{{0.148661, 0.133894, -0.003811},{0.149069, 0.134190, -0.002594},{
      0.147303, 0.135956, -0.002594},{0.147006, 0.135549, -0.003811}}],
    Polygon[{{0.149069, 0.134190, -0.002594},{0.149317, 0.134371, -0.001313},{
      0.147483, 0.136205, -0.001313},{0.147303, 0.135956, -0.002594}}],
    Polygon[{{0.149317, 0.134371, -0.001313},{0.149401, 0.134432, 0.000000},{
      0.147544, 0.136289, 0.000000},{0.147483, 0.136205, -0.001313}}],
    Polygon[{{0.149401, 0.134432, 0.000000},{0.149317, 0.134371, 0.001313},{
      0.147483, 0.136205, 0.001313},{0.147544, 0.136289, 0.000000}}],
    Polygon[{{0.149317, 0.134371, 0.001313},{0.149069, 0.134190, 0.002594},{
      0.147303, 0.135956, 0.002594},{0.147483, 0.136205, 0.001313}}],
    Polygon[{{0.149069, 0.134190, 0.002594},{0.148661, 0.133894, 0.003811},{
      0.147006, 0.135549, 0.003811},{0.147303, 0.135956, 0.002594}}],
    Polygon[{{0.148661, 0.133894, 0.003811},{0.148104, 0.133490, 0.004934},{
      0.146602, 0.134992, 0.004934},{0.147006, 0.135549, 0.003811}}],
    Polygon[{{0.148104, 0.133490, 0.004934},{0.147412, 0.132987, 0.005935},{
      0.146099, 0.134300, 0.005935},{0.146602, 0.134992, 0.004934}}],
    Polygon[{{0.147412, 0.132987, 0.005935},{0.146602, 0.132398, 0.006791},{
      0.145510, 0.133490, 0.006791},{0.146099, 0.134300, 0.005935}}],
    Polygon[{{0.146602, 0.132398, 0.006791},{0.145693, 0.131738, 0.007479},{
      0.144850, 0.132581, 0.007479},{0.145510, 0.133490, 0.006791}}],
    Polygon[{{0.145693, 0.131738, 0.007479},{0.144709, 0.131023, 0.007983},{
      0.144135, 0.131597, 0.007983},{0.144850, 0.132581, 0.007479}}],
    Polygon[{{0.144709, 0.131023, 0.007983},{0.143673, 0.130270, 0.008290},{
      0.143382, 0.130560, 0.008290},{0.144135, 0.131597, 0.007983}}],
    Polygon[{{0.143382, 0.130560, -0.008290},{0.144135, 0.131597, -0.007983},{
      0.143412, 0.131965, -0.007983},{0.143016, 0.130747, -0.008290}}],
    Polygon[{{0.144135, 0.131597, -0.007983},{0.144850, 0.132581, -0.007479},{
      0.143788, 0.133122, -0.007479},{0.143412, 0.131965, -0.007983}}],
    Polygon[{{0.144850, 0.132581, -0.007479},{0.145510, 0.133490, -0.006791},{
      0.144135, 0.134190, -0.006791},{0.143788, 0.133122, -0.007479}}],
    Polygon[{{0.145510, 0.133490, -0.006791},{0.146099, 0.134300, -0.005935},{
      0.144444, 0.135143, -0.005935},{0.144135, 0.134190, -0.006791}}],
    Polygon[{{0.146099, 0.134300, -0.005935},{0.146602, 0.134992, -0.004934},{
      0.144709, 0.135956, -0.004934},{0.144444, 0.135143, -0.005935}}],
    Polygon[{{0.146602, 0.134992, -0.004934},{0.147006, 0.135549, -0.003811},{
      0.144921, 0.136611, -0.003811},{0.144709, 0.135956, -0.004934}}],
    Polygon[{{0.147006, 0.135549, -0.003811},{0.147303, 0.135956, -0.002594},{
      0.145077, 0.137090, -0.002594},{0.144921, 0.136611, -0.003811}}],
    Polygon[{{0.147303, 0.135956, -0.002594},{0.147483, 0.136205, -0.001313},{
      0.145172, 0.137383, -0.001313},{0.145077, 0.137090, -0.002594}}],
    Polygon[{{0.147483, 0.136205, -0.001313},{0.147544, 0.136289, 0.000000},{
      0.145204, 0.137481, 0.000000},{0.145172, 0.137383, -0.001313}}],
    Polygon[{{0.147544, 0.136289, 0.000000},{0.147483, 0.136205, 0.001313},{
      0.145172, 0.137383, 0.001313},{0.145204, 0.137481, 0.000000}}],
    Polygon[{{0.147483, 0.136205, 0.001313},{0.147303, 0.135956, 0.002594},{
      0.145077, 0.137090, 0.002594},{0.145172, 0.137383, 0.001313}}],
    Polygon[{{0.147303, 0.135956, 0.002594},{0.147006, 0.135549, 0.003811},{
      0.144921, 0.136611, 0.003811},{0.145077, 0.137090, 0.002594}}],
    Polygon[{{0.147006, 0.135549, 0.003811},{0.146602, 0.134992, 0.004934},{
      0.144709, 0.135956, 0.004934},{0.144921, 0.136611, 0.003811}}],
    Polygon[{{0.146602, 0.134992, 0.004934},{0.146099, 0.134300, 0.005935},{
      0.144444, 0.135143, 0.005935},{0.144709, 0.135956, 0.004934}}],
    Polygon[{{0.146099, 0.134300, 0.005935},{0.145510, 0.133490, 0.006791},{
      0.144135, 0.134190, 0.006791},{0.144444, 0.135143, 0.005935}}],
    Polygon[{{0.145510, 0.133490, 0.006791},{0.144850, 0.132581, 0.007479},{
      0.143788, 0.133122, 0.007479},{0.144135, 0.134190, 0.006791}}],
    Polygon[{{0.144850, 0.132581, 0.007479},{0.144135, 0.131597, 0.007983},{
      0.143412, 0.131965, 0.007983},{0.143788, 0.133122, 0.007479}}],
    Polygon[{{0.144135, 0.131597, 0.007983},{0.143382, 0.130560, 0.008290},{
      0.143016, 0.130747, 0.008290},{0.143412, 0.131965, 0.007983}}],
    Polygon[{{0.143016, 0.130747, -0.008290},{0.143412, 0.131965, -0.007983},{
      0.142610, 0.132092, -0.007983},{0.142610, 0.130811, -0.008290}}],
    Polygon[{{0.143412, 0.131965, -0.007983},{0.143788, 0.133122, -0.007479},{
      0.142610, 0.133309, -0.007479},{0.142610, 0.132092, -0.007983}}],
    Polygon[{{0.143788, 0.133122, -0.007479},{0.144135, 0.134190, -0.006791},{
      0.142610, 0.134432, -0.006791},{0.142610, 0.133309, -0.007479}}],
    Polygon[{{0.144135, 0.134190, -0.006791},{0.144444, 0.135143, -0.005935},{
      0.142610, 0.135433, -0.005935},{0.142610, 0.134432, -0.006791}}],
    Polygon[{{0.144444, 0.135143, -0.005935},{0.144709, 0.135956, -0.004934},{
      0.142610, 0.136289, -0.004934},{0.142610, 0.135433, -0.005935}}],
    Polygon[{{0.144709, 0.135956, -0.004934},{0.144921, 0.136611, -0.003811},{
      0.142610, 0.136977, -0.003811},{0.142610, 0.136289, -0.004934}}],
    Polygon[{{0.144921, 0.136611, -0.003811},{0.145077, 0.137090, -0.002594},{
      0.142610, 0.137481, -0.002594},{0.142610, 0.136977, -0.003811}}],
    Polygon[{{0.145077, 0.137090, -0.002594},{0.145172, 0.137383, -0.001313},{
      0.142610, 0.137788, -0.001313},{0.142610, 0.137481, -0.002594}}],
    Polygon[{{0.145172, 0.137383, -0.001313},{0.145204, 0.137481, 0.000000},{
      0.142610, 0.137892, 0.000000},{0.142610, 0.137788, -0.001313}}],
    Polygon[{{0.145204, 0.137481, 0.000000},{0.145172, 0.137383, 0.001313},{
      0.142610, 0.137788, 0.001313},{0.142610, 0.137892, 0.000000}}],
    Polygon[{{0.145172, 0.137383, 0.001313},{0.145077, 0.137090, 0.002594},{
      0.142610, 0.137481, 0.002594},{0.142610, 0.137788, 0.001313}}],
    Polygon[{{0.145077, 0.137090, 0.002594},{0.144921, 0.136611, 0.003811},{
      0.142610, 0.136977, 0.003811},{0.142610, 0.137481, 0.002594}}],
    Polygon[{{0.144921, 0.136611, 0.003811},{0.144709, 0.135956, 0.004934},{
      0.142610, 0.136289, 0.004934},{0.142610, 0.136977, 0.003811}}],
    Polygon[{{0.144709, 0.135956, 0.004934},{0.144444, 0.135143, 0.005935},{
      0.142610, 0.135433, 0.005935},{0.142610, 0.136289, 0.004934}}],
    Polygon[{{0.144444, 0.135143, 0.005935},{0.144135, 0.134190, 0.006791},{
      0.142610, 0.134432, 0.006791},{0.142610, 0.135433, 0.005935}}],
    Polygon[{{0.144135, 0.134190, 0.006791},{0.143788, 0.133122, 0.007479},{
      0.142610, 0.133309, 0.007479},{0.142610, 0.134432, 0.006791}}],
    Polygon[{{0.143788, 0.133122, 0.007479},{0.143412, 0.131965, 0.007983},{
      0.142610, 0.132092, 0.007983},{0.142610, 0.133309, 0.007479}}],
    Polygon[{{0.143412, 0.131965, 0.007983},{0.143016, 0.130747, 0.008290},{
      0.142610, 0.130811, 0.008290},{0.142610, 0.132092, 0.007983}}],
    Polygon[{{0.142610, 0.130811, -0.008290},{0.142610, 0.132092, -0.007983},{
      0.141809, 0.131965, -0.007983},{0.142205, 0.130747, -0.008290}}],
    Polygon[{{0.142610, 0.132092, -0.007983},{0.142610, 0.133309, -0.007479},{
      0.141433, 0.133122, -0.007479},{0.141809, 0.131965, -0.007983}}],
    Polygon[{{0.142610, 0.133309, -0.007479},{0.142610, 0.134432, -0.006791},{
      0.141086, 0.134190, -0.006791},{0.141433, 0.133122, -0.007479}}],
    Polygon[{{0.142610, 0.134432, -0.006791},{0.142610, 0.135433, -0.005935},{
      0.140776, 0.135143, -0.005935},{0.141086, 0.134190, -0.006791}}],
    Polygon[{{0.142610, 0.135433, -0.005935},{0.142610, 0.136289, -0.004934},{
      0.140512, 0.135956, -0.004934},{0.140776, 0.135143, -0.005935}}],
    Polygon[{{0.142610, 0.136289, -0.004934},{0.142610, 0.136977, -0.003811},{
      0.140299, 0.136611, -0.003811},{0.140512, 0.135956, -0.004934}}],
    Polygon[{{0.142610, 0.136977, -0.003811},{0.142610, 0.137481, -0.002594},{
      0.140144, 0.137090, -0.002594},{0.140299, 0.136611, -0.003811}}],
    Polygon[{{0.142610, 0.137481, -0.002594},{0.142610, 0.137788, -0.001313},{
      0.140049, 0.137383, -0.001313},{0.140144, 0.137090, -0.002594}}],
    Polygon[{{0.142610, 0.137788, -0.001313},{0.142610, 0.137892, 0.000000},{
      0.140017, 0.137481, 0.000000},{0.140049, 0.137383, -0.001313}}],
    Polygon[{{0.142610, 0.137892, 0.000000},{0.142610, 0.137788, 0.001313},{
      0.140049, 0.137383, 0.001313},{0.140017, 0.137481, 0.000000}}],
    Polygon[{{0.142610, 0.137788, 0.001313},{0.142610, 0.137481, 0.002594},{
      0.140144, 0.137090, 0.002594},{0.140049, 0.137383, 0.001313}}],
    Polygon[{{0.142610, 0.137481, 0.002594},{0.142610, 0.136977, 0.003811},{
      0.140299, 0.136611, 0.003811},{0.140144, 0.137090, 0.002594}}],
    Polygon[{{0.142610, 0.136977, 0.003811},{0.142610, 0.136289, 0.004934},{
      0.140512, 0.135956, 0.004934},{0.140299, 0.136611, 0.003811}}],
    Polygon[{{0.142610, 0.136289, 0.004934},{0.142610, 0.135433, 0.005935},{
      0.140776, 0.135143, 0.005935},{0.140512, 0.135956, 0.004934}}],
    Polygon[{{0.142610, 0.135433, 0.005935},{0.142610, 0.134432, 0.006791},{
      0.141086, 0.134190, 0.006791},{0.140776, 0.135143, 0.005935}}],
    Polygon[{{0.142610, 0.134432, 0.006791},{0.142610, 0.133309, 0.007479},{
      0.141433, 0.133122, 0.007479},{0.141086, 0.134190, 0.006791}}],
    Polygon[{{0.142610, 0.133309, 0.007479},{0.142610, 0.132092, 0.007983},{
      0.141809, 0.131965, 0.007983},{0.141433, 0.133122, 0.007479}}],
    Polygon[{{0.142610, 0.132092, 0.007983},{0.142610, 0.130811, 0.008290},{
      0.142205, 0.130747, 0.008290},{0.141809, 0.131965, 0.007983}}],
    Polygon[{{0.142205, 0.130747, -0.008290},{0.141809, 0.131965, -0.007983},{
      0.141086, 0.131597, -0.007983},{0.141839, 0.130560, -0.008290}}],
    Polygon[{{0.141809, 0.131965, -0.007983},{0.141433, 0.133122, -0.007479},{
      0.140371, 0.132581, -0.007479},{0.141086, 0.131597, -0.007983}}],
    Polygon[{{0.141433, 0.133122, -0.007479},{0.141086, 0.134190, -0.006791},{
      0.139710, 0.133490, -0.006791},{0.140371, 0.132581, -0.007479}}],
    Polygon[{{0.141086, 0.134190, -0.006791},{0.140776, 0.135143, -0.005935},{
      0.139122, 0.134300, -0.005935},{0.139710, 0.133490, -0.006791}}],
    Polygon[{{0.140776, 0.135143, -0.005935},{0.140512, 0.135956, -0.004934},{
      0.138619, 0.134992, -0.004934},{0.139122, 0.134300, -0.005935}}],
    Polygon[{{0.140512, 0.135956, -0.004934},{0.140299, 0.136611, -0.003811},{
      0.138215, 0.135549, -0.003811},{0.138619, 0.134992, -0.004934}}],
    Polygon[{{0.140299, 0.136611, -0.003811},{0.140144, 0.137090, -0.002594},{
      0.137918, 0.135956, -0.002594},{0.138215, 0.135549, -0.003811}}],
    Polygon[{{0.140144, 0.137090, -0.002594},{0.140049, 0.137383, -0.001313},{
      0.137738, 0.136205, -0.001313},{0.137918, 0.135956, -0.002594}}],
    Polygon[{{0.140049, 0.137383, -0.001313},{0.140017, 0.137481, 0.000000},{
      0.137677, 0.136289, 0.000000},{0.137738, 0.136205, -0.001313}}],
    Polygon[{{0.140017, 0.137481, 0.000000},{0.140049, 0.137383, 0.001313},{
      0.137738, 0.136205, 0.001313},{0.137677, 0.136289, 0.000000}}],
    Polygon[{{0.140049, 0.137383, 0.001313},{0.140144, 0.137090, 0.002594},{
      0.137918, 0.135956, 0.002594},{0.137738, 0.136205, 0.001313}}],
    Polygon[{{0.140144, 0.137090, 0.002594},{0.140299, 0.136611, 0.003811},{
      0.138215, 0.135549, 0.003811},{0.137918, 0.135956, 0.002594}}],
    Polygon[{{0.140299, 0.136611, 0.003811},{0.140512, 0.135956, 0.004934},{
      0.138619, 0.134992, 0.004934},{0.138215, 0.135549, 0.003811}}],
    Polygon[{{0.140512, 0.135956, 0.004934},{0.140776, 0.135143, 0.005935},{
      0.139122, 0.134300, 0.005935},{0.138619, 0.134992, 0.004934}}],
    Polygon[{{0.140776, 0.135143, 0.005935},{0.141086, 0.134190, 0.006791},{
      0.139710, 0.133490, 0.006791},{0.139122, 0.134300, 0.005935}}],
    Polygon[{{0.141086, 0.134190, 0.006791},{0.141433, 0.133122, 0.007479},{
      0.140371, 0.132581, 0.007479},{0.139710, 0.133490, 0.006791}}],
    Polygon[{{0.141433, 0.133122, 0.007479},{0.141809, 0.131965, 0.007983},{
      0.141086, 0.131597, 0.007983},{0.140371, 0.132581, 0.007479}}],
    Polygon[{{0.141809, 0.131965, 0.007983},{0.142205, 0.130747, 0.008290},{
      0.141839, 0.130560, 0.008290},{0.141086, 0.131597, 0.007983}}],
    Polygon[{{0.141839, 0.130560, -0.008290},{0.141086, 0.131597, -0.007983},{
      0.140512, 0.131023, -0.007983},{0.141548, 0.130270, -0.008290}}],
    Polygon[{{0.141086, 0.131597, -0.007983},{0.140371, 0.132581, -0.007479},{
      0.139528, 0.131738, -0.007479},{0.140512, 0.131023, -0.007983}}],
    Polygon[{{0.140371, 0.132581, -0.007479},{0.139710, 0.133490, -0.006791},{
      0.138619, 0.132398, -0.006791},{0.139528, 0.131738, -0.007479}}],
    Polygon[{{0.139710, 0.133490, -0.006791},{0.139122, 0.134300, -0.005935},{
      0.137809, 0.132987, -0.005935},{0.138619, 0.132398, -0.006791}}],
    Polygon[{{0.139122, 0.134300, -0.005935},{0.138619, 0.134992, -0.004934},{
      0.137117, 0.133490, -0.004934},{0.137809, 0.132987, -0.005935}}],
    Polygon[{{0.138619, 0.134992, -0.004934},{0.138215, 0.135549, -0.003811},{
      0.136560, 0.133894, -0.003811},{0.137117, 0.133490, -0.004934}}],
    Polygon[{{0.138215, 0.135549, -0.003811},{0.137918, 0.135956, -0.002594},{
      0.136152, 0.134190, -0.002594},{0.136560, 0.133894, -0.003811}}],
    Polygon[{{0.137918, 0.135956, -0.002594},{0.137738, 0.136205, -0.001313},{
      0.135903, 0.134371, -0.001313},{0.136152, 0.134190, -0.002594}}],
    Polygon[{{0.137738, 0.136205, -0.001313},{0.137677, 0.136289, 0.000000},{
      0.135820, 0.134432, 0.000000},{0.135903, 0.134371, -0.001313}}],
    Polygon[{{0.137677, 0.136289, 0.000000},{0.137738, 0.136205, 0.001313},{
      0.135903, 0.134371, 0.001313},{0.135820, 0.134432, 0.000000}}],
    Polygon[{{0.137738, 0.136205, 0.001313},{0.137918, 0.135956, 0.002594},{
      0.136152, 0.134190, 0.002594},{0.135903, 0.134371, 0.001313}}],
    Polygon[{{0.137918, 0.135956, 0.002594},{0.138215, 0.135549, 0.003811},{
      0.136560, 0.133894, 0.003811},{0.136152, 0.134190, 0.002594}}],
    Polygon[{{0.138215, 0.135549, 0.003811},{0.138619, 0.134992, 0.004934},{
      0.137117, 0.133490, 0.004934},{0.136560, 0.133894, 0.003811}}],
    Polygon[{{0.138619, 0.134992, 0.004934},{0.139122, 0.134300, 0.005935},{
      0.137809, 0.132987, 0.005935},{0.137117, 0.133490, 0.004934}}],
    Polygon[{{0.139122, 0.134300, 0.005935},{0.139710, 0.133490, 0.006791},{
      0.138619, 0.132398, 0.006791},{0.137809, 0.132987, 0.005935}}],
    Polygon[{{0.139710, 0.133490, 0.006791},{0.140371, 0.132581, 0.007479},{
      0.139528, 0.131738, 0.007479},{0.138619, 0.132398, 0.006791}}],
    Polygon[{{0.140371, 0.132581, 0.007479},{0.141086, 0.131597, 0.007983},{
      0.140512, 0.131023, 0.007983},{0.139528, 0.131738, 0.007479}}],
    Polygon[{{0.141086, 0.131597, 0.007983},{0.141839, 0.130560, 0.008290},{
      0.141548, 0.130270, 0.008290},{0.140512, 0.131023, 0.007983}}],
    Polygon[{{0.141548, 0.130270, -0.008290},{0.140512, 0.131023, -0.007983},{
      0.140144, 0.130300, -0.007983},{0.141362, 0.129904, -0.008290}}],
    Polygon[{{0.140512, 0.131023, -0.007983},{0.139528, 0.131738, -0.007479},{
      0.138986, 0.130676, -0.007479},{0.140144, 0.130300, -0.007983}}],
    Polygon[{{0.139528, 0.131738, -0.007479},{0.138619, 0.132398, -0.006791},{
      0.137918, 0.131023, -0.006791},{0.138986, 0.130676, -0.007479}}],
    Polygon[{{0.138619, 0.132398, -0.006791},{0.137809, 0.132987, -0.005935},{
      0.136966, 0.131332, -0.005935},{0.137918, 0.131023, -0.006791}}],
    Polygon[{{0.137809, 0.132987, -0.005935},{0.137117, 0.133490, -0.004934},{
      0.136152, 0.131597, -0.004934},{0.136966, 0.131332, -0.005935}}],
    Polygon[{{0.137117, 0.133490, -0.004934},{0.136560, 0.133894, -0.003811},{
      0.135498, 0.131809, -0.003811},{0.136152, 0.131597, -0.004934}}],
    Polygon[{{0.136560, 0.133894, -0.003811},{0.136152, 0.134190, -0.002594},{
      0.135018, 0.131965, -0.002594},{0.135498, 0.131809, -0.003811}}],
    Polygon[{{0.136152, 0.134190, -0.002594},{0.135903, 0.134371, -0.001313},{
      0.134726, 0.132060, -0.001313},{0.135018, 0.131965, -0.002594}}],
    Polygon[{{0.135903, 0.134371, -0.001313},{0.135820, 0.134432, 0.000000},{
      0.134628, 0.132092, 0.000000},{0.134726, 0.132060, -0.001313}}],
    Polygon[{{0.135820, 0.134432, 0.000000},{0.135903, 0.134371, 0.001313},{
      0.134726, 0.132060, 0.001313},{0.134628, 0.132092, 0.000000}}],
    Polygon[{{0.135903, 0.134371, 0.001313},{0.136152, 0.134190, 0.002594},{
      0.135018, 0.131965, 0.002594},{0.134726, 0.132060, 0.001313}}],
    Polygon[{{0.136152, 0.134190, 0.002594},{0.136560, 0.133894, 0.003811},{
      0.135498, 0.131809, 0.003811},{0.135018, 0.131965, 0.002594}}],
    Polygon[{{0.136560, 0.133894, 0.003811},{0.137117, 0.133490, 0.004934},{
      0.136152, 0.131597, 0.004934},{0.135498, 0.131809, 0.003811}}],
    Polygon[{{0.137117, 0.133490, 0.004934},{0.137809, 0.132987, 0.005935},{
      0.136966, 0.131332, 0.005935},{0.136152, 0.131597, 0.004934}}],
    Polygon[{{0.137809, 0.132987, 0.005935},{0.138619, 0.132398, 0.006791},{
      0.137918, 0.131023, 0.006791},{0.136966, 0.131332, 0.005935}}],
    Polygon[{{0.138619, 0.132398, 0.006791},{0.139528, 0.131738, 0.007479},{
      0.138986, 0.130676, 0.007479},{0.137918, 0.131023, 0.006791}}],
    Polygon[{{0.139528, 0.131738, 0.007479},{0.140512, 0.131023, 0.007983},{
      0.140144, 0.130300, 0.007983},{0.138986, 0.130676, 0.007479}}],
    Polygon[{{0.140512, 0.131023, 0.007983},{0.141548, 0.130270, 0.008290},{
      0.141362, 0.129904, 0.008290},{0.140144, 0.130300, 0.007983}}],
    Polygon[{{0.141362, 0.129904, -0.008290},{0.140144, 0.130300, -0.007983},{
      0.140017, 0.129498, -0.007983},{0.141297, 0.129498, -0.008290}}],
    Polygon[{{0.140144, 0.130300, -0.007983},{0.138986, 0.130676, -0.007479},{
      0.138800, 0.129498, -0.007479},{0.140017, 0.129498, -0.007983}}],
    Polygon[{{0.138986, 0.130676, -0.007479},{0.137918, 0.131023, -0.006791},{
      0.137677, 0.129498, -0.006791},{0.138800, 0.129498, -0.007479}}],
    Polygon[{{0.137918, 0.131023, -0.006791},{0.136966, 0.131332, -0.005935},{
      0.136675, 0.129498, -0.005935},{0.137677, 0.129498, -0.006791}}],
    Polygon[{{0.136966, 0.131332, -0.005935},{0.136152, 0.131597, -0.004934},{
      0.135820, 0.129498, -0.004934},{0.136675, 0.129498, -0.005935}}],
    Polygon[{{0.136152, 0.131597, -0.004934},{0.135498, 0.131809, -0.003811},{
      0.135132, 0.129498, -0.003811},{0.135820, 0.129498, -0.004934}}],
    Polygon[{{0.135498, 0.131809, -0.003811},{0.135018, 0.131965, -0.002594},{
      0.134628, 0.129498, -0.002594},{0.135132, 0.129498, -0.003811}}],
    Polygon[{{0.135018, 0.131965, -0.002594},{0.134726, 0.132060, -0.001313},{
      0.134320, 0.129498, -0.001313},{0.134628, 0.129498, -0.002594}}],
    Polygon[{{0.134726, 0.132060, -0.001313},{0.134628, 0.132092, 0.000000},{
      0.134217, 0.129498, 0.000000},{0.134320, 0.129498, -0.001313}}],
    Polygon[{{0.134628, 0.132092, 0.000000},{0.134726, 0.132060, 0.001313},{
      0.134320, 0.129498, 0.001313},{0.134217, 0.129498, 0.000000}}],
    Polygon[{{0.134726, 0.132060, 0.001313},{0.135018, 0.131965, 0.002594},{
      0.134628, 0.129498, 0.002594},{0.134320, 0.129498, 0.001313}}],
    Polygon[{{0.135018, 0.131965, 0.002594},{0.135498, 0.131809, 0.003811},{
      0.135132, 0.129498, 0.003811},{0.134628, 0.129498, 0.002594}}],
    Polygon[{{0.135498, 0.131809, 0.003811},{0.136152, 0.131597, 0.004934},{
      0.135820, 0.129498, 0.004934},{0.135132, 0.129498, 0.003811}}],
    Polygon[{{0.136152, 0.131597, 0.004934},{0.136966, 0.131332, 0.005935},{
      0.136675, 0.129498, 0.005935},{0.135820, 0.129498, 0.004934}}],
    Polygon[{{0.136966, 0.131332, 0.005935},{0.137918, 0.131023, 0.006791},{
      0.137677, 0.129498, 0.006791},{0.136675, 0.129498, 0.005935}}],
    Polygon[{{0.137918, 0.131023, 0.006791},{0.138986, 0.130676, 0.007479},{
      0.138800, 0.129498, 0.007479},{0.137677, 0.129498, 0.006791}}],
    Polygon[{{0.138986, 0.130676, 0.007479},{0.140144, 0.130300, 0.007983},{
      0.140017, 0.129498, 0.007983},{0.138800, 0.129498, 0.007479}}],
    Polygon[{{0.140144, 0.130300, 0.007983},{0.141362, 0.129904, 0.008290},{
      0.141297, 0.129498, 0.008290},{0.140017, 0.129498, 0.007983}}],
    Polygon[{{0.141297, 0.129498, -0.008290},{0.140017, 0.129498, -0.007983},{
      0.140144, 0.128697, -0.007983},{0.141362, 0.129092, -0.008290}}],
    Polygon[{{0.140017, 0.129498, -0.007983},{0.138800, 0.129498, -0.007479},{
      0.138986, 0.128321, -0.007479},{0.140144, 0.128697, -0.007983}}],
    Polygon[{{0.138800, 0.129498, -0.007479},{0.137677, 0.129498, -0.006791},{
      0.137918, 0.127974, -0.006791},{0.138986, 0.128321, -0.007479}}],
    Polygon[{{0.137677, 0.129498, -0.006791},{0.136675, 0.129498, -0.005935},{
      0.136966, 0.127664, -0.005935},{0.137918, 0.127974, -0.006791}}],
    Polygon[{{0.136675, 0.129498, -0.005935},{0.135820, 0.129498, -0.004934},{
      0.136152, 0.127400, -0.004934},{0.136966, 0.127664, -0.005935}}],
    Polygon[{{0.135820, 0.129498, -0.004934},{0.135132, 0.129498, -0.003811},{
      0.135498, 0.127187, -0.003811},{0.136152, 0.127400, -0.004934}}],
    Polygon[{{0.135132, 0.129498, -0.003811},{0.134628, 0.129498, -0.002594},{
      0.135018, 0.127031, -0.002594},{0.135498, 0.127187, -0.003811}}],
    Polygon[{{0.134628, 0.129498, -0.002594},{0.134320, 0.129498, -0.001313},{
      0.134726, 0.126936, -0.001313},{0.135018, 0.127031, -0.002594}}],
    Polygon[{{0.134320, 0.129498, -0.001313},{0.134217, 0.129498, 0.000000},{
      0.134628, 0.126904, 0.000000},{0.134726, 0.126936, -0.001313}}],
    Polygon[{{0.134217, 0.129498, 0.000000},{0.134320, 0.129498, 0.001313},{
      0.134726, 0.126936, 0.001313},{0.134628, 0.126904, 0.000000}}],
    Polygon[{{0.134320, 0.129498, 0.001313},{0.134628, 0.129498, 0.002594},{
      0.135018, 0.127031, 0.002594},{0.134726, 0.126936, 0.001313}}],
    Polygon[{{0.134628, 0.129498, 0.002594},{0.135132, 0.129498, 0.003811},{
      0.135498, 0.127187, 0.003811},{0.135018, 0.127031, 0.002594}}],
    Polygon[{{0.135132, 0.129498, 0.003811},{0.135820, 0.129498, 0.004934},{
      0.136152, 0.127400, 0.004934},{0.135498, 0.127187, 0.003811}}],
    Polygon[{{0.135820, 0.129498, 0.004934},{0.136675, 0.129498, 0.005935},{
      0.136966, 0.127664, 0.005935},{0.136152, 0.127400, 0.004934}}],
    Polygon[{{0.136675, 0.129498, 0.005935},{0.137677, 0.129498, 0.006791},{
      0.137918, 0.127974, 0.006791},{0.136966, 0.127664, 0.005935}}],
    Polygon[{{0.137677, 0.129498, 0.006791},{0.138800, 0.129498, 0.007479},{
      0.138986, 0.128321, 0.007479},{0.137918, 0.127974, 0.006791}}],
    Polygon[{{0.138800, 0.129498, 0.007479},{0.140017, 0.129498, 0.007983},{
      0.140144, 0.128697, 0.007983},{0.138986, 0.128321, 0.007479}}],
    Polygon[{{0.140017, 0.129498, 0.007983},{0.141297, 0.129498, 0.008290},{
      0.141362, 0.129092, 0.008290},{0.140144, 0.128697, 0.007983}}],
    Polygon[{{0.141362, 0.129092, -0.008290},{0.140144, 0.128697, -0.007983},{
      0.140512, 0.127974, -0.007983},{0.141548, 0.128726, -0.008290}}],
    Polygon[{{0.140144, 0.128697, -0.007983},{0.138986, 0.128321, -0.007479},{
      0.139528, 0.127258, -0.007479},{0.140512, 0.127974, -0.007983}}],
    Polygon[{{0.138986, 0.128321, -0.007479},{0.137918, 0.127974, -0.006791},{
      0.138619, 0.126598, -0.006791},{0.139528, 0.127258, -0.007479}}],
    Polygon[{{0.137918, 0.127974, -0.006791},{0.136966, 0.127664, -0.005935},{
      0.137809, 0.126010, -0.005935},{0.138619, 0.126598, -0.006791}}],
    Polygon[{{0.136966, 0.127664, -0.005935},{0.136152, 0.127400, -0.004934},{
      0.137117, 0.125507, -0.004934},{0.137809, 0.126010, -0.005935}}],
    Polygon[{{0.136152, 0.127400, -0.004934},{0.135498, 0.127187, -0.003811},{
      0.136560, 0.125102, -0.003811},{0.137117, 0.125507, -0.004934}}],
    Polygon[{{0.135498, 0.127187, -0.003811},{0.135018, 0.127031, -0.002594},{
      0.136152, 0.124806, -0.002594},{0.136560, 0.125102, -0.003811}}],
    Polygon[{{0.135018, 0.127031, -0.002594},{0.134726, 0.126936, -0.001313},{
      0.135903, 0.124625, -0.001313},{0.136152, 0.124806, -0.002594}}],
    Polygon[{{0.134726, 0.126936, -0.001313},{0.134628, 0.126904, 0.000000},{
      0.135820, 0.124564, 0.000000},{0.135903, 0.124625, -0.001313}}],
    Polygon[{{0.134628, 0.126904, 0.000000},{0.134726, 0.126936, 0.001313},{
      0.135903, 0.124625, 0.001313},{0.135820, 0.124564, 0.000000}}],
    Polygon[{{0.134726, 0.126936, 0.001313},{0.135018, 0.127031, 0.002594},{
      0.136152, 0.124806, 0.002594},{0.135903, 0.124625, 0.001313}}],
    Polygon[{{0.135018, 0.127031, 0.002594},{0.135498, 0.127187, 0.003811},{
      0.136560, 0.125102, 0.003811},{0.136152, 0.124806, 0.002594}}],
    Polygon[{{0.135498, 0.127187, 0.003811},{0.136152, 0.127400, 0.004934},{
      0.137117, 0.125507, 0.004934},{0.136560, 0.125102, 0.003811}}],
    Polygon[{{0.136152, 0.127400, 0.004934},{0.136966, 0.127664, 0.005935},{
      0.137809, 0.126010, 0.005935},{0.137117, 0.125507, 0.004934}}],
    Polygon[{{0.136966, 0.127664, 0.005935},{0.137918, 0.127974, 0.006791},{
      0.138619, 0.126598, 0.006791},{0.137809, 0.126010, 0.005935}}],
    Polygon[{{0.137918, 0.127974, 0.006791},{0.138986, 0.128321, 0.007479},{
      0.139528, 0.127258, 0.007479},{0.138619, 0.126598, 0.006791}}],
    Polygon[{{0.138986, 0.128321, 0.007479},{0.140144, 0.128697, 0.007983},{
      0.140512, 0.127974, 0.007983},{0.139528, 0.127258, 0.007479}}],
    Polygon[{{0.140144, 0.128697, 0.007983},{0.141362, 0.129092, 0.008290},{
      0.141548, 0.128726, 0.008290},{0.140512, 0.127974, 0.007983}}],
    Polygon[{{0.141548, 0.128726, -0.008290},{0.140512, 0.127974, -0.007983},{
      0.141086, 0.127400, -0.007983},{0.141839, 0.128436, -0.008290}}],
    Polygon[{{0.140512, 0.127974, -0.007983},{0.139528, 0.127258, -0.007479},{
      0.140371, 0.126415, -0.007479},{0.141086, 0.127400, -0.007983}}],
    Polygon[{{0.139528, 0.127258, -0.007479},{0.138619, 0.126598, -0.006791},{
      0.139710, 0.125507, -0.006791},{0.140371, 0.126415, -0.007479}}],
    Polygon[{{0.138619, 0.126598, -0.006791},{0.137809, 0.126010, -0.005935},{
      0.139122, 0.124696, -0.005935},{0.139710, 0.125507, -0.006791}}],
    Polygon[{{0.137809, 0.126010, -0.005935},{0.137117, 0.125507, -0.004934},{
      0.138619, 0.124004, -0.004934},{0.139122, 0.124696, -0.005935}}],
    Polygon[{{0.137117, 0.125507, -0.004934},{0.136560, 0.125102, -0.003811},{
      0.138215, 0.123448, -0.003811},{0.138619, 0.124004, -0.004934}}],
    Polygon[{{0.136560, 0.125102, -0.003811},{0.136152, 0.124806, -0.002594},{
      0.137918, 0.123040, -0.002594},{0.138215, 0.123448, -0.003811}}],
    Polygon[{{0.136152, 0.124806, -0.002594},{0.135903, 0.124625, -0.001313},{
      0.137738, 0.122791, -0.001313},{0.137918, 0.123040, -0.002594}}],
    Polygon[{{0.135903, 0.124625, -0.001313},{0.135820, 0.124564, 0.000000},{
      0.137677, 0.122708, 0.000000},{0.137738, 0.122791, -0.001313}}],
    Polygon[{{0.135820, 0.124564, 0.000000},{0.135903, 0.124625, 0.001313},{
      0.137738, 0.122791, 0.001313},{0.137677, 0.122708, 0.000000}}],
    Polygon[{{0.135903, 0.124625, 0.001313},{0.136152, 0.124806, 0.002594},{
      0.137918, 0.123040, 0.002594},{0.137738, 0.122791, 0.001313}}],
    Polygon[{{0.136152, 0.124806, 0.002594},{0.136560, 0.125102, 0.003811},{
      0.138215, 0.123448, 0.003811},{0.137918, 0.123040, 0.002594}}],
    Polygon[{{0.136560, 0.125102, 0.003811},{0.137117, 0.125507, 0.004934},{
      0.138619, 0.124004, 0.004934},{0.138215, 0.123448, 0.003811}}],
    Polygon[{{0.137117, 0.125507, 0.004934},{0.137809, 0.126010, 0.005935},{
      0.139122, 0.124696, 0.005935},{0.138619, 0.124004, 0.004934}}],
    Polygon[{{0.137809, 0.126010, 0.005935},{0.138619, 0.126598, 0.006791},{
      0.139710, 0.125507, 0.006791},{0.139122, 0.124696, 0.005935}}],
    Polygon[{{0.138619, 0.126598, 0.006791},{0.139528, 0.127258, 0.007479},{
      0.140371, 0.126415, 0.007479},{0.139710, 0.125507, 0.006791}}],
    Polygon[{{0.139528, 0.127258, 0.007479},{0.140512, 0.127974, 0.007983},{
      0.141086, 0.127400, 0.007983},{0.140371, 0.126415, 0.007479}}],
    Polygon[{{0.140512, 0.127974, 0.007983},{0.141548, 0.128726, 0.008290},{
      0.141839, 0.128436, 0.008290},{0.141086, 0.127400, 0.007983}}],
    Polygon[{{0.141839, 0.128436, -0.008290},{0.141086, 0.127400, -0.007983},{
      0.141809, 0.127031, -0.007983},{0.142205, 0.128249, -0.008290}}],
    Polygon[{{0.141086, 0.127400, -0.007983},{0.140371, 0.126415, -0.007479},{
      0.141433, 0.125874, -0.007479},{0.141809, 0.127031, -0.007983}}],
    Polygon[{{0.140371, 0.126415, -0.007479},{0.139710, 0.125507, -0.006791},{
      0.141086, 0.124806, -0.006791},{0.141433, 0.125874, -0.007479}}],
    Polygon[{{0.139710, 0.125507, -0.006791},{0.139122, 0.124696, -0.005935},{
      0.140776, 0.123853, -0.005935},{0.141086, 0.124806, -0.006791}}],
    Polygon[{{0.139122, 0.124696, -0.005935},{0.138619, 0.124004, -0.004934},{
      0.140512, 0.123040, -0.004934},{0.140776, 0.123853, -0.005935}}],
    Polygon[{{0.138619, 0.124004, -0.004934},{0.138215, 0.123448, -0.003811},{
      0.140299, 0.122385, -0.003811},{0.140512, 0.123040, -0.004934}}],
    Polygon[{{0.138215, 0.123448, -0.003811},{0.137918, 0.123040, -0.002594},{
      0.140144, 0.121906, -0.002594},{0.140299, 0.122385, -0.003811}}],
    Polygon[{{0.137918, 0.123040, -0.002594},{0.137738, 0.122791, -0.001313},{
      0.140049, 0.121614, -0.001313},{0.140144, 0.121906, -0.002594}}],
    Polygon[{{0.137738, 0.122791, -0.001313},{0.137677, 0.122708, 0.000000},{
      0.140017, 0.121515, 0.000000},{0.140049, 0.121614, -0.001313}}],
    Polygon[{{0.137677, 0.122708, 0.000000},{0.137738, 0.122791, 0.001313},{
      0.140049, 0.121614, 0.001313},{0.140017, 0.121515, 0.000000}}],
    Polygon[{{0.137738, 0.122791, 0.001313},{0.137918, 0.123040, 0.002594},{
      0.140144, 0.121906, 0.002594},{0.140049, 0.121614, 0.001313}}],
    Polygon[{{0.137918, 0.123040, 0.002594},{0.138215, 0.123448, 0.003811},{
      0.140299, 0.122385, 0.003811},{0.140144, 0.121906, 0.002594}}],
    Polygon[{{0.138215, 0.123448, 0.003811},{0.138619, 0.124004, 0.004934},{
      0.140512, 0.123040, 0.004934},{0.140299, 0.122385, 0.003811}}],
    Polygon[{{0.138619, 0.124004, 0.004934},{0.139122, 0.124696, 0.005935},{
      0.140776, 0.123853, 0.005935},{0.140512, 0.123040, 0.004934}}],
    Polygon[{{0.139122, 0.124696, 0.005935},{0.139710, 0.125507, 0.006791},{
      0.141086, 0.124806, 0.006791},{0.140776, 0.123853, 0.005935}}],
    Polygon[{{0.139710, 0.125507, 0.006791},{0.140371, 0.126415, 0.007479},{
      0.141433, 0.125874, 0.007479},{0.141086, 0.124806, 0.006791}}],
    Polygon[{{0.140371, 0.126415, 0.007479},{0.141086, 0.127400, 0.007983},{
      0.141809, 0.127031, 0.007983},{0.141433, 0.125874, 0.007479}}],
    Polygon[{{0.141086, 0.127400, 0.007983},{0.141839, 0.128436, 0.008290},{
      0.142205, 0.128249, 0.008290},{0.141809, 0.127031, 0.007983}}],
    Polygon[{{0.142205, 0.128249, -0.008290},{0.141809, 0.127031, -0.007983},{
      0.142610, 0.126904, -0.007983},{0.142610, 0.128185, -0.008290}}],
    Polygon[{{0.141809, 0.127031, -0.007983},{0.141433, 0.125874, -0.007479},{
      0.142610, 0.125687, -0.007479},{0.142610, 0.126904, -0.007983}}],
    Polygon[{{0.141433, 0.125874, -0.007479},{0.141086, 0.124806, -0.006791},{
      0.142610, 0.124564, -0.006791},{0.142610, 0.125687, -0.007479}}],
    Polygon[{{0.141086, 0.124806, -0.006791},{0.140776, 0.123853, -0.005935},{
      0.142610, 0.123563, -0.005935},{0.142610, 0.124564, -0.006791}}],
    Polygon[{{0.140776, 0.123853, -0.005935},{0.140512, 0.123040, -0.004934},{
      0.142610, 0.122708, -0.004934},{0.142610, 0.123563, -0.005935}}],
    Polygon[{{0.140512, 0.123040, -0.004934},{0.140299, 0.122385, -0.003811},{
      0.142610, 0.122019, -0.003811},{0.142610, 0.122708, -0.004934}}],
    Polygon[{{0.140299, 0.122385, -0.003811},{0.140144, 0.121906, -0.002594},{
      0.142610, 0.121515, -0.002594},{0.142610, 0.122019, -0.003811}}],
    Polygon[{{0.140144, 0.121906, -0.002594},{0.140049, 0.121614, -0.001313},{
      0.142610, 0.121208, -0.001313},{0.142610, 0.121515, -0.002594}}],
    Polygon[{{0.140049, 0.121614, -0.001313},{0.140017, 0.121515, 0.000000},{
      0.142610, 0.121105, 0.000000},{0.142610, 0.121208, -0.001313}}],
    Polygon[{{0.140017, 0.121515, 0.000000},{0.140049, 0.121614, 0.001313},{
      0.142610, 0.121208, 0.001313},{0.142610, 0.121105, 0.000000}}],
    Polygon[{{0.140049, 0.121614, 0.001313},{0.140144, 0.121906, 0.002594},{
      0.142610, 0.121515, 0.002594},{0.142610, 0.121208, 0.001313}}],
    Polygon[{{0.140144, 0.121906, 0.002594},{0.140299, 0.122385, 0.003811},{
      0.142610, 0.122019, 0.003811},{0.142610, 0.121515, 0.002594}}],
    Polygon[{{0.140299, 0.122385, 0.003811},{0.140512, 0.123040, 0.004934},{
      0.142610, 0.122708, 0.004934},{0.142610, 0.122019, 0.003811}}],
    Polygon[{{0.140512, 0.123040, 0.004934},{0.140776, 0.123853, 0.005935},{
      0.142610, 0.123563, 0.005935},{0.142610, 0.122708, 0.004934}}],
    Polygon[{{0.140776, 0.123853, 0.005935},{0.141086, 0.124806, 0.006791},{
      0.142610, 0.124564, 0.006791},{0.142610, 0.123563, 0.005935}}],
    Polygon[{{0.141086, 0.124806, 0.006791},{0.141433, 0.125874, 0.007479},{
      0.142610, 0.125687, 0.007479},{0.142610, 0.124564, 0.006791}}],
    Polygon[{{0.141433, 0.125874, 0.007479},{0.141809, 0.127031, 0.007983},{
      0.142610, 0.126904, 0.007983},{0.142610, 0.125687, 0.007479}}],
    Polygon[{{0.141809, 0.127031, 0.007983},{0.142205, 0.128249, 0.008290},{
      0.142610, 0.128185, 0.008290},{0.142610, 0.126904, 0.007983}}],
    Polygon[{{0.142610, 0.128185, -0.008290},{0.142610, 0.126904, -0.007983},{
      0.143412, 0.127031, -0.007983},{0.143016, 0.128249, -0.008290}}],
    Polygon[{{0.142610, 0.126904, -0.007983},{0.142610, 0.125687, -0.007479},{
      0.143788, 0.125874, -0.007479},{0.143412, 0.127031, -0.007983}}],
    Polygon[{{0.142610, 0.125687, -0.007479},{0.142610, 0.124564, -0.006791},{
      0.144135, 0.124806, -0.006791},{0.143788, 0.125874, -0.007479}}],
    Polygon[{{0.142610, 0.124564, -0.006791},{0.142610, 0.123563, -0.005935},{
      0.144444, 0.123853, -0.005935},{0.144135, 0.124806, -0.006791}}],
    Polygon[{{0.142610, 0.123563, -0.005935},{0.142610, 0.122708, -0.004934},{
      0.144709, 0.123040, -0.004934},{0.144444, 0.123853, -0.005935}}],
    Polygon[{{0.142610, 0.122708, -0.004934},{0.142610, 0.122019, -0.003811},{
      0.144921, 0.122385, -0.003811},{0.144709, 0.123040, -0.004934}}],
    Polygon[{{0.142610, 0.122019, -0.003811},{0.142610, 0.121515, -0.002594},{
      0.145077, 0.121906, -0.002594},{0.144921, 0.122385, -0.003811}}],
    Polygon[{{0.142610, 0.121515, -0.002594},{0.142610, 0.121208, -0.001313},{
      0.145172, 0.121614, -0.001313},{0.145077, 0.121906, -0.002594}}],
    Polygon[{{0.142610, 0.121208, -0.001313},{0.142610, 0.121105, 0.000000},{
      0.145204, 0.121515, 0.000000},{0.145172, 0.121614, -0.001313}}],
    Polygon[{{0.142610, 0.121105, 0.000000},{0.142610, 0.121208, 0.001313},{
      0.145172, 0.121614, 0.001313},{0.145204, 0.121515, 0.000000}}],
    Polygon[{{0.142610, 0.121208, 0.001313},{0.142610, 0.121515, 0.002594},{
      0.145077, 0.121906, 0.002594},{0.145172, 0.121614, 0.001313}}],
    Polygon[{{0.142610, 0.121515, 0.002594},{0.142610, 0.122019, 0.003811},{
      0.144921, 0.122385, 0.003811},{0.145077, 0.121906, 0.002594}}],
    Polygon[{{0.142610, 0.122019, 0.003811},{0.142610, 0.122708, 0.004934},{
      0.144709, 0.123040, 0.004934},{0.144921, 0.122385, 0.003811}}],
    Polygon[{{0.142610, 0.122708, 0.004934},{0.142610, 0.123563, 0.005935},{
      0.144444, 0.123853, 0.005935},{0.144709, 0.123040, 0.004934}}],
    Polygon[{{0.142610, 0.123563, 0.005935},{0.142610, 0.124564, 0.006791},{
      0.144135, 0.124806, 0.006791},{0.144444, 0.123853, 0.005935}}],
    Polygon[{{0.142610, 0.124564, 0.006791},{0.142610, 0.125687, 0.007479},{
      0.143788, 0.125874, 0.007479},{0.144135, 0.124806, 0.006791}}],
    Polygon[{{0.142610, 0.125687, 0.007479},{0.142610, 0.126904, 0.007983},{
      0.143412, 0.127031, 0.007983},{0.143788, 0.125874, 0.007479}}],
    Polygon[{{0.142610, 0.126904, 0.007983},{0.142610, 0.128185, 0.008290},{
      0.143016, 0.128249, 0.008290},{0.143412, 0.127031, 0.007983}}],
    Polygon[{{0.143016, 0.128249, -0.008290},{0.143412, 0.127031, -0.007983},{
      0.144135, 0.127400, -0.007983},{0.143382, 0.128436, -0.008290}}],
    Polygon[{{0.143412, 0.127031, -0.007983},{0.143788, 0.125874, -0.007479},{
      0.144850, 0.126415, -0.007479},{0.144135, 0.127400, -0.007983}}],
    Polygon[{{0.143788, 0.125874, -0.007479},{0.144135, 0.124806, -0.006791},{
      0.145510, 0.125507, -0.006791},{0.144850, 0.126415, -0.007479}}],
    Polygon[{{0.144135, 0.124806, -0.006791},{0.144444, 0.123853, -0.005935},{
      0.146099, 0.124696, -0.005935},{0.145510, 0.125507, -0.006791}}],
    Polygon[{{0.144444, 0.123853, -0.005935},{0.144709, 0.123040, -0.004934},{
      0.146602, 0.124004, -0.004934},{0.146099, 0.124696, -0.005935}}],
    Polygon[{{0.144709, 0.123040, -0.004934},{0.144921, 0.122385, -0.003811},{
      0.147006, 0.123448, -0.003811},{0.146602, 0.124004, -0.004934}}],
    Polygon[{{0.144921, 0.122385, -0.003811},{0.145077, 0.121906, -0.002594},{
      0.147303, 0.123040, -0.002594},{0.147006, 0.123448, -0.003811}}],
    Polygon[{{0.145077, 0.121906, -0.002594},{0.145172, 0.121614, -0.001313},{
      0.147483, 0.122791, -0.001313},{0.147303, 0.123040, -0.002594}}],
    Polygon[{{0.145172, 0.121614, -0.001313},{0.145204, 0.121515, 0.000000},{
      0.147544, 0.122708, 0.000000},{0.147483, 0.122791, -0.001313}}],
    Polygon[{{0.145204, 0.121515, 0.000000},{0.145172, 0.121614, 0.001313},{
      0.147483, 0.122791, 0.001313},{0.147544, 0.122708, 0.000000}}],
    Polygon[{{0.145172, 0.121614, 0.001313},{0.145077, 0.121906, 0.002594},{
      0.147303, 0.123040, 0.002594},{0.147483, 0.122791, 0.001313}}],
    Polygon[{{0.145077, 0.121906, 0.002594},{0.144921, 0.122385, 0.003811},{
      0.147006, 0.123448, 0.003811},{0.147303, 0.123040, 0.002594}}],
    Polygon[{{0.144921, 0.122385, 0.003811},{0.144709, 0.123040, 0.004934},{
      0.146602, 0.124004, 0.004934},{0.147006, 0.123448, 0.003811}}],
    Polygon[{{0.144709, 0.123040, 0.004934},{0.144444, 0.123853, 0.005935},{
      0.146099, 0.124696, 0.005935},{0.146602, 0.124004, 0.004934}}],
    Polygon[{{0.144444, 0.123853, 0.005935},{0.144135, 0.124806, 0.006791},{
      0.145510, 0.125507, 0.006791},{0.146099, 0.124696, 0.005935}}],
    Polygon[{{0.144135, 0.124806, 0.006791},{0.143788, 0.125874, 0.007479},{
      0.144850, 0.126415, 0.007479},{0.145510, 0.125507, 0.006791}}],
    Polygon[{{0.143788, 0.125874, 0.007479},{0.143412, 0.127031, 0.007983},{
      0.144135, 0.127400, 0.007983},{0.144850, 0.126415, 0.007479}}],
    Polygon[{{0.143412, 0.127031, 0.007983},{0.143016, 0.128249, 0.008290},{
      0.143382, 0.128436, 0.008290},{0.144135, 0.127400, 0.007983}}],
    Polygon[{{0.143382, 0.128436, -0.008290},{0.144135, 0.127400, -0.007983},{
      0.144709, 0.127974, -0.007983},{0.143673, 0.128726, -0.008290}}],
    Polygon[{{0.144135, 0.127400, -0.007983},{0.144850, 0.126415, -0.007479},{
      0.145693, 0.127258, -0.007479},{0.144709, 0.127974, -0.007983}}],
    Polygon[{{0.144850, 0.126415, -0.007479},{0.145510, 0.125507, -0.006791},{
      0.146602, 0.126598, -0.006791},{0.145693, 0.127258, -0.007479}}],
    Polygon[{{0.145510, 0.125507, -0.006791},{0.146099, 0.124696, -0.005935},{
      0.147412, 0.126010, -0.005935},{0.146602, 0.126598, -0.006791}}],
    Polygon[{{0.146099, 0.124696, -0.005935},{0.146602, 0.124004, -0.004934},{
      0.148104, 0.125507, -0.004934},{0.147412, 0.126010, -0.005935}}],
    Polygon[{{0.146602, 0.124004, -0.004934},{0.147006, 0.123448, -0.003811},{
      0.148661, 0.125102, -0.003811},{0.148104, 0.125507, -0.004934}}],
    Polygon[{{0.147006, 0.123448, -0.003811},{0.147303, 0.123040, -0.002594},{
      0.149069, 0.124806, -0.002594},{0.148661, 0.125102, -0.003811}}],
    Polygon[{{0.147303, 0.123040, -0.002594},{0.147483, 0.122791, -0.001313},{
      0.149317, 0.124625, -0.001313},{0.149069, 0.124806, -0.002594}}],
    Polygon[{{0.147483, 0.122791, -0.001313},{0.147544, 0.122708, 0.000000},{
      0.149401, 0.124564, 0.000000},{0.149317, 0.124625, -0.001313}}],
    Polygon[{{0.147544, 0.122708, 0.000000},{0.147483, 0.122791, 0.001313},{
      0.149317, 0.124625, 0.001313},{0.149401, 0.124564, 0.000000}}],
    Polygon[{{0.147483, 0.122791, 0.001313},{0.147303, 0.123040, 0.002594},{
      0.149069, 0.124806, 0.002594},{0.149317, 0.124625, 0.001313}}],
    Polygon[{{0.147303, 0.123040, 0.002594},{0.147006, 0.123448, 0.003811},{
      0.148661, 0.125102, 0.003811},{0.149069, 0.124806, 0.002594}}],
    Polygon[{{0.147006, 0.123448, 0.003811},{0.146602, 0.124004, 0.004934},{
      0.148104, 0.125507, 0.004934},{0.148661, 0.125102, 0.003811}}],
    Polygon[{{0.146602, 0.124004, 0.004934},{0.146099, 0.124696, 0.005935},{
      0.147412, 0.126010, 0.005935},{0.148104, 0.125507, 0.004934}}],
    Polygon[{{0.146099, 0.124696, 0.005935},{0.145510, 0.125507, 0.006791},{
      0.146602, 0.126598, 0.006791},{0.147412, 0.126010, 0.005935}}],
    Polygon[{{0.145510, 0.125507, 0.006791},{0.144850, 0.126415, 0.007479},{
      0.145693, 0.127258, 0.007479},{0.146602, 0.126598, 0.006791}}],
    Polygon[{{0.144850, 0.126415, 0.007479},{0.144135, 0.127400, 0.007983},{
      0.144709, 0.127974, 0.007983},{0.145693, 0.127258, 0.007479}}],
    Polygon[{{0.144135, 0.127400, 0.007983},{0.143382, 0.128436, 0.008290},{
      0.143673, 0.128726, 0.008290},{0.144709, 0.127974, 0.007983}}],
    Polygon[{{0.143673, 0.128726, -0.008290},{0.144709, 0.127974, -0.007983},{
      0.145077, 0.128697, -0.007983},{0.143859, 0.129092, -0.008290}}],
    Polygon[{{0.144709, 0.127974, -0.007983},{0.145693, 0.127258, -0.007479},{
      0.146235, 0.128321, -0.007479},{0.145077, 0.128697, -0.007983}}],
    Polygon[{{0.145693, 0.127258, -0.007479},{0.146602, 0.126598, -0.006791},{
      0.147303, 0.127974, -0.006791},{0.146235, 0.128321, -0.007479}}],
    Polygon[{{0.146602, 0.126598, -0.006791},{0.147412, 0.126010, -0.005935},{
      0.148255, 0.127664, -0.005935},{0.147303, 0.127974, -0.006791}}],
    Polygon[{{0.147412, 0.126010, -0.005935},{0.148104, 0.125507, -0.004934},{
      0.149069, 0.127400, -0.004934},{0.148255, 0.127664, -0.005935}}],
    Polygon[{{0.148104, 0.125507, -0.004934},{0.148661, 0.125102, -0.003811},{
      0.149723, 0.127187, -0.003811},{0.149069, 0.127400, -0.004934}}],
    Polygon[{{0.148661, 0.125102, -0.003811},{0.149069, 0.124806, -0.002594},{
      0.150202, 0.127031, -0.002594},{0.149723, 0.127187, -0.003811}}],
    Polygon[{{0.149069, 0.124806, -0.002594},{0.149317, 0.124625, -0.001313},{
      0.150495, 0.126936, -0.001313},{0.150202, 0.127031, -0.002594}}],
    Polygon[{{0.149317, 0.124625, -0.001313},{0.149401, 0.124564, 0.000000},{
      0.150593, 0.126904, 0.000000},{0.150495, 0.126936, -0.001313}}],
    Polygon[{{0.149401, 0.124564, 0.000000},{0.149317, 0.124625, 0.001313},{
      0.150495, 0.126936, 0.001313},{0.150593, 0.126904, 0.000000}}],
    Polygon[{{0.149317, 0.124625, 0.001313},{0.149069, 0.124806, 0.002594},{
      0.150202, 0.127031, 0.002594},{0.150495, 0.126936, 0.001313}}],
    Polygon[{{0.149069, 0.124806, 0.002594},{0.148661, 0.125102, 0.003811},{
      0.149723, 0.127187, 0.003811},{0.150202, 0.127031, 0.002594}}],
    Polygon[{{0.148661, 0.125102, 0.003811},{0.148104, 0.125507, 0.004934},{
      0.149069, 0.127400, 0.004934},{0.149723, 0.127187, 0.003811}}],
    Polygon[{{0.148104, 0.125507, 0.004934},{0.147412, 0.126010, 0.005935},{
      0.148255, 0.127664, 0.005935},{0.149069, 0.127400, 0.004934}}],
    Polygon[{{0.147412, 0.126010, 0.005935},{0.146602, 0.126598, 0.006791},{
      0.147303, 0.127974, 0.006791},{0.148255, 0.127664, 0.005935}}],
    Polygon[{{0.146602, 0.126598, 0.006791},{0.145693, 0.127258, 0.007479},{
      0.146235, 0.128321, 0.007479},{0.147303, 0.127974, 0.006791}}],
    Polygon[{{0.145693, 0.127258, 0.007479},{0.144709, 0.127974, 0.007983},{
      0.145077, 0.128697, 0.007983},{0.146235, 0.128321, 0.007479}}],
    Polygon[{{0.144709, 0.127974, 0.007983},{0.143673, 0.128726, 0.008290},{
      0.143859, 0.129092, 0.008290},{0.145077, 0.128697, 0.007983}}],
    Polygon[{{0.143859, 0.129092, -0.008290},{0.145077, 0.128697, -0.007983},{
      0.145204, 0.129498, -0.007983},{0.143923, 0.129498, -0.008290}}],
    Polygon[{{0.145077, 0.128697, -0.007983},{0.146235, 0.128321, -0.007479},{
      0.146421, 0.129498, -0.007479},{0.145204, 0.129498, -0.007983}}],
    Polygon[{{0.146235, 0.128321, -0.007479},{0.147303, 0.127974, -0.006791},{
      0.147544, 0.129498, -0.006791},{0.146421, 0.129498, -0.007479}}],
    Polygon[{{0.147303, 0.127974, -0.006791},{0.148255, 0.127664, -0.005935},{
      0.148546, 0.129498, -0.005935},{0.147544, 0.129498, -0.006791}}],
    Polygon[{{0.148255, 0.127664, -0.005935},{0.149069, 0.127400, -0.004934},{
      0.149401, 0.129498, -0.004934},{0.148546, 0.129498, -0.005935}}],
    Polygon[{{0.149069, 0.127400, -0.004934},{0.149723, 0.127187, -0.003811},{
      0.150089, 0.129498, -0.003811},{0.149401, 0.129498, -0.004934}}],
    Polygon[{{0.149723, 0.127187, -0.003811},{0.150202, 0.127031, -0.002594},{
      0.150593, 0.129498, -0.002594},{0.150089, 0.129498, -0.003811}}],
    Polygon[{{0.150202, 0.127031, -0.002594},{0.150495, 0.126936, -0.001313},{
      0.150901, 0.129498, -0.001313},{0.150593, 0.129498, -0.002594}}],
    Polygon[{{0.150495, 0.126936, -0.001313},{0.150593, 0.126904, 0.000000},{
      0.151004, 0.129498, 0.000000},{0.150901, 0.129498, -0.001313}}],
    Polygon[{{0.150593, 0.126904, 0.000000},{0.150495, 0.126936, 0.001313},{
      0.150901, 0.129498, 0.001313},{0.151004, 0.129498, 0.000000}}],
    Polygon[{{0.150495, 0.126936, 0.001313},{0.150202, 0.127031, 0.002594},{
      0.150593, 0.129498, 0.002594},{0.150901, 0.129498, 0.001313}}],
    Polygon[{{0.150202, 0.127031, 0.002594},{0.149723, 0.127187, 0.003811},{
      0.150089, 0.129498, 0.003811},{0.150593, 0.129498, 0.002594}}],
    Polygon[{{0.149723, 0.127187, 0.003811},{0.149069, 0.127400, 0.004934},{
      0.149401, 0.129498, 0.004934},{0.150089, 0.129498, 0.003811}}],
    Polygon[{{0.149069, 0.127400, 0.004934},{0.148255, 0.127664, 0.005935},{
      0.148546, 0.129498, 0.005935},{0.149401, 0.129498, 0.004934}}],
    Polygon[{{0.148255, 0.127664, 0.005935},{0.147303, 0.127974, 0.006791},{
      0.147544, 0.129498, 0.006791},{0.148546, 0.129498, 0.005935}}],
    Polygon[{{0.147303, 0.127974, 0.006791},{0.146235, 0.128321, 0.007479},{
      0.146421, 0.129498, 0.007479},{0.147544, 0.129498, 0.006791}}],
    Polygon[{{0.146235, 0.128321, 0.007479},{0.145077, 0.128697, 0.007983},{
      0.145204, 0.129498, 0.007983},{0.146421, 0.129498, 0.007479}}],
    Polygon[{{0.145077, 0.128697, 0.007983},{0.143859, 0.129092, 0.008290},{
      0.143923, 0.129498, 0.008290},{0.145204, 0.129498, 0.007983}}],
    Polygon[{{0.589451, 0.077350, -0.076398},{0.601253, 0.077350, -0.073564},{
      0.600083, 0.084737, -0.073564},{0.588858, 0.081089, -0.076398}}],
    Polygon[{{0.601253, 0.077350, -0.073564},{0.612467, 0.077350, -0.068920},{
      0.610748, 0.088202, -0.068920},{0.600083, 0.084737, -0.073564}}],
    Polygon[{{0.612467, 0.077350, -0.068920},{0.622816, 0.077350, -0.062578},{
      0.620590, 0.091400, -0.062578},{0.610748, 0.088202, -0.068920}}],
    Polygon[{{0.622816, 0.077350, -0.062578},{0.632045, 0.077350, -0.054695},{
      0.629368, 0.094252, -0.054695},{0.620590, 0.091400, -0.062578}}],
    Polygon[{{0.632045, 0.077350, -0.054695},{0.639928, 0.077350, -0.045465},{
      0.636865, 0.096688, -0.045465},{0.629368, 0.094252, -0.054695}}],
    Polygon[{{0.639928, 0.077350, -0.045465},{0.646270, 0.077350, -0.035116},{
      0.642897, 0.098648, -0.035116},{0.636865, 0.096688, -0.045465}}],
    Polygon[{{0.646270, 0.077350, -0.035116},{0.650915, 0.077350, -0.023903},{
      0.647314, 0.100083, -0.023903},{0.642897, 0.098648, -0.035116}}],
    Polygon[{{0.650915, 0.077350, -0.023903},{0.653748, 0.077350, -0.012100},{
      0.650009, 0.100959, -0.012100},{0.647314, 0.100083, -0.023903}}],
    Polygon[{{0.653748, 0.077350, -0.012100},{0.654701, 0.077350, 0.000000},{
      0.650915, 0.101253, 0.000000},{0.650009, 0.100959, -0.012100}}],
    Polygon[{{0.654701, 0.077350, 0.000000},{0.653748, 0.077350, 0.012100},{
      0.650009, 0.100959, 0.012100},{0.650915, 0.101253, 0.000000}}],
    Polygon[{{0.653748, 0.077350, 0.012100},{0.650915, 0.077350, 0.023903},{
      0.647314, 0.100083, 0.023903},{0.650009, 0.100959, 0.012100}}],
    Polygon[{{0.650915, 0.077350, 0.023903},{0.646270, 0.077350, 0.035116},{
      0.642897, 0.098648, 0.035116},{0.647314, 0.100083, 0.023903}}],
    Polygon[{{0.646270, 0.077350, 0.035116},{0.639928, 0.077350, 0.045465},{
      0.636865, 0.096688, 0.045465},{0.642897, 0.098648, 0.035116}}],
    Polygon[{{0.639928, 0.077350, 0.045465},{0.632045, 0.077350, 0.054695},{
      0.629368, 0.094252, 0.054695},{0.636865, 0.096688, 0.045465}}],
    Polygon[{{0.632045, 0.077350, 0.054695},{0.622816, 0.077350, 0.062578},{
      0.620590, 0.091400, 0.062578},{0.629368, 0.094252, 0.054695}}],
    Polygon[{{0.622816, 0.077350, 0.062578},{0.612467, 0.077350, 0.068920},{
      0.610748, 0.088202, 0.068920},{0.620590, 0.091400, 0.062578}}],
    Polygon[{{0.612467, 0.077350, 0.068920},{0.601253, 0.077350, 0.073564},{
      0.600083, 0.084737, 0.073564},{0.610748, 0.088202, 0.068920}}],
    Polygon[{{0.601253, 0.077350, 0.073564},{0.589451, 0.077350, 0.076398},{
      0.588858, 0.081089, 0.076398},{0.600083, 0.084737, 0.073564}}],
    Polygon[{{0.588858, 0.081089, -0.076398},{0.600083, 0.084737, -0.073564},{
      0.596688, 0.091400, -0.073564},{0.587140, 0.084463, -0.076398}}],
    Polygon[{{0.600083, 0.084737, -0.073564},{0.610748, 0.088202, -0.068920},{
      0.605760, 0.097991, -0.068920},{0.596688, 0.091400, -0.073564}}],
    Polygon[{{0.610748, 0.088202, -0.068920},{0.620590, 0.091400, -0.062578},{
      0.614133, 0.104074, -0.062578},{0.605760, 0.097991, -0.068920}}],
    Polygon[{{0.620590, 0.091400, -0.062578},{0.629368, 0.094252, -0.054695},{
      0.621599, 0.109499, -0.054695},{0.614133, 0.104074, -0.062578}}],
    Polygon[{{0.629368, 0.094252, -0.054695},{0.636865, 0.096688, -0.045465},{
      0.627977, 0.114133, -0.045465},{0.621599, 0.109499, -0.054695}}],
    Polygon[{{0.636865, 0.096688, -0.045465},{0.642897, 0.098648, -0.035116},{
      0.633107, 0.117860, -0.035116},{0.627977, 0.114133, -0.045465}}],
    Polygon[{{0.642897, 0.098648, -0.035116},{0.647314, 0.100083, -0.023903},{
      0.636865, 0.120590, -0.023903},{0.633107, 0.117860, -0.035116}}],
    Polygon[{{0.647314, 0.100083, -0.023903},{0.650009, 0.100959, -0.012100},{
      0.639158, 0.122256, -0.012100},{0.636865, 0.120590, -0.023903}}],
    Polygon[{{0.650009, 0.100959, -0.012100},{0.650915, 0.101253, 0.000000},{
      0.639928, 0.122816, 0.000000},{0.639158, 0.122256, -0.012100}}],
    Polygon[{{0.650915, 0.101253, 0.000000},{0.650009, 0.100959, 0.012100},{
      0.639158, 0.122256, 0.012100},{0.639928, 0.122816, 0.000000}}],
    Polygon[{{0.650009, 0.100959, 0.012100},{0.647314, 0.100083, 0.023903},{
      0.636865, 0.120590, 0.023903},{0.639158, 0.122256, 0.012100}}],
    Polygon[{{0.647314, 0.100083, 0.023903},{0.642897, 0.098648, 0.035116},{
      0.633107, 0.117860, 0.035116},{0.636865, 0.120590, 0.023903}}],
    Polygon[{{0.642897, 0.098648, 0.035116},{0.636865, 0.096688, 0.045465},{
      0.627977, 0.114133, 0.045465},{0.633107, 0.117860, 0.035116}}],
    Polygon[{{0.636865, 0.096688, 0.045465},{0.629368, 0.094252, 0.054695},{
      0.621599, 0.109499, 0.054695},{0.627977, 0.114133, 0.045465}}],
    Polygon[{{0.629368, 0.094252, 0.054695},{0.620590, 0.091400, 0.062578},{
      0.614133, 0.104074, 0.062578},{0.621599, 0.109499, 0.054695}}],
    Polygon[{{0.620590, 0.091400, 0.062578},{0.610748, 0.088202, 0.068920},{
      0.605760, 0.097991, 0.068920},{0.614133, 0.104074, 0.062578}}],
    Polygon[{{0.610748, 0.088202, 0.068920},{0.600083, 0.084737, 0.073564},{
      0.596688, 0.091400, 0.073564},{0.605760, 0.097991, 0.068920}}],
    Polygon[{{0.600083, 0.084737, 0.073564},{0.588858, 0.081089, 0.076398},{
      0.587140, 0.084463, 0.076398},{0.596688, 0.091400, 0.073564}}],
    Polygon[{{0.587140, 0.084463, -0.076398},{0.596688, 0.091400, -0.073564},{
      0.591400, 0.096688, -0.073564},{0.584463, 0.087140, -0.076398}}],
    Polygon[{{0.596688, 0.091400, -0.073564},{0.605760, 0.097991, -0.068920},{
      0.597991, 0.105760, -0.068920},{0.591400, 0.096688, -0.073564}}],
    Polygon[{{0.605760, 0.097991, -0.068920},{0.614133, 0.104074, -0.062578},{
      0.604074, 0.114133, -0.062578},{0.597991, 0.105760, -0.068920}}],
    Polygon[{{0.614133, 0.104074, -0.062578},{0.621599, 0.109499, -0.054695},{
      0.609499, 0.121599, -0.054695},{0.604074, 0.114133, -0.062578}}],
    Polygon[{{0.621599, 0.109499, -0.054695},{0.627977, 0.114133, -0.045465},{
      0.614133, 0.127977, -0.045465},{0.609499, 0.121599, -0.054695}}],
    Polygon[{{0.627977, 0.114133, -0.045465},{0.633107, 0.117860, -0.035116},{
      0.617860, 0.133107, -0.035116},{0.614133, 0.127977, -0.045465}}],
    Polygon[{{0.633107, 0.117860, -0.035116},{0.636865, 0.120590, -0.023903},{
      0.620590, 0.136865, -0.023903},{0.617860, 0.133107, -0.035116}}],
    Polygon[{{0.636865, 0.120590, -0.023903},{0.639158, 0.122256, -0.012100},{
      0.622256, 0.139158, -0.012100},{0.620590, 0.136865, -0.023903}}],
    Polygon[{{0.639158, 0.122256, -0.012100},{0.639928, 0.122816, 0.000000},{
      0.622816, 0.139928, 0.000000},{0.622256, 0.139158, -0.012100}}],
    Polygon[{{0.639928, 0.122816, 0.000000},{0.639158, 0.122256, 0.012100},{
      0.622256, 0.139158, 0.012100},{0.622816, 0.139928, 0.000000}}],
    Polygon[{{0.639158, 0.122256, 0.012100},{0.636865, 0.120590, 0.023903},{
      0.620590, 0.136865, 0.023903},{0.622256, 0.139158, 0.012100}}],
    Polygon[{{0.636865, 0.120590, 0.023903},{0.633107, 0.117860, 0.035116},{
      0.617860, 0.133107, 0.035116},{0.620590, 0.136865, 0.023903}}],
    Polygon[{{0.633107, 0.117860, 0.035116},{0.627977, 0.114133, 0.045465},{
      0.614133, 0.127977, 0.045465},{0.617860, 0.133107, 0.035116}}],
    Polygon[{{0.627977, 0.114133, 0.045465},{0.621599, 0.109499, 0.054695},{
      0.609499, 0.121599, 0.054695},{0.614133, 0.127977, 0.045465}}],
    Polygon[{{0.621599, 0.109499, 0.054695},{0.614133, 0.104074, 0.062578},{
      0.604074, 0.114133, 0.062578},{0.609499, 0.121599, 0.054695}}],
    Polygon[{{0.614133, 0.104074, 0.062578},{0.605760, 0.097991, 0.068920},{
      0.597991, 0.105760, 0.068920},{0.604074, 0.114133, 0.062578}}],
    Polygon[{{0.605760, 0.097991, 0.068920},{0.596688, 0.091400, 0.073564},{
      0.591400, 0.096688, 0.073564},{0.597991, 0.105760, 0.068920}}],
    Polygon[{{0.596688, 0.091400, 0.073564},{0.587140, 0.084463, 0.076398},{
      0.584463, 0.087140, 0.076398},{0.591400, 0.096688, 0.073564}}],
    Polygon[{{0.584463, 0.087140, -0.076398},{0.591400, 0.096688, -0.073564},{
      0.584737, 0.100083, -0.073564},{0.581089, 0.088858, -0.076398}}],
    Polygon[{{0.591400, 0.096688, -0.073564},{0.597991, 0.105760, -0.068920},{
      0.588202, 0.110748, -0.068920},{0.584737, 0.100083, -0.073564}}],
    Polygon[{{0.597991, 0.105760, -0.068920},{0.604074, 0.114133, -0.062578},{
      0.591400, 0.120590, -0.062578},{0.588202, 0.110748, -0.068920}}],
    Polygon[{{0.604074, 0.114133, -0.062578},{0.609499, 0.121599, -0.054695},{
      0.594252, 0.129368, -0.054695},{0.591400, 0.120590, -0.062578}}],
    Polygon[{{0.609499, 0.121599, -0.054695},{0.614133, 0.127977, -0.045465},{
      0.596688, 0.136865, -0.045465},{0.594252, 0.129368, -0.054695}}],
    Polygon[{{0.614133, 0.127977, -0.045465},{0.617860, 0.133107, -0.035116},{
      0.598648, 0.142897, -0.035116},{0.596688, 0.136865, -0.045465}}],
    Polygon[{{0.617860, 0.133107, -0.035116},{0.620590, 0.136865, -0.023903},{
      0.600083, 0.147314, -0.023903},{0.598648, 0.142897, -0.035116}}],
    Polygon[{{0.620590, 0.136865, -0.023903},{0.622256, 0.139158, -0.012100},{
      0.600959, 0.150009, -0.012100},{0.600083, 0.147314, -0.023903}}],
    Polygon[{{0.622256, 0.139158, -0.012100},{0.622816, 0.139928, 0.000000},{
      0.601253, 0.150915, 0.000000},{0.600959, 0.150009, -0.012100}}],
    Polygon[{{0.622816, 0.139928, 0.000000},{0.622256, 0.139158, 0.012100},{
      0.600959, 0.150009, 0.012100},{0.601253, 0.150915, 0.000000}}],
    Polygon[{{0.622256, 0.139158, 0.012100},{0.620590, 0.136865, 0.023903},{
      0.600083, 0.147314, 0.023903},{0.600959, 0.150009, 0.012100}}],
    Polygon[{{0.620590, 0.136865, 0.023903},{0.617860, 0.133107, 0.035116},{
      0.598648, 0.142897, 0.035116},{0.600083, 0.147314, 0.023903}}],
    Polygon[{{0.617860, 0.133107, 0.035116},{0.614133, 0.127977, 0.045465},{
      0.596688, 0.136865, 0.045465},{0.598648, 0.142897, 0.035116}}],
    Polygon[{{0.614133, 0.127977, 0.045465},{0.609499, 0.121599, 0.054695},{
      0.594252, 0.129368, 0.054695},{0.596688, 0.136865, 0.045465}}],
    Polygon[{{0.609499, 0.121599, 0.054695},{0.604074, 0.114133, 0.062578},{
      0.591400, 0.120590, 0.062578},{0.594252, 0.129368, 0.054695}}],
    Polygon[{{0.604074, 0.114133, 0.062578},{0.597991, 0.105760, 0.068920},{
      0.588202, 0.110748, 0.068920},{0.591400, 0.120590, 0.062578}}],
    Polygon[{{0.597991, 0.105760, 0.068920},{0.591400, 0.096688, 0.073564},{
      0.584737, 0.100083, 0.073564},{0.588202, 0.110748, 0.068920}}],
    Polygon[{{0.591400, 0.096688, 0.073564},{0.584463, 0.087140, 0.076398},{
      0.581089, 0.088858, 0.076398},{0.584737, 0.100083, 0.073564}}],
    Polygon[{{0.581089, 0.088858, -0.076398},{0.584737, 0.100083, -0.073564},{
      0.577350, 0.101253, -0.073564},{0.577350, 0.089451, -0.076398}}],
    Polygon[{{0.584737, 0.100083, -0.073564},{0.588202, 0.110748, -0.068920},{
      0.577350, 0.112467, -0.068920},{0.577350, 0.101253, -0.073564}}],
    Polygon[{{0.588202, 0.110748, -0.068920},{0.591400, 0.120590, -0.062578},{
      0.577350, 0.122816, -0.062578},{0.577350, 0.112467, -0.068920}}],
    Polygon[{{0.591400, 0.120590, -0.062578},{0.594252, 0.129368, -0.054695},{
      0.577350, 0.132045, -0.054695},{0.577350, 0.122816, -0.062578}}],
    Polygon[{{0.594252, 0.129368, -0.054695},{0.596688, 0.136865, -0.045465},{
      0.577350, 0.139928, -0.045465},{0.577350, 0.132045, -0.054695}}],
    Polygon[{{0.596688, 0.136865, -0.045465},{0.598648, 0.142897, -0.035116},{
      0.577350, 0.146270, -0.035116},{0.577350, 0.139928, -0.045465}}],
    Polygon[{{0.598648, 0.142897, -0.035116},{0.600083, 0.147314, -0.023903},{
      0.577350, 0.150915, -0.023903},{0.577350, 0.146270, -0.035116}}],
    Polygon[{{0.600083, 0.147314, -0.023903},{0.600959, 0.150009, -0.012100},{
      0.577350, 0.153748, -0.012100},{0.577350, 0.150915, -0.023903}}],
    Polygon[{{0.600959, 0.150009, -0.012100},{0.601253, 0.150915, 0.000000},{
      0.577350, 0.154701, 0.000000},{0.577350, 0.153748, -0.012100}}],
    Polygon[{{0.601253, 0.150915, 0.000000},{0.600959, 0.150009, 0.012100},{
      0.577350, 0.153748, 0.012100},{0.577350, 0.154701, 0.000000}}],
    Polygon[{{0.600959, 0.150009, 0.012100},{0.600083, 0.147314, 0.023903},{
      0.577350, 0.150915, 0.023903},{0.577350, 0.153748, 0.012100}}],
    Polygon[{{0.600083, 0.147314, 0.023903},{0.598648, 0.142897, 0.035116},{
      0.577350, 0.146270, 0.035116},{0.577350, 0.150915, 0.023903}}],
    Polygon[{{0.598648, 0.142897, 0.035116},{0.596688, 0.136865, 0.045465},{
      0.577350, 0.139928, 0.045465},{0.577350, 0.146270, 0.035116}}],
    Polygon[{{0.596688, 0.136865, 0.045465},{0.594252, 0.129368, 0.054695},{
      0.577350, 0.132045, 0.054695},{0.577350, 0.139928, 0.045465}}],
    Polygon[{{0.594252, 0.129368, 0.054695},{0.591400, 0.120590, 0.062578},{
      0.577350, 0.122816, 0.062578},{0.577350, 0.132045, 0.054695}}],
    Polygon[{{0.591400, 0.120590, 0.062578},{0.588202, 0.110748, 0.068920},{
      0.577350, 0.112467, 0.068920},{0.577350, 0.122816, 0.062578}}],
    Polygon[{{0.588202, 0.110748, 0.068920},{0.584737, 0.100083, 0.073564},{
      0.577350, 0.101253, 0.073564},{0.577350, 0.112467, 0.068920}}],
    Polygon[{{0.584737, 0.100083, 0.073564},{0.581089, 0.088858, 0.076398},{
      0.577350, 0.089451, 0.076398},{0.577350, 0.101253, 0.073564}}],
    Polygon[{{0.577350, 0.089451, -0.076398},{0.577350, 0.101253, -0.073564},{
      0.569964, 0.100083, -0.073564},{0.573611, 0.088858, -0.076398}}],
    Polygon[{{0.577350, 0.101253, -0.073564},{0.577350, 0.112467, -0.068920},{
      0.566499, 0.110748, -0.068920},{0.569964, 0.100083, -0.073564}}],
    Polygon[{{0.577350, 0.112467, -0.068920},{0.577350, 0.122816, -0.062578},{
      0.563301, 0.120590, -0.062578},{0.566499, 0.110748, -0.068920}}],
    Polygon[{{0.577350, 0.122816, -0.062578},{0.577350, 0.132045, -0.054695},{
      0.560449, 0.129368, -0.054695},{0.563301, 0.120590, -0.062578}}],
    Polygon[{{0.577350, 0.132045, -0.054695},{0.577350, 0.139928, -0.045465},{
      0.558013, 0.136865, -0.045465},{0.560449, 0.129368, -0.054695}}],
    Polygon[{{0.577350, 0.139928, -0.045465},{0.577350, 0.146270, -0.035116},{
      0.556053, 0.142897, -0.035116},{0.558013, 0.136865, -0.045465}}],
    Polygon[{{0.577350, 0.146270, -0.035116},{0.577350, 0.150915, -0.023903},{
      0.554618, 0.147314, -0.023903},{0.556053, 0.142897, -0.035116}}],
    Polygon[{{0.577350, 0.150915, -0.023903},{0.577350, 0.153748, -0.012100},{
      0.553742, 0.150009, -0.012100},{0.554618, 0.147314, -0.023903}}],
    Polygon[{{0.577350, 0.153748, -0.012100},{0.577350, 0.154701, 0.000000},{
      0.553448, 0.150915, 0.000000},{0.553742, 0.150009, -0.012100}}],
    Polygon[{{0.577350, 0.154701, 0.000000},{0.577350, 0.153748, 0.012100},{
      0.553742, 0.150009, 0.012100},{0.553448, 0.150915, 0.000000}}],
    Polygon[{{0.577350, 0.153748, 0.012100},{0.577350, 0.150915, 0.023903},{
      0.554618, 0.147314, 0.023903},{0.553742, 0.150009, 0.012100}}],
    Polygon[{{0.577350, 0.150915, 0.023903},{0.577350, 0.146270, 0.035116},{
      0.556053, 0.142897, 0.035116},{0.554618, 0.147314, 0.023903}}],
    Polygon[{{0.577350, 0.146270, 0.035116},{0.577350, 0.139928, 0.045465},{
      0.558013, 0.136865, 0.045465},{0.556053, 0.142897, 0.035116}}],
    Polygon[{{0.577350, 0.139928, 0.045465},{0.577350, 0.132045, 0.054695},{
      0.560449, 0.129368, 0.054695},{0.558013, 0.136865, 0.045465}}],
    Polygon[{{0.577350, 0.132045, 0.054695},{0.577350, 0.122816, 0.062578},{
      0.563301, 0.120590, 0.062578},{0.560449, 0.129368, 0.054695}}],
    Polygon[{{0.577350, 0.122816, 0.062578},{0.577350, 0.112467, 0.068920},{
      0.566499, 0.110748, 0.068920},{0.563301, 0.120590, 0.062578}}],
    Polygon[{{0.577350, 0.112467, 0.068920},{0.577350, 0.101253, 0.073564},{
      0.569964, 0.100083, 0.073564},{0.566499, 0.110748, 0.068920}}],
    Polygon[{{0.577350, 0.101253, 0.073564},{0.577350, 0.089451, 0.076398},{
      0.573611, 0.088858, 0.076398},{0.569964, 0.100083, 0.073564}}],
    Polygon[{{0.573611, 0.088858, -0.076398},{0.569964, 0.100083, -0.073564},{
      0.563301, 0.096688, -0.073564},{0.570238, 0.087140, -0.076398}}],
    Polygon[{{0.569964, 0.100083, -0.073564},{0.566499, 0.110748, -0.068920},{
      0.556709, 0.105760, -0.068920},{0.563301, 0.096688, -0.073564}}],
    Polygon[{{0.566499, 0.110748, -0.068920},{0.563301, 0.120590, -0.062578},{
      0.550626, 0.114133, -0.062578},{0.556709, 0.105760, -0.068920}}],
    Polygon[{{0.563301, 0.120590, -0.062578},{0.560449, 0.129368, -0.054695},{
      0.545201, 0.121599, -0.054695},{0.550626, 0.114133, -0.062578}}],
    Polygon[{{0.560449, 0.129368, -0.054695},{0.558013, 0.136865, -0.045465},{
      0.540568, 0.127977, -0.045465},{0.545201, 0.121599, -0.054695}}],
    Polygon[{{0.558013, 0.136865, -0.045465},{0.556053, 0.142897, -0.035116},{
      0.536840, 0.133107, -0.035116},{0.540568, 0.127977, -0.045465}}],
    Polygon[{{0.556053, 0.142897, -0.035116},{0.554618, 0.147314, -0.023903},{
      0.534110, 0.136865, -0.023903},{0.536840, 0.133107, -0.035116}}],
    Polygon[{{0.554618, 0.147314, -0.023903},{0.553742, 0.150009, -0.012100},{
      0.532445, 0.139158, -0.012100},{0.534110, 0.136865, -0.023903}}],
    Polygon[{{0.553742, 0.150009, -0.012100},{0.553448, 0.150915, 0.000000},{
      0.531885, 0.139928, 0.000000},{0.532445, 0.139158, -0.012100}}],
    Polygon[{{0.553448, 0.150915, 0.000000},{0.553742, 0.150009, 0.012100},{
      0.532445, 0.139158, 0.012100},{0.531885, 0.139928, 0.000000}}],
    Polygon[{{0.553742, 0.150009, 0.012100},{0.554618, 0.147314, 0.023903},{
      0.534110, 0.136865, 0.023903},{0.532445, 0.139158, 0.012100}}],
    Polygon[{{0.554618, 0.147314, 0.023903},{0.556053, 0.142897, 0.035116},{
      0.536840, 0.133107, 0.035116},{0.534110, 0.136865, 0.023903}}],
    Polygon[{{0.556053, 0.142897, 0.035116},{0.558013, 0.136865, 0.045465},{
      0.540568, 0.127977, 0.045465},{0.536840, 0.133107, 0.035116}}],
    Polygon[{{0.558013, 0.136865, 0.045465},{0.560449, 0.129368, 0.054695},{
      0.545201, 0.121599, 0.054695},{0.540568, 0.127977, 0.045465}}],
    Polygon[{{0.560449, 0.129368, 0.054695},{0.563301, 0.120590, 0.062578},{
      0.550626, 0.114133, 0.062578},{0.545201, 0.121599, 0.054695}}],
    Polygon[{{0.563301, 0.120590, 0.062578},{0.566499, 0.110748, 0.068920},{
      0.556709, 0.105760, 0.068920},{0.550626, 0.114133, 0.062578}}],
    Polygon[{{0.566499, 0.110748, 0.068920},{0.569964, 0.100083, 0.073564},{
      0.563301, 0.096688, 0.073564},{0.556709, 0.105760, 0.068920}}],
    Polygon[{{0.569964, 0.100083, 0.073564},{0.573611, 0.088858, 0.076398},{
      0.570238, 0.087140, 0.076398},{0.563301, 0.096688, 0.073564}}],
    Polygon[{{0.570238, 0.087140, -0.076398},{0.563301, 0.096688, -0.073564},{
      0.558013, 0.091400, -0.073564},{0.567561, 0.084463, -0.076398}}],
    Polygon[{{0.563301, 0.096688, -0.073564},{0.556709, 0.105760, -0.068920},{
      0.548941, 0.097991, -0.068920},{0.558013, 0.091400, -0.073564}}],
    Polygon[{{0.556709, 0.105760, -0.068920},{0.550626, 0.114133, -0.062578},{
      0.540568, 0.104074, -0.062578},{0.548941, 0.097991, -0.068920}}],
    Polygon[{{0.550626, 0.114133, -0.062578},{0.545201, 0.121599, -0.054695},{
      0.533101, 0.109499, -0.054695},{0.540568, 0.104074, -0.062578}}],
    Polygon[{{0.545201, 0.121599, -0.054695},{0.540568, 0.127977, -0.045465},{
      0.526724, 0.114133, -0.045465},{0.533101, 0.109499, -0.054695}}],
    Polygon[{{0.540568, 0.127977, -0.045465},{0.536840, 0.133107, -0.035116},{
      0.521593, 0.117860, -0.035116},{0.526724, 0.114133, -0.045465}}],
    Polygon[{{0.536840, 0.133107, -0.035116},{0.534110, 0.136865, -0.023903},{
      0.517835, 0.120590, -0.023903},{0.521593, 0.117860, -0.035116}}],
    Polygon[{{0.534110, 0.136865, -0.023903},{0.532445, 0.139158, -0.012100},{
      0.515543, 0.122256, -0.012100},{0.517835, 0.120590, -0.023903}}],
    Polygon[{{0.532445, 0.139158, -0.012100},{0.531885, 0.139928, 0.000000},{
      0.514773, 0.122816, 0.000000},{0.515543, 0.122256, -0.012100}}],
    Polygon[{{0.531885, 0.139928, 0.000000},{0.532445, 0.139158, 0.012100},{
      0.515543, 0.122256, 0.012100},{0.514773, 0.122816, 0.000000}}],
    Polygon[{{0.532445, 0.139158, 0.012100},{0.534110, 0.136865, 0.023903},{
      0.517835, 0.120590, 0.023903},{0.515543, 0.122256, 0.012100}}],
    Polygon[{{0.534110, 0.136865, 0.023903},{0.536840, 0.133107, 0.035116},{
      0.521593, 0.117860, 0.035116},{0.517835, 0.120590, 0.023903}}],
    Polygon[{{0.536840, 0.133107, 0.035116},{0.540568, 0.127977, 0.045465},{
      0.526724, 0.114133, 0.045465},{0.521593, 0.117860, 0.035116}}],
    Polygon[{{0.540568, 0.127977, 0.045465},{0.545201, 0.121599, 0.054695},{
      0.533101, 0.109499, 0.054695},{0.526724, 0.114133, 0.045465}}],
    Polygon[{{0.545201, 0.121599, 0.054695},{0.550626, 0.114133, 0.062578},{
      0.540568, 0.104074, 0.062578},{0.533101, 0.109499, 0.054695}}],
    Polygon[{{0.550626, 0.114133, 0.062578},{0.556709, 0.105760, 0.068920},{
      0.548941, 0.097991, 0.068920},{0.540568, 0.104074, 0.062578}}],
    Polygon[{{0.556709, 0.105760, 0.068920},{0.563301, 0.096688, 0.073564},{
      0.558013, 0.091400, 0.073564},{0.548941, 0.097991, 0.068920}}],
    Polygon[{{0.563301, 0.096688, 0.073564},{0.570238, 0.087140, 0.076398},{
      0.567561, 0.084463, 0.076398},{0.558013, 0.091400, 0.073564}}],
    Polygon[{{0.567561, 0.084463, -0.076398},{0.558013, 0.091400, -0.073564},{
      0.554618, 0.084737, -0.073564},{0.565842, 0.081089, -0.076398}}],
    Polygon[{{0.558013, 0.091400, -0.073564},{0.548941, 0.097991, -0.068920},{
      0.543953, 0.088202, -0.068920},{0.554618, 0.084737, -0.073564}}],
    Polygon[{{0.548941, 0.097991, -0.068920},{0.540568, 0.104074, -0.062578},{
      0.534110, 0.091400, -0.062578},{0.543953, 0.088202, -0.068920}}],
    Polygon[{{0.540568, 0.104074, -0.062578},{0.533101, 0.109499, -0.054695},{
      0.525332, 0.094252, -0.054695},{0.534110, 0.091400, -0.062578}}],
    Polygon[{{0.533101, 0.109499, -0.054695},{0.526724, 0.114133, -0.045465},{
      0.517835, 0.096688, -0.045465},{0.525332, 0.094252, -0.054695}}],
    Polygon[{{0.526724, 0.114133, -0.045465},{0.521593, 0.117860, -0.035116},{
      0.511804, 0.098648, -0.035116},{0.517835, 0.096688, -0.045465}}],
    Polygon[{{0.521593, 0.117860, -0.035116},{0.517835, 0.120590, -0.023903},{
      0.507386, 0.100083, -0.023903},{0.511804, 0.098648, -0.035116}}],
    Polygon[{{0.517835, 0.120590, -0.023903},{0.515543, 0.122256, -0.012100},{
      0.504691, 0.100959, -0.012100},{0.507386, 0.100083, -0.023903}}],
    Polygon[{{0.515543, 0.122256, -0.012100},{0.514773, 0.122816, 0.000000},{
      0.503786, 0.101253, 0.000000},{0.504691, 0.100959, -0.012100}}],
    Polygon[{{0.514773, 0.122816, 0.000000},{0.515543, 0.122256, 0.012100},{
      0.504691, 0.100959, 0.012100},{0.503786, 0.101253, 0.000000}}],
    Polygon[{{0.515543, 0.122256, 0.012100},{0.517835, 0.120590, 0.023903},{
      0.507386, 0.100083, 0.023903},{0.504691, 0.100959, 0.012100}}],
    Polygon[{{0.517835, 0.120590, 0.023903},{0.521593, 0.117860, 0.035116},{
      0.511804, 0.098648, 0.035116},{0.507386, 0.100083, 0.023903}}],
    Polygon[{{0.521593, 0.117860, 0.035116},{0.526724, 0.114133, 0.045465},{
      0.517835, 0.096688, 0.045465},{0.511804, 0.098648, 0.035116}}],
    Polygon[{{0.526724, 0.114133, 0.045465},{0.533101, 0.109499, 0.054695},{
      0.525332, 0.094252, 0.054695},{0.517835, 0.096688, 0.045465}}],
    Polygon[{{0.533101, 0.109499, 0.054695},{0.540568, 0.104074, 0.062578},{
      0.534110, 0.091400, 0.062578},{0.525332, 0.094252, 0.054695}}],
    Polygon[{{0.540568, 0.104074, 0.062578},{0.548941, 0.097991, 0.068920},{
      0.543953, 0.088202, 0.068920},{0.534110, 0.091400, 0.062578}}],
    Polygon[{{0.548941, 0.097991, 0.068920},{0.558013, 0.091400, 0.073564},{
      0.554618, 0.084737, 0.073564},{0.543953, 0.088202, 0.068920}}],
    Polygon[{{0.558013, 0.091400, 0.073564},{0.567561, 0.084463, 0.076398},{
      0.565842, 0.081089, 0.076398},{0.554618, 0.084737, 0.073564}}],
    Polygon[{{0.565842, 0.081089, -0.076398},{0.554618, 0.084737, -0.073564},{
      0.553448, 0.077350, -0.073564},{0.565250, 0.077350, -0.076398}}],
    Polygon[{{0.554618, 0.084737, -0.073564},{0.543953, 0.088202, -0.068920},{
      0.542234, 0.077350, -0.068920},{0.553448, 0.077350, -0.073564}}],
    Polygon[{{0.543953, 0.088202, -0.068920},{0.534110, 0.091400, -0.062578},{
      0.531885, 0.077350, -0.062578},{0.542234, 0.077350, -0.068920}}],
    Polygon[{{0.534110, 0.091400, -0.062578},{0.525332, 0.094252, -0.054695},{
      0.522655, 0.077350, -0.054695},{0.531885, 0.077350, -0.062578}}],
    Polygon[{{0.525332, 0.094252, -0.054695},{0.517835, 0.096688, -0.045465},{
      0.514773, 0.077350, -0.045465},{0.522655, 0.077350, -0.054695}}],
    Polygon[{{0.517835, 0.096688, -0.045465},{0.511804, 0.098648, -0.035116},{
      0.508431, 0.077350, -0.035116},{0.514773, 0.077350, -0.045465}}],
    Polygon[{{0.511804, 0.098648, -0.035116},{0.507386, 0.100083, -0.023903},{
      0.503786, 0.077350, -0.023903},{0.508431, 0.077350, -0.035116}}],
    Polygon[{{0.507386, 0.100083, -0.023903},{0.504691, 0.100959, -0.012100},{
      0.500952, 0.077350, -0.012100},{0.503786, 0.077350, -0.023903}}],
    Polygon[{{0.504691, 0.100959, -0.012100},{0.503786, 0.101253, 0.000000},{
      0.500000, 0.077350, 0.000000},{0.500952, 0.077350, -0.012100}}],
    Polygon[{{0.503786, 0.101253, 0.000000},{0.504691, 0.100959, 0.012100},{
      0.500952, 0.077350, 0.012100},{0.500000, 0.077350, 0.000000}}],
    Polygon[{{0.504691, 0.100959, 0.012100},{0.507386, 0.100083, 0.023903},{
      0.503786, 0.077350, 0.023903},{0.500952, 0.077350, 0.012100}}],
    Polygon[{{0.507386, 0.100083, 0.023903},{0.511804, 0.098648, 0.035116},{
      0.508431, 0.077350, 0.035116},{0.503786, 0.077350, 0.023903}}],
    Polygon[{{0.511804, 0.098648, 0.035116},{0.517835, 0.096688, 0.045465},{
      0.514773, 0.077350, 0.045465},{0.508431, 0.077350, 0.035116}}],
    Polygon[{{0.517835, 0.096688, 0.045465},{0.525332, 0.094252, 0.054695},{
      0.522655, 0.077350, 0.054695},{0.514773, 0.077350, 0.045465}}],
    Polygon[{{0.525332, 0.094252, 0.054695},{0.534110, 0.091400, 0.062578},{
      0.531885, 0.077350, 0.062578},{0.522655, 0.077350, 0.054695}}],
    Polygon[{{0.534110, 0.091400, 0.062578},{0.543953, 0.088202, 0.068920},{
      0.542234, 0.077350, 0.068920},{0.531885, 0.077350, 0.062578}}],
    Polygon[{{0.543953, 0.088202, 0.068920},{0.554618, 0.084737, 0.073564},{
      0.553448, 0.077350, 0.073564},{0.542234, 0.077350, 0.068920}}],
    Polygon[{{0.554618, 0.084737, 0.073564},{0.565842, 0.081089, 0.076398},{
      0.565250, 0.077350, 0.076398},{0.553448, 0.077350, 0.073564}}],
    Polygon[{{0.565250, 0.077350, -0.076398},{0.553448, 0.077350, -0.073564},{
      0.554618, 0.069964, -0.073564},{0.565842, 0.073611, -0.076398}}],
    Polygon[{{0.553448, 0.077350, -0.073564},{0.542234, 0.077350, -0.068920},{
      0.543953, 0.066499, -0.068920},{0.554618, 0.069964, -0.073564}}],
    Polygon[{{0.542234, 0.077350, -0.068920},{0.531885, 0.077350, -0.062578},{
      0.534110, 0.063301, -0.062578},{0.543953, 0.066499, -0.068920}}],
    Polygon[{{0.531885, 0.077350, -0.062578},{0.522655, 0.077350, -0.054695},{
      0.525332, 0.060449, -0.054695},{0.534110, 0.063301, -0.062578}}],
    Polygon[{{0.522655, 0.077350, -0.054695},{0.514773, 0.077350, -0.045465},{
      0.517835, 0.058013, -0.045465},{0.525332, 0.060449, -0.054695}}],
    Polygon[{{0.514773, 0.077350, -0.045465},{0.508431, 0.077350, -0.035116},{
      0.511804, 0.056053, -0.035116},{0.517835, 0.058013, -0.045465}}],
    Polygon[{{0.508431, 0.077350, -0.035116},{0.503786, 0.077350, -0.023903},{
      0.507386, 0.054618, -0.023903},{0.511804, 0.056053, -0.035116}}],
    Polygon[{{0.503786, 0.077350, -0.023903},{0.500952, 0.077350, -0.012100},{
      0.504691, 0.053742, -0.012100},{0.507386, 0.054618, -0.023903}}],
    Polygon[{{0.500952, 0.077350, -0.012100},{0.500000, 0.077350, 0.000000},{
      0.503786, 0.053448, 0.000000},{0.504691, 0.053742, -0.012100}}],
    Polygon[{{0.500000, 0.077350, 0.000000},{0.500952, 0.077350, 0.012100},{
      0.504691, 0.053742, 0.012100},{0.503786, 0.053448, 0.000000}}],
    Polygon[{{0.500952, 0.077350, 0.012100},{0.503786, 0.077350, 0.023903},{
      0.507386, 0.054618, 0.023903},{0.504691, 0.053742, 0.012100}}],
    Polygon[{{0.503786, 0.077350, 0.023903},{0.508431, 0.077350, 0.035116},{
      0.511804, 0.056053, 0.035116},{0.507386, 0.054618, 0.023903}}],
    Polygon[{{0.508431, 0.077350, 0.035116},{0.514773, 0.077350, 0.045465},{
      0.517835, 0.058013, 0.045465},{0.511804, 0.056053, 0.035116}}],
    Polygon[{{0.514773, 0.077350, 0.045465},{0.522655, 0.077350, 0.054695},{
      0.525332, 0.060449, 0.054695},{0.517835, 0.058013, 0.045465}}],
    Polygon[{{0.522655, 0.077350, 0.054695},{0.531885, 0.077350, 0.062578},{
      0.534110, 0.063301, 0.062578},{0.525332, 0.060449, 0.054695}}],
    Polygon[{{0.531885, 0.077350, 0.062578},{0.542234, 0.077350, 0.068920},{
      0.543953, 0.066499, 0.068920},{0.534110, 0.063301, 0.062578}}],
    Polygon[{{0.542234, 0.077350, 0.068920},{0.553448, 0.077350, 0.073564},{
      0.554618, 0.069964, 0.073564},{0.543953, 0.066499, 0.068920}}],
    Polygon[{{0.553448, 0.077350, 0.073564},{0.565250, 0.077350, 0.076398},{
      0.565842, 0.073611, 0.076398},{0.554618, 0.069964, 0.073564}}],
    Polygon[{{0.565842, 0.073611, -0.076398},{0.554618, 0.069964, -0.073564},{
      0.558013, 0.063301, -0.073564},{0.567561, 0.070238, -0.076398}}],
    Polygon[{{0.554618, 0.069964, -0.073564},{0.543953, 0.066499, -0.068920},{
      0.548941, 0.056709, -0.068920},{0.558013, 0.063301, -0.073564}}],
    Polygon[{{0.543953, 0.066499, -0.068920},{0.534110, 0.063301, -0.062578},{
      0.540568, 0.050626, -0.062578},{0.548941, 0.056709, -0.068920}}],
    Polygon[{{0.534110, 0.063301, -0.062578},{0.525332, 0.060449, -0.054695},{
      0.533101, 0.045201, -0.054695},{0.540568, 0.050626, -0.062578}}],
    Polygon[{{0.525332, 0.060449, -0.054695},{0.517835, 0.058013, -0.045465},{
      0.526724, 0.040568, -0.045465},{0.533101, 0.045201, -0.054695}}],
    Polygon[{{0.517835, 0.058013, -0.045465},{0.511804, 0.056053, -0.035116},{
      0.521593, 0.036840, -0.035116},{0.526724, 0.040568, -0.045465}}],
    Polygon[{{0.511804, 0.056053, -0.035116},{0.507386, 0.054618, -0.023903},{
      0.517835, 0.034110, -0.023903},{0.521593, 0.036840, -0.035116}}],
    Polygon[{{0.507386, 0.054618, -0.023903},{0.504691, 0.053742, -0.012100},{
      0.515543, 0.032445, -0.012100},{0.517835, 0.034110, -0.023903}}],
    Polygon[{{0.504691, 0.053742, -0.012100},{0.503786, 0.053448, 0.000000},{
      0.514773, 0.031885, 0.000000},{0.515543, 0.032445, -0.012100}}],
    Polygon[{{0.503786, 0.053448, 0.000000},{0.504691, 0.053742, 0.012100},{
      0.515543, 0.032445, 0.012100},{0.514773, 0.031885, 0.000000}}],
    Polygon[{{0.504691, 0.053742, 0.012100},{0.507386, 0.054618, 0.023903},{
      0.517835, 0.034110, 0.023903},{0.515543, 0.032445, 0.012100}}],
    Polygon[{{0.507386, 0.054618, 0.023903},{0.511804, 0.056053, 0.035116},{
      0.521593, 0.036840, 0.035116},{0.517835, 0.034110, 0.023903}}],
    Polygon[{{0.511804, 0.056053, 0.035116},{0.517835, 0.058013, 0.045465},{
      0.526724, 0.040568, 0.045465},{0.521593, 0.036840, 0.035116}}],
    Polygon[{{0.517835, 0.058013, 0.045465},{0.525332, 0.060449, 0.054695},{
      0.533101, 0.045201, 0.054695},{0.526724, 0.040568, 0.045465}}],
    Polygon[{{0.525332, 0.060449, 0.054695},{0.534110, 0.063301, 0.062578},{
      0.540568, 0.050626, 0.062578},{0.533101, 0.045201, 0.054695}}],
    Polygon[{{0.534110, 0.063301, 0.062578},{0.543953, 0.066499, 0.068920},{
      0.548941, 0.056709, 0.068920},{0.540568, 0.050626, 0.062578}}],
    Polygon[{{0.543953, 0.066499, 0.068920},{0.554618, 0.069964, 0.073564},{
      0.558013, 0.063301, 0.073564},{0.548941, 0.056709, 0.068920}}],
    Polygon[{{0.554618, 0.069964, 0.073564},{0.565842, 0.073611, 0.076398},{
      0.567561, 0.070238, 0.076398},{0.558013, 0.063301, 0.073564}}],
    Polygon[{{0.567561, 0.070238, -0.076398},{0.558013, 0.063301, -0.073564},{
      0.563301, 0.058013, -0.073564},{0.570238, 0.067561, -0.076398}}],
    Polygon[{{0.558013, 0.063301, -0.073564},{0.548941, 0.056709, -0.068920},{
      0.556709, 0.048941, -0.068920},{0.563301, 0.058013, -0.073564}}],
    Polygon[{{0.548941, 0.056709, -0.068920},{0.540568, 0.050626, -0.062578},{
      0.550626, 0.040568, -0.062578},{0.556709, 0.048941, -0.068920}}],
    Polygon[{{0.540568, 0.050626, -0.062578},{0.533101, 0.045201, -0.054695},{
      0.545201, 0.033101, -0.054695},{0.550626, 0.040568, -0.062578}}],
    Polygon[{{0.533101, 0.045201, -0.054695},{0.526724, 0.040568, -0.045465},{
      0.540568, 0.026724, -0.045465},{0.545201, 0.033101, -0.054695}}],
    Polygon[{{0.526724, 0.040568, -0.045465},{0.521593, 0.036840, -0.035116},{
      0.536840, 0.021593, -0.035116},{0.540568, 0.026724, -0.045465}}],
    Polygon[{{0.521593, 0.036840, -0.035116},{0.517835, 0.034110, -0.023903},{
      0.534110, 0.017835, -0.023903},{0.536840, 0.021593, -0.035116}}],
    Polygon[{{0.517835, 0.034110, -0.023903},{0.515543, 0.032445, -0.012100},{
      0.532445, 0.015543, -0.012100},{0.534110, 0.017835, -0.023903}}],
    Polygon[{{0.515543, 0.032445, -0.012100},{0.514773, 0.031885, 0.000000},{
      0.531885, 0.014773, 0.000000},{0.532445, 0.015543, -0.012100}}],
    Polygon[{{0.514773, 0.031885, 0.000000},{0.515543, 0.032445, 0.012100},{
      0.532445, 0.015543, 0.012100},{0.531885, 0.014773, 0.000000}}],
    Polygon[{{0.515543, 0.032445, 0.012100},{0.517835, 0.034110, 0.023903},{
      0.534110, 0.017835, 0.023903},{0.532445, 0.015543, 0.012100}}],
    Polygon[{{0.517835, 0.034110, 0.023903},{0.521593, 0.036840, 0.035116},{
      0.536840, 0.021593, 0.035116},{0.534110, 0.017835, 0.023903}}],
    Polygon[{{0.521593, 0.036840, 0.035116},{0.526724, 0.040568, 0.045465},{
      0.540568, 0.026724, 0.045465},{0.536840, 0.021593, 0.035116}}],
    Polygon[{{0.526724, 0.040568, 0.045465},{0.533101, 0.045201, 0.054695},{
      0.545201, 0.033101, 0.054695},{0.540568, 0.026724, 0.045465}}],
    Polygon[{{0.533101, 0.045201, 0.054695},{0.540568, 0.050626, 0.062578},{
      0.550626, 0.040568, 0.062578},{0.545201, 0.033101, 0.054695}}],
    Polygon[{{0.540568, 0.050626, 0.062578},{0.548941, 0.056709, 0.068920},{
      0.556709, 0.048941, 0.068920},{0.550626, 0.040568, 0.062578}}],
    Polygon[{{0.548941, 0.056709, 0.068920},{0.558013, 0.063301, 0.073564},{
      0.563301, 0.058013, 0.073564},{0.556709, 0.048941, 0.068920}}],
    Polygon[{{0.558013, 0.063301, 0.073564},{0.567561, 0.070238, 0.076398},{
      0.570238, 0.067561, 0.076398},{0.563301, 0.058013, 0.073564}}],
    Polygon[{{0.570238, 0.067561, -0.076398},{0.563301, 0.058013, -0.073564},{
      0.569964, 0.054618, -0.073564},{0.573611, 0.065842, -0.076398}}],
    Polygon[{{0.563301, 0.058013, -0.073564},{0.556709, 0.048941, -0.068920},{
      0.566499, 0.043953, -0.068920},{0.569964, 0.054618, -0.073564}}],
    Polygon[{{0.556709, 0.048941, -0.068920},{0.550626, 0.040568, -0.062578},{
      0.563301, 0.034110, -0.062578},{0.566499, 0.043953, -0.068920}}],
    Polygon[{{0.550626, 0.040568, -0.062578},{0.545201, 0.033101, -0.054695},{
      0.560449, 0.025332, -0.054695},{0.563301, 0.034110, -0.062578}}],
    Polygon[{{0.545201, 0.033101, -0.054695},{0.540568, 0.026724, -0.045465},{
      0.558013, 0.017835, -0.045465},{0.560449, 0.025332, -0.054695}}],
    Polygon[{{0.540568, 0.026724, -0.045465},{0.536840, 0.021593, -0.035116},{
      0.556053, 0.011804, -0.035116},{0.558013, 0.017835, -0.045465}}],
    Polygon[{{0.536840, 0.021593, -0.035116},{0.534110, 0.017835, -0.023903},{
      0.554618, 0.007386, -0.023903},{0.556053, 0.011804, -0.035116}}],
    Polygon[{{0.534110, 0.017835, -0.023903},{0.532445, 0.015543, -0.012100},{
      0.553742, 0.004691, -0.012100},{0.554618, 0.007386, -0.023903}}],
    Polygon[{{0.532445, 0.015543, -0.012100},{0.531885, 0.014773, 0.000000},{
      0.553448, 0.003786, 0.000000},{0.553742, 0.004691, -0.012100}}],
    Polygon[{{0.531885, 0.014773, 0.000000},{0.532445, 0.015543, 0.012100},{
      0.553742, 0.004691, 0.012100},{0.553448, 0.003786, 0.000000}}],
    Polygon[{{0.532445, 0.015543, 0.012100},{0.534110, 0.017835, 0.023903},{
      0.554618, 0.007386, 0.023903},{0.553742, 0.004691, 0.012100}}],
    Polygon[{{0.534110, 0.017835, 0.023903},{0.536840, 0.021593, 0.035116},{
      0.556053, 0.011804, 0.035116},{0.554618, 0.007386, 0.023903}}],
    Polygon[{{0.536840, 0.021593, 0.035116},{0.540568, 0.026724, 0.045465},{
      0.558013, 0.017835, 0.045465},{0.556053, 0.011804, 0.035116}}],
    Polygon[{{0.540568, 0.026724, 0.045465},{0.545201, 0.033101, 0.054695},{
      0.560449, 0.025332, 0.054695},{0.558013, 0.017835, 0.045465}}],
    Polygon[{{0.545201, 0.033101, 0.054695},{0.550626, 0.040568, 0.062578},{
      0.563301, 0.034110, 0.062578},{0.560449, 0.025332, 0.054695}}],
    Polygon[{{0.550626, 0.040568, 0.062578},{0.556709, 0.048941, 0.068920},{
      0.566499, 0.043953, 0.068920},{0.563301, 0.034110, 0.062578}}],
    Polygon[{{0.556709, 0.048941, 0.068920},{0.563301, 0.058013, 0.073564},{
      0.569964, 0.054618, 0.073564},{0.566499, 0.043953, 0.068920}}],
    Polygon[{{0.563301, 0.058013, 0.073564},{0.570238, 0.067561, 0.076398},{
      0.573611, 0.065842, 0.076398},{0.569964, 0.054618, 0.073564}}],
    Polygon[{{0.573611, 0.065842, -0.076398},{0.569964, 0.054618, -0.073564},{
      0.577350, 0.053448, -0.073564},{0.577350, 0.065250, -0.076398}}],
    Polygon[{{0.569964, 0.054618, -0.073564},{0.566499, 0.043953, -0.068920},{
      0.577350, 0.042234, -0.068920},{0.577350, 0.053448, -0.073564}}],
    Polygon[{{0.566499, 0.043953, -0.068920},{0.563301, 0.034110, -0.062578},{
      0.577350, 0.031885, -0.062578},{0.577350, 0.042234, -0.068920}}],
    Polygon[{{0.563301, 0.034110, -0.062578},{0.560449, 0.025332, -0.054695},{
      0.577350, 0.022655, -0.054695},{0.577350, 0.031885, -0.062578}}],
    Polygon[{{0.560449, 0.025332, -0.054695},{0.558013, 0.017835, -0.045465},{
      0.577350, 0.014773, -0.045465},{0.577350, 0.022655, -0.054695}}],
    Polygon[{{0.558013, 0.017835, -0.045465},{0.556053, 0.011804, -0.035116},{
      0.577350, 0.008431, -0.035116},{0.577350, 0.014773, -0.045465}}],
    Polygon[{{0.556053, 0.011804, -0.035116},{0.554618, 0.007386, -0.023903},{
      0.577350, 0.003786, -0.023903},{0.577350, 0.008431, -0.035116}}],
    Polygon[{{0.554618, 0.007386, -0.023903},{0.553742, 0.004691, -0.012100},{
      0.577350, 0.000952, -0.012100},{0.577350, 0.003786, -0.023903}}],
    Polygon[{{0.553742, 0.004691, -0.012100},{0.553448, 0.003786, 0.000000},{
      0.577350, 0.000000, 0.000000},{0.577350, 0.000952, -0.012100}}],
    Polygon[{{0.553448, 0.003786, 0.000000},{0.553742, 0.004691, 0.012100},{
      0.577350, 0.000952, 0.012100},{0.577350, 0.000000, 0.000000}}],
    Polygon[{{0.553742, 0.004691, 0.012100},{0.554618, 0.007386, 0.023903},{
      0.577350, 0.003786, 0.023903},{0.577350, 0.000952, 0.012100}}],
    Polygon[{{0.554618, 0.007386, 0.023903},{0.556053, 0.011804, 0.035116},{
      0.577350, 0.008431, 0.035116},{0.577350, 0.003786, 0.023903}}],
    Polygon[{{0.556053, 0.011804, 0.035116},{0.558013, 0.017835, 0.045465},{
      0.577350, 0.014773, 0.045465},{0.577350, 0.008431, 0.035116}}],
    Polygon[{{0.558013, 0.017835, 0.045465},{0.560449, 0.025332, 0.054695},{
      0.577350, 0.022655, 0.054695},{0.577350, 0.014773, 0.045465}}],
    Polygon[{{0.560449, 0.025332, 0.054695},{0.563301, 0.034110, 0.062578},{
      0.577350, 0.031885, 0.062578},{0.577350, 0.022655, 0.054695}}],
    Polygon[{{0.563301, 0.034110, 0.062578},{0.566499, 0.043953, 0.068920},{
      0.577350, 0.042234, 0.068920},{0.577350, 0.031885, 0.062578}}],
    Polygon[{{0.566499, 0.043953, 0.068920},{0.569964, 0.054618, 0.073564},{
      0.577350, 0.053448, 0.073564},{0.577350, 0.042234, 0.068920}}],
    Polygon[{{0.569964, 0.054618, 0.073564},{0.573611, 0.065842, 0.076398},{
      0.577350, 0.065250, 0.076398},{0.577350, 0.053448, 0.073564}}],
    Polygon[{{0.577350, 0.065250, -0.076398},{0.577350, 0.053448, -0.073564},{
      0.584737, 0.054618, -0.073564},{0.581089, 0.065842, -0.076398}}],
    Polygon[{{0.577350, 0.053448, -0.073564},{0.577350, 0.042234, -0.068920},{
      0.588202, 0.043953, -0.068920},{0.584737, 0.054618, -0.073564}}],
    Polygon[{{0.577350, 0.042234, -0.068920},{0.577350, 0.031885, -0.062578},{
      0.591400, 0.034110, -0.062578},{0.588202, 0.043953, -0.068920}}],
    Polygon[{{0.577350, 0.031885, -0.062578},{0.577350, 0.022655, -0.054695},{
      0.594252, 0.025332, -0.054695},{0.591400, 0.034110, -0.062578}}],
    Polygon[{{0.577350, 0.022655, -0.054695},{0.577350, 0.014773, -0.045465},{
      0.596688, 0.017835, -0.045465},{0.594252, 0.025332, -0.054695}}],
    Polygon[{{0.577350, 0.014773, -0.045465},{0.577350, 0.008431, -0.035116},{
      0.598648, 0.011804, -0.035116},{0.596688, 0.017835, -0.045465}}],
    Polygon[{{0.577350, 0.008431, -0.035116},{0.577350, 0.003786, -0.023903},{
      0.600083, 0.007386, -0.023903},{0.598648, 0.011804, -0.035116}}],
    Polygon[{{0.577350, 0.003786, -0.023903},{0.577350, 0.000952, -0.012100},{
      0.600959, 0.004691, -0.012100},{0.600083, 0.007386, -0.023903}}],
    Polygon[{{0.577350, 0.000952, -0.012100},{0.577350, 0.000000, 0.000000},{
      0.601253, 0.003786, 0.000000},{0.600959, 0.004691, -0.012100}}],
    Polygon[{{0.577350, 0.000000, 0.000000},{0.577350, 0.000952, 0.012100},{
      0.600959, 0.004691, 0.012100},{0.601253, 0.003786, 0.000000}}],
    Polygon[{{0.577350, 0.000952, 0.012100},{0.577350, 0.003786, 0.023903},{
      0.600083, 0.007386, 0.023903},{0.600959, 0.004691, 0.012100}}],
    Polygon[{{0.577350, 0.003786, 0.023903},{0.577350, 0.008431, 0.035116},{
      0.598648, 0.011804, 0.035116},{0.600083, 0.007386, 0.023903}}],
    Polygon[{{0.577350, 0.008431, 0.035116},{0.577350, 0.014773, 0.045465},{
      0.596688, 0.017835, 0.045465},{0.598648, 0.011804, 0.035116}}],
    Polygon[{{0.577350, 0.014773, 0.045465},{0.577350, 0.022655, 0.054695},{
      0.594252, 0.025332, 0.054695},{0.596688, 0.017835, 0.045465}}],
    Polygon[{{0.577350, 0.022655, 0.054695},{0.577350, 0.031885, 0.062578},{
      0.591400, 0.034110, 0.062578},{0.594252, 0.025332, 0.054695}}],
    Polygon[{{0.577350, 0.031885, 0.062578},{0.577350, 0.042234, 0.068920},{
      0.588202, 0.043953, 0.068920},{0.591400, 0.034110, 0.062578}}],
    Polygon[{{0.577350, 0.042234, 0.068920},{0.577350, 0.053448, 0.073564},{
      0.584737, 0.054618, 0.073564},{0.588202, 0.043953, 0.068920}}],
    Polygon[{{0.577350, 0.053448, 0.073564},{0.577350, 0.065250, 0.076398},{
      0.581089, 0.065842, 0.076398},{0.584737, 0.054618, 0.073564}}],
    Polygon[{{0.581089, 0.065842, -0.076398},{0.584737, 0.054618, -0.073564},{
      0.591400, 0.058013, -0.073564},{0.584463, 0.067561, -0.076398}}],
    Polygon[{{0.584737, 0.054618, -0.073564},{0.588202, 0.043953, -0.068920},{
      0.597991, 0.048941, -0.068920},{0.591400, 0.058013, -0.073564}}],
    Polygon[{{0.588202, 0.043953, -0.068920},{0.591400, 0.034110, -0.062578},{
      0.604074, 0.040568, -0.062578},{0.597991, 0.048941, -0.068920}}],
    Polygon[{{0.591400, 0.034110, -0.062578},{0.594252, 0.025332, -0.054695},{
      0.609499, 0.033101, -0.054695},{0.604074, 0.040568, -0.062578}}],
    Polygon[{{0.594252, 0.025332, -0.054695},{0.596688, 0.017835, -0.045465},{
      0.614133, 0.026724, -0.045465},{0.609499, 0.033101, -0.054695}}],
    Polygon[{{0.596688, 0.017835, -0.045465},{0.598648, 0.011804, -0.035116},{
      0.617860, 0.021593, -0.035116},{0.614133, 0.026724, -0.045465}}],
    Polygon[{{0.598648, 0.011804, -0.035116},{0.600083, 0.007386, -0.023903},{
      0.620590, 0.017835, -0.023903},{0.617860, 0.021593, -0.035116}}],
    Polygon[{{0.600083, 0.007386, -0.023903},{0.600959, 0.004691, -0.012100},{
      0.622256, 0.015543, -0.012100},{0.620590, 0.017835, -0.023903}}],
    Polygon[{{0.600959, 0.004691, -0.012100},{0.601253, 0.003786, 0.000000},{
      0.622816, 0.014773, 0.000000},{0.622256, 0.015543, -0.012100}}],
    Polygon[{{0.601253, 0.003786, 0.000000},{0.600959, 0.004691, 0.012100},{
      0.622256, 0.015543, 0.012100},{0.622816, 0.014773, 0.000000}}],
    Polygon[{{0.600959, 0.004691, 0.012100},{0.600083, 0.007386, 0.023903},{
      0.620590, 0.017835, 0.023903},{0.622256, 0.015543, 0.012100}}],
    Polygon[{{0.600083, 0.007386, 0.023903},{0.598648, 0.011804, 0.035116},{
      0.617860, 0.021593, 0.035116},{0.620590, 0.017835, 0.023903}}],
    Polygon[{{0.598648, 0.011804, 0.035116},{0.596688, 0.017835, 0.045465},{
      0.614133, 0.026724, 0.045465},{0.617860, 0.021593, 0.035116}}],
    Polygon[{{0.596688, 0.017835, 0.045465},{0.594252, 0.025332, 0.054695},{
      0.609499, 0.033101, 0.054695},{0.614133, 0.026724, 0.045465}}],
    Polygon[{{0.594252, 0.025332, 0.054695},{0.591400, 0.034110, 0.062578},{
      0.604074, 0.040568, 0.062578},{0.609499, 0.033101, 0.054695}}],
    Polygon[{{0.591400, 0.034110, 0.062578},{0.588202, 0.043953, 0.068920},{
      0.597991, 0.048941, 0.068920},{0.604074, 0.040568, 0.062578}}],
    Polygon[{{0.588202, 0.043953, 0.068920},{0.584737, 0.054618, 0.073564},{
      0.591400, 0.058013, 0.073564},{0.597991, 0.048941, 0.068920}}],
    Polygon[{{0.584737, 0.054618, 0.073564},{0.581089, 0.065842, 0.076398},{
      0.584463, 0.067561, 0.076398},{0.591400, 0.058013, 0.073564}}],
    Polygon[{{0.584463, 0.067561, -0.076398},{0.591400, 0.058013, -0.073564},{
      0.596688, 0.063301, -0.073564},{0.587140, 0.070238, -0.076398}}],
    Polygon[{{0.591400, 0.058013, -0.073564},{0.597991, 0.048941, -0.068920},{
      0.605760, 0.056709, -0.068920},{0.596688, 0.063301, -0.073564}}],
    Polygon[{{0.597991, 0.048941, -0.068920},{0.604074, 0.040568, -0.062578},{
      0.614133, 0.050626, -0.062578},{0.605760, 0.056709, -0.068920}}],
    Polygon[{{0.604074, 0.040568, -0.062578},{0.609499, 0.033101, -0.054695},{
      0.621599, 0.045201, -0.054695},{0.614133, 0.050626, -0.062578}}],
    Polygon[{{0.609499, 0.033101, -0.054695},{0.614133, 0.026724, -0.045465},{
      0.627977, 0.040568, -0.045465},{0.621599, 0.045201, -0.054695}}],
    Polygon[{{0.614133, 0.026724, -0.045465},{0.617860, 0.021593, -0.035116},{
      0.633107, 0.036840, -0.035116},{0.627977, 0.040568, -0.045465}}],
    Polygon[{{0.617860, 0.021593, -0.035116},{0.620590, 0.017835, -0.023903},{
      0.636865, 0.034110, -0.023903},{0.633107, 0.036840, -0.035116}}],
    Polygon[{{0.620590, 0.017835, -0.023903},{0.622256, 0.015543, -0.012100},{
      0.639158, 0.032445, -0.012100},{0.636865, 0.034110, -0.023903}}],
    Polygon[{{0.622256, 0.015543, -0.012100},{0.622816, 0.014773, 0.000000},{
      0.639928, 0.031885, 0.000000},{0.639158, 0.032445, -0.012100}}],
    Polygon[{{0.622816, 0.014773, 0.000000},{0.622256, 0.015543, 0.012100},{
      0.639158, 0.032445, 0.012100},{0.639928, 0.031885, 0.000000}}],
    Polygon[{{0.622256, 0.015543, 0.012100},{0.620590, 0.017835, 0.023903},{
      0.636865, 0.034110, 0.023903},{0.639158, 0.032445, 0.012100}}],
    Polygon[{{0.620590, 0.017835, 0.023903},{0.617860, 0.021593, 0.035116},{
      0.633107, 0.036840, 0.035116},{0.636865, 0.034110, 0.023903}}],
    Polygon[{{0.617860, 0.021593, 0.035116},{0.614133, 0.026724, 0.045465},{
      0.627977, 0.040568, 0.045465},{0.633107, 0.036840, 0.035116}}],
    Polygon[{{0.614133, 0.026724, 0.045465},{0.609499, 0.033101, 0.054695},{
      0.621599, 0.045201, 0.054695},{0.627977, 0.040568, 0.045465}}],
    Polygon[{{0.609499, 0.033101, 0.054695},{0.604074, 0.040568, 0.062578},{
      0.614133, 0.050626, 0.062578},{0.621599, 0.045201, 0.054695}}],
    Polygon[{{0.604074, 0.040568, 0.062578},{0.597991, 0.048941, 0.068920},{
      0.605760, 0.056709, 0.068920},{0.614133, 0.050626, 0.062578}}],
    Polygon[{{0.597991, 0.048941, 0.068920},{0.591400, 0.058013, 0.073564},{
      0.596688, 0.063301, 0.073564},{0.605760, 0.056709, 0.068920}}],
    Polygon[{{0.591400, 0.058013, 0.073564},{0.584463, 0.067561, 0.076398},{
      0.587140, 0.070238, 0.076398},{0.596688, 0.063301, 0.073564}}],
    Polygon[{{0.587140, 0.070238, -0.076398},{0.596688, 0.063301, -0.073564},{
      0.600083, 0.069964, -0.073564},{0.588858, 0.073611, -0.076398}}],
    Polygon[{{0.596688, 0.063301, -0.073564},{0.605760, 0.056709, -0.068920},{
      0.610748, 0.066499, -0.068920},{0.600083, 0.069964, -0.073564}}],
    Polygon[{{0.605760, 0.056709, -0.068920},{0.614133, 0.050626, -0.062578},{
      0.620590, 0.063301, -0.062578},{0.610748, 0.066499, -0.068920}}],
    Polygon[{{0.614133, 0.050626, -0.062578},{0.621599, 0.045201, -0.054695},{
      0.629368, 0.060449, -0.054695},{0.620590, 0.063301, -0.062578}}],
    Polygon[{{0.621599, 0.045201, -0.054695},{0.627977, 0.040568, -0.045465},{
      0.636865, 0.058013, -0.045465},{0.629368, 0.060449, -0.054695}}],
    Polygon[{{0.627977, 0.040568, -0.045465},{0.633107, 0.036840, -0.035116},{
      0.642897, 0.056053, -0.035116},{0.636865, 0.058013, -0.045465}}],
    Polygon[{{0.633107, 0.036840, -0.035116},{0.636865, 0.034110, -0.023903},{
      0.647314, 0.054618, -0.023903},{0.642897, 0.056053, -0.035116}}],
    Polygon[{{0.636865, 0.034110, -0.023903},{0.639158, 0.032445, -0.012100},{
      0.650009, 0.053742, -0.012100},{0.647314, 0.054618, -0.023903}}],
    Polygon[{{0.639158, 0.032445, -0.012100},{0.639928, 0.031885, 0.000000},{
      0.650915, 0.053448, 0.000000},{0.650009, 0.053742, -0.012100}}],
    Polygon[{{0.639928, 0.031885, 0.000000},{0.639158, 0.032445, 0.012100},{
      0.650009, 0.053742, 0.012100},{0.650915, 0.053448, 0.000000}}],
    Polygon[{{0.639158, 0.032445, 0.012100},{0.636865, 0.034110, 0.023903},{
      0.647314, 0.054618, 0.023903},{0.650009, 0.053742, 0.012100}}],
    Polygon[{{0.636865, 0.034110, 0.023903},{0.633107, 0.036840, 0.035116},{
      0.642897, 0.056053, 0.035116},{0.647314, 0.054618, 0.023903}}],
    Polygon[{{0.633107, 0.036840, 0.035116},{0.627977, 0.040568, 0.045465},{
      0.636865, 0.058013, 0.045465},{0.642897, 0.056053, 0.035116}}],
    Polygon[{{0.627977, 0.040568, 0.045465},{0.621599, 0.045201, 0.054695},{
      0.629368, 0.060449, 0.054695},{0.636865, 0.058013, 0.045465}}],
    Polygon[{{0.621599, 0.045201, 0.054695},{0.614133, 0.050626, 0.062578},{
      0.620590, 0.063301, 0.062578},{0.629368, 0.060449, 0.054695}}],
    Polygon[{{0.614133, 0.050626, 0.062578},{0.605760, 0.056709, 0.068920},{
      0.610748, 0.066499, 0.068920},{0.620590, 0.063301, 0.062578}}],
    Polygon[{{0.605760, 0.056709, 0.068920},{0.596688, 0.063301, 0.073564},{
      0.600083, 0.069964, 0.073564},{0.610748, 0.066499, 0.068920}}],
    Polygon[{{0.596688, 0.063301, 0.073564},{0.587140, 0.070238, 0.076398},{
      0.588858, 0.073611, 0.076398},{0.600083, 0.069964, 0.073564}}],
    Polygon[{{0.588858, 0.073611, -0.076398},{0.600083, 0.069964, -0.073564},{
      0.601253, 0.077350, -0.073564},{0.589451, 0.077350, -0.076398}}],
    Polygon[{{0.600083, 0.069964, -0.073564},{0.610748, 0.066499, -0.068920},{
      0.612467, 0.077350, -0.068920},{0.601253, 0.077350, -0.073564}}],
    Polygon[{{0.610748, 0.066499, -0.068920},{0.620590, 0.063301, -0.062578},{
      0.622816, 0.077350, -0.062578},{0.612467, 0.077350, -0.068920}}],
    Polygon[{{0.620590, 0.063301, -0.062578},{0.629368, 0.060449, -0.054695},{
      0.632045, 0.077350, -0.054695},{0.622816, 0.077350, -0.062578}}],
    Polygon[{{0.629368, 0.060449, -0.054695},{0.636865, 0.058013, -0.045465},{
      0.639928, 0.077350, -0.045465},{0.632045, 0.077350, -0.054695}}],
    Polygon[{{0.636865, 0.058013, -0.045465},{0.642897, 0.056053, -0.035116},{
      0.646270, 0.077350, -0.035116},{0.639928, 0.077350, -0.045465}}],
    Polygon[{{0.642897, 0.056053, -0.035116},{0.647314, 0.054618, -0.023903},{
      0.650915, 0.077350, -0.023903},{0.646270, 0.077350, -0.035116}}],
    Polygon[{{0.647314, 0.054618, -0.023903},{0.650009, 0.053742, -0.012100},{
      0.653748, 0.077350, -0.012100},{0.650915, 0.077350, -0.023903}}],
    Polygon[{{0.650009, 0.053742, -0.012100},{0.650915, 0.053448, 0.000000},{
      0.654701, 0.077350, 0.000000},{0.653748, 0.077350, -0.012100}}],
    Polygon[{{0.650915, 0.053448, 0.000000},{0.650009, 0.053742, 0.012100},{
      0.653748, 0.077350, 0.012100},{0.654701, 0.077350, 0.000000}}],
    Polygon[{{0.650009, 0.053742, 0.012100},{0.647314, 0.054618, 0.023903},{
      0.650915, 0.077350, 0.023903},{0.653748, 0.077350, 0.012100}}],
    Polygon[{{0.647314, 0.054618, 0.023903},{0.642897, 0.056053, 0.035116},{
      0.646270, 0.077350, 0.035116},{0.650915, 0.077350, 0.023903}}],
    Polygon[{{0.642897, 0.056053, 0.035116},{0.636865, 0.058013, 0.045465},{
      0.639928, 0.077350, 0.045465},{0.646270, 0.077350, 0.035116}}],
    Polygon[{{0.636865, 0.058013, 0.045465},{0.629368, 0.060449, 0.054695},{
      0.632045, 0.077350, 0.054695},{0.639928, 0.077350, 0.045465}}],
    Polygon[{{0.629368, 0.060449, 0.054695},{0.620590, 0.063301, 0.062578},{
      0.622816, 0.077350, 0.062578},{0.632045, 0.077350, 0.054695}}],
    Polygon[{{0.620590, 0.063301, 0.062578},{0.610748, 0.066499, 0.068920},{
      0.612467, 0.077350, 0.068920},{0.622816, 0.077350, 0.062578}}],
    Polygon[{{0.610748, 0.066499, 0.068920},{0.600083, 0.069964, 0.073564},{
      0.601253, 0.077350, 0.073564},{0.612467, 0.077350, 0.068920}}],
    Polygon[{{0.600083, 0.069964, 0.073564},{0.588858, 0.073611, 0.076398},{
      0.589451, 0.077350, 0.076398},{0.601253, 0.077350, 0.073564}}],
    Polygon[{{0.697083, 0.041452, -0.040942},{0.703408, 0.041452, -0.039423},{
      0.702781, 0.045410, -0.039423},{0.696766, 0.043456, -0.040942}}],
    Polygon[{{0.703408, 0.041452, -0.039423},{0.709418, 0.041452, -0.036934},{
      0.708497, 0.047267, -0.036934},{0.702781, 0.045410, -0.039423}}],
    Polygon[{{0.709418, 0.041452, -0.036934},{0.714964, 0.041452, -0.033535},{
      0.713771, 0.048981, -0.033535},{0.708497, 0.047267, -0.036934}}],
    Polygon[{{0.714964, 0.041452, -0.033535},{0.719910, 0.041452, -0.029311},{
      0.718475, 0.050509, -0.029311},{0.713771, 0.048981, -0.033535}}],
    Polygon[{{0.719910, 0.041452, -0.029311},{0.724134, 0.041452, -0.024365},{
      0.722493, 0.051815, -0.024365},{0.718475, 0.050509, -0.029311}}],
    Polygon[{{0.724134, 0.041452, -0.024365},{0.727533, 0.041452, -0.018819},{
      0.725725, 0.052865, -0.018819},{0.722493, 0.051815, -0.024365}}],
    Polygon[{{0.727533, 0.041452, -0.018819},{0.730022, 0.041452, -0.012809},{
      0.728092, 0.053634, -0.012809},{0.725725, 0.052865, -0.018819}}],
    Polygon[{{0.730022, 0.041452, -0.012809},{0.731540, 0.041452, -0.006485},{
      0.729537, 0.054104, -0.006485},{0.728092, 0.053634, -0.012809}}],
    Polygon[{{0.731540, 0.041452, -0.006485},{0.732051, 0.041452, 0.000000},{
      0.730022, 0.054261, 0.000000},{0.729537, 0.054104, -0.006485}}],
    Polygon[{{0.732051, 0.041452, 0.000000},{0.731540, 0.041452, 0.006485},{
      0.729537, 0.054104, 0.006485},{0.730022, 0.054261, 0.000000}}],
    Polygon[{{0.731540, 0.041452, 0.006485},{0.730022, 0.041452, 0.012809},{
      0.728092, 0.053634, 0.012809},{0.729537, 0.054104, 0.006485}}],
    Polygon[{{0.730022, 0.041452, 0.012809},{0.727533, 0.041452, 0.018819},{
      0.725725, 0.052865, 0.018819},{0.728092, 0.053634, 0.012809}}],
    Polygon[{{0.727533, 0.041452, 0.018819},{0.724134, 0.041452, 0.024365},{
      0.722493, 0.051815, 0.024365},{0.725725, 0.052865, 0.018819}}],
    Polygon[{{0.724134, 0.041452, 0.024365},{0.719910, 0.041452, 0.029311},{
      0.718475, 0.050509, 0.029311},{0.722493, 0.051815, 0.024365}}],
    Polygon[{{0.719910, 0.041452, 0.029311},{0.714964, 0.041452, 0.033535},{
      0.713771, 0.048981, 0.033535},{0.718475, 0.050509, 0.029311}}],
    Polygon[{{0.714964, 0.041452, 0.033535},{0.709418, 0.041452, 0.036934},{
      0.708497, 0.047267, 0.036934},{0.713771, 0.048981, 0.033535}}],
    Polygon[{{0.709418, 0.041452, 0.036934},{0.703408, 0.041452, 0.039423},{
      0.702781, 0.045410, 0.039423},{0.708497, 0.047267, 0.036934}}],
    Polygon[{{0.703408, 0.041452, 0.039423},{0.697083, 0.041452, 0.040942},{
      0.696766, 0.043456, 0.040942},{0.702781, 0.045410, 0.039423}}],
    Polygon[{{0.696766, 0.043456, -0.040942},{0.702781, 0.045410, -0.039423},{
      0.700962, 0.048981, -0.039423},{0.695845, 0.045263, -0.040942}}],
    Polygon[{{0.702781, 0.045410, -0.039423},{0.708497, 0.047267, -0.036934},{
      0.705824, 0.052513, -0.036934},{0.700962, 0.048981, -0.039423}}],
    Polygon[{{0.708497, 0.047267, -0.036934},{0.713771, 0.048981, -0.033535},{
      0.710310, 0.055773, -0.033535},{0.705824, 0.052513, -0.036934}}],
    Polygon[{{0.713771, 0.048981, -0.033535},{0.718475, 0.050509, -0.029311},{
      0.714312, 0.058680, -0.029311},{0.710310, 0.055773, -0.033535}}],
    Polygon[{{0.718475, 0.050509, -0.029311},{0.722493, 0.051815, -0.024365},{
      0.717730, 0.061163, -0.024365},{0.714312, 0.058680, -0.029311}}],
    Polygon[{{0.722493, 0.051815, -0.024365},{0.725725, 0.052865, -0.018819},{
      0.720479, 0.063161, -0.018819},{0.717730, 0.061163, -0.024365}}],
    Polygon[{{0.725725, 0.052865, -0.018819},{0.728092, 0.053634, -0.012809},{
      0.722493, 0.064624, -0.012809},{0.720479, 0.063161, -0.018819}}],
    Polygon[{{0.728092, 0.053634, -0.012809},{0.729537, 0.054104, -0.006485},{
      0.723721, 0.065517, -0.006485},{0.722493, 0.064624, -0.012809}}],
    Polygon[{{0.729537, 0.054104, -0.006485},{0.730022, 0.054261, 0.000000},{
      0.724134, 0.065817, 0.000000},{0.723721, 0.065517, -0.006485}}],
    Polygon[{{0.730022, 0.054261, 0.000000},{0.729537, 0.054104, 0.006485},{
      0.723721, 0.065517, 0.006485},{0.724134, 0.065817, 0.000000}}],
    Polygon[{{0.729537, 0.054104, 0.006485},{0.728092, 0.053634, 0.012809},{
      0.722493, 0.064624, 0.012809},{0.723721, 0.065517, 0.006485}}],
    Polygon[{{0.728092, 0.053634, 0.012809},{0.725725, 0.052865, 0.018819},{
      0.720479, 0.063161, 0.018819},{0.722493, 0.064624, 0.012809}}],
    Polygon[{{0.725725, 0.052865, 0.018819},{0.722493, 0.051815, 0.024365},{
      0.717730, 0.061163, 0.024365},{0.720479, 0.063161, 0.018819}}],
    Polygon[{{0.722493, 0.051815, 0.024365},{0.718475, 0.050509, 0.029311},{
      0.714312, 0.058680, 0.029311},{0.717730, 0.061163, 0.024365}}],
    Polygon[{{0.718475, 0.050509, 0.029311},{0.713771, 0.048981, 0.033535},{
      0.710310, 0.055773, 0.033535},{0.714312, 0.058680, 0.029311}}],
    Polygon[{{0.713771, 0.048981, 0.033535},{0.708497, 0.047267, 0.036934},{
      0.705824, 0.052513, 0.036934},{0.710310, 0.055773, 0.033535}}],
    Polygon[{{0.708497, 0.047267, 0.036934},{0.702781, 0.045410, 0.039423},{
      0.700962, 0.048981, 0.039423},{0.705824, 0.052513, 0.036934}}],
    Polygon[{{0.702781, 0.045410, 0.039423},{0.696766, 0.043456, 0.040942},{
      0.695845, 0.045263, 0.040942},{0.700962, 0.048981, 0.039423}}],
    Polygon[{{0.695845, 0.045263, -0.040942},{0.700962, 0.048981, -0.039423},{
      0.698128, 0.051815, -0.039423},{0.694410, 0.046698, -0.040942}}],
    Polygon[{{0.700962, 0.048981, -0.039423},{0.705824, 0.052513, -0.036934},{
      0.701660, 0.056677, -0.036934},{0.698128, 0.051815, -0.039423}}],
    Polygon[{{0.705824, 0.052513, -0.036934},{0.710310, 0.055773, -0.033535},{
      0.704920, 0.061163, -0.033535},{0.701660, 0.056677, -0.036934}}],
    Polygon[{{0.710310, 0.055773, -0.033535},{0.714312, 0.058680, -0.029311},{
      0.707827, 0.065165, -0.029311},{0.704920, 0.061163, -0.033535}}],
    Polygon[{{0.714312, 0.058680, -0.029311},{0.717730, 0.061163, -0.024365},{
      0.710310, 0.068582, -0.024365},{0.707827, 0.065165, -0.029311}}],
    Polygon[{{0.717730, 0.061163, -0.024365},{0.720479, 0.063161, -0.018819},{
      0.712308, 0.071332, -0.018819},{0.710310, 0.068582, -0.024365}}],
    Polygon[{{0.720479, 0.063161, -0.018819},{0.722493, 0.064624, -0.012809},{
      0.713771, 0.073346, -0.012809},{0.712308, 0.071332, -0.018819}}],
    Polygon[{{0.722493, 0.064624, -0.012809},{0.723721, 0.065517, -0.006485},{
      0.714664, 0.074574, -0.006485},{0.713771, 0.073346, -0.012809}}],
    Polygon[{{0.723721, 0.065517, -0.006485},{0.724134, 0.065817, 0.000000},{
      0.714964, 0.074987, 0.000000},{0.714664, 0.074574, -0.006485}}],
    Polygon[{{0.724134, 0.065817, 0.000000},{0.723721, 0.065517, 0.006485},{
      0.714664, 0.074574, 0.006485},{0.714964, 0.074987, 0.000000}}],
    Polygon[{{0.723721, 0.065517, 0.006485},{0.722493, 0.064624, 0.012809},{
      0.713771, 0.073346, 0.012809},{0.714664, 0.074574, 0.006485}}],
    Polygon[{{0.722493, 0.064624, 0.012809},{0.720479, 0.063161, 0.018819},{
      0.712308, 0.071332, 0.018819},{0.713771, 0.073346, 0.012809}}],
    Polygon[{{0.720479, 0.063161, 0.018819},{0.717730, 0.061163, 0.024365},{
      0.710310, 0.068582, 0.024365},{0.712308, 0.071332, 0.018819}}],
    Polygon[{{0.717730, 0.061163, 0.024365},{0.714312, 0.058680, 0.029311},{
      0.707827, 0.065165, 0.029311},{0.710310, 0.068582, 0.024365}}],
    Polygon[{{0.714312, 0.058680, 0.029311},{0.710310, 0.055773, 0.033535},{
      0.704920, 0.061163, 0.033535},{0.707827, 0.065165, 0.029311}}],
    Polygon[{{0.710310, 0.055773, 0.033535},{0.705824, 0.052513, 0.036934},{
      0.701660, 0.056677, 0.036934},{0.704920, 0.061163, 0.033535}}],
    Polygon[{{0.705824, 0.052513, 0.036934},{0.700962, 0.048981, 0.039423},{
      0.698128, 0.051815, 0.039423},{0.701660, 0.056677, 0.036934}}],
    Polygon[{{0.700962, 0.048981, 0.039423},{0.695845, 0.045263, 0.040942},{
      0.694410, 0.046698, 0.040942},{0.698128, 0.051815, 0.039423}}],
    Polygon[{{0.694410, 0.046698, -0.040942},{0.698128, 0.051815, -0.039423},{
      0.694557, 0.053634, -0.039423},{0.692603, 0.047619, -0.040942}}],
    Polygon[{{0.698128, 0.051815, -0.039423},{0.701660, 0.056677, -0.036934},{
      0.696414, 0.059350, -0.036934},{0.694557, 0.053634, -0.039423}}],
    Polygon[{{0.701660, 0.056677, -0.036934},{0.704920, 0.061163, -0.033535},{
      0.698128, 0.064624, -0.033535},{0.696414, 0.059350, -0.036934}}],
    Polygon[{{0.704920, 0.061163, -0.033535},{0.707827, 0.065165, -0.029311},{
      0.699656, 0.069328, -0.029311},{0.698128, 0.064624, -0.033535}}],
    Polygon[{{0.707827, 0.065165, -0.029311},{0.710310, 0.068582, -0.024365},{
      0.700962, 0.073346, -0.024365},{0.699656, 0.069328, -0.029311}}],
    Polygon[{{0.710310, 0.068582, -0.024365},{0.712308, 0.071332, -0.018819},{
      0.702012, 0.076578, -0.018819},{0.700962, 0.073346, -0.024365}}],
    Polygon[{{0.712308, 0.071332, -0.018819},{0.713771, 0.073346, -0.012809},{
      0.702781, 0.078945, -0.012809},{0.702012, 0.076578, -0.018819}}],
    Polygon[{{0.713771, 0.073346, -0.012809},{0.714664, 0.074574, -0.006485},{
      0.703251, 0.080390, -0.006485},{0.702781, 0.078945, -0.012809}}],
    Polygon[{{0.714664, 0.074574, -0.006485},{0.714964, 0.074987, 0.000000},{
      0.703408, 0.080875, 0.000000},{0.703251, 0.080390, -0.006485}}],
    Polygon[{{0.714964, 0.074987, 0.000000},{0.714664, 0.074574, 0.006485},{
      0.703251, 0.080390, 0.006485},{0.703408, 0.080875, 0.000000}}],
    Polygon[{{0.714664, 0.074574, 0.006485},{0.713771, 0.073346, 0.012809},{
      0.702781, 0.078945, 0.012809},{0.703251, 0.080390, 0.006485}}],
    Polygon[{{0.713771, 0.073346, 0.012809},{0.712308, 0.071332, 0.018819},{
      0.702012, 0.076578, 0.018819},{0.702781, 0.078945, 0.012809}}],
    Polygon[{{0.712308, 0.071332, 0.018819},{0.710310, 0.068582, 0.024365},{
      0.700962, 0.073346, 0.024365},{0.702012, 0.076578, 0.018819}}],
    Polygon[{{0.710310, 0.068582, 0.024365},{0.707827, 0.065165, 0.029311},{
      0.699656, 0.069328, 0.029311},{0.700962, 0.073346, 0.024365}}],
    Polygon[{{0.707827, 0.065165, 0.029311},{0.704920, 0.061163, 0.033535},{
      0.698128, 0.064624, 0.033535},{0.699656, 0.069328, 0.029311}}],
    Polygon[{{0.704920, 0.061163, 0.033535},{0.701660, 0.056677, 0.036934},{
      0.696414, 0.059350, 0.036934},{0.698128, 0.064624, 0.033535}}],
    Polygon[{{0.701660, 0.056677, 0.036934},{0.698128, 0.051815, 0.039423},{
      0.694557, 0.053634, 0.039423},{0.696414, 0.059350, 0.036934}}],
    Polygon[{{0.698128, 0.051815, 0.039423},{0.694410, 0.046698, 0.040942},{
      0.692603, 0.047619, 0.040942},{0.694557, 0.053634, 0.039423}}],
    Polygon[{{0.692603, 0.047619, -0.040942},{0.694557, 0.053634, -0.039423},{
      0.690599, 0.054261, -0.039423},{0.690599, 0.047936, -0.040942}}],
    Polygon[{{0.694557, 0.053634, -0.039423},{0.696414, 0.059350, -0.036934},{
      0.690599, 0.060271, -0.036934},{0.690599, 0.054261, -0.039423}}],
    Polygon[{{0.696414, 0.059350, -0.036934},{0.698128, 0.064624, -0.033535},{
      0.690599, 0.065817, -0.033535},{0.690599, 0.060271, -0.036934}}],
    Polygon[{{0.698128, 0.064624, -0.033535},{0.699656, 0.069328, -0.029311},{
      0.690599, 0.070763, -0.029311},{0.690599, 0.065817, -0.033535}}],
    Polygon[{{0.699656, 0.069328, -0.029311},{0.700962, 0.073346, -0.024365},{
      0.690599, 0.074987, -0.024365},{0.690599, 0.070763, -0.029311}}],
    Polygon[{{0.700962, 0.073346, -0.024365},{0.702012, 0.076578, -0.018819},{
      0.690599, 0.078386, -0.018819},{0.690599, 0.074987, -0.024365}}],
    Polygon[{{0.702012, 0.076578, -0.018819},{0.702781, 0.078945, -0.012809},{
      0.690599, 0.080875, -0.012809},{0.690599, 0.078386, -0.018819}}],
    Polygon[{{0.702781, 0.078945, -0.012809},{0.703251, 0.080390, -0.006485},{
      0.690599, 0.082393, -0.006485},{0.690599, 0.080875, -0.012809}}],
    Polygon[{{0.703251, 0.080390, -0.006485},{0.703408, 0.080875, 0.000000},{
      0.690599, 0.082904, 0.000000},{0.690599, 0.082393, -0.006485}}],
    Polygon[{{0.703408, 0.080875, 0.000000},{0.703251, 0.080390, 0.006485},{
      0.690599, 0.082393, 0.006485},{0.690599, 0.082904, 0.000000}}],
    Polygon[{{0.703251, 0.080390, 0.006485},{0.702781, 0.078945, 0.012809},{
      0.690599, 0.080875, 0.012809},{0.690599, 0.082393, 0.006485}}],
    Polygon[{{0.702781, 0.078945, 0.012809},{0.702012, 0.076578, 0.018819},{
      0.690599, 0.078386, 0.018819},{0.690599, 0.080875, 0.012809}}],
    Polygon[{{0.702012, 0.076578, 0.018819},{0.700962, 0.073346, 0.024365},{
      0.690599, 0.074987, 0.024365},{0.690599, 0.078386, 0.018819}}],
    Polygon[{{0.700962, 0.073346, 0.024365},{0.699656, 0.069328, 0.029311},{
      0.690599, 0.070763, 0.029311},{0.690599, 0.074987, 0.024365}}],
    Polygon[{{0.699656, 0.069328, 0.029311},{0.698128, 0.064624, 0.033535},{
      0.690599, 0.065817, 0.033535},{0.690599, 0.070763, 0.029311}}],
    Polygon[{{0.698128, 0.064624, 0.033535},{0.696414, 0.059350, 0.036934},{
      0.690599, 0.060271, 0.036934},{0.690599, 0.065817, 0.033535}}],
    Polygon[{{0.696414, 0.059350, 0.036934},{0.694557, 0.053634, 0.039423},{
      0.690599, 0.054261, 0.039423},{0.690599, 0.060271, 0.036934}}],
    Polygon[{{0.694557, 0.053634, 0.039423},{0.692603, 0.047619, 0.040942},{
      0.690599, 0.047936, 0.040942},{0.690599, 0.054261, 0.039423}}],
    Polygon[{{0.690599, 0.047936, -0.040942},{0.690599, 0.054261, -0.039423},{
      0.686641, 0.053634, -0.039423},{0.688595, 0.047619, -0.040942}}],
    Polygon[{{0.690599, 0.054261, -0.039423},{0.690599, 0.060271, -0.036934},{
      0.684784, 0.059350, -0.036934},{0.686641, 0.053634, -0.039423}}],
    Polygon[{{0.690599, 0.060271, -0.036934},{0.690599, 0.065817, -0.033535},{
      0.683070, 0.064624, -0.033535},{0.684784, 0.059350, -0.036934}}],
    Polygon[{{0.690599, 0.065817, -0.033535},{0.690599, 0.070763, -0.029311},{
      0.681541, 0.069328, -0.029311},{0.683070, 0.064624, -0.033535}}],
    Polygon[{{0.690599, 0.070763, -0.029311},{0.690599, 0.074987, -0.024365},{
      0.680236, 0.073346, -0.024365},{0.681541, 0.069328, -0.029311}}],
    Polygon[{{0.690599, 0.074987, -0.024365},{0.690599, 0.078386, -0.018819},{
      0.679186, 0.076578, -0.018819},{0.680236, 0.073346, -0.024365}}],
    Polygon[{{0.690599, 0.078386, -0.018819},{0.690599, 0.080875, -0.012809},{
      0.678416, 0.078945, -0.012809},{0.679186, 0.076578, -0.018819}}],
    Polygon[{{0.690599, 0.080875, -0.012809},{0.690599, 0.082393, -0.006485},{
      0.677947, 0.080390, -0.006485},{0.678416, 0.078945, -0.012809}}],
    Polygon[{{0.690599, 0.082393, -0.006485},{0.690599, 0.082904, 0.000000},{
      0.677790, 0.080875, 0.000000},{0.677947, 0.080390, -0.006485}}],
    Polygon[{{0.690599, 0.082904, 0.000000},{0.690599, 0.082393, 0.006485},{
      0.677947, 0.080390, 0.006485},{0.677790, 0.080875, 0.000000}}],
    Polygon[{{0.690599, 0.082393, 0.006485},{0.690599, 0.080875, 0.012809},{
      0.678416, 0.078945, 0.012809},{0.677947, 0.080390, 0.006485}}],
    Polygon[{{0.690599, 0.080875, 0.012809},{0.690599, 0.078386, 0.018819},{
      0.679186, 0.076578, 0.018819},{0.678416, 0.078945, 0.012809}}],
    Polygon[{{0.690599, 0.078386, 0.018819},{0.690599, 0.074987, 0.024365},{
      0.680236, 0.073346, 0.024365},{0.679186, 0.076578, 0.018819}}],
    Polygon[{{0.690599, 0.074987, 0.024365},{0.690599, 0.070763, 0.029311},{
      0.681541, 0.069328, 0.029311},{0.680236, 0.073346, 0.024365}}],
    Polygon[{{0.690599, 0.070763, 0.029311},{0.690599, 0.065817, 0.033535},{
      0.683070, 0.064624, 0.033535},{0.681541, 0.069328, 0.029311}}],
    Polygon[{{0.690599, 0.065817, 0.033535},{0.690599, 0.060271, 0.036934},{
      0.684784, 0.059350, 0.036934},{0.683070, 0.064624, 0.033535}}],
    Polygon[{{0.690599, 0.060271, 0.036934},{0.690599, 0.054261, 0.039423},{
      0.686641, 0.053634, 0.039423},{0.684784, 0.059350, 0.036934}}],
    Polygon[{{0.690599, 0.054261, 0.039423},{0.690599, 0.047936, 0.040942},{
      0.688595, 0.047619, 0.040942},{0.686641, 0.053634, 0.039423}}],
    Polygon[{{0.688595, 0.047619, -0.040942},{0.686641, 0.053634, -0.039423},{
      0.683070, 0.051815, -0.039423},{0.686787, 0.046698, -0.040942}}],
    Polygon[{{0.686641, 0.053634, -0.039423},{0.684784, 0.059350, -0.036934},{
      0.679538, 0.056677, -0.036934},{0.683070, 0.051815, -0.039423}}],
    Polygon[{{0.684784, 0.059350, -0.036934},{0.683070, 0.064624, -0.033535},{
      0.676278, 0.061163, -0.033535},{0.679538, 0.056677, -0.036934}}],
    Polygon[{{0.683070, 0.064624, -0.033535},{0.681541, 0.069328, -0.029311},{
      0.673370, 0.065165, -0.029311},{0.676278, 0.061163, -0.033535}}],
    Polygon[{{0.681541, 0.069328, -0.029311},{0.680236, 0.073346, -0.024365},{
      0.670887, 0.068582, -0.024365},{0.673370, 0.065165, -0.029311}}],
    Polygon[{{0.680236, 0.073346, -0.024365},{0.679186, 0.076578, -0.018819},{
      0.668890, 0.071332, -0.018819},{0.670887, 0.068582, -0.024365}}],
    Polygon[{{0.679186, 0.076578, -0.018819},{0.678416, 0.078945, -0.012809},{
      0.667427, 0.073346, -0.012809},{0.668890, 0.071332, -0.018819}}],
    Polygon[{{0.678416, 0.078945, -0.012809},{0.677947, 0.080390, -0.006485},{
      0.666534, 0.074574, -0.006485},{0.667427, 0.073346, -0.012809}}],
    Polygon[{{0.677947, 0.080390, -0.006485},{0.677790, 0.080875, 0.000000},{
      0.666234, 0.074987, 0.000000},{0.666534, 0.074574, -0.006485}}],
    Polygon[{{0.677790, 0.080875, 0.000000},{0.677947, 0.080390, 0.006485},{
      0.666534, 0.074574, 0.006485},{0.666234, 0.074987, 0.000000}}],
    Polygon[{{0.677947, 0.080390, 0.006485},{0.678416, 0.078945, 0.012809},{
      0.667427, 0.073346, 0.012809},{0.666534, 0.074574, 0.006485}}],
    Polygon[{{0.678416, 0.078945, 0.012809},{0.679186, 0.076578, 0.018819},{
      0.668890, 0.071332, 0.018819},{0.667427, 0.073346, 0.012809}}],
    Polygon[{{0.679186, 0.076578, 0.018819},{0.680236, 0.073346, 0.024365},{
      0.670887, 0.068582, 0.024365},{0.668890, 0.071332, 0.018819}}],
    Polygon[{{0.680236, 0.073346, 0.024365},{0.681541, 0.069328, 0.029311},{
      0.673370, 0.065165, 0.029311},{0.670887, 0.068582, 0.024365}}],
    Polygon[{{0.681541, 0.069328, 0.029311},{0.683070, 0.064624, 0.033535},{
      0.676278, 0.061163, 0.033535},{0.673370, 0.065165, 0.029311}}],
    Polygon[{{0.683070, 0.064624, 0.033535},{0.684784, 0.059350, 0.036934},{
      0.679538, 0.056677, 0.036934},{0.676278, 0.061163, 0.033535}}],
    Polygon[{{0.684784, 0.059350, 0.036934},{0.686641, 0.053634, 0.039423},{
      0.683070, 0.051815, 0.039423},{0.679538, 0.056677, 0.036934}}],
    Polygon[{{0.686641, 0.053634, 0.039423},{0.688595, 0.047619, 0.040942},{
      0.686787, 0.046698, 0.040942},{0.683070, 0.051815, 0.039423}}],
    Polygon[{{0.686787, 0.046698, -0.040942},{0.683070, 0.051815, -0.039423},{
      0.680236, 0.048981, -0.039423},{0.685353, 0.045263, -0.040942}}],
    Polygon[{{0.683070, 0.051815, -0.039423},{0.679538, 0.056677, -0.036934},{
      0.675374, 0.052513, -0.036934},{0.680236, 0.048981, -0.039423}}],
    Polygon[{{0.679538, 0.056677, -0.036934},{0.676278, 0.061163, -0.033535},{
      0.670887, 0.055773, -0.033535},{0.675374, 0.052513, -0.036934}}],
    Polygon[{{0.676278, 0.061163, -0.033535},{0.673370, 0.065165, -0.029311},{
      0.666886, 0.058680, -0.029311},{0.670887, 0.055773, -0.033535}}],
    Polygon[{{0.673370, 0.065165, -0.029311},{0.670887, 0.068582, -0.024365},{
      0.663468, 0.061163, -0.024365},{0.666886, 0.058680, -0.029311}}],
    Polygon[{{0.670887, 0.068582, -0.024365},{0.668890, 0.071332, -0.018819},{
      0.660719, 0.063161, -0.018819},{0.663468, 0.061163, -0.024365}}],
    Polygon[{{0.668890, 0.071332, -0.018819},{0.667427, 0.073346, -0.012809},{
      0.658705, 0.064624, -0.012809},{0.660719, 0.063161, -0.018819}}],
    Polygon[{{0.667427, 0.073346, -0.012809},{0.666534, 0.074574, -0.006485},{
      0.657477, 0.065517, -0.006485},{0.658705, 0.064624, -0.012809}}],
    Polygon[{{0.666534, 0.074574, -0.006485},{0.666234, 0.074987, 0.000000},{
      0.657064, 0.065817, 0.000000},{0.657477, 0.065517, -0.006485}}],
    Polygon[{{0.666234, 0.074987, 0.000000},{0.666534, 0.074574, 0.006485},{
      0.657477, 0.065517, 0.006485},{0.657064, 0.065817, 0.000000}}],
    Polygon[{{0.666534, 0.074574, 0.006485},{0.667427, 0.073346, 0.012809},{
      0.658705, 0.064624, 0.012809},{0.657477, 0.065517, 0.006485}}],
    Polygon[{{0.667427, 0.073346, 0.012809},{0.668890, 0.071332, 0.018819},{
      0.660719, 0.063161, 0.018819},{0.658705, 0.064624, 0.012809}}],
    Polygon[{{0.668890, 0.071332, 0.018819},{0.670887, 0.068582, 0.024365},{
      0.663468, 0.061163, 0.024365},{0.660719, 0.063161, 0.018819}}],
    Polygon[{{0.670887, 0.068582, 0.024365},{0.673370, 0.065165, 0.029311},{
      0.666886, 0.058680, 0.029311},{0.663468, 0.061163, 0.024365}}],
    Polygon[{{0.673370, 0.065165, 0.029311},{0.676278, 0.061163, 0.033535},{
      0.670887, 0.055773, 0.033535},{0.666886, 0.058680, 0.029311}}],
    Polygon[{{0.676278, 0.061163, 0.033535},{0.679538, 0.056677, 0.036934},{
      0.675374, 0.052513, 0.036934},{0.670887, 0.055773, 0.033535}}],
    Polygon[{{0.679538, 0.056677, 0.036934},{0.683070, 0.051815, 0.039423},{
      0.680236, 0.048981, 0.039423},{0.675374, 0.052513, 0.036934}}],
    Polygon[{{0.683070, 0.051815, 0.039423},{0.686787, 0.046698, 0.040942},{
      0.685353, 0.045263, 0.040942},{0.680236, 0.048981, 0.039423}}],
    Polygon[{{0.685353, 0.045263, -0.040942},{0.680236, 0.048981, -0.039423},{
      0.678416, 0.045410, -0.039423},{0.684432, 0.043456, -0.040942}}],
    Polygon[{{0.680236, 0.048981, -0.039423},{0.675374, 0.052513, -0.036934},{
      0.672701, 0.047267, -0.036934},{0.678416, 0.045410, -0.039423}}],
    Polygon[{{0.675374, 0.052513, -0.036934},{0.670887, 0.055773, -0.033535},{
      0.667427, 0.048981, -0.033535},{0.672701, 0.047267, -0.036934}}],
    Polygon[{{0.670887, 0.055773, -0.033535},{0.666886, 0.058680, -0.029311},{
      0.662723, 0.050509, -0.029311},{0.667427, 0.048981, -0.033535}}],
    Polygon[{{0.666886, 0.058680, -0.029311},{0.663468, 0.061163, -0.024365},{
      0.658705, 0.051815, -0.024365},{0.662723, 0.050509, -0.029311}}],
    Polygon[{{0.663468, 0.061163, -0.024365},{0.660719, 0.063161, -0.018819},{
      0.655473, 0.052865, -0.018819},{0.658705, 0.051815, -0.024365}}],
    Polygon[{{0.660719, 0.063161, -0.018819},{0.658705, 0.064624, -0.012809},{
      0.653105, 0.053634, -0.012809},{0.655473, 0.052865, -0.018819}}],
    Polygon[{{0.658705, 0.064624, -0.012809},{0.657477, 0.065517, -0.006485},{
      0.651661, 0.054104, -0.006485},{0.653105, 0.053634, -0.012809}}],
    Polygon[{{0.657477, 0.065517, -0.006485},{0.657064, 0.065817, 0.000000},{
      0.651176, 0.054261, 0.000000},{0.651661, 0.054104, -0.006485}}],
    Polygon[{{0.657064, 0.065817, 0.000000},{0.657477, 0.065517, 0.006485},{
      0.651661, 0.054104, 0.006485},{0.651176, 0.054261, 0.000000}}],
    Polygon[{{0.657477, 0.065517, 0.006485},{0.658705, 0.064624, 0.012809},{
      0.653105, 0.053634, 0.012809},{0.651661, 0.054104, 0.006485}}],
    Polygon[{{0.658705, 0.064624, 0.012809},{0.660719, 0.063161, 0.018819},{
      0.655473, 0.052865, 0.018819},{0.653105, 0.053634, 0.012809}}],
    Polygon[{{0.660719, 0.063161, 0.018819},{0.663468, 0.061163, 0.024365},{
      0.658705, 0.051815, 0.024365},{0.655473, 0.052865, 0.018819}}],
    Polygon[{{0.663468, 0.061163, 0.024365},{0.666886, 0.058680, 0.029311},{
      0.662723, 0.050509, 0.029311},{0.658705, 0.051815, 0.024365}}],
    Polygon[{{0.666886, 0.058680, 0.029311},{0.670887, 0.055773, 0.033535},{
      0.667427, 0.048981, 0.033535},{0.662723, 0.050509, 0.029311}}],
    Polygon[{{0.670887, 0.055773, 0.033535},{0.675374, 0.052513, 0.036934},{
      0.672701, 0.047267, 0.036934},{0.667427, 0.048981, 0.033535}}],
    Polygon[{{0.675374, 0.052513, 0.036934},{0.680236, 0.048981, 0.039423},{
      0.678416, 0.045410, 0.039423},{0.672701, 0.047267, 0.036934}}],
    Polygon[{{0.680236, 0.048981, 0.039423},{0.685353, 0.045263, 0.040942},{
      0.684432, 0.043456, 0.040942},{0.678416, 0.045410, 0.039423}}],
    Polygon[{{0.684432, 0.043456, -0.040942},{0.678416, 0.045410, -0.039423},{
      0.677790, 0.041452, -0.039423},{0.684114, 0.041452, -0.040942}}],
    Polygon[{{0.678416, 0.045410, -0.039423},{0.672701, 0.047267, -0.036934},{
      0.671780, 0.041452, -0.036934},{0.677790, 0.041452, -0.039423}}],
    Polygon[{{0.672701, 0.047267, -0.036934},{0.667427, 0.048981, -0.033535},{
      0.666234, 0.041452, -0.033535},{0.671780, 0.041452, -0.036934}}],
    Polygon[{{0.667427, 0.048981, -0.033535},{0.662723, 0.050509, -0.029311},{
      0.661288, 0.041452, -0.029311},{0.666234, 0.041452, -0.033535}}],
    Polygon[{{0.662723, 0.050509, -0.029311},{0.658705, 0.051815, -0.024365},{
      0.657064, 0.041452, -0.024365},{0.661288, 0.041452, -0.029311}}],
    Polygon[{{0.658705, 0.051815, -0.024365},{0.655473, 0.052865, -0.018819},{
      0.653665, 0.041452, -0.018819},{0.657064, 0.041452, -0.024365}}],
    Polygon[{{0.655473, 0.052865, -0.018819},{0.653105, 0.053634, -0.012809},{
      0.651176, 0.041452, -0.012809},{0.653665, 0.041452, -0.018819}}],
    Polygon[{{0.653105, 0.053634, -0.012809},{0.651661, 0.054104, -0.006485},{
      0.649657, 0.041452, -0.006485},{0.651176, 0.041452, -0.012809}}],
    Polygon[{{0.651661, 0.054104, -0.006485},{0.651176, 0.054261, 0.000000},{
      0.649147, 0.041452, 0.000000},{0.649657, 0.041452, -0.006485}}],
    Polygon[{{0.651176, 0.054261, 0.000000},{0.651661, 0.054104, 0.006485},{
      0.649657, 0.041452, 0.006485},{0.649147, 0.041452, 0.000000}}],
    Polygon[{{0.651661, 0.054104, 0.006485},{0.653105, 0.053634, 0.012809},{
      0.651176, 0.041452, 0.012809},{0.649657, 0.041452, 0.006485}}],
    Polygon[{{0.653105, 0.053634, 0.012809},{0.655473, 0.052865, 0.018819},{
      0.653665, 0.041452, 0.018819},{0.651176, 0.041452, 0.012809}}],
    Polygon[{{0.655473, 0.052865, 0.018819},{0.658705, 0.051815, 0.024365},{
      0.657064, 0.041452, 0.024365},{0.653665, 0.041452, 0.018819}}],
    Polygon[{{0.658705, 0.051815, 0.024365},{0.662723, 0.050509, 0.029311},{
      0.661288, 0.041452, 0.029311},{0.657064, 0.041452, 0.024365}}],
    Polygon[{{0.662723, 0.050509, 0.029311},{0.667427, 0.048981, 0.033535},{
      0.666234, 0.041452, 0.033535},{0.661288, 0.041452, 0.029311}}],
    Polygon[{{0.667427, 0.048981, 0.033535},{0.672701, 0.047267, 0.036934},{
      0.671780, 0.041452, 0.036934},{0.666234, 0.041452, 0.033535}}],
    Polygon[{{0.672701, 0.047267, 0.036934},{0.678416, 0.045410, 0.039423},{
      0.677790, 0.041452, 0.039423},{0.671780, 0.041452, 0.036934}}],
    Polygon[{{0.678416, 0.045410, 0.039423},{0.684432, 0.043456, 0.040942},{
      0.684114, 0.041452, 0.040942},{0.677790, 0.041452, 0.039423}}],
    Polygon[{{0.684114, 0.041452, -0.040942},{0.677790, 0.041452, -0.039423},{
      0.678416, 0.037494, -0.039423},{0.684432, 0.039448, -0.040942}}],
    Polygon[{{0.677790, 0.041452, -0.039423},{0.671780, 0.041452, -0.036934},{
      0.672701, 0.035637, -0.036934},{0.678416, 0.037494, -0.039423}}],
    Polygon[{{0.671780, 0.041452, -0.036934},{0.666234, 0.041452, -0.033535},{
      0.667427, 0.033923, -0.033535},{0.672701, 0.035637, -0.036934}}],
    Polygon[{{0.666234, 0.041452, -0.033535},{0.661288, 0.041452, -0.029311},{
      0.662723, 0.032394, -0.029311},{0.667427, 0.033923, -0.033535}}],
    Polygon[{{0.661288, 0.041452, -0.029311},{0.657064, 0.041452, -0.024365},{
      0.658705, 0.031089, -0.024365},{0.662723, 0.032394, -0.029311}}],
    Polygon[{{0.657064, 0.041452, -0.024365},{0.653665, 0.041452, -0.018819},{
      0.655473, 0.030039, -0.018819},{0.658705, 0.031089, -0.024365}}],
    Polygon[{{0.653665, 0.041452, -0.018819},{0.651176, 0.041452, -0.012809},{
      0.653105, 0.029269, -0.012809},{0.655473, 0.030039, -0.018819}}],
    Polygon[{{0.651176, 0.041452, -0.012809},{0.649657, 0.041452, -0.006485},{
      0.651661, 0.028800, -0.006485},{0.653105, 0.029269, -0.012809}}],
    Polygon[{{0.649657, 0.041452, -0.006485},{0.649147, 0.041452, 0.000000},{
      0.651176, 0.028643, 0.000000},{0.651661, 0.028800, -0.006485}}],
    Polygon[{{0.649147, 0.041452, 0.000000},{0.649657, 0.041452, 0.006485},{
      0.651661, 0.028800, 0.006485},{0.651176, 0.028643, 0.000000}}],
    Polygon[{{0.649657, 0.041452, 0.006485},{0.651176, 0.041452, 0.012809},{
      0.653105, 0.029269, 0.012809},{0.651661, 0.028800, 0.006485}}],
    Polygon[{{0.651176, 0.041452, 0.012809},{0.653665, 0.041452, 0.018819},{
      0.655473, 0.030039, 0.018819},{0.653105, 0.029269, 0.012809}}],
    Polygon[{{0.653665, 0.041452, 0.018819},{0.657064, 0.041452, 0.024365},{
      0.658705, 0.031089, 0.024365},{0.655473, 0.030039, 0.018819}}],
    Polygon[{{0.657064, 0.041452, 0.024365},{0.661288, 0.041452, 0.029311},{
      0.662723, 0.032394, 0.029311},{0.658705, 0.031089, 0.024365}}],
    Polygon[{{0.661288, 0.041452, 0.029311},{0.666234, 0.041452, 0.033535},{
      0.667427, 0.033923, 0.033535},{0.662723, 0.032394, 0.029311}}],
    Polygon[{{0.666234, 0.041452, 0.033535},{0.671780, 0.041452, 0.036934},{
      0.672701, 0.035637, 0.036934},{0.667427, 0.033923, 0.033535}}],
    Polygon[{{0.671780, 0.041452, 0.036934},{0.677790, 0.041452, 0.039423},{
      0.678416, 0.037494, 0.039423},{0.672701, 0.035637, 0.036934}}],
    Polygon[{{0.677790, 0.041452, 0.039423},{0.684114, 0.041452, 0.040942},{
      0.684432, 0.039448, 0.040942},{0.678416, 0.037494, 0.039423}}],
    Polygon[{{0.684432, 0.039448, -0.040942},{0.678416, 0.037494, -0.039423},{
      0.680236, 0.033923, -0.039423},{0.685353, 0.037640, -0.040942}}],
    Polygon[{{0.678416, 0.037494, -0.039423},{0.672701, 0.035637, -0.036934},{
      0.675374, 0.030390, -0.036934},{0.680236, 0.033923, -0.039423}}],
    Polygon[{{0.672701, 0.035637, -0.036934},{0.667427, 0.033923, -0.033535},{
      0.670887, 0.027131, -0.033535},{0.675374, 0.030390, -0.036934}}],
    Polygon[{{0.667427, 0.033923, -0.033535},{0.662723, 0.032394, -0.029311},{
      0.666886, 0.024223, -0.029311},{0.670887, 0.027131, -0.033535}}],
    Polygon[{{0.662723, 0.032394, -0.029311},{0.658705, 0.031089, -0.024365},{
      0.663468, 0.021740, -0.024365},{0.666886, 0.024223, -0.029311}}],
    Polygon[{{0.658705, 0.031089, -0.024365},{0.655473, 0.030039, -0.018819},{
      0.660719, 0.019743, -0.018819},{0.663468, 0.021740, -0.024365}}],
    Polygon[{{0.655473, 0.030039, -0.018819},{0.653105, 0.029269, -0.012809},{
      0.658705, 0.018280, -0.012809},{0.660719, 0.019743, -0.018819}}],
    Polygon[{{0.653105, 0.029269, -0.012809},{0.651661, 0.028800, -0.006485},{
      0.657477, 0.017387, -0.006485},{0.658705, 0.018280, -0.012809}}],
    Polygon[{{0.651661, 0.028800, -0.006485},{0.651176, 0.028643, 0.000000},{
      0.657064, 0.017087, 0.000000},{0.657477, 0.017387, -0.006485}}],
    Polygon[{{0.651176, 0.028643, 0.000000},{0.651661, 0.028800, 0.006485},{
      0.657477, 0.017387, 0.006485},{0.657064, 0.017087, 0.000000}}],
    Polygon[{{0.651661, 0.028800, 0.006485},{0.653105, 0.029269, 0.012809},{
      0.658705, 0.018280, 0.012809},{0.657477, 0.017387, 0.006485}}],
    Polygon[{{0.653105, 0.029269, 0.012809},{0.655473, 0.030039, 0.018819},{
      0.660719, 0.019743, 0.018819},{0.658705, 0.018280, 0.012809}}],
    Polygon[{{0.655473, 0.030039, 0.018819},{0.658705, 0.031089, 0.024365},{
      0.663468, 0.021740, 0.024365},{0.660719, 0.019743, 0.018819}}],
    Polygon[{{0.658705, 0.031089, 0.024365},{0.662723, 0.032394, 0.029311},{
      0.666886, 0.024223, 0.029311},{0.663468, 0.021740, 0.024365}}],
    Polygon[{{0.662723, 0.032394, 0.029311},{0.667427, 0.033923, 0.033535},{
      0.670887, 0.027131, 0.033535},{0.666886, 0.024223, 0.029311}}],
    Polygon[{{0.667427, 0.033923, 0.033535},{0.672701, 0.035637, 0.036934},{
      0.675374, 0.030390, 0.036934},{0.670887, 0.027131, 0.033535}}],
    Polygon[{{0.672701, 0.035637, 0.036934},{0.678416, 0.037494, 0.039423},{
      0.680236, 0.033923, 0.039423},{0.675374, 0.030390, 0.036934}}],
    Polygon[{{0.678416, 0.037494, 0.039423},{0.684432, 0.039448, 0.040942},{
      0.685353, 0.037640, 0.040942},{0.680236, 0.033923, 0.039423}}],
    Polygon[{{0.685353, 0.037640, -0.040942},{0.680236, 0.033923, -0.039423},{
      0.683070, 0.031089, -0.039423},{0.686787, 0.036206, -0.040942}}],
    Polygon[{{0.680236, 0.033923, -0.039423},{0.675374, 0.030390, -0.036934},{
      0.679538, 0.026227, -0.036934},{0.683070, 0.031089, -0.039423}}],
    Polygon[{{0.675374, 0.030390, -0.036934},{0.670887, 0.027131, -0.033535},{
      0.676278, 0.021740, -0.033535},{0.679538, 0.026227, -0.036934}}],
    Polygon[{{0.670887, 0.027131, -0.033535},{0.666886, 0.024223, -0.029311},{
      0.673370, 0.017739, -0.029311},{0.676278, 0.021740, -0.033535}}],
    Polygon[{{0.666886, 0.024223, -0.029311},{0.663468, 0.021740, -0.024365},{
      0.670887, 0.014321, -0.024365},{0.673370, 0.017739, -0.029311}}],
    Polygon[{{0.663468, 0.021740, -0.024365},{0.660719, 0.019743, -0.018819},{
      0.668890, 0.011572, -0.018819},{0.670887, 0.014321, -0.024365}}],
    Polygon[{{0.660719, 0.019743, -0.018819},{0.658705, 0.018280, -0.012809},{
      0.667427, 0.009558, -0.012809},{0.668890, 0.011572, -0.018819}}],
    Polygon[{{0.658705, 0.018280, -0.012809},{0.657477, 0.017387, -0.006485},{
      0.666534, 0.008329, -0.006485},{0.667427, 0.009558, -0.012809}}],
    Polygon[{{0.657477, 0.017387, -0.006485},{0.657064, 0.017087, 0.000000},{
      0.666234, 0.007917, 0.000000},{0.666534, 0.008329, -0.006485}}],
    Polygon[{{0.657064, 0.017087, 0.000000},{0.657477, 0.017387, 0.006485},{
      0.666534, 0.008329, 0.006485},{0.666234, 0.007917, 0.000000}}],
    Polygon[{{0.657477, 0.017387, 0.006485},{0.658705, 0.018280, 0.012809},{
      0.667427, 0.009558, 0.012809},{0.666534, 0.008329, 0.006485}}],
    Polygon[{{0.658705, 0.018280, 0.012809},{0.660719, 0.019743, 0.018819},{
      0.668890, 0.011572, 0.018819},{0.667427, 0.009558, 0.012809}}],
    Polygon[{{0.660719, 0.019743, 0.018819},{0.663468, 0.021740, 0.024365},{
      0.670887, 0.014321, 0.024365},{0.668890, 0.011572, 0.018819}}],
    Polygon[{{0.663468, 0.021740, 0.024365},{0.666886, 0.024223, 0.029311},{
      0.673370, 0.017739, 0.029311},{0.670887, 0.014321, 0.024365}}],
    Polygon[{{0.666886, 0.024223, 0.029311},{0.670887, 0.027131, 0.033535},{
      0.676278, 0.021740, 0.033535},{0.673370, 0.017739, 0.029311}}],
    Polygon[{{0.670887, 0.027131, 0.033535},{0.675374, 0.030390, 0.036934},{
      0.679538, 0.026227, 0.036934},{0.676278, 0.021740, 0.033535}}],
    Polygon[{{0.675374, 0.030390, 0.036934},{0.680236, 0.033923, 0.039423},{
      0.683070, 0.031089, 0.039423},{0.679538, 0.026227, 0.036934}}],
    Polygon[{{0.680236, 0.033923, 0.039423},{0.685353, 0.037640, 0.040942},{
      0.686787, 0.036206, 0.040942},{0.683070, 0.031089, 0.039423}}],
    Polygon[{{0.686787, 0.036206, -0.040942},{0.683070, 0.031089, -0.039423},{
      0.686641, 0.029269, -0.039423},{0.688595, 0.035285, -0.040942}}],
    Polygon[{{0.683070, 0.031089, -0.039423},{0.679538, 0.026227, -0.036934},{
      0.684784, 0.023554, -0.036934},{0.686641, 0.029269, -0.039423}}],
    Polygon[{{0.679538, 0.026227, -0.036934},{0.676278, 0.021740, -0.033535},{
      0.683070, 0.018280, -0.033535},{0.684784, 0.023554, -0.036934}}],
    Polygon[{{0.676278, 0.021740, -0.033535},{0.673370, 0.017739, -0.029311},{
      0.681541, 0.013576, -0.029311},{0.683070, 0.018280, -0.033535}}],
    Polygon[{{0.673370, 0.017739, -0.029311},{0.670887, 0.014321, -0.024365},{
      0.680236, 0.009558, -0.024365},{0.681541, 0.013576, -0.029311}}],
    Polygon[{{0.670887, 0.014321, -0.024365},{0.668890, 0.011572, -0.018819},{
      0.679186, 0.006326, -0.018819},{0.680236, 0.009558, -0.024365}}],
    Polygon[{{0.668890, 0.011572, -0.018819},{0.667427, 0.009558, -0.012809},{
      0.678416, 0.003958, -0.012809},{0.679186, 0.006326, -0.018819}}],
    Polygon[{{0.667427, 0.009558, -0.012809},{0.666534, 0.008329, -0.006485},{
      0.677947, 0.002514, -0.006485},{0.678416, 0.003958, -0.012809}}],
    Polygon[{{0.666534, 0.008329, -0.006485},{0.666234, 0.007917, 0.000000},{
      0.677790, 0.002029, 0.000000},{0.677947, 0.002514, -0.006485}}],
    Polygon[{{0.666234, 0.007917, 0.000000},{0.666534, 0.008329, 0.006485},{
      0.677947, 0.002514, 0.006485},{0.677790, 0.002029, 0.000000}}],
    Polygon[{{0.666534, 0.008329, 0.006485},{0.667427, 0.009558, 0.012809},{
      0.678416, 0.003958, 0.012809},{0.677947, 0.002514, 0.006485}}],
    Polygon[{{0.667427, 0.009558, 0.012809},{0.668890, 0.011572, 0.018819},{
      0.679186, 0.006326, 0.018819},{0.678416, 0.003958, 0.012809}}],
    Polygon[{{0.668890, 0.011572, 0.018819},{0.670887, 0.014321, 0.024365},{
      0.680236, 0.009558, 0.024365},{0.679186, 0.006326, 0.018819}}],
    Polygon[{{0.670887, 0.014321, 0.024365},{0.673370, 0.017739, 0.029311},{
      0.681541, 0.013576, 0.029311},{0.680236, 0.009558, 0.024365}}],
    Polygon[{{0.673370, 0.017739, 0.029311},{0.676278, 0.021740, 0.033535},{
      0.683070, 0.018280, 0.033535},{0.681541, 0.013576, 0.029311}}],
    Polygon[{{0.676278, 0.021740, 0.033535},{0.679538, 0.026227, 0.036934},{
      0.684784, 0.023554, 0.036934},{0.683070, 0.018280, 0.033535}}],
    Polygon[{{0.679538, 0.026227, 0.036934},{0.683070, 0.031089, 0.039423},{
      0.686641, 0.029269, 0.039423},{0.684784, 0.023554, 0.036934}}],
    Polygon[{{0.683070, 0.031089, 0.039423},{0.686787, 0.036206, 0.040942},{
      0.688595, 0.035285, 0.040942},{0.686641, 0.029269, 0.039423}}],
    Polygon[{{0.688595, 0.035285, -0.040942},{0.686641, 0.029269, -0.039423},{
      0.690599, 0.028643, -0.039423},{0.690599, 0.034967, -0.040942}}],
    Polygon[{{0.686641, 0.029269, -0.039423},{0.684784, 0.023554, -0.036934},{
      0.690599, 0.022633, -0.036934},{0.690599, 0.028643, -0.039423}}],
    Polygon[{{0.684784, 0.023554, -0.036934},{0.683070, 0.018280, -0.033535},{
      0.690599, 0.017087, -0.033535},{0.690599, 0.022633, -0.036934}}],
    Polygon[{{0.683070, 0.018280, -0.033535},{0.681541, 0.013576, -0.029311},{
      0.690599, 0.012141, -0.029311},{0.690599, 0.017087, -0.033535}}],
    Polygon[{{0.681541, 0.013576, -0.029311},{0.680236, 0.009558, -0.024365},{
      0.690599, 0.007917, -0.024365},{0.690599, 0.012141, -0.029311}}],
    Polygon[{{0.680236, 0.009558, -0.024365},{0.679186, 0.006326, -0.018819},{
      0.690599, 0.004518, -0.018819},{0.690599, 0.007917, -0.024365}}],
    Polygon[{{0.679186, 0.006326, -0.018819},{0.678416, 0.003958, -0.012809},{
      0.690599, 0.002029, -0.012809},{0.690599, 0.004518, -0.018819}}],
    Polygon[{{0.678416, 0.003958, -0.012809},{0.677947, 0.002514, -0.006485},{
      0.690599, 0.000510, -0.006485},{0.690599, 0.002029, -0.012809}}],
    Polygon[{{0.677947, 0.002514, -0.006485},{0.677790, 0.002029, 0.000000},{
      0.690599, 0.000000, 0.000000},{0.690599, 0.000510, -0.006485}}],
    Polygon[{{0.677790, 0.002029, 0.000000},{0.677947, 0.002514, 0.006485},{
      0.690599, 0.000510, 0.006485},{0.690599, 0.000000, 0.000000}}],
    Polygon[{{0.677947, 0.002514, 0.006485},{0.678416, 0.003958, 0.012809},{
      0.690599, 0.002029, 0.012809},{0.690599, 0.000510, 0.006485}}],
    Polygon[{{0.678416, 0.003958, 0.012809},{0.679186, 0.006326, 0.018819},{
      0.690599, 0.004518, 0.018819},{0.690599, 0.002029, 0.012809}}],
    Polygon[{{0.679186, 0.006326, 0.018819},{0.680236, 0.009558, 0.024365},{
      0.690599, 0.007917, 0.024365},{0.690599, 0.004518, 0.018819}}],
    Polygon[{{0.680236, 0.009558, 0.024365},{0.681541, 0.013576, 0.029311},{
      0.690599, 0.012141, 0.029311},{0.690599, 0.007917, 0.024365}}],
    Polygon[{{0.681541, 0.013576, 0.029311},{0.683070, 0.018280, 0.033535},{
      0.690599, 0.017087, 0.033535},{0.690599, 0.012141, 0.029311}}],
    Polygon[{{0.683070, 0.018280, 0.033535},{0.684784, 0.023554, 0.036934},{
      0.690599, 0.022633, 0.036934},{0.690599, 0.017087, 0.033535}}],
    Polygon[{{0.684784, 0.023554, 0.036934},{0.686641, 0.029269, 0.039423},{
      0.690599, 0.028643, 0.039423},{0.690599, 0.022633, 0.036934}}],
    Polygon[{{0.686641, 0.029269, 0.039423},{0.688595, 0.035285, 0.040942},{
      0.690599, 0.034967, 0.040942},{0.690599, 0.028643, 0.039423}}],
    Polygon[{{0.690599, 0.034967, -0.040942},{0.690599, 0.028643, -0.039423},{
      0.694557, 0.029269, -0.039423},{0.692603, 0.035285, -0.040942}}],
    Polygon[{{0.690599, 0.028643, -0.039423},{0.690599, 0.022633, -0.036934},{
      0.696414, 0.023554, -0.036934},{0.694557, 0.029269, -0.039423}}],
    Polygon[{{0.690599, 0.022633, -0.036934},{0.690599, 0.017087, -0.033535},{
      0.698128, 0.018280, -0.033535},{0.696414, 0.023554, -0.036934}}],
    Polygon[{{0.690599, 0.017087, -0.033535},{0.690599, 0.012141, -0.029311},{
      0.699656, 0.013576, -0.029311},{0.698128, 0.018280, -0.033535}}],
    Polygon[{{0.690599, 0.012141, -0.029311},{0.690599, 0.007917, -0.024365},{
      0.700962, 0.009558, -0.024365},{0.699656, 0.013576, -0.029311}}],
    Polygon[{{0.690599, 0.007917, -0.024365},{0.690599, 0.004518, -0.018819},{
      0.702012, 0.006326, -0.018819},{0.700962, 0.009558, -0.024365}}],
    Polygon[{{0.690599, 0.004518, -0.018819},{0.690599, 0.002029, -0.012809},{
      0.702781, 0.003958, -0.012809},{0.702012, 0.006326, -0.018819}}],
    Polygon[{{0.690599, 0.002029, -0.012809},{0.690599, 0.000510, -0.006485},{
      0.703251, 0.002514, -0.006485},{0.702781, 0.003958, -0.012809}}],
    Polygon[{{0.690599, 0.000510, -0.006485},{0.690599, 0.000000, 0.000000},{
      0.703408, 0.002029, 0.000000},{0.703251, 0.002514, -0.006485}}],
    Polygon[{{0.690599, 0.000000, 0.000000},{0.690599, 0.000510, 0.006485},{
      0.703251, 0.002514, 0.006485},{0.703408, 0.002029, 0.000000}}],
    Polygon[{{0.690599, 0.000510, 0.006485},{0.690599, 0.002029, 0.012809},{
      0.702781, 0.003958, 0.012809},{0.703251, 0.002514, 0.006485}}],
    Polygon[{{0.690599, 0.002029, 0.012809},{0.690599, 0.004518, 0.018819},{
      0.702012, 0.006326, 0.018819},{0.702781, 0.003958, 0.012809}}],
    Polygon[{{0.690599, 0.004518, 0.018819},{0.690599, 0.007917, 0.024365},{
      0.700962, 0.009558, 0.024365},{0.702012, 0.006326, 0.018819}}],
    Polygon[{{0.690599, 0.007917, 0.024365},{0.690599, 0.012141, 0.029311},{
      0.699656, 0.013576, 0.029311},{0.700962, 0.009558, 0.024365}}],
    Polygon[{{0.690599, 0.012141, 0.029311},{0.690599, 0.017087, 0.033535},{
      0.698128, 0.018280, 0.033535},{0.699656, 0.013576, 0.029311}}],
    Polygon[{{0.690599, 0.017087, 0.033535},{0.690599, 0.022633, 0.036934},{
      0.696414, 0.023554, 0.036934},{0.698128, 0.018280, 0.033535}}],
    Polygon[{{0.690599, 0.022633, 0.036934},{0.690599, 0.028643, 0.039423},{
      0.694557, 0.029269, 0.039423},{0.696414, 0.023554, 0.036934}}],
    Polygon[{{0.690599, 0.028643, 0.039423},{0.690599, 0.034967, 0.040942},{
      0.692603, 0.035285, 0.040942},{0.694557, 0.029269, 0.039423}}],
    Polygon[{{0.692603, 0.035285, -0.040942},{0.694557, 0.029269, -0.039423},{
      0.698128, 0.031089, -0.039423},{0.694410, 0.036206, -0.040942}}],
    Polygon[{{0.694557, 0.029269, -0.039423},{0.696414, 0.023554, -0.036934},{
      0.701660, 0.026227, -0.036934},{0.698128, 0.031089, -0.039423}}],
    Polygon[{{0.696414, 0.023554, -0.036934},{0.698128, 0.018280, -0.033535},{
      0.704920, 0.021740, -0.033535},{0.701660, 0.026227, -0.036934}}],
    Polygon[{{0.698128, 0.018280, -0.033535},{0.699656, 0.013576, -0.029311},{
      0.707827, 0.017739, -0.029311},{0.704920, 0.021740, -0.033535}}],
    Polygon[{{0.699656, 0.013576, -0.029311},{0.700962, 0.009558, -0.024365},{
      0.710310, 0.014321, -0.024365},{0.707827, 0.017739, -0.029311}}],
    Polygon[{{0.700962, 0.009558, -0.024365},{0.702012, 0.006326, -0.018819},{
      0.712308, 0.011572, -0.018819},{0.710310, 0.014321, -0.024365}}],
    Polygon[{{0.702012, 0.006326, -0.018819},{0.702781, 0.003958, -0.012809},{
      0.713771, 0.009558, -0.012809},{0.712308, 0.011572, -0.018819}}],
    Polygon[{{0.702781, 0.003958, -0.012809},{0.703251, 0.002514, -0.006485},{
      0.714664, 0.008329, -0.006485},{0.713771, 0.009558, -0.012809}}],
    Polygon[{{0.703251, 0.002514, -0.006485},{0.703408, 0.002029, 0.000000},{
      0.714964, 0.007917, 0.000000},{0.714664, 0.008329, -0.006485}}],
    Polygon[{{0.703408, 0.002029, 0.000000},{0.703251, 0.002514, 0.006485},{
      0.714664, 0.008329, 0.006485},{0.714964, 0.007917, 0.000000}}],
    Polygon[{{0.703251, 0.002514, 0.006485},{0.702781, 0.003958, 0.012809},{
      0.713771, 0.009558, 0.012809},{0.714664, 0.008329, 0.006485}}],
    Polygon[{{0.702781, 0.003958, 0.012809},{0.702012, 0.006326, 0.018819},{
      0.712308, 0.011572, 0.018819},{0.713771, 0.009558, 0.012809}}],
    Polygon[{{0.702012, 0.006326, 0.018819},{0.700962, 0.009558, 0.024365},{
      0.710310, 0.014321, 0.024365},{0.712308, 0.011572, 0.018819}}],
    Polygon[{{0.700962, 0.009558, 0.024365},{0.699656, 0.013576, 0.029311},{
      0.707827, 0.017739, 0.029311},{0.710310, 0.014321, 0.024365}}],
    Polygon[{{0.699656, 0.013576, 0.029311},{0.698128, 0.018280, 0.033535},{
      0.704920, 0.021740, 0.033535},{0.707827, 0.017739, 0.029311}}],
    Polygon[{{0.698128, 0.018280, 0.033535},{0.696414, 0.023554, 0.036934},{
      0.701660, 0.026227, 0.036934},{0.704920, 0.021740, 0.033535}}],
    Polygon[{{0.696414, 0.023554, 0.036934},{0.694557, 0.029269, 0.039423},{
      0.698128, 0.031089, 0.039423},{0.701660, 0.026227, 0.036934}}],
    Polygon[{{0.694557, 0.029269, 0.039423},{0.692603, 0.035285, 0.040942},{
      0.694410, 0.036206, 0.040942},{0.698128, 0.031089, 0.039423}}],
    Polygon[{{0.694410, 0.036206, -0.040942},{0.698128, 0.031089, -0.039423},{
      0.700962, 0.033923, -0.039423},{0.695845, 0.037640, -0.040942}}],
    Polygon[{{0.698128, 0.031089, -0.039423},{0.701660, 0.026227, -0.036934},{
      0.705824, 0.030390, -0.036934},{0.700962, 0.033923, -0.039423}}],
    Polygon[{{0.701660, 0.026227, -0.036934},{0.704920, 0.021740, -0.033535},{
      0.710310, 0.027131, -0.033535},{0.705824, 0.030390, -0.036934}}],
    Polygon[{{0.704920, 0.021740, -0.033535},{0.707827, 0.017739, -0.029311},{
      0.714312, 0.024223, -0.029311},{0.710310, 0.027131, -0.033535}}],
    Polygon[{{0.707827, 0.017739, -0.029311},{0.710310, 0.014321, -0.024365},{
      0.717730, 0.021740, -0.024365},{0.714312, 0.024223, -0.029311}}],
    Polygon[{{0.710310, 0.014321, -0.024365},{0.712308, 0.011572, -0.018819},{
      0.720479, 0.019743, -0.018819},{0.717730, 0.021740, -0.024365}}],
    Polygon[{{0.712308, 0.011572, -0.018819},{0.713771, 0.009558, -0.012809},{
      0.722493, 0.018280, -0.012809},{0.720479, 0.019743, -0.018819}}],
    Polygon[{{0.713771, 0.009558, -0.012809},{0.714664, 0.008329, -0.006485},{
      0.723721, 0.017387, -0.006485},{0.722493, 0.018280, -0.012809}}],
    Polygon[{{0.714664, 0.008329, -0.006485},{0.714964, 0.007917, 0.000000},{
      0.724134, 0.017087, 0.000000},{0.723721, 0.017387, -0.006485}}],
    Polygon[{{0.714964, 0.007917, 0.000000},{0.714664, 0.008329, 0.006485},{
      0.723721, 0.017387, 0.006485},{0.724134, 0.017087, 0.000000}}],
    Polygon[{{0.714664, 0.008329, 0.006485},{0.713771, 0.009558, 0.012809},{
      0.722493, 0.018280, 0.012809},{0.723721, 0.017387, 0.006485}}],
    Polygon[{{0.713771, 0.009558, 0.012809},{0.712308, 0.011572, 0.018819},{
      0.720479, 0.019743, 0.018819},{0.722493, 0.018280, 0.012809}}],
    Polygon[{{0.712308, 0.011572, 0.018819},{0.710310, 0.014321, 0.024365},{
      0.717730, 0.021740, 0.024365},{0.720479, 0.019743, 0.018819}}],
    Polygon[{{0.710310, 0.014321, 0.024365},{0.707827, 0.017739, 0.029311},{
      0.714312, 0.024223, 0.029311},{0.717730, 0.021740, 0.024365}}],
    Polygon[{{0.707827, 0.017739, 0.029311},{0.704920, 0.021740, 0.033535},{
      0.710310, 0.027131, 0.033535},{0.714312, 0.024223, 0.029311}}],
    Polygon[{{0.704920, 0.021740, 0.033535},{0.701660, 0.026227, 0.036934},{
      0.705824, 0.030390, 0.036934},{0.710310, 0.027131, 0.033535}}],
    Polygon[{{0.701660, 0.026227, 0.036934},{0.698128, 0.031089, 0.039423},{
      0.700962, 0.033923, 0.039423},{0.705824, 0.030390, 0.036934}}],
    Polygon[{{0.698128, 0.031089, 0.039423},{0.694410, 0.036206, 0.040942},{
      0.695845, 0.037640, 0.040942},{0.700962, 0.033923, 0.039423}}],
    Polygon[{{0.695845, 0.037640, -0.040942},{0.700962, 0.033923, -0.039423},{
      0.702781, 0.037494, -0.039423},{0.696766, 0.039448, -0.040942}}],
    Polygon[{{0.700962, 0.033923, -0.039423},{0.705824, 0.030390, -0.036934},{
      0.708497, 0.035637, -0.036934},{0.702781, 0.037494, -0.039423}}],
    Polygon[{{0.705824, 0.030390, -0.036934},{0.710310, 0.027131, -0.033535},{
      0.713771, 0.033923, -0.033535},{0.708497, 0.035637, -0.036934}}],
    Polygon[{{0.710310, 0.027131, -0.033535},{0.714312, 0.024223, -0.029311},{
      0.718475, 0.032394, -0.029311},{0.713771, 0.033923, -0.033535}}],
    Polygon[{{0.714312, 0.024223, -0.029311},{0.717730, 0.021740, -0.024365},{
      0.722493, 0.031089, -0.024365},{0.718475, 0.032394, -0.029311}}],
    Polygon[{{0.717730, 0.021740, -0.024365},{0.720479, 0.019743, -0.018819},{
      0.725725, 0.030039, -0.018819},{0.722493, 0.031089, -0.024365}}],
    Polygon[{{0.720479, 0.019743, -0.018819},{0.722493, 0.018280, -0.012809},{
      0.728092, 0.029269, -0.012809},{0.725725, 0.030039, -0.018819}}],
    Polygon[{{0.722493, 0.018280, -0.012809},{0.723721, 0.017387, -0.006485},{
      0.729537, 0.028800, -0.006485},{0.728092, 0.029269, -0.012809}}],
    Polygon[{{0.723721, 0.017387, -0.006485},{0.724134, 0.017087, 0.000000},{
      0.730022, 0.028643, 0.000000},{0.729537, 0.028800, -0.006485}}],
    Polygon[{{0.724134, 0.017087, 0.000000},{0.723721, 0.017387, 0.006485},{
      0.729537, 0.028800, 0.006485},{0.730022, 0.028643, 0.000000}}],
    Polygon[{{0.723721, 0.017387, 0.006485},{0.722493, 0.018280, 0.012809},{
      0.728092, 0.029269, 0.012809},{0.729537, 0.028800, 0.006485}}],
    Polygon[{{0.722493, 0.018280, 0.012809},{0.720479, 0.019743, 0.018819},{
      0.725725, 0.030039, 0.018819},{0.728092, 0.029269, 0.012809}}],
    Polygon[{{0.720479, 0.019743, 0.018819},{0.717730, 0.021740, 0.024365},{
      0.722493, 0.031089, 0.024365},{0.725725, 0.030039, 0.018819}}],
    Polygon[{{0.717730, 0.021740, 0.024365},{0.714312, 0.024223, 0.029311},{
      0.718475, 0.032394, 0.029311},{0.722493, 0.031089, 0.024365}}],
    Polygon[{{0.714312, 0.024223, 0.029311},{0.710310, 0.027131, 0.033535},{
      0.713771, 0.033923, 0.033535},{0.718475, 0.032394, 0.029311}}],
    Polygon[{{0.710310, 0.027131, 0.033535},{0.705824, 0.030390, 0.036934},{
      0.708497, 0.035637, 0.036934},{0.713771, 0.033923, 0.033535}}],
    Polygon[{{0.705824, 0.030390, 0.036934},{0.700962, 0.033923, 0.039423},{
      0.702781, 0.037494, 0.039423},{0.708497, 0.035637, 0.036934}}],
    Polygon[{{0.700962, 0.033923, 0.039423},{0.695845, 0.037640, 0.040942},{
      0.696766, 0.039448, 0.040942},{0.702781, 0.037494, 0.039423}}],
    Polygon[{{0.696766, 0.039448, -0.040942},{0.702781, 0.037494, -0.039423},{
      0.703408, 0.041452, -0.039423},{0.697083, 0.041452, -0.040942}}],
    Polygon[{{0.702781, 0.037494, -0.039423},{0.708497, 0.035637, -0.036934},{
      0.709418, 0.041452, -0.036934},{0.703408, 0.041452, -0.039423}}],
    Polygon[{{0.708497, 0.035637, -0.036934},{0.713771, 0.033923, -0.033535},{
      0.714964, 0.041452, -0.033535},{0.709418, 0.041452, -0.036934}}],
    Polygon[{{0.713771, 0.033923, -0.033535},{0.718475, 0.032394, -0.029311},{
      0.719910, 0.041452, -0.029311},{0.714964, 0.041452, -0.033535}}],
    Polygon[{{0.718475, 0.032394, -0.029311},{0.722493, 0.031089, -0.024365},{
      0.724134, 0.041452, -0.024365},{0.719910, 0.041452, -0.029311}}],
    Polygon[{{0.722493, 0.031089, -0.024365},{0.725725, 0.030039, -0.018819},{
      0.727533, 0.041452, -0.018819},{0.724134, 0.041452, -0.024365}}],
    Polygon[{{0.725725, 0.030039, -0.018819},{0.728092, 0.029269, -0.012809},{
      0.730022, 0.041452, -0.012809},{0.727533, 0.041452, -0.018819}}],
    Polygon[{{0.728092, 0.029269, -0.012809},{0.729537, 0.028800, -0.006485},{
      0.731540, 0.041452, -0.006485},{0.730022, 0.041452, -0.012809}}],
    Polygon[{{0.729537, 0.028800, -0.006485},{0.730022, 0.028643, 0.000000},{
      0.732051, 0.041452, 0.000000},{0.731540, 0.041452, -0.006485}}],
    Polygon[{{0.730022, 0.028643, 0.000000},{0.729537, 0.028800, 0.006485},{
      0.731540, 0.041452, 0.006485},{0.732051, 0.041452, 0.000000}}],
    Polygon[{{0.729537, 0.028800, 0.006485},{0.728092, 0.029269, 0.012809},{
      0.730022, 0.041452, 0.012809},{0.731540, 0.041452, 0.006485}}],
    Polygon[{{0.728092, 0.029269, 0.012809},{0.725725, 0.030039, 0.018819},{
      0.727533, 0.041452, 0.018819},{0.730022, 0.041452, 0.012809}}],
    Polygon[{{0.725725, 0.030039, 0.018819},{0.722493, 0.031089, 0.024365},{
      0.724134, 0.041452, 0.024365},{0.727533, 0.041452, 0.018819}}],
    Polygon[{{0.722493, 0.031089, 0.024365},{0.718475, 0.032394, 0.029311},{
      0.719910, 0.041452, 0.029311},{0.724134, 0.041452, 0.024365}}],
    Polygon[{{0.718475, 0.032394, 0.029311},{0.713771, 0.033923, 0.033535},{
      0.714964, 0.041452, 0.033535},{0.719910, 0.041452, 0.029311}}],
    Polygon[{{0.713771, 0.033923, 0.033535},{0.708497, 0.035637, 0.036934},{
      0.709418, 0.041452, 0.036934},{0.714964, 0.041452, 0.033535}}],
    Polygon[{{0.708497, 0.035637, 0.036934},{0.702781, 0.037494, 0.039423},{
      0.703408, 0.041452, 0.039423},{0.709418, 0.041452, 0.036934}}],
    Polygon[{{0.702781, 0.037494, 0.039423},{0.696766, 0.039448, 0.040942},{
      0.697083, 0.041452, 0.040942},{0.703408, 0.041452, 0.039423}}],
    Polygon[{{0.760017, 0.025783, -0.025466},{0.763951, 0.025783, -0.024521},{
      0.763561, 0.028246, -0.024521},{0.759819, 0.027030, -0.025466}}],
    Polygon[{{0.763951, 0.025783, -0.024521},{0.767689, 0.025783, -0.022973},{
      0.767116, 0.029401, -0.022973},{0.763561, 0.028246, -0.024521}}],
    Polygon[{{0.767689, 0.025783, -0.022973},{0.771138, 0.025783, -0.020859},{
      0.770396, 0.030467, -0.020859},{0.767116, 0.029401, -0.022973}}],
    Polygon[{{0.771138, 0.025783, -0.020859},{0.774215, 0.025783, -0.018232},{
      0.773322, 0.031417, -0.018232},{0.770396, 0.030467, -0.020859}}],
    Polygon[{{0.774215, 0.025783, -0.018232},{0.776842, 0.025783, -0.015155},{
      0.775821, 0.032229, -0.015155},{0.773322, 0.031417, -0.018232}}],
    Polygon[{{0.776842, 0.025783, -0.015155},{0.778956, 0.025783, -0.011705},{
      0.777832, 0.032883, -0.011705},{0.775821, 0.032229, -0.015155}}],
    Polygon[{{0.778956, 0.025783, -0.011705},{0.780505, 0.025783, -0.007968},{
      0.779304, 0.033361, -0.007968},{0.777832, 0.032883, -0.011705}}],
    Polygon[{{0.780505, 0.025783, -0.007968},{0.781449, 0.025783, -0.004033},{
      0.780203, 0.033653, -0.004033},{0.779304, 0.033361, -0.007968}}],
    Polygon[{{0.781449, 0.025783, -0.004033},{0.781766, 0.025783, 0.000000},{
      0.780505, 0.033751, 0.000000},{0.780203, 0.033653, -0.004033}}],
    Polygon[{{0.781766, 0.025783, 0.000000},{0.781449, 0.025783, 0.004033},{
      0.780203, 0.033653, 0.004033},{0.780505, 0.033751, 0.000000}}],
    Polygon[{{0.781449, 0.025783, 0.004033},{0.780505, 0.025783, 0.007968},{
      0.779304, 0.033361, 0.007968},{0.780203, 0.033653, 0.004033}}],
    Polygon[{{0.780505, 0.025783, 0.007968},{0.778956, 0.025783, 0.011705},{
      0.777832, 0.032883, 0.011705},{0.779304, 0.033361, 0.007968}}],
    Polygon[{{0.778956, 0.025783, 0.011705},{0.776842, 0.025783, 0.015155},{
      0.775821, 0.032229, 0.015155},{0.777832, 0.032883, 0.011705}}],
    Polygon[{{0.776842, 0.025783, 0.015155},{0.774215, 0.025783, 0.018232},{
      0.773322, 0.031417, 0.018232},{0.775821, 0.032229, 0.015155}}],
    Polygon[{{0.774215, 0.025783, 0.018232},{0.771138, 0.025783, 0.020859},{
      0.770396, 0.030467, 0.020859},{0.773322, 0.031417, 0.018232}}],
    Polygon[{{0.771138, 0.025783, 0.020859},{0.767689, 0.025783, 0.022973},{
      0.767116, 0.029401, 0.022973},{0.770396, 0.030467, 0.020859}}],
    Polygon[{{0.767689, 0.025783, 0.022973},{0.763951, 0.025783, 0.024521},{
      0.763561, 0.028246, 0.024521},{0.767116, 0.029401, 0.022973}}],
    Polygon[{{0.763951, 0.025783, 0.024521},{0.760017, 0.025783, 0.025466},{
      0.759819, 0.027030, 0.025466},{0.763561, 0.028246, 0.024521}}],
    Polygon[{{0.759819, 0.027030, -0.025466},{0.763561, 0.028246, -0.024521},{
      0.762429, 0.030467, -0.024521},{0.759246, 0.028154, -0.025466}}],
    Polygon[{{0.763561, 0.028246, -0.024521},{0.767116, 0.029401, -0.022973},{
      0.765453, 0.032664, -0.022973},{0.762429, 0.030467, -0.024521}}],
    Polygon[{{0.767116, 0.029401, -0.022973},{0.770396, 0.030467, -0.020859},{
      0.768244, 0.034691, -0.020859},{0.765453, 0.032664, -0.022973}}],
    Polygon[{{0.770396, 0.030467, -0.020859},{0.773322, 0.031417, -0.018232},{
      0.770733, 0.036500, -0.018232},{0.768244, 0.034691, -0.020859}}],
    Polygon[{{0.773322, 0.031417, -0.018232},{0.775821, 0.032229, -0.015155},{
      0.772859, 0.038044, -0.015155},{0.770733, 0.036500, -0.018232}}],
    Polygon[{{0.775821, 0.032229, -0.015155},{0.777832, 0.032883, -0.011705},{
      0.774569, 0.039287, -0.011705},{0.772859, 0.038044, -0.015155}}],
    Polygon[{{0.777832, 0.032883, -0.011705},{0.779304, 0.033361, -0.007968},{
      0.775821, 0.040197, -0.007968},{0.774569, 0.039287, -0.011705}}],
    Polygon[{{0.779304, 0.033361, -0.007968},{0.780203, 0.033653, -0.004033},{
      0.776585, 0.040752, -0.004033},{0.775821, 0.040197, -0.007968}}],
    Polygon[{{0.780203, 0.033653, -0.004033},{0.780505, 0.033751, 0.000000},{
      0.776842, 0.040939, 0.000000},{0.776585, 0.040752, -0.004033}}],
    Polygon[{{0.780505, 0.033751, 0.000000},{0.780203, 0.033653, 0.004033},{
      0.776585, 0.040752, 0.004033},{0.776842, 0.040939, 0.000000}}],
    Polygon[{{0.780203, 0.033653, 0.004033},{0.779304, 0.033361, 0.007968},{
      0.775821, 0.040197, 0.007968},{0.776585, 0.040752, 0.004033}}],
    Polygon[{{0.779304, 0.033361, 0.007968},{0.777832, 0.032883, 0.011705},{
      0.774569, 0.039287, 0.011705},{0.775821, 0.040197, 0.007968}}],
    Polygon[{{0.777832, 0.032883, 0.011705},{0.775821, 0.032229, 0.015155},{
      0.772859, 0.038044, 0.015155},{0.774569, 0.039287, 0.011705}}],
    Polygon[{{0.775821, 0.032229, 0.015155},{0.773322, 0.031417, 0.018232},{
      0.770733, 0.036500, 0.018232},{0.772859, 0.038044, 0.015155}}],
    Polygon[{{0.773322, 0.031417, 0.018232},{0.770396, 0.030467, 0.020859},{
      0.768244, 0.034691, 0.020859},{0.770733, 0.036500, 0.018232}}],
    Polygon[{{0.770396, 0.030467, 0.020859},{0.767116, 0.029401, 0.022973},{
      0.765453, 0.032664, 0.022973},{0.768244, 0.034691, 0.020859}}],
    Polygon[{{0.767116, 0.029401, 0.022973},{0.763561, 0.028246, 0.024521},{
      0.762429, 0.030467, 0.024521},{0.765453, 0.032664, 0.022973}}],
    Polygon[{{0.763561, 0.028246, 0.024521},{0.759819, 0.027030, 0.025466},{
      0.759246, 0.028154, 0.025466},{0.762429, 0.030467, 0.024521}}],
    Polygon[{{0.759246, 0.028154, -0.025466},{0.762429, 0.030467, -0.024521},{
      0.760666, 0.032229, -0.024521},{0.758354, 0.029047, -0.025466}}],
    Polygon[{{0.762429, 0.030467, -0.024521},{0.765453, 0.032664, -0.022973},{
      0.762863, 0.035253, -0.022973},{0.760666, 0.032229, -0.024521}}],
    Polygon[{{0.765453, 0.032664, -0.022973},{0.768244, 0.034691, -0.020859},{
      0.764891, 0.038044, -0.020859},{0.762863, 0.035253, -0.022973}}],
    Polygon[{{0.768244, 0.034691, -0.020859},{0.770733, 0.036500, -0.018232},{
      0.766699, 0.040533, -0.018232},{0.764891, 0.038044, -0.020859}}],
    Polygon[{{0.770733, 0.036500, -0.018232},{0.772859, 0.038044, -0.015155},{
      0.768244, 0.042659, -0.015155},{0.766699, 0.040533, -0.018232}}],
    Polygon[{{0.772859, 0.038044, -0.015155},{0.774569, 0.039287, -0.011705},{
      0.769486, 0.044369, -0.011705},{0.768244, 0.042659, -0.015155}}],
    Polygon[{{0.774569, 0.039287, -0.011705},{0.775821, 0.040197, -0.007968},{
      0.770396, 0.045622, -0.007968},{0.769486, 0.044369, -0.011705}}],
    Polygon[{{0.775821, 0.040197, -0.007968},{0.776585, 0.040752, -0.004033},{
      0.770952, 0.046386, -0.004033},{0.770396, 0.045622, -0.007968}}],
    Polygon[{{0.776585, 0.040752, -0.004033},{0.776842, 0.040939, 0.000000},{
      0.771138, 0.046643, 0.000000},{0.770952, 0.046386, -0.004033}}],
    Polygon[{{0.776842, 0.040939, 0.000000},{0.776585, 0.040752, 0.004033},{
      0.770952, 0.046386, 0.004033},{0.771138, 0.046643, 0.000000}}],
    Polygon[{{0.776585, 0.040752, 0.004033},{0.775821, 0.040197, 0.007968},{
      0.770396, 0.045622, 0.007968},{0.770952, 0.046386, 0.004033}}],
    Polygon[{{0.775821, 0.040197, 0.007968},{0.774569, 0.039287, 0.011705},{
      0.769486, 0.044369, 0.011705},{0.770396, 0.045622, 0.007968}}],
    Polygon[{{0.774569, 0.039287, 0.011705},{0.772859, 0.038044, 0.015155},{
      0.768244, 0.042659, 0.015155},{0.769486, 0.044369, 0.011705}}],
    Polygon[{{0.772859, 0.038044, 0.015155},{0.770733, 0.036500, 0.018232},{
      0.766699, 0.040533, 0.018232},{0.768244, 0.042659, 0.015155}}],
    Polygon[{{0.770733, 0.036500, 0.018232},{0.768244, 0.034691, 0.020859},{
      0.764891, 0.038044, 0.020859},{0.766699, 0.040533, 0.018232}}],
    Polygon[{{0.768244, 0.034691, 0.020859},{0.765453, 0.032664, 0.022973},{
      0.762863, 0.035253, 0.022973},{0.764891, 0.038044, 0.020859}}],
    Polygon[{{0.765453, 0.032664, 0.022973},{0.762429, 0.030467, 0.024521},{
      0.760666, 0.032229, 0.024521},{0.762863, 0.035253, 0.022973}}],
    Polygon[{{0.762429, 0.030467, 0.024521},{0.759246, 0.028154, 0.025466},{
      0.758354, 0.029047, 0.025466},{0.760666, 0.032229, 0.024521}}],
    Polygon[{{0.758354, 0.029047, -0.025466},{0.760666, 0.032229, -0.024521},{
      0.758445, 0.033361, -0.024521},{0.757229, 0.029619, -0.025466}}],
    Polygon[{{0.760666, 0.032229, -0.024521},{0.762863, 0.035253, -0.022973},{
      0.759600, 0.036916, -0.022973},{0.758445, 0.033361, -0.024521}}],
    Polygon[{{0.762863, 0.035253, -0.022973},{0.764891, 0.038044, -0.020859},{
      0.760666, 0.040197, -0.020859},{0.759600, 0.036916, -0.022973}}],
    Polygon[{{0.764891, 0.038044, -0.020859},{0.766699, 0.040533, -0.018232},{
      0.761617, 0.043123, -0.018232},{0.760666, 0.040197, -0.020859}}],
    Polygon[{{0.766699, 0.040533, -0.018232},{0.768244, 0.042659, -0.015155},{
      0.762429, 0.045622, -0.015155},{0.761617, 0.043123, -0.018232}}],
    Polygon[{{0.768244, 0.042659, -0.015155},{0.769486, 0.044369, -0.011705},{
      0.763082, 0.047632, -0.011705},{0.762429, 0.045622, -0.015155}}],
    Polygon[{{0.769486, 0.044369, -0.011705},{0.770396, 0.045622, -0.007968},{
      0.763561, 0.049105, -0.007968},{0.763082, 0.047632, -0.011705}}],
    Polygon[{{0.770396, 0.045622, -0.007968},{0.770952, 0.046386, -0.004033},{
      0.763852, 0.050003, -0.004033},{0.763561, 0.049105, -0.007968}}],
    Polygon[{{0.770952, 0.046386, -0.004033},{0.771138, 0.046643, 0.000000},{
      0.763951, 0.050305, 0.000000},{0.763852, 0.050003, -0.004033}}],
    Polygon[{{0.771138, 0.046643, 0.000000},{0.770952, 0.046386, 0.004033},{
      0.763852, 0.050003, 0.004033},{0.763951, 0.050305, 0.000000}}],
    Polygon[{{0.770952, 0.046386, 0.004033},{0.770396, 0.045622, 0.007968},{
      0.763561, 0.049105, 0.007968},{0.763852, 0.050003, 0.004033}}],
    Polygon[{{0.770396, 0.045622, 0.007968},{0.769486, 0.044369, 0.011705},{
      0.763082, 0.047632, 0.011705},{0.763561, 0.049105, 0.007968}}],
    Polygon[{{0.769486, 0.044369, 0.011705},{0.768244, 0.042659, 0.015155},{
      0.762429, 0.045622, 0.015155},{0.763082, 0.047632, 0.011705}}],
    Polygon[{{0.768244, 0.042659, 0.015155},{0.766699, 0.040533, 0.018232},{
      0.761617, 0.043123, 0.018232},{0.762429, 0.045622, 0.015155}}],
    Polygon[{{0.766699, 0.040533, 0.018232},{0.764891, 0.038044, 0.020859},{
      0.760666, 0.040197, 0.020859},{0.761617, 0.043123, 0.018232}}],
    Polygon[{{0.764891, 0.038044, 0.020859},{0.762863, 0.035253, 0.022973},{
      0.759600, 0.036916, 0.022973},{0.760666, 0.040197, 0.020859}}],
    Polygon[{{0.762863, 0.035253, 0.022973},{0.760666, 0.032229, 0.024521},{
      0.758445, 0.033361, 0.024521},{0.759600, 0.036916, 0.022973}}],
    Polygon[{{0.760666, 0.032229, 0.024521},{0.758354, 0.029047, 0.025466},{
      0.757229, 0.029619, 0.025466},{0.758445, 0.033361, 0.024521}}],
    Polygon[{{0.757229, 0.029619, -0.025466},{0.758445, 0.033361, -0.024521},{
      0.755983, 0.033751, -0.024521},{0.755983, 0.029817, -0.025466}}],
    Polygon[{{0.758445, 0.033361, -0.024521},{0.759600, 0.036916, -0.022973},{
      0.755983, 0.037489, -0.022973},{0.755983, 0.033751, -0.024521}}],
    Polygon[{{0.759600, 0.036916, -0.022973},{0.760666, 0.040197, -0.020859},{
      0.755983, 0.040939, -0.020859},{0.755983, 0.037489, -0.022973}}],
    Polygon[{{0.760666, 0.040197, -0.020859},{0.761617, 0.043123, -0.018232},{
      0.755983, 0.044015, -0.018232},{0.755983, 0.040939, -0.020859}}],
    Polygon[{{0.761617, 0.043123, -0.018232},{0.762429, 0.045622, -0.015155},{
      0.755983, 0.046643, -0.015155},{0.755983, 0.044015, -0.018232}}],
    Polygon[{{0.762429, 0.045622, -0.015155},{0.763082, 0.047632, -0.011705},{
      0.755983, 0.048757, -0.011705},{0.755983, 0.046643, -0.015155}}],
    Polygon[{{0.763082, 0.047632, -0.011705},{0.763561, 0.049105, -0.007968},{
      0.755983, 0.050305, -0.007968},{0.755983, 0.048757, -0.011705}}],
    Polygon[{{0.763561, 0.049105, -0.007968},{0.763852, 0.050003, -0.004033},{
      0.755983, 0.051249, -0.004033},{0.755983, 0.050305, -0.007968}}],
    Polygon[{{0.763852, 0.050003, -0.004033},{0.763951, 0.050305, 0.000000},{
      0.755983, 0.051567, 0.000000},{0.755983, 0.051249, -0.004033}}],
    Polygon[{{0.763951, 0.050305, 0.000000},{0.763852, 0.050003, 0.004033},{
      0.755983, 0.051249, 0.004033},{0.755983, 0.051567, 0.000000}}],
    Polygon[{{0.763852, 0.050003, 0.004033},{0.763561, 0.049105, 0.007968},{
      0.755983, 0.050305, 0.007968},{0.755983, 0.051249, 0.004033}}],
    Polygon[{{0.763561, 0.049105, 0.007968},{0.763082, 0.047632, 0.011705},{
      0.755983, 0.048757, 0.011705},{0.755983, 0.050305, 0.007968}}],
    Polygon[{{0.763082, 0.047632, 0.011705},{0.762429, 0.045622, 0.015155},{
      0.755983, 0.046643, 0.015155},{0.755983, 0.048757, 0.011705}}],
    Polygon[{{0.762429, 0.045622, 0.015155},{0.761617, 0.043123, 0.018232},{
      0.755983, 0.044015, 0.018232},{0.755983, 0.046643, 0.015155}}],
    Polygon[{{0.761617, 0.043123, 0.018232},{0.760666, 0.040197, 0.020859},{
      0.755983, 0.040939, 0.020859},{0.755983, 0.044015, 0.018232}}],
    Polygon[{{0.760666, 0.040197, 0.020859},{0.759600, 0.036916, 0.022973},{
      0.755983, 0.037489, 0.022973},{0.755983, 0.040939, 0.020859}}],
    Polygon[{{0.759600, 0.036916, 0.022973},{0.758445, 0.033361, 0.024521},{
      0.755983, 0.033751, 0.024521},{0.755983, 0.037489, 0.022973}}],
    Polygon[{{0.758445, 0.033361, 0.024521},{0.757229, 0.029619, 0.025466},{
      0.755983, 0.029817, 0.025466},{0.755983, 0.033751, 0.024521}}],
    Polygon[{{0.755983, 0.029817, -0.025466},{0.755983, 0.033751, -0.024521},{
      0.753521, 0.033361, -0.024521},{0.754737, 0.029619, -0.025466}}],
    Polygon[{{0.755983, 0.033751, -0.024521},{0.755983, 0.037489, -0.022973},{
      0.752366, 0.036916, -0.022973},{0.753521, 0.033361, -0.024521}}],
    Polygon[{{0.755983, 0.037489, -0.022973},{0.755983, 0.040939, -0.020859},{
      0.751300, 0.040197, -0.020859},{0.752366, 0.036916, -0.022973}}],
    Polygon[{{0.755983, 0.040939, -0.020859},{0.755983, 0.044015, -0.018232},{
      0.750349, 0.043123, -0.018232},{0.751300, 0.040197, -0.020859}}],
    Polygon[{{0.755983, 0.044015, -0.018232},{0.755983, 0.046643, -0.015155},{
      0.749537, 0.045622, -0.015155},{0.750349, 0.043123, -0.018232}}],
    Polygon[{{0.755983, 0.046643, -0.015155},{0.755983, 0.048757, -0.011705},{
      0.748884, 0.047632, -0.011705},{0.749537, 0.045622, -0.015155}}],
    Polygon[{{0.755983, 0.048757, -0.011705},{0.755983, 0.050305, -0.007968},{
      0.748406, 0.049105, -0.007968},{0.748884, 0.047632, -0.011705}}],
    Polygon[{{0.755983, 0.050305, -0.007968},{0.755983, 0.051249, -0.004033},{
      0.748114, 0.050003, -0.004033},{0.748406, 0.049105, -0.007968}}],
    Polygon[{{0.755983, 0.051249, -0.004033},{0.755983, 0.051567, 0.000000},{
      0.748016, 0.050305, 0.000000},{0.748114, 0.050003, -0.004033}}],
    Polygon[{{0.755983, 0.051567, 0.000000},{0.755983, 0.051249, 0.004033},{
      0.748114, 0.050003, 0.004033},{0.748016, 0.050305, 0.000000}}],
    Polygon[{{0.755983, 0.051249, 0.004033},{0.755983, 0.050305, 0.007968},{
      0.748406, 0.049105, 0.007968},{0.748114, 0.050003, 0.004033}}],
    Polygon[{{0.755983, 0.050305, 0.007968},{0.755983, 0.048757, 0.011705},{
      0.748884, 0.047632, 0.011705},{0.748406, 0.049105, 0.007968}}],
    Polygon[{{0.755983, 0.048757, 0.011705},{0.755983, 0.046643, 0.015155},{
      0.749537, 0.045622, 0.015155},{0.748884, 0.047632, 0.011705}}],
    Polygon[{{0.755983, 0.046643, 0.015155},{0.755983, 0.044015, 0.018232},{
      0.750349, 0.043123, 0.018232},{0.749537, 0.045622, 0.015155}}],
    Polygon[{{0.755983, 0.044015, 0.018232},{0.755983, 0.040939, 0.020859},{
      0.751300, 0.040197, 0.020859},{0.750349, 0.043123, 0.018232}}],
    Polygon[{{0.755983, 0.040939, 0.020859},{0.755983, 0.037489, 0.022973},{
      0.752366, 0.036916, 0.022973},{0.751300, 0.040197, 0.020859}}],
    Polygon[{{0.755983, 0.037489, 0.022973},{0.755983, 0.033751, 0.024521},{
      0.753521, 0.033361, 0.024521},{0.752366, 0.036916, 0.022973}}],
    Polygon[{{0.755983, 0.033751, 0.024521},{0.755983, 0.029817, 0.025466},{
      0.754737, 0.029619, 0.025466},{0.753521, 0.033361, 0.024521}}],
    Polygon[{{0.754737, 0.029619, -0.025466},{0.753521, 0.033361, -0.024521},{
      0.751300, 0.032229, -0.024521},{0.753612, 0.029047, -0.025466}}],
    Polygon[{{0.753521, 0.033361, -0.024521},{0.752366, 0.036916, -0.022973},{
      0.749103, 0.035253, -0.022973},{0.751300, 0.032229, -0.024521}}],
    Polygon[{{0.752366, 0.036916, -0.022973},{0.751300, 0.040197, -0.020859},{
      0.747075, 0.038044, -0.020859},{0.749103, 0.035253, -0.022973}}],
    Polygon[{{0.751300, 0.040197, -0.020859},{0.750349, 0.043123, -0.018232},{
      0.745267, 0.040533, -0.018232},{0.747075, 0.038044, -0.020859}}],
    Polygon[{{0.750349, 0.043123, -0.018232},{0.749537, 0.045622, -0.015155},{
      0.743722, 0.042659, -0.015155},{0.745267, 0.040533, -0.018232}}],
    Polygon[{{0.749537, 0.045622, -0.015155},{0.748884, 0.047632, -0.011705},{
      0.742480, 0.044369, -0.011705},{0.743722, 0.042659, -0.015155}}],
    Polygon[{{0.748884, 0.047632, -0.011705},{0.748406, 0.049105, -0.007968},{
      0.741570, 0.045622, -0.007968},{0.742480, 0.044369, -0.011705}}],
    Polygon[{{0.748406, 0.049105, -0.007968},{0.748114, 0.050003, -0.004033},{
      0.741015, 0.046386, -0.004033},{0.741570, 0.045622, -0.007968}}],
    Polygon[{{0.748114, 0.050003, -0.004033},{0.748016, 0.050305, 0.000000},{
      0.740828, 0.046643, 0.000000},{0.741015, 0.046386, -0.004033}}],
    Polygon[{{0.748016, 0.050305, 0.000000},{0.748114, 0.050003, 0.004033},{
      0.741015, 0.046386, 0.004033},{0.740828, 0.046643, 0.000000}}],
    Polygon[{{0.748114, 0.050003, 0.004033},{0.748406, 0.049105, 0.007968},{
      0.741570, 0.045622, 0.007968},{0.741015, 0.046386, 0.004033}}],
    Polygon[{{0.748406, 0.049105, 0.007968},{0.748884, 0.047632, 0.011705},{
      0.742480, 0.044369, 0.011705},{0.741570, 0.045622, 0.007968}}],
    Polygon[{{0.748884, 0.047632, 0.011705},{0.749537, 0.045622, 0.015155},{
      0.743722, 0.042659, 0.015155},{0.742480, 0.044369, 0.011705}}],
    Polygon[{{0.749537, 0.045622, 0.015155},{0.750349, 0.043123, 0.018232},{
      0.745267, 0.040533, 0.018232},{0.743722, 0.042659, 0.015155}}],
    Polygon[{{0.750349, 0.043123, 0.018232},{0.751300, 0.040197, 0.020859},{
      0.747075, 0.038044, 0.020859},{0.745267, 0.040533, 0.018232}}],
    Polygon[{{0.751300, 0.040197, 0.020859},{0.752366, 0.036916, 0.022973},{
      0.749103, 0.035253, 0.022973},{0.747075, 0.038044, 0.020859}}],
    Polygon[{{0.752366, 0.036916, 0.022973},{0.753521, 0.033361, 0.024521},{
      0.751300, 0.032229, 0.024521},{0.749103, 0.035253, 0.022973}}],
    Polygon[{{0.753521, 0.033361, 0.024521},{0.754737, 0.029619, 0.025466},{
      0.753612, 0.029047, 0.025466},{0.751300, 0.032229, 0.024521}}],
    Polygon[{{0.753612, 0.029047, -0.025466},{0.751300, 0.032229, -0.024521},{
      0.749537, 0.030467, -0.024521},{0.752720, 0.028154, -0.025466}}],
    Polygon[{{0.751300, 0.032229, -0.024521},{0.749103, 0.035253, -0.022973},{
      0.746513, 0.032664, -0.022973},{0.749537, 0.030467, -0.024521}}],
    Polygon[{{0.749103, 0.035253, -0.022973},{0.747075, 0.038044, -0.020859},{
      0.743722, 0.034691, -0.020859},{0.746513, 0.032664, -0.022973}}],
    Polygon[{{0.747075, 0.038044, -0.020859},{0.745267, 0.040533, -0.018232},{
      0.741233, 0.036500, -0.018232},{0.743722, 0.034691, -0.020859}}],
    Polygon[{{0.745267, 0.040533, -0.018232},{0.743722, 0.042659, -0.015155},{
      0.739108, 0.038044, -0.015155},{0.741233, 0.036500, -0.018232}}],
    Polygon[{{0.743722, 0.042659, -0.015155},{0.742480, 0.044369, -0.011705},{
      0.737397, 0.039287, -0.011705},{0.739108, 0.038044, -0.015155}}],
    Polygon[{{0.742480, 0.044369, -0.011705},{0.741570, 0.045622, -0.007968},{
      0.736145, 0.040197, -0.007968},{0.737397, 0.039287, -0.011705}}],
    Polygon[{{0.741570, 0.045622, -0.007968},{0.741015, 0.046386, -0.004033},{
      0.735381, 0.040752, -0.004033},{0.736145, 0.040197, -0.007968}}],
    Polygon[{{0.741015, 0.046386, -0.004033},{0.740828, 0.046643, 0.000000},{
      0.735124, 0.040939, 0.000000},{0.735381, 0.040752, -0.004033}}],
    Polygon[{{0.740828, 0.046643, 0.000000},{0.741015, 0.046386, 0.004033},{
      0.735381, 0.040752, 0.004033},{0.735124, 0.040939, 0.000000}}],
    Polygon[{{0.741015, 0.046386, 0.004033},{0.741570, 0.045622, 0.007968},{
      0.736145, 0.040197, 0.007968},{0.735381, 0.040752, 0.004033}}],
    Polygon[{{0.741570, 0.045622, 0.007968},{0.742480, 0.044369, 0.011705},{
      0.737397, 0.039287, 0.011705},{0.736145, 0.040197, 0.007968}}],
    Polygon[{{0.742480, 0.044369, 0.011705},{0.743722, 0.042659, 0.015155},{
      0.739108, 0.038044, 0.015155},{0.737397, 0.039287, 0.011705}}],
    Polygon[{{0.743722, 0.042659, 0.015155},{0.745267, 0.040533, 0.018232},{
      0.741233, 0.036500, 0.018232},{0.739108, 0.038044, 0.015155}}],
    Polygon[{{0.745267, 0.040533, 0.018232},{0.747075, 0.038044, 0.020859},{
      0.743722, 0.034691, 0.020859},{0.741233, 0.036500, 0.018232}}],
    Polygon[{{0.747075, 0.038044, 0.020859},{0.749103, 0.035253, 0.022973},{
      0.746513, 0.032664, 0.022973},{0.743722, 0.034691, 0.020859}}],
    Polygon[{{0.749103, 0.035253, 0.022973},{0.751300, 0.032229, 0.024521},{
      0.749537, 0.030467, 0.024521},{0.746513, 0.032664, 0.022973}}],
    Polygon[{{0.751300, 0.032229, 0.024521},{0.753612, 0.029047, 0.025466},{
      0.752720, 0.028154, 0.025466},{0.749537, 0.030467, 0.024521}}],
    Polygon[{{0.752720, 0.028154, -0.025466},{0.749537, 0.030467, -0.024521},{
      0.748406, 0.028246, -0.024521},{0.752147, 0.027030, -0.025466}}],
    Polygon[{{0.749537, 0.030467, -0.024521},{0.746513, 0.032664, -0.022973},{
      0.744851, 0.029401, -0.022973},{0.748406, 0.028246, -0.024521}}],
    Polygon[{{0.746513, 0.032664, -0.022973},{0.743722, 0.034691, -0.020859},{
      0.741570, 0.030467, -0.020859},{0.744851, 0.029401, -0.022973}}],
    Polygon[{{0.743722, 0.034691, -0.020859},{0.741233, 0.036500, -0.018232},{
      0.738644, 0.031417, -0.018232},{0.741570, 0.030467, -0.020859}}],
    Polygon[{{0.741233, 0.036500, -0.018232},{0.739108, 0.038044, -0.015155},{
      0.736145, 0.032229, -0.015155},{0.738644, 0.031417, -0.018232}}],
    Polygon[{{0.739108, 0.038044, -0.015155},{0.737397, 0.039287, -0.011705},{
      0.734134, 0.032883, -0.011705},{0.736145, 0.032229, -0.015155}}],
    Polygon[{{0.737397, 0.039287, -0.011705},{0.736145, 0.040197, -0.007968},{
      0.732662, 0.033361, -0.007968},{0.734134, 0.032883, -0.011705}}],
    Polygon[{{0.736145, 0.040197, -0.007968},{0.735381, 0.040752, -0.004033},{
      0.731763, 0.033653, -0.004033},{0.732662, 0.033361, -0.007968}}],
    Polygon[{{0.735381, 0.040752, -0.004033},{0.735124, 0.040939, 0.000000},{
      0.731462, 0.033751, 0.000000},{0.731763, 0.033653, -0.004033}}],
    Polygon[{{0.735124, 0.040939, 0.000000},{0.735381, 0.040752, 0.004033},{
      0.731763, 0.033653, 0.004033},{0.731462, 0.033751, 0.000000}}],
    Polygon[{{0.735381, 0.040752, 0.004033},{0.736145, 0.040197, 0.007968},{
      0.732662, 0.033361, 0.007968},{0.731763, 0.033653, 0.004033}}],
    Polygon[{{0.736145, 0.040197, 0.007968},{0.737397, 0.039287, 0.011705},{
      0.734134, 0.032883, 0.011705},{0.732662, 0.033361, 0.007968}}],
    Polygon[{{0.737397, 0.039287, 0.011705},{0.739108, 0.038044, 0.015155},{
      0.736145, 0.032229, 0.015155},{0.734134, 0.032883, 0.011705}}],
    Polygon[{{0.739108, 0.038044, 0.015155},{0.741233, 0.036500, 0.018232},{
      0.738644, 0.031417, 0.018232},{0.736145, 0.032229, 0.015155}}],
    Polygon[{{0.741233, 0.036500, 0.018232},{0.743722, 0.034691, 0.020859},{
      0.741570, 0.030467, 0.020859},{0.738644, 0.031417, 0.018232}}],
    Polygon[{{0.743722, 0.034691, 0.020859},{0.746513, 0.032664, 0.022973},{
      0.744851, 0.029401, 0.022973},{0.741570, 0.030467, 0.020859}}],
    Polygon[{{0.746513, 0.032664, 0.022973},{0.749537, 0.030467, 0.024521},{
      0.748406, 0.028246, 0.024521},{0.744851, 0.029401, 0.022973}}],
    Polygon[{{0.749537, 0.030467, 0.024521},{0.752720, 0.028154, 0.025466},{
      0.752147, 0.027030, 0.025466},{0.748406, 0.028246, 0.024521}}],
    Polygon[{{0.752147, 0.027030, -0.025466},{0.748406, 0.028246, -0.024521},{
      0.748016, 0.025783, -0.024521},{0.751950, 0.025783, -0.025466}}],
    Polygon[{{0.748406, 0.028246, -0.024521},{0.744851, 0.029401, -0.022973},{
      0.744278, 0.025783, -0.022973},{0.748016, 0.025783, -0.024521}}],
    Polygon[{{0.744851, 0.029401, -0.022973},{0.741570, 0.030467, -0.020859},{
      0.740828, 0.025783, -0.020859},{0.744278, 0.025783, -0.022973}}],
    Polygon[{{0.741570, 0.030467, -0.020859},{0.738644, 0.031417, -0.018232},{
      0.737751, 0.025783, -0.018232},{0.740828, 0.025783, -0.020859}}],
    Polygon[{{0.738644, 0.031417, -0.018232},{0.736145, 0.032229, -0.015155},{
      0.735124, 0.025783, -0.015155},{0.737751, 0.025783, -0.018232}}],
    Polygon[{{0.736145, 0.032229, -0.015155},{0.734134, 0.032883, -0.011705},{
      0.733010, 0.025783, -0.011705},{0.735124, 0.025783, -0.015155}}],
    Polygon[{{0.734134, 0.032883, -0.011705},{0.732662, 0.033361, -0.007968},{
      0.731462, 0.025783, -0.007968},{0.733010, 0.025783, -0.011705}}],
    Polygon[{{0.732662, 0.033361, -0.007968},{0.731763, 0.033653, -0.004033},{
      0.730517, 0.025783, -0.004033},{0.731462, 0.025783, -0.007968}}],
    Polygon[{{0.731763, 0.033653, -0.004033},{0.731462, 0.033751, 0.000000},{
      0.730200, 0.025783, 0.000000},{0.730517, 0.025783, -0.004033}}],
    Polygon[{{0.731462, 0.033751, 0.000000},{0.731763, 0.033653, 0.004033},{
      0.730517, 0.025783, 0.004033},{0.730200, 0.025783, 0.000000}}],
    Polygon[{{0.731763, 0.033653, 0.004033},{0.732662, 0.033361, 0.007968},{
      0.731462, 0.025783, 0.007968},{0.730517, 0.025783, 0.004033}}],
    Polygon[{{0.732662, 0.033361, 0.007968},{0.734134, 0.032883, 0.011705},{
      0.733010, 0.025783, 0.011705},{0.731462, 0.025783, 0.007968}}],
    Polygon[{{0.734134, 0.032883, 0.011705},{0.736145, 0.032229, 0.015155},{
      0.735124, 0.025783, 0.015155},{0.733010, 0.025783, 0.011705}}],
    Polygon[{{0.736145, 0.032229, 0.015155},{0.738644, 0.031417, 0.018232},{
      0.737751, 0.025783, 0.018232},{0.735124, 0.025783, 0.015155}}],
    Polygon[{{0.738644, 0.031417, 0.018232},{0.741570, 0.030467, 0.020859},{
      0.740828, 0.025783, 0.020859},{0.737751, 0.025783, 0.018232}}],
    Polygon[{{0.741570, 0.030467, 0.020859},{0.744851, 0.029401, 0.022973},{
      0.744278, 0.025783, 0.022973},{0.740828, 0.025783, 0.020859}}],
    Polygon[{{0.744851, 0.029401, 0.022973},{0.748406, 0.028246, 0.024521},{
      0.748016, 0.025783, 0.024521},{0.744278, 0.025783, 0.022973}}],
    Polygon[{{0.748406, 0.028246, 0.024521},{0.752147, 0.027030, 0.025466},{
      0.751950, 0.025783, 0.025466},{0.748016, 0.025783, 0.024521}}],
    Polygon[{{0.751950, 0.025783, -0.025466},{0.748016, 0.025783, -0.024521},{
      0.748406, 0.023321, -0.024521},{0.752147, 0.024537, -0.025466}}],
    Polygon[{{0.748016, 0.025783, -0.024521},{0.744278, 0.025783, -0.022973},{
      0.744851, 0.022166, -0.022973},{0.748406, 0.023321, -0.024521}}],
    Polygon[{{0.744278, 0.025783, -0.022973},{0.740828, 0.025783, -0.020859},{
      0.741570, 0.021100, -0.020859},{0.744851, 0.022166, -0.022973}}],
    Polygon[{{0.740828, 0.025783, -0.020859},{0.737751, 0.025783, -0.018232},{
      0.738644, 0.020150, -0.018232},{0.741570, 0.021100, -0.020859}}],
    Polygon[{{0.737751, 0.025783, -0.018232},{0.735124, 0.025783, -0.015155},{
      0.736145, 0.019338, -0.015155},{0.738644, 0.020150, -0.018232}}],
    Polygon[{{0.735124, 0.025783, -0.015155},{0.733010, 0.025783, -0.011705},{
      0.734134, 0.018684, -0.011705},{0.736145, 0.019338, -0.015155}}],
    Polygon[{{0.733010, 0.025783, -0.011705},{0.731462, 0.025783, -0.007968},{
      0.732662, 0.018206, -0.007968},{0.734134, 0.018684, -0.011705}}],
    Polygon[{{0.731462, 0.025783, -0.007968},{0.730517, 0.025783, -0.004033},{
      0.731763, 0.017914, -0.004033},{0.732662, 0.018206, -0.007968}}],
    Polygon[{{0.730517, 0.025783, -0.004033},{0.730200, 0.025783, 0.000000},{
      0.731462, 0.017816, 0.000000},{0.731763, 0.017914, -0.004033}}],
    Polygon[{{0.730200, 0.025783, 0.000000},{0.730517, 0.025783, 0.004033},{
      0.731763, 0.017914, 0.004033},{0.731462, 0.017816, 0.000000}}],
    Polygon[{{0.730517, 0.025783, 0.004033},{0.731462, 0.025783, 0.007968},{
      0.732662, 0.018206, 0.007968},{0.731763, 0.017914, 0.004033}}],
    Polygon[{{0.731462, 0.025783, 0.007968},{0.733010, 0.025783, 0.011705},{
      0.734134, 0.018684, 0.011705},{0.732662, 0.018206, 0.007968}}],
    Polygon[{{0.733010, 0.025783, 0.011705},{0.735124, 0.025783, 0.015155},{
      0.736145, 0.019338, 0.015155},{0.734134, 0.018684, 0.011705}}],
    Polygon[{{0.735124, 0.025783, 0.015155},{0.737751, 0.025783, 0.018232},{
      0.738644, 0.020150, 0.018232},{0.736145, 0.019338, 0.015155}}],
    Polygon[{{0.737751, 0.025783, 0.018232},{0.740828, 0.025783, 0.020859},{
      0.741570, 0.021100, 0.020859},{0.738644, 0.020150, 0.018232}}],
    Polygon[{{0.740828, 0.025783, 0.020859},{0.744278, 0.025783, 0.022973},{
      0.744851, 0.022166, 0.022973},{0.741570, 0.021100, 0.020859}}],
    Polygon[{{0.744278, 0.025783, 0.022973},{0.748016, 0.025783, 0.024521},{
      0.748406, 0.023321, 0.024521},{0.744851, 0.022166, 0.022973}}],
    Polygon[{{0.748016, 0.025783, 0.024521},{0.751950, 0.025783, 0.025466},{
      0.752147, 0.024537, 0.025466},{0.748406, 0.023321, 0.024521}}],
    Polygon[{{0.752147, 0.024537, -0.025466},{0.748406, 0.023321, -0.024521},{
      0.749537, 0.021100, -0.024521},{0.752720, 0.023413, -0.025466}}],
    Polygon[{{0.748406, 0.023321, -0.024521},{0.744851, 0.022166, -0.022973},{
      0.746513, 0.018903, -0.022973},{0.749537, 0.021100, -0.024521}}],
    Polygon[{{0.744851, 0.022166, -0.022973},{0.741570, 0.021100, -0.020859},{
      0.743722, 0.016875, -0.020859},{0.746513, 0.018903, -0.022973}}],
    Polygon[{{0.741570, 0.021100, -0.020859},{0.738644, 0.020150, -0.018232},{
      0.741233, 0.015067, -0.018232},{0.743722, 0.016875, -0.020859}}],
    Polygon[{{0.738644, 0.020150, -0.018232},{0.736145, 0.019338, -0.015155},{
      0.739108, 0.013523, -0.015155},{0.741233, 0.015067, -0.018232}}],
    Polygon[{{0.736145, 0.019338, -0.015155},{0.734134, 0.018684, -0.011705},{
      0.737397, 0.012280, -0.011705},{0.739108, 0.013523, -0.015155}}],
    Polygon[{{0.734134, 0.018684, -0.011705},{0.732662, 0.018206, -0.007968},{
      0.736145, 0.011370, -0.007968},{0.737397, 0.012280, -0.011705}}],
    Polygon[{{0.732662, 0.018206, -0.007968},{0.731763, 0.017914, -0.004033},{
      0.735381, 0.010815, -0.004033},{0.736145, 0.011370, -0.007968}}],
    Polygon[{{0.731763, 0.017914, -0.004033},{0.731462, 0.017816, 0.000000},{
      0.735124, 0.010628, 0.000000},{0.735381, 0.010815, -0.004033}}],
    Polygon[{{0.731462, 0.017816, 0.000000},{0.731763, 0.017914, 0.004033},{
      0.735381, 0.010815, 0.004033},{0.735124, 0.010628, 0.000000}}],
    Polygon[{{0.731763, 0.017914, 0.004033},{0.732662, 0.018206, 0.007968},{
      0.736145, 0.011370, 0.007968},{0.735381, 0.010815, 0.004033}}],
    Polygon[{{0.732662, 0.018206, 0.007968},{0.734134, 0.018684, 0.011705},{
      0.737397, 0.012280, 0.011705},{0.736145, 0.011370, 0.007968}}],
    Polygon[{{0.734134, 0.018684, 0.011705},{0.736145, 0.019338, 0.015155},{
      0.739108, 0.013523, 0.015155},{0.737397, 0.012280, 0.011705}}],
    Polygon[{{0.736145, 0.019338, 0.015155},{0.738644, 0.020150, 0.018232},{
      0.741233, 0.015067, 0.018232},{0.739108, 0.013523, 0.015155}}],
    Polygon[{{0.738644, 0.020150, 0.018232},{0.741570, 0.021100, 0.020859},{
      0.743722, 0.016875, 0.020859},{0.741233, 0.015067, 0.018232}}],
    Polygon[{{0.741570, 0.021100, 0.020859},{0.744851, 0.022166, 0.022973},{
      0.746513, 0.018903, 0.022973},{0.743722, 0.016875, 0.020859}}],
    Polygon[{{0.744851, 0.022166, 0.022973},{0.748406, 0.023321, 0.024521},{
      0.749537, 0.021100, 0.024521},{0.746513, 0.018903, 0.022973}}],
    Polygon[{{0.748406, 0.023321, 0.024521},{0.752147, 0.024537, 0.025466},{
      0.752720, 0.023413, 0.025466},{0.749537, 0.021100, 0.024521}}],
    Polygon[{{0.752720, 0.023413, -0.025466},{0.749537, 0.021100, -0.024521},{
      0.751300, 0.019338, -0.024521},{0.753612, 0.022520, -0.025466}}],
    Polygon[{{0.749537, 0.021100, -0.024521},{0.746513, 0.018903, -0.022973},{
      0.749103, 0.016314, -0.022973},{0.751300, 0.019338, -0.024521}}],
    Polygon[{{0.746513, 0.018903, -0.022973},{0.743722, 0.016875, -0.020859},{
      0.747075, 0.013523, -0.020859},{0.749103, 0.016314, -0.022973}}],
    Polygon[{{0.743722, 0.016875, -0.020859},{0.741233, 0.015067, -0.018232},{
      0.745267, 0.011034, -0.018232},{0.747075, 0.013523, -0.020859}}],
    Polygon[{{0.741233, 0.015067, -0.018232},{0.739108, 0.013523, -0.015155},{
      0.743722, 0.008908, -0.015155},{0.745267, 0.011034, -0.018232}}],
    Polygon[{{0.739108, 0.013523, -0.015155},{0.737397, 0.012280, -0.011705},{
      0.742480, 0.007198, -0.011705},{0.743722, 0.008908, -0.015155}}],
    Polygon[{{0.737397, 0.012280, -0.011705},{0.736145, 0.011370, -0.007968},{
      0.741570, 0.005945, -0.007968},{0.742480, 0.007198, -0.011705}}],
    Polygon[{{0.736145, 0.011370, -0.007968},{0.735381, 0.010815, -0.004033},{
      0.741015, 0.005181, -0.004033},{0.741570, 0.005945, -0.007968}}],
    Polygon[{{0.735381, 0.010815, -0.004033},{0.735124, 0.010628, 0.000000},{
      0.740828, 0.004924, 0.000000},{0.741015, 0.005181, -0.004033}}],
    Polygon[{{0.735124, 0.010628, 0.000000},{0.735381, 0.010815, 0.004033},{
      0.741015, 0.005181, 0.004033},{0.740828, 0.004924, 0.000000}}],
    Polygon[{{0.735381, 0.010815, 0.004033},{0.736145, 0.011370, 0.007968},{
      0.741570, 0.005945, 0.007968},{0.741015, 0.005181, 0.004033}}],
    Polygon[{{0.736145, 0.011370, 0.007968},{0.737397, 0.012280, 0.011705},{
      0.742480, 0.007198, 0.011705},{0.741570, 0.005945, 0.007968}}],
    Polygon[{{0.737397, 0.012280, 0.011705},{0.739108, 0.013523, 0.015155},{
      0.743722, 0.008908, 0.015155},{0.742480, 0.007198, 0.011705}}],
    Polygon[{{0.739108, 0.013523, 0.015155},{0.741233, 0.015067, 0.018232},{
      0.745267, 0.011034, 0.018232},{0.743722, 0.008908, 0.015155}}],
    Polygon[{{0.741233, 0.015067, 0.018232},{0.743722, 0.016875, 0.020859},{
      0.747075, 0.013523, 0.020859},{0.745267, 0.011034, 0.018232}}],
    Polygon[{{0.743722, 0.016875, 0.020859},{0.746513, 0.018903, 0.022973},{
      0.749103, 0.016314, 0.022973},{0.747075, 0.013523, 0.020859}}],
    Polygon[{{0.746513, 0.018903, 0.022973},{0.749537, 0.021100, 0.024521},{
      0.751300, 0.019338, 0.024521},{0.749103, 0.016314, 0.022973}}],
    Polygon[{{0.749537, 0.021100, 0.024521},{0.752720, 0.023413, 0.025466},{
      0.753612, 0.022520, 0.025466},{0.751300, 0.019338, 0.024521}}],
    Polygon[{{0.753612, 0.022520, -0.025466},{0.751300, 0.019338, -0.024521},{
      0.753521, 0.018206, -0.024521},{0.754737, 0.021947, -0.025466}}],
    Polygon[{{0.751300, 0.019338, -0.024521},{0.749103, 0.016314, -0.022973},{
      0.752366, 0.014651, -0.022973},{0.753521, 0.018206, -0.024521}}],
    Polygon[{{0.749103, 0.016314, -0.022973},{0.747075, 0.013523, -0.020859},{
      0.751300, 0.011370, -0.020859},{0.752366, 0.014651, -0.022973}}],
    Polygon[{{0.747075, 0.013523, -0.020859},{0.745267, 0.011034, -0.018232},{
      0.750349, 0.008444, -0.018232},{0.751300, 0.011370, -0.020859}}],
    Polygon[{{0.745267, 0.011034, -0.018232},{0.743722, 0.008908, -0.015155},{
      0.749537, 0.005945, -0.015155},{0.750349, 0.008444, -0.018232}}],
    Polygon[{{0.743722, 0.008908, -0.015155},{0.742480, 0.007198, -0.011705},{
      0.748884, 0.003935, -0.011705},{0.749537, 0.005945, -0.015155}}],
    Polygon[{{0.742480, 0.007198, -0.011705},{0.741570, 0.005945, -0.007968},{
      0.748406, 0.002462, -0.007968},{0.748884, 0.003935, -0.011705}}],
    Polygon[{{0.741570, 0.005945, -0.007968},{0.741015, 0.005181, -0.004033},{
      0.748114, 0.001564, -0.004033},{0.748406, 0.002462, -0.007968}}],
    Polygon[{{0.741015, 0.005181, -0.004033},{0.740828, 0.004924, 0.000000},{
      0.748016, 0.001262, 0.000000},{0.748114, 0.001564, -0.004033}}],
    Polygon[{{0.740828, 0.004924, 0.000000},{0.741015, 0.005181, 0.004033},{
      0.748114, 0.001564, 0.004033},{0.748016, 0.001262, 0.000000}}],
    Polygon[{{0.741015, 0.005181, 0.004033},{0.741570, 0.005945, 0.007968},{
      0.748406, 0.002462, 0.007968},{0.748114, 0.001564, 0.004033}}],
    Polygon[{{0.741570, 0.005945, 0.007968},{0.742480, 0.007198, 0.011705},{
      0.748884, 0.003935, 0.011705},{0.748406, 0.002462, 0.007968}}],
    Polygon[{{0.742480, 0.007198, 0.011705},{0.743722, 0.008908, 0.015155},{
      0.749537, 0.005945, 0.015155},{0.748884, 0.003935, 0.011705}}],
    Polygon[{{0.743722, 0.008908, 0.015155},{0.745267, 0.011034, 0.018232},{
      0.750349, 0.008444, 0.018232},{0.749537, 0.005945, 0.015155}}],
    Polygon[{{0.745267, 0.011034, 0.018232},{0.747075, 0.013523, 0.020859},{
      0.751300, 0.011370, 0.020859},{0.750349, 0.008444, 0.018232}}],
    Polygon[{{0.747075, 0.013523, 0.020859},{0.749103, 0.016314, 0.022973},{
      0.752366, 0.014651, 0.022973},{0.751300, 0.011370, 0.020859}}],
    Polygon[{{0.749103, 0.016314, 0.022973},{0.751300, 0.019338, 0.024521},{
      0.753521, 0.018206, 0.024521},{0.752366, 0.014651, 0.022973}}],
    Polygon[{{0.751300, 0.019338, 0.024521},{0.753612, 0.022520, 0.025466},{
      0.754737, 0.021947, 0.025466},{0.753521, 0.018206, 0.024521}}],
    Polygon[{{0.754737, 0.021947, -0.025466},{0.753521, 0.018206, -0.024521},{
      0.755983, 0.017816, -0.024521},{0.755983, 0.021750, -0.025466}}],
    Polygon[{{0.753521, 0.018206, -0.024521},{0.752366, 0.014651, -0.022973},{
      0.755983, 0.014078, -0.022973},{0.755983, 0.017816, -0.024521}}],
    Polygon[{{0.752366, 0.014651, -0.022973},{0.751300, 0.011370, -0.020859},{
      0.755983, 0.010628, -0.020859},{0.755983, 0.014078, -0.022973}}],
    Polygon[{{0.751300, 0.011370, -0.020859},{0.750349, 0.008444, -0.018232},{
      0.755983, 0.007552, -0.018232},{0.755983, 0.010628, -0.020859}}],
    Polygon[{{0.750349, 0.008444, -0.018232},{0.749537, 0.005945, -0.015155},{
      0.755983, 0.004924, -0.015155},{0.755983, 0.007552, -0.018232}}],
    Polygon[{{0.749537, 0.005945, -0.015155},{0.748884, 0.003935, -0.011705},{
      0.755983, 0.002810, -0.011705},{0.755983, 0.004924, -0.015155}}],
    Polygon[{{0.748884, 0.003935, -0.011705},{0.748406, 0.002462, -0.007968},{
      0.755983, 0.001262, -0.007968},{0.755983, 0.002810, -0.011705}}],
    Polygon[{{0.748406, 0.002462, -0.007968},{0.748114, 0.001564, -0.004033},{
      0.755983, 0.000317, -0.004033},{0.755983, 0.001262, -0.007968}}],
    Polygon[{{0.748114, 0.001564, -0.004033},{0.748016, 0.001262, 0.000000},{
      0.755983, 0.000000, 0.000000},{0.755983, 0.000317, -0.004033}}],
    Polygon[{{0.748016, 0.001262, 0.000000},{0.748114, 0.001564, 0.004033},{
      0.755983, 0.000317, 0.004033},{0.755983, 0.000000, 0.000000}}],
    Polygon[{{0.748114, 0.001564, 0.004033},{0.748406, 0.002462, 0.007968},{
      0.755983, 0.001262, 0.007968},{0.755983, 0.000317, 0.004033}}],
    Polygon[{{0.748406, 0.002462, 0.007968},{0.748884, 0.003935, 0.011705},{
      0.755983, 0.002810, 0.011705},{0.755983, 0.001262, 0.007968}}],
    Polygon[{{0.748884, 0.003935, 0.011705},{0.749537, 0.005945, 0.015155},{
      0.755983, 0.004924, 0.015155},{0.755983, 0.002810, 0.011705}}],
    Polygon[{{0.749537, 0.005945, 0.015155},{0.750349, 0.008444, 0.018232},{
      0.755983, 0.007552, 0.018232},{0.755983, 0.004924, 0.015155}}],
    Polygon[{{0.750349, 0.008444, 0.018232},{0.751300, 0.011370, 0.020859},{
      0.755983, 0.010628, 0.020859},{0.755983, 0.007552, 0.018232}}],
    Polygon[{{0.751300, 0.011370, 0.020859},{0.752366, 0.014651, 0.022973},{
      0.755983, 0.014078, 0.022973},{0.755983, 0.010628, 0.020859}}],
    Polygon[{{0.752366, 0.014651, 0.022973},{0.753521, 0.018206, 0.024521},{
      0.755983, 0.017816, 0.024521},{0.755983, 0.014078, 0.022973}}],
    Polygon[{{0.753521, 0.018206, 0.024521},{0.754737, 0.021947, 0.025466},{
      0.755983, 0.021750, 0.025466},{0.755983, 0.017816, 0.024521}}],
    Polygon[{{0.755983, 0.021750, -0.025466},{0.755983, 0.017816, -0.024521},{
      0.758445, 0.018206, -0.024521},{0.757229, 0.021947, -0.025466}}],
    Polygon[{{0.755983, 0.017816, -0.024521},{0.755983, 0.014078, -0.022973},{
      0.759600, 0.014651, -0.022973},{0.758445, 0.018206, -0.024521}}],
    Polygon[{{0.755983, 0.014078, -0.022973},{0.755983, 0.010628, -0.020859},{
      0.760666, 0.011370, -0.020859},{0.759600, 0.014651, -0.022973}}],
    Polygon[{{0.755983, 0.010628, -0.020859},{0.755983, 0.007552, -0.018232},{
      0.761617, 0.008444, -0.018232},{0.760666, 0.011370, -0.020859}}],
    Polygon[{{0.755983, 0.007552, -0.018232},{0.755983, 0.004924, -0.015155},{
      0.762429, 0.005945, -0.015155},{0.761617, 0.008444, -0.018232}}],
    Polygon[{{0.755983, 0.004924, -0.015155},{0.755983, 0.002810, -0.011705},{
      0.763082, 0.003935, -0.011705},{0.762429, 0.005945, -0.015155}}],
    Polygon[{{0.755983, 0.002810, -0.011705},{0.755983, 0.001262, -0.007968},{
      0.763561, 0.002462, -0.007968},{0.763082, 0.003935, -0.011705}}],
    Polygon[{{0.755983, 0.001262, -0.007968},{0.755983, 0.000317, -0.004033},{
      0.763852, 0.001564, -0.004033},{0.763561, 0.002462, -0.007968}}],
    Polygon[{{0.755983, 0.000317, -0.004033},{0.755983, 0.000000, 0.000000},{
      0.763951, 0.001262, 0.000000},{0.763852, 0.001564, -0.004033}}],
    Polygon[{{0.755983, 0.000000, 0.000000},{0.755983, 0.000317, 0.004033},{
      0.763852, 0.001564, 0.004033},{0.763951, 0.001262, 0.000000}}],
    Polygon[{{0.755983, 0.000317, 0.004033},{0.755983, 0.001262, 0.007968},{
      0.763561, 0.002462, 0.007968},{0.763852, 0.001564, 0.004033}}],
    Polygon[{{0.755983, 0.001262, 0.007968},{0.755983, 0.002810, 0.011705},{
      0.763082, 0.003935, 0.011705},{0.763561, 0.002462, 0.007968}}],
    Polygon[{{0.755983, 0.002810, 0.011705},{0.755983, 0.004924, 0.015155},{
      0.762429, 0.005945, 0.015155},{0.763082, 0.003935, 0.011705}}],
    Polygon[{{0.755983, 0.004924, 0.015155},{0.755983, 0.007552, 0.018232},{
      0.761617, 0.008444, 0.018232},{0.762429, 0.005945, 0.015155}}],
    Polygon[{{0.755983, 0.007552, 0.018232},{0.755983, 0.010628, 0.020859},{
      0.760666, 0.011370, 0.020859},{0.761617, 0.008444, 0.018232}}],
    Polygon[{{0.755983, 0.010628, 0.020859},{0.755983, 0.014078, 0.022973},{
      0.759600, 0.014651, 0.022973},{0.760666, 0.011370, 0.020859}}],
    Polygon[{{0.755983, 0.014078, 0.022973},{0.755983, 0.017816, 0.024521},{
      0.758445, 0.018206, 0.024521},{0.759600, 0.014651, 0.022973}}],
    Polygon[{{0.755983, 0.017816, 0.024521},{0.755983, 0.021750, 0.025466},{
      0.757229, 0.021947, 0.025466},{0.758445, 0.018206, 0.024521}}],
    Polygon[{{0.757229, 0.021947, -0.025466},{0.758445, 0.018206, -0.024521},{
      0.760666, 0.019338, -0.024521},{0.758354, 0.022520, -0.025466}}],
    Polygon[{{0.758445, 0.018206, -0.024521},{0.759600, 0.014651, -0.022973},{
      0.762863, 0.016314, -0.022973},{0.760666, 0.019338, -0.024521}}],
    Polygon[{{0.759600, 0.014651, -0.022973},{0.760666, 0.011370, -0.020859},{
      0.764891, 0.013523, -0.020859},{0.762863, 0.016314, -0.022973}}],
    Polygon[{{0.760666, 0.011370, -0.020859},{0.761617, 0.008444, -0.018232},{
      0.766699, 0.011034, -0.018232},{0.764891, 0.013523, -0.020859}}],
    Polygon[{{0.761617, 0.008444, -0.018232},{0.762429, 0.005945, -0.015155},{
      0.768244, 0.008908, -0.015155},{0.766699, 0.011034, -0.018232}}],
    Polygon[{{0.762429, 0.005945, -0.015155},{0.763082, 0.003935, -0.011705},{
      0.769486, 0.007198, -0.011705},{0.768244, 0.008908, -0.015155}}],
    Polygon[{{0.763082, 0.003935, -0.011705},{0.763561, 0.002462, -0.007968},{
      0.770396, 0.005945, -0.007968},{0.769486, 0.007198, -0.011705}}],
    Polygon[{{0.763561, 0.002462, -0.007968},{0.763852, 0.001564, -0.004033},{
      0.770952, 0.005181, -0.004033},{0.770396, 0.005945, -0.007968}}],
    Polygon[{{0.763852, 0.001564, -0.004033},{0.763951, 0.001262, 0.000000},{
      0.771138, 0.004924, 0.000000},{0.770952, 0.005181, -0.004033}}],
    Polygon[{{0.763951, 0.001262, 0.000000},{0.763852, 0.001564, 0.004033},{
      0.770952, 0.005181, 0.004033},{0.771138, 0.004924, 0.000000}}],
    Polygon[{{0.763852, 0.001564, 0.004033},{0.763561, 0.002462, 0.007968},{
      0.770396, 0.005945, 0.007968},{0.770952, 0.005181, 0.004033}}],
    Polygon[{{0.763561, 0.002462, 0.007968},{0.763082, 0.003935, 0.011705},{
      0.769486, 0.007198, 0.011705},{0.770396, 0.005945, 0.007968}}],
    Polygon[{{0.763082, 0.003935, 0.011705},{0.762429, 0.005945, 0.015155},{
      0.768244, 0.008908, 0.015155},{0.769486, 0.007198, 0.011705}}],
    Polygon[{{0.762429, 0.005945, 0.015155},{0.761617, 0.008444, 0.018232},{
      0.766699, 0.011034, 0.018232},{0.768244, 0.008908, 0.015155}}],
    Polygon[{{0.761617, 0.008444, 0.018232},{0.760666, 0.011370, 0.020859},{
      0.764891, 0.013523, 0.020859},{0.766699, 0.011034, 0.018232}}],
    Polygon[{{0.760666, 0.011370, 0.020859},{0.759600, 0.014651, 0.022973},{
      0.762863, 0.016314, 0.022973},{0.764891, 0.013523, 0.020859}}],
    Polygon[{{0.759600, 0.014651, 0.022973},{0.758445, 0.018206, 0.024521},{
      0.760666, 0.019338, 0.024521},{0.762863, 0.016314, 0.022973}}],
    Polygon[{{0.758445, 0.018206, 0.024521},{0.757229, 0.021947, 0.025466},{
      0.758354, 0.022520, 0.025466},{0.760666, 0.019338, 0.024521}}],
    Polygon[{{0.758354, 0.022520, -0.025466},{0.760666, 0.019338, -0.024521},{
      0.762429, 0.021100, -0.024521},{0.759246, 0.023413, -0.025466}}],
    Polygon[{{0.760666, 0.019338, -0.024521},{0.762863, 0.016314, -0.022973},{
      0.765453, 0.018903, -0.022973},{0.762429, 0.021100, -0.024521}}],
    Polygon[{{0.762863, 0.016314, -0.022973},{0.764891, 0.013523, -0.020859},{
      0.768244, 0.016875, -0.020859},{0.765453, 0.018903, -0.022973}}],
    Polygon[{{0.764891, 0.013523, -0.020859},{0.766699, 0.011034, -0.018232},{
      0.770733, 0.015067, -0.018232},{0.768244, 0.016875, -0.020859}}],
    Polygon[{{0.766699, 0.011034, -0.018232},{0.768244, 0.008908, -0.015155},{
      0.772859, 0.013523, -0.015155},{0.770733, 0.015067, -0.018232}}],
    Polygon[{{0.768244, 0.008908, -0.015155},{0.769486, 0.007198, -0.011705},{
      0.774569, 0.012280, -0.011705},{0.772859, 0.013523, -0.015155}}],
    Polygon[{{0.769486, 0.007198, -0.011705},{0.770396, 0.005945, -0.007968},{
      0.775821, 0.011370, -0.007968},{0.774569, 0.012280, -0.011705}}],
    Polygon[{{0.770396, 0.005945, -0.007968},{0.770952, 0.005181, -0.004033},{
      0.776585, 0.010815, -0.004033},{0.775821, 0.011370, -0.007968}}],
    Polygon[{{0.770952, 0.005181, -0.004033},{0.771138, 0.004924, 0.000000},{
      0.776842, 0.010628, 0.000000},{0.776585, 0.010815, -0.004033}}],
    Polygon[{{0.771138, 0.004924, 0.000000},{0.770952, 0.005181, 0.004033},{
      0.776585, 0.010815, 0.004033},{0.776842, 0.010628, 0.000000}}],
    Polygon[{{0.770952, 0.005181, 0.004033},{0.770396, 0.005945, 0.007968},{
      0.775821, 0.011370, 0.007968},{0.776585, 0.010815, 0.004033}}],
    Polygon[{{0.770396, 0.005945, 0.007968},{0.769486, 0.007198, 0.011705},{
      0.774569, 0.012280, 0.011705},{0.775821, 0.011370, 0.007968}}],
    Polygon[{{0.769486, 0.007198, 0.011705},{0.768244, 0.008908, 0.015155},{
      0.772859, 0.013523, 0.015155},{0.774569, 0.012280, 0.011705}}],
    Polygon[{{0.768244, 0.008908, 0.015155},{0.766699, 0.011034, 0.018232},{
      0.770733, 0.015067, 0.018232},{0.772859, 0.013523, 0.015155}}],
    Polygon[{{0.766699, 0.011034, 0.018232},{0.764891, 0.013523, 0.020859},{
      0.768244, 0.016875, 0.020859},{0.770733, 0.015067, 0.018232}}],
    Polygon[{{0.764891, 0.013523, 0.020859},{0.762863, 0.016314, 0.022973},{
      0.765453, 0.018903, 0.022973},{0.768244, 0.016875, 0.020859}}],
    Polygon[{{0.762863, 0.016314, 0.022973},{0.760666, 0.019338, 0.024521},{
      0.762429, 0.021100, 0.024521},{0.765453, 0.018903, 0.022973}}],
    Polygon[{{0.760666, 0.019338, 0.024521},{0.758354, 0.022520, 0.025466},{
      0.759246, 0.023413, 0.025466},{0.762429, 0.021100, 0.024521}}],
    Polygon[{{0.759246, 0.023413, -0.025466},{0.762429, 0.021100, -0.024521},{
      0.763561, 0.023321, -0.024521},{0.759819, 0.024537, -0.025466}}],
    Polygon[{{0.762429, 0.021100, -0.024521},{0.765453, 0.018903, -0.022973},{
      0.767116, 0.022166, -0.022973},{0.763561, 0.023321, -0.024521}}],
    Polygon[{{0.765453, 0.018903, -0.022973},{0.768244, 0.016875, -0.020859},{
      0.770396, 0.021100, -0.020859},{0.767116, 0.022166, -0.022973}}],
    Polygon[{{0.768244, 0.016875, -0.020859},{0.770733, 0.015067, -0.018232},{
      0.773322, 0.020150, -0.018232},{0.770396, 0.021100, -0.020859}}],
    Polygon[{{0.770733, 0.015067, -0.018232},{0.772859, 0.013523, -0.015155},{
      0.775821, 0.019338, -0.015155},{0.773322, 0.020150, -0.018232}}],
    Polygon[{{0.772859, 0.013523, -0.015155},{0.774569, 0.012280, -0.011705},{
      0.777832, 0.018684, -0.011705},{0.775821, 0.019338, -0.015155}}],
    Polygon[{{0.774569, 0.012280, -0.011705},{0.775821, 0.011370, -0.007968},{
      0.779304, 0.018206, -0.007968},{0.777832, 0.018684, -0.011705}}],
    Polygon[{{0.775821, 0.011370, -0.007968},{0.776585, 0.010815, -0.004033},{
      0.780203, 0.017914, -0.004033},{0.779304, 0.018206, -0.007968}}],
    Polygon[{{0.776585, 0.010815, -0.004033},{0.776842, 0.010628, 0.000000},{
      0.780505, 0.017816, 0.000000},{0.780203, 0.017914, -0.004033}}],
    Polygon[{{0.776842, 0.010628, 0.000000},{0.776585, 0.010815, 0.004033},{
      0.780203, 0.017914, 0.004033},{0.780505, 0.017816, 0.000000}}],
    Polygon[{{0.776585, 0.010815, 0.004033},{0.775821, 0.011370, 0.007968},{
      0.779304, 0.018206, 0.007968},{0.780203, 0.017914, 0.004033}}],
    Polygon[{{0.775821, 0.011370, 0.007968},{0.774569, 0.012280, 0.011705},{
      0.777832, 0.018684, 0.011705},{0.779304, 0.018206, 0.007968}}],
    Polygon[{{0.774569, 0.012280, 0.011705},{0.772859, 0.013523, 0.015155},{
      0.775821, 0.019338, 0.015155},{0.777832, 0.018684, 0.011705}}],
    Polygon[{{0.772859, 0.013523, 0.015155},{0.770733, 0.015067, 0.018232},{
      0.773322, 0.020150, 0.018232},{0.775821, 0.019338, 0.015155}}],
    Polygon[{{0.770733, 0.015067, 0.018232},{0.768244, 0.016875, 0.020859},{
      0.770396, 0.021100, 0.020859},{0.773322, 0.020150, 0.018232}}],
    Polygon[{{0.768244, 0.016875, 0.020859},{0.765453, 0.018903, 0.022973},{
      0.767116, 0.022166, 0.022973},{0.770396, 0.021100, 0.020859}}],
    Polygon[{{0.765453, 0.018903, 0.022973},{0.762429, 0.021100, 0.024521},{
      0.763561, 0.023321, 0.024521},{0.767116, 0.022166, 0.022973}}],
    Polygon[{{0.762429, 0.021100, 0.024521},{0.759246, 0.023413, 0.025466},{
      0.759819, 0.024537, 0.025466},{0.763561, 0.023321, 0.024521}}],
    Polygon[{{0.759819, 0.024537, -0.025466},{0.763561, 0.023321, -0.024521},{
      0.763951, 0.025783, -0.024521},{0.760017, 0.025783, -0.025466}}],
    Polygon[{{0.763561, 0.023321, -0.024521},{0.767116, 0.022166, -0.022973},{
      0.767689, 0.025783, -0.022973},{0.763951, 0.025783, -0.024521}}],
    Polygon[{{0.767116, 0.022166, -0.022973},{0.770396, 0.021100, -0.020859},{
      0.771138, 0.025783, -0.020859},{0.767689, 0.025783, -0.022973}}],
    Polygon[{{0.770396, 0.021100, -0.020859},{0.773322, 0.020150, -0.018232},{
      0.774215, 0.025783, -0.018232},{0.771138, 0.025783, -0.020859}}],
    Polygon[{{0.773322, 0.020150, -0.018232},{0.775821, 0.019338, -0.015155},{
      0.776842, 0.025783, -0.015155},{0.774215, 0.025783, -0.018232}}],
    Polygon[{{0.775821, 0.019338, -0.015155},{0.777832, 0.018684, -0.011705},{
      0.778956, 0.025783, -0.011705},{0.776842, 0.025783, -0.015155}}],
    Polygon[{{0.777832, 0.018684, -0.011705},{0.779304, 0.018206, -0.007968},{
      0.780505, 0.025783, -0.007968},{0.778956, 0.025783, -0.011705}}],
    Polygon[{{0.779304, 0.018206, -0.007968},{0.780203, 0.017914, -0.004033},{
      0.781449, 0.025783, -0.004033},{0.780505, 0.025783, -0.007968}}],
    Polygon[{{0.780203, 0.017914, -0.004033},{0.780505, 0.017816, 0.000000},{
      0.781766, 0.025783, 0.000000},{0.781449, 0.025783, -0.004033}}],
    Polygon[{{0.780505, 0.017816, 0.000000},{0.780203, 0.017914, 0.004033},{
      0.781449, 0.025783, 0.004033},{0.781766, 0.025783, 0.000000}}],
    Polygon[{{0.780203, 0.017914, 0.004033},{0.779304, 0.018206, 0.007968},{
      0.780505, 0.025783, 0.007968},{0.781449, 0.025783, 0.004033}}],
    Polygon[{{0.779304, 0.018206, 0.007968},{0.777832, 0.018684, 0.011705},{
      0.778956, 0.025783, 0.011705},{0.780505, 0.025783, 0.007968}}],
    Polygon[{{0.777832, 0.018684, 0.011705},{0.775821, 0.019338, 0.015155},{
      0.776842, 0.025783, 0.015155},{0.778956, 0.025783, 0.011705}}],
    Polygon[{{0.775821, 0.019338, 0.015155},{0.773322, 0.020150, 0.018232},{
      0.774215, 0.025783, 0.018232},{0.776842, 0.025783, 0.015155}}],
    Polygon[{{0.773322, 0.020150, 0.018232},{0.770396, 0.021100, 0.020859},{
      0.771138, 0.025783, 0.020859},{0.774215, 0.025783, 0.018232}}],
    Polygon[{{0.770396, 0.021100, 0.020859},{0.767116, 0.022166, 0.022973},{
      0.767689, 0.025783, 0.022973},{0.771138, 0.025783, 0.020859}}],
    Polygon[{{0.767116, 0.022166, 0.022973},{0.763561, 0.023321, 0.024521},{
      0.763951, 0.025783, 0.024521},{0.767689, 0.025783, 0.022973}}],
    Polygon[{{0.763561, 0.023321, 0.024521},{0.759819, 0.024537, 0.025466},{
      0.760017, 0.025783, 0.025466},{0.763951, 0.025783, 0.024521}}],
    Polygon[{{0.644896, 0.013817, -0.013647},{0.647004, 0.013817, -0.013141},{
      0.646795, 0.015137, -0.013141},{0.644790, 0.014485, -0.013647}}],
    Polygon[{{0.647004, 0.013817, -0.013141},{0.649007, 0.013817, -0.012311},{
      0.648700, 0.015756, -0.012311},{0.646795, 0.015137, -0.013141}}],
    Polygon[{{0.649007, 0.013817, -0.012311},{0.650856, 0.013817, -0.011178},{
      0.650459, 0.016327, -0.011178},{0.648700, 0.015756, -0.012311}}],
    Polygon[{{0.650856, 0.013817, -0.011178},{0.652505, 0.013817, -0.009770},{
      0.652027, 0.016836, -0.009770},{0.650459, 0.016327, -0.011178}}],
    Polygon[{{0.652505, 0.013817, -0.009770},{0.653913, 0.013817, -0.008122},{
      0.653366, 0.017272, -0.008122},{0.652027, 0.016836, -0.009770}}],
    Polygon[{{0.653913, 0.013817, -0.008122},{0.655046, 0.013817, -0.006273},{
      0.654443, 0.017622, -0.006273},{0.653366, 0.017272, -0.008122}}],
    Polygon[{{0.655046, 0.013817, -0.006273},{0.655875, 0.013817, -0.004270},{
      0.655232, 0.017878, -0.004270},{0.654443, 0.017622, -0.006273}}],
    Polygon[{{0.655875, 0.013817, -0.004270},{0.656382, 0.013817, -0.002162},{
      0.655714, 0.018035, -0.002162},{0.655232, 0.017878, -0.004270}}],
    Polygon[{{0.656382, 0.013817, -0.002162},{0.656552, 0.013817, 0.000000},{
      0.655875, 0.018087, 0.000000},{0.655714, 0.018035, -0.002162}}],
    Polygon[{{0.656552, 0.013817, 0.000000},{0.656382, 0.013817, 0.002162},{
      0.655714, 0.018035, 0.002162},{0.655875, 0.018087, 0.000000}}],
    Polygon[{{0.656382, 0.013817, 0.002162},{0.655875, 0.013817, 0.004270},{
      0.655232, 0.017878, 0.004270},{0.655714, 0.018035, 0.002162}}],
    Polygon[{{0.655875, 0.013817, 0.004270},{0.655046, 0.013817, 0.006273},{
      0.654443, 0.017622, 0.006273},{0.655232, 0.017878, 0.004270}}],
    Polygon[{{0.655046, 0.013817, 0.006273},{0.653913, 0.013817, 0.008122},{
      0.653366, 0.017272, 0.008122},{0.654443, 0.017622, 0.006273}}],
    Polygon[{{0.653913, 0.013817, 0.008122},{0.652505, 0.013817, 0.009770},{
      0.652027, 0.016836, 0.009770},{0.653366, 0.017272, 0.008122}}],
    Polygon[{{0.652505, 0.013817, 0.009770},{0.650856, 0.013817, 0.011178},{
      0.650459, 0.016327, 0.011178},{0.652027, 0.016836, 0.009770}}],
    Polygon[{{0.650856, 0.013817, 0.011178},{0.649007, 0.013817, 0.012311},{
      0.648700, 0.015756, 0.012311},{0.650459, 0.016327, 0.011178}}],
    Polygon[{{0.649007, 0.013817, 0.012311},{0.647004, 0.013817, 0.013141},{
      0.646795, 0.015137, 0.013141},{0.648700, 0.015756, 0.012311}}],
    Polygon[{{0.647004, 0.013817, 0.013141},{0.644896, 0.013817, 0.013647},{
      0.644790, 0.014485, 0.013647},{0.646795, 0.015137, 0.013141}}],
    Polygon[{{0.644790, 0.014485, -0.013647},{0.646795, 0.015137, -0.013141},{
      0.646189, 0.016327, -0.013141},{0.644483, 0.015088, -0.013647}}],
    Polygon[{{0.646795, 0.015137, -0.013141},{0.648700, 0.015756, -0.012311},{
      0.647809, 0.017504, -0.012311},{0.646189, 0.016327, -0.013141}}],
    Polygon[{{0.648700, 0.015756, -0.012311},{0.650459, 0.016327, -0.011178},{
      0.649305, 0.018591, -0.011178},{0.647809, 0.017504, -0.012311}}],
    Polygon[{{0.650459, 0.016327, -0.011178},{0.652027, 0.016836, -0.009770},{
      0.650639, 0.019560, -0.009770},{0.649305, 0.018591, -0.011178}}],
    Polygon[{{0.652027, 0.016836, -0.009770},{0.653366, 0.017272, -0.008122},{
      0.651778, 0.020388, -0.008122},{0.650639, 0.019560, -0.009770}}],
    Polygon[{{0.653366, 0.017272, -0.008122},{0.654443, 0.017622, -0.006273},{
      0.652694, 0.021054, -0.006273},{0.651778, 0.020388, -0.008122}}],
    Polygon[{{0.654443, 0.017622, -0.006273},{0.655232, 0.017878, -0.004270},{
      0.653366, 0.021541, -0.004270},{0.652694, 0.021054, -0.006273}}],
    Polygon[{{0.655232, 0.017878, -0.004270},{0.655714, 0.018035, -0.002162},{
      0.653775, 0.021839, -0.002162},{0.653366, 0.021541, -0.004270}}],
    Polygon[{{0.655714, 0.018035, -0.002162},{0.655875, 0.018087, 0.000000},{
      0.653913, 0.021939, 0.000000},{0.653775, 0.021839, -0.002162}}],
    Polygon[{{0.655875, 0.018087, 0.000000},{0.655714, 0.018035, 0.002162},{
      0.653775, 0.021839, 0.002162},{0.653913, 0.021939, 0.000000}}],
    Polygon[{{0.655714, 0.018035, 0.002162},{0.655232, 0.017878, 0.004270},{
      0.653366, 0.021541, 0.004270},{0.653775, 0.021839, 0.002162}}],
    Polygon[{{0.655232, 0.017878, 0.004270},{0.654443, 0.017622, 0.006273},{
      0.652694, 0.021054, 0.006273},{0.653366, 0.021541, 0.004270}}],
    Polygon[{{0.654443, 0.017622, 0.006273},{0.653366, 0.017272, 0.008122},{
      0.651778, 0.020388, 0.008122},{0.652694, 0.021054, 0.006273}}],
    Polygon[{{0.653366, 0.017272, 0.008122},{0.652027, 0.016836, 0.009770},{
      0.650639, 0.019560, 0.009770},{0.651778, 0.020388, 0.008122}}],
    Polygon[{{0.652027, 0.016836, 0.009770},{0.650459, 0.016327, 0.011178},{
      0.649305, 0.018591, 0.011178},{0.650639, 0.019560, 0.009770}}],
    Polygon[{{0.650459, 0.016327, 0.011178},{0.648700, 0.015756, 0.012311},{
      0.647809, 0.017504, 0.012311},{0.649305, 0.018591, 0.011178}}],
    Polygon[{{0.648700, 0.015756, 0.012311},{0.646795, 0.015137, 0.013141},{
      0.646189, 0.016327, 0.013141},{0.647809, 0.017504, 0.012311}}],
    Polygon[{{0.646795, 0.015137, 0.013141},{0.644790, 0.014485, 0.013647},{
      0.644483, 0.015088, 0.013647},{0.646189, 0.016327, 0.013141}}],
    Polygon[{{0.644483, 0.015088, -0.013647},{0.646189, 0.016327, -0.013141},{
      0.645244, 0.017272, -0.013141},{0.644005, 0.015566, -0.013647}}],
    Polygon[{{0.646189, 0.016327, -0.013141},{0.647809, 0.017504, -0.012311},{
      0.646422, 0.018892, -0.012311},{0.645244, 0.017272, -0.013141}}],
    Polygon[{{0.647809, 0.017504, -0.012311},{0.649305, 0.018591, -0.011178},{
      0.647508, 0.020388, -0.011178},{0.646422, 0.018892, -0.012311}}],
    Polygon[{{0.649305, 0.018591, -0.011178},{0.650639, 0.019560, -0.009770},{
      0.648477, 0.021722, -0.009770},{0.647508, 0.020388, -0.011178}}],
    Polygon[{{0.650639, 0.019560, -0.009770},{0.651778, 0.020388, -0.008122},{
      0.649305, 0.022861, -0.008122},{0.648477, 0.021722, -0.009770}}],
    Polygon[{{0.651778, 0.020388, -0.008122},{0.652694, 0.021054, -0.006273},{
      0.649971, 0.023777, -0.006273},{0.649305, 0.022861, -0.008122}}],
    Polygon[{{0.652694, 0.021054, -0.006273},{0.653366, 0.021541, -0.004270},{
      0.650459, 0.024449, -0.004270},{0.649971, 0.023777, -0.006273}}],
    Polygon[{{0.653366, 0.021541, -0.004270},{0.653775, 0.021839, -0.002162},{
      0.650756, 0.024858, -0.002162},{0.650459, 0.024449, -0.004270}}],
    Polygon[{{0.653775, 0.021839, -0.002162},{0.653913, 0.021939, 0.000000},{
      0.650856, 0.024996, 0.000000},{0.650756, 0.024858, -0.002162}}],
    Polygon[{{0.653913, 0.021939, 0.000000},{0.653775, 0.021839, 0.002162},{
      0.650756, 0.024858, 0.002162},{0.650856, 0.024996, 0.000000}}],
    Polygon[{{0.653775, 0.021839, 0.002162},{0.653366, 0.021541, 0.004270},{
      0.650459, 0.024449, 0.004270},{0.650756, 0.024858, 0.002162}}],
    Polygon[{{0.653366, 0.021541, 0.004270},{0.652694, 0.021054, 0.006273},{
      0.649971, 0.023777, 0.006273},{0.650459, 0.024449, 0.004270}}],
    Polygon[{{0.652694, 0.021054, 0.006273},{0.651778, 0.020388, 0.008122},{
      0.649305, 0.022861, 0.008122},{0.649971, 0.023777, 0.006273}}],
    Polygon[{{0.651778, 0.020388, 0.008122},{0.650639, 0.019560, 0.009770},{
      0.648477, 0.021722, 0.009770},{0.649305, 0.022861, 0.008122}}],
    Polygon[{{0.650639, 0.019560, 0.009770},{0.649305, 0.018591, 0.011178},{
      0.647508, 0.020388, 0.011178},{0.648477, 0.021722, 0.009770}}],
    Polygon[{{0.649305, 0.018591, 0.011178},{0.647809, 0.017504, 0.012311},{
      0.646422, 0.018892, 0.012311},{0.647508, 0.020388, 0.011178}}],
    Polygon[{{0.647809, 0.017504, 0.012311},{0.646189, 0.016327, 0.013141},{
      0.645244, 0.017272, 0.013141},{0.646422, 0.018892, 0.012311}}],
    Polygon[{{0.646189, 0.016327, 0.013141},{0.644483, 0.015088, 0.013647},{
      0.644005, 0.015566, 0.013647},{0.645244, 0.017272, 0.013141}}],
    Polygon[{{0.644005, 0.015566, -0.013647},{0.645244, 0.017272, -0.013141},{
      0.644054, 0.017878, -0.013141},{0.643402, 0.015873, -0.013647}}],
    Polygon[{{0.645244, 0.017272, -0.013141},{0.646422, 0.018892, -0.012311},{
      0.644673, 0.019783, -0.012311},{0.644054, 0.017878, -0.013141}}],
    Polygon[{{0.646422, 0.018892, -0.012311},{0.647508, 0.020388, -0.011178},{
      0.645244, 0.021541, -0.011178},{0.644673, 0.019783, -0.012311}}],
    Polygon[{{0.647508, 0.020388, -0.011178},{0.648477, 0.021722, -0.009770},{
      0.645754, 0.023109, -0.009770},{0.645244, 0.021541, -0.011178}}],
    Polygon[{{0.648477, 0.021722, -0.009770},{0.649305, 0.022861, -0.008122},{
      0.646189, 0.024449, -0.008122},{0.645754, 0.023109, -0.009770}}],
    Polygon[{{0.649305, 0.022861, -0.008122},{0.649971, 0.023777, -0.006273},{
      0.646539, 0.025526, -0.006273},{0.646189, 0.024449, -0.008122}}],
    Polygon[{{0.649971, 0.023777, -0.006273},{0.650459, 0.024449, -0.004270},{
      0.646795, 0.026315, -0.004270},{0.646539, 0.025526, -0.006273}}],
    Polygon[{{0.650459, 0.024449, -0.004270},{0.650756, 0.024858, -0.002162},{
      0.646952, 0.026797, -0.002162},{0.646795, 0.026315, -0.004270}}],
    Polygon[{{0.650756, 0.024858, -0.002162},{0.650856, 0.024996, 0.000000},{
      0.647004, 0.026958, 0.000000},{0.646952, 0.026797, -0.002162}}],
    Polygon[{{0.650856, 0.024996, 0.000000},{0.650756, 0.024858, 0.002162},{
      0.646952, 0.026797, 0.002162},{0.647004, 0.026958, 0.000000}}],
    Polygon[{{0.650756, 0.024858, 0.002162},{0.650459, 0.024449, 0.004270},{
      0.646795, 0.026315, 0.004270},{0.646952, 0.026797, 0.002162}}],
    Polygon[{{0.650459, 0.024449, 0.004270},{0.649971, 0.023777, 0.006273},{
      0.646539, 0.025526, 0.006273},{0.646795, 0.026315, 0.004270}}],
    Polygon[{{0.649971, 0.023777, 0.006273},{0.649305, 0.022861, 0.008122},{
      0.646189, 0.024449, 0.008122},{0.646539, 0.025526, 0.006273}}],
    Polygon[{{0.649305, 0.022861, 0.008122},{0.648477, 0.021722, 0.009770},{
      0.645754, 0.023109, 0.009770},{0.646189, 0.024449, 0.008122}}],
    Polygon[{{0.648477, 0.021722, 0.009770},{0.647508, 0.020388, 0.011178},{
      0.645244, 0.021541, 0.011178},{0.645754, 0.023109, 0.009770}}],
    Polygon[{{0.647508, 0.020388, 0.011178},{0.646422, 0.018892, 0.012311},{
      0.644673, 0.019783, 0.012311},{0.645244, 0.021541, 0.011178}}],
    Polygon[{{0.646422, 0.018892, 0.012311},{0.645244, 0.017272, 0.013141},{
      0.644054, 0.017878, 0.013141},{0.644673, 0.019783, 0.012311}}],
    Polygon[{{0.645244, 0.017272, 0.013141},{0.644005, 0.015566, 0.013647},{
      0.643402, 0.015873, 0.013647},{0.644054, 0.017878, 0.013141}}],
    Polygon[{{0.643402, 0.015873, -0.013647},{0.644054, 0.017878, -0.013141},{
      0.642734, 0.018087, -0.013141},{0.642734, 0.015979, -0.013647}}],
    Polygon[{{0.644054, 0.017878, -0.013141},{0.644673, 0.019783, -0.012311},{
      0.642734, 0.020090, -0.012311},{0.642734, 0.018087, -0.013141}}],
    Polygon[{{0.644673, 0.019783, -0.012311},{0.645244, 0.021541, -0.011178},{
      0.642734, 0.021939, -0.011178},{0.642734, 0.020090, -0.012311}}],
    Polygon[{{0.645244, 0.021541, -0.011178},{0.645754, 0.023109, -0.009770},{
      0.642734, 0.023588, -0.009770},{0.642734, 0.021939, -0.011178}}],
    Polygon[{{0.645754, 0.023109, -0.009770},{0.646189, 0.024449, -0.008122},{
      0.642734, 0.024996, -0.008122},{0.642734, 0.023588, -0.009770}}],
    Polygon[{{0.646189, 0.024449, -0.008122},{0.646539, 0.025526, -0.006273},{
      0.642734, 0.026129, -0.006273},{0.642734, 0.024996, -0.008122}}],
    Polygon[{{0.646539, 0.025526, -0.006273},{0.646795, 0.026315, -0.004270},{
      0.642734, 0.026958, -0.004270},{0.642734, 0.026129, -0.006273}}],
    Polygon[{{0.646795, 0.026315, -0.004270},{0.646952, 0.026797, -0.002162},{
      0.642734, 0.027464, -0.002162},{0.642734, 0.026958, -0.004270}}],
    Polygon[{{0.646952, 0.026797, -0.002162},{0.647004, 0.026958, 0.000000},{
      0.642734, 0.027635, 0.000000},{0.642734, 0.027464, -0.002162}}],
    Polygon[{{0.647004, 0.026958, 0.000000},{0.646952, 0.026797, 0.002162},{
      0.642734, 0.027464, 0.002162},{0.642734, 0.027635, 0.000000}}],
    Polygon[{{0.646952, 0.026797, 0.002162},{0.646795, 0.026315, 0.004270},{
      0.642734, 0.026958, 0.004270},{0.642734, 0.027464, 0.002162}}],
    Polygon[{{0.646795, 0.026315, 0.004270},{0.646539, 0.025526, 0.006273},{
      0.642734, 0.026129, 0.006273},{0.642734, 0.026958, 0.004270}}],
    Polygon[{{0.646539, 0.025526, 0.006273},{0.646189, 0.024449, 0.008122},{
      0.642734, 0.024996, 0.008122},{0.642734, 0.026129, 0.006273}}],
    Polygon[{{0.646189, 0.024449, 0.008122},{0.645754, 0.023109, 0.009770},{
      0.642734, 0.023588, 0.009770},{0.642734, 0.024996, 0.008122}}],
    Polygon[{{0.645754, 0.023109, 0.009770},{0.645244, 0.021541, 0.011178},{
      0.642734, 0.021939, 0.011178},{0.642734, 0.023588, 0.009770}}],
    Polygon[{{0.645244, 0.021541, 0.011178},{0.644673, 0.019783, 0.012311},{
      0.642734, 0.020090, 0.012311},{0.642734, 0.021939, 0.011178}}],
    Polygon[{{0.644673, 0.019783, 0.012311},{0.644054, 0.017878, 0.013141},{
      0.642734, 0.018087, 0.013141},{0.642734, 0.020090, 0.012311}}],
    Polygon[{{0.644054, 0.017878, 0.013141},{0.643402, 0.015873, 0.013647},{
      0.642734, 0.015979, 0.013647},{0.642734, 0.018087, 0.013141}}],
    Polygon[{{0.642734, 0.015979, -0.013647},{0.642734, 0.018087, -0.013141},{
      0.641415, 0.017878, -0.013141},{0.642066, 0.015873, -0.013647}}],
    Polygon[{{0.642734, 0.018087, -0.013141},{0.642734, 0.020090, -0.012311},{
      0.640796, 0.019783, -0.012311},{0.641415, 0.017878, -0.013141}}],
    Polygon[{{0.642734, 0.020090, -0.012311},{0.642734, 0.021939, -0.011178},{
      0.640225, 0.021541, -0.011178},{0.640796, 0.019783, -0.012311}}],
    Polygon[{{0.642734, 0.021939, -0.011178},{0.642734, 0.023588, -0.009770},{
      0.639715, 0.023109, -0.009770},{0.640225, 0.021541, -0.011178}}],
    Polygon[{{0.642734, 0.023588, -0.009770},{0.642734, 0.024996, -0.008122},{
      0.639280, 0.024449, -0.008122},{0.639715, 0.023109, -0.009770}}],
    Polygon[{{0.642734, 0.024996, -0.008122},{0.642734, 0.026129, -0.006273},{
      0.638930, 0.025526, -0.006273},{0.639280, 0.024449, -0.008122}}],
    Polygon[{{0.642734, 0.026129, -0.006273},{0.642734, 0.026958, -0.004270},{
      0.638674, 0.026315, -0.004270},{0.638930, 0.025526, -0.006273}}],
    Polygon[{{0.642734, 0.026958, -0.004270},{0.642734, 0.027464, -0.002162},{
      0.638517, 0.026797, -0.002162},{0.638674, 0.026315, -0.004270}}],
    Polygon[{{0.642734, 0.027464, -0.002162},{0.642734, 0.027635, 0.000000},{
      0.638465, 0.026958, 0.000000},{0.638517, 0.026797, -0.002162}}],
    Polygon[{{0.642734, 0.027635, 0.000000},{0.642734, 0.027464, 0.002162},{
      0.638517, 0.026797, 0.002162},{0.638465, 0.026958, 0.000000}}],
    Polygon[{{0.642734, 0.027464, 0.002162},{0.642734, 0.026958, 0.004270},{
      0.638674, 0.026315, 0.004270},{0.638517, 0.026797, 0.002162}}],
    Polygon[{{0.642734, 0.026958, 0.004270},{0.642734, 0.026129, 0.006273},{
      0.638930, 0.025526, 0.006273},{0.638674, 0.026315, 0.004270}}],
    Polygon[{{0.642734, 0.026129, 0.006273},{0.642734, 0.024996, 0.008122},{
      0.639280, 0.024449, 0.008122},{0.638930, 0.025526, 0.006273}}],
    Polygon[{{0.642734, 0.024996, 0.008122},{0.642734, 0.023588, 0.009770},{
      0.639715, 0.023109, 0.009770},{0.639280, 0.024449, 0.008122}}],
    Polygon[{{0.642734, 0.023588, 0.009770},{0.642734, 0.021939, 0.011178},{
      0.640225, 0.021541, 0.011178},{0.639715, 0.023109, 0.009770}}],
    Polygon[{{0.642734, 0.021939, 0.011178},{0.642734, 0.020090, 0.012311},{
      0.640796, 0.019783, 0.012311},{0.640225, 0.021541, 0.011178}}],
    Polygon[{{0.642734, 0.020090, 0.012311},{0.642734, 0.018087, 0.013141},{
      0.641415, 0.017878, 0.013141},{0.640796, 0.019783, 0.012311}}],
    Polygon[{{0.642734, 0.018087, 0.013141},{0.642734, 0.015979, 0.013647},{
      0.642066, 0.015873, 0.013647},{0.641415, 0.017878, 0.013141}}],
    Polygon[{{0.642066, 0.015873, -0.013647},{0.641415, 0.017878, -0.013141},{
      0.640225, 0.017272, -0.013141},{0.641464, 0.015566, -0.013647}}],
    Polygon[{{0.641415, 0.017878, -0.013141},{0.640796, 0.019783, -0.012311},{
      0.639047, 0.018892, -0.012311},{0.640225, 0.017272, -0.013141}}],
    Polygon[{{0.640796, 0.019783, -0.012311},{0.640225, 0.021541, -0.011178},{
      0.637961, 0.020388, -0.011178},{0.639047, 0.018892, -0.012311}}],
    Polygon[{{0.640225, 0.021541, -0.011178},{0.639715, 0.023109, -0.009770},{
      0.636992, 0.021722, -0.009770},{0.637961, 0.020388, -0.011178}}],
    Polygon[{{0.639715, 0.023109, -0.009770},{0.639280, 0.024449, -0.008122},{
      0.636164, 0.022861, -0.008122},{0.636992, 0.021722, -0.009770}}],
    Polygon[{{0.639280, 0.024449, -0.008122},{0.638930, 0.025526, -0.006273},{
      0.635498, 0.023777, -0.006273},{0.636164, 0.022861, -0.008122}}],
    Polygon[{{0.638930, 0.025526, -0.006273},{0.638674, 0.026315, -0.004270},{
      0.635010, 0.024449, -0.004270},{0.635498, 0.023777, -0.006273}}],
    Polygon[{{0.638674, 0.026315, -0.004270},{0.638517, 0.026797, -0.002162},{
      0.634713, 0.024858, -0.002162},{0.635010, 0.024449, -0.004270}}],
    Polygon[{{0.638517, 0.026797, -0.002162},{0.638465, 0.026958, 0.000000},{
      0.634613, 0.024996, 0.000000},{0.634713, 0.024858, -0.002162}}],
    Polygon[{{0.638465, 0.026958, 0.000000},{0.638517, 0.026797, 0.002162},{
      0.634713, 0.024858, 0.002162},{0.634613, 0.024996, 0.000000}}],
    Polygon[{{0.638517, 0.026797, 0.002162},{0.638674, 0.026315, 0.004270},{
      0.635010, 0.024449, 0.004270},{0.634713, 0.024858, 0.002162}}],
    Polygon[{{0.638674, 0.026315, 0.004270},{0.638930, 0.025526, 0.006273},{
      0.635498, 0.023777, 0.006273},{0.635010, 0.024449, 0.004270}}],
    Polygon[{{0.638930, 0.025526, 0.006273},{0.639280, 0.024449, 0.008122},{
      0.636164, 0.022861, 0.008122},{0.635498, 0.023777, 0.006273}}],
    Polygon[{{0.639280, 0.024449, 0.008122},{0.639715, 0.023109, 0.009770},{
      0.636992, 0.021722, 0.009770},{0.636164, 0.022861, 0.008122}}],
    Polygon[{{0.639715, 0.023109, 0.009770},{0.640225, 0.021541, 0.011178},{
      0.637961, 0.020388, 0.011178},{0.636992, 0.021722, 0.009770}}],
    Polygon[{{0.640225, 0.021541, 0.011178},{0.640796, 0.019783, 0.012311},{
      0.639047, 0.018892, 0.012311},{0.637961, 0.020388, 0.011178}}],
    Polygon[{{0.640796, 0.019783, 0.012311},{0.641415, 0.017878, 0.013141},{
      0.640225, 0.017272, 0.013141},{0.639047, 0.018892, 0.012311}}],
    Polygon[{{0.641415, 0.017878, 0.013141},{0.642066, 0.015873, 0.013647},{
      0.641464, 0.015566, 0.013647},{0.640225, 0.017272, 0.013141}}],
    Polygon[{{0.641464, 0.015566, -0.013647},{0.640225, 0.017272, -0.013141},{
      0.639280, 0.016327, -0.013141},{0.640986, 0.015088, -0.013647}}],
    Polygon[{{0.640225, 0.017272, -0.013141},{0.639047, 0.018892, -0.012311},{
      0.637659, 0.017504, -0.012311},{0.639280, 0.016327, -0.013141}}],
    Polygon[{{0.639047, 0.018892, -0.012311},{0.637961, 0.020388, -0.011178},{
      0.636164, 0.018591, -0.011178},{0.637659, 0.017504, -0.012311}}],
    Polygon[{{0.637961, 0.020388, -0.011178},{0.636992, 0.021722, -0.009770},{
      0.634830, 0.019560, -0.009770},{0.636164, 0.018591, -0.011178}}],
    Polygon[{{0.636992, 0.021722, -0.009770},{0.636164, 0.022861, -0.008122},{
      0.633691, 0.020388, -0.008122},{0.634830, 0.019560, -0.009770}}],
    Polygon[{{0.636164, 0.022861, -0.008122},{0.635498, 0.023777, -0.006273},{
      0.632774, 0.021054, -0.006273},{0.633691, 0.020388, -0.008122}}],
    Polygon[{{0.635498, 0.023777, -0.006273},{0.635010, 0.024449, -0.004270},{
      0.632103, 0.021541, -0.004270},{0.632774, 0.021054, -0.006273}}],
    Polygon[{{0.635010, 0.024449, -0.004270},{0.634713, 0.024858, -0.002162},{
      0.631694, 0.021839, -0.002162},{0.632103, 0.021541, -0.004270}}],
    Polygon[{{0.634713, 0.024858, -0.002162},{0.634613, 0.024996, 0.000000},{
      0.631556, 0.021939, 0.000000},{0.631694, 0.021839, -0.002162}}],
    Polygon[{{0.634613, 0.024996, 0.000000},{0.634713, 0.024858, 0.002162},{
      0.631694, 0.021839, 0.002162},{0.631556, 0.021939, 0.000000}}],
    Polygon[{{0.634713, 0.024858, 0.002162},{0.635010, 0.024449, 0.004270},{
      0.632103, 0.021541, 0.004270},{0.631694, 0.021839, 0.002162}}],
    Polygon[{{0.635010, 0.024449, 0.004270},{0.635498, 0.023777, 0.006273},{
      0.632774, 0.021054, 0.006273},{0.632103, 0.021541, 0.004270}}],
    Polygon[{{0.635498, 0.023777, 0.006273},{0.636164, 0.022861, 0.008122},{
      0.633691, 0.020388, 0.008122},{0.632774, 0.021054, 0.006273}}],
    Polygon[{{0.636164, 0.022861, 0.008122},{0.636992, 0.021722, 0.009770},{
      0.634830, 0.019560, 0.009770},{0.633691, 0.020388, 0.008122}}],
    Polygon[{{0.636992, 0.021722, 0.009770},{0.637961, 0.020388, 0.011178},{
      0.636164, 0.018591, 0.011178},{0.634830, 0.019560, 0.009770}}],
    Polygon[{{0.637961, 0.020388, 0.011178},{0.639047, 0.018892, 0.012311},{
      0.637659, 0.017504, 0.012311},{0.636164, 0.018591, 0.011178}}],
    Polygon[{{0.639047, 0.018892, 0.012311},{0.640225, 0.017272, 0.013141},{
      0.639280, 0.016327, 0.013141},{0.637659, 0.017504, 0.012311}}],
    Polygon[{{0.640225, 0.017272, 0.013141},{0.641464, 0.015566, 0.013647},{
      0.640986, 0.015088, 0.013647},{0.639280, 0.016327, 0.013141}}],
    Polygon[{{0.640986, 0.015088, -0.013647},{0.639280, 0.016327, -0.013141},{
      0.638674, 0.015137, -0.013141},{0.640679, 0.014485, -0.013647}}],
    Polygon[{{0.639280, 0.016327, -0.013141},{0.637659, 0.017504, -0.012311},{
      0.636769, 0.015756, -0.012311},{0.638674, 0.015137, -0.013141}}],
    Polygon[{{0.637659, 0.017504, -0.012311},{0.636164, 0.018591, -0.011178},{
      0.635010, 0.016327, -0.011178},{0.636769, 0.015756, -0.012311}}],
    Polygon[{{0.636164, 0.018591, -0.011178},{0.634830, 0.019560, -0.009770},{
      0.633442, 0.016836, -0.009770},{0.635010, 0.016327, -0.011178}}],
    Polygon[{{0.634830, 0.019560, -0.009770},{0.633691, 0.020388, -0.008122},{
      0.632103, 0.017272, -0.008122},{0.633442, 0.016836, -0.009770}}],
    Polygon[{{0.633691, 0.020388, -0.008122},{0.632774, 0.021054, -0.006273},{
      0.631026, 0.017622, -0.006273},{0.632103, 0.017272, -0.008122}}],
    Polygon[{{0.632774, 0.021054, -0.006273},{0.632103, 0.021541, -0.004270},{
      0.630237, 0.017878, -0.004270},{0.631026, 0.017622, -0.006273}}],
    Polygon[{{0.632103, 0.021541, -0.004270},{0.631694, 0.021839, -0.002162},{
      0.629755, 0.018035, -0.002162},{0.630237, 0.017878, -0.004270}}],
    Polygon[{{0.631694, 0.021839, -0.002162},{0.631556, 0.021939, 0.000000},{
      0.629593, 0.018087, 0.000000},{0.629755, 0.018035, -0.002162}}],
    Polygon[{{0.631556, 0.021939, 0.000000},{0.631694, 0.021839, 0.002162},{
      0.629755, 0.018035, 0.002162},{0.629593, 0.018087, 0.000000}}],
    Polygon[{{0.631694, 0.021839, 0.002162},{0.632103, 0.021541, 0.004270},{
      0.630237, 0.017878, 0.004270},{0.629755, 0.018035, 0.002162}}],
    Polygon[{{0.632103, 0.021541, 0.004270},{0.632774, 0.021054, 0.006273},{
      0.631026, 0.017622, 0.006273},{0.630237, 0.017878, 0.004270}}],
    Polygon[{{0.632774, 0.021054, 0.006273},{0.633691, 0.020388, 0.008122},{
      0.632103, 0.017272, 0.008122},{0.631026, 0.017622, 0.006273}}],
    Polygon[{{0.633691, 0.020388, 0.008122},{0.634830, 0.019560, 0.009770},{
      0.633442, 0.016836, 0.009770},{0.632103, 0.017272, 0.008122}}],
    Polygon[{{0.634830, 0.019560, 0.009770},{0.636164, 0.018591, 0.011178},{
      0.635010, 0.016327, 0.011178},{0.633442, 0.016836, 0.009770}}],
    Polygon[{{0.636164, 0.018591, 0.011178},{0.637659, 0.017504, 0.012311},{
      0.636769, 0.015756, 0.012311},{0.635010, 0.016327, 0.011178}}],
    Polygon[{{0.637659, 0.017504, 0.012311},{0.639280, 0.016327, 0.013141},{
      0.638674, 0.015137, 0.013141},{0.636769, 0.015756, 0.012311}}],
    Polygon[{{0.639280, 0.016327, 0.013141},{0.640986, 0.015088, 0.013647},{
      0.640679, 0.014485, 0.013647},{0.638674, 0.015137, 0.013141}}],
    Polygon[{{0.640679, 0.014485, -0.013647},{0.638674, 0.015137, -0.013141},{
      0.638465, 0.013817, -0.013141},{0.640573, 0.013817, -0.013647}}],
    Polygon[{{0.638674, 0.015137, -0.013141},{0.636769, 0.015756, -0.012311},{
      0.636461, 0.013817, -0.012311},{0.638465, 0.013817, -0.013141}}],
    Polygon[{{0.636769, 0.015756, -0.012311},{0.635010, 0.016327, -0.011178},{
      0.634613, 0.013817, -0.011178},{0.636461, 0.013817, -0.012311}}],
    Polygon[{{0.635010, 0.016327, -0.011178},{0.633442, 0.016836, -0.009770},{
      0.632964, 0.013817, -0.009770},{0.634613, 0.013817, -0.011178}}],
    Polygon[{{0.633442, 0.016836, -0.009770},{0.632103, 0.017272, -0.008122},{
      0.631556, 0.013817, -0.008122},{0.632964, 0.013817, -0.009770}}],
    Polygon[{{0.632103, 0.017272, -0.008122},{0.631026, 0.017622, -0.006273},{
      0.630423, 0.013817, -0.006273},{0.631556, 0.013817, -0.008122}}],
    Polygon[{{0.631026, 0.017622, -0.006273},{0.630237, 0.017878, -0.004270},{
      0.629593, 0.013817, -0.004270},{0.630423, 0.013817, -0.006273}}],
    Polygon[{{0.630237, 0.017878, -0.004270},{0.629755, 0.018035, -0.002162},{
      0.629087, 0.013817, -0.002162},{0.629593, 0.013817, -0.004270}}],
    Polygon[{{0.629755, 0.018035, -0.002162},{0.629593, 0.018087, 0.000000},{
      0.628917, 0.013817, 0.000000},{0.629087, 0.013817, -0.002162}}],
    Polygon[{{0.629593, 0.018087, 0.000000},{0.629755, 0.018035, 0.002162},{
      0.629087, 0.013817, 0.002162},{0.628917, 0.013817, 0.000000}}],
    Polygon[{{0.629755, 0.018035, 0.002162},{0.630237, 0.017878, 0.004270},{
      0.629593, 0.013817, 0.004270},{0.629087, 0.013817, 0.002162}}],
    Polygon[{{0.630237, 0.017878, 0.004270},{0.631026, 0.017622, 0.006273},{
      0.630423, 0.013817, 0.006273},{0.629593, 0.013817, 0.004270}}],
    Polygon[{{0.631026, 0.017622, 0.006273},{0.632103, 0.017272, 0.008122},{
      0.631556, 0.013817, 0.008122},{0.630423, 0.013817, 0.006273}}],
    Polygon[{{0.632103, 0.017272, 0.008122},{0.633442, 0.016836, 0.009770},{
      0.632964, 0.013817, 0.009770},{0.631556, 0.013817, 0.008122}}],
    Polygon[{{0.633442, 0.016836, 0.009770},{0.635010, 0.016327, 0.011178},{
      0.634613, 0.013817, 0.011178},{0.632964, 0.013817, 0.009770}}],
    Polygon[{{0.635010, 0.016327, 0.011178},{0.636769, 0.015756, 0.012311},{
      0.636461, 0.013817, 0.012311},{0.634613, 0.013817, 0.011178}}],
    Polygon[{{0.636769, 0.015756, 0.012311},{0.638674, 0.015137, 0.013141},{
      0.638465, 0.013817, 0.013141},{0.636461, 0.013817, 0.012311}}],
    Polygon[{{0.638674, 0.015137, 0.013141},{0.640679, 0.014485, 0.013647},{
      0.640573, 0.013817, 0.013647},{0.638465, 0.013817, 0.013141}}],
    Polygon[{{0.640573, 0.013817, -0.013647},{0.638465, 0.013817, -0.013141},{
      0.638674, 0.012498, -0.013141},{0.640679, 0.013149, -0.013647}}],
    Polygon[{{0.638465, 0.013817, -0.013141},{0.636461, 0.013817, -0.012311},{
      0.636769, 0.011879, -0.012311},{0.638674, 0.012498, -0.013141}}],
    Polygon[{{0.636461, 0.013817, -0.012311},{0.634613, 0.013817, -0.011178},{
      0.635010, 0.011308, -0.011178},{0.636769, 0.011879, -0.012311}}],
    Polygon[{{0.634613, 0.013817, -0.011178},{0.632964, 0.013817, -0.009770},{
      0.633442, 0.010798, -0.009770},{0.635010, 0.011308, -0.011178}}],
    Polygon[{{0.632964, 0.013817, -0.009770},{0.631556, 0.013817, -0.008122},{
      0.632103, 0.010363, -0.008122},{0.633442, 0.010798, -0.009770}}],
    Polygon[{{0.631556, 0.013817, -0.008122},{0.630423, 0.013817, -0.006273},{
      0.631026, 0.010013, -0.006273},{0.632103, 0.010363, -0.008122}}],
    Polygon[{{0.630423, 0.013817, -0.006273},{0.629593, 0.013817, -0.004270},{
      0.630237, 0.009756, -0.004270},{0.631026, 0.010013, -0.006273}}],
    Polygon[{{0.629593, 0.013817, -0.004270},{0.629087, 0.013817, -0.002162},{
      0.629755, 0.009600, -0.002162},{0.630237, 0.009756, -0.004270}}],
    Polygon[{{0.629087, 0.013817, -0.002162},{0.628917, 0.013817, 0.000000},{
      0.629593, 0.009548, 0.000000},{0.629755, 0.009600, -0.002162}}],
    Polygon[{{0.628917, 0.013817, 0.000000},{0.629087, 0.013817, 0.002162},{
      0.629755, 0.009600, 0.002162},{0.629593, 0.009548, 0.000000}}],
    Polygon[{{0.629087, 0.013817, 0.002162},{0.629593, 0.013817, 0.004270},{
      0.630237, 0.009756, 0.004270},{0.629755, 0.009600, 0.002162}}],
    Polygon[{{0.629593, 0.013817, 0.004270},{0.630423, 0.013817, 0.006273},{
      0.631026, 0.010013, 0.006273},{0.630237, 0.009756, 0.004270}}],
    Polygon[{{0.630423, 0.013817, 0.006273},{0.631556, 0.013817, 0.008122},{
      0.632103, 0.010363, 0.008122},{0.631026, 0.010013, 0.006273}}],
    Polygon[{{0.631556, 0.013817, 0.008122},{0.632964, 0.013817, 0.009770},{
      0.633442, 0.010798, 0.009770},{0.632103, 0.010363, 0.008122}}],
    Polygon[{{0.632964, 0.013817, 0.009770},{0.634613, 0.013817, 0.011178},{
      0.635010, 0.011308, 0.011178},{0.633442, 0.010798, 0.009770}}],
    Polygon[{{0.634613, 0.013817, 0.011178},{0.636461, 0.013817, 0.012311},{
      0.636769, 0.011879, 0.012311},{0.635010, 0.011308, 0.011178}}],
    Polygon[{{0.636461, 0.013817, 0.012311},{0.638465, 0.013817, 0.013141},{
      0.638674, 0.012498, 0.013141},{0.636769, 0.011879, 0.012311}}],
    Polygon[{{0.638465, 0.013817, 0.013141},{0.640573, 0.013817, 0.013647},{
      0.640679, 0.013149, 0.013647},{0.638674, 0.012498, 0.013141}}],
    Polygon[{{0.640679, 0.013149, -0.013647},{0.638674, 0.012498, -0.013141},{
      0.639280, 0.011308, -0.013141},{0.640986, 0.012547, -0.013647}}],
    Polygon[{{0.638674, 0.012498, -0.013141},{0.636769, 0.011879, -0.012311},{
      0.637659, 0.010130, -0.012311},{0.639280, 0.011308, -0.013141}}],
    Polygon[{{0.636769, 0.011879, -0.012311},{0.635010, 0.011308, -0.011178},{
      0.636164, 0.009044, -0.011178},{0.637659, 0.010130, -0.012311}}],
    Polygon[{{0.635010, 0.011308, -0.011178},{0.633442, 0.010798, -0.009770},{
      0.634830, 0.008074, -0.009770},{0.636164, 0.009044, -0.011178}}],
    Polygon[{{0.633442, 0.010798, -0.009770},{0.632103, 0.010363, -0.008122},{
      0.633691, 0.007247, -0.008122},{0.634830, 0.008074, -0.009770}}],
    Polygon[{{0.632103, 0.010363, -0.008122},{0.631026, 0.010013, -0.006273},{
      0.632774, 0.006581, -0.006273},{0.633691, 0.007247, -0.008122}}],
    Polygon[{{0.631026, 0.010013, -0.006273},{0.630237, 0.009756, -0.004270},{
      0.632103, 0.006093, -0.004270},{0.632774, 0.006581, -0.006273}}],
    Polygon[{{0.630237, 0.009756, -0.004270},{0.629755, 0.009600, -0.002162},{
      0.631694, 0.005796, -0.002162},{0.632103, 0.006093, -0.004270}}],
    Polygon[{{0.629755, 0.009600, -0.002162},{0.629593, 0.009548, 0.000000},{
      0.631556, 0.005696, 0.000000},{0.631694, 0.005796, -0.002162}}],
    Polygon[{{0.629593, 0.009548, 0.000000},{0.629755, 0.009600, 0.002162},{
      0.631694, 0.005796, 0.002162},{0.631556, 0.005696, 0.000000}}],
    Polygon[{{0.629755, 0.009600, 0.002162},{0.630237, 0.009756, 0.004270},{
      0.632103, 0.006093, 0.004270},{0.631694, 0.005796, 0.002162}}],
    Polygon[{{0.630237, 0.009756, 0.004270},{0.631026, 0.010013, 0.006273},{
      0.632774, 0.006581, 0.006273},{0.632103, 0.006093, 0.004270}}],
    Polygon[{{0.631026, 0.010013, 0.006273},{0.632103, 0.010363, 0.008122},{
      0.633691, 0.007247, 0.008122},{0.632774, 0.006581, 0.006273}}],
    Polygon[{{0.632103, 0.010363, 0.008122},{0.633442, 0.010798, 0.009770},{
      0.634830, 0.008074, 0.009770},{0.633691, 0.007247, 0.008122}}],
    Polygon[{{0.633442, 0.010798, 0.009770},{0.635010, 0.011308, 0.011178},{
      0.636164, 0.009044, 0.011178},{0.634830, 0.008074, 0.009770}}],
    Polygon[{{0.635010, 0.011308, 0.011178},{0.636769, 0.011879, 0.012311},{
      0.637659, 0.010130, 0.012311},{0.636164, 0.009044, 0.011178}}],
    Polygon[{{0.636769, 0.011879, 0.012311},{0.638674, 0.012498, 0.013141},{
      0.639280, 0.011308, 0.013141},{0.637659, 0.010130, 0.012311}}],
    Polygon[{{0.638674, 0.012498, 0.013141},{0.640679, 0.013149, 0.013647},{
      0.640986, 0.012547, 0.013647},{0.639280, 0.011308, 0.013141}}],
    Polygon[{{0.640986, 0.012547, -0.013647},{0.639280, 0.011308, -0.013141},{
      0.640225, 0.010363, -0.013141},{0.641464, 0.012069, -0.013647}}],
    Polygon[{{0.639280, 0.011308, -0.013141},{0.637659, 0.010130, -0.012311},{
      0.639047, 0.008742, -0.012311},{0.640225, 0.010363, -0.013141}}],
    Polygon[{{0.637659, 0.010130, -0.012311},{0.636164, 0.009044, -0.011178},{
      0.637961, 0.007247, -0.011178},{0.639047, 0.008742, -0.012311}}],
    Polygon[{{0.636164, 0.009044, -0.011178},{0.634830, 0.008074, -0.009770},{
      0.636992, 0.005913, -0.009770},{0.637961, 0.007247, -0.011178}}],
    Polygon[{{0.634830, 0.008074, -0.009770},{0.633691, 0.007247, -0.008122},{
      0.636164, 0.004774, -0.008122},{0.636992, 0.005913, -0.009770}}],
    Polygon[{{0.633691, 0.007247, -0.008122},{0.632774, 0.006581, -0.006273},{
      0.635498, 0.003857, -0.006273},{0.636164, 0.004774, -0.008122}}],
    Polygon[{{0.632774, 0.006581, -0.006273},{0.632103, 0.006093, -0.004270},{
      0.635010, 0.003186, -0.004270},{0.635498, 0.003857, -0.006273}}],
    Polygon[{{0.632103, 0.006093, -0.004270},{0.631694, 0.005796, -0.002162},{
      0.634713, 0.002776, -0.002162},{0.635010, 0.003186, -0.004270}}],
    Polygon[{{0.631694, 0.005796, -0.002162},{0.631556, 0.005696, 0.000000},{
      0.634613, 0.002639, 0.000000},{0.634713, 0.002776, -0.002162}}],
    Polygon[{{0.631556, 0.005696, 0.000000},{0.631694, 0.005796, 0.002162},{
      0.634713, 0.002776, 0.002162},{0.634613, 0.002639, 0.000000}}],
    Polygon[{{0.631694, 0.005796, 0.002162},{0.632103, 0.006093, 0.004270},{
      0.635010, 0.003186, 0.004270},{0.634713, 0.002776, 0.002162}}],
    Polygon[{{0.632103, 0.006093, 0.004270},{0.632774, 0.006581, 0.006273},{
      0.635498, 0.003857, 0.006273},{0.635010, 0.003186, 0.004270}}],
    Polygon[{{0.632774, 0.006581, 0.006273},{0.633691, 0.007247, 0.008122},{
      0.636164, 0.004774, 0.008122},{0.635498, 0.003857, 0.006273}}],
    Polygon[{{0.633691, 0.007247, 0.008122},{0.634830, 0.008074, 0.009770},{
      0.636992, 0.005913, 0.009770},{0.636164, 0.004774, 0.008122}}],
    Polygon[{{0.634830, 0.008074, 0.009770},{0.636164, 0.009044, 0.011178},{
      0.637961, 0.007247, 0.011178},{0.636992, 0.005913, 0.009770}}],
    Polygon[{{0.636164, 0.009044, 0.011178},{0.637659, 0.010130, 0.012311},{
      0.639047, 0.008742, 0.012311},{0.637961, 0.007247, 0.011178}}],
    Polygon[{{0.637659, 0.010130, 0.012311},{0.639280, 0.011308, 0.013141},{
      0.640225, 0.010363, 0.013141},{0.639047, 0.008742, 0.012311}}],
    Polygon[{{0.639280, 0.011308, 0.013141},{0.640986, 0.012547, 0.013647},{
      0.641464, 0.012069, 0.013647},{0.640225, 0.010363, 0.013141}}],
    Polygon[{{0.641464, 0.012069, -0.013647},{0.640225, 0.010363, -0.013141},{
      0.641415, 0.009756, -0.013141},{0.642066, 0.011762, -0.013647}}],
    Polygon[{{0.640225, 0.010363, -0.013141},{0.639047, 0.008742, -0.012311},{
      0.640796, 0.007851, -0.012311},{0.641415, 0.009756, -0.013141}}],
    Polygon[{{0.639047, 0.008742, -0.012311},{0.637961, 0.007247, -0.011178},{
      0.640225, 0.006093, -0.011178},{0.640796, 0.007851, -0.012311}}],
    Polygon[{{0.637961, 0.007247, -0.011178},{0.636992, 0.005913, -0.009770},{
      0.639715, 0.004525, -0.009770},{0.640225, 0.006093, -0.011178}}],
    Polygon[{{0.636992, 0.005913, -0.009770},{0.636164, 0.004774, -0.008122},{
      0.639280, 0.003186, -0.008122},{0.639715, 0.004525, -0.009770}}],
    Polygon[{{0.636164, 0.004774, -0.008122},{0.635498, 0.003857, -0.006273},{
      0.638930, 0.002109, -0.006273},{0.639280, 0.003186, -0.008122}}],
    Polygon[{{0.635498, 0.003857, -0.006273},{0.635010, 0.003186, -0.004270},{
      0.638674, 0.001319, -0.004270},{0.638930, 0.002109, -0.006273}}],
    Polygon[{{0.635010, 0.003186, -0.004270},{0.634713, 0.002776, -0.002162},{
      0.638517, 0.000838, -0.002162},{0.638674, 0.001319, -0.004270}}],
    Polygon[{{0.634713, 0.002776, -0.002162},{0.634613, 0.002639, 0.000000},{
      0.638465, 0.000676, 0.000000},{0.638517, 0.000838, -0.002162}}],
    Polygon[{{0.634613, 0.002639, 0.000000},{0.634713, 0.002776, 0.002162},{
      0.638517, 0.000838, 0.002162},{0.638465, 0.000676, 0.000000}}],
    Polygon[{{0.634713, 0.002776, 0.002162},{0.635010, 0.003186, 0.004270},{
      0.638674, 0.001319, 0.004270},{0.638517, 0.000838, 0.002162}}],
    Polygon[{{0.635010, 0.003186, 0.004270},{0.635498, 0.003857, 0.006273},{
      0.638930, 0.002109, 0.006273},{0.638674, 0.001319, 0.004270}}],
    Polygon[{{0.635498, 0.003857, 0.006273},{0.636164, 0.004774, 0.008122},{
      0.639280, 0.003186, 0.008122},{0.638930, 0.002109, 0.006273}}],
    Polygon[{{0.636164, 0.004774, 0.008122},{0.636992, 0.005913, 0.009770},{
      0.639715, 0.004525, 0.009770},{0.639280, 0.003186, 0.008122}}],
    Polygon[{{0.636992, 0.005913, 0.009770},{0.637961, 0.007247, 0.011178},{
      0.640225, 0.006093, 0.011178},{0.639715, 0.004525, 0.009770}}],
    Polygon[{{0.637961, 0.007247, 0.011178},{0.639047, 0.008742, 0.012311},{
      0.640796, 0.007851, 0.012311},{0.640225, 0.006093, 0.011178}}],
    Polygon[{{0.639047, 0.008742, 0.012311},{0.640225, 0.010363, 0.013141},{
      0.641415, 0.009756, 0.013141},{0.640796, 0.007851, 0.012311}}],
    Polygon[{{0.640225, 0.010363, 0.013141},{0.641464, 0.012069, 0.013647},{
      0.642066, 0.011762, 0.013647},{0.641415, 0.009756, 0.013141}}],
    Polygon[{{0.642066, 0.011762, -0.013647},{0.641415, 0.009756, -0.013141},{
      0.642734, 0.009548, -0.013141},{0.642734, 0.011656, -0.013647}}],
    Polygon[{{0.641415, 0.009756, -0.013141},{0.640796, 0.007851, -0.012311},{
      0.642734, 0.007544, -0.012311},{0.642734, 0.009548, -0.013141}}],
    Polygon[{{0.640796, 0.007851, -0.012311},{0.640225, 0.006093, -0.011178},{
      0.642734, 0.005696, -0.011178},{0.642734, 0.007544, -0.012311}}],
    Polygon[{{0.640225, 0.006093, -0.011178},{0.639715, 0.004525, -0.009770},{
      0.642734, 0.004047, -0.009770},{0.642734, 0.005696, -0.011178}}],
    Polygon[{{0.639715, 0.004525, -0.009770},{0.639280, 0.003186, -0.008122},{
      0.642734, 0.002639, -0.008122},{0.642734, 0.004047, -0.009770}}],
    Polygon[{{0.639280, 0.003186, -0.008122},{0.638930, 0.002109, -0.006273},{
      0.642734, 0.001506, -0.006273},{0.642734, 0.002639, -0.008122}}],
    Polygon[{{0.638930, 0.002109, -0.006273},{0.638674, 0.001319, -0.004270},{
      0.642734, 0.000676, -0.004270},{0.642734, 0.001506, -0.006273}}],
    Polygon[{{0.638674, 0.001319, -0.004270},{0.638517, 0.000838, -0.002162},{
      0.642734, 0.000170, -0.002162},{0.642734, 0.000676, -0.004270}}],
    Polygon[{{0.638517, 0.000838, -0.002162},{0.638465, 0.000676, 0.000000},{
      0.642734, 0.000000, 0.000000},{0.642734, 0.000170, -0.002162}}],
    Polygon[{{0.638465, 0.000676, 0.000000},{0.638517, 0.000838, 0.002162},{
      0.642734, 0.000170, 0.002162},{0.642734, 0.000000, 0.000000}}],
    Polygon[{{0.638517, 0.000838, 0.002162},{0.638674, 0.001319, 0.004270},{
      0.642734, 0.000676, 0.004270},{0.642734, 0.000170, 0.002162}}],
    Polygon[{{0.638674, 0.001319, 0.004270},{0.638930, 0.002109, 0.006273},{
      0.642734, 0.001506, 0.006273},{0.642734, 0.000676, 0.004270}}],
    Polygon[{{0.638930, 0.002109, 0.006273},{0.639280, 0.003186, 0.008122},{
      0.642734, 0.002639, 0.008122},{0.642734, 0.001506, 0.006273}}],
    Polygon[{{0.639280, 0.003186, 0.008122},{0.639715, 0.004525, 0.009770},{
      0.642734, 0.004047, 0.009770},{0.642734, 0.002639, 0.008122}}],
    Polygon[{{0.639715, 0.004525, 0.009770},{0.640225, 0.006093, 0.011178},{
      0.642734, 0.005696, 0.011178},{0.642734, 0.004047, 0.009770}}],
    Polygon[{{0.640225, 0.006093, 0.011178},{0.640796, 0.007851, 0.012311},{
      0.642734, 0.007544, 0.012311},{0.642734, 0.005696, 0.011178}}],
    Polygon[{{0.640796, 0.007851, 0.012311},{0.641415, 0.009756, 0.013141},{
      0.642734, 0.009548, 0.013141},{0.642734, 0.007544, 0.012311}}],
    Polygon[{{0.641415, 0.009756, 0.013141},{0.642066, 0.011762, 0.013647},{
      0.642734, 0.011656, 0.013647},{0.642734, 0.009548, 0.013141}}],
    Polygon[{{0.642734, 0.011656, -0.013647},{0.642734, 0.009548, -0.013141},{
      0.644054, 0.009756, -0.013141},{0.643402, 0.011762, -0.013647}}],
    Polygon[{{0.642734, 0.009548, -0.013141},{0.642734, 0.007544, -0.012311},{
      0.644673, 0.007851, -0.012311},{0.644054, 0.009756, -0.013141}}],
    Polygon[{{0.642734, 0.007544, -0.012311},{0.642734, 0.005696, -0.011178},{
      0.645244, 0.006093, -0.011178},{0.644673, 0.007851, -0.012311}}],
    Polygon[{{0.642734, 0.005696, -0.011178},{0.642734, 0.004047, -0.009770},{
      0.645754, 0.004525, -0.009770},{0.645244, 0.006093, -0.011178}}],
    Polygon[{{0.642734, 0.004047, -0.009770},{0.642734, 0.002639, -0.008122},{
      0.646189, 0.003186, -0.008122},{0.645754, 0.004525, -0.009770}}],
    Polygon[{{0.642734, 0.002639, -0.008122},{0.642734, 0.001506, -0.006273},{
      0.646539, 0.002109, -0.006273},{0.646189, 0.003186, -0.008122}}],
    Polygon[{{0.642734, 0.001506, -0.006273},{0.642734, 0.000676, -0.004270},{
      0.646795, 0.001319, -0.004270},{0.646539, 0.002109, -0.006273}}],
    Polygon[{{0.642734, 0.000676, -0.004270},{0.642734, 0.000170, -0.002162},{
      0.646952, 0.000838, -0.002162},{0.646795, 0.001319, -0.004270}}],
    Polygon[{{0.642734, 0.000170, -0.002162},{0.642734, 0.000000, 0.000000},{
      0.647004, 0.000676, 0.000000},{0.646952, 0.000838, -0.002162}}],
    Polygon[{{0.642734, 0.000000, 0.000000},{0.642734, 0.000170, 0.002162},{
      0.646952, 0.000838, 0.002162},{0.647004, 0.000676, 0.000000}}],
    Polygon[{{0.642734, 0.000170, 0.002162},{0.642734, 0.000676, 0.004270},{
      0.646795, 0.001319, 0.004270},{0.646952, 0.000838, 0.002162}}],
    Polygon[{{0.642734, 0.000676, 0.004270},{0.642734, 0.001506, 0.006273},{
      0.646539, 0.002109, 0.006273},{0.646795, 0.001319, 0.004270}}],
    Polygon[{{0.642734, 0.001506, 0.006273},{0.642734, 0.002639, 0.008122},{
      0.646189, 0.003186, 0.008122},{0.646539, 0.002109, 0.006273}}],
    Polygon[{{0.642734, 0.002639, 0.008122},{0.642734, 0.004047, 0.009770},{
      0.645754, 0.004525, 0.009770},{0.646189, 0.003186, 0.008122}}],
    Polygon[{{0.642734, 0.004047, 0.009770},{0.642734, 0.005696, 0.011178},{
      0.645244, 0.006093, 0.011178},{0.645754, 0.004525, 0.009770}}],
    Polygon[{{0.642734, 0.005696, 0.011178},{0.642734, 0.007544, 0.012311},{
      0.644673, 0.007851, 0.012311},{0.645244, 0.006093, 0.011178}}],
    Polygon[{{0.642734, 0.007544, 0.012311},{0.642734, 0.009548, 0.013141},{
      0.644054, 0.009756, 0.013141},{0.644673, 0.007851, 0.012311}}],
    Polygon[{{0.642734, 0.009548, 0.013141},{0.642734, 0.011656, 0.013647},{
      0.643402, 0.011762, 0.013647},{0.644054, 0.009756, 0.013141}}],
    Polygon[{{0.643402, 0.011762, -0.013647},{0.644054, 0.009756, -0.013141},{
      0.645244, 0.010363, -0.013141},{0.644005, 0.012069, -0.013647}}],
    Polygon[{{0.644054, 0.009756, -0.013141},{0.644673, 0.007851, -0.012311},{
      0.646422, 0.008742, -0.012311},{0.645244, 0.010363, -0.013141}}],
    Polygon[{{0.644673, 0.007851, -0.012311},{0.645244, 0.006093, -0.011178},{
      0.647508, 0.007247, -0.011178},{0.646422, 0.008742, -0.012311}}],
    Polygon[{{0.645244, 0.006093, -0.011178},{0.645754, 0.004525, -0.009770},{
      0.648477, 0.005913, -0.009770},{0.647508, 0.007247, -0.011178}}],
    Polygon[{{0.645754, 0.004525, -0.009770},{0.646189, 0.003186, -0.008122},{
      0.649305, 0.004774, -0.008122},{0.648477, 0.005913, -0.009770}}],
    Polygon[{{0.646189, 0.003186, -0.008122},{0.646539, 0.002109, -0.006273},{
      0.649971, 0.003857, -0.006273},{0.649305, 0.004774, -0.008122}}],
    Polygon[{{0.646539, 0.002109, -0.006273},{0.646795, 0.001319, -0.004270},{
      0.650459, 0.003186, -0.004270},{0.649971, 0.003857, -0.006273}}],
    Polygon[{{0.646795, 0.001319, -0.004270},{0.646952, 0.000838, -0.002162},{
      0.650756, 0.002776, -0.002162},{0.650459, 0.003186, -0.004270}}],
    Polygon[{{0.646952, 0.000838, -0.002162},{0.647004, 0.000676, 0.000000},{
      0.650856, 0.002639, 0.000000},{0.650756, 0.002776, -0.002162}}],
    Polygon[{{0.647004, 0.000676, 0.000000},{0.646952, 0.000838, 0.002162},{
      0.650756, 0.002776, 0.002162},{0.650856, 0.002639, 0.000000}}],
    Polygon[{{0.646952, 0.000838, 0.002162},{0.646795, 0.001319, 0.004270},{
      0.650459, 0.003186, 0.004270},{0.650756, 0.002776, 0.002162}}],
    Polygon[{{0.646795, 0.001319, 0.004270},{0.646539, 0.002109, 0.006273},{
      0.649971, 0.003857, 0.006273},{0.650459, 0.003186, 0.004270}}],
    Polygon[{{0.646539, 0.002109, 0.006273},{0.646189, 0.003186, 0.008122},{
      0.649305, 0.004774, 0.008122},{0.649971, 0.003857, 0.006273}}],
    Polygon[{{0.646189, 0.003186, 0.008122},{0.645754, 0.004525, 0.009770},{
      0.648477, 0.005913, 0.009770},{0.649305, 0.004774, 0.008122}}],
    Polygon[{{0.645754, 0.004525, 0.009770},{0.645244, 0.006093, 0.011178},{
      0.647508, 0.007247, 0.011178},{0.648477, 0.005913, 0.009770}}],
    Polygon[{{0.645244, 0.006093, 0.011178},{0.644673, 0.007851, 0.012311},{
      0.646422, 0.008742, 0.012311},{0.647508, 0.007247, 0.011178}}],
    Polygon[{{0.644673, 0.007851, 0.012311},{0.644054, 0.009756, 0.013141},{
      0.645244, 0.010363, 0.013141},{0.646422, 0.008742, 0.012311}}],
    Polygon[{{0.644054, 0.009756, 0.013141},{0.643402, 0.011762, 0.013647},{
      0.644005, 0.012069, 0.013647},{0.645244, 0.010363, 0.013141}}],
    Polygon[{{0.644005, 0.012069, -0.013647},{0.645244, 0.010363, -0.013141},{
      0.646189, 0.011308, -0.013141},{0.644483, 0.012547, -0.013647}}],
    Polygon[{{0.645244, 0.010363, -0.013141},{0.646422, 0.008742, -0.012311},{
      0.647809, 0.010130, -0.012311},{0.646189, 0.011308, -0.013141}}],
    Polygon[{{0.646422, 0.008742, -0.012311},{0.647508, 0.007247, -0.011178},{
      0.649305, 0.009044, -0.011178},{0.647809, 0.010130, -0.012311}}],
    Polygon[{{0.647508, 0.007247, -0.011178},{0.648477, 0.005913, -0.009770},{
      0.650639, 0.008074, -0.009770},{0.649305, 0.009044, -0.011178}}],
    Polygon[{{0.648477, 0.005913, -0.009770},{0.649305, 0.004774, -0.008122},{
      0.651778, 0.007247, -0.008122},{0.650639, 0.008074, -0.009770}}],
    Polygon[{{0.649305, 0.004774, -0.008122},{0.649971, 0.003857, -0.006273},{
      0.652694, 0.006581, -0.006273},{0.651778, 0.007247, -0.008122}}],
    Polygon[{{0.649971, 0.003857, -0.006273},{0.650459, 0.003186, -0.004270},{
      0.653366, 0.006093, -0.004270},{0.652694, 0.006581, -0.006273}}],
    Polygon[{{0.650459, 0.003186, -0.004270},{0.650756, 0.002776, -0.002162},{
      0.653775, 0.005796, -0.002162},{0.653366, 0.006093, -0.004270}}],
    Polygon[{{0.650756, 0.002776, -0.002162},{0.650856, 0.002639, 0.000000},{
      0.653913, 0.005696, 0.000000},{0.653775, 0.005796, -0.002162}}],
    Polygon[{{0.650856, 0.002639, 0.000000},{0.650756, 0.002776, 0.002162},{
      0.653775, 0.005796, 0.002162},{0.653913, 0.005696, 0.000000}}],
    Polygon[{{0.650756, 0.002776, 0.002162},{0.650459, 0.003186, 0.004270},{
      0.653366, 0.006093, 0.004270},{0.653775, 0.005796, 0.002162}}],
    Polygon[{{0.650459, 0.003186, 0.004270},{0.649971, 0.003857, 0.006273},{
      0.652694, 0.006581, 0.006273},{0.653366, 0.006093, 0.004270}}],
    Polygon[{{0.649971, 0.003857, 0.006273},{0.649305, 0.004774, 0.008122},{
      0.651778, 0.007247, 0.008122},{0.652694, 0.006581, 0.006273}}],
    Polygon[{{0.649305, 0.004774, 0.008122},{0.648477, 0.005913, 0.009770},{
      0.650639, 0.008074, 0.009770},{0.651778, 0.007247, 0.008122}}],
    Polygon[{{0.648477, 0.005913, 0.009770},{0.647508, 0.007247, 0.011178},{
      0.649305, 0.009044, 0.011178},{0.650639, 0.008074, 0.009770}}],
    Polygon[{{0.647508, 0.007247, 0.011178},{0.646422, 0.008742, 0.012311},{
      0.647809, 0.010130, 0.012311},{0.649305, 0.009044, 0.011178}}],
    Polygon[{{0.646422, 0.008742, 0.012311},{0.645244, 0.010363, 0.013141},{
      0.646189, 0.011308, 0.013141},{0.647809, 0.010130, 0.012311}}],
    Polygon[{{0.645244, 0.010363, 0.013141},{0.644005, 0.012069, 0.013647},{
      0.644483, 0.012547, 0.013647},{0.646189, 0.011308, 0.013141}}],
    Polygon[{{0.644483, 0.012547, -0.013647},{0.646189, 0.011308, -0.013141},{
      0.646795, 0.012498, -0.013141},{0.644790, 0.013149, -0.013647}}],
    Polygon[{{0.646189, 0.011308, -0.013141},{0.647809, 0.010130, -0.012311},{
      0.648700, 0.011879, -0.012311},{0.646795, 0.012498, -0.013141}}],
    Polygon[{{0.647809, 0.010130, -0.012311},{0.649305, 0.009044, -0.011178},{
      0.650459, 0.011308, -0.011178},{0.648700, 0.011879, -0.012311}}],
    Polygon[{{0.649305, 0.009044, -0.011178},{0.650639, 0.008074, -0.009770},{
      0.652027, 0.010798, -0.009770},{0.650459, 0.011308, -0.011178}}],
    Polygon[{{0.650639, 0.008074, -0.009770},{0.651778, 0.007247, -0.008122},{
      0.653366, 0.010363, -0.008122},{0.652027, 0.010798, -0.009770}}],
    Polygon[{{0.651778, 0.007247, -0.008122},{0.652694, 0.006581, -0.006273},{
      0.654443, 0.010013, -0.006273},{0.653366, 0.010363, -0.008122}}],
    Polygon[{{0.652694, 0.006581, -0.006273},{0.653366, 0.006093, -0.004270},{
      0.655232, 0.009756, -0.004270},{0.654443, 0.010013, -0.006273}}],
    Polygon[{{0.653366, 0.006093, -0.004270},{0.653775, 0.005796, -0.002162},{
      0.655714, 0.009600, -0.002162},{0.655232, 0.009756, -0.004270}}],
    Polygon[{{0.653775, 0.005796, -0.002162},{0.653913, 0.005696, 0.000000},{
      0.655875, 0.009548, 0.000000},{0.655714, 0.009600, -0.002162}}],
    Polygon[{{0.653913, 0.005696, 0.000000},{0.653775, 0.005796, 0.002162},{
      0.655714, 0.009600, 0.002162},{0.655875, 0.009548, 0.000000}}],
    Polygon[{{0.653775, 0.005796, 0.002162},{0.653366, 0.006093, 0.004270},{
      0.655232, 0.009756, 0.004270},{0.655714, 0.009600, 0.002162}}],
    Polygon[{{0.653366, 0.006093, 0.004270},{0.652694, 0.006581, 0.006273},{
      0.654443, 0.010013, 0.006273},{0.655232, 0.009756, 0.004270}}],
    Polygon[{{0.652694, 0.006581, 0.006273},{0.651778, 0.007247, 0.008122},{
      0.653366, 0.010363, 0.008122},{0.654443, 0.010013, 0.006273}}],
    Polygon[{{0.651778, 0.007247, 0.008122},{0.650639, 0.008074, 0.009770},{
      0.652027, 0.010798, 0.009770},{0.653366, 0.010363, 0.008122}}],
    Polygon[{{0.650639, 0.008074, 0.009770},{0.649305, 0.009044, 0.011178},{
      0.650459, 0.011308, 0.011178},{0.652027, 0.010798, 0.009770}}],
    Polygon[{{0.649305, 0.009044, 0.011178},{0.647809, 0.010130, 0.012311},{
      0.648700, 0.011879, 0.012311},{0.650459, 0.011308, 0.011178}}],
    Polygon[{{0.647809, 0.010130, 0.012311},{0.646189, 0.011308, 0.013141},{
      0.646795, 0.012498, 0.013141},{0.648700, 0.011879, 0.012311}}],
    Polygon[{{0.646189, 0.011308, 0.013141},{0.644483, 0.012547, 0.013647},{
      0.644790, 0.013149, 0.013647},{0.646795, 0.012498, 0.013141}}],
    Polygon[{{0.644790, 0.013149, -0.013647},{0.646795, 0.012498, -0.013141},{
      0.647004, 0.013817, -0.013141},{0.644896, 0.013817, -0.013647}}],
    Polygon[{{0.646795, 0.012498, -0.013141},{0.648700, 0.011879, -0.012311},{
      0.649007, 0.013817, -0.012311},{0.647004, 0.013817, -0.013141}}],
    Polygon[{{0.648700, 0.011879, -0.012311},{0.650459, 0.011308, -0.011178},{
      0.650856, 0.013817, -0.011178},{0.649007, 0.013817, -0.012311}}],
    Polygon[{{0.650459, 0.011308, -0.011178},{0.652027, 0.010798, -0.009770},{
      0.652505, 0.013817, -0.009770},{0.650856, 0.013817, -0.011178}}],
    Polygon[{{0.652027, 0.010798, -0.009770},{0.653366, 0.010363, -0.008122},{
      0.653913, 0.013817, -0.008122},{0.652505, 0.013817, -0.009770}}],
    Polygon[{{0.653366, 0.010363, -0.008122},{0.654443, 0.010013, -0.006273},{
      0.655046, 0.013817, -0.006273},{0.653913, 0.013817, -0.008122}}],
    Polygon[{{0.654443, 0.010013, -0.006273},{0.655232, 0.009756, -0.004270},{
      0.655875, 0.013817, -0.004270},{0.655046, 0.013817, -0.006273}}],
    Polygon[{{0.655232, 0.009756, -0.004270},{0.655714, 0.009600, -0.002162},{
      0.656382, 0.013817, -0.002162},{0.655875, 0.013817, -0.004270}}],
    Polygon[{{0.655714, 0.009600, -0.002162},{0.655875, 0.009548, 0.000000},{
      0.656552, 0.013817, 0.000000},{0.656382, 0.013817, -0.002162}}],
    Polygon[{{0.655875, 0.009548, 0.000000},{0.655714, 0.009600, 0.002162},{
      0.656382, 0.013817, 0.002162},{0.656552, 0.013817, 0.000000}}],
    Polygon[{{0.655714, 0.009600, 0.002162},{0.655232, 0.009756, 0.004270},{
      0.655875, 0.013817, 0.004270},{0.656382, 0.013817, 0.002162}}],
    Polygon[{{0.655232, 0.009756, 0.004270},{0.654443, 0.010013, 0.006273},{
      0.655046, 0.013817, 0.006273},{0.655875, 0.013817, 0.004270}}],
    Polygon[{{0.654443, 0.010013, 0.006273},{0.653366, 0.010363, 0.008122},{
      0.653913, 0.013817, 0.008122},{0.655046, 0.013817, 0.006273}}],
    Polygon[{{0.653366, 0.010363, 0.008122},{0.652027, 0.010798, 0.009770},{
      0.652505, 0.013817, 0.009770},{0.653913, 0.013817, 0.008122}}],
    Polygon[{{0.652027, 0.010798, 0.009770},{0.650459, 0.011308, 0.011178},{
      0.650856, 0.013817, 0.011178},{0.652505, 0.013817, 0.009770}}],
    Polygon[{{0.650459, 0.011308, 0.011178},{0.648700, 0.011879, 0.012311},{
      0.649007, 0.013817, 0.012311},{0.650856, 0.013817, 0.011178}}],
    Polygon[{{0.648700, 0.011879, 0.012311},{0.646795, 0.012498, 0.013141},{
      0.647004, 0.013817, 0.013141},{0.649007, 0.013817, 0.012311}}],
    Polygon[{{0.646795, 0.012498, 0.013141},{0.644790, 0.013149, 0.013647},{
      0.644896, 0.013817, 0.013647},{0.647004, 0.013817, 0.013141}}],
    Polygon[{{0.668683, 0.090242, -0.012733},{0.670650, 0.090242, -0.012261},{
      0.670455, 0.091473, -0.012261},{0.668585, 0.090865, -0.012733}}],
    Polygon[{{0.670650, 0.090242, -0.012261},{0.672519, 0.090242, -0.011487},{
      0.672233, 0.092051, -0.011487},{0.670455, 0.091473, -0.012261}}],
    Polygon[{{0.672519, 0.090242, -0.011487},{0.674244, 0.090242, -0.010430},{
      0.673873, 0.092584, -0.010430},{0.672233, 0.092051, -0.011487}}],
    Polygon[{{0.674244, 0.090242, -0.010430},{0.675783, 0.090242, -0.009116},{
      0.675336, 0.093059, -0.009116},{0.673873, 0.092584, -0.010430}}],
    Polygon[{{0.675783, 0.090242, -0.009116},{0.677096, 0.090242, -0.007578},{
      0.676586, 0.093465, -0.007578},{0.675336, 0.093059, -0.009116}}],
    Polygon[{{0.677096, 0.090242, -0.007578},{0.678153, 0.090242, -0.005853},{
      0.677591, 0.093792, -0.005853},{0.676586, 0.093465, -0.007578}}],
    Polygon[{{0.678153, 0.090242, -0.005853},{0.678927, 0.090242, -0.003984},{
      0.678327, 0.094031, -0.003984},{0.677591, 0.093792, -0.005853}}],
    Polygon[{{0.678927, 0.090242, -0.003984},{0.679400, 0.090242, -0.002017},{
      0.678776, 0.094177, -0.002017},{0.678327, 0.094031, -0.003984}}],
    Polygon[{{0.679400, 0.090242, -0.002017},{0.679558, 0.090242, 0.000000},{
      0.678927, 0.094226, 0.000000},{0.678776, 0.094177, -0.002017}}],
    Polygon[{{0.679558, 0.090242, 0.000000},{0.679400, 0.090242, 0.002017},{
      0.678776, 0.094177, 0.002017},{0.678927, 0.094226, 0.000000}}],
    Polygon[{{0.679400, 0.090242, 0.002017},{0.678927, 0.090242, 0.003984},{
      0.678327, 0.094031, 0.003984},{0.678776, 0.094177, 0.002017}}],
    Polygon[{{0.678927, 0.090242, 0.003984},{0.678153, 0.090242, 0.005853},{
      0.677591, 0.093792, 0.005853},{0.678327, 0.094031, 0.003984}}],
    Polygon[{{0.678153, 0.090242, 0.005853},{0.677096, 0.090242, 0.007578},{
      0.676586, 0.093465, 0.007578},{0.677591, 0.093792, 0.005853}}],
    Polygon[{{0.677096, 0.090242, 0.007578},{0.675783, 0.090242, 0.009116},{
      0.675336, 0.093059, 0.009116},{0.676586, 0.093465, 0.007578}}],
    Polygon[{{0.675783, 0.090242, 0.009116},{0.674244, 0.090242, 0.010430},{
      0.673873, 0.092584, 0.010430},{0.675336, 0.093059, 0.009116}}],
    Polygon[{{0.674244, 0.090242, 0.010430},{0.672519, 0.090242, 0.011487},{
      0.672233, 0.092051, 0.011487},{0.673873, 0.092584, 0.010430}}],
    Polygon[{{0.672519, 0.090242, 0.011487},{0.670650, 0.090242, 0.012261},{
      0.670455, 0.091473, 0.012261},{0.672233, 0.092051, 0.011487}}],
    Polygon[{{0.670650, 0.090242, 0.012261},{0.668683, 0.090242, 0.012733},{
      0.668585, 0.090865, 0.012733},{0.670455, 0.091473, 0.012261}}],
    Polygon[{{0.668585, 0.090865, -0.012733},{0.670455, 0.091473, -0.012261},{
      0.669890, 0.092584, -0.012261},{0.668298, 0.091427, -0.012733}}],
    Polygon[{{0.670455, 0.091473, -0.012261},{0.672233, 0.092051, -0.011487},{
      0.671402, 0.093682, -0.011487},{0.669890, 0.092584, -0.012261}}],
    Polygon[{{0.672233, 0.092051, -0.011487},{0.673873, 0.092584, -0.010430},{
      0.672797, 0.094696, -0.010430},{0.671402, 0.093682, -0.011487}}],
    Polygon[{{0.673873, 0.092584, -0.010430},{0.675336, 0.093059, -0.009116},{
      0.674042, 0.095600, -0.009116},{0.672797, 0.094696, -0.010430}}],
    Polygon[{{0.675336, 0.093059, -0.009116},{0.676586, 0.093465, -0.007578},{
      0.675104, 0.096372, -0.007578},{0.674042, 0.095600, -0.009116}}],
    Polygon[{{0.676586, 0.093465, -0.007578},{0.677591, 0.093792, -0.005853},{
      0.675960, 0.096994, -0.005853},{0.675104, 0.096372, -0.007578}}],
    Polygon[{{0.677591, 0.093792, -0.005853},{0.678327, 0.094031, -0.003984},{
      0.676586, 0.097449, -0.003984},{0.675960, 0.096994, -0.005853}}],
    Polygon[{{0.678327, 0.094031, -0.003984},{0.678776, 0.094177, -0.002017},{
      0.676968, 0.097726, -0.002017},{0.676586, 0.097449, -0.003984}}],
    Polygon[{{0.678776, 0.094177, -0.002017},{0.678927, 0.094226, 0.000000},{
      0.677096, 0.097820, 0.000000},{0.676968, 0.097726, -0.002017}}],
    Polygon[{{0.678927, 0.094226, 0.000000},{0.678776, 0.094177, 0.002017},{
      0.676968, 0.097726, 0.002017},{0.677096, 0.097820, 0.000000}}],
    Polygon[{{0.678776, 0.094177, 0.002017},{0.678327, 0.094031, 0.003984},{
      0.676586, 0.097449, 0.003984},{0.676968, 0.097726, 0.002017}}],
    Polygon[{{0.678327, 0.094031, 0.003984},{0.677591, 0.093792, 0.005853},{
      0.675960, 0.096994, 0.005853},{0.676586, 0.097449, 0.003984}}],
    Polygon[{{0.677591, 0.093792, 0.005853},{0.676586, 0.093465, 0.007578},{
      0.675104, 0.096372, 0.007578},{0.675960, 0.096994, 0.005853}}],
    Polygon[{{0.676586, 0.093465, 0.007578},{0.675336, 0.093059, 0.009116},{
      0.674042, 0.095600, 0.009116},{0.675104, 0.096372, 0.007578}}],
    Polygon[{{0.675336, 0.093059, 0.009116},{0.673873, 0.092584, 0.010430},{
      0.672797, 0.094696, 0.010430},{0.674042, 0.095600, 0.009116}}],
    Polygon[{{0.673873, 0.092584, 0.010430},{0.672233, 0.092051, 0.011487},{
      0.671402, 0.093682, 0.011487},{0.672797, 0.094696, 0.010430}}],
    Polygon[{{0.672233, 0.092051, 0.011487},{0.670455, 0.091473, 0.012261},{
      0.669890, 0.092584, 0.012261},{0.671402, 0.093682, 0.011487}}],
    Polygon[{{0.670455, 0.091473, 0.012261},{0.668585, 0.090865, 0.012733},{
      0.668298, 0.091427, 0.012733},{0.669890, 0.092584, 0.012261}}],
    Polygon[{{0.668298, 0.091427, -0.012733},{0.669890, 0.092584, -0.012261},{
      0.669008, 0.093465, -0.012261},{0.667852, 0.091874, -0.012733}}],
    Polygon[{{0.669890, 0.092584, -0.012261},{0.671402, 0.093682, -0.011487},{
      0.670107, 0.094977, -0.011487},{0.669008, 0.093465, -0.012261}}],
    Polygon[{{0.671402, 0.093682, -0.011487},{0.672797, 0.094696, -0.010430},{
      0.671121, 0.096372, -0.010430},{0.670107, 0.094977, -0.011487}}],
    Polygon[{{0.672797, 0.094696, -0.010430},{0.674042, 0.095600, -0.009116},{
      0.672025, 0.097617, -0.009116},{0.671121, 0.096372, -0.010430}}],
    Polygon[{{0.674042, 0.095600, -0.009116},{0.675104, 0.096372, -0.007578},{
      0.672797, 0.098680, -0.007578},{0.672025, 0.097617, -0.009116}}],
    Polygon[{{0.675104, 0.096372, -0.007578},{0.675960, 0.096994, -0.005853},{
      0.673418, 0.099535, -0.005853},{0.672797, 0.098680, -0.007578}}],
    Polygon[{{0.675960, 0.096994, -0.005853},{0.676586, 0.097449, -0.003984},{
      0.673873, 0.100161, -0.003984},{0.673418, 0.099535, -0.005853}}],
    Polygon[{{0.676586, 0.097449, -0.003984},{0.676968, 0.097726, -0.002017},{
      0.674151, 0.100543, -0.002017},{0.673873, 0.100161, -0.003984}}],
    Polygon[{{0.676968, 0.097726, -0.002017},{0.677096, 0.097820, 0.000000},{
      0.674244, 0.100672, 0.000000},{0.674151, 0.100543, -0.002017}}],
    Polygon[{{0.677096, 0.097820, 0.000000},{0.676968, 0.097726, 0.002017},{
      0.674151, 0.100543, 0.002017},{0.674244, 0.100672, 0.000000}}],
    Polygon[{{0.676968, 0.097726, 0.002017},{0.676586, 0.097449, 0.003984},{
      0.673873, 0.100161, 0.003984},{0.674151, 0.100543, 0.002017}}],
    Polygon[{{0.676586, 0.097449, 0.003984},{0.675960, 0.096994, 0.005853},{
      0.673418, 0.099535, 0.005853},{0.673873, 0.100161, 0.003984}}],
    Polygon[{{0.675960, 0.096994, 0.005853},{0.675104, 0.096372, 0.007578},{
      0.672797, 0.098680, 0.007578},{0.673418, 0.099535, 0.005853}}],
    Polygon[{{0.675104, 0.096372, 0.007578},{0.674042, 0.095600, 0.009116},{
      0.672025, 0.097617, 0.009116},{0.672797, 0.098680, 0.007578}}],
    Polygon[{{0.674042, 0.095600, 0.009116},{0.672797, 0.094696, 0.010430},{
      0.671121, 0.096372, 0.010430},{0.672025, 0.097617, 0.009116}}],
    Polygon[{{0.672797, 0.094696, 0.010430},{0.671402, 0.093682, 0.011487},{
      0.670107, 0.094977, 0.011487},{0.671121, 0.096372, 0.010430}}],
    Polygon[{{0.671402, 0.093682, 0.011487},{0.669890, 0.092584, 0.012261},{
      0.669008, 0.093465, 0.012261},{0.670107, 0.094977, 0.011487}}],
    Polygon[{{0.669890, 0.092584, 0.012261},{0.668298, 0.091427, 0.012733},{
      0.667852, 0.091874, 0.012733},{0.669008, 0.093465, 0.012261}}],
    Polygon[{{0.667852, 0.091874, -0.012733},{0.669008, 0.093465, -0.012261},{
      0.667898, 0.094031, -0.012261},{0.667290, 0.092160, -0.012733}}],
    Polygon[{{0.669008, 0.093465, -0.012261},{0.670107, 0.094977, -0.011487},{
      0.668475, 0.095808, -0.011487},{0.667898, 0.094031, -0.012261}}],
    Polygon[{{0.670107, 0.094977, -0.011487},{0.671121, 0.096372, -0.010430},{
      0.669008, 0.097449, -0.010430},{0.668475, 0.095808, -0.011487}}],
    Polygon[{{0.671121, 0.096372, -0.010430},{0.672025, 0.097617, -0.009116},{
      0.669484, 0.098912, -0.009116},{0.669008, 0.097449, -0.010430}}],
    Polygon[{{0.672025, 0.097617, -0.009116},{0.672797, 0.098680, -0.007578},{
      0.669890, 0.100161, -0.007578},{0.669484, 0.098912, -0.009116}}],
    Polygon[{{0.672797, 0.098680, -0.007578},{0.673418, 0.099535, -0.005853},{
      0.670216, 0.101166, -0.005853},{0.669890, 0.100161, -0.007578}}],
    Polygon[{{0.673418, 0.099535, -0.005853},{0.673873, 0.100161, -0.003984},{
      0.670455, 0.101903, -0.003984},{0.670216, 0.101166, -0.005853}}],
    Polygon[{{0.673873, 0.100161, -0.003984},{0.674151, 0.100543, -0.002017},{
      0.670601, 0.102352, -0.002017},{0.670455, 0.101903, -0.003984}}],
    Polygon[{{0.674151, 0.100543, -0.002017},{0.674244, 0.100672, 0.000000},{
      0.670650, 0.102503, 0.000000},{0.670601, 0.102352, -0.002017}}],
    Polygon[{{0.674244, 0.100672, 0.000000},{0.674151, 0.100543, 0.002017},{
      0.670601, 0.102352, 0.002017},{0.670650, 0.102503, 0.000000}}],
    Polygon[{{0.674151, 0.100543, 0.002017},{0.673873, 0.100161, 0.003984},{
      0.670455, 0.101903, 0.003984},{0.670601, 0.102352, 0.002017}}],
    Polygon[{{0.673873, 0.100161, 0.003984},{0.673418, 0.099535, 0.005853},{
      0.670216, 0.101166, 0.005853},{0.670455, 0.101903, 0.003984}}],
    Polygon[{{0.673418, 0.099535, 0.005853},{0.672797, 0.098680, 0.007578},{
      0.669890, 0.100161, 0.007578},{0.670216, 0.101166, 0.005853}}],
    Polygon[{{0.672797, 0.098680, 0.007578},{0.672025, 0.097617, 0.009116},{
      0.669484, 0.098912, 0.009116},{0.669890, 0.100161, 0.007578}}],
    Polygon[{{0.672025, 0.097617, 0.009116},{0.671121, 0.096372, 0.010430},{
      0.669008, 0.097449, 0.010430},{0.669484, 0.098912, 0.009116}}],
    Polygon[{{0.671121, 0.096372, 0.010430},{0.670107, 0.094977, 0.011487},{
      0.668475, 0.095808, 0.011487},{0.669008, 0.097449, 0.010430}}],
    Polygon[{{0.670107, 0.094977, 0.011487},{0.669008, 0.093465, 0.012261},{
      0.667898, 0.094031, 0.012261},{0.668475, 0.095808, 0.011487}}],
    Polygon[{{0.669008, 0.093465, 0.012261},{0.667852, 0.091874, 0.012733},{
      0.667290, 0.092160, 0.012733},{0.667898, 0.094031, 0.012261}}],
    Polygon[{{0.667290, 0.092160, -0.012733},{0.667898, 0.094031, -0.012261},{
      0.666667, 0.094226, -0.012261},{0.666667, 0.092259, -0.012733}}],
    Polygon[{{0.667898, 0.094031, -0.012261},{0.668475, 0.095808, -0.011487},{
      0.666667, 0.096095, -0.011487},{0.666667, 0.094226, -0.012261}}],
    Polygon[{{0.668475, 0.095808, -0.011487},{0.669008, 0.097449, -0.010430},{
      0.666667, 0.097820, -0.010430},{0.666667, 0.096095, -0.011487}}],
    Polygon[{{0.669008, 0.097449, -0.010430},{0.669484, 0.098912, -0.009116},{
      0.666667, 0.099358, -0.009116},{0.666667, 0.097820, -0.010430}}],
    Polygon[{{0.669484, 0.098912, -0.009116},{0.669890, 0.100161, -0.007578},{
      0.666667, 0.100672, -0.007578},{0.666667, 0.099358, -0.009116}}],
    Polygon[{{0.669890, 0.100161, -0.007578},{0.670216, 0.101166, -0.005853},{
      0.666667, 0.101729, -0.005853},{0.666667, 0.100672, -0.007578}}],
    Polygon[{{0.670216, 0.101166, -0.005853},{0.670455, 0.101903, -0.003984},{
      0.666667, 0.102503, -0.003984},{0.666667, 0.101729, -0.005853}}],
    Polygon[{{0.670455, 0.101903, -0.003984},{0.670601, 0.102352, -0.002017},{
      0.666667, 0.102975, -0.002017},{0.666667, 0.102503, -0.003984}}],
    Polygon[{{0.670601, 0.102352, -0.002017},{0.670650, 0.102503, 0.000000},{
      0.666667, 0.103134, 0.000000},{0.666667, 0.102975, -0.002017}}],
    Polygon[{{0.670650, 0.102503, 0.000000},{0.670601, 0.102352, 0.002017},{
      0.666667, 0.102975, 0.002017},{0.666667, 0.103134, 0.000000}}],
    Polygon[{{0.670601, 0.102352, 0.002017},{0.670455, 0.101903, 0.003984},{
      0.666667, 0.102503, 0.003984},{0.666667, 0.102975, 0.002017}}],
    Polygon[{{0.670455, 0.101903, 0.003984},{0.670216, 0.101166, 0.005853},{
      0.666667, 0.101729, 0.005853},{0.666667, 0.102503, 0.003984}}],
    Polygon[{{0.670216, 0.101166, 0.005853},{0.669890, 0.100161, 0.007578},{
      0.666667, 0.100672, 0.007578},{0.666667, 0.101729, 0.005853}}],
    Polygon[{{0.669890, 0.100161, 0.007578},{0.669484, 0.098912, 0.009116},{
      0.666667, 0.099358, 0.009116},{0.666667, 0.100672, 0.007578}}],
    Polygon[{{0.669484, 0.098912, 0.009116},{0.669008, 0.097449, 0.010430},{
      0.666667, 0.097820, 0.010430},{0.666667, 0.099358, 0.009116}}],
    Polygon[{{0.669008, 0.097449, 0.010430},{0.668475, 0.095808, 0.011487},{
      0.666667, 0.096095, 0.011487},{0.666667, 0.097820, 0.010430}}],
    Polygon[{{0.668475, 0.095808, 0.011487},{0.667898, 0.094031, 0.012261},{
      0.666667, 0.094226, 0.012261},{0.666667, 0.096095, 0.011487}}],
    Polygon[{{0.667898, 0.094031, 0.012261},{0.667290, 0.092160, 0.012733},{
      0.666667, 0.092259, 0.012733},{0.666667, 0.094226, 0.012261}}],
    Polygon[{{0.666667, 0.092259, -0.012733},{0.666667, 0.094226, -0.012261},{
      0.665436, 0.094031, -0.012261},{0.666043, 0.092160, -0.012733}}],
    Polygon[{{0.666667, 0.094226, -0.012261},{0.666667, 0.096095, -0.011487},{
      0.664858, 0.095808, -0.011487},{0.665436, 0.094031, -0.012261}}],
    Polygon[{{0.666667, 0.096095, -0.011487},{0.666667, 0.097820, -0.010430},{
      0.664325, 0.097449, -0.010430},{0.664858, 0.095808, -0.011487}}],
    Polygon[{{0.666667, 0.097820, -0.010430},{0.666667, 0.099358, -0.009116},{
      0.663850, 0.098912, -0.009116},{0.664325, 0.097449, -0.010430}}],
    Polygon[{{0.666667, 0.099358, -0.009116},{0.666667, 0.100672, -0.007578},{
      0.663444, 0.100161, -0.007578},{0.663850, 0.098912, -0.009116}}],
    Polygon[{{0.666667, 0.100672, -0.007578},{0.666667, 0.101729, -0.005853},{
      0.663117, 0.101166, -0.005853},{0.663444, 0.100161, -0.007578}}],
    Polygon[{{0.666667, 0.101729, -0.005853},{0.666667, 0.102503, -0.003984},{
      0.662878, 0.101903, -0.003984},{0.663117, 0.101166, -0.005853}}],
    Polygon[{{0.666667, 0.102503, -0.003984},{0.666667, 0.102975, -0.002017},{
      0.662732, 0.102352, -0.002017},{0.662878, 0.101903, -0.003984}}],
    Polygon[{{0.666667, 0.102975, -0.002017},{0.666667, 0.103134, 0.000000},{
      0.662683, 0.102503, 0.000000},{0.662732, 0.102352, -0.002017}}],
    Polygon[{{0.666667, 0.103134, 0.000000},{0.666667, 0.102975, 0.002017},{
      0.662732, 0.102352, 0.002017},{0.662683, 0.102503, 0.000000}}],
    Polygon[{{0.666667, 0.102975, 0.002017},{0.666667, 0.102503, 0.003984},{
      0.662878, 0.101903, 0.003984},{0.662732, 0.102352, 0.002017}}],
    Polygon[{{0.666667, 0.102503, 0.003984},{0.666667, 0.101729, 0.005853},{
      0.663117, 0.101166, 0.005853},{0.662878, 0.101903, 0.003984}}],
    Polygon[{{0.666667, 0.101729, 0.005853},{0.666667, 0.100672, 0.007578},{
      0.663444, 0.100161, 0.007578},{0.663117, 0.101166, 0.005853}}],
    Polygon[{{0.666667, 0.100672, 0.007578},{0.666667, 0.099358, 0.009116},{
      0.663850, 0.098912, 0.009116},{0.663444, 0.100161, 0.007578}}],
    Polygon[{{0.666667, 0.099358, 0.009116},{0.666667, 0.097820, 0.010430},{
      0.664325, 0.097449, 0.010430},{0.663850, 0.098912, 0.009116}}],
    Polygon[{{0.666667, 0.097820, 0.010430},{0.666667, 0.096095, 0.011487},{
      0.664858, 0.095808, 0.011487},{0.664325, 0.097449, 0.010430}}],
    Polygon[{{0.666667, 0.096095, 0.011487},{0.666667, 0.094226, 0.012261},{
      0.665436, 0.094031, 0.012261},{0.664858, 0.095808, 0.011487}}],
    Polygon[{{0.666667, 0.094226, 0.012261},{0.666667, 0.092259, 0.012733},{
      0.666043, 0.092160, 0.012733},{0.665436, 0.094031, 0.012261}}],
    Polygon[{{0.666043, 0.092160, -0.012733},{0.665436, 0.094031, -0.012261},{
      0.664325, 0.093465, -0.012261},{0.665481, 0.091874, -0.012733}}],
    Polygon[{{0.665436, 0.094031, -0.012261},{0.664858, 0.095808, -0.011487},{
      0.663227, 0.094977, -0.011487},{0.664325, 0.093465, -0.012261}}],
    Polygon[{{0.664858, 0.095808, -0.011487},{0.664325, 0.097449, -0.010430},{
      0.662213, 0.096372, -0.010430},{0.663227, 0.094977, -0.011487}}],
    Polygon[{{0.664325, 0.097449, -0.010430},{0.663850, 0.098912, -0.009116},{
      0.661309, 0.097617, -0.009116},{0.662213, 0.096372, -0.010430}}],
    Polygon[{{0.663850, 0.098912, -0.009116},{0.663444, 0.100161, -0.007578},{
      0.660536, 0.098680, -0.007578},{0.661309, 0.097617, -0.009116}}],
    Polygon[{{0.663444, 0.100161, -0.007578},{0.663117, 0.101166, -0.005853},{
      0.659915, 0.099535, -0.005853},{0.660536, 0.098680, -0.007578}}],
    Polygon[{{0.663117, 0.101166, -0.005853},{0.662878, 0.101903, -0.003984},{
      0.659460, 0.100161, -0.003984},{0.659915, 0.099535, -0.005853}}],
    Polygon[{{0.662878, 0.101903, -0.003984},{0.662732, 0.102352, -0.002017},{
      0.659182, 0.100543, -0.002017},{0.659460, 0.100161, -0.003984}}],
    Polygon[{{0.662732, 0.102352, -0.002017},{0.662683, 0.102503, 0.000000},{
      0.659089, 0.100672, 0.000000},{0.659182, 0.100543, -0.002017}}],
    Polygon[{{0.662683, 0.102503, 0.000000},{0.662732, 0.102352, 0.002017},{
      0.659182, 0.100543, 0.002017},{0.659089, 0.100672, 0.000000}}],
    Polygon[{{0.662732, 0.102352, 0.002017},{0.662878, 0.101903, 0.003984},{
      0.659460, 0.100161, 0.003984},{0.659182, 0.100543, 0.002017}}],
    Polygon[{{0.662878, 0.101903, 0.003984},{0.663117, 0.101166, 0.005853},{
      0.659915, 0.099535, 0.005853},{0.659460, 0.100161, 0.003984}}],
    Polygon[{{0.663117, 0.101166, 0.005853},{0.663444, 0.100161, 0.007578},{
      0.660536, 0.098680, 0.007578},{0.659915, 0.099535, 0.005853}}],
    Polygon[{{0.663444, 0.100161, 0.007578},{0.663850, 0.098912, 0.009116},{
      0.661309, 0.097617, 0.009116},{0.660536, 0.098680, 0.007578}}],
    Polygon[{{0.663850, 0.098912, 0.009116},{0.664325, 0.097449, 0.010430},{
      0.662213, 0.096372, 0.010430},{0.661309, 0.097617, 0.009116}}],
    Polygon[{{0.664325, 0.097449, 0.010430},{0.664858, 0.095808, 0.011487},{
      0.663227, 0.094977, 0.011487},{0.662213, 0.096372, 0.010430}}],
    Polygon[{{0.664858, 0.095808, 0.011487},{0.665436, 0.094031, 0.012261},{
      0.664325, 0.093465, 0.012261},{0.663227, 0.094977, 0.011487}}],
    Polygon[{{0.665436, 0.094031, 0.012261},{0.666043, 0.092160, 0.012733},{
      0.665481, 0.091874, 0.012733},{0.664325, 0.093465, 0.012261}}],
    Polygon[{{0.665481, 0.091874, -0.012733},{0.664325, 0.093465, -0.012261},{
      0.663444, 0.092584, -0.012261},{0.665035, 0.091427, -0.012733}}],
    Polygon[{{0.664325, 0.093465, -0.012261},{0.663227, 0.094977, -0.011487},{
      0.661932, 0.093682, -0.011487},{0.663444, 0.092584, -0.012261}}],
    Polygon[{{0.663227, 0.094977, -0.011487},{0.662213, 0.096372, -0.010430},{
      0.660536, 0.094696, -0.010430},{0.661932, 0.093682, -0.011487}}],
    Polygon[{{0.662213, 0.096372, -0.010430},{0.661309, 0.097617, -0.009116},{
      0.659292, 0.095600, -0.009116},{0.660536, 0.094696, -0.010430}}],
    Polygon[{{0.661309, 0.097617, -0.009116},{0.660536, 0.098680, -0.007578},{
      0.658229, 0.096372, -0.007578},{0.659292, 0.095600, -0.009116}}],
    Polygon[{{0.660536, 0.098680, -0.007578},{0.659915, 0.099535, -0.005853},{
      0.657374, 0.096994, -0.005853},{0.658229, 0.096372, -0.007578}}],
    Polygon[{{0.659915, 0.099535, -0.005853},{0.659460, 0.100161, -0.003984},{
      0.656748, 0.097449, -0.003984},{0.657374, 0.096994, -0.005853}}],
    Polygon[{{0.659460, 0.100161, -0.003984},{0.659182, 0.100543, -0.002017},{
      0.656365, 0.097726, -0.002017},{0.656748, 0.097449, -0.003984}}],
    Polygon[{{0.659182, 0.100543, -0.002017},{0.659089, 0.100672, 0.000000},{
      0.656237, 0.097820, 0.000000},{0.656365, 0.097726, -0.002017}}],
    Polygon[{{0.659089, 0.100672, 0.000000},{0.659182, 0.100543, 0.002017},{
      0.656365, 0.097726, 0.002017},{0.656237, 0.097820, 0.000000}}],
    Polygon[{{0.659182, 0.100543, 0.002017},{0.659460, 0.100161, 0.003984},{
      0.656748, 0.097449, 0.003984},{0.656365, 0.097726, 0.002017}}],
    Polygon[{{0.659460, 0.100161, 0.003984},{0.659915, 0.099535, 0.005853},{
      0.657374, 0.096994, 0.005853},{0.656748, 0.097449, 0.003984}}],
    Polygon[{{0.659915, 0.099535, 0.005853},{0.660536, 0.098680, 0.007578},{
      0.658229, 0.096372, 0.007578},{0.657374, 0.096994, 0.005853}}],
    Polygon[{{0.660536, 0.098680, 0.007578},{0.661309, 0.097617, 0.009116},{
      0.659292, 0.095600, 0.009116},{0.658229, 0.096372, 0.007578}}],
    Polygon[{{0.661309, 0.097617, 0.009116},{0.662213, 0.096372, 0.010430},{
      0.660536, 0.094696, 0.010430},{0.659292, 0.095600, 0.009116}}],
    Polygon[{{0.662213, 0.096372, 0.010430},{0.663227, 0.094977, 0.011487},{
      0.661932, 0.093682, 0.011487},{0.660536, 0.094696, 0.010430}}],
    Polygon[{{0.663227, 0.094977, 0.011487},{0.664325, 0.093465, 0.012261},{
      0.663444, 0.092584, 0.012261},{0.661932, 0.093682, 0.011487}}],
    Polygon[{{0.664325, 0.093465, 0.012261},{0.665481, 0.091874, 0.012733},{
      0.665035, 0.091427, 0.012733},{0.663444, 0.092584, 0.012261}}],
    Polygon[{{0.665035, 0.091427, -0.012733},{0.663444, 0.092584, -0.012261},{
      0.662878, 0.091473, -0.012261},{0.664749, 0.090865, -0.012733}}],
    Polygon[{{0.663444, 0.092584, -0.012261},{0.661932, 0.093682, -0.011487},{
      0.661100, 0.092051, -0.011487},{0.662878, 0.091473, -0.012261}}],
    Polygon[{{0.661932, 0.093682, -0.011487},{0.660536, 0.094696, -0.010430},{
      0.659460, 0.092584, -0.010430},{0.661100, 0.092051, -0.011487}}],
    Polygon[{{0.660536, 0.094696, -0.010430},{0.659292, 0.095600, -0.009116},{
      0.657997, 0.093059, -0.009116},{0.659460, 0.092584, -0.010430}}],
    Polygon[{{0.659292, 0.095600, -0.009116},{0.658229, 0.096372, -0.007578},{
      0.656748, 0.093465, -0.007578},{0.657997, 0.093059, -0.009116}}],
    Polygon[{{0.658229, 0.096372, -0.007578},{0.657374, 0.096994, -0.005853},{
      0.655742, 0.093792, -0.005853},{0.656748, 0.093465, -0.007578}}],
    Polygon[{{0.657374, 0.096994, -0.005853},{0.656748, 0.097449, -0.003984},{
      0.655006, 0.094031, -0.003984},{0.655742, 0.093792, -0.005853}}],
    Polygon[{{0.656748, 0.097449, -0.003984},{0.656365, 0.097726, -0.002017},{
      0.654557, 0.094177, -0.002017},{0.655006, 0.094031, -0.003984}}],
    Polygon[{{0.656365, 0.097726, -0.002017},{0.656237, 0.097820, 0.000000},{
      0.654406, 0.094226, 0.000000},{0.654557, 0.094177, -0.002017}}],
    Polygon[{{0.656237, 0.097820, 0.000000},{0.656365, 0.097726, 0.002017},{
      0.654557, 0.094177, 0.002017},{0.654406, 0.094226, 0.000000}}],
    Polygon[{{0.656365, 0.097726, 0.002017},{0.656748, 0.097449, 0.003984},{
      0.655006, 0.094031, 0.003984},{0.654557, 0.094177, 0.002017}}],
    Polygon[{{0.656748, 0.097449, 0.003984},{0.657374, 0.096994, 0.005853},{
      0.655742, 0.093792, 0.005853},{0.655006, 0.094031, 0.003984}}],
    Polygon[{{0.657374, 0.096994, 0.005853},{0.658229, 0.096372, 0.007578},{
      0.656748, 0.093465, 0.007578},{0.655742, 0.093792, 0.005853}}],
    Polygon[{{0.658229, 0.096372, 0.007578},{0.659292, 0.095600, 0.009116},{
      0.657997, 0.093059, 0.009116},{0.656748, 0.093465, 0.007578}}],
    Polygon[{{0.659292, 0.095600, 0.009116},{0.660536, 0.094696, 0.010430},{
      0.659460, 0.092584, 0.010430},{0.657997, 0.093059, 0.009116}}],
    Polygon[{{0.660536, 0.094696, 0.010430},{0.661932, 0.093682, 0.011487},{
      0.661100, 0.092051, 0.011487},{0.659460, 0.092584, 0.010430}}],
    Polygon[{{0.661932, 0.093682, 0.011487},{0.663444, 0.092584, 0.012261},{
      0.662878, 0.091473, 0.012261},{0.661100, 0.092051, 0.011487}}],
    Polygon[{{0.663444, 0.092584, 0.012261},{0.665035, 0.091427, 0.012733},{
      0.664749, 0.090865, 0.012733},{0.662878, 0.091473, 0.012261}}],
    Polygon[{{0.664749, 0.090865, -0.012733},{0.662878, 0.091473, -0.012261},{
      0.662683, 0.090242, -0.012261},{0.664650, 0.090242, -0.012733}}],
    Polygon[{{0.662878, 0.091473, -0.012261},{0.661100, 0.092051, -0.011487},{
      0.660814, 0.090242, -0.011487},{0.662683, 0.090242, -0.012261}}],
    Polygon[{{0.661100, 0.092051, -0.011487},{0.659460, 0.092584, -0.010430},{
      0.659089, 0.090242, -0.010430},{0.660814, 0.090242, -0.011487}}],
    Polygon[{{0.659460, 0.092584, -0.010430},{0.657997, 0.093059, -0.009116},{
      0.657551, 0.090242, -0.009116},{0.659089, 0.090242, -0.010430}}],
    Polygon[{{0.657997, 0.093059, -0.009116},{0.656748, 0.093465, -0.007578},{
      0.656237, 0.090242, -0.007578},{0.657551, 0.090242, -0.009116}}],
    Polygon[{{0.656748, 0.093465, -0.007578},{0.655742, 0.093792, -0.005853},{
      0.655180, 0.090242, -0.005853},{0.656237, 0.090242, -0.007578}}],
    Polygon[{{0.655742, 0.093792, -0.005853},{0.655006, 0.094031, -0.003984},{
      0.654406, 0.090242, -0.003984},{0.655180, 0.090242, -0.005853}}],
    Polygon[{{0.655006, 0.094031, -0.003984},{0.654557, 0.094177, -0.002017},{
      0.653934, 0.090242, -0.002017},{0.654406, 0.090242, -0.003984}}],
    Polygon[{{0.654557, 0.094177, -0.002017},{0.654406, 0.094226, 0.000000},{
      0.653775, 0.090242, 0.000000},{0.653934, 0.090242, -0.002017}}],
    Polygon[{{0.654406, 0.094226, 0.000000},{0.654557, 0.094177, 0.002017},{
      0.653934, 0.090242, 0.002017},{0.653775, 0.090242, 0.000000}}],
    Polygon[{{0.654557, 0.094177, 0.002017},{0.655006, 0.094031, 0.003984},{
      0.654406, 0.090242, 0.003984},{0.653934, 0.090242, 0.002017}}],
    Polygon[{{0.655006, 0.094031, 0.003984},{0.655742, 0.093792, 0.005853},{
      0.655180, 0.090242, 0.005853},{0.654406, 0.090242, 0.003984}}],
    Polygon[{{0.655742, 0.093792, 0.005853},{0.656748, 0.093465, 0.007578},{
      0.656237, 0.090242, 0.007578},{0.655180, 0.090242, 0.005853}}],
    Polygon[{{0.656748, 0.093465, 0.007578},{0.657997, 0.093059, 0.009116},{
      0.657551, 0.090242, 0.009116},{0.656237, 0.090242, 0.007578}}],
    Polygon[{{0.657997, 0.093059, 0.009116},{0.659460, 0.092584, 0.010430},{
      0.659089, 0.090242, 0.010430},{0.657551, 0.090242, 0.009116}}],
    Polygon[{{0.659460, 0.092584, 0.010430},{0.661100, 0.092051, 0.011487},{
      0.660814, 0.090242, 0.011487},{0.659089, 0.090242, 0.010430}}],
    Polygon[{{0.661100, 0.092051, 0.011487},{0.662878, 0.091473, 0.012261},{
      0.662683, 0.090242, 0.012261},{0.660814, 0.090242, 0.011487}}],
    Polygon[{{0.662878, 0.091473, 0.012261},{0.664749, 0.090865, 0.012733},{
      0.664650, 0.090242, 0.012733},{0.662683, 0.090242, 0.012261}}],
    Polygon[{{0.664650, 0.090242, -0.012733},{0.662683, 0.090242, -0.012261},{
      0.662878, 0.089011, -0.012261},{0.664749, 0.089619, -0.012733}}],
    Polygon[{{0.662683, 0.090242, -0.012261},{0.660814, 0.090242, -0.011487},{
      0.661100, 0.088433, -0.011487},{0.662878, 0.089011, -0.012261}}],
    Polygon[{{0.660814, 0.090242, -0.011487},{0.659089, 0.090242, -0.010430},{
      0.659460, 0.087900, -0.010430},{0.661100, 0.088433, -0.011487}}],
    Polygon[{{0.659089, 0.090242, -0.010430},{0.657551, 0.090242, -0.009116},{
      0.657997, 0.087425, -0.009116},{0.659460, 0.087900, -0.010430}}],
    Polygon[{{0.657551, 0.090242, -0.009116},{0.656237, 0.090242, -0.007578},{
      0.656748, 0.087019, -0.007578},{0.657997, 0.087425, -0.009116}}],
    Polygon[{{0.656237, 0.090242, -0.007578},{0.655180, 0.090242, -0.005853},{
      0.655742, 0.086692, -0.005853},{0.656748, 0.087019, -0.007578}}],
    Polygon[{{0.655180, 0.090242, -0.005853},{0.654406, 0.090242, -0.003984},{
      0.655006, 0.086453, -0.003984},{0.655742, 0.086692, -0.005853}}],
    Polygon[{{0.654406, 0.090242, -0.003984},{0.653934, 0.090242, -0.002017},{
      0.654557, 0.086307, -0.002017},{0.655006, 0.086453, -0.003984}}],
    Polygon[{{0.653934, 0.090242, -0.002017},{0.653775, 0.090242, 0.000000},{
      0.654406, 0.086258, 0.000000},{0.654557, 0.086307, -0.002017}}],
    Polygon[{{0.653775, 0.090242, 0.000000},{0.653934, 0.090242, 0.002017},{
      0.654557, 0.086307, 0.002017},{0.654406, 0.086258, 0.000000}}],
    Polygon[{{0.653934, 0.090242, 0.002017},{0.654406, 0.090242, 0.003984},{
      0.655006, 0.086453, 0.003984},{0.654557, 0.086307, 0.002017}}],
    Polygon[{{0.654406, 0.090242, 0.003984},{0.655180, 0.090242, 0.005853},{
      0.655742, 0.086692, 0.005853},{0.655006, 0.086453, 0.003984}}],
    Polygon[{{0.655180, 0.090242, 0.005853},{0.656237, 0.090242, 0.007578},{
      0.656748, 0.087019, 0.007578},{0.655742, 0.086692, 0.005853}}],
    Polygon[{{0.656237, 0.090242, 0.007578},{0.657551, 0.090242, 0.009116},{
      0.657997, 0.087425, 0.009116},{0.656748, 0.087019, 0.007578}}],
    Polygon[{{0.657551, 0.090242, 0.009116},{0.659089, 0.090242, 0.010430},{
      0.659460, 0.087900, 0.010430},{0.657997, 0.087425, 0.009116}}],
    Polygon[{{0.659089, 0.090242, 0.010430},{0.660814, 0.090242, 0.011487},{
      0.661100, 0.088433, 0.011487},{0.659460, 0.087900, 0.010430}}],
    Polygon[{{0.660814, 0.090242, 0.011487},{0.662683, 0.090242, 0.012261},{
      0.662878, 0.089011, 0.012261},{0.661100, 0.088433, 0.011487}}],
    Polygon[{{0.662683, 0.090242, 0.012261},{0.664650, 0.090242, 0.012733},{
      0.664749, 0.089619, 0.012733},{0.662878, 0.089011, 0.012261}}],
    Polygon[{{0.664749, 0.089619, -0.012733},{0.662878, 0.089011, -0.012261},{
      0.663444, 0.087900, -0.012261},{0.665035, 0.089057, -0.012733}}],
    Polygon[{{0.662878, 0.089011, -0.012261},{0.661100, 0.088433, -0.011487},{
      0.661932, 0.086802, -0.011487},{0.663444, 0.087900, -0.012261}}],
    Polygon[{{0.661100, 0.088433, -0.011487},{0.659460, 0.087900, -0.010430},{
      0.660536, 0.085788, -0.010430},{0.661932, 0.086802, -0.011487}}],
    Polygon[{{0.659460, 0.087900, -0.010430},{0.657997, 0.087425, -0.009116},{
      0.659292, 0.084884, -0.009116},{0.660536, 0.085788, -0.010430}}],
    Polygon[{{0.657997, 0.087425, -0.009116},{0.656748, 0.087019, -0.007578},{
      0.658229, 0.084112, -0.007578},{0.659292, 0.084884, -0.009116}}],
    Polygon[{{0.656748, 0.087019, -0.007578},{0.655742, 0.086692, -0.005853},{
      0.657374, 0.083490, -0.005853},{0.658229, 0.084112, -0.007578}}],
    Polygon[{{0.655742, 0.086692, -0.005853},{0.655006, 0.086453, -0.003984},{
      0.656748, 0.083035, -0.003984},{0.657374, 0.083490, -0.005853}}],
    Polygon[{{0.655006, 0.086453, -0.003984},{0.654557, 0.086307, -0.002017},{
      0.656365, 0.082758, -0.002017},{0.656748, 0.083035, -0.003984}}],
    Polygon[{{0.654557, 0.086307, -0.002017},{0.654406, 0.086258, 0.000000},{
      0.656237, 0.082664, 0.000000},{0.656365, 0.082758, -0.002017}}],
    Polygon[{{0.654406, 0.086258, 0.000000},{0.654557, 0.086307, 0.002017},{
      0.656365, 0.082758, 0.002017},{0.656237, 0.082664, 0.000000}}],
    Polygon[{{0.654557, 0.086307, 0.002017},{0.655006, 0.086453, 0.003984},{
      0.656748, 0.083035, 0.003984},{0.656365, 0.082758, 0.002017}}],
    Polygon[{{0.655006, 0.086453, 0.003984},{0.655742, 0.086692, 0.005853},{
      0.657374, 0.083490, 0.005853},{0.656748, 0.083035, 0.003984}}],
    Polygon[{{0.655742, 0.086692, 0.005853},{0.656748, 0.087019, 0.007578},{
      0.658229, 0.084112, 0.007578},{0.657374, 0.083490, 0.005853}}],
    Polygon[{{0.656748, 0.087019, 0.007578},{0.657997, 0.087425, 0.009116},{
      0.659292, 0.084884, 0.009116},{0.658229, 0.084112, 0.007578}}],
    Polygon[{{0.657997, 0.087425, 0.009116},{0.659460, 0.087900, 0.010430},{
      0.660536, 0.085788, 0.010430},{0.659292, 0.084884, 0.009116}}],
    Polygon[{{0.659460, 0.087900, 0.010430},{0.661100, 0.088433, 0.011487},{
      0.661932, 0.086802, 0.011487},{0.660536, 0.085788, 0.010430}}],
    Polygon[{{0.661100, 0.088433, 0.011487},{0.662878, 0.089011, 0.012261},{
      0.663444, 0.087900, 0.012261},{0.661932, 0.086802, 0.011487}}],
    Polygon[{{0.662878, 0.089011, 0.012261},{0.664749, 0.089619, 0.012733},{
      0.665035, 0.089057, 0.012733},{0.663444, 0.087900, 0.012261}}],
    Polygon[{{0.665035, 0.089057, -0.012733},{0.663444, 0.087900, -0.012261},{
      0.664325, 0.087019, -0.012261},{0.665481, 0.088610, -0.012733}}],
    Polygon[{{0.663444, 0.087900, -0.012261},{0.661932, 0.086802, -0.011487},{
      0.663227, 0.085507, -0.011487},{0.664325, 0.087019, -0.012261}}],
    Polygon[{{0.661932, 0.086802, -0.011487},{0.660536, 0.085788, -0.010430},{
      0.662213, 0.084112, -0.010430},{0.663227, 0.085507, -0.011487}}],
    Polygon[{{0.660536, 0.085788, -0.010430},{0.659292, 0.084884, -0.009116},{
      0.661309, 0.082867, -0.009116},{0.662213, 0.084112, -0.010430}}],
    Polygon[{{0.659292, 0.084884, -0.009116},{0.658229, 0.084112, -0.007578},{
      0.660536, 0.081804, -0.007578},{0.661309, 0.082867, -0.009116}}],
    Polygon[{{0.658229, 0.084112, -0.007578},{0.657374, 0.083490, -0.005853},{
      0.659915, 0.080949, -0.005853},{0.660536, 0.081804, -0.007578}}],
    Polygon[{{0.657374, 0.083490, -0.005853},{0.656748, 0.083035, -0.003984},{
      0.659460, 0.080323, -0.003984},{0.659915, 0.080949, -0.005853}}],
    Polygon[{{0.656748, 0.083035, -0.003984},{0.656365, 0.082758, -0.002017},{
      0.659182, 0.079941, -0.002017},{0.659460, 0.080323, -0.003984}}],
    Polygon[{{0.656365, 0.082758, -0.002017},{0.656237, 0.082664, 0.000000},{
      0.659089, 0.079812, 0.000000},{0.659182, 0.079941, -0.002017}}],
    Polygon[{{0.656237, 0.082664, 0.000000},{0.656365, 0.082758, 0.002017},{
      0.659182, 0.079941, 0.002017},{0.659089, 0.079812, 0.000000}}],
    Polygon[{{0.656365, 0.082758, 0.002017},{0.656748, 0.083035, 0.003984},{
      0.659460, 0.080323, 0.003984},{0.659182, 0.079941, 0.002017}}],
    Polygon[{{0.656748, 0.083035, 0.003984},{0.657374, 0.083490, 0.005853},{
      0.659915, 0.080949, 0.005853},{0.659460, 0.080323, 0.003984}}],
    Polygon[{{0.657374, 0.083490, 0.005853},{0.658229, 0.084112, 0.007578},{
      0.660536, 0.081804, 0.007578},{0.659915, 0.080949, 0.005853}}],
    Polygon[{{0.658229, 0.084112, 0.007578},{0.659292, 0.084884, 0.009116},{
      0.661309, 0.082867, 0.009116},{0.660536, 0.081804, 0.007578}}],
    Polygon[{{0.659292, 0.084884, 0.009116},{0.660536, 0.085788, 0.010430},{
      0.662213, 0.084112, 0.010430},{0.661309, 0.082867, 0.009116}}],
    Polygon[{{0.660536, 0.085788, 0.010430},{0.661932, 0.086802, 0.011487},{
      0.663227, 0.085507, 0.011487},{0.662213, 0.084112, 0.010430}}],
    Polygon[{{0.661932, 0.086802, 0.011487},{0.663444, 0.087900, 0.012261},{
      0.664325, 0.087019, 0.012261},{0.663227, 0.085507, 0.011487}}],
    Polygon[{{0.663444, 0.087900, 0.012261},{0.665035, 0.089057, 0.012733},{
      0.665481, 0.088610, 0.012733},{0.664325, 0.087019, 0.012261}}],
    Polygon[{{0.665481, 0.088610, -0.012733},{0.664325, 0.087019, -0.012261},{
      0.665436, 0.086453, -0.012261},{0.666043, 0.088324, -0.012733}}],
    Polygon[{{0.664325, 0.087019, -0.012261},{0.663227, 0.085507, -0.011487},{
      0.664858, 0.084676, -0.011487},{0.665436, 0.086453, -0.012261}}],
    Polygon[{{0.663227, 0.085507, -0.011487},{0.662213, 0.084112, -0.010430},{
      0.664325, 0.083035, -0.010430},{0.664858, 0.084676, -0.011487}}],
    Polygon[{{0.662213, 0.084112, -0.010430},{0.661309, 0.082867, -0.009116},{
      0.663850, 0.081572, -0.009116},{0.664325, 0.083035, -0.010430}}],
    Polygon[{{0.661309, 0.082867, -0.009116},{0.660536, 0.081804, -0.007578},{
      0.663444, 0.080323, -0.007578},{0.663850, 0.081572, -0.009116}}],
    Polygon[{{0.660536, 0.081804, -0.007578},{0.659915, 0.080949, -0.005853},{
      0.663117, 0.079318, -0.005853},{0.663444, 0.080323, -0.007578}}],
    Polygon[{{0.659915, 0.080949, -0.005853},{0.659460, 0.080323, -0.003984},{
      0.662878, 0.078581, -0.003984},{0.663117, 0.079318, -0.005853}}],
    Polygon[{{0.659460, 0.080323, -0.003984},{0.659182, 0.079941, -0.002017},{
      0.662732, 0.078132, -0.002017},{0.662878, 0.078581, -0.003984}}],
    Polygon[{{0.659182, 0.079941, -0.002017},{0.659089, 0.079812, 0.000000},{
      0.662683, 0.077981, 0.000000},{0.662732, 0.078132, -0.002017}}],
    Polygon[{{0.659089, 0.079812, 0.000000},{0.659182, 0.079941, 0.002017},{
      0.662732, 0.078132, 0.002017},{0.662683, 0.077981, 0.000000}}],
    Polygon[{{0.659182, 0.079941, 0.002017},{0.659460, 0.080323, 0.003984},{
      0.662878, 0.078581, 0.003984},{0.662732, 0.078132, 0.002017}}],
    Polygon[{{0.659460, 0.080323, 0.003984},{0.659915, 0.080949, 0.005853},{
      0.663117, 0.079318, 0.005853},{0.662878, 0.078581, 0.003984}}],
    Polygon[{{0.659915, 0.080949, 0.005853},{0.660536, 0.081804, 0.007578},{
      0.663444, 0.080323, 0.007578},{0.663117, 0.079318, 0.005853}}],
    Polygon[{{0.660536, 0.081804, 0.007578},{0.661309, 0.082867, 0.009116},{
      0.663850, 0.081572, 0.009116},{0.663444, 0.080323, 0.007578}}],
    Polygon[{{0.661309, 0.082867, 0.009116},{0.662213, 0.084112, 0.010430},{
      0.664325, 0.083035, 0.010430},{0.663850, 0.081572, 0.009116}}],
    Polygon[{{0.662213, 0.084112, 0.010430},{0.663227, 0.085507, 0.011487},{
      0.664858, 0.084676, 0.011487},{0.664325, 0.083035, 0.010430}}],
    Polygon[{{0.663227, 0.085507, 0.011487},{0.664325, 0.087019, 0.012261},{
      0.665436, 0.086453, 0.012261},{0.664858, 0.084676, 0.011487}}],
    Polygon[{{0.664325, 0.087019, 0.012261},{0.665481, 0.088610, 0.012733},{
      0.666043, 0.088324, 0.012733},{0.665436, 0.086453, 0.012261}}],
    Polygon[{{0.666043, 0.088324, -0.012733},{0.665436, 0.086453, -0.012261},{
      0.666667, 0.086258, -0.012261},{0.666667, 0.088225, -0.012733}}],
    Polygon[{{0.665436, 0.086453, -0.012261},{0.664858, 0.084676, -0.011487},{
      0.666667, 0.084389, -0.011487},{0.666667, 0.086258, -0.012261}}],
    Polygon[{{0.664858, 0.084676, -0.011487},{0.664325, 0.083035, -0.010430},{
      0.666667, 0.082664, -0.010430},{0.666667, 0.084389, -0.011487}}],
    Polygon[{{0.664325, 0.083035, -0.010430},{0.663850, 0.081572, -0.009116},{
      0.666667, 0.081126, -0.009116},{0.666667, 0.082664, -0.010430}}],
    Polygon[{{0.663850, 0.081572, -0.009116},{0.663444, 0.080323, -0.007578},{
      0.666667, 0.079812, -0.007578},{0.666667, 0.081126, -0.009116}}],
    Polygon[{{0.663444, 0.080323, -0.007578},{0.663117, 0.079318, -0.005853},{
      0.666667, 0.078755, -0.005853},{0.666667, 0.079812, -0.007578}}],
    Polygon[{{0.663117, 0.079318, -0.005853},{0.662878, 0.078581, -0.003984},{
      0.666667, 0.077981, -0.003984},{0.666667, 0.078755, -0.005853}}],
    Polygon[{{0.662878, 0.078581, -0.003984},{0.662732, 0.078132, -0.002017},{
      0.666667, 0.077509, -0.002017},{0.666667, 0.077981, -0.003984}}],
    Polygon[{{0.662732, 0.078132, -0.002017},{0.662683, 0.077981, 0.000000},{
      0.666667, 0.077350, 0.000000},{0.666667, 0.077509, -0.002017}}],
    Polygon[{{0.662683, 0.077981, 0.000000},{0.662732, 0.078132, 0.002017},{
      0.666667, 0.077509, 0.002017},{0.666667, 0.077350, 0.000000}}],
    Polygon[{{0.662732, 0.078132, 0.002017},{0.662878, 0.078581, 0.003984},{
      0.666667, 0.077981, 0.003984},{0.666667, 0.077509, 0.002017}}],
    Polygon[{{0.662878, 0.078581, 0.003984},{0.663117, 0.079318, 0.005853},{
      0.666667, 0.078755, 0.005853},{0.666667, 0.077981, 0.003984}}],
    Polygon[{{0.663117, 0.079318, 0.005853},{0.663444, 0.080323, 0.007578},{
      0.666667, 0.079812, 0.007578},{0.666667, 0.078755, 0.005853}}],
    Polygon[{{0.663444, 0.080323, 0.007578},{0.663850, 0.081572, 0.009116},{
      0.666667, 0.081126, 0.009116},{0.666667, 0.079812, 0.007578}}],
    Polygon[{{0.663850, 0.081572, 0.009116},{0.664325, 0.083035, 0.010430},{
      0.666667, 0.082664, 0.010430},{0.666667, 0.081126, 0.009116}}],
    Polygon[{{0.664325, 0.083035, 0.010430},{0.664858, 0.084676, 0.011487},{
      0.666667, 0.084389, 0.011487},{0.666667, 0.082664, 0.010430}}],
    Polygon[{{0.664858, 0.084676, 0.011487},{0.665436, 0.086453, 0.012261},{
      0.666667, 0.086258, 0.012261},{0.666667, 0.084389, 0.011487}}],
    Polygon[{{0.665436, 0.086453, 0.012261},{0.666043, 0.088324, 0.012733},{
      0.666667, 0.088225, 0.012733},{0.666667, 0.086258, 0.012261}}],
    Polygon[{{0.666667, 0.088225, -0.012733},{0.666667, 0.086258, -0.012261},{
      0.667898, 0.086453, -0.012261},{0.667290, 0.088324, -0.012733}}],
    Polygon[{{0.666667, 0.086258, -0.012261},{0.666667, 0.084389, -0.011487},{
      0.668475, 0.084676, -0.011487},{0.667898, 0.086453, -0.012261}}],
    Polygon[{{0.666667, 0.084389, -0.011487},{0.666667, 0.082664, -0.010430},{
      0.669008, 0.083035, -0.010430},{0.668475, 0.084676, -0.011487}}],
    Polygon[{{0.666667, 0.082664, -0.010430},{0.666667, 0.081126, -0.009116},{
      0.669484, 0.081572, -0.009116},{0.669008, 0.083035, -0.010430}}],
    Polygon[{{0.666667, 0.081126, -0.009116},{0.666667, 0.079812, -0.007578},{
      0.669890, 0.080323, -0.007578},{0.669484, 0.081572, -0.009116}}],
    Polygon[{{0.666667, 0.079812, -0.007578},{0.666667, 0.078755, -0.005853},{
      0.670216, 0.079318, -0.005853},{0.669890, 0.080323, -0.007578}}],
    Polygon[{{0.666667, 0.078755, -0.005853},{0.666667, 0.077981, -0.003984},{
      0.670455, 0.078581, -0.003984},{0.670216, 0.079318, -0.005853}}],
    Polygon[{{0.666667, 0.077981, -0.003984},{0.666667, 0.077509, -0.002017},{
      0.670601, 0.078132, -0.002017},{0.670455, 0.078581, -0.003984}}],
    Polygon[{{0.666667, 0.077509, -0.002017},{0.666667, 0.077350, 0.000000},{
      0.670650, 0.077981, 0.000000},{0.670601, 0.078132, -0.002017}}],
    Polygon[{{0.666667, 0.077350, 0.000000},{0.666667, 0.077509, 0.002017},{
      0.670601, 0.078132, 0.002017},{0.670650, 0.077981, 0.000000}}],
    Polygon[{{0.666667, 0.077509, 0.002017},{0.666667, 0.077981, 0.003984},{
      0.670455, 0.078581, 0.003984},{0.670601, 0.078132, 0.002017}}],
    Polygon[{{0.666667, 0.077981, 0.003984},{0.666667, 0.078755, 0.005853},{
      0.670216, 0.079318, 0.005853},{0.670455, 0.078581, 0.003984}}],
    Polygon[{{0.666667, 0.078755, 0.005853},{0.666667, 0.079812, 0.007578},{
      0.669890, 0.080323, 0.007578},{0.670216, 0.079318, 0.005853}}],
    Polygon[{{0.666667, 0.079812, 0.007578},{0.666667, 0.081126, 0.009116},{
      0.669484, 0.081572, 0.009116},{0.669890, 0.080323, 0.007578}}],
    Polygon[{{0.666667, 0.081126, 0.009116},{0.666667, 0.082664, 0.010430},{
      0.669008, 0.083035, 0.010430},{0.669484, 0.081572, 0.009116}}],
    Polygon[{{0.666667, 0.082664, 0.010430},{0.666667, 0.084389, 0.011487},{
      0.668475, 0.084676, 0.011487},{0.669008, 0.083035, 0.010430}}],
    Polygon[{{0.666667, 0.084389, 0.011487},{0.666667, 0.086258, 0.012261},{
      0.667898, 0.086453, 0.012261},{0.668475, 0.084676, 0.011487}}],
    Polygon[{{0.666667, 0.086258, 0.012261},{0.666667, 0.088225, 0.012733},{
      0.667290, 0.088324, 0.012733},{0.667898, 0.086453, 0.012261}}],
    Polygon[{{0.667290, 0.088324, -0.012733},{0.667898, 0.086453, -0.012261},{
      0.669008, 0.087019, -0.012261},{0.667852, 0.088610, -0.012733}}],
    Polygon[{{0.667898, 0.086453, -0.012261},{0.668475, 0.084676, -0.011487},{
      0.670107, 0.085507, -0.011487},{0.669008, 0.087019, -0.012261}}],
    Polygon[{{0.668475, 0.084676, -0.011487},{0.669008, 0.083035, -0.010430},{
      0.671121, 0.084112, -0.010430},{0.670107, 0.085507, -0.011487}}],
    Polygon[{{0.669008, 0.083035, -0.010430},{0.669484, 0.081572, -0.009116},{
      0.672025, 0.082867, -0.009116},{0.671121, 0.084112, -0.010430}}],
    Polygon[{{0.669484, 0.081572, -0.009116},{0.669890, 0.080323, -0.007578},{
      0.672797, 0.081804, -0.007578},{0.672025, 0.082867, -0.009116}}],
    Polygon[{{0.669890, 0.080323, -0.007578},{0.670216, 0.079318, -0.005853},{
      0.673418, 0.080949, -0.005853},{0.672797, 0.081804, -0.007578}}],
    Polygon[{{0.670216, 0.079318, -0.005853},{0.670455, 0.078581, -0.003984},{
      0.673873, 0.080323, -0.003984},{0.673418, 0.080949, -0.005853}}],
    Polygon[{{0.670455, 0.078581, -0.003984},{0.670601, 0.078132, -0.002017},{
      0.674151, 0.079941, -0.002017},{0.673873, 0.080323, -0.003984}}],
    Polygon[{{0.670601, 0.078132, -0.002017},{0.670650, 0.077981, 0.000000},{
      0.674244, 0.079812, 0.000000},{0.674151, 0.079941, -0.002017}}],
    Polygon[{{0.670650, 0.077981, 0.000000},{0.670601, 0.078132, 0.002017},{
      0.674151, 0.079941, 0.002017},{0.674244, 0.079812, 0.000000}}],
    Polygon[{{0.670601, 0.078132, 0.002017},{0.670455, 0.078581, 0.003984},{
      0.673873, 0.080323, 0.003984},{0.674151, 0.079941, 0.002017}}],
    Polygon[{{0.670455, 0.078581, 0.003984},{0.670216, 0.079318, 0.005853},{
      0.673418, 0.080949, 0.005853},{0.673873, 0.080323, 0.003984}}],
    Polygon[{{0.670216, 0.079318, 0.005853},{0.669890, 0.080323, 0.007578},{
      0.672797, 0.081804, 0.007578},{0.673418, 0.080949, 0.005853}}],
    Polygon[{{0.669890, 0.080323, 0.007578},{0.669484, 0.081572, 0.009116},{
      0.672025, 0.082867, 0.009116},{0.672797, 0.081804, 0.007578}}],
    Polygon[{{0.669484, 0.081572, 0.009116},{0.669008, 0.083035, 0.010430},{
      0.671121, 0.084112, 0.010430},{0.672025, 0.082867, 0.009116}}],
    Polygon[{{0.669008, 0.083035, 0.010430},{0.668475, 0.084676, 0.011487},{
      0.670107, 0.085507, 0.011487},{0.671121, 0.084112, 0.010430}}],
    Polygon[{{0.668475, 0.084676, 0.011487},{0.667898, 0.086453, 0.012261},{
      0.669008, 0.087019, 0.012261},{0.670107, 0.085507, 0.011487}}],
    Polygon[{{0.667898, 0.086453, 0.012261},{0.667290, 0.088324, 0.012733},{
      0.667852, 0.088610, 0.012733},{0.669008, 0.087019, 0.012261}}],
    Polygon[{{0.667852, 0.088610, -0.012733},{0.669008, 0.087019, -0.012261},{
      0.669890, 0.087900, -0.012261},{0.668298, 0.089057, -0.012733}}],
    Polygon[{{0.669008, 0.087019, -0.012261},{0.670107, 0.085507, -0.011487},{
      0.671402, 0.086802, -0.011487},{0.669890, 0.087900, -0.012261}}],
    Polygon[{{0.670107, 0.085507, -0.011487},{0.671121, 0.084112, -0.010430},{
      0.672797, 0.085788, -0.010430},{0.671402, 0.086802, -0.011487}}],
    Polygon[{{0.671121, 0.084112, -0.010430},{0.672025, 0.082867, -0.009116},{
      0.674042, 0.084884, -0.009116},{0.672797, 0.085788, -0.010430}}],
    Polygon[{{0.672025, 0.082867, -0.009116},{0.672797, 0.081804, -0.007578},{
      0.675104, 0.084112, -0.007578},{0.674042, 0.084884, -0.009116}}],
    Polygon[{{0.672797, 0.081804, -0.007578},{0.673418, 0.080949, -0.005853},{
      0.675960, 0.083490, -0.005853},{0.675104, 0.084112, -0.007578}}],
    Polygon[{{0.673418, 0.080949, -0.005853},{0.673873, 0.080323, -0.003984},{
      0.676586, 0.083035, -0.003984},{0.675960, 0.083490, -0.005853}}],
    Polygon[{{0.673873, 0.080323, -0.003984},{0.674151, 0.079941, -0.002017},{
      0.676968, 0.082758, -0.002017},{0.676586, 0.083035, -0.003984}}],
    Polygon[{{0.674151, 0.079941, -0.002017},{0.674244, 0.079812, 0.000000},{
      0.677096, 0.082664, 0.000000},{0.676968, 0.082758, -0.002017}}],
    Polygon[{{0.674244, 0.079812, 0.000000},{0.674151, 0.079941, 0.002017},{
      0.676968, 0.082758, 0.002017},{0.677096, 0.082664, 0.000000}}],
    Polygon[{{0.674151, 0.079941, 0.002017},{0.673873, 0.080323, 0.003984},{
      0.676586, 0.083035, 0.003984},{0.676968, 0.082758, 0.002017}}],
    Polygon[{{0.673873, 0.080323, 0.003984},{0.673418, 0.080949, 0.005853},{
      0.675960, 0.083490, 0.005853},{0.676586, 0.083035, 0.003984}}],
    Polygon[{{0.673418, 0.080949, 0.005853},{0.672797, 0.081804, 0.007578},{
      0.675104, 0.084112, 0.007578},{0.675960, 0.083490, 0.005853}}],
    Polygon[{{0.672797, 0.081804, 0.007578},{0.672025, 0.082867, 0.009116},{
      0.674042, 0.084884, 0.009116},{0.675104, 0.084112, 0.007578}}],
    Polygon[{{0.672025, 0.082867, 0.009116},{0.671121, 0.084112, 0.010430},{
      0.672797, 0.085788, 0.010430},{0.674042, 0.084884, 0.009116}}],
    Polygon[{{0.671121, 0.084112, 0.010430},{0.670107, 0.085507, 0.011487},{
      0.671402, 0.086802, 0.011487},{0.672797, 0.085788, 0.010430}}],
    Polygon[{{0.670107, 0.085507, 0.011487},{0.669008, 0.087019, 0.012261},{
      0.669890, 0.087900, 0.012261},{0.671402, 0.086802, 0.011487}}],
    Polygon[{{0.669008, 0.087019, 0.012261},{0.667852, 0.088610, 0.012733},{
      0.668298, 0.089057, 0.012733},{0.669890, 0.087900, 0.012261}}],
    Polygon[{{0.668298, 0.089057, -0.012733},{0.669890, 0.087900, -0.012261},{
      0.670455, 0.089011, -0.012261},{0.668585, 0.089619, -0.012733}}],
    Polygon[{{0.669890, 0.087900, -0.012261},{0.671402, 0.086802, -0.011487},{
      0.672233, 0.088433, -0.011487},{0.670455, 0.089011, -0.012261}}],
    Polygon[{{0.671402, 0.086802, -0.011487},{0.672797, 0.085788, -0.010430},{
      0.673873, 0.087900, -0.010430},{0.672233, 0.088433, -0.011487}}],
    Polygon[{{0.672797, 0.085788, -0.010430},{0.674042, 0.084884, -0.009116},{
      0.675336, 0.087425, -0.009116},{0.673873, 0.087900, -0.010430}}],
    Polygon[{{0.674042, 0.084884, -0.009116},{0.675104, 0.084112, -0.007578},{
      0.676586, 0.087019, -0.007578},{0.675336, 0.087425, -0.009116}}],
    Polygon[{{0.675104, 0.084112, -0.007578},{0.675960, 0.083490, -0.005853},{
      0.677591, 0.086692, -0.005853},{0.676586, 0.087019, -0.007578}}],
    Polygon[{{0.675960, 0.083490, -0.005853},{0.676586, 0.083035, -0.003984},{
      0.678327, 0.086453, -0.003984},{0.677591, 0.086692, -0.005853}}],
    Polygon[{{0.676586, 0.083035, -0.003984},{0.676968, 0.082758, -0.002017},{
      0.678776, 0.086307, -0.002017},{0.678327, 0.086453, -0.003984}}],
    Polygon[{{0.676968, 0.082758, -0.002017},{0.677096, 0.082664, 0.000000},{
      0.678927, 0.086258, 0.000000},{0.678776, 0.086307, -0.002017}}],
    Polygon[{{0.677096, 0.082664, 0.000000},{0.676968, 0.082758, 0.002017},{
      0.678776, 0.086307, 0.002017},{0.678927, 0.086258, 0.000000}}],
    Polygon[{{0.676968, 0.082758, 0.002017},{0.676586, 0.083035, 0.003984},{
      0.678327, 0.086453, 0.003984},{0.678776, 0.086307, 0.002017}}],
    Polygon[{{0.676586, 0.083035, 0.003984},{0.675960, 0.083490, 0.005853},{
      0.677591, 0.086692, 0.005853},{0.678327, 0.086453, 0.003984}}],
    Polygon[{{0.675960, 0.083490, 0.005853},{0.675104, 0.084112, 0.007578},{
      0.676586, 0.087019, 0.007578},{0.677591, 0.086692, 0.005853}}],
    Polygon[{{0.675104, 0.084112, 0.007578},{0.674042, 0.084884, 0.009116},{
      0.675336, 0.087425, 0.009116},{0.676586, 0.087019, 0.007578}}],
    Polygon[{{0.674042, 0.084884, 0.009116},{0.672797, 0.085788, 0.010430},{
      0.673873, 0.087900, 0.010430},{0.675336, 0.087425, 0.009116}}],
    Polygon[{{0.672797, 0.085788, 0.010430},{0.671402, 0.086802, 0.011487},{
      0.672233, 0.088433, 0.011487},{0.673873, 0.087900, 0.010430}}],
    Polygon[{{0.671402, 0.086802, 0.011487},{0.669890, 0.087900, 0.012261},{
      0.670455, 0.089011, 0.012261},{0.672233, 0.088433, 0.011487}}],
    Polygon[{{0.669890, 0.087900, 0.012261},{0.668298, 0.089057, 0.012733},{
      0.668585, 0.089619, 0.012733},{0.670455, 0.089011, 0.012261}}],
    Polygon[{{0.668585, 0.089619, -0.012733},{0.670455, 0.089011, -0.012261},{
      0.670650, 0.090242, -0.012261},{0.668683, 0.090242, -0.012733}}],
    Polygon[{{0.670455, 0.089011, -0.012261},{0.672233, 0.088433, -0.011487},{
      0.672519, 0.090242, -0.011487},{0.670650, 0.090242, -0.012261}}],
    Polygon[{{0.672233, 0.088433, -0.011487},{0.673873, 0.087900, -0.010430},{
      0.674244, 0.090242, -0.010430},{0.672519, 0.090242, -0.011487}}],
    Polygon[{{0.673873, 0.087900, -0.010430},{0.675336, 0.087425, -0.009116},{
      0.675783, 0.090242, -0.009116},{0.674244, 0.090242, -0.010430}}],
    Polygon[{{0.675336, 0.087425, -0.009116},{0.676586, 0.087019, -0.007578},{
      0.677096, 0.090242, -0.007578},{0.675783, 0.090242, -0.009116}}],
    Polygon[{{0.676586, 0.087019, -0.007578},{0.677591, 0.086692, -0.005853},{
      0.678153, 0.090242, -0.005853},{0.677096, 0.090242, -0.007578}}],
    Polygon[{{0.677591, 0.086692, -0.005853},{0.678327, 0.086453, -0.003984},{
      0.678927, 0.090242, -0.003984},{0.678153, 0.090242, -0.005853}}],
    Polygon[{{0.678327, 0.086453, -0.003984},{0.678776, 0.086307, -0.002017},{
      0.679400, 0.090242, -0.002017},{0.678927, 0.090242, -0.003984}}],
    Polygon[{{0.678776, 0.086307, -0.002017},{0.678927, 0.086258, 0.000000},{
      0.679558, 0.090242, 0.000000},{0.679400, 0.090242, -0.002017}}],
    Polygon[{{0.678927, 0.086258, 0.000000},{0.678776, 0.086307, 0.002017},{
      0.679400, 0.090242, 0.002017},{0.679558, 0.090242, 0.000000}}],
    Polygon[{{0.678776, 0.086307, 0.002017},{0.678327, 0.086453, 0.003984},{
      0.678927, 0.090242, 0.003984},{0.679400, 0.090242, 0.002017}}],
    Polygon[{{0.678327, 0.086453, 0.003984},{0.677591, 0.086692, 0.005853},{
      0.678153, 0.090242, 0.005853},{0.678927, 0.090242, 0.003984}}],
    Polygon[{{0.677591, 0.086692, 0.005853},{0.676586, 0.087019, 0.007578},{
      0.677096, 0.090242, 0.007578},{0.678153, 0.090242, 0.005853}}],
    Polygon[{{0.676586, 0.087019, 0.007578},{0.675336, 0.087425, 0.009116},{
      0.675783, 0.090242, 0.009116},{0.677096, 0.090242, 0.007578}}],
    Polygon[{{0.675336, 0.087425, 0.009116},{0.673873, 0.087900, 0.010430},{
      0.674244, 0.090242, 0.010430},{0.675783, 0.090242, 0.009116}}],
    Polygon[{{0.673873, 0.087900, 0.010430},{0.672233, 0.088433, 0.011487},{
      0.672519, 0.090242, 0.011487},{0.674244, 0.090242, 0.010430}}],
    Polygon[{{0.672233, 0.088433, 0.011487},{0.670455, 0.089011, 0.012261},{
      0.670650, 0.090242, 0.012261},{0.672519, 0.090242, 0.011487}}],
    Polygon[{{0.670455, 0.089011, 0.012261},{0.668585, 0.089619, 0.012733},{
      0.668683, 0.090242, 0.012733},{0.670650, 0.090242, 0.012261}}],
    Polygon[{{0.487205, 0.028972, -0.028615},{0.491626, 0.028972, -0.027554},{
      0.491187, 0.031738, -0.027554},{0.486983, 0.030372, -0.028615}}],
    Polygon[{{0.491626, 0.028972, -0.027554},{0.495826, 0.028972, -0.025814},{
      0.495182, 0.033036, -0.025814},{0.491187, 0.031738, -0.027554}}],
    Polygon[{{0.495826, 0.028972, -0.025814},{0.499702, 0.028972, -0.023438},{
      0.498868, 0.034234, -0.023438},{0.495182, 0.033036, -0.025814}}],
    Polygon[{{0.499702, 0.028972, -0.023438},{0.503159, 0.028972, -0.020486},{
      0.502156, 0.035302, -0.020486},{0.498868, 0.034234, -0.023438}}],
    Polygon[{{0.503159, 0.028972, -0.020486},{0.506111, 0.028972, -0.017029},{
      0.504964, 0.036214, -0.017029},{0.502156, 0.035302, -0.020486}}],
    Polygon[{{0.506111, 0.028972, -0.017029},{0.508487, 0.028972, -0.013153},{
      0.507223, 0.036948, -0.013153},{0.504964, 0.036214, -0.017029}}],
    Polygon[{{0.508487, 0.028972, -0.013153},{0.510226, 0.028972, -0.008953},{
      0.508878, 0.037486, -0.008953},{0.507223, 0.036948, -0.013153}}],
    Polygon[{{0.510226, 0.028972, -0.008953},{0.511288, 0.028972, -0.004532},{
      0.509887, 0.037814, -0.004532},{0.508878, 0.037486, -0.008953}}],
    Polygon[{{0.511288, 0.028972, -0.004532},{0.511644, 0.028972, 0.000000},{
      0.510226, 0.037924, 0.000000},{0.509887, 0.037814, -0.004532}}],
    Polygon[{{0.511644, 0.028972, 0.000000},{0.511288, 0.028972, 0.004532},{
      0.509887, 0.037814, 0.004532},{0.510226, 0.037924, 0.000000}}],
    Polygon[{{0.511288, 0.028972, 0.004532},{0.510226, 0.028972, 0.008953},{
      0.508878, 0.037486, 0.008953},{0.509887, 0.037814, 0.004532}}],
    Polygon[{{0.510226, 0.028972, 0.008953},{0.508487, 0.028972, 0.013153},{
      0.507223, 0.036948, 0.013153},{0.508878, 0.037486, 0.008953}}],
    Polygon[{{0.508487, 0.028972, 0.013153},{0.506111, 0.028972, 0.017029},{
      0.504964, 0.036214, 0.017029},{0.507223, 0.036948, 0.013153}}],
    Polygon[{{0.506111, 0.028972, 0.017029},{0.503159, 0.028972, 0.020486},{
      0.502156, 0.035302, 0.020486},{0.504964, 0.036214, 0.017029}}],
    Polygon[{{0.503159, 0.028972, 0.020486},{0.499702, 0.028972, 0.023438},{
      0.498868, 0.034234, 0.023438},{0.502156, 0.035302, 0.020486}}],
    Polygon[{{0.499702, 0.028972, 0.023438},{0.495826, 0.028972, 0.025814},{
      0.495182, 0.033036, 0.025814},{0.498868, 0.034234, 0.023438}}],
    Polygon[{{0.495826, 0.028972, 0.025814},{0.491626, 0.028972, 0.027554},{
      0.491187, 0.031738, 0.027554},{0.495182, 0.033036, 0.025814}}],
    Polygon[{{0.491626, 0.028972, 0.027554},{0.487205, 0.028972, 0.028615},{
      0.486983, 0.030372, 0.028615},{0.491187, 0.031738, 0.027554}}],
    Polygon[{{0.486983, 0.030372, -0.028615},{0.491187, 0.031738, -0.027554},{
      0.489916, 0.034234, -0.027554},{0.486339, 0.031635, -0.028615}}],
    Polygon[{{0.491187, 0.031738, -0.027554},{0.495182, 0.033036, -0.025814},{
      0.493314, 0.036703, -0.025814},{0.489916, 0.034234, -0.027554}}],
    Polygon[{{0.495182, 0.033036, -0.025814},{0.498868, 0.034234, -0.023438},{
      0.496450, 0.038981, -0.023438},{0.493314, 0.036703, -0.025814}}],
    Polygon[{{0.498868, 0.034234, -0.023438},{0.502156, 0.035302, -0.020486},{
      0.499246, 0.041013, -0.020486},{0.496450, 0.038981, -0.023438}}],
    Polygon[{{0.502156, 0.035302, -0.020486},{0.504964, 0.036214, -0.017029},{
      0.501635, 0.042748, -0.017029},{0.499246, 0.041013, -0.020486}}],
    Polygon[{{0.504964, 0.036214, -0.017029},{0.507223, 0.036948, -0.013153},{
      0.503557, 0.044144, -0.013153},{0.501635, 0.042748, -0.017029}}],
    Polygon[{{0.507223, 0.036948, -0.013153},{0.508878, 0.037486, -0.008953},{
      0.504964, 0.045167, -0.008953},{0.503557, 0.044144, -0.013153}}],
    Polygon[{{0.508878, 0.037486, -0.008953},{0.509887, 0.037814, -0.004532},{
      0.505823, 0.045791, -0.004532},{0.504964, 0.045167, -0.008953}}],
    Polygon[{{0.509887, 0.037814, -0.004532},{0.510226, 0.037924, 0.000000},{
      0.506111, 0.046001, 0.000000},{0.505823, 0.045791, -0.004532}}],
    Polygon[{{0.510226, 0.037924, 0.000000},{0.509887, 0.037814, 0.004532},{
      0.505823, 0.045791, 0.004532},{0.506111, 0.046001, 0.000000}}],
    Polygon[{{0.509887, 0.037814, 0.004532},{0.508878, 0.037486, 0.008953},{
      0.504964, 0.045167, 0.008953},{0.505823, 0.045791, 0.004532}}],
    Polygon[{{0.508878, 0.037486, 0.008953},{0.507223, 0.036948, 0.013153},{
      0.503557, 0.044144, 0.013153},{0.504964, 0.045167, 0.008953}}],
    Polygon[{{0.507223, 0.036948, 0.013153},{0.504964, 0.036214, 0.017029},{
      0.501635, 0.042748, 0.017029},{0.503557, 0.044144, 0.013153}}],
    Polygon[{{0.504964, 0.036214, 0.017029},{0.502156, 0.035302, 0.020486},{
      0.499246, 0.041013, 0.020486},{0.501635, 0.042748, 0.017029}}],
    Polygon[{{0.502156, 0.035302, 0.020486},{0.498868, 0.034234, 0.023438},{
      0.496450, 0.038981, 0.023438},{0.499246, 0.041013, 0.020486}}],
    Polygon[{{0.498868, 0.034234, 0.023438},{0.495182, 0.033036, 0.025814},{
      0.493314, 0.036703, 0.025814},{0.496450, 0.038981, 0.023438}}],
    Polygon[{{0.495182, 0.033036, 0.025814},{0.491187, 0.031738, 0.027554},{
      0.489916, 0.034234, 0.027554},{0.493314, 0.036703, 0.025814}}],
    Polygon[{{0.491187, 0.031738, 0.027554},{0.486983, 0.030372, 0.028615},{
      0.486339, 0.031635, 0.028615},{0.489916, 0.034234, 0.027554}}],
    Polygon[{{0.486339, 0.031635, -0.028615},{0.489916, 0.034234, -0.027554},{
      0.487935, 0.036214, -0.027554},{0.485337, 0.032638, -0.028615}}],
    Polygon[{{0.489916, 0.034234, -0.027554},{0.493314, 0.036703, -0.025814},{
      0.490404, 0.039612, -0.025814},{0.487935, 0.036214, -0.027554}}],
    Polygon[{{0.493314, 0.036703, -0.025814},{0.496450, 0.038981, -0.023438},{
      0.492682, 0.042748, -0.023438},{0.490404, 0.039612, -0.025814}}],
    Polygon[{{0.496450, 0.038981, -0.023438},{0.499246, 0.041013, -0.020486},{
      0.494714, 0.045545, -0.020486},{0.492682, 0.042748, -0.023438}}],
    Polygon[{{0.499246, 0.041013, -0.020486},{0.501635, 0.042748, -0.017029},{
      0.496450, 0.047934, -0.017029},{0.494714, 0.045545, -0.020486}}],
    Polygon[{{0.501635, 0.042748, -0.017029},{0.503557, 0.044144, -0.013153},{
      0.497846, 0.049855, -0.013153},{0.496450, 0.047934, -0.017029}}],
    Polygon[{{0.503557, 0.044144, -0.013153},{0.504964, 0.045167, -0.008953},{
      0.498868, 0.051263, -0.008953},{0.497846, 0.049855, -0.013153}}],
    Polygon[{{0.504964, 0.045167, -0.008953},{0.505823, 0.045791, -0.004532},{
      0.499492, 0.052121, -0.004532},{0.498868, 0.051263, -0.008953}}],
    Polygon[{{0.505823, 0.045791, -0.004532},{0.506111, 0.046001, 0.000000},{
      0.499702, 0.052410, 0.000000},{0.499492, 0.052121, -0.004532}}],
    Polygon[{{0.506111, 0.046001, 0.000000},{0.505823, 0.045791, 0.004532},{
      0.499492, 0.052121, 0.004532},{0.499702, 0.052410, 0.000000}}],
    Polygon[{{0.505823, 0.045791, 0.004532},{0.504964, 0.045167, 0.008953},{
      0.498868, 0.051263, 0.008953},{0.499492, 0.052121, 0.004532}}],
    Polygon[{{0.504964, 0.045167, 0.008953},{0.503557, 0.044144, 0.013153},{
      0.497846, 0.049855, 0.013153},{0.498868, 0.051263, 0.008953}}],
    Polygon[{{0.503557, 0.044144, 0.013153},{0.501635, 0.042748, 0.017029},{
      0.496450, 0.047934, 0.017029},{0.497846, 0.049855, 0.013153}}],
    Polygon[{{0.501635, 0.042748, 0.017029},{0.499246, 0.041013, 0.020486},{
      0.494714, 0.045545, 0.020486},{0.496450, 0.047934, 0.017029}}],
    Polygon[{{0.499246, 0.041013, 0.020486},{0.496450, 0.038981, 0.023438},{
      0.492682, 0.042748, 0.023438},{0.494714, 0.045545, 0.020486}}],
    Polygon[{{0.496450, 0.038981, 0.023438},{0.493314, 0.036703, 0.025814},{
      0.490404, 0.039612, 0.025814},{0.492682, 0.042748, 0.023438}}],
    Polygon[{{0.493314, 0.036703, 0.025814},{0.489916, 0.034234, 0.027554},{
      0.487935, 0.036214, 0.027554},{0.490404, 0.039612, 0.025814}}],
    Polygon[{{0.489916, 0.034234, 0.027554},{0.486339, 0.031635, 0.028615},{
      0.485337, 0.032638, 0.028615},{0.487935, 0.036214, 0.027554}}],
    Polygon[{{0.485337, 0.032638, -0.028615},{0.487935, 0.036214, -0.027554},{
      0.485439, 0.037486, -0.027554},{0.484073, 0.033282, -0.028615}}],
    Polygon[{{0.487935, 0.036214, -0.027554},{0.490404, 0.039612, -0.025814},{
      0.486737, 0.041481, -0.025814},{0.485439, 0.037486, -0.027554}}],
    Polygon[{{0.490404, 0.039612, -0.025814},{0.492682, 0.042748, -0.023438},{
      0.487935, 0.045167, -0.023438},{0.486737, 0.041481, -0.025814}}],
    Polygon[{{0.492682, 0.042748, -0.023438},{0.494714, 0.045545, -0.020486},{
      0.489003, 0.048455, -0.020486},{0.487935, 0.045167, -0.023438}}],
    Polygon[{{0.494714, 0.045545, -0.020486},{0.496450, 0.047934, -0.017029},{
      0.489916, 0.051263, -0.017029},{0.489003, 0.048455, -0.020486}}],
    Polygon[{{0.496450, 0.047934, -0.017029},{0.497846, 0.049855, -0.013153},{
      0.490650, 0.053522, -0.013153},{0.489916, 0.051263, -0.017029}}],
    Polygon[{{0.497846, 0.049855, -0.013153},{0.498868, 0.051263, -0.008953},{
      0.491187, 0.055177, -0.008953},{0.490650, 0.053522, -0.013153}}],
    Polygon[{{0.498868, 0.051263, -0.008953},{0.499492, 0.052121, -0.004532},{
      0.491515, 0.056186, -0.004532},{0.491187, 0.055177, -0.008953}}],
    Polygon[{{0.499492, 0.052121, -0.004532},{0.499702, 0.052410, 0.000000},{
      0.491626, 0.056525, 0.000000},{0.491515, 0.056186, -0.004532}}],
    Polygon[{{0.499702, 0.052410, 0.000000},{0.499492, 0.052121, 0.004532},{
      0.491515, 0.056186, 0.004532},{0.491626, 0.056525, 0.000000}}],
    Polygon[{{0.499492, 0.052121, 0.004532},{0.498868, 0.051263, 0.008953},{
      0.491187, 0.055177, 0.008953},{0.491515, 0.056186, 0.004532}}],
    Polygon[{{0.498868, 0.051263, 0.008953},{0.497846, 0.049855, 0.013153},{
      0.490650, 0.053522, 0.013153},{0.491187, 0.055177, 0.008953}}],
    Polygon[{{0.497846, 0.049855, 0.013153},{0.496450, 0.047934, 0.017029},{
      0.489916, 0.051263, 0.017029},{0.490650, 0.053522, 0.013153}}],
    Polygon[{{0.496450, 0.047934, 0.017029},{0.494714, 0.045545, 0.020486},{
      0.489003, 0.048455, 0.020486},{0.489916, 0.051263, 0.017029}}],
    Polygon[{{0.494714, 0.045545, 0.020486},{0.492682, 0.042748, 0.023438},{
      0.487935, 0.045167, 0.023438},{0.489003, 0.048455, 0.020486}}],
    Polygon[{{0.492682, 0.042748, 0.023438},{0.490404, 0.039612, 0.025814},{
      0.486737, 0.041481, 0.025814},{0.487935, 0.045167, 0.023438}}],
    Polygon[{{0.490404, 0.039612, 0.025814},{0.487935, 0.036214, 0.027554},{
      0.485439, 0.037486, 0.027554},{0.486737, 0.041481, 0.025814}}],
    Polygon[{{0.487935, 0.036214, 0.027554},{0.485337, 0.032638, 0.028615},{
      0.484073, 0.033282, 0.028615},{0.485439, 0.037486, 0.027554}}],
    Polygon[{{0.484073, 0.033282, -0.028615},{0.485439, 0.037486, -0.027554},{
      0.482673, 0.037924, -0.027554},{0.482673, 0.033504, -0.028615}}],
    Polygon[{{0.485439, 0.037486, -0.027554},{0.486737, 0.041481, -0.025814},{
      0.482673, 0.042124, -0.025814},{0.482673, 0.037924, -0.027554}}],
    Polygon[{{0.486737, 0.041481, -0.025814},{0.487935, 0.045167, -0.023438},{
      0.482673, 0.046001, -0.023438},{0.482673, 0.042124, -0.025814}}],
    Polygon[{{0.487935, 0.045167, -0.023438},{0.489003, 0.048455, -0.020486},{
      0.482673, 0.049457, -0.020486},{0.482673, 0.046001, -0.023438}}],
    Polygon[{{0.489003, 0.048455, -0.020486},{0.489916, 0.051263, -0.017029},{
      0.482673, 0.052410, -0.017029},{0.482673, 0.049457, -0.020486}}],
    Polygon[{{0.489916, 0.051263, -0.017029},{0.490650, 0.053522, -0.013153},{
      0.482673, 0.054785, -0.013153},{0.482673, 0.052410, -0.017029}}],
    Polygon[{{0.490650, 0.053522, -0.013153},{0.491187, 0.055177, -0.008953},{
      0.482673, 0.056525, -0.008953},{0.482673, 0.054785, -0.013153}}],
    Polygon[{{0.491187, 0.055177, -0.008953},{0.491515, 0.056186, -0.004532},{
      0.482673, 0.057586, -0.004532},{0.482673, 0.056525, -0.008953}}],
    Polygon[{{0.491515, 0.056186, -0.004532},{0.491626, 0.056525, 0.000000},{
      0.482673, 0.057943, 0.000000},{0.482673, 0.057586, -0.004532}}],
    Polygon[{{0.491626, 0.056525, 0.000000},{0.491515, 0.056186, 0.004532},{
      0.482673, 0.057586, 0.004532},{0.482673, 0.057943, 0.000000}}],
    Polygon[{{0.491515, 0.056186, 0.004532},{0.491187, 0.055177, 0.008953},{
      0.482673, 0.056525, 0.008953},{0.482673, 0.057586, 0.004532}}],
    Polygon[{{0.491187, 0.055177, 0.008953},{0.490650, 0.053522, 0.013153},{
      0.482673, 0.054785, 0.013153},{0.482673, 0.056525, 0.008953}}],
    Polygon[{{0.490650, 0.053522, 0.013153},{0.489916, 0.051263, 0.017029},{
      0.482673, 0.052410, 0.017029},{0.482673, 0.054785, 0.013153}}],
    Polygon[{{0.489916, 0.051263, 0.017029},{0.489003, 0.048455, 0.020486},{
      0.482673, 0.049457, 0.020486},{0.482673, 0.052410, 0.017029}}],
    Polygon[{{0.489003, 0.048455, 0.020486},{0.487935, 0.045167, 0.023438},{
      0.482673, 0.046001, 0.023438},{0.482673, 0.049457, 0.020486}}],
    Polygon[{{0.487935, 0.045167, 0.023438},{0.486737, 0.041481, 0.025814},{
      0.482673, 0.042124, 0.025814},{0.482673, 0.046001, 0.023438}}],
    Polygon[{{0.486737, 0.041481, 0.025814},{0.485439, 0.037486, 0.027554},{
      0.482673, 0.037924, 0.027554},{0.482673, 0.042124, 0.025814}}],
    Polygon[{{0.485439, 0.037486, 0.027554},{0.484073, 0.033282, 0.028615},{
      0.482673, 0.033504, 0.028615},{0.482673, 0.037924, 0.027554}}],
    Polygon[{{0.482673, 0.033504, -0.028615},{0.482673, 0.037924, -0.027554},{
      0.479906, 0.037486, -0.027554},{0.481272, 0.033282, -0.028615}}],
    Polygon[{{0.482673, 0.037924, -0.027554},{0.482673, 0.042124, -0.025814},{
      0.478608, 0.041481, -0.025814},{0.479906, 0.037486, -0.027554}}],
    Polygon[{{0.482673, 0.042124, -0.025814},{0.482673, 0.046001, -0.023438},{
      0.477411, 0.045167, -0.023438},{0.478608, 0.041481, -0.025814}}],
    Polygon[{{0.482673, 0.046001, -0.023438},{0.482673, 0.049457, -0.020486},{
      0.476342, 0.048455, -0.020486},{0.477411, 0.045167, -0.023438}}],
    Polygon[{{0.482673, 0.049457, -0.020486},{0.482673, 0.052410, -0.017029},{
      0.475430, 0.051263, -0.017029},{0.476342, 0.048455, -0.020486}}],
    Polygon[{{0.482673, 0.052410, -0.017029},{0.482673, 0.054785, -0.013153},{
      0.474696, 0.053522, -0.013153},{0.475430, 0.051263, -0.017029}}],
    Polygon[{{0.482673, 0.054785, -0.013153},{0.482673, 0.056525, -0.008953},{
      0.474158, 0.055177, -0.008953},{0.474696, 0.053522, -0.013153}}],
    Polygon[{{0.482673, 0.056525, -0.008953},{0.482673, 0.057586, -0.004532},{
      0.473830, 0.056186, -0.004532},{0.474158, 0.055177, -0.008953}}],
    Polygon[{{0.482673, 0.057586, -0.004532},{0.482673, 0.057943, 0.000000},{
      0.473720, 0.056525, 0.000000},{0.473830, 0.056186, -0.004532}}],
    Polygon[{{0.482673, 0.057943, 0.000000},{0.482673, 0.057586, 0.004532},{
      0.473830, 0.056186, 0.004532},{0.473720, 0.056525, 0.000000}}],
    Polygon[{{0.482673, 0.057586, 0.004532},{0.482673, 0.056525, 0.008953},{
      0.474158, 0.055177, 0.008953},{0.473830, 0.056186, 0.004532}}],
    Polygon[{{0.482673, 0.056525, 0.008953},{0.482673, 0.054785, 0.013153},{
      0.474696, 0.053522, 0.013153},{0.474158, 0.055177, 0.008953}}],
    Polygon[{{0.482673, 0.054785, 0.013153},{0.482673, 0.052410, 0.017029},{
      0.475430, 0.051263, 0.017029},{0.474696, 0.053522, 0.013153}}],
    Polygon[{{0.482673, 0.052410, 0.017029},{0.482673, 0.049457, 0.020486},{
      0.476342, 0.048455, 0.020486},{0.475430, 0.051263, 0.017029}}],
    Polygon[{{0.482673, 0.049457, 0.020486},{0.482673, 0.046001, 0.023438},{
      0.477411, 0.045167, 0.023438},{0.476342, 0.048455, 0.020486}}],
    Polygon[{{0.482673, 0.046001, 0.023438},{0.482673, 0.042124, 0.025814},{
      0.478608, 0.041481, 0.025814},{0.477411, 0.045167, 0.023438}}],
    Polygon[{{0.482673, 0.042124, 0.025814},{0.482673, 0.037924, 0.027554},{
      0.479906, 0.037486, 0.027554},{0.478608, 0.041481, 0.025814}}],
    Polygon[{{0.482673, 0.037924, 0.027554},{0.482673, 0.033504, 0.028615},{
      0.481272, 0.033282, 0.028615},{0.479906, 0.037486, 0.027554}}],
    Polygon[{{0.481272, 0.033282, -0.028615},{0.479906, 0.037486, -0.027554},{
      0.477411, 0.036214, -0.027554},{0.480009, 0.032638, -0.028615}}],
    Polygon[{{0.479906, 0.037486, -0.027554},{0.478608, 0.041481, -0.025814},{
      0.474942, 0.039612, -0.025814},{0.477411, 0.036214, -0.027554}}],
    Polygon[{{0.478608, 0.041481, -0.025814},{0.477411, 0.045167, -0.023438},{
      0.472663, 0.042748, -0.023438},{0.474942, 0.039612, -0.025814}}],
    Polygon[{{0.477411, 0.045167, -0.023438},{0.476342, 0.048455, -0.020486},{
      0.470631, 0.045545, -0.020486},{0.472663, 0.042748, -0.023438}}],
    Polygon[{{0.476342, 0.048455, -0.020486},{0.475430, 0.051263, -0.017029},{
      0.468896, 0.047934, -0.017029},{0.470631, 0.045545, -0.020486}}],
    Polygon[{{0.475430, 0.051263, -0.017029},{0.474696, 0.053522, -0.013153},{
      0.467500, 0.049855, -0.013153},{0.468896, 0.047934, -0.017029}}],
    Polygon[{{0.474696, 0.053522, -0.013153},{0.474158, 0.055177, -0.008953},{
      0.466477, 0.051263, -0.008953},{0.467500, 0.049855, -0.013153}}],
    Polygon[{{0.474158, 0.055177, -0.008953},{0.473830, 0.056186, -0.004532},{
      0.465853, 0.052121, -0.004532},{0.466477, 0.051263, -0.008953}}],
    Polygon[{{0.473830, 0.056186, -0.004532},{0.473720, 0.056525, 0.000000},{
      0.465644, 0.052410, 0.000000},{0.465853, 0.052121, -0.004532}}],
    Polygon[{{0.473720, 0.056525, 0.000000},{0.473830, 0.056186, 0.004532},{
      0.465853, 0.052121, 0.004532},{0.465644, 0.052410, 0.000000}}],
    Polygon[{{0.473830, 0.056186, 0.004532},{0.474158, 0.055177, 0.008953},{
      0.466477, 0.051263, 0.008953},{0.465853, 0.052121, 0.004532}}],
    Polygon[{{0.474158, 0.055177, 0.008953},{0.474696, 0.053522, 0.013153},{
      0.467500, 0.049855, 0.013153},{0.466477, 0.051263, 0.008953}}],
    Polygon[{{0.474696, 0.053522, 0.013153},{0.475430, 0.051263, 0.017029},{
      0.468896, 0.047934, 0.017029},{0.467500, 0.049855, 0.013153}}],
    Polygon[{{0.475430, 0.051263, 0.017029},{0.476342, 0.048455, 0.020486},{
      0.470631, 0.045545, 0.020486},{0.468896, 0.047934, 0.017029}}],
    Polygon[{{0.476342, 0.048455, 0.020486},{0.477411, 0.045167, 0.023438},{
      0.472663, 0.042748, 0.023438},{0.470631, 0.045545, 0.020486}}],
    Polygon[{{0.477411, 0.045167, 0.023438},{0.478608, 0.041481, 0.025814},{
      0.474942, 0.039612, 0.025814},{0.472663, 0.042748, 0.023438}}],
    Polygon[{{0.478608, 0.041481, 0.025814},{0.479906, 0.037486, 0.027554},{
      0.477411, 0.036214, 0.027554},{0.474942, 0.039612, 0.025814}}],
    Polygon[{{0.479906, 0.037486, 0.027554},{0.481272, 0.033282, 0.028615},{
      0.480009, 0.032638, 0.028615},{0.477411, 0.036214, 0.027554}}],
    Polygon[{{0.480009, 0.032638, -0.028615},{0.477411, 0.036214, -0.027554},{
      0.475430, 0.034234, -0.027554},{0.479006, 0.031635, -0.028615}}],
    Polygon[{{0.477411, 0.036214, -0.027554},{0.474942, 0.039612, -0.025814},{
      0.472032, 0.036703, -0.025814},{0.475430, 0.034234, -0.027554}}],
    Polygon[{{0.474942, 0.039612, -0.025814},{0.472663, 0.042748, -0.023438},{
      0.468896, 0.038981, -0.023438},{0.472032, 0.036703, -0.025814}}],
    Polygon[{{0.472663, 0.042748, -0.023438},{0.470631, 0.045545, -0.020486},{
      0.466099, 0.041013, -0.020486},{0.468896, 0.038981, -0.023438}}],
    Polygon[{{0.470631, 0.045545, -0.020486},{0.468896, 0.047934, -0.017029},{
      0.463711, 0.042748, -0.017029},{0.466099, 0.041013, -0.020486}}],
    Polygon[{{0.468896, 0.047934, -0.017029},{0.467500, 0.049855, -0.013153},{
      0.461789, 0.044144, -0.013153},{0.463711, 0.042748, -0.017029}}],
    Polygon[{{0.467500, 0.049855, -0.013153},{0.466477, 0.051263, -0.008953},{
      0.460382, 0.045167, -0.008953},{0.461789, 0.044144, -0.013153}}],
    Polygon[{{0.466477, 0.051263, -0.008953},{0.465853, 0.052121, -0.004532},{
      0.459523, 0.045791, -0.004532},{0.460382, 0.045167, -0.008953}}],
    Polygon[{{0.465853, 0.052121, -0.004532},{0.465644, 0.052410, 0.000000},{
      0.459234, 0.046001, 0.000000},{0.459523, 0.045791, -0.004532}}],
    Polygon[{{0.465644, 0.052410, 0.000000},{0.465853, 0.052121, 0.004532},{
      0.459523, 0.045791, 0.004532},{0.459234, 0.046001, 0.000000}}],
    Polygon[{{0.465853, 0.052121, 0.004532},{0.466477, 0.051263, 0.008953},{
      0.460382, 0.045167, 0.008953},{0.459523, 0.045791, 0.004532}}],
    Polygon[{{0.466477, 0.051263, 0.008953},{0.467500, 0.049855, 0.013153},{
      0.461789, 0.044144, 0.013153},{0.460382, 0.045167, 0.008953}}],
    Polygon[{{0.467500, 0.049855, 0.013153},{0.468896, 0.047934, 0.017029},{
      0.463711, 0.042748, 0.017029},{0.461789, 0.044144, 0.013153}}],
    Polygon[{{0.468896, 0.047934, 0.017029},{0.470631, 0.045545, 0.020486},{
      0.466099, 0.041013, 0.020486},{0.463711, 0.042748, 0.017029}}],
    Polygon[{{0.470631, 0.045545, 0.020486},{0.472663, 0.042748, 0.023438},{
      0.468896, 0.038981, 0.023438},{0.466099, 0.041013, 0.020486}}],
    Polygon[{{0.472663, 0.042748, 0.023438},{0.474942, 0.039612, 0.025814},{
      0.472032, 0.036703, 0.025814},{0.468896, 0.038981, 0.023438}}],
    Polygon[{{0.474942, 0.039612, 0.025814},{0.477411, 0.036214, 0.027554},{
      0.475430, 0.034234, 0.027554},{0.472032, 0.036703, 0.025814}}],
    Polygon[{{0.477411, 0.036214, 0.027554},{0.480009, 0.032638, 0.028615},{
      0.479006, 0.031635, 0.028615},{0.475430, 0.034234, 0.027554}}],
    Polygon[{{0.479006, 0.031635, -0.028615},{0.475430, 0.034234, -0.027554},{
      0.474158, 0.031738, -0.027554},{0.478363, 0.030372, -0.028615}}],
    Polygon[{{0.475430, 0.034234, -0.027554},{0.472032, 0.036703, -0.025814},{
      0.470164, 0.033036, -0.025814},{0.474158, 0.031738, -0.027554}}],
    Polygon[{{0.472032, 0.036703, -0.025814},{0.468896, 0.038981, -0.023438},{
      0.466477, 0.034234, -0.023438},{0.470164, 0.033036, -0.025814}}],
    Polygon[{{0.468896, 0.038981, -0.023438},{0.466099, 0.041013, -0.020486},{
      0.463190, 0.035302, -0.020486},{0.466477, 0.034234, -0.023438}}],
    Polygon[{{0.466099, 0.041013, -0.020486},{0.463711, 0.042748, -0.017029},{
      0.460382, 0.036214, -0.017029},{0.463190, 0.035302, -0.020486}}],
    Polygon[{{0.463711, 0.042748, -0.017029},{0.461789, 0.044144, -0.013153},{
      0.458122, 0.036948, -0.013153},{0.460382, 0.036214, -0.017029}}],
    Polygon[{{0.461789, 0.044144, -0.013153},{0.460382, 0.045167, -0.008953},{
      0.456468, 0.037486, -0.008953},{0.458122, 0.036948, -0.013153}}],
    Polygon[{{0.460382, 0.045167, -0.008953},{0.459523, 0.045791, -0.004532},{
      0.455458, 0.037814, -0.004532},{0.456468, 0.037486, -0.008953}}],
    Polygon[{{0.459523, 0.045791, -0.004532},{0.459234, 0.046001, 0.000000},{
      0.455119, 0.037924, 0.000000},{0.455458, 0.037814, -0.004532}}],
    Polygon[{{0.459234, 0.046001, 0.000000},{0.459523, 0.045791, 0.004532},{
      0.455458, 0.037814, 0.004532},{0.455119, 0.037924, 0.000000}}],
    Polygon[{{0.459523, 0.045791, 0.004532},{0.460382, 0.045167, 0.008953},{
      0.456468, 0.037486, 0.008953},{0.455458, 0.037814, 0.004532}}],
    Polygon[{{0.460382, 0.045167, 0.008953},{0.461789, 0.044144, 0.013153},{
      0.458122, 0.036948, 0.013153},{0.456468, 0.037486, 0.008953}}],
    Polygon[{{0.461789, 0.044144, 0.013153},{0.463711, 0.042748, 0.017029},{
      0.460382, 0.036214, 0.017029},{0.458122, 0.036948, 0.013153}}],
    Polygon[{{0.463711, 0.042748, 0.017029},{0.466099, 0.041013, 0.020486},{
      0.463190, 0.035302, 0.020486},{0.460382, 0.036214, 0.017029}}],
    Polygon[{{0.466099, 0.041013, 0.020486},{0.468896, 0.038981, 0.023438},{
      0.466477, 0.034234, 0.023438},{0.463190, 0.035302, 0.020486}}],
    Polygon[{{0.468896, 0.038981, 0.023438},{0.472032, 0.036703, 0.025814},{
      0.470164, 0.033036, 0.025814},{0.466477, 0.034234, 0.023438}}],
    Polygon[{{0.472032, 0.036703, 0.025814},{0.475430, 0.034234, 0.027554},{
      0.474158, 0.031738, 0.027554},{0.470164, 0.033036, 0.025814}}],
    Polygon[{{0.475430, 0.034234, 0.027554},{0.479006, 0.031635, 0.028615},{
      0.478363, 0.030372, 0.028615},{0.474158, 0.031738, 0.027554}}],
    Polygon[{{0.478363, 0.030372, -0.028615},{0.474158, 0.031738, -0.027554},{
      0.473720, 0.028972, -0.027554},{0.478141, 0.028972, -0.028615}}],
    Polygon[{{0.474158, 0.031738, -0.027554},{0.470164, 0.033036, -0.025814},{
      0.469520, 0.028972, -0.025814},{0.473720, 0.028972, -0.027554}}],
    Polygon[{{0.470164, 0.033036, -0.025814},{0.466477, 0.034234, -0.023438},{
      0.465644, 0.028972, -0.023438},{0.469520, 0.028972, -0.025814}}],
    Polygon[{{0.466477, 0.034234, -0.023438},{0.463190, 0.035302, -0.020486},{
      0.462187, 0.028972, -0.020486},{0.465644, 0.028972, -0.023438}}],
    Polygon[{{0.463190, 0.035302, -0.020486},{0.460382, 0.036214, -0.017029},{
      0.459234, 0.028972, -0.017029},{0.462187, 0.028972, -0.020486}}],
    Polygon[{{0.460382, 0.036214, -0.017029},{0.458122, 0.036948, -0.013153},{
      0.456859, 0.028972, -0.013153},{0.459234, 0.028972, -0.017029}}],
    Polygon[{{0.458122, 0.036948, -0.013153},{0.456468, 0.037486, -0.008953},{
      0.455119, 0.028972, -0.008953},{0.456859, 0.028972, -0.013153}}],
    Polygon[{{0.456468, 0.037486, -0.008953},{0.455458, 0.037814, -0.004532},{
      0.454058, 0.028972, -0.004532},{0.455119, 0.028972, -0.008953}}],
    Polygon[{{0.455458, 0.037814, -0.004532},{0.455119, 0.037924, 0.000000},{
      0.453701, 0.028972, 0.000000},{0.454058, 0.028972, -0.004532}}],
    Polygon[{{0.455119, 0.037924, 0.000000},{0.455458, 0.037814, 0.004532},{
      0.454058, 0.028972, 0.004532},{0.453701, 0.028972, 0.000000}}],
    Polygon[{{0.455458, 0.037814, 0.004532},{0.456468, 0.037486, 0.008953},{
      0.455119, 0.028972, 0.008953},{0.454058, 0.028972, 0.004532}}],
    Polygon[{{0.456468, 0.037486, 0.008953},{0.458122, 0.036948, 0.013153},{
      0.456859, 0.028972, 0.013153},{0.455119, 0.028972, 0.008953}}],
    Polygon[{{0.458122, 0.036948, 0.013153},{0.460382, 0.036214, 0.017029},{
      0.459234, 0.028972, 0.017029},{0.456859, 0.028972, 0.013153}}],
    Polygon[{{0.460382, 0.036214, 0.017029},{0.463190, 0.035302, 0.020486},{
      0.462187, 0.028972, 0.020486},{0.459234, 0.028972, 0.017029}}],
    Polygon[{{0.463190, 0.035302, 0.020486},{0.466477, 0.034234, 0.023438},{
      0.465644, 0.028972, 0.023438},{0.462187, 0.028972, 0.020486}}],
    Polygon[{{0.466477, 0.034234, 0.023438},{0.470164, 0.033036, 0.025814},{
      0.469520, 0.028972, 0.025814},{0.465644, 0.028972, 0.023438}}],
    Polygon[{{0.470164, 0.033036, 0.025814},{0.474158, 0.031738, 0.027554},{
      0.473720, 0.028972, 0.027554},{0.469520, 0.028972, 0.025814}}],
    Polygon[{{0.474158, 0.031738, 0.027554},{0.478363, 0.030372, 0.028615},{
      0.478141, 0.028972, 0.028615},{0.473720, 0.028972, 0.027554}}],
    Polygon[{{0.478141, 0.028972, -0.028615},{0.473720, 0.028972, -0.027554},{
      0.474158, 0.026205, -0.027554},{0.478363, 0.027571, -0.028615}}],
    Polygon[{{0.473720, 0.028972, -0.027554},{0.469520, 0.028972, -0.025814},{
      0.470164, 0.024907, -0.025814},{0.474158, 0.026205, -0.027554}}],
    Polygon[{{0.469520, 0.028972, -0.025814},{0.465644, 0.028972, -0.023438},{
      0.466477, 0.023709, -0.023438},{0.470164, 0.024907, -0.025814}}],
    Polygon[{{0.465644, 0.028972, -0.023438},{0.462187, 0.028972, -0.020486},{
      0.463190, 0.022641, -0.020486},{0.466477, 0.023709, -0.023438}}],
    Polygon[{{0.462187, 0.028972, -0.020486},{0.459234, 0.028972, -0.017029},{
      0.460382, 0.021729, -0.017029},{0.463190, 0.022641, -0.020486}}],
    Polygon[{{0.459234, 0.028972, -0.017029},{0.456859, 0.028972, -0.013153},{
      0.458122, 0.020995, -0.013153},{0.460382, 0.021729, -0.017029}}],
    Polygon[{{0.456859, 0.028972, -0.013153},{0.455119, 0.028972, -0.008953},{
      0.456468, 0.020457, -0.008953},{0.458122, 0.020995, -0.013153}}],
    Polygon[{{0.455119, 0.028972, -0.008953},{0.454058, 0.028972, -0.004532},{
      0.455458, 0.020129, -0.004532},{0.456468, 0.020457, -0.008953}}],
    Polygon[{{0.454058, 0.028972, -0.004532},{0.453701, 0.028972, 0.000000},{
      0.455119, 0.020019, 0.000000},{0.455458, 0.020129, -0.004532}}],
    Polygon[{{0.453701, 0.028972, 0.000000},{0.454058, 0.028972, 0.004532},{
      0.455458, 0.020129, 0.004532},{0.455119, 0.020019, 0.000000}}],
    Polygon[{{0.454058, 0.028972, 0.004532},{0.455119, 0.028972, 0.008953},{
      0.456468, 0.020457, 0.008953},{0.455458, 0.020129, 0.004532}}],
    Polygon[{{0.455119, 0.028972, 0.008953},{0.456859, 0.028972, 0.013153},{
      0.458122, 0.020995, 0.013153},{0.456468, 0.020457, 0.008953}}],
    Polygon[{{0.456859, 0.028972, 0.013153},{0.459234, 0.028972, 0.017029},{
      0.460382, 0.021729, 0.017029},{0.458122, 0.020995, 0.013153}}],
    Polygon[{{0.459234, 0.028972, 0.017029},{0.462187, 0.028972, 0.020486},{
      0.463190, 0.022641, 0.020486},{0.460382, 0.021729, 0.017029}}],
    Polygon[{{0.462187, 0.028972, 0.020486},{0.465644, 0.028972, 0.023438},{
      0.466477, 0.023709, 0.023438},{0.463190, 0.022641, 0.020486}}],
    Polygon[{{0.465644, 0.028972, 0.023438},{0.469520, 0.028972, 0.025814},{
      0.470164, 0.024907, 0.025814},{0.466477, 0.023709, 0.023438}}],
    Polygon[{{0.469520, 0.028972, 0.025814},{0.473720, 0.028972, 0.027554},{
      0.474158, 0.026205, 0.027554},{0.470164, 0.024907, 0.025814}}],
    Polygon[{{0.473720, 0.028972, 0.027554},{0.478141, 0.028972, 0.028615},{
      0.478363, 0.027571, 0.028615},{0.474158, 0.026205, 0.027554}}],
    Polygon[{{0.478363, 0.027571, -0.028615},{0.474158, 0.026205, -0.027554},{
      0.475430, 0.023709, -0.027554},{0.479006, 0.026308, -0.028615}}],
    Polygon[{{0.474158, 0.026205, -0.027554},{0.470164, 0.024907, -0.025814},{
      0.472032, 0.021240, -0.025814},{0.475430, 0.023709, -0.027554}}],
    Polygon[{{0.470164, 0.024907, -0.025814},{0.466477, 0.023709, -0.023438},{
      0.468896, 0.018962, -0.023438},{0.472032, 0.021240, -0.025814}}],
    Polygon[{{0.466477, 0.023709, -0.023438},{0.463190, 0.022641, -0.020486},{
      0.466099, 0.016930, -0.020486},{0.468896, 0.018962, -0.023438}}],
    Polygon[{{0.463190, 0.022641, -0.020486},{0.460382, 0.021729, -0.017029},{
      0.463711, 0.015195, -0.017029},{0.466099, 0.016930, -0.020486}}],
    Polygon[{{0.460382, 0.021729, -0.017029},{0.458122, 0.020995, -0.013153},{
      0.461789, 0.013799, -0.013153},{0.463711, 0.015195, -0.017029}}],
    Polygon[{{0.458122, 0.020995, -0.013153},{0.456468, 0.020457, -0.008953},{
      0.460382, 0.012776, -0.008953},{0.461789, 0.013799, -0.013153}}],
    Polygon[{{0.456468, 0.020457, -0.008953},{0.455458, 0.020129, -0.004532},{
      0.459523, 0.012152, -0.004532},{0.460382, 0.012776, -0.008953}}],
    Polygon[{{0.455458, 0.020129, -0.004532},{0.455119, 0.020019, 0.000000},{
      0.459234, 0.011942, 0.000000},{0.459523, 0.012152, -0.004532}}],
    Polygon[{{0.455119, 0.020019, 0.000000},{0.455458, 0.020129, 0.004532},{
      0.459523, 0.012152, 0.004532},{0.459234, 0.011942, 0.000000}}],
    Polygon[{{0.455458, 0.020129, 0.004532},{0.456468, 0.020457, 0.008953},{
      0.460382, 0.012776, 0.008953},{0.459523, 0.012152, 0.004532}}],
    Polygon[{{0.456468, 0.020457, 0.008953},{0.458122, 0.020995, 0.013153},{
      0.461789, 0.013799, 0.013153},{0.460382, 0.012776, 0.008953}}],
    Polygon[{{0.458122, 0.020995, 0.013153},{0.460382, 0.021729, 0.017029},{
      0.463711, 0.015195, 0.017029},{0.461789, 0.013799, 0.013153}}],
    Polygon[{{0.460382, 0.021729, 0.017029},{0.463190, 0.022641, 0.020486},{
      0.466099, 0.016930, 0.020486},{0.463711, 0.015195, 0.017029}}],
    Polygon[{{0.463190, 0.022641, 0.020486},{0.466477, 0.023709, 0.023438},{
      0.468896, 0.018962, 0.023438},{0.466099, 0.016930, 0.020486}}],
    Polygon[{{0.466477, 0.023709, 0.023438},{0.470164, 0.024907, 0.025814},{
      0.472032, 0.021240, 0.025814},{0.468896, 0.018962, 0.023438}}],
    Polygon[{{0.470164, 0.024907, 0.025814},{0.474158, 0.026205, 0.027554},{
      0.475430, 0.023709, 0.027554},{0.472032, 0.021240, 0.025814}}],
    Polygon[{{0.474158, 0.026205, 0.027554},{0.478363, 0.027571, 0.028615},{
      0.479006, 0.026308, 0.028615},{0.475430, 0.023709, 0.027554}}],
    Polygon[{{0.479006, 0.026308, -0.028615},{0.475430, 0.023709, -0.027554},{
      0.477411, 0.021729, -0.027554},{0.480009, 0.025305, -0.028615}}],
    Polygon[{{0.475430, 0.023709, -0.027554},{0.472032, 0.021240, -0.025814},{
      0.474942, 0.018331, -0.025814},{0.477411, 0.021729, -0.027554}}],
    Polygon[{{0.472032, 0.021240, -0.025814},{0.468896, 0.018962, -0.023438},{
      0.472663, 0.015195, -0.023438},{0.474942, 0.018331, -0.025814}}],
    Polygon[{{0.468896, 0.018962, -0.023438},{0.466099, 0.016930, -0.020486},{
      0.470631, 0.012398, -0.020486},{0.472663, 0.015195, -0.023438}}],
    Polygon[{{0.466099, 0.016930, -0.020486},{0.463711, 0.015195, -0.017029},{
      0.468896, 0.010009, -0.017029},{0.470631, 0.012398, -0.020486}}],
    Polygon[{{0.463711, 0.015195, -0.017029},{0.461789, 0.013799, -0.013153},{
      0.467500, 0.008088, -0.013153},{0.468896, 0.010009, -0.017029}}],
    Polygon[{{0.461789, 0.013799, -0.013153},{0.460382, 0.012776, -0.008953},{
      0.466477, 0.006680, -0.008953},{0.467500, 0.008088, -0.013153}}],
    Polygon[{{0.460382, 0.012776, -0.008953},{0.459523, 0.012152, -0.004532},{
      0.465853, 0.005822, -0.004532},{0.466477, 0.006680, -0.008953}}],
    Polygon[{{0.459523, 0.012152, -0.004532},{0.459234, 0.011942, 0.000000},{
      0.465644, 0.005533, 0.000000},{0.465853, 0.005822, -0.004532}}],
    Polygon[{{0.459234, 0.011942, 0.000000},{0.459523, 0.012152, 0.004532},{
      0.465853, 0.005822, 0.004532},{0.465644, 0.005533, 0.000000}}],
    Polygon[{{0.459523, 0.012152, 0.004532},{0.460382, 0.012776, 0.008953},{
      0.466477, 0.006680, 0.008953},{0.465853, 0.005822, 0.004532}}],
    Polygon[{{0.460382, 0.012776, 0.008953},{0.461789, 0.013799, 0.013153},{
      0.467500, 0.008088, 0.013153},{0.466477, 0.006680, 0.008953}}],
    Polygon[{{0.461789, 0.013799, 0.013153},{0.463711, 0.015195, 0.017029},{
      0.468896, 0.010009, 0.017029},{0.467500, 0.008088, 0.013153}}],
    Polygon[{{0.463711, 0.015195, 0.017029},{0.466099, 0.016930, 0.020486},{
      0.470631, 0.012398, 0.020486},{0.468896, 0.010009, 0.017029}}],
    Polygon[{{0.466099, 0.016930, 0.020486},{0.468896, 0.018962, 0.023438},{
      0.472663, 0.015195, 0.023438},{0.470631, 0.012398, 0.020486}}],
    Polygon[{{0.468896, 0.018962, 0.023438},{0.472032, 0.021240, 0.025814},{
      0.474942, 0.018331, 0.025814},{0.472663, 0.015195, 0.023438}}],
    Polygon[{{0.472032, 0.021240, 0.025814},{0.475430, 0.023709, 0.027554},{
      0.477411, 0.021729, 0.027554},{0.474942, 0.018331, 0.025814}}],
    Polygon[{{0.475430, 0.023709, 0.027554},{0.479006, 0.026308, 0.028615},{
      0.480009, 0.025305, 0.028615},{0.477411, 0.021729, 0.027554}}],
    Polygon[{{0.480009, 0.025305, -0.028615},{0.477411, 0.021729, -0.027554},{
      0.479906, 0.020457, -0.027554},{0.481272, 0.024661, -0.028615}}],
    Polygon[{{0.477411, 0.021729, -0.027554},{0.474942, 0.018331, -0.025814},{
      0.478608, 0.016462, -0.025814},{0.479906, 0.020457, -0.027554}}],
    Polygon[{{0.474942, 0.018331, -0.025814},{0.472663, 0.015195, -0.023438},{
      0.477411, 0.012776, -0.023438},{0.478608, 0.016462, -0.025814}}],
    Polygon[{{0.472663, 0.015195, -0.023438},{0.470631, 0.012398, -0.020486},{
      0.476342, 0.009488, -0.020486},{0.477411, 0.012776, -0.023438}}],
    Polygon[{{0.470631, 0.012398, -0.020486},{0.468896, 0.010009, -0.017029},{
      0.475430, 0.006680, -0.017029},{0.476342, 0.009488, -0.020486}}],
    Polygon[{{0.468896, 0.010009, -0.017029},{0.467500, 0.008088, -0.013153},{
      0.474696, 0.004421, -0.013153},{0.475430, 0.006680, -0.017029}}],
    Polygon[{{0.467500, 0.008088, -0.013153},{0.466477, 0.006680, -0.008953},{
      0.474158, 0.002767, -0.008953},{0.474696, 0.004421, -0.013153}}],
    Polygon[{{0.466477, 0.006680, -0.008953},{0.465853, 0.005822, -0.004532},{
      0.473830, 0.001757, -0.004532},{0.474158, 0.002767, -0.008953}}],
    Polygon[{{0.465853, 0.005822, -0.004532},{0.465644, 0.005533, 0.000000},{
      0.473720, 0.001418, 0.000000},{0.473830, 0.001757, -0.004532}}],
    Polygon[{{0.465644, 0.005533, 0.000000},{0.465853, 0.005822, 0.004532},{
      0.473830, 0.001757, 0.004532},{0.473720, 0.001418, 0.000000}}],
    Polygon[{{0.465853, 0.005822, 0.004532},{0.466477, 0.006680, 0.008953},{
      0.474158, 0.002767, 0.008953},{0.473830, 0.001757, 0.004532}}],
    Polygon[{{0.466477, 0.006680, 0.008953},{0.467500, 0.008088, 0.013153},{
      0.474696, 0.004421, 0.013153},{0.474158, 0.002767, 0.008953}}],
    Polygon[{{0.467500, 0.008088, 0.013153},{0.468896, 0.010009, 0.017029},{
      0.475430, 0.006680, 0.017029},{0.474696, 0.004421, 0.013153}}],
    Polygon[{{0.468896, 0.010009, 0.017029},{0.470631, 0.012398, 0.020486},{
      0.476342, 0.009488, 0.020486},{0.475430, 0.006680, 0.017029}}],
    Polygon[{{0.470631, 0.012398, 0.020486},{0.472663, 0.015195, 0.023438},{
      0.477411, 0.012776, 0.023438},{0.476342, 0.009488, 0.020486}}],
    Polygon[{{0.472663, 0.015195, 0.023438},{0.474942, 0.018331, 0.025814},{
      0.478608, 0.016462, 0.025814},{0.477411, 0.012776, 0.023438}}],
    Polygon[{{0.474942, 0.018331, 0.025814},{0.477411, 0.021729, 0.027554},{
      0.479906, 0.020457, 0.027554},{0.478608, 0.016462, 0.025814}}],
    Polygon[{{0.477411, 0.021729, 0.027554},{0.480009, 0.025305, 0.028615},{
      0.481272, 0.024661, 0.028615},{0.479906, 0.020457, 0.027554}}],
    Polygon[{{0.481272, 0.024661, -0.028615},{0.479906, 0.020457, -0.027554},{
      0.482673, 0.020019, -0.027554},{0.482673, 0.024439, -0.028615}}],
    Polygon[{{0.479906, 0.020457, -0.027554},{0.478608, 0.016462, -0.025814},{
      0.482673, 0.015819, -0.025814},{0.482673, 0.020019, -0.027554}}],
    Polygon[{{0.478608, 0.016462, -0.025814},{0.477411, 0.012776, -0.023438},{
      0.482673, 0.011942, -0.023438},{0.482673, 0.015819, -0.025814}}],
    Polygon[{{0.477411, 0.012776, -0.023438},{0.476342, 0.009488, -0.020486},{
      0.482673, 0.008486, -0.020486},{0.482673, 0.011942, -0.023438}}],
    Polygon[{{0.476342, 0.009488, -0.020486},{0.475430, 0.006680, -0.017029},{
      0.482673, 0.005533, -0.017029},{0.482673, 0.008486, -0.020486}}],
    Polygon[{{0.475430, 0.006680, -0.017029},{0.474696, 0.004421, -0.013153},{
      0.482673, 0.003158, -0.013153},{0.482673, 0.005533, -0.017029}}],
    Polygon[{{0.474696, 0.004421, -0.013153},{0.474158, 0.002767, -0.008953},{
      0.482673, 0.001418, -0.008953},{0.482673, 0.003158, -0.013153}}],
    Polygon[{{0.474158, 0.002767, -0.008953},{0.473830, 0.001757, -0.004532},{
      0.482673, 0.000357, -0.004532},{0.482673, 0.001418, -0.008953}}],
    Polygon[{{0.473830, 0.001757, -0.004532},{0.473720, 0.001418, 0.000000},{
      0.482673, 0.000000, 0.000000},{0.482673, 0.000357, -0.004532}}],
    Polygon[{{0.473720, 0.001418, 0.000000},{0.473830, 0.001757, 0.004532},{
      0.482673, 0.000357, 0.004532},{0.482673, 0.000000, 0.000000}}],
    Polygon[{{0.473830, 0.001757, 0.004532},{0.474158, 0.002767, 0.008953},{
      0.482673, 0.001418, 0.008953},{0.482673, 0.000357, 0.004532}}],
    Polygon[{{0.474158, 0.002767, 0.008953},{0.474696, 0.004421, 0.013153},{
      0.482673, 0.003158, 0.013153},{0.482673, 0.001418, 0.008953}}],
    Polygon[{{0.474696, 0.004421, 0.013153},{0.475430, 0.006680, 0.017029},{
      0.482673, 0.005533, 0.017029},{0.482673, 0.003158, 0.013153}}],
    Polygon[{{0.475430, 0.006680, 0.017029},{0.476342, 0.009488, 0.020486},{
      0.482673, 0.008486, 0.020486},{0.482673, 0.005533, 0.017029}}],
    Polygon[{{0.476342, 0.009488, 0.020486},{0.477411, 0.012776, 0.023438},{
      0.482673, 0.011942, 0.023438},{0.482673, 0.008486, 0.020486}}],
    Polygon[{{0.477411, 0.012776, 0.023438},{0.478608, 0.016462, 0.025814},{
      0.482673, 0.015819, 0.025814},{0.482673, 0.011942, 0.023438}}],
    Polygon[{{0.478608, 0.016462, 0.025814},{0.479906, 0.020457, 0.027554},{
      0.482673, 0.020019, 0.027554},{0.482673, 0.015819, 0.025814}}],
    Polygon[{{0.479906, 0.020457, 0.027554},{0.481272, 0.024661, 0.028615},{
      0.482673, 0.024439, 0.028615},{0.482673, 0.020019, 0.027554}}],
    Polygon[{{0.482673, 0.024439, -0.028615},{0.482673, 0.020019, -0.027554},{
      0.485439, 0.020457, -0.027554},{0.484073, 0.024661, -0.028615}}],
    Polygon[{{0.482673, 0.020019, -0.027554},{0.482673, 0.015819, -0.025814},{
      0.486737, 0.016462, -0.025814},{0.485439, 0.020457, -0.027554}}],
    Polygon[{{0.482673, 0.015819, -0.025814},{0.482673, 0.011942, -0.023438},{
      0.487935, 0.012776, -0.023438},{0.486737, 0.016462, -0.025814}}],
    Polygon[{{0.482673, 0.011942, -0.023438},{0.482673, 0.008486, -0.020486},{
      0.489003, 0.009488, -0.020486},{0.487935, 0.012776, -0.023438}}],
    Polygon[{{0.482673, 0.008486, -0.020486},{0.482673, 0.005533, -0.017029},{
      0.489916, 0.006680, -0.017029},{0.489003, 0.009488, -0.020486}}],
    Polygon[{{0.482673, 0.005533, -0.017029},{0.482673, 0.003158, -0.013153},{
      0.490650, 0.004421, -0.013153},{0.489916, 0.006680, -0.017029}}],
    Polygon[{{0.482673, 0.003158, -0.013153},{0.482673, 0.001418, -0.008953},{
      0.491187, 0.002767, -0.008953},{0.490650, 0.004421, -0.013153}}],
    Polygon[{{0.482673, 0.001418, -0.008953},{0.482673, 0.000357, -0.004532},{
      0.491515, 0.001757, -0.004532},{0.491187, 0.002767, -0.008953}}],
    Polygon[{{0.482673, 0.000357, -0.004532},{0.482673, 0.000000, 0.000000},{
      0.491626, 0.001418, 0.000000},{0.491515, 0.001757, -0.004532}}],
    Polygon[{{0.482673, 0.000000, 0.000000},{0.482673, 0.000357, 0.004532},{
      0.491515, 0.001757, 0.004532},{0.491626, 0.001418, 0.000000}}],
    Polygon[{{0.482673, 0.000357, 0.004532},{0.482673, 0.001418, 0.008953},{
      0.491187, 0.002767, 0.008953},{0.491515, 0.001757, 0.004532}}],
    Polygon[{{0.482673, 0.001418, 0.008953},{0.482673, 0.003158, 0.013153},{
      0.490650, 0.004421, 0.013153},{0.491187, 0.002767, 0.008953}}],
    Polygon[{{0.482673, 0.003158, 0.013153},{0.482673, 0.005533, 0.017029},{
      0.489916, 0.006680, 0.017029},{0.490650, 0.004421, 0.013153}}],
    Polygon[{{0.482673, 0.005533, 0.017029},{0.482673, 0.008486, 0.020486},{
      0.489003, 0.009488, 0.020486},{0.489916, 0.006680, 0.017029}}],
    Polygon[{{0.482673, 0.008486, 0.020486},{0.482673, 0.011942, 0.023438},{
      0.487935, 0.012776, 0.023438},{0.489003, 0.009488, 0.020486}}],
    Polygon[{{0.482673, 0.011942, 0.023438},{0.482673, 0.015819, 0.025814},{
      0.486737, 0.016462, 0.025814},{0.487935, 0.012776, 0.023438}}],
    Polygon[{{0.482673, 0.015819, 0.025814},{0.482673, 0.020019, 0.027554},{
      0.485439, 0.020457, 0.027554},{0.486737, 0.016462, 0.025814}}],
    Polygon[{{0.482673, 0.020019, 0.027554},{0.482673, 0.024439, 0.028615},{
      0.484073, 0.024661, 0.028615},{0.485439, 0.020457, 0.027554}}],
    Polygon[{{0.484073, 0.024661, -0.028615},{0.485439, 0.020457, -0.027554},{
      0.487935, 0.021729, -0.027554},{0.485337, 0.025305, -0.028615}}],
    Polygon[{{0.485439, 0.020457, -0.027554},{0.486737, 0.016462, -0.025814},{
      0.490404, 0.018331, -0.025814},{0.487935, 0.021729, -0.027554}}],
    Polygon[{{0.486737, 0.016462, -0.025814},{0.487935, 0.012776, -0.023438},{
      0.492682, 0.015195, -0.023438},{0.490404, 0.018331, -0.025814}}],
    Polygon[{{0.487935, 0.012776, -0.023438},{0.489003, 0.009488, -0.020486},{
      0.494714, 0.012398, -0.020486},{0.492682, 0.015195, -0.023438}}],
    Polygon[{{0.489003, 0.009488, -0.020486},{0.489916, 0.006680, -0.017029},{
      0.496450, 0.010009, -0.017029},{0.494714, 0.012398, -0.020486}}],
    Polygon[{{0.489916, 0.006680, -0.017029},{0.490650, 0.004421, -0.013153},{
      0.497846, 0.008088, -0.013153},{0.496450, 0.010009, -0.017029}}],
    Polygon[{{0.490650, 0.004421, -0.013153},{0.491187, 0.002767, -0.008953},{
      0.498868, 0.006680, -0.008953},{0.497846, 0.008088, -0.013153}}],
    Polygon[{{0.491187, 0.002767, -0.008953},{0.491515, 0.001757, -0.004532},{
      0.499492, 0.005822, -0.004532},{0.498868, 0.006680, -0.008953}}],
    Polygon[{{0.491515, 0.001757, -0.004532},{0.491626, 0.001418, 0.000000},{
      0.499702, 0.005533, 0.000000},{0.499492, 0.005822, -0.004532}}],
    Polygon[{{0.491626, 0.001418, 0.000000},{0.491515, 0.001757, 0.004532},{
      0.499492, 0.005822, 0.004532},{0.499702, 0.005533, 0.000000}}],
    Polygon[{{0.491515, 0.001757, 0.004532},{0.491187, 0.002767, 0.008953},{
      0.498868, 0.006680, 0.008953},{0.499492, 0.005822, 0.004532}}],
    Polygon[{{0.491187, 0.002767, 0.008953},{0.490650, 0.004421, 0.013153},{
      0.497846, 0.008088, 0.013153},{0.498868, 0.006680, 0.008953}}],
    Polygon[{{0.490650, 0.004421, 0.013153},{0.489916, 0.006680, 0.017029},{
      0.496450, 0.010009, 0.017029},{0.497846, 0.008088, 0.013153}}],
    Polygon[{{0.489916, 0.006680, 0.017029},{0.489003, 0.009488, 0.020486},{
      0.494714, 0.012398, 0.020486},{0.496450, 0.010009, 0.017029}}],
    Polygon[{{0.489003, 0.009488, 0.020486},{0.487935, 0.012776, 0.023438},{
      0.492682, 0.015195, 0.023438},{0.494714, 0.012398, 0.020486}}],
    Polygon[{{0.487935, 0.012776, 0.023438},{0.486737, 0.016462, 0.025814},{
      0.490404, 0.018331, 0.025814},{0.492682, 0.015195, 0.023438}}],
    Polygon[{{0.486737, 0.016462, 0.025814},{0.485439, 0.020457, 0.027554},{
      0.487935, 0.021729, 0.027554},{0.490404, 0.018331, 0.025814}}],
    Polygon[{{0.485439, 0.020457, 0.027554},{0.484073, 0.024661, 0.028615},{
      0.485337, 0.025305, 0.028615},{0.487935, 0.021729, 0.027554}}],
    Polygon[{{0.485337, 0.025305, -0.028615},{0.487935, 0.021729, -0.027554},{
      0.489916, 0.023709, -0.027554},{0.486339, 0.026308, -0.028615}}],
    Polygon[{{0.487935, 0.021729, -0.027554},{0.490404, 0.018331, -0.025814},{
      0.493314, 0.021240, -0.025814},{0.489916, 0.023709, -0.027554}}],
    Polygon[{{0.490404, 0.018331, -0.025814},{0.492682, 0.015195, -0.023438},{
      0.496450, 0.018962, -0.023438},{0.493314, 0.021240, -0.025814}}],
    Polygon[{{0.492682, 0.015195, -0.023438},{0.494714, 0.012398, -0.020486},{
      0.499246, 0.016930, -0.020486},{0.496450, 0.018962, -0.023438}}],
    Polygon[{{0.494714, 0.012398, -0.020486},{0.496450, 0.010009, -0.017029},{
      0.501635, 0.015195, -0.017029},{0.499246, 0.016930, -0.020486}}],
    Polygon[{{0.496450, 0.010009, -0.017029},{0.497846, 0.008088, -0.013153},{
      0.503557, 0.013799, -0.013153},{0.501635, 0.015195, -0.017029}}],
    Polygon[{{0.497846, 0.008088, -0.013153},{0.498868, 0.006680, -0.008953},{
      0.504964, 0.012776, -0.008953},{0.503557, 0.013799, -0.013153}}],
    Polygon[{{0.498868, 0.006680, -0.008953},{0.499492, 0.005822, -0.004532},{
      0.505823, 0.012152, -0.004532},{0.504964, 0.012776, -0.008953}}],
    Polygon[{{0.499492, 0.005822, -0.004532},{0.499702, 0.005533, 0.000000},{
      0.506111, 0.011942, 0.000000},{0.505823, 0.012152, -0.004532}}],
    Polygon[{{0.499702, 0.005533, 0.000000},{0.499492, 0.005822, 0.004532},{
      0.505823, 0.012152, 0.004532},{0.506111, 0.011942, 0.000000}}],
    Polygon[{{0.499492, 0.005822, 0.004532},{0.498868, 0.006680, 0.008953},{
      0.504964, 0.012776, 0.008953},{0.505823, 0.012152, 0.004532}}],
    Polygon[{{0.498868, 0.006680, 0.008953},{0.497846, 0.008088, 0.013153},{
      0.503557, 0.013799, 0.013153},{0.504964, 0.012776, 0.008953}}],
    Polygon[{{0.497846, 0.008088, 0.013153},{0.496450, 0.010009, 0.017029},{
      0.501635, 0.015195, 0.017029},{0.503557, 0.013799, 0.013153}}],
    Polygon[{{0.496450, 0.010009, 0.017029},{0.494714, 0.012398, 0.020486},{
      0.499246, 0.016930, 0.020486},{0.501635, 0.015195, 0.017029}}],
    Polygon[{{0.494714, 0.012398, 0.020486},{0.492682, 0.015195, 0.023438},{
      0.496450, 0.018962, 0.023438},{0.499246, 0.016930, 0.020486}}],
    Polygon[{{0.492682, 0.015195, 0.023438},{0.490404, 0.018331, 0.025814},{
      0.493314, 0.021240, 0.025814},{0.496450, 0.018962, 0.023438}}],
    Polygon[{{0.490404, 0.018331, 0.025814},{0.487935, 0.021729, 0.027554},{
      0.489916, 0.023709, 0.027554},{0.493314, 0.021240, 0.025814}}],
    Polygon[{{0.487935, 0.021729, 0.027554},{0.485337, 0.025305, 0.028615},{
      0.486339, 0.026308, 0.028615},{0.489916, 0.023709, 0.027554}}],
    Polygon[{{0.486339, 0.026308, -0.028615},{0.489916, 0.023709, -0.027554},{
      0.491187, 0.026205, -0.027554},{0.486983, 0.027571, -0.028615}}],
    Polygon[{{0.489916, 0.023709, -0.027554},{0.493314, 0.021240, -0.025814},{
      0.495182, 0.024907, -0.025814},{0.491187, 0.026205, -0.027554}}],
    Polygon[{{0.493314, 0.021240, -0.025814},{0.496450, 0.018962, -0.023438},{
      0.498868, 0.023709, -0.023438},{0.495182, 0.024907, -0.025814}}],
    Polygon[{{0.496450, 0.018962, -0.023438},{0.499246, 0.016930, -0.020486},{
      0.502156, 0.022641, -0.020486},{0.498868, 0.023709, -0.023438}}],
    Polygon[{{0.499246, 0.016930, -0.020486},{0.501635, 0.015195, -0.017029},{
      0.504964, 0.021729, -0.017029},{0.502156, 0.022641, -0.020486}}],
    Polygon[{{0.501635, 0.015195, -0.017029},{0.503557, 0.013799, -0.013153},{
      0.507223, 0.020995, -0.013153},{0.504964, 0.021729, -0.017029}}],
    Polygon[{{0.503557, 0.013799, -0.013153},{0.504964, 0.012776, -0.008953},{
      0.508878, 0.020457, -0.008953},{0.507223, 0.020995, -0.013153}}],
    Polygon[{{0.504964, 0.012776, -0.008953},{0.505823, 0.012152, -0.004532},{
      0.509887, 0.020129, -0.004532},{0.508878, 0.020457, -0.008953}}],
    Polygon[{{0.505823, 0.012152, -0.004532},{0.506111, 0.011942, 0.000000},{
      0.510226, 0.020019, 0.000000},{0.509887, 0.020129, -0.004532}}],
    Polygon[{{0.506111, 0.011942, 0.000000},{0.505823, 0.012152, 0.004532},{
      0.509887, 0.020129, 0.004532},{0.510226, 0.020019, 0.000000}}],
    Polygon[{{0.505823, 0.012152, 0.004532},{0.504964, 0.012776, 0.008953},{
      0.508878, 0.020457, 0.008953},{0.509887, 0.020129, 0.004532}}],
    Polygon[{{0.504964, 0.012776, 0.008953},{0.503557, 0.013799, 0.013153},{
      0.507223, 0.020995, 0.013153},{0.508878, 0.020457, 0.008953}}],
    Polygon[{{0.503557, 0.013799, 0.013153},{0.501635, 0.015195, 0.017029},{
      0.504964, 0.021729, 0.017029},{0.507223, 0.020995, 0.013153}}],
    Polygon[{{0.501635, 0.015195, 0.017029},{0.499246, 0.016930, 0.020486},{
      0.502156, 0.022641, 0.020486},{0.504964, 0.021729, 0.017029}}],
    Polygon[{{0.499246, 0.016930, 0.020486},{0.496450, 0.018962, 0.023438},{
      0.498868, 0.023709, 0.023438},{0.502156, 0.022641, 0.020486}}],
    Polygon[{{0.496450, 0.018962, 0.023438},{0.493314, 0.021240, 0.025814},{
      0.495182, 0.024907, 0.025814},{0.498868, 0.023709, 0.023438}}],
    Polygon[{{0.493314, 0.021240, 0.025814},{0.489916, 0.023709, 0.027554},{
      0.491187, 0.026205, 0.027554},{0.495182, 0.024907, 0.025814}}],
    Polygon[{{0.489916, 0.023709, 0.027554},{0.486339, 0.026308, 0.028615},{
      0.486983, 0.027571, 0.028615},{0.491187, 0.026205, 0.027554}}],
    Polygon[{{0.486983, 0.027571, -0.028615},{0.491187, 0.026205, -0.027554},{
      0.491626, 0.028972, -0.027554},{0.487205, 0.028972, -0.028615}}],
    Polygon[{{0.491187, 0.026205, -0.027554},{0.495182, 0.024907, -0.025814},{
      0.495826, 0.028972, -0.025814},{0.491626, 0.028972, -0.027554}}],
    Polygon[{{0.495182, 0.024907, -0.025814},{0.498868, 0.023709, -0.023438},{
      0.499702, 0.028972, -0.023438},{0.495826, 0.028972, -0.025814}}],
    Polygon[{{0.498868, 0.023709, -0.023438},{0.502156, 0.022641, -0.020486},{
      0.503159, 0.028972, -0.020486},{0.499702, 0.028972, -0.023438}}],
    Polygon[{{0.502156, 0.022641, -0.020486},{0.504964, 0.021729, -0.017029},{
      0.506111, 0.028972, -0.017029},{0.503159, 0.028972, -0.020486}}],
    Polygon[{{0.504964, 0.021729, -0.017029},{0.507223, 0.020995, -0.013153},{
      0.508487, 0.028972, -0.013153},{0.506111, 0.028972, -0.017029}}],
    Polygon[{{0.507223, 0.020995, -0.013153},{0.508878, 0.020457, -0.008953},{
      0.510226, 0.028972, -0.008953},{0.508487, 0.028972, -0.013153}}],
    Polygon[{{0.508878, 0.020457, -0.008953},{0.509887, 0.020129, -0.004532},{
      0.511288, 0.028972, -0.004532},{0.510226, 0.028972, -0.008953}}],
    Polygon[{{0.509887, 0.020129, -0.004532},{0.510226, 0.020019, 0.000000},{
      0.511644, 0.028972, 0.000000},{0.511288, 0.028972, -0.004532}}],
    Polygon[{{0.510226, 0.020019, 0.000000},{0.509887, 0.020129, 0.004532},{
      0.511288, 0.028972, 0.004532},{0.511644, 0.028972, 0.000000}}],
    Polygon[{{0.509887, 0.020129, 0.004532},{0.508878, 0.020457, 0.008953},{
      0.510226, 0.028972, 0.008953},{0.511288, 0.028972, 0.004532}}],
    Polygon[{{0.508878, 0.020457, 0.008953},{0.507223, 0.020995, 0.013153},{
      0.508487, 0.028972, 0.013153},{0.510226, 0.028972, 0.008953}}],
    Polygon[{{0.507223, 0.020995, 0.013153},{0.504964, 0.021729, 0.017029},{
      0.506111, 0.028972, 0.017029},{0.508487, 0.028972, 0.013153}}],
    Polygon[{{0.504964, 0.021729, 0.017029},{0.502156, 0.022641, 0.020486},{
      0.503159, 0.028972, 0.020486},{0.506111, 0.028972, 0.017029}}],
    Polygon[{{0.502156, 0.022641, 0.020486},{0.498868, 0.023709, 0.023438},{
      0.499702, 0.028972, 0.023438},{0.503159, 0.028972, 0.020486}}],
    Polygon[{{0.498868, 0.023709, 0.023438},{0.495182, 0.024907, 0.025814},{
      0.495826, 0.028972, 0.025814},{0.499702, 0.028972, 0.023438}}],
    Polygon[{{0.495182, 0.024907, 0.025814},{0.491187, 0.026205, 0.027554},{
      0.491626, 0.028972, 0.027554},{0.495826, 0.028972, 0.025814}}],
    Polygon[{{0.491187, 0.026205, 0.027554},{0.486983, 0.027571, 0.028615},{
      0.487205, 0.028972, 0.028615},{0.491626, 0.028972, 0.027554}}],
    Polygon[{{0.443279, 0.015038, -0.014853},{0.445574, 0.015038, -0.014302},{
      0.445347, 0.016474, -0.014302},{0.443164, 0.015765, -0.014853}}],
    Polygon[{{0.445574, 0.015038, -0.014302},{0.447754, 0.015038, -0.013399},{
      0.447420, 0.017148, -0.013399},{0.445347, 0.016474, -0.014302}}],
    Polygon[{{0.447754, 0.015038, -0.013399},{0.449766, 0.015038, -0.012166},{
      0.449334, 0.017770, -0.012166},{0.447420, 0.017148, -0.013399}}],
    Polygon[{{0.449766, 0.015038, -0.012166},{0.451561, 0.015038, -0.010634},{
      0.451040, 0.018324, -0.010634},{0.449334, 0.017770, -0.012166}}],
    Polygon[{{0.451561, 0.015038, -0.010634},{0.453093, 0.015038, -0.008839},{
      0.452498, 0.018798, -0.008839},{0.451040, 0.018324, -0.010634}}],
    Polygon[{{0.453093, 0.015038, -0.008839},{0.454326, 0.015038, -0.006827},{
      0.453670, 0.019179, -0.006827},{0.452498, 0.018798, -0.008839}}],
    Polygon[{{0.454326, 0.015038, -0.006827},{0.455229, 0.015038, -0.004647},{
      0.454529, 0.019458, -0.004647},{0.453670, 0.019179, -0.006827}}],
    Polygon[{{0.455229, 0.015038, -0.004647},{0.455780, 0.015038, -0.002352},{
      0.455053, 0.019628, -0.002352},{0.454529, 0.019458, -0.004647}}],
    Polygon[{{0.455780, 0.015038, -0.002352},{0.455965, 0.015038, 0.000000},{
      0.455229, 0.019685, 0.000000},{0.455053, 0.019628, -0.002352}}],
    Polygon[{{0.455965, 0.015038, 0.000000},{0.455780, 0.015038, 0.002352},{
      0.455053, 0.019628, 0.002352},{0.455229, 0.019685, 0.000000}}],
    Polygon[{{0.455780, 0.015038, 0.002352},{0.455229, 0.015038, 0.004647},{
      0.454529, 0.019458, 0.004647},{0.455053, 0.019628, 0.002352}}],
    Polygon[{{0.455229, 0.015038, 0.004647},{0.454326, 0.015038, 0.006827},{
      0.453670, 0.019179, 0.006827},{0.454529, 0.019458, 0.004647}}],
    Polygon[{{0.454326, 0.015038, 0.006827},{0.453093, 0.015038, 0.008839},{
      0.452498, 0.018798, 0.008839},{0.453670, 0.019179, 0.006827}}],
    Polygon[{{0.453093, 0.015038, 0.008839},{0.451561, 0.015038, 0.010634},{
      0.451040, 0.018324, 0.010634},{0.452498, 0.018798, 0.008839}}],
    Polygon[{{0.451561, 0.015038, 0.010634},{0.449766, 0.015038, 0.012166},{
      0.449334, 0.017770, 0.012166},{0.451040, 0.018324, 0.010634}}],
    Polygon[{{0.449766, 0.015038, 0.012166},{0.447754, 0.015038, 0.013399},{
      0.447420, 0.017148, 0.013399},{0.449334, 0.017770, 0.012166}}],
    Polygon[{{0.447754, 0.015038, 0.013399},{0.445574, 0.015038, 0.014302},{
      0.445347, 0.016474, 0.014302},{0.447420, 0.017148, 0.013399}}],
    Polygon[{{0.445574, 0.015038, 0.014302},{0.443279, 0.015038, 0.014853},{
      0.443164, 0.015765, 0.014853},{0.445347, 0.016474, 0.014302}}],
    Polygon[{{0.443164, 0.015765, -0.014853},{0.445347, 0.016474, -0.014302},{
      0.444687, 0.017770, -0.014302},{0.442830, 0.016421, -0.014853}}],
    Polygon[{{0.445347, 0.016474, -0.014302},{0.447420, 0.017148, -0.013399},{
      0.446450, 0.019051, -0.013399},{0.444687, 0.017770, -0.014302}}],
    Polygon[{{0.447420, 0.017148, -0.013399},{0.449334, 0.017770, -0.012166},{
      0.448078, 0.020234, -0.012166},{0.446450, 0.019051, -0.013399}}],
    Polygon[{{0.449334, 0.017770, -0.012166},{0.451040, 0.018324, -0.010634},{
      0.449530, 0.021288, -0.010634},{0.448078, 0.020234, -0.012166}}],
    Polygon[{{0.451040, 0.018324, -0.010634},{0.452498, 0.018798, -0.008839},{
      0.450770, 0.022189, -0.008839},{0.449530, 0.021288, -0.010634}}],
    Polygon[{{0.452498, 0.018798, -0.008839},{0.453670, 0.019179, -0.006827},{
      0.451767, 0.022914, -0.006827},{0.450770, 0.022189, -0.008839}}],
    Polygon[{{0.453670, 0.019179, -0.006827},{0.454529, 0.019458, -0.004647},{
      0.452498, 0.023445, -0.004647},{0.451767, 0.022914, -0.006827}}],
    Polygon[{{0.454529, 0.019458, -0.004647},{0.455053, 0.019628, -0.002352},{
      0.452943, 0.023769, -0.002352},{0.452498, 0.023445, -0.004647}}],
    Polygon[{{0.455053, 0.019628, -0.002352},{0.455229, 0.019685, 0.000000},{
      0.453093, 0.023877, 0.000000},{0.452943, 0.023769, -0.002352}}],
    Polygon[{{0.455229, 0.019685, 0.000000},{0.455053, 0.019628, 0.002352},{
      0.452943, 0.023769, 0.002352},{0.453093, 0.023877, 0.000000}}],
    Polygon[{{0.455053, 0.019628, 0.002352},{0.454529, 0.019458, 0.004647},{
      0.452498, 0.023445, 0.004647},{0.452943, 0.023769, 0.002352}}],
    Polygon[{{0.454529, 0.019458, 0.004647},{0.453670, 0.019179, 0.006827},{
      0.451767, 0.022914, 0.006827},{0.452498, 0.023445, 0.004647}}],
    Polygon[{{0.453670, 0.019179, 0.006827},{0.452498, 0.018798, 0.008839},{
      0.450770, 0.022189, 0.008839},{0.451767, 0.022914, 0.006827}}],
    Polygon[{{0.452498, 0.018798, 0.008839},{0.451040, 0.018324, 0.010634},{
      0.449530, 0.021288, 0.010634},{0.450770, 0.022189, 0.008839}}],
    Polygon[{{0.451040, 0.018324, 0.010634},{0.449334, 0.017770, 0.012166},{
      0.448078, 0.020234, 0.012166},{0.449530, 0.021288, 0.010634}}],
    Polygon[{{0.449334, 0.017770, 0.012166},{0.447420, 0.017148, 0.013399},{
      0.446450, 0.019051, 0.013399},{0.448078, 0.020234, 0.012166}}],
    Polygon[{{0.447420, 0.017148, 0.013399},{0.445347, 0.016474, 0.014302},{
      0.444687, 0.017770, 0.014302},{0.446450, 0.019051, 0.013399}}],
    Polygon[{{0.445347, 0.016474, 0.014302},{0.443164, 0.015765, 0.014853},{
      0.442830, 0.016421, 0.014853},{0.444687, 0.017770, 0.014302}}],
    Polygon[{{0.442830, 0.016421, -0.014853},{0.444687, 0.017770, -0.014302},{
      0.443658, 0.018798, -0.014302},{0.442310, 0.016941, -0.014853}}],
    Polygon[{{0.444687, 0.017770, -0.014302},{0.446450, 0.019051, -0.013399},{
      0.444940, 0.020561, -0.013399},{0.443658, 0.018798, -0.014302}}],
    Polygon[{{0.446450, 0.019051, -0.013399},{0.448078, 0.020234, -0.012166},{
      0.446123, 0.022189, -0.012166},{0.444940, 0.020561, -0.013399}}],
    Polygon[{{0.448078, 0.020234, -0.012166},{0.449530, 0.021288, -0.010634},{
      0.447177, 0.023641, -0.010634},{0.446123, 0.022189, -0.012166}}],
    Polygon[{{0.449530, 0.021288, -0.010634},{0.450770, 0.022189, -0.008839},{
      0.448078, 0.024881, -0.008839},{0.447177, 0.023641, -0.010634}}],
    Polygon[{{0.450770, 0.022189, -0.008839},{0.451767, 0.022914, -0.006827},{
      0.448803, 0.025878, -0.006827},{0.448078, 0.024881, -0.008839}}],
    Polygon[{{0.451767, 0.022914, -0.006827},{0.452498, 0.023445, -0.004647},{
      0.449334, 0.026609, -0.004647},{0.448803, 0.025878, -0.006827}}],
    Polygon[{{0.452498, 0.023445, -0.004647},{0.452943, 0.023769, -0.002352},{
      0.449657, 0.027055, -0.002352},{0.449334, 0.026609, -0.004647}}],
    Polygon[{{0.452943, 0.023769, -0.002352},{0.453093, 0.023877, 0.000000},{
      0.449766, 0.027204, 0.000000},{0.449657, 0.027055, -0.002352}}],
    Polygon[{{0.453093, 0.023877, 0.000000},{0.452943, 0.023769, 0.002352},{
      0.449657, 0.027055, 0.002352},{0.449766, 0.027204, 0.000000}}],
    Polygon[{{0.452943, 0.023769, 0.002352},{0.452498, 0.023445, 0.004647},{
      0.449334, 0.026609, 0.004647},{0.449657, 0.027055, 0.002352}}],
    Polygon[{{0.452498, 0.023445, 0.004647},{0.451767, 0.022914, 0.006827},{
      0.448803, 0.025878, 0.006827},{0.449334, 0.026609, 0.004647}}],
    Polygon[{{0.451767, 0.022914, 0.006827},{0.450770, 0.022189, 0.008839},{
      0.448078, 0.024881, 0.008839},{0.448803, 0.025878, 0.006827}}],
    Polygon[{{0.450770, 0.022189, 0.008839},{0.449530, 0.021288, 0.010634},{
      0.447177, 0.023641, 0.010634},{0.448078, 0.024881, 0.008839}}],
    Polygon[{{0.449530, 0.021288, 0.010634},{0.448078, 0.020234, 0.012166},{
      0.446123, 0.022189, 0.012166},{0.447177, 0.023641, 0.010634}}],
    Polygon[{{0.448078, 0.020234, 0.012166},{0.446450, 0.019051, 0.013399},{
      0.444940, 0.020561, 0.013399},{0.446123, 0.022189, 0.012166}}],
    Polygon[{{0.446450, 0.019051, 0.013399},{0.444687, 0.017770, 0.014302},{
      0.443658, 0.018798, 0.014302},{0.444940, 0.020561, 0.013399}}],
    Polygon[{{0.444687, 0.017770, 0.014302},{0.442830, 0.016421, 0.014853},{
      0.442310, 0.016941, 0.014853},{0.443658, 0.018798, 0.014302}}],
    Polygon[{{0.442310, 0.016941, -0.014853},{0.443658, 0.018798, -0.014302},{
      0.442363, 0.019458, -0.014302},{0.441654, 0.017276, -0.014853}}],
    Polygon[{{0.443658, 0.018798, -0.014302},{0.444940, 0.020561, -0.013399},{
      0.443037, 0.021531, -0.013399},{0.442363, 0.019458, -0.014302}}],
    Polygon[{{0.444940, 0.020561, -0.013399},{0.446123, 0.022189, -0.012166},{
      0.443658, 0.023445, -0.012166},{0.443037, 0.021531, -0.013399}}],
    Polygon[{{0.446123, 0.022189, -0.012166},{0.447177, 0.023641, -0.010634},{
      0.444213, 0.025151, -0.010634},{0.443658, 0.023445, -0.012166}}],
    Polygon[{{0.447177, 0.023641, -0.010634},{0.448078, 0.024881, -0.008839},{
      0.444687, 0.026609, -0.008839},{0.444213, 0.025151, -0.010634}}],
    Polygon[{{0.448078, 0.024881, -0.008839},{0.448803, 0.025878, -0.006827},{
      0.445068, 0.027781, -0.006827},{0.444687, 0.026609, -0.008839}}],
    Polygon[{{0.448803, 0.025878, -0.006827},{0.449334, 0.026609, -0.004647},{
      0.445347, 0.028640, -0.004647},{0.445068, 0.027781, -0.006827}}],
    Polygon[{{0.449334, 0.026609, -0.004647},{0.449657, 0.027055, -0.002352},{
      0.445517, 0.029164, -0.002352},{0.445347, 0.028640, -0.004647}}],
    Polygon[{{0.449657, 0.027055, -0.002352},{0.449766, 0.027204, 0.000000},{
      0.445574, 0.029340, 0.000000},{0.445517, 0.029164, -0.002352}}],
    Polygon[{{0.449766, 0.027204, 0.000000},{0.449657, 0.027055, 0.002352},{
      0.445517, 0.029164, 0.002352},{0.445574, 0.029340, 0.000000}}],
    Polygon[{{0.449657, 0.027055, 0.002352},{0.449334, 0.026609, 0.004647},{
      0.445347, 0.028640, 0.004647},{0.445517, 0.029164, 0.002352}}],
    Polygon[{{0.449334, 0.026609, 0.004647},{0.448803, 0.025878, 0.006827},{
      0.445068, 0.027781, 0.006827},{0.445347, 0.028640, 0.004647}}],
    Polygon[{{0.448803, 0.025878, 0.006827},{0.448078, 0.024881, 0.008839},{
      0.444687, 0.026609, 0.008839},{0.445068, 0.027781, 0.006827}}],
    Polygon[{{0.448078, 0.024881, 0.008839},{0.447177, 0.023641, 0.010634},{
      0.444213, 0.025151, 0.010634},{0.444687, 0.026609, 0.008839}}],
    Polygon[{{0.447177, 0.023641, 0.010634},{0.446123, 0.022189, 0.012166},{
      0.443658, 0.023445, 0.012166},{0.444213, 0.025151, 0.010634}}],
    Polygon[{{0.446123, 0.022189, 0.012166},{0.444940, 0.020561, 0.013399},{
      0.443037, 0.021531, 0.013399},{0.443658, 0.023445, 0.012166}}],
    Polygon[{{0.444940, 0.020561, 0.013399},{0.443658, 0.018798, 0.014302},{
      0.442363, 0.019458, 0.014302},{0.443037, 0.021531, 0.013399}}],
    Polygon[{{0.443658, 0.018798, 0.014302},{0.442310, 0.016941, 0.014853},{
      0.441654, 0.017276, 0.014853},{0.442363, 0.019458, 0.014302}}],
    Polygon[{{0.441654, 0.017276, -0.014853},{0.442363, 0.019458, -0.014302},{
      0.440927, 0.019685, -0.014302},{0.440927, 0.017391, -0.014853}}],
    Polygon[{{0.442363, 0.019458, -0.014302},{0.443037, 0.021531, -0.013399},{
      0.440927, 0.021865, -0.013399},{0.440927, 0.019685, -0.014302}}],
    Polygon[{{0.443037, 0.021531, -0.013399},{0.443658, 0.023445, -0.012166},{
      0.440927, 0.023877, -0.012166},{0.440927, 0.021865, -0.013399}}],
    Polygon[{{0.443658, 0.023445, -0.012166},{0.444213, 0.025151, -0.010634},{
      0.440927, 0.025672, -0.010634},{0.440927, 0.023877, -0.012166}}],
    Polygon[{{0.444213, 0.025151, -0.010634},{0.444687, 0.026609, -0.008839},{
      0.440927, 0.027204, -0.008839},{0.440927, 0.025672, -0.010634}}],
    Polygon[{{0.444687, 0.026609, -0.008839},{0.445068, 0.027781, -0.006827},{
      0.440927, 0.028437, -0.006827},{0.440927, 0.027204, -0.008839}}],
    Polygon[{{0.445068, 0.027781, -0.006827},{0.445347, 0.028640, -0.004647},{
      0.440927, 0.029340, -0.004647},{0.440927, 0.028437, -0.006827}}],
    Polygon[{{0.445347, 0.028640, -0.004647},{0.445517, 0.029164, -0.002352},{
      0.440927, 0.029891, -0.002352},{0.440927, 0.029340, -0.004647}}],
    Polygon[{{0.445517, 0.029164, -0.002352},{0.445574, 0.029340, 0.000000},{
      0.440927, 0.030076, 0.000000},{0.440927, 0.029891, -0.002352}}],
    Polygon[{{0.445574, 0.029340, 0.000000},{0.445517, 0.029164, 0.002352},{
      0.440927, 0.029891, 0.002352},{0.440927, 0.030076, 0.000000}}],
    Polygon[{{0.445517, 0.029164, 0.002352},{0.445347, 0.028640, 0.004647},{
      0.440927, 0.029340, 0.004647},{0.440927, 0.029891, 0.002352}}],
    Polygon[{{0.445347, 0.028640, 0.004647},{0.445068, 0.027781, 0.006827},{
      0.440927, 0.028437, 0.006827},{0.440927, 0.029340, 0.004647}}],
    Polygon[{{0.445068, 0.027781, 0.006827},{0.444687, 0.026609, 0.008839},{
      0.440927, 0.027204, 0.008839},{0.440927, 0.028437, 0.006827}}],
    Polygon[{{0.444687, 0.026609, 0.008839},{0.444213, 0.025151, 0.010634},{
      0.440927, 0.025672, 0.010634},{0.440927, 0.027204, 0.008839}}],
    Polygon[{{0.444213, 0.025151, 0.010634},{0.443658, 0.023445, 0.012166},{
      0.440927, 0.023877, 0.012166},{0.440927, 0.025672, 0.010634}}],
    Polygon[{{0.443658, 0.023445, 0.012166},{0.443037, 0.021531, 0.013399},{
      0.440927, 0.021865, 0.013399},{0.440927, 0.023877, 0.012166}}],
    Polygon[{{0.443037, 0.021531, 0.013399},{0.442363, 0.019458, 0.014302},{
      0.440927, 0.019685, 0.014302},{0.440927, 0.021865, 0.013399}}],
    Polygon[{{0.442363, 0.019458, 0.014302},{0.441654, 0.017276, 0.014853},{
      0.440927, 0.017391, 0.014853},{0.440927, 0.019685, 0.014302}}],
    Polygon[{{0.440927, 0.017391, -0.014853},{0.440927, 0.019685, -0.014302},{
      0.439491, 0.019458, -0.014302},{0.440200, 0.017276, -0.014853}}],
    Polygon[{{0.440927, 0.019685, -0.014302},{0.440927, 0.021865, -0.013399},{
      0.438817, 0.021531, -0.013399},{0.439491, 0.019458, -0.014302}}],
    Polygon[{{0.440927, 0.021865, -0.013399},{0.440927, 0.023877, -0.012166},{
      0.438196, 0.023445, -0.012166},{0.438817, 0.021531, -0.013399}}],
    Polygon[{{0.440927, 0.023877, -0.012166},{0.440927, 0.025672, -0.010634},{
      0.437641, 0.025151, -0.010634},{0.438196, 0.023445, -0.012166}}],
    Polygon[{{0.440927, 0.025672, -0.010634},{0.440927, 0.027204, -0.008839},{
      0.437167, 0.026609, -0.008839},{0.437641, 0.025151, -0.010634}}],
    Polygon[{{0.440927, 0.027204, -0.008839},{0.440927, 0.028437, -0.006827},{
      0.436786, 0.027781, -0.006827},{0.437167, 0.026609, -0.008839}}],
    Polygon[{{0.440927, 0.028437, -0.006827},{0.440927, 0.029340, -0.004647},{
      0.436507, 0.028640, -0.004647},{0.436786, 0.027781, -0.006827}}],
    Polygon[{{0.440927, 0.029340, -0.004647},{0.440927, 0.029891, -0.002352},{
      0.436337, 0.029164, -0.002352},{0.436507, 0.028640, -0.004647}}],
    Polygon[{{0.440927, 0.029891, -0.002352},{0.440927, 0.030076, 0.000000},{
      0.436280, 0.029340, 0.000000},{0.436337, 0.029164, -0.002352}}],
    Polygon[{{0.440927, 0.030076, 0.000000},{0.440927, 0.029891, 0.002352},{
      0.436337, 0.029164, 0.002352},{0.436280, 0.029340, 0.000000}}],
    Polygon[{{0.440927, 0.029891, 0.002352},{0.440927, 0.029340, 0.004647},{
      0.436507, 0.028640, 0.004647},{0.436337, 0.029164, 0.002352}}],
    Polygon[{{0.440927, 0.029340, 0.004647},{0.440927, 0.028437, 0.006827},{
      0.436786, 0.027781, 0.006827},{0.436507, 0.028640, 0.004647}}],
    Polygon[{{0.440927, 0.028437, 0.006827},{0.440927, 0.027204, 0.008839},{
      0.437167, 0.026609, 0.008839},{0.436786, 0.027781, 0.006827}}],
    Polygon[{{0.440927, 0.027204, 0.008839},{0.440927, 0.025672, 0.010634},{
      0.437641, 0.025151, 0.010634},{0.437167, 0.026609, 0.008839}}],
    Polygon[{{0.440927, 0.025672, 0.010634},{0.440927, 0.023877, 0.012166},{
      0.438196, 0.023445, 0.012166},{0.437641, 0.025151, 0.010634}}],
    Polygon[{{0.440927, 0.023877, 0.012166},{0.440927, 0.021865, 0.013399},{
      0.438817, 0.021531, 0.013399},{0.438196, 0.023445, 0.012166}}],
    Polygon[{{0.440927, 0.021865, 0.013399},{0.440927, 0.019685, 0.014302},{
      0.439491, 0.019458, 0.014302},{0.438817, 0.021531, 0.013399}}],
    Polygon[{{0.440927, 0.019685, 0.014302},{0.440927, 0.017391, 0.014853},{
      0.440200, 0.017276, 0.014853},{0.439491, 0.019458, 0.014302}}],
    Polygon[{{0.440200, 0.017276, -0.014853},{0.439491, 0.019458, -0.014302},{
      0.438196, 0.018798, -0.014302},{0.439544, 0.016941, -0.014853}}],
    Polygon[{{0.439491, 0.019458, -0.014302},{0.438817, 0.021531, -0.013399},{
      0.436914, 0.020561, -0.013399},{0.438196, 0.018798, -0.014302}}],
    Polygon[{{0.438817, 0.021531, -0.013399},{0.438196, 0.023445, -0.012166},{
      0.435731, 0.022189, -0.012166},{0.436914, 0.020561, -0.013399}}],
    Polygon[{{0.438196, 0.023445, -0.012166},{0.437641, 0.025151, -0.010634},{
      0.434677, 0.023641, -0.010634},{0.435731, 0.022189, -0.012166}}],
    Polygon[{{0.437641, 0.025151, -0.010634},{0.437167, 0.026609, -0.008839},{
      0.433776, 0.024881, -0.008839},{0.434677, 0.023641, -0.010634}}],
    Polygon[{{0.437167, 0.026609, -0.008839},{0.436786, 0.027781, -0.006827},{
      0.433051, 0.025878, -0.006827},{0.433776, 0.024881, -0.008839}}],
    Polygon[{{0.436786, 0.027781, -0.006827},{0.436507, 0.028640, -0.004647},{
      0.432520, 0.026609, -0.004647},{0.433051, 0.025878, -0.006827}}],
    Polygon[{{0.436507, 0.028640, -0.004647},{0.436337, 0.029164, -0.002352},{
      0.432197, 0.027055, -0.002352},{0.432520, 0.026609, -0.004647}}],
    Polygon[{{0.436337, 0.029164, -0.002352},{0.436280, 0.029340, 0.000000},{
      0.432088, 0.027204, 0.000000},{0.432197, 0.027055, -0.002352}}],
    Polygon[{{0.436280, 0.029340, 0.000000},{0.436337, 0.029164, 0.002352},{
      0.432197, 0.027055, 0.002352},{0.432088, 0.027204, 0.000000}}],
    Polygon[{{0.436337, 0.029164, 0.002352},{0.436507, 0.028640, 0.004647},{
      0.432520, 0.026609, 0.004647},{0.432197, 0.027055, 0.002352}}],
    Polygon[{{0.436507, 0.028640, 0.004647},{0.436786, 0.027781, 0.006827},{
      0.433051, 0.025878, 0.006827},{0.432520, 0.026609, 0.004647}}],
    Polygon[{{0.436786, 0.027781, 0.006827},{0.437167, 0.026609, 0.008839},{
      0.433776, 0.024881, 0.008839},{0.433051, 0.025878, 0.006827}}],
    Polygon[{{0.437167, 0.026609, 0.008839},{0.437641, 0.025151, 0.010634},{
      0.434677, 0.023641, 0.010634},{0.433776, 0.024881, 0.008839}}],
    Polygon[{{0.437641, 0.025151, 0.010634},{0.438196, 0.023445, 0.012166},{
      0.435731, 0.022189, 0.012166},{0.434677, 0.023641, 0.010634}}],
    Polygon[{{0.438196, 0.023445, 0.012166},{0.438817, 0.021531, 0.013399},{
      0.436914, 0.020561, 0.013399},{0.435731, 0.022189, 0.012166}}],
    Polygon[{{0.438817, 0.021531, 0.013399},{0.439491, 0.019458, 0.014302},{
      0.438196, 0.018798, 0.014302},{0.436914, 0.020561, 0.013399}}],
    Polygon[{{0.439491, 0.019458, 0.014302},{0.440200, 0.017276, 0.014853},{
      0.439544, 0.016941, 0.014853},{0.438196, 0.018798, 0.014302}}],
    Polygon[{{0.439544, 0.016941, -0.014853},{0.438196, 0.018798, -0.014302},{
      0.437167, 0.017770, -0.014302},{0.439024, 0.016421, -0.014853}}],
    Polygon[{{0.438196, 0.018798, -0.014302},{0.436914, 0.020561, -0.013399},{
      0.435404, 0.019051, -0.013399},{0.437167, 0.017770, -0.014302}}],
    Polygon[{{0.436914, 0.020561, -0.013399},{0.435731, 0.022189, -0.012166},{
      0.433776, 0.020234, -0.012166},{0.435404, 0.019051, -0.013399}}],
    Polygon[{{0.435731, 0.022189, -0.012166},{0.434677, 0.023641, -0.010634},{
      0.432324, 0.021288, -0.010634},{0.433776, 0.020234, -0.012166}}],
    Polygon[{{0.434677, 0.023641, -0.010634},{0.433776, 0.024881, -0.008839},{
      0.431084, 0.022189, -0.008839},{0.432324, 0.021288, -0.010634}}],
    Polygon[{{0.433776, 0.024881, -0.008839},{0.433051, 0.025878, -0.006827},{
      0.430087, 0.022914, -0.006827},{0.431084, 0.022189, -0.008839}}],
    Polygon[{{0.433051, 0.025878, -0.006827},{0.432520, 0.026609, -0.004647},{
      0.429356, 0.023445, -0.004647},{0.430087, 0.022914, -0.006827}}],
    Polygon[{{0.432520, 0.026609, -0.004647},{0.432197, 0.027055, -0.002352},{
      0.428911, 0.023769, -0.002352},{0.429356, 0.023445, -0.004647}}],
    Polygon[{{0.432197, 0.027055, -0.002352},{0.432088, 0.027204, 0.000000},{
      0.428761, 0.023877, 0.000000},{0.428911, 0.023769, -0.002352}}],
    Polygon[{{0.432088, 0.027204, 0.000000},{0.432197, 0.027055, 0.002352},{
      0.428911, 0.023769, 0.002352},{0.428761, 0.023877, 0.000000}}],
    Polygon[{{0.432197, 0.027055, 0.002352},{0.432520, 0.026609, 0.004647},{
      0.429356, 0.023445, 0.004647},{0.428911, 0.023769, 0.002352}}],
    Polygon[{{0.432520, 0.026609, 0.004647},{0.433051, 0.025878, 0.006827},{
      0.430087, 0.022914, 0.006827},{0.429356, 0.023445, 0.004647}}],
    Polygon[{{0.433051, 0.025878, 0.006827},{0.433776, 0.024881, 0.008839},{
      0.431084, 0.022189, 0.008839},{0.430087, 0.022914, 0.006827}}],
    Polygon[{{0.433776, 0.024881, 0.008839},{0.434677, 0.023641, 0.010634},{
      0.432324, 0.021288, 0.010634},{0.431084, 0.022189, 0.008839}}],
    Polygon[{{0.434677, 0.023641, 0.010634},{0.435731, 0.022189, 0.012166},{
      0.433776, 0.020234, 0.012166},{0.432324, 0.021288, 0.010634}}],
    Polygon[{{0.435731, 0.022189, 0.012166},{0.436914, 0.020561, 0.013399},{
      0.435404, 0.019051, 0.013399},{0.433776, 0.020234, 0.012166}}],
    Polygon[{{0.436914, 0.020561, 0.013399},{0.438196, 0.018798, 0.014302},{
      0.437167, 0.017770, 0.014302},{0.435404, 0.019051, 0.013399}}],
    Polygon[{{0.438196, 0.018798, 0.014302},{0.439544, 0.016941, 0.014853},{
      0.439024, 0.016421, 0.014853},{0.437167, 0.017770, 0.014302}}],
    Polygon[{{0.439024, 0.016421, -0.014853},{0.437167, 0.017770, -0.014302},{
      0.436507, 0.016474, -0.014302},{0.438690, 0.015765, -0.014853}}],
    Polygon[{{0.437167, 0.017770, -0.014302},{0.435404, 0.019051, -0.013399},{
      0.434434, 0.017148, -0.013399},{0.436507, 0.016474, -0.014302}}],
    Polygon[{{0.435404, 0.019051, -0.013399},{0.433776, 0.020234, -0.012166},{
      0.432520, 0.017770, -0.012166},{0.434434, 0.017148, -0.013399}}],
    Polygon[{{0.433776, 0.020234, -0.012166},{0.432324, 0.021288, -0.010634},{
      0.430814, 0.018324, -0.010634},{0.432520, 0.017770, -0.012166}}],
    Polygon[{{0.432324, 0.021288, -0.010634},{0.431084, 0.022189, -0.008839},{
      0.429356, 0.018798, -0.008839},{0.430814, 0.018324, -0.010634}}],
    Polygon[{{0.431084, 0.022189, -0.008839},{0.430087, 0.022914, -0.006827},{
      0.428184, 0.019179, -0.006827},{0.429356, 0.018798, -0.008839}}],
    Polygon[{{0.430087, 0.022914, -0.006827},{0.429356, 0.023445, -0.004647},{
      0.427325, 0.019458, -0.004647},{0.428184, 0.019179, -0.006827}}],
    Polygon[{{0.429356, 0.023445, -0.004647},{0.428911, 0.023769, -0.002352},{
      0.426801, 0.019628, -0.002352},{0.427325, 0.019458, -0.004647}}],
    Polygon[{{0.428911, 0.023769, -0.002352},{0.428761, 0.023877, 0.000000},{
      0.426625, 0.019685, 0.000000},{0.426801, 0.019628, -0.002352}}],
    Polygon[{{0.428761, 0.023877, 0.000000},{0.428911, 0.023769, 0.002352},{
      0.426801, 0.019628, 0.002352},{0.426625, 0.019685, 0.000000}}],
    Polygon[{{0.428911, 0.023769, 0.002352},{0.429356, 0.023445, 0.004647},{
      0.427325, 0.019458, 0.004647},{0.426801, 0.019628, 0.002352}}],
    Polygon[{{0.429356, 0.023445, 0.004647},{0.430087, 0.022914, 0.006827},{
      0.428184, 0.019179, 0.006827},{0.427325, 0.019458, 0.004647}}],
    Polygon[{{0.430087, 0.022914, 0.006827},{0.431084, 0.022189, 0.008839},{
      0.429356, 0.018798, 0.008839},{0.428184, 0.019179, 0.006827}}],
    Polygon[{{0.431084, 0.022189, 0.008839},{0.432324, 0.021288, 0.010634},{
      0.430814, 0.018324, 0.010634},{0.429356, 0.018798, 0.008839}}],
    Polygon[{{0.432324, 0.021288, 0.010634},{0.433776, 0.020234, 0.012166},{
      0.432520, 0.017770, 0.012166},{0.430814, 0.018324, 0.010634}}],
    Polygon[{{0.433776, 0.020234, 0.012166},{0.435404, 0.019051, 0.013399},{
      0.434434, 0.017148, 0.013399},{0.432520, 0.017770, 0.012166}}],
    Polygon[{{0.435404, 0.019051, 0.013399},{0.437167, 0.017770, 0.014302},{
      0.436507, 0.016474, 0.014302},{0.434434, 0.017148, 0.013399}}],
    Polygon[{{0.437167, 0.017770, 0.014302},{0.439024, 0.016421, 0.014853},{
      0.438690, 0.015765, 0.014853},{0.436507, 0.016474, 0.014302}}],
    Polygon[{{0.438690, 0.015765, -0.014853},{0.436507, 0.016474, -0.014302},{
      0.436280, 0.015038, -0.014302},{0.438574, 0.015038, -0.014853}}],
    Polygon[{{0.436507, 0.016474, -0.014302},{0.434434, 0.017148, -0.013399},{
      0.434100, 0.015038, -0.013399},{0.436280, 0.015038, -0.014302}}],
    Polygon[{{0.434434, 0.017148, -0.013399},{0.432520, 0.017770, -0.012166},{
      0.432088, 0.015038, -0.012166},{0.434100, 0.015038, -0.013399}}],
    Polygon[{{0.432520, 0.017770, -0.012166},{0.430814, 0.018324, -0.010634},{
      0.430293, 0.015038, -0.010634},{0.432088, 0.015038, -0.012166}}],
    Polygon[{{0.430814, 0.018324, -0.010634},{0.429356, 0.018798, -0.008839},{
      0.428761, 0.015038, -0.008839},{0.430293, 0.015038, -0.010634}}],
    Polygon[{{0.429356, 0.018798, -0.008839},{0.428184, 0.019179, -0.006827},{
      0.427528, 0.015038, -0.006827},{0.428761, 0.015038, -0.008839}}],
    Polygon[{{0.428184, 0.019179, -0.006827},{0.427325, 0.019458, -0.004647},{
      0.426625, 0.015038, -0.004647},{0.427528, 0.015038, -0.006827}}],
    Polygon[{{0.427325, 0.019458, -0.004647},{0.426801, 0.019628, -0.002352},{
      0.426074, 0.015038, -0.002352},{0.426625, 0.015038, -0.004647}}],
    Polygon[{{0.426801, 0.019628, -0.002352},{0.426625, 0.019685, 0.000000},{
      0.425889, 0.015038, 0.000000},{0.426074, 0.015038, -0.002352}}],
    Polygon[{{0.426625, 0.019685, 0.000000},{0.426801, 0.019628, 0.002352},{
      0.426074, 0.015038, 0.002352},{0.425889, 0.015038, 0.000000}}],
    Polygon[{{0.426801, 0.019628, 0.002352},{0.427325, 0.019458, 0.004647},{
      0.426625, 0.015038, 0.004647},{0.426074, 0.015038, 0.002352}}],
    Polygon[{{0.427325, 0.019458, 0.004647},{0.428184, 0.019179, 0.006827},{
      0.427528, 0.015038, 0.006827},{0.426625, 0.015038, 0.004647}}],
    Polygon[{{0.428184, 0.019179, 0.006827},{0.429356, 0.018798, 0.008839},{
      0.428761, 0.015038, 0.008839},{0.427528, 0.015038, 0.006827}}],
    Polygon[{{0.429356, 0.018798, 0.008839},{0.430814, 0.018324, 0.010634},{
      0.430293, 0.015038, 0.010634},{0.428761, 0.015038, 0.008839}}],
    Polygon[{{0.430814, 0.018324, 0.010634},{0.432520, 0.017770, 0.012166},{
      0.432088, 0.015038, 0.012166},{0.430293, 0.015038, 0.010634}}],
    Polygon[{{0.432520, 0.017770, 0.012166},{0.434434, 0.017148, 0.013399},{
      0.434100, 0.015038, 0.013399},{0.432088, 0.015038, 0.012166}}],
    Polygon[{{0.434434, 0.017148, 0.013399},{0.436507, 0.016474, 0.014302},{
      0.436280, 0.015038, 0.014302},{0.434100, 0.015038, 0.013399}}],
    Polygon[{{0.436507, 0.016474, 0.014302},{0.438690, 0.015765, 0.014853},{
      0.438574, 0.015038, 0.014853},{0.436280, 0.015038, 0.014302}}],
    Polygon[{{0.438574, 0.015038, -0.014853},{0.436280, 0.015038, -0.014302},{
      0.436507, 0.013602, -0.014302},{0.438690, 0.014311, -0.014853}}],
    Polygon[{{0.436280, 0.015038, -0.014302},{0.434100, 0.015038, -0.013399},{
      0.434434, 0.012928, -0.013399},{0.436507, 0.013602, -0.014302}}],
    Polygon[{{0.434100, 0.015038, -0.013399},{0.432088, 0.015038, -0.012166},{
      0.432520, 0.012307, -0.012166},{0.434434, 0.012928, -0.013399}}],
    Polygon[{{0.432088, 0.015038, -0.012166},{0.430293, 0.015038, -0.010634},{
      0.430814, 0.011752, -0.010634},{0.432520, 0.012307, -0.012166}}],
    Polygon[{{0.430293, 0.015038, -0.010634},{0.428761, 0.015038, -0.008839},{
      0.429356, 0.011279, -0.008839},{0.430814, 0.011752, -0.010634}}],
    Polygon[{{0.428761, 0.015038, -0.008839},{0.427528, 0.015038, -0.006827},{
      0.428184, 0.010898, -0.006827},{0.429356, 0.011279, -0.008839}}],
    Polygon[{{0.427528, 0.015038, -0.006827},{0.426625, 0.015038, -0.004647},{
      0.427325, 0.010619, -0.004647},{0.428184, 0.010898, -0.006827}}],
    Polygon[{{0.426625, 0.015038, -0.004647},{0.426074, 0.015038, -0.002352},{
      0.426801, 0.010448, -0.002352},{0.427325, 0.010619, -0.004647}}],
    Polygon[{{0.426074, 0.015038, -0.002352},{0.425889, 0.015038, 0.000000},{
      0.426625, 0.010391, 0.000000},{0.426801, 0.010448, -0.002352}}],
    Polygon[{{0.425889, 0.015038, 0.000000},{0.426074, 0.015038, 0.002352},{
      0.426801, 0.010448, 0.002352},{0.426625, 0.010391, 0.000000}}],
    Polygon[{{0.426074, 0.015038, 0.002352},{0.426625, 0.015038, 0.004647},{
      0.427325, 0.010619, 0.004647},{0.426801, 0.010448, 0.002352}}],
    Polygon[{{0.426625, 0.015038, 0.004647},{0.427528, 0.015038, 0.006827},{
      0.428184, 0.010898, 0.006827},{0.427325, 0.010619, 0.004647}}],
    Polygon[{{0.427528, 0.015038, 0.006827},{0.428761, 0.015038, 0.008839},{
      0.429356, 0.011279, 0.008839},{0.428184, 0.010898, 0.006827}}],
    Polygon[{{0.428761, 0.015038, 0.008839},{0.430293, 0.015038, 0.010634},{
      0.430814, 0.011752, 0.010634},{0.429356, 0.011279, 0.008839}}],
    Polygon[{{0.430293, 0.015038, 0.010634},{0.432088, 0.015038, 0.012166},{
      0.432520, 0.012307, 0.012166},{0.430814, 0.011752, 0.010634}}],
    Polygon[{{0.432088, 0.015038, 0.012166},{0.434100, 0.015038, 0.013399},{
      0.434434, 0.012928, 0.013399},{0.432520, 0.012307, 0.012166}}],
    Polygon[{{0.434100, 0.015038, 0.013399},{0.436280, 0.015038, 0.014302},{
      0.436507, 0.013602, 0.014302},{0.434434, 0.012928, 0.013399}}],
    Polygon[{{0.436280, 0.015038, 0.014302},{0.438574, 0.015038, 0.014853},{
      0.438690, 0.014311, 0.014853},{0.436507, 0.013602, 0.014302}}],
    Polygon[{{0.438690, 0.014311, -0.014853},{0.436507, 0.013602, -0.014302},{
      0.437167, 0.012307, -0.014302},{0.439024, 0.013655, -0.014853}}],
    Polygon[{{0.436507, 0.013602, -0.014302},{0.434434, 0.012928, -0.013399},{
      0.435404, 0.011025, -0.013399},{0.437167, 0.012307, -0.014302}}],
    Polygon[{{0.434434, 0.012928, -0.013399},{0.432520, 0.012307, -0.012166},{
      0.433776, 0.009843, -0.012166},{0.435404, 0.011025, -0.013399}}],
    Polygon[{{0.432520, 0.012307, -0.012166},{0.430814, 0.011752, -0.010634},{
      0.432324, 0.008788, -0.010634},{0.433776, 0.009843, -0.012166}}],
    Polygon[{{0.430814, 0.011752, -0.010634},{0.429356, 0.011279, -0.008839},{
      0.431084, 0.007887, -0.008839},{0.432324, 0.008788, -0.010634}}],
    Polygon[{{0.429356, 0.011279, -0.008839},{0.428184, 0.010898, -0.006827},{
      0.430087, 0.007162, -0.006827},{0.431084, 0.007887, -0.008839}}],
    Polygon[{{0.428184, 0.010898, -0.006827},{0.427325, 0.010619, -0.004647},{
      0.429356, 0.006632, -0.004647},{0.430087, 0.007162, -0.006827}}],
    Polygon[{{0.427325, 0.010619, -0.004647},{0.426801, 0.010448, -0.002352},{
      0.428911, 0.006308, -0.002352},{0.429356, 0.006632, -0.004647}}],
    Polygon[{{0.426801, 0.010448, -0.002352},{0.426625, 0.010391, 0.000000},{
      0.428761, 0.006199, 0.000000},{0.428911, 0.006308, -0.002352}}],
    Polygon[{{0.426625, 0.010391, 0.000000},{0.426801, 0.010448, 0.002352},{
      0.428911, 0.006308, 0.002352},{0.428761, 0.006199, 0.000000}}],
    Polygon[{{0.426801, 0.010448, 0.002352},{0.427325, 0.010619, 0.004647},{
      0.429356, 0.006632, 0.004647},{0.428911, 0.006308, 0.002352}}],
    Polygon[{{0.427325, 0.010619, 0.004647},{0.428184, 0.010898, 0.006827},{
      0.430087, 0.007162, 0.006827},{0.429356, 0.006632, 0.004647}}],
    Polygon[{{0.428184, 0.010898, 0.006827},{0.429356, 0.011279, 0.008839},{
      0.431084, 0.007887, 0.008839},{0.430087, 0.007162, 0.006827}}],
    Polygon[{{0.429356, 0.011279, 0.008839},{0.430814, 0.011752, 0.010634},{
      0.432324, 0.008788, 0.010634},{0.431084, 0.007887, 0.008839}}],
    Polygon[{{0.430814, 0.011752, 0.010634},{0.432520, 0.012307, 0.012166},{
      0.433776, 0.009843, 0.012166},{0.432324, 0.008788, 0.010634}}],
    Polygon[{{0.432520, 0.012307, 0.012166},{0.434434, 0.012928, 0.013399},{
      0.435404, 0.011025, 0.013399},{0.433776, 0.009843, 0.012166}}],
    Polygon[{{0.434434, 0.012928, 0.013399},{0.436507, 0.013602, 0.014302},{
      0.437167, 0.012307, 0.014302},{0.435404, 0.011025, 0.013399}}],
    Polygon[{{0.436507, 0.013602, 0.014302},{0.438690, 0.014311, 0.014853},{
      0.439024, 0.013655, 0.014853},{0.437167, 0.012307, 0.014302}}],
    Polygon[{{0.439024, 0.013655, -0.014853},{0.437167, 0.012307, -0.014302},{
      0.438196, 0.011279, -0.014302},{0.439544, 0.013135, -0.014853}}],
    Polygon[{{0.437167, 0.012307, -0.014302},{0.435404, 0.011025, -0.013399},{
      0.436914, 0.009515, -0.013399},{0.438196, 0.011279, -0.014302}}],
    Polygon[{{0.435404, 0.011025, -0.013399},{0.433776, 0.009843, -0.012166},{
      0.435731, 0.007887, -0.012166},{0.436914, 0.009515, -0.013399}}],
    Polygon[{{0.433776, 0.009843, -0.012166},{0.432324, 0.008788, -0.010634},{
      0.434677, 0.006435, -0.010634},{0.435731, 0.007887, -0.012166}}],
    Polygon[{{0.432324, 0.008788, -0.010634},{0.431084, 0.007887, -0.008839},{
      0.433776, 0.005196, -0.008839},{0.434677, 0.006435, -0.010634}}],
    Polygon[{{0.431084, 0.007887, -0.008839},{0.430087, 0.007162, -0.006827},{
      0.433051, 0.004198, -0.006827},{0.433776, 0.005196, -0.008839}}],
    Polygon[{{0.430087, 0.007162, -0.006827},{0.429356, 0.006632, -0.004647},{
      0.432520, 0.003467, -0.004647},{0.433051, 0.004198, -0.006827}}],
    Polygon[{{0.429356, 0.006632, -0.004647},{0.428911, 0.006308, -0.002352},{
      0.432197, 0.003022, -0.002352},{0.432520, 0.003467, -0.004647}}],
    Polygon[{{0.428911, 0.006308, -0.002352},{0.428761, 0.006199, 0.000000},{
      0.432088, 0.002872, 0.000000},{0.432197, 0.003022, -0.002352}}],
    Polygon[{{0.428761, 0.006199, 0.000000},{0.428911, 0.006308, 0.002352},{
      0.432197, 0.003022, 0.002352},{0.432088, 0.002872, 0.000000}}],
    Polygon[{{0.428911, 0.006308, 0.002352},{0.429356, 0.006632, 0.004647},{
      0.432520, 0.003467, 0.004647},{0.432197, 0.003022, 0.002352}}],
    Polygon[{{0.429356, 0.006632, 0.004647},{0.430087, 0.007162, 0.006827},{
      0.433051, 0.004198, 0.006827},{0.432520, 0.003467, 0.004647}}],
    Polygon[{{0.430087, 0.007162, 0.006827},{0.431084, 0.007887, 0.008839},{
      0.433776, 0.005196, 0.008839},{0.433051, 0.004198, 0.006827}}],
    Polygon[{{0.431084, 0.007887, 0.008839},{0.432324, 0.008788, 0.010634},{
      0.434677, 0.006435, 0.010634},{0.433776, 0.005196, 0.008839}}],
    Polygon[{{0.432324, 0.008788, 0.010634},{0.433776, 0.009843, 0.012166},{
      0.435731, 0.007887, 0.012166},{0.434677, 0.006435, 0.010634}}],
    Polygon[{{0.433776, 0.009843, 0.012166},{0.435404, 0.011025, 0.013399},{
      0.436914, 0.009515, 0.013399},{0.435731, 0.007887, 0.012166}}],
    Polygon[{{0.435404, 0.011025, 0.013399},{0.437167, 0.012307, 0.014302},{
      0.438196, 0.011279, 0.014302},{0.436914, 0.009515, 0.013399}}],
    Polygon[{{0.437167, 0.012307, 0.014302},{0.439024, 0.013655, 0.014853},{
      0.439544, 0.013135, 0.014853},{0.438196, 0.011279, 0.014302}}],
    Polygon[{{0.439544, 0.013135, -0.014853},{0.438196, 0.011279, -0.014302},{
      0.439491, 0.010619, -0.014302},{0.440200, 0.012801, -0.014853}}],
    Polygon[{{0.438196, 0.011279, -0.014302},{0.436914, 0.009515, -0.013399},{
      0.438817, 0.008545, -0.013399},{0.439491, 0.010619, -0.014302}}],
    Polygon[{{0.436914, 0.009515, -0.013399},{0.435731, 0.007887, -0.012166},{
      0.438196, 0.006632, -0.012166},{0.438817, 0.008545, -0.013399}}],
    Polygon[{{0.435731, 0.007887, -0.012166},{0.434677, 0.006435, -0.010634},{
      0.437641, 0.004925, -0.010634},{0.438196, 0.006632, -0.012166}}],
    Polygon[{{0.434677, 0.006435, -0.010634},{0.433776, 0.005196, -0.008839},{
      0.437167, 0.003467, -0.008839},{0.437641, 0.004925, -0.010634}}],
    Polygon[{{0.433776, 0.005196, -0.008839},{0.433051, 0.004198, -0.006827},{
      0.436786, 0.002295, -0.006827},{0.437167, 0.003467, -0.008839}}],
    Polygon[{{0.433051, 0.004198, -0.006827},{0.432520, 0.003467, -0.004647},{
      0.436507, 0.001436, -0.004647},{0.436786, 0.002295, -0.006827}}],
    Polygon[{{0.432520, 0.003467, -0.004647},{0.432197, 0.003022, -0.002352},{
      0.436337, 0.000912, -0.002352},{0.436507, 0.001436, -0.004647}}],
    Polygon[{{0.432197, 0.003022, -0.002352},{0.432088, 0.002872, 0.000000},{
      0.436280, 0.000736, 0.000000},{0.436337, 0.000912, -0.002352}}],
    Polygon[{{0.432088, 0.002872, 0.000000},{0.432197, 0.003022, 0.002352},{
      0.436337, 0.000912, 0.002352},{0.436280, 0.000736, 0.000000}}],
    Polygon[{{0.432197, 0.003022, 0.002352},{0.432520, 0.003467, 0.004647},{
      0.436507, 0.001436, 0.004647},{0.436337, 0.000912, 0.002352}}],
    Polygon[{{0.432520, 0.003467, 0.004647},{0.433051, 0.004198, 0.006827},{
      0.436786, 0.002295, 0.006827},{0.436507, 0.001436, 0.004647}}],
    Polygon[{{0.433051, 0.004198, 0.006827},{0.433776, 0.005196, 0.008839},{
      0.437167, 0.003467, 0.008839},{0.436786, 0.002295, 0.006827}}],
    Polygon[{{0.433776, 0.005196, 0.008839},{0.434677, 0.006435, 0.010634},{
      0.437641, 0.004925, 0.010634},{0.437167, 0.003467, 0.008839}}],
    Polygon[{{0.434677, 0.006435, 0.010634},{0.435731, 0.007887, 0.012166},{
      0.438196, 0.006632, 0.012166},{0.437641, 0.004925, 0.010634}}],
    Polygon[{{0.435731, 0.007887, 0.012166},{0.436914, 0.009515, 0.013399},{
      0.438817, 0.008545, 0.013399},{0.438196, 0.006632, 0.012166}}],
    Polygon[{{0.436914, 0.009515, 0.013399},{0.438196, 0.011279, 0.014302},{
      0.439491, 0.010619, 0.014302},{0.438817, 0.008545, 0.013399}}],
    Polygon[{{0.438196, 0.011279, 0.014302},{0.439544, 0.013135, 0.014853},{
      0.440200, 0.012801, 0.014853},{0.439491, 0.010619, 0.014302}}],
    Polygon[{{0.440200, 0.012801, -0.014853},{0.439491, 0.010619, -0.014302},{
      0.440927, 0.010391, -0.014302},{0.440927, 0.012686, -0.014853}}],
    Polygon[{{0.439491, 0.010619, -0.014302},{0.438817, 0.008545, -0.013399},{
      0.440927, 0.008211, -0.013399},{0.440927, 0.010391, -0.014302}}],
    Polygon[{{0.438817, 0.008545, -0.013399},{0.438196, 0.006632, -0.012166},{
      0.440927, 0.006199, -0.012166},{0.440927, 0.008211, -0.013399}}],
    Polygon[{{0.438196, 0.006632, -0.012166},{0.437641, 0.004925, -0.010634},{
      0.440927, 0.004405, -0.010634},{0.440927, 0.006199, -0.012166}}],
    Polygon[{{0.437641, 0.004925, -0.010634},{0.437167, 0.003467, -0.008839},{
      0.440927, 0.002872, -0.008839},{0.440927, 0.004405, -0.010634}}],
    Polygon[{{0.437167, 0.003467, -0.008839},{0.436786, 0.002295, -0.006827},{
      0.440927, 0.001639, -0.006827},{0.440927, 0.002872, -0.008839}}],
    Polygon[{{0.436786, 0.002295, -0.006827},{0.436507, 0.001436, -0.004647},{
      0.440927, 0.000736, -0.004647},{0.440927, 0.001639, -0.006827}}],
    Polygon[{{0.436507, 0.001436, -0.004647},{0.436337, 0.000912, -0.002352},{
      0.440927, 0.000185, -0.002352},{0.440927, 0.000736, -0.004647}}],
    Polygon[{{0.436337, 0.000912, -0.002352},{0.436280, 0.000736, 0.000000},{
      0.440927, 0.000000, 0.000000},{0.440927, 0.000185, -0.002352}}],
    Polygon[{{0.436280, 0.000736, 0.000000},{0.436337, 0.000912, 0.002352},{
      0.440927, 0.000185, 0.002352},{0.440927, 0.000000, 0.000000}}],
    Polygon[{{0.436337, 0.000912, 0.002352},{0.436507, 0.001436, 0.004647},{
      0.440927, 0.000736, 0.004647},{0.440927, 0.000185, 0.002352}}],
    Polygon[{{0.436507, 0.001436, 0.004647},{0.436786, 0.002295, 0.006827},{
      0.440927, 0.001639, 0.006827},{0.440927, 0.000736, 0.004647}}],
    Polygon[{{0.436786, 0.002295, 0.006827},{0.437167, 0.003467, 0.008839},{
      0.440927, 0.002872, 0.008839},{0.440927, 0.001639, 0.006827}}],
    Polygon[{{0.437167, 0.003467, 0.008839},{0.437641, 0.004925, 0.010634},{
      0.440927, 0.004405, 0.010634},{0.440927, 0.002872, 0.008839}}],
    Polygon[{{0.437641, 0.004925, 0.010634},{0.438196, 0.006632, 0.012166},{
      0.440927, 0.006199, 0.012166},{0.440927, 0.004405, 0.010634}}],
    Polygon[{{0.438196, 0.006632, 0.012166},{0.438817, 0.008545, 0.013399},{
      0.440927, 0.008211, 0.013399},{0.440927, 0.006199, 0.012166}}],
    Polygon[{{0.438817, 0.008545, 0.013399},{0.439491, 0.010619, 0.014302},{
      0.440927, 0.010391, 0.014302},{0.440927, 0.008211, 0.013399}}],
    Polygon[{{0.439491, 0.010619, 0.014302},{0.440200, 0.012801, 0.014853},{
      0.440927, 0.012686, 0.014853},{0.440927, 0.010391, 0.014302}}],
    Polygon[{{0.440927, 0.012686, -0.014853},{0.440927, 0.010391, -0.014302},{
      0.442363, 0.010619, -0.014302},{0.441654, 0.012801, -0.014853}}],
    Polygon[{{0.440927, 0.010391, -0.014302},{0.440927, 0.008211, -0.013399},{
      0.443037, 0.008545, -0.013399},{0.442363, 0.010619, -0.014302}}],
    Polygon[{{0.440927, 0.008211, -0.013399},{0.440927, 0.006199, -0.012166},{
      0.443658, 0.006632, -0.012166},{0.443037, 0.008545, -0.013399}}],
    Polygon[{{0.440927, 0.006199, -0.012166},{0.440927, 0.004405, -0.010634},{
      0.444213, 0.004925, -0.010634},{0.443658, 0.006632, -0.012166}}],
    Polygon[{{0.440927, 0.004405, -0.010634},{0.440927, 0.002872, -0.008839},{
      0.444687, 0.003467, -0.008839},{0.444213, 0.004925, -0.010634}}],
    Polygon[{{0.440927, 0.002872, -0.008839},{0.440927, 0.001639, -0.006827},{
      0.445068, 0.002295, -0.006827},{0.444687, 0.003467, -0.008839}}],
    Polygon[{{0.440927, 0.001639, -0.006827},{0.440927, 0.000736, -0.004647},{
      0.445347, 0.001436, -0.004647},{0.445068, 0.002295, -0.006827}}],
    Polygon[{{0.440927, 0.000736, -0.004647},{0.440927, 0.000185, -0.002352},{
      0.445517, 0.000912, -0.002352},{0.445347, 0.001436, -0.004647}}],
    Polygon[{{0.440927, 0.000185, -0.002352},{0.440927, 0.000000, 0.000000},{
      0.445574, 0.000736, 0.000000},{0.445517, 0.000912, -0.002352}}],
    Polygon[{{0.440927, 0.000000, 0.000000},{0.440927, 0.000185, 0.002352},{
      0.445517, 0.000912, 0.002352},{0.445574, 0.000736, 0.000000}}],
    Polygon[{{0.440927, 0.000185, 0.002352},{0.440927, 0.000736, 0.004647},{
      0.445347, 0.001436, 0.004647},{0.445517, 0.000912, 0.002352}}],
    Polygon[{{0.440927, 0.000736, 0.004647},{0.440927, 0.001639, 0.006827},{
      0.445068, 0.002295, 0.006827},{0.445347, 0.001436, 0.004647}}],
    Polygon[{{0.440927, 0.001639, 0.006827},{0.440927, 0.002872, 0.008839},{
      0.444687, 0.003467, 0.008839},{0.445068, 0.002295, 0.006827}}],
    Polygon[{{0.440927, 0.002872, 0.008839},{0.440927, 0.004405, 0.010634},{
      0.444213, 0.004925, 0.010634},{0.444687, 0.003467, 0.008839}}],
    Polygon[{{0.440927, 0.004405, 0.010634},{0.440927, 0.006199, 0.012166},{
      0.443658, 0.006632, 0.012166},{0.444213, 0.004925, 0.010634}}],
    Polygon[{{0.440927, 0.006199, 0.012166},{0.440927, 0.008211, 0.013399},{
      0.443037, 0.008545, 0.013399},{0.443658, 0.006632, 0.012166}}],
    Polygon[{{0.440927, 0.008211, 0.013399},{0.440927, 0.010391, 0.014302},{
      0.442363, 0.010619, 0.014302},{0.443037, 0.008545, 0.013399}}],
    Polygon[{{0.440927, 0.010391, 0.014302},{0.440927, 0.012686, 0.014853},{
      0.441654, 0.012801, 0.014853},{0.442363, 0.010619, 0.014302}}],
    Polygon[{{0.441654, 0.012801, -0.014853},{0.442363, 0.010619, -0.014302},{
      0.443658, 0.011279, -0.014302},{0.442310, 0.013135, -0.014853}}],
    Polygon[{{0.442363, 0.010619, -0.014302},{0.443037, 0.008545, -0.013399},{
      0.444940, 0.009515, -0.013399},{0.443658, 0.011279, -0.014302}}],
    Polygon[{{0.443037, 0.008545, -0.013399},{0.443658, 0.006632, -0.012166},{
      0.446123, 0.007887, -0.012166},{0.444940, 0.009515, -0.013399}}],
    Polygon[{{0.443658, 0.006632, -0.012166},{0.444213, 0.004925, -0.010634},{
      0.447177, 0.006435, -0.010634},{0.446123, 0.007887, -0.012166}}],
    Polygon[{{0.444213, 0.004925, -0.010634},{0.444687, 0.003467, -0.008839},{
      0.448078, 0.005196, -0.008839},{0.447177, 0.006435, -0.010634}}],
    Polygon[{{0.444687, 0.003467, -0.008839},{0.445068, 0.002295, -0.006827},{
      0.448803, 0.004198, -0.006827},{0.448078, 0.005196, -0.008839}}],
    Polygon[{{0.445068, 0.002295, -0.006827},{0.445347, 0.001436, -0.004647},{
      0.449334, 0.003467, -0.004647},{0.448803, 0.004198, -0.006827}}],
    Polygon[{{0.445347, 0.001436, -0.004647},{0.445517, 0.000912, -0.002352},{
      0.449657, 0.003022, -0.002352},{0.449334, 0.003467, -0.004647}}],
    Polygon[{{0.445517, 0.000912, -0.002352},{0.445574, 0.000736, 0.000000},{
      0.449766, 0.002872, 0.000000},{0.449657, 0.003022, -0.002352}}],
    Polygon[{{0.445574, 0.000736, 0.000000},{0.445517, 0.000912, 0.002352},{
      0.449657, 0.003022, 0.002352},{0.449766, 0.002872, 0.000000}}],
    Polygon[{{0.445517, 0.000912, 0.002352},{0.445347, 0.001436, 0.004647},{
      0.449334, 0.003467, 0.004647},{0.449657, 0.003022, 0.002352}}],
    Polygon[{{0.445347, 0.001436, 0.004647},{0.445068, 0.002295, 0.006827},{
      0.448803, 0.004198, 0.006827},{0.449334, 0.003467, 0.004647}}],
    Polygon[{{0.445068, 0.002295, 0.006827},{0.444687, 0.003467, 0.008839},{
      0.448078, 0.005196, 0.008839},{0.448803, 0.004198, 0.006827}}],
    Polygon[{{0.444687, 0.003467, 0.008839},{0.444213, 0.004925, 0.010634},{
      0.447177, 0.006435, 0.010634},{0.448078, 0.005196, 0.008839}}],
    Polygon[{{0.444213, 0.004925, 0.010634},{0.443658, 0.006632, 0.012166},{
      0.446123, 0.007887, 0.012166},{0.447177, 0.006435, 0.010634}}],
    Polygon[{{0.443658, 0.006632, 0.012166},{0.443037, 0.008545, 0.013399},{
      0.444940, 0.009515, 0.013399},{0.446123, 0.007887, 0.012166}}],
    Polygon[{{0.443037, 0.008545, 0.013399},{0.442363, 0.010619, 0.014302},{
      0.443658, 0.011279, 0.014302},{0.444940, 0.009515, 0.013399}}],
    Polygon[{{0.442363, 0.010619, 0.014302},{0.441654, 0.012801, 0.014853},{
      0.442310, 0.013135, 0.014853},{0.443658, 0.011279, 0.014302}}],
    Polygon[{{0.442310, 0.013135, -0.014853},{0.443658, 0.011279, -0.014302},{
      0.444687, 0.012307, -0.014302},{0.442830, 0.013655, -0.014853}}],
    Polygon[{{0.443658, 0.011279, -0.014302},{0.444940, 0.009515, -0.013399},{
      0.446450, 0.011025, -0.013399},{0.444687, 0.012307, -0.014302}}],
    Polygon[{{0.444940, 0.009515, -0.013399},{0.446123, 0.007887, -0.012166},{
      0.448078, 0.009843, -0.012166},{0.446450, 0.011025, -0.013399}}],
    Polygon[{{0.446123, 0.007887, -0.012166},{0.447177, 0.006435, -0.010634},{
      0.449530, 0.008788, -0.010634},{0.448078, 0.009843, -0.012166}}],
    Polygon[{{0.447177, 0.006435, -0.010634},{0.448078, 0.005196, -0.008839},{
      0.450770, 0.007887, -0.008839},{0.449530, 0.008788, -0.010634}}],
    Polygon[{{0.448078, 0.005196, -0.008839},{0.448803, 0.004198, -0.006827},{
      0.451767, 0.007162, -0.006827},{0.450770, 0.007887, -0.008839}}],
    Polygon[{{0.448803, 0.004198, -0.006827},{0.449334, 0.003467, -0.004647},{
      0.452498, 0.006632, -0.004647},{0.451767, 0.007162, -0.006827}}],
    Polygon[{{0.449334, 0.003467, -0.004647},{0.449657, 0.003022, -0.002352},{
      0.452943, 0.006308, -0.002352},{0.452498, 0.006632, -0.004647}}],
    Polygon[{{0.449657, 0.003022, -0.002352},{0.449766, 0.002872, 0.000000},{
      0.453093, 0.006199, 0.000000},{0.452943, 0.006308, -0.002352}}],
    Polygon[{{0.449766, 0.002872, 0.000000},{0.449657, 0.003022, 0.002352},{
      0.452943, 0.006308, 0.002352},{0.453093, 0.006199, 0.000000}}],
    Polygon[{{0.449657, 0.003022, 0.002352},{0.449334, 0.003467, 0.004647},{
      0.452498, 0.006632, 0.004647},{0.452943, 0.006308, 0.002352}}],
    Polygon[{{0.449334, 0.003467, 0.004647},{0.448803, 0.004198, 0.006827},{
      0.451767, 0.007162, 0.006827},{0.452498, 0.006632, 0.004647}}],
    Polygon[{{0.448803, 0.004198, 0.006827},{0.448078, 0.005196, 0.008839},{
      0.450770, 0.007887, 0.008839},{0.451767, 0.007162, 0.006827}}],
    Polygon[{{0.448078, 0.005196, 0.008839},{0.447177, 0.006435, 0.010634},{
      0.449530, 0.008788, 0.010634},{0.450770, 0.007887, 0.008839}}],
    Polygon[{{0.447177, 0.006435, 0.010634},{0.446123, 0.007887, 0.012166},{
      0.448078, 0.009843, 0.012166},{0.449530, 0.008788, 0.010634}}],
    Polygon[{{0.446123, 0.007887, 0.012166},{0.444940, 0.009515, 0.013399},{
      0.446450, 0.011025, 0.013399},{0.448078, 0.009843, 0.012166}}],
    Polygon[{{0.444940, 0.009515, 0.013399},{0.443658, 0.011279, 0.014302},{
      0.444687, 0.012307, 0.014302},{0.446450, 0.011025, 0.013399}}],
    Polygon[{{0.443658, 0.011279, 0.014302},{0.442310, 0.013135, 0.014853},{
      0.442830, 0.013655, 0.014853},{0.444687, 0.012307, 0.014302}}],
    Polygon[{{0.442830, 0.013655, -0.014853},{0.444687, 0.012307, -0.014302},{
      0.445347, 0.013602, -0.014302},{0.443164, 0.014311, -0.014853}}],
    Polygon[{{0.444687, 0.012307, -0.014302},{0.446450, 0.011025, -0.013399},{
      0.447420, 0.012928, -0.013399},{0.445347, 0.013602, -0.014302}}],
    Polygon[{{0.446450, 0.011025, -0.013399},{0.448078, 0.009843, -0.012166},{
      0.449334, 0.012307, -0.012166},{0.447420, 0.012928, -0.013399}}],
    Polygon[{{0.448078, 0.009843, -0.012166},{0.449530, 0.008788, -0.010634},{
      0.451040, 0.011752, -0.010634},{0.449334, 0.012307, -0.012166}}],
    Polygon[{{0.449530, 0.008788, -0.010634},{0.450770, 0.007887, -0.008839},{
      0.452498, 0.011279, -0.008839},{0.451040, 0.011752, -0.010634}}],
    Polygon[{{0.450770, 0.007887, -0.008839},{0.451767, 0.007162, -0.006827},{
      0.453670, 0.010898, -0.006827},{0.452498, 0.011279, -0.008839}}],
    Polygon[{{0.451767, 0.007162, -0.006827},{0.452498, 0.006632, -0.004647},{
      0.454529, 0.010619, -0.004647},{0.453670, 0.010898, -0.006827}}],
    Polygon[{{0.452498, 0.006632, -0.004647},{0.452943, 0.006308, -0.002352},{
      0.455053, 0.010448, -0.002352},{0.454529, 0.010619, -0.004647}}],
    Polygon[{{0.452943, 0.006308, -0.002352},{0.453093, 0.006199, 0.000000},{
      0.455229, 0.010391, 0.000000},{0.455053, 0.010448, -0.002352}}],
    Polygon[{{0.453093, 0.006199, 0.000000},{0.452943, 0.006308, 0.002352},{
      0.455053, 0.010448, 0.002352},{0.455229, 0.010391, 0.000000}}],
    Polygon[{{0.452943, 0.006308, 0.002352},{0.452498, 0.006632, 0.004647},{
      0.454529, 0.010619, 0.004647},{0.455053, 0.010448, 0.002352}}],
    Polygon[{{0.452498, 0.006632, 0.004647},{0.451767, 0.007162, 0.006827},{
      0.453670, 0.010898, 0.006827},{0.454529, 0.010619, 0.004647}}],
    Polygon[{{0.451767, 0.007162, 0.006827},{0.450770, 0.007887, 0.008839},{
      0.452498, 0.011279, 0.008839},{0.453670, 0.010898, 0.006827}}],
    Polygon[{{0.450770, 0.007887, 0.008839},{0.449530, 0.008788, 0.010634},{
      0.451040, 0.011752, 0.010634},{0.452498, 0.011279, 0.008839}}],
    Polygon[{{0.449530, 0.008788, 0.010634},{0.448078, 0.009843, 0.012166},{
      0.449334, 0.012307, 0.012166},{0.451040, 0.011752, 0.010634}}],
    Polygon[{{0.448078, 0.009843, 0.012166},{0.446450, 0.011025, 0.013399},{
      0.447420, 0.012928, 0.013399},{0.449334, 0.012307, 0.012166}}],
    Polygon[{{0.446450, 0.011025, 0.013399},{0.444687, 0.012307, 0.014302},{
      0.445347, 0.013602, 0.014302},{0.447420, 0.012928, 0.013399}}],
    Polygon[{{0.444687, 0.012307, 0.014302},{0.442830, 0.013655, 0.014853},{
      0.443164, 0.014311, 0.014853},{0.445347, 0.013602, 0.014302}}],
    Polygon[{{0.443164, 0.014311, -0.014853},{0.445347, 0.013602, -0.014302},{
      0.445574, 0.015038, -0.014302},{0.443279, 0.015038, -0.014853}}],
    Polygon[{{0.445347, 0.013602, -0.014302},{0.447420, 0.012928, -0.013399},{
      0.447754, 0.015038, -0.013399},{0.445574, 0.015038, -0.014302}}],
    Polygon[{{0.447420, 0.012928, -0.013399},{0.449334, 0.012307, -0.012166},{
      0.449766, 0.015038, -0.012166},{0.447754, 0.015038, -0.013399}}],
    Polygon[{{0.449334, 0.012307, -0.012166},{0.451040, 0.011752, -0.010634},{
      0.451561, 0.015038, -0.010634},{0.449766, 0.015038, -0.012166}}],
    Polygon[{{0.451040, 0.011752, -0.010634},{0.452498, 0.011279, -0.008839},{
      0.453093, 0.015038, -0.008839},{0.451561, 0.015038, -0.010634}}],
    Polygon[{{0.452498, 0.011279, -0.008839},{0.453670, 0.010898, -0.006827},{
      0.454326, 0.015038, -0.006827},{0.453093, 0.015038, -0.008839}}],
    Polygon[{{0.453670, 0.010898, -0.006827},{0.454529, 0.010619, -0.004647},{
      0.455229, 0.015038, -0.004647},{0.454326, 0.015038, -0.006827}}],
    Polygon[{{0.454529, 0.010619, -0.004647},{0.455053, 0.010448, -0.002352},{
      0.455780, 0.015038, -0.002352},{0.455229, 0.015038, -0.004647}}],
    Polygon[{{0.455053, 0.010448, -0.002352},{0.455229, 0.010391, 0.000000},{
      0.455965, 0.015038, 0.000000},{0.455780, 0.015038, -0.002352}}],
    Polygon[{{0.455229, 0.010391, 0.000000},{0.455053, 0.010448, 0.002352},{
      0.455780, 0.015038, 0.002352},{0.455965, 0.015038, 0.000000}}],
    Polygon[{{0.455053, 0.010448, 0.002352},{0.454529, 0.010619, 0.004647},{
      0.455229, 0.015038, 0.004647},{0.455780, 0.015038, 0.002352}}],
    Polygon[{{0.454529, 0.010619, 0.004647},{0.453670, 0.010898, 0.006827},{
      0.454326, 0.015038, 0.006827},{0.455229, 0.015038, 0.004647}}],
    Polygon[{{0.453670, 0.010898, 0.006827},{0.452498, 0.011279, 0.008839},{
      0.453093, 0.015038, 0.008839},{0.454326, 0.015038, 0.006827}}],
    Polygon[{{0.452498, 0.011279, 0.008839},{0.451040, 0.011752, 0.010634},{
      0.451561, 0.015038, 0.010634},{0.453093, 0.015038, 0.008839}}],
    Polygon[{{0.451040, 0.011752, 0.010634},{0.449334, 0.012307, 0.012166},{
      0.449766, 0.015038, 0.012166},{0.451561, 0.015038, 0.010634}}],
    Polygon[{{0.449334, 0.012307, 0.012166},{0.447420, 0.012928, 0.013399},{
      0.447754, 0.015038, 0.013399},{0.449766, 0.015038, 0.012166}}],
    Polygon[{{0.447420, 0.012928, 0.013399},{0.445347, 0.013602, 0.014302},{
      0.445574, 0.015038, 0.014302},{0.447754, 0.015038, 0.013399}}],
    Polygon[{{0.445347, 0.013602, 0.014302},{0.443164, 0.014311, 0.014853},{
      0.443279, 0.015038, 0.014853},{0.445574, 0.015038, 0.014302}}],
    Polygon[{{0.520362, 0.011149, -0.011012},{0.522063, 0.011149, -0.010603},{
      0.521894, 0.012214, -0.010603},{0.520276, 0.011688, -0.011012}}],
    Polygon[{{0.522063, 0.011149, -0.010603},{0.523679, 0.011149, -0.009934},{
      0.523431, 0.012713, -0.009934},{0.521894, 0.012214, -0.010603}}],
    Polygon[{{0.523679, 0.011149, -0.009934},{0.525171, 0.011149, -0.009020},{
      0.524850, 0.013174, -0.009020},{0.523431, 0.012713, -0.009934}}],
    Polygon[{{0.525171, 0.011149, -0.009020},{0.526501, 0.011149, -0.007884},{
      0.526115, 0.013585, -0.007884},{0.524850, 0.013174, -0.009020}}],
    Polygon[{{0.526501, 0.011149, -0.007884},{0.527637, 0.011149, -0.006553},{
      0.527196, 0.013936, -0.006553},{0.526115, 0.013585, -0.007884}}],
    Polygon[{{0.527637, 0.011149, -0.006553},{0.528551, 0.011149, -0.005062},{
      0.528065, 0.014219, -0.005062},{0.527196, 0.013936, -0.006553}}],
    Polygon[{{0.528551, 0.011149, -0.005062},{0.529221, 0.011149, -0.003445},{
      0.528702, 0.014426, -0.003445},{0.528065, 0.014219, -0.005062}}],
    Polygon[{{0.529221, 0.011149, -0.003445},{0.529629, 0.011149, -0.001744},{
      0.529090, 0.014552, -0.001744},{0.528702, 0.014426, -0.003445}}],
    Polygon[{{0.529629, 0.011149, -0.001744},{0.529767, 0.011149, 0.000000},{
      0.529221, 0.014594, 0.000000},{0.529090, 0.014552, -0.001744}}],
    Polygon[{{0.529767, 0.011149, 0.000000},{0.529629, 0.011149, 0.001744},{
      0.529090, 0.014552, 0.001744},{0.529221, 0.014594, 0.000000}}],
    Polygon[{{0.529629, 0.011149, 0.001744},{0.529221, 0.011149, 0.003445},{
      0.528702, 0.014426, 0.003445},{0.529090, 0.014552, 0.001744}}],
    Polygon[{{0.529221, 0.011149, 0.003445},{0.528551, 0.011149, 0.005062},{
      0.528065, 0.014219, 0.005062},{0.528702, 0.014426, 0.003445}}],
    Polygon[{{0.528551, 0.011149, 0.005062},{0.527637, 0.011149, 0.006553},{
      0.527196, 0.013936, 0.006553},{0.528065, 0.014219, 0.005062}}],
    Polygon[{{0.527637, 0.011149, 0.006553},{0.526501, 0.011149, 0.007884},{
      0.526115, 0.013585, 0.007884},{0.527196, 0.013936, 0.006553}}],
    Polygon[{{0.526501, 0.011149, 0.007884},{0.525171, 0.011149, 0.009020},{
      0.524850, 0.013174, 0.009020},{0.526115, 0.013585, 0.007884}}],
    Polygon[{{0.525171, 0.011149, 0.009020},{0.523679, 0.011149, 0.009934},{
      0.523431, 0.012713, 0.009934},{0.524850, 0.013174, 0.009020}}],
    Polygon[{{0.523679, 0.011149, 0.009934},{0.522063, 0.011149, 0.010603},{
      0.521894, 0.012214, 0.010603},{0.523431, 0.012713, 0.009934}}],
    Polygon[{{0.522063, 0.011149, 0.010603},{0.520362, 0.011149, 0.011012},{
      0.520276, 0.011688, 0.011012},{0.521894, 0.012214, 0.010603}}],
    Polygon[{{0.520276, 0.011688, -0.011012},{0.521894, 0.012214, -0.010603},{
      0.521405, 0.013174, -0.010603},{0.520029, 0.012174, -0.011012}}],
    Polygon[{{0.521894, 0.012214, -0.010603},{0.523431, 0.012713, -0.009934},{
      0.522712, 0.014124, -0.009934},{0.521405, 0.013174, -0.010603}}],
    Polygon[{{0.523431, 0.012713, -0.009934},{0.524850, 0.013174, -0.009020},{
      0.523919, 0.015001, -0.009020},{0.522712, 0.014124, -0.009934}}],
    Polygon[{{0.524850, 0.013174, -0.009020},{0.526115, 0.013585, -0.007884},{
      0.524996, 0.015783, -0.007884},{0.523919, 0.015001, -0.009020}}],
    Polygon[{{0.526115, 0.013585, -0.007884},{0.527196, 0.013936, -0.006553},{
      0.525915, 0.016451, -0.006553},{0.524996, 0.015783, -0.007884}}],
    Polygon[{{0.527196, 0.013936, -0.006553},{0.528065, 0.014219, -0.005062},{
      0.526654, 0.016988, -0.005062},{0.525915, 0.016451, -0.006553}}],
    Polygon[{{0.528065, 0.014219, -0.005062},{0.528702, 0.014426, -0.003445},{
      0.527196, 0.017382, -0.003445},{0.526654, 0.016988, -0.005062}}],
    Polygon[{{0.528702, 0.014426, -0.003445},{0.529090, 0.014552, -0.001744},{
      0.527526, 0.017622, -0.001744},{0.527196, 0.017382, -0.003445}}],
    Polygon[{{0.529090, 0.014552, -0.001744},{0.529221, 0.014594, 0.000000},{
      0.527637, 0.017702, 0.000000},{0.527526, 0.017622, -0.001744}}],
    Polygon[{{0.529221, 0.014594, 0.000000},{0.529090, 0.014552, 0.001744},{
      0.527526, 0.017622, 0.001744},{0.527637, 0.017702, 0.000000}}],
    Polygon[{{0.529090, 0.014552, 0.001744},{0.528702, 0.014426, 0.003445},{
      0.527196, 0.017382, 0.003445},{0.527526, 0.017622, 0.001744}}],
    Polygon[{{0.528702, 0.014426, 0.003445},{0.528065, 0.014219, 0.005062},{
      0.526654, 0.016988, 0.005062},{0.527196, 0.017382, 0.003445}}],
    Polygon[{{0.528065, 0.014219, 0.005062},{0.527196, 0.013936, 0.006553},{
      0.525915, 0.016451, 0.006553},{0.526654, 0.016988, 0.005062}}],
    Polygon[{{0.527196, 0.013936, 0.006553},{0.526115, 0.013585, 0.007884},{
      0.524996, 0.015783, 0.007884},{0.525915, 0.016451, 0.006553}}],
    Polygon[{{0.526115, 0.013585, 0.007884},{0.524850, 0.013174, 0.009020},{
      0.523919, 0.015001, 0.009020},{0.524996, 0.015783, 0.007884}}],
    Polygon[{{0.524850, 0.013174, 0.009020},{0.523431, 0.012713, 0.009934},{
      0.522712, 0.014124, 0.009934},{0.523919, 0.015001, 0.009020}}],
    Polygon[{{0.523431, 0.012713, 0.009934},{0.521894, 0.012214, 0.010603},{
      0.521405, 0.013174, 0.010603},{0.522712, 0.014124, 0.009934}}],
    Polygon[{{0.521894, 0.012214, 0.010603},{0.520276, 0.011688, 0.011012},{
      0.520029, 0.012174, 0.011012},{0.521405, 0.013174, 0.010603}}],
    Polygon[{{0.520029, 0.012174, -0.011012},{0.521405, 0.013174, -0.010603},{
      0.520643, 0.013936, -0.010603},{0.519643, 0.012560, -0.011012}}],
    Polygon[{{0.521405, 0.013174, -0.010603},{0.522712, 0.014124, -0.009934},{
      0.521593, 0.015244, -0.009934},{0.520643, 0.013936, -0.010603}}],
    Polygon[{{0.522712, 0.014124, -0.009934},{0.523919, 0.015001, -0.009020},{
      0.522469, 0.016451, -0.009020},{0.521593, 0.015244, -0.009934}}],
    Polygon[{{0.523919, 0.015001, -0.009020},{0.524996, 0.015783, -0.007884},{
      0.523251, 0.017527, -0.007884},{0.522469, 0.016451, -0.009020}}],
    Polygon[{{0.524996, 0.015783, -0.007884},{0.525915, 0.016451, -0.006553},{
      0.523919, 0.018446, -0.006553},{0.523251, 0.017527, -0.007884}}],
    Polygon[{{0.525915, 0.016451, -0.006553},{0.526654, 0.016988, -0.005062},{
      0.524457, 0.019186, -0.005062},{0.523919, 0.018446, -0.006553}}],
    Polygon[{{0.526654, 0.016988, -0.005062},{0.527196, 0.017382, -0.003445},{
      0.524850, 0.019727, -0.003445},{0.524457, 0.019186, -0.005062}}],
    Polygon[{{0.527196, 0.017382, -0.003445},{0.527526, 0.017622, -0.001744},{
      0.525090, 0.020058, -0.001744},{0.524850, 0.019727, -0.003445}}],
    Polygon[{{0.527526, 0.017622, -0.001744},{0.527637, 0.017702, 0.000000},{
      0.525171, 0.020169, 0.000000},{0.525090, 0.020058, -0.001744}}],
    Polygon[{{0.527637, 0.017702, 0.000000},{0.527526, 0.017622, 0.001744},{
      0.525090, 0.020058, 0.001744},{0.525171, 0.020169, 0.000000}}],
    Polygon[{{0.527526, 0.017622, 0.001744},{0.527196, 0.017382, 0.003445},{
      0.524850, 0.019727, 0.003445},{0.525090, 0.020058, 0.001744}}],
    Polygon[{{0.527196, 0.017382, 0.003445},{0.526654, 0.016988, 0.005062},{
      0.524457, 0.019186, 0.005062},{0.524850, 0.019727, 0.003445}}],
    Polygon[{{0.526654, 0.016988, 0.005062},{0.525915, 0.016451, 0.006553},{
      0.523919, 0.018446, 0.006553},{0.524457, 0.019186, 0.005062}}],
    Polygon[{{0.525915, 0.016451, 0.006553},{0.524996, 0.015783, 0.007884},{
      0.523251, 0.017527, 0.007884},{0.523919, 0.018446, 0.006553}}],
    Polygon[{{0.524996, 0.015783, 0.007884},{0.523919, 0.015001, 0.009020},{
      0.522469, 0.016451, 0.009020},{0.523251, 0.017527, 0.007884}}],
    Polygon[{{0.523919, 0.015001, 0.009020},{0.522712, 0.014124, 0.009934},{
      0.521593, 0.015244, 0.009934},{0.522469, 0.016451, 0.009020}}],
    Polygon[{{0.522712, 0.014124, 0.009934},{0.521405, 0.013174, 0.010603},{
      0.520643, 0.013936, 0.010603},{0.521593, 0.015244, 0.009934}}],
    Polygon[{{0.521405, 0.013174, 0.010603},{0.520029, 0.012174, 0.011012},{
      0.519643, 0.012560, 0.011012},{0.520643, 0.013936, 0.010603}}],
    Polygon[{{0.519643, 0.012560, -0.011012},{0.520643, 0.013936, -0.010603},{
      0.519682, 0.014426, -0.010603},{0.519157, 0.012808, -0.011012}}],
    Polygon[{{0.520643, 0.013936, -0.010603},{0.521593, 0.015244, -0.009934},{
      0.520182, 0.015963, -0.009934},{0.519682, 0.014426, -0.010603}}],
    Polygon[{{0.521593, 0.015244, -0.009934},{0.522469, 0.016451, -0.009020},{
      0.520643, 0.017382, -0.009020},{0.520182, 0.015963, -0.009934}}],
    Polygon[{{0.522469, 0.016451, -0.009020},{0.523251, 0.017527, -0.007884},{
      0.521054, 0.018647, -0.007884},{0.520643, 0.017382, -0.009020}}],
    Polygon[{{0.523251, 0.017527, -0.007884},{0.523919, 0.018446, -0.006553},{
      0.521405, 0.019727, -0.006553},{0.521054, 0.018647, -0.007884}}],
    Polygon[{{0.523919, 0.018446, -0.006553},{0.524457, 0.019186, -0.005062},{
      0.521687, 0.020597, -0.005062},{0.521405, 0.019727, -0.006553}}],
    Polygon[{{0.524457, 0.019186, -0.005062},{0.524850, 0.019727, -0.003445},{
      0.521894, 0.021233, -0.003445},{0.521687, 0.020597, -0.005062}}],
    Polygon[{{0.524850, 0.019727, -0.003445},{0.525090, 0.020058, -0.001744},{
      0.522020, 0.021622, -0.001744},{0.521894, 0.021233, -0.003445}}],
    Polygon[{{0.525090, 0.020058, -0.001744},{0.525171, 0.020169, 0.000000},{
      0.522063, 0.021752, 0.000000},{0.522020, 0.021622, -0.001744}}],
    Polygon[{{0.525171, 0.020169, 0.000000},{0.525090, 0.020058, 0.001744},{
      0.522020, 0.021622, 0.001744},{0.522063, 0.021752, 0.000000}}],
    Polygon[{{0.525090, 0.020058, 0.001744},{0.524850, 0.019727, 0.003445},{
      0.521894, 0.021233, 0.003445},{0.522020, 0.021622, 0.001744}}],
    Polygon[{{0.524850, 0.019727, 0.003445},{0.524457, 0.019186, 0.005062},{
      0.521687, 0.020597, 0.005062},{0.521894, 0.021233, 0.003445}}],
    Polygon[{{0.524457, 0.019186, 0.005062},{0.523919, 0.018446, 0.006553},{
      0.521405, 0.019727, 0.006553},{0.521687, 0.020597, 0.005062}}],
    Polygon[{{0.523919, 0.018446, 0.006553},{0.523251, 0.017527, 0.007884},{
      0.521054, 0.018647, 0.007884},{0.521405, 0.019727, 0.006553}}],
    Polygon[{{0.523251, 0.017527, 0.007884},{0.522469, 0.016451, 0.009020},{
      0.520643, 0.017382, 0.009020},{0.521054, 0.018647, 0.007884}}],
    Polygon[{{0.522469, 0.016451, 0.009020},{0.521593, 0.015244, 0.009934},{
      0.520182, 0.015963, 0.009934},{0.520643, 0.017382, 0.009020}}],
    Polygon[{{0.521593, 0.015244, 0.009934},{0.520643, 0.013936, 0.010603},{
      0.519682, 0.014426, 0.010603},{0.520182, 0.015963, 0.009934}}],
    Polygon[{{0.520643, 0.013936, 0.010603},{0.519643, 0.012560, 0.011012},{
      0.519157, 0.012808, 0.011012},{0.519682, 0.014426, 0.010603}}],
    Polygon[{{0.519157, 0.012808, -0.011012},{0.519682, 0.014426, -0.010603},{
      0.518618, 0.014594, -0.010603},{0.518618, 0.012893, -0.011012}}],
    Polygon[{{0.519682, 0.014426, -0.010603},{0.520182, 0.015963, -0.009934},{
      0.518618, 0.016211, -0.009934},{0.518618, 0.014594, -0.010603}}],
    Polygon[{{0.520182, 0.015963, -0.009934},{0.520643, 0.017382, -0.009020},{
      0.518618, 0.017702, -0.009020},{0.518618, 0.016211, -0.009934}}],
    Polygon[{{0.520643, 0.017382, -0.009020},{0.521054, 0.018647, -0.007884},{
      0.518618, 0.019033, -0.007884},{0.518618, 0.017702, -0.009020}}],
    Polygon[{{0.521054, 0.018647, -0.007884},{0.521405, 0.019727, -0.006553},{
      0.518618, 0.020169, -0.006553},{0.518618, 0.019033, -0.007884}}],
    Polygon[{{0.521405, 0.019727, -0.006553},{0.521687, 0.020597, -0.005062},{
      0.518618, 0.021083, -0.005062},{0.518618, 0.020169, -0.006553}}],
    Polygon[{{0.521687, 0.020597, -0.005062},{0.521894, 0.021233, -0.003445},{
      0.518618, 0.021752, -0.003445},{0.518618, 0.021083, -0.005062}}],
    Polygon[{{0.521894, 0.021233, -0.003445},{0.522020, 0.021622, -0.001744},{
      0.518618, 0.022161, -0.001744},{0.518618, 0.021752, -0.003445}}],
    Polygon[{{0.522020, 0.021622, -0.001744},{0.522063, 0.021752, 0.000000},{
      0.518618, 0.022298, 0.000000},{0.518618, 0.022161, -0.001744}}],
    Polygon[{{0.522063, 0.021752, 0.000000},{0.522020, 0.021622, 0.001744},{
      0.518618, 0.022161, 0.001744},{0.518618, 0.022298, 0.000000}}],
    Polygon[{{0.522020, 0.021622, 0.001744},{0.521894, 0.021233, 0.003445},{
      0.518618, 0.021752, 0.003445},{0.518618, 0.022161, 0.001744}}],
    Polygon[{{0.521894, 0.021233, 0.003445},{0.521687, 0.020597, 0.005062},{
      0.518618, 0.021083, 0.005062},{0.518618, 0.021752, 0.003445}}],
    Polygon[{{0.521687, 0.020597, 0.005062},{0.521405, 0.019727, 0.006553},{
      0.518618, 0.020169, 0.006553},{0.518618, 0.021083, 0.005062}}],
    Polygon[{{0.521405, 0.019727, 0.006553},{0.521054, 0.018647, 0.007884},{
      0.518618, 0.019033, 0.007884},{0.518618, 0.020169, 0.006553}}],
    Polygon[{{0.521054, 0.018647, 0.007884},{0.520643, 0.017382, 0.009020},{
      0.518618, 0.017702, 0.009020},{0.518618, 0.019033, 0.007884}}],
    Polygon[{{0.520643, 0.017382, 0.009020},{0.520182, 0.015963, 0.009934},{
      0.518618, 0.016211, 0.009934},{0.518618, 0.017702, 0.009020}}],
    Polygon[{{0.520182, 0.015963, 0.009934},{0.519682, 0.014426, 0.010603},{
      0.518618, 0.014594, 0.010603},{0.518618, 0.016211, 0.009934}}],
    Polygon[{{0.519682, 0.014426, 0.010603},{0.519157, 0.012808, 0.011012},{
      0.518618, 0.012893, 0.011012},{0.518618, 0.014594, 0.010603}}],
    Polygon[{{0.518618, 0.012893, -0.011012},{0.518618, 0.014594, -0.010603},{
      0.517553, 0.014426, -0.010603},{0.518079, 0.012808, -0.011012}}],
    Polygon[{{0.518618, 0.014594, -0.010603},{0.518618, 0.016211, -0.009934},{
      0.517053, 0.015963, -0.009934},{0.517553, 0.014426, -0.010603}}],
    Polygon[{{0.518618, 0.016211, -0.009934},{0.518618, 0.017702, -0.009020},{
      0.516592, 0.017382, -0.009020},{0.517053, 0.015963, -0.009934}}],
    Polygon[{{0.518618, 0.017702, -0.009020},{0.518618, 0.019033, -0.007884},{
      0.516181, 0.018647, -0.007884},{0.516592, 0.017382, -0.009020}}],
    Polygon[{{0.518618, 0.019033, -0.007884},{0.518618, 0.020169, -0.006553},{
      0.515830, 0.019727, -0.006553},{0.516181, 0.018647, -0.007884}}],
    Polygon[{{0.518618, 0.020169, -0.006553},{0.518618, 0.021083, -0.005062},{
      0.515548, 0.020597, -0.005062},{0.515830, 0.019727, -0.006553}}],
    Polygon[{{0.518618, 0.021083, -0.005062},{0.518618, 0.021752, -0.003445},{
      0.515341, 0.021233, -0.003445},{0.515548, 0.020597, -0.005062}}],
    Polygon[{{0.518618, 0.021752, -0.003445},{0.518618, 0.022161, -0.001744},{
      0.515215, 0.021622, -0.001744},{0.515341, 0.021233, -0.003445}}],
    Polygon[{{0.518618, 0.022161, -0.001744},{0.518618, 0.022298, 0.000000},{
      0.515172, 0.021752, 0.000000},{0.515215, 0.021622, -0.001744}}],
    Polygon[{{0.518618, 0.022298, 0.000000},{0.518618, 0.022161, 0.001744},{
      0.515215, 0.021622, 0.001744},{0.515172, 0.021752, 0.000000}}],
    Polygon[{{0.518618, 0.022161, 0.001744},{0.518618, 0.021752, 0.003445},{
      0.515341, 0.021233, 0.003445},{0.515215, 0.021622, 0.001744}}],
    Polygon[{{0.518618, 0.021752, 0.003445},{0.518618, 0.021083, 0.005062},{
      0.515548, 0.020597, 0.005062},{0.515341, 0.021233, 0.003445}}],
    Polygon[{{0.518618, 0.021083, 0.005062},{0.518618, 0.020169, 0.006553},{
      0.515830, 0.019727, 0.006553},{0.515548, 0.020597, 0.005062}}],
    Polygon[{{0.518618, 0.020169, 0.006553},{0.518618, 0.019033, 0.007884},{
      0.516181, 0.018647, 0.007884},{0.515830, 0.019727, 0.006553}}],
    Polygon[{{0.518618, 0.019033, 0.007884},{0.518618, 0.017702, 0.009020},{
      0.516592, 0.017382, 0.009020},{0.516181, 0.018647, 0.007884}}],
    Polygon[{{0.518618, 0.017702, 0.009020},{0.518618, 0.016211, 0.009934},{
      0.517053, 0.015963, 0.009934},{0.516592, 0.017382, 0.009020}}],
    Polygon[{{0.518618, 0.016211, 0.009934},{0.518618, 0.014594, 0.010603},{
      0.517553, 0.014426, 0.010603},{0.517053, 0.015963, 0.009934}}],
    Polygon[{{0.518618, 0.014594, 0.010603},{0.518618, 0.012893, 0.011012},{
      0.518079, 0.012808, 0.011012},{0.517553, 0.014426, 0.010603}}],
    Polygon[{{0.518079, 0.012808, -0.011012},{0.517553, 0.014426, -0.010603},{
      0.516592, 0.013936, -0.010603},{0.517592, 0.012560, -0.011012}}],
    Polygon[{{0.517553, 0.014426, -0.010603},{0.517053, 0.015963, -0.009934},{
      0.515642, 0.015244, -0.009934},{0.516592, 0.013936, -0.010603}}],
    Polygon[{{0.517053, 0.015963, -0.009934},{0.516592, 0.017382, -0.009020},{
      0.514766, 0.016451, -0.009020},{0.515642, 0.015244, -0.009934}}],
    Polygon[{{0.516592, 0.017382, -0.009020},{0.516181, 0.018647, -0.007884},{
      0.513984, 0.017527, -0.007884},{0.514766, 0.016451, -0.009020}}],
    Polygon[{{0.516181, 0.018647, -0.007884},{0.515830, 0.019727, -0.006553},{
      0.513316, 0.018446, -0.006553},{0.513984, 0.017527, -0.007884}}],
    Polygon[{{0.515830, 0.019727, -0.006553},{0.515548, 0.020597, -0.005062},{
      0.512779, 0.019186, -0.005062},{0.513316, 0.018446, -0.006553}}],
    Polygon[{{0.515548, 0.020597, -0.005062},{0.515341, 0.021233, -0.003445},{
      0.512385, 0.019727, -0.003445},{0.512779, 0.019186, -0.005062}}],
    Polygon[{{0.515341, 0.021233, -0.003445},{0.515215, 0.021622, -0.001744},{
      0.512145, 0.020058, -0.001744},{0.512385, 0.019727, -0.003445}}],
    Polygon[{{0.515215, 0.021622, -0.001744},{0.515172, 0.021752, 0.000000},{
      0.512064, 0.020169, 0.000000},{0.512145, 0.020058, -0.001744}}],
    Polygon[{{0.515172, 0.021752, 0.000000},{0.515215, 0.021622, 0.001744},{
      0.512145, 0.020058, 0.001744},{0.512064, 0.020169, 0.000000}}],
    Polygon[{{0.515215, 0.021622, 0.001744},{0.515341, 0.021233, 0.003445},{
      0.512385, 0.019727, 0.003445},{0.512145, 0.020058, 0.001744}}],
    Polygon[{{0.515341, 0.021233, 0.003445},{0.515548, 0.020597, 0.005062},{
      0.512779, 0.019186, 0.005062},{0.512385, 0.019727, 0.003445}}],
    Polygon[{{0.515548, 0.020597, 0.005062},{0.515830, 0.019727, 0.006553},{
      0.513316, 0.018446, 0.006553},{0.512779, 0.019186, 0.005062}}],
    Polygon[{{0.515830, 0.019727, 0.006553},{0.516181, 0.018647, 0.007884},{
      0.513984, 0.017527, 0.007884},{0.513316, 0.018446, 0.006553}}],
    Polygon[{{0.516181, 0.018647, 0.007884},{0.516592, 0.017382, 0.009020},{
      0.514766, 0.016451, 0.009020},{0.513984, 0.017527, 0.007884}}],
    Polygon[{{0.516592, 0.017382, 0.009020},{0.517053, 0.015963, 0.009934},{
      0.515642, 0.015244, 0.009934},{0.514766, 0.016451, 0.009020}}],
    Polygon[{{0.517053, 0.015963, 0.009934},{0.517553, 0.014426, 0.010603},{
      0.516592, 0.013936, 0.010603},{0.515642, 0.015244, 0.009934}}],
    Polygon[{{0.517553, 0.014426, 0.010603},{0.518079, 0.012808, 0.011012},{
      0.517592, 0.012560, 0.011012},{0.516592, 0.013936, 0.010603}}],
    Polygon[{{0.517592, 0.012560, -0.011012},{0.516592, 0.013936, -0.010603},{
      0.515830, 0.013174, -0.010603},{0.517207, 0.012174, -0.011012}}],
    Polygon[{{0.516592, 0.013936, -0.010603},{0.515642, 0.015244, -0.009934},{
      0.514523, 0.014124, -0.009934},{0.515830, 0.013174, -0.010603}}],
    Polygon[{{0.515642, 0.015244, -0.009934},{0.514766, 0.016451, -0.009020},{
      0.513316, 0.015001, -0.009020},{0.514523, 0.014124, -0.009934}}],
    Polygon[{{0.514766, 0.016451, -0.009020},{0.513984, 0.017527, -0.007884},{
      0.512240, 0.015783, -0.007884},{0.513316, 0.015001, -0.009020}}],
    Polygon[{{0.513984, 0.017527, -0.007884},{0.513316, 0.018446, -0.006553},{
      0.511320, 0.016451, -0.006553},{0.512240, 0.015783, -0.007884}}],
    Polygon[{{0.513316, 0.018446, -0.006553},{0.512779, 0.019186, -0.005062},{
      0.510581, 0.016988, -0.005062},{0.511320, 0.016451, -0.006553}}],
    Polygon[{{0.512779, 0.019186, -0.005062},{0.512385, 0.019727, -0.003445},{
      0.510039, 0.017382, -0.003445},{0.510581, 0.016988, -0.005062}}],
    Polygon[{{0.512385, 0.019727, -0.003445},{0.512145, 0.020058, -0.001744},{
      0.509709, 0.017622, -0.001744},{0.510039, 0.017382, -0.003445}}],
    Polygon[{{0.512145, 0.020058, -0.001744},{0.512064, 0.020169, 0.000000},{
      0.509598, 0.017702, 0.000000},{0.509709, 0.017622, -0.001744}}],
    Polygon[{{0.512064, 0.020169, 0.000000},{0.512145, 0.020058, 0.001744},{
      0.509709, 0.017622, 0.001744},{0.509598, 0.017702, 0.000000}}],
    Polygon[{{0.512145, 0.020058, 0.001744},{0.512385, 0.019727, 0.003445},{
      0.510039, 0.017382, 0.003445},{0.509709, 0.017622, 0.001744}}],
    Polygon[{{0.512385, 0.019727, 0.003445},{0.512779, 0.019186, 0.005062},{
      0.510581, 0.016988, 0.005062},{0.510039, 0.017382, 0.003445}}],
    Polygon[{{0.512779, 0.019186, 0.005062},{0.513316, 0.018446, 0.006553},{
      0.511320, 0.016451, 0.006553},{0.510581, 0.016988, 0.005062}}],
    Polygon[{{0.513316, 0.018446, 0.006553},{0.513984, 0.017527, 0.007884},{
      0.512240, 0.015783, 0.007884},{0.511320, 0.016451, 0.006553}}],
    Polygon[{{0.513984, 0.017527, 0.007884},{0.514766, 0.016451, 0.009020},{
      0.513316, 0.015001, 0.009020},{0.512240, 0.015783, 0.007884}}],
    Polygon[{{0.514766, 0.016451, 0.009020},{0.515642, 0.015244, 0.009934},{
      0.514523, 0.014124, 0.009934},{0.513316, 0.015001, 0.009020}}],
    Polygon[{{0.515642, 0.015244, 0.009934},{0.516592, 0.013936, 0.010603},{
      0.515830, 0.013174, 0.010603},{0.514523, 0.014124, 0.009934}}],
    Polygon[{{0.516592, 0.013936, 0.010603},{0.517592, 0.012560, 0.011012},{
      0.517207, 0.012174, 0.011012},{0.515830, 0.013174, 0.010603}}],
    Polygon[{{0.517207, 0.012174, -0.011012},{0.515830, 0.013174, -0.010603},{
      0.515341, 0.012214, -0.010603},{0.516959, 0.011688, -0.011012}}],
    Polygon[{{0.515830, 0.013174, -0.010603},{0.514523, 0.014124, -0.009934},{
      0.513804, 0.012713, -0.009934},{0.515341, 0.012214, -0.010603}}],
    Polygon[{{0.514523, 0.014124, -0.009934},{0.513316, 0.015001, -0.009020},{
      0.512385, 0.013174, -0.009020},{0.513804, 0.012713, -0.009934}}],
    Polygon[{{0.513316, 0.015001, -0.009020},{0.512240, 0.015783, -0.007884},{
      0.511120, 0.013585, -0.007884},{0.512385, 0.013174, -0.009020}}],
    Polygon[{{0.512240, 0.015783, -0.007884},{0.511320, 0.016451, -0.006553},{
      0.510039, 0.013936, -0.006553},{0.511120, 0.013585, -0.007884}}],
    Polygon[{{0.511320, 0.016451, -0.006553},{0.510581, 0.016988, -0.005062},{
      0.509170, 0.014219, -0.005062},{0.510039, 0.013936, -0.006553}}],
    Polygon[{{0.510581, 0.016988, -0.005062},{0.510039, 0.017382, -0.003445},{
      0.508533, 0.014426, -0.003445},{0.509170, 0.014219, -0.005062}}],
    Polygon[{{0.510039, 0.017382, -0.003445},{0.509709, 0.017622, -0.001744},{
      0.508145, 0.014552, -0.001744},{0.508533, 0.014426, -0.003445}}],
    Polygon[{{0.509709, 0.017622, -0.001744},{0.509598, 0.017702, 0.000000},{
      0.508014, 0.014594, 0.000000},{0.508145, 0.014552, -0.001744}}],
    Polygon[{{0.509598, 0.017702, 0.000000},{0.509709, 0.017622, 0.001744},{
      0.508145, 0.014552, 0.001744},{0.508014, 0.014594, 0.000000}}],
    Polygon[{{0.509709, 0.017622, 0.001744},{0.510039, 0.017382, 0.003445},{
      0.508533, 0.014426, 0.003445},{0.508145, 0.014552, 0.001744}}],
    Polygon[{{0.510039, 0.017382, 0.003445},{0.510581, 0.016988, 0.005062},{
      0.509170, 0.014219, 0.005062},{0.508533, 0.014426, 0.003445}}],
    Polygon[{{0.510581, 0.016988, 0.005062},{0.511320, 0.016451, 0.006553},{
      0.510039, 0.013936, 0.006553},{0.509170, 0.014219, 0.005062}}],
    Polygon[{{0.511320, 0.016451, 0.006553},{0.512240, 0.015783, 0.007884},{
      0.511120, 0.013585, 0.007884},{0.510039, 0.013936, 0.006553}}],
    Polygon[{{0.512240, 0.015783, 0.007884},{0.513316, 0.015001, 0.009020},{
      0.512385, 0.013174, 0.009020},{0.511120, 0.013585, 0.007884}}],
    Polygon[{{0.513316, 0.015001, 0.009020},{0.514523, 0.014124, 0.009934},{
      0.513804, 0.012713, 0.009934},{0.512385, 0.013174, 0.009020}}],
    Polygon[{{0.514523, 0.014124, 0.009934},{0.515830, 0.013174, 0.010603},{
      0.515341, 0.012214, 0.010603},{0.513804, 0.012713, 0.009934}}],
    Polygon[{{0.515830, 0.013174, 0.010603},{0.517207, 0.012174, 0.011012},{
      0.516959, 0.011688, 0.011012},{0.515341, 0.012214, 0.010603}}],
    Polygon[{{0.516959, 0.011688, -0.011012},{0.515341, 0.012214, -0.010603},{
      0.515172, 0.011149, -0.010603},{0.516873, 0.011149, -0.011012}}],
    Polygon[{{0.515341, 0.012214, -0.010603},{0.513804, 0.012713, -0.009934},{
      0.513556, 0.011149, -0.009934},{0.515172, 0.011149, -0.010603}}],
    Polygon[{{0.513804, 0.012713, -0.009934},{0.512385, 0.013174, -0.009020},{
      0.512064, 0.011149, -0.009020},{0.513556, 0.011149, -0.009934}}],
    Polygon[{{0.512385, 0.013174, -0.009020},{0.511120, 0.013585, -0.007884},{
      0.510734, 0.011149, -0.007884},{0.512064, 0.011149, -0.009020}}],
    Polygon[{{0.511120, 0.013585, -0.007884},{0.510039, 0.013936, -0.006553},{
      0.509598, 0.011149, -0.006553},{0.510734, 0.011149, -0.007884}}],
    Polygon[{{0.510039, 0.013936, -0.006553},{0.509170, 0.014219, -0.005062},{
      0.508684, 0.011149, -0.005062},{0.509598, 0.011149, -0.006553}}],
    Polygon[{{0.509170, 0.014219, -0.005062},{0.508533, 0.014426, -0.003445},{
      0.508014, 0.011149, -0.003445},{0.508684, 0.011149, -0.005062}}],
    Polygon[{{0.508533, 0.014426, -0.003445},{0.508145, 0.014552, -0.001744},{
      0.507606, 0.011149, -0.001744},{0.508014, 0.011149, -0.003445}}],
    Polygon[{{0.508145, 0.014552, -0.001744},{0.508014, 0.014594, 0.000000},{
      0.507468, 0.011149, 0.000000},{0.507606, 0.011149, -0.001744}}],
    Polygon[{{0.508014, 0.014594, 0.000000},{0.508145, 0.014552, 0.001744},{
      0.507606, 0.011149, 0.001744},{0.507468, 0.011149, 0.000000}}],
    Polygon[{{0.508145, 0.014552, 0.001744},{0.508533, 0.014426, 0.003445},{
      0.508014, 0.011149, 0.003445},{0.507606, 0.011149, 0.001744}}],
    Polygon[{{0.508533, 0.014426, 0.003445},{0.509170, 0.014219, 0.005062},{
      0.508684, 0.011149, 0.005062},{0.508014, 0.011149, 0.003445}}],
    Polygon[{{0.509170, 0.014219, 0.005062},{0.510039, 0.013936, 0.006553},{
      0.509598, 0.011149, 0.006553},{0.508684, 0.011149, 0.005062}}],
    Polygon[{{0.510039, 0.013936, 0.006553},{0.511120, 0.013585, 0.007884},{
      0.510734, 0.011149, 0.007884},{0.509598, 0.011149, 0.006553}}],
    Polygon[{{0.511120, 0.013585, 0.007884},{0.512385, 0.013174, 0.009020},{
      0.512064, 0.011149, 0.009020},{0.510734, 0.011149, 0.007884}}],
    Polygon[{{0.512385, 0.013174, 0.009020},{0.513804, 0.012713, 0.009934},{
      0.513556, 0.011149, 0.009934},{0.512064, 0.011149, 0.009020}}],
    Polygon[{{0.513804, 0.012713, 0.009934},{0.515341, 0.012214, 0.010603},{
      0.515172, 0.011149, 0.010603},{0.513556, 0.011149, 0.009934}}],
    Polygon[{{0.515341, 0.012214, 0.010603},{0.516959, 0.011688, 0.011012},{
      0.516873, 0.011149, 0.011012},{0.515172, 0.011149, 0.010603}}],
    Polygon[{{0.516873, 0.011149, -0.011012},{0.515172, 0.011149, -0.010603},{
      0.515341, 0.010084, -0.010603},{0.516959, 0.010610, -0.011012}}],
    Polygon[{{0.515172, 0.011149, -0.010603},{0.513556, 0.011149, -0.009934},{
      0.513804, 0.009585, -0.009934},{0.515341, 0.010084, -0.010603}}],
    Polygon[{{0.513556, 0.011149, -0.009934},{0.512064, 0.011149, -0.009020},{
      0.512385, 0.009124, -0.009020},{0.513804, 0.009585, -0.009934}}],
    Polygon[{{0.512064, 0.011149, -0.009020},{0.510734, 0.011149, -0.007884},{
      0.511120, 0.008713, -0.007884},{0.512385, 0.009124, -0.009020}}],
    Polygon[{{0.510734, 0.011149, -0.007884},{0.509598, 0.011149, -0.006553},{
      0.510039, 0.008362, -0.006553},{0.511120, 0.008713, -0.007884}}],
    Polygon[{{0.509598, 0.011149, -0.006553},{0.508684, 0.011149, -0.005062},{
      0.509170, 0.008079, -0.005062},{0.510039, 0.008362, -0.006553}}],
    Polygon[{{0.508684, 0.011149, -0.005062},{0.508014, 0.011149, -0.003445},{
      0.508533, 0.007872, -0.003445},{0.509170, 0.008079, -0.005062}}],
    Polygon[{{0.508014, 0.011149, -0.003445},{0.507606, 0.011149, -0.001744},{
      0.508145, 0.007746, -0.001744},{0.508533, 0.007872, -0.003445}}],
    Polygon[{{0.507606, 0.011149, -0.001744},{0.507468, 0.011149, 0.000000},{
      0.508014, 0.007704, 0.000000},{0.508145, 0.007746, -0.001744}}],
    Polygon[{{0.507468, 0.011149, 0.000000},{0.507606, 0.011149, 0.001744},{
      0.508145, 0.007746, 0.001744},{0.508014, 0.007704, 0.000000}}],
    Polygon[{{0.507606, 0.011149, 0.001744},{0.508014, 0.011149, 0.003445},{
      0.508533, 0.007872, 0.003445},{0.508145, 0.007746, 0.001744}}],
    Polygon[{{0.508014, 0.011149, 0.003445},{0.508684, 0.011149, 0.005062},{
      0.509170, 0.008079, 0.005062},{0.508533, 0.007872, 0.003445}}],
    Polygon[{{0.508684, 0.011149, 0.005062},{0.509598, 0.011149, 0.006553},{
      0.510039, 0.008362, 0.006553},{0.509170, 0.008079, 0.005062}}],
    Polygon[{{0.509598, 0.011149, 0.006553},{0.510734, 0.011149, 0.007884},{
      0.511120, 0.008713, 0.007884},{0.510039, 0.008362, 0.006553}}],
    Polygon[{{0.510734, 0.011149, 0.007884},{0.512064, 0.011149, 0.009020},{
      0.512385, 0.009124, 0.009020},{0.511120, 0.008713, 0.007884}}],
    Polygon[{{0.512064, 0.011149, 0.009020},{0.513556, 0.011149, 0.009934},{
      0.513804, 0.009585, 0.009934},{0.512385, 0.009124, 0.009020}}],
    Polygon[{{0.513556, 0.011149, 0.009934},{0.515172, 0.011149, 0.010603},{
      0.515341, 0.010084, 0.010603},{0.513804, 0.009585, 0.009934}}],
    Polygon[{{0.515172, 0.011149, 0.010603},{0.516873, 0.011149, 0.011012},{
      0.516959, 0.010610, 0.011012},{0.515341, 0.010084, 0.010603}}],
    Polygon[{{0.516959, 0.010610, -0.011012},{0.515341, 0.010084, -0.010603},{
      0.515830, 0.009124, -0.010603},{0.517207, 0.010124, -0.011012}}],
    Polygon[{{0.515341, 0.010084, -0.010603},{0.513804, 0.009585, -0.009934},{
      0.514523, 0.008174, -0.009934},{0.515830, 0.009124, -0.010603}}],
    Polygon[{{0.513804, 0.009585, -0.009934},{0.512385, 0.009124, -0.009020},{
      0.513316, 0.007297, -0.009020},{0.514523, 0.008174, -0.009934}}],
    Polygon[{{0.512385, 0.009124, -0.009020},{0.511120, 0.008713, -0.007884},{
      0.512240, 0.006515, -0.007884},{0.513316, 0.007297, -0.009020}}],
    Polygon[{{0.511120, 0.008713, -0.007884},{0.510039, 0.008362, -0.006553},{
      0.511320, 0.005847, -0.006553},{0.512240, 0.006515, -0.007884}}],
    Polygon[{{0.510039, 0.008362, -0.006553},{0.509170, 0.008079, -0.005062},{
      0.510581, 0.005310, -0.005062},{0.511320, 0.005847, -0.006553}}],
    Polygon[{{0.509170, 0.008079, -0.005062},{0.508533, 0.007872, -0.003445},{
      0.510039, 0.004917, -0.003445},{0.510581, 0.005310, -0.005062}}],
    Polygon[{{0.508533, 0.007872, -0.003445},{0.508145, 0.007746, -0.001744},{
      0.509709, 0.004676, -0.001744},{0.510039, 0.004917, -0.003445}}],
    Polygon[{{0.508145, 0.007746, -0.001744},{0.508014, 0.007704, 0.000000},{
      0.509598, 0.004596, 0.000000},{0.509709, 0.004676, -0.001744}}],
    Polygon[{{0.508014, 0.007704, 0.000000},{0.508145, 0.007746, 0.001744},{
      0.509709, 0.004676, 0.001744},{0.509598, 0.004596, 0.000000}}],
    Polygon[{{0.508145, 0.007746, 0.001744},{0.508533, 0.007872, 0.003445},{
      0.510039, 0.004917, 0.003445},{0.509709, 0.004676, 0.001744}}],
    Polygon[{{0.508533, 0.007872, 0.003445},{0.509170, 0.008079, 0.005062},{
      0.510581, 0.005310, 0.005062},{0.510039, 0.004917, 0.003445}}],
    Polygon[{{0.509170, 0.008079, 0.005062},{0.510039, 0.008362, 0.006553},{
      0.511320, 0.005847, 0.006553},{0.510581, 0.005310, 0.005062}}],
    Polygon[{{0.510039, 0.008362, 0.006553},{0.511120, 0.008713, 0.007884},{
      0.512240, 0.006515, 0.007884},{0.511320, 0.005847, 0.006553}}],
    Polygon[{{0.511120, 0.008713, 0.007884},{0.512385, 0.009124, 0.009020},{
      0.513316, 0.007297, 0.009020},{0.512240, 0.006515, 0.007884}}],
    Polygon[{{0.512385, 0.009124, 0.009020},{0.513804, 0.009585, 0.009934},{
      0.514523, 0.008174, 0.009934},{0.513316, 0.007297, 0.009020}}],
    Polygon[{{0.513804, 0.009585, 0.009934},{0.515341, 0.010084, 0.010603},{
      0.515830, 0.009124, 0.010603},{0.514523, 0.008174, 0.009934}}],
    Polygon[{{0.515341, 0.010084, 0.010603},{0.516959, 0.010610, 0.011012},{
      0.517207, 0.010124, 0.011012},{0.515830, 0.009124, 0.010603}}],
    Polygon[{{0.517207, 0.010124, -0.011012},{0.515830, 0.009124, -0.010603},{
      0.516592, 0.008362, -0.010603},{0.517592, 0.009738, -0.011012}}],
    Polygon[{{0.515830, 0.009124, -0.010603},{0.514523, 0.008174, -0.009934},{
      0.515642, 0.007054, -0.009934},{0.516592, 0.008362, -0.010603}}],
    Polygon[{{0.514523, 0.008174, -0.009934},{0.513316, 0.007297, -0.009020},{
      0.514766, 0.005847, -0.009020},{0.515642, 0.007054, -0.009934}}],
    Polygon[{{0.513316, 0.007297, -0.009020},{0.512240, 0.006515, -0.007884},{
      0.513984, 0.004771, -0.007884},{0.514766, 0.005847, -0.009020}}],
    Polygon[{{0.512240, 0.006515, -0.007884},{0.511320, 0.005847, -0.006553},{
      0.513316, 0.003852, -0.006553},{0.513984, 0.004771, -0.007884}}],
    Polygon[{{0.511320, 0.005847, -0.006553},{0.510581, 0.005310, -0.005062},{
      0.512779, 0.003112, -0.005062},{0.513316, 0.003852, -0.006553}}],
    Polygon[{{0.510581, 0.005310, -0.005062},{0.510039, 0.004917, -0.003445},{
      0.512385, 0.002571, -0.003445},{0.512779, 0.003112, -0.005062}}],
    Polygon[{{0.510039, 0.004917, -0.003445},{0.509709, 0.004676, -0.001744},{
      0.512145, 0.002240, -0.001744},{0.512385, 0.002571, -0.003445}}],
    Polygon[{{0.509709, 0.004676, -0.001744},{0.509598, 0.004596, 0.000000},{
      0.512064, 0.002129, 0.000000},{0.512145, 0.002240, -0.001744}}],
    Polygon[{{0.509598, 0.004596, 0.000000},{0.509709, 0.004676, 0.001744},{
      0.512145, 0.002240, 0.001744},{0.512064, 0.002129, 0.000000}}],
    Polygon[{{0.509709, 0.004676, 0.001744},{0.510039, 0.004917, 0.003445},{
      0.512385, 0.002571, 0.003445},{0.512145, 0.002240, 0.001744}}],
    Polygon[{{0.510039, 0.004917, 0.003445},{0.510581, 0.005310, 0.005062},{
      0.512779, 0.003112, 0.005062},{0.512385, 0.002571, 0.003445}}],
    Polygon[{{0.510581, 0.005310, 0.005062},{0.511320, 0.005847, 0.006553},{
      0.513316, 0.003852, 0.006553},{0.512779, 0.003112, 0.005062}}],
    Polygon[{{0.511320, 0.005847, 0.006553},{0.512240, 0.006515, 0.007884},{
      0.513984, 0.004771, 0.007884},{0.513316, 0.003852, 0.006553}}],
    Polygon[{{0.512240, 0.006515, 0.007884},{0.513316, 0.007297, 0.009020},{
      0.514766, 0.005847, 0.009020},{0.513984, 0.004771, 0.007884}}],
    Polygon[{{0.513316, 0.007297, 0.009020},{0.514523, 0.008174, 0.009934},{
      0.515642, 0.007054, 0.009934},{0.514766, 0.005847, 0.009020}}],
    Polygon[{{0.514523, 0.008174, 0.009934},{0.515830, 0.009124, 0.010603},{
      0.516592, 0.008362, 0.010603},{0.515642, 0.007054, 0.009934}}],
    Polygon[{{0.515830, 0.009124, 0.010603},{0.517207, 0.010124, 0.011012},{
      0.517592, 0.009738, 0.011012},{0.516592, 0.008362, 0.010603}}],
    Polygon[{{0.517592, 0.009738, -0.011012},{0.516592, 0.008362, -0.010603},{
      0.517553, 0.007872, -0.010603},{0.518079, 0.009490, -0.011012}}],
    Polygon[{{0.516592, 0.008362, -0.010603},{0.515642, 0.007054, -0.009934},{
      0.517053, 0.006335, -0.009934},{0.517553, 0.007872, -0.010603}}],
    Polygon[{{0.515642, 0.007054, -0.009934},{0.514766, 0.005847, -0.009020},{
      0.516592, 0.004917, -0.009020},{0.517053, 0.006335, -0.009934}}],
    Polygon[{{0.514766, 0.005847, -0.009020},{0.513984, 0.004771, -0.007884},{
      0.516181, 0.003651, -0.007884},{0.516592, 0.004917, -0.009020}}],
    Polygon[{{0.513984, 0.004771, -0.007884},{0.513316, 0.003852, -0.006553},{
      0.515830, 0.002571, -0.006553},{0.516181, 0.003651, -0.007884}}],
    Polygon[{{0.513316, 0.003852, -0.006553},{0.512779, 0.003112, -0.005062},{
      0.515548, 0.001701, -0.005062},{0.515830, 0.002571, -0.006553}}],
    Polygon[{{0.512779, 0.003112, -0.005062},{0.512385, 0.002571, -0.003445},{
      0.515341, 0.001065, -0.003445},{0.515548, 0.001701, -0.005062}}],
    Polygon[{{0.512385, 0.002571, -0.003445},{0.512145, 0.002240, -0.001744},{
      0.515215, 0.000676, -0.001744},{0.515341, 0.001065, -0.003445}}],
    Polygon[{{0.512145, 0.002240, -0.001744},{0.512064, 0.002129, 0.000000},{
      0.515172, 0.000546, 0.000000},{0.515215, 0.000676, -0.001744}}],
    Polygon[{{0.512064, 0.002129, 0.000000},{0.512145, 0.002240, 0.001744},{
      0.515215, 0.000676, 0.001744},{0.515172, 0.000546, 0.000000}}],
    Polygon[{{0.512145, 0.002240, 0.001744},{0.512385, 0.002571, 0.003445},{
      0.515341, 0.001065, 0.003445},{0.515215, 0.000676, 0.001744}}],
    Polygon[{{0.512385, 0.002571, 0.003445},{0.512779, 0.003112, 0.005062},{
      0.515548, 0.001701, 0.005062},{0.515341, 0.001065, 0.003445}}],
    Polygon[{{0.512779, 0.003112, 0.005062},{0.513316, 0.003852, 0.006553},{
      0.515830, 0.002571, 0.006553},{0.515548, 0.001701, 0.005062}}],
    Polygon[{{0.513316, 0.003852, 0.006553},{0.513984, 0.004771, 0.007884},{
      0.516181, 0.003651, 0.007884},{0.515830, 0.002571, 0.006553}}],
    Polygon[{{0.513984, 0.004771, 0.007884},{0.514766, 0.005847, 0.009020},{
      0.516592, 0.004917, 0.009020},{0.516181, 0.003651, 0.007884}}],
    Polygon[{{0.514766, 0.005847, 0.009020},{0.515642, 0.007054, 0.009934},{
      0.517053, 0.006335, 0.009934},{0.516592, 0.004917, 0.009020}}],
    Polygon[{{0.515642, 0.007054, 0.009934},{0.516592, 0.008362, 0.010603},{
      0.517553, 0.007872, 0.010603},{0.517053, 0.006335, 0.009934}}],
    Polygon[{{0.516592, 0.008362, 0.010603},{0.517592, 0.009738, 0.011012},{
      0.518079, 0.009490, 0.011012},{0.517553, 0.007872, 0.010603}}],
    Polygon[{{0.518079, 0.009490, -0.011012},{0.517553, 0.007872, -0.010603},{
      0.518618, 0.007704, -0.010603},{0.518618, 0.009405, -0.011012}}],
    Polygon[{{0.517553, 0.007872, -0.010603},{0.517053, 0.006335, -0.009934},{
      0.518618, 0.006087, -0.009934},{0.518618, 0.007704, -0.010603}}],
    Polygon[{{0.517053, 0.006335, -0.009934},{0.516592, 0.004917, -0.009020},{
      0.518618, 0.004596, -0.009020},{0.518618, 0.006087, -0.009934}}],
    Polygon[{{0.516592, 0.004917, -0.009020},{0.516181, 0.003651, -0.007884},{
      0.518618, 0.003265, -0.007884},{0.518618, 0.004596, -0.009020}}],
    Polygon[{{0.516181, 0.003651, -0.007884},{0.515830, 0.002571, -0.006553},{
      0.518618, 0.002129, -0.006553},{0.518618, 0.003265, -0.007884}}],
    Polygon[{{0.515830, 0.002571, -0.006553},{0.515548, 0.001701, -0.005062},{
      0.518618, 0.001215, -0.005062},{0.518618, 0.002129, -0.006553}}],
    Polygon[{{0.515548, 0.001701, -0.005062},{0.515341, 0.001065, -0.003445},{
      0.518618, 0.000546, -0.003445},{0.518618, 0.001215, -0.005062}}],
    Polygon[{{0.515341, 0.001065, -0.003445},{0.515215, 0.000676, -0.001744},{
      0.518618, 0.000137, -0.001744},{0.518618, 0.000546, -0.003445}}],
    Polygon[{{0.515215, 0.000676, -0.001744},{0.515172, 0.000546, 0.000000},{
      0.518618, 0.000000, 0.000000},{0.518618, 0.000137, -0.001744}}],
    Polygon[{{0.515172, 0.000546, 0.000000},{0.515215, 0.000676, 0.001744},{
      0.518618, 0.000137, 0.001744},{0.518618, 0.000000, 0.000000}}],
    Polygon[{{0.515215, 0.000676, 0.001744},{0.515341, 0.001065, 0.003445},{
      0.518618, 0.000546, 0.003445},{0.518618, 0.000137, 0.001744}}],
    Polygon[{{0.515341, 0.001065, 0.003445},{0.515548, 0.001701, 0.005062},{
      0.518618, 0.001215, 0.005062},{0.518618, 0.000546, 0.003445}}],
    Polygon[{{0.515548, 0.001701, 0.005062},{0.515830, 0.002571, 0.006553},{
      0.518618, 0.002129, 0.006553},{0.518618, 0.001215, 0.005062}}],
    Polygon[{{0.515830, 0.002571, 0.006553},{0.516181, 0.003651, 0.007884},{
      0.518618, 0.003265, 0.007884},{0.518618, 0.002129, 0.006553}}],
    Polygon[{{0.516181, 0.003651, 0.007884},{0.516592, 0.004917, 0.009020},{
      0.518618, 0.004596, 0.009020},{0.518618, 0.003265, 0.007884}}],
    Polygon[{{0.516592, 0.004917, 0.009020},{0.517053, 0.006335, 0.009934},{
      0.518618, 0.006087, 0.009934},{0.518618, 0.004596, 0.009020}}],
    Polygon[{{0.517053, 0.006335, 0.009934},{0.517553, 0.007872, 0.010603},{
      0.518618, 0.007704, 0.010603},{0.518618, 0.006087, 0.009934}}],
    Polygon[{{0.517553, 0.007872, 0.010603},{0.518079, 0.009490, 0.011012},{
      0.518618, 0.009405, 0.011012},{0.518618, 0.007704, 0.010603}}],
    Polygon[{{0.518618, 0.009405, -0.011012},{0.518618, 0.007704, -0.010603},{
      0.519682, 0.007872, -0.010603},{0.519157, 0.009490, -0.011012}}],
    Polygon[{{0.518618, 0.007704, -0.010603},{0.518618, 0.006087, -0.009934},{
      0.520182, 0.006335, -0.009934},{0.519682, 0.007872, -0.010603}}],
    Polygon[{{0.518618, 0.006087, -0.009934},{0.518618, 0.004596, -0.009020},{
      0.520643, 0.004917, -0.009020},{0.520182, 0.006335, -0.009934}}],
    Polygon[{{0.518618, 0.004596, -0.009020},{0.518618, 0.003265, -0.007884},{
      0.521054, 0.003651, -0.007884},{0.520643, 0.004917, -0.009020}}],
    Polygon[{{0.518618, 0.003265, -0.007884},{0.518618, 0.002129, -0.006553},{
      0.521405, 0.002571, -0.006553},{0.521054, 0.003651, -0.007884}}],
    Polygon[{{0.518618, 0.002129, -0.006553},{0.518618, 0.001215, -0.005062},{
      0.521687, 0.001701, -0.005062},{0.521405, 0.002571, -0.006553}}],
    Polygon[{{0.518618, 0.001215, -0.005062},{0.518618, 0.000546, -0.003445},{
      0.521894, 0.001065, -0.003445},{0.521687, 0.001701, -0.005062}}],
    Polygon[{{0.518618, 0.000546, -0.003445},{0.518618, 0.000137, -0.001744},{
      0.522020, 0.000676, -0.001744},{0.521894, 0.001065, -0.003445}}],
    Polygon[{{0.518618, 0.000137, -0.001744},{0.518618, 0.000000, 0.000000},{
      0.522063, 0.000546, 0.000000},{0.522020, 0.000676, -0.001744}}],
    Polygon[{{0.518618, 0.000000, 0.000000},{0.518618, 0.000137, 0.001744},{
      0.522020, 0.000676, 0.001744},{0.522063, 0.000546, 0.000000}}],
    Polygon[{{0.518618, 0.000137, 0.001744},{0.518618, 0.000546, 0.003445},{
      0.521894, 0.001065, 0.003445},{0.522020, 0.000676, 0.001744}}],
    Polygon[{{0.518618, 0.000546, 0.003445},{0.518618, 0.001215, 0.005062},{
      0.521687, 0.001701, 0.005062},{0.521894, 0.001065, 0.003445}}],
    Polygon[{{0.518618, 0.001215, 0.005062},{0.518618, 0.002129, 0.006553},{
      0.521405, 0.002571, 0.006553},{0.521687, 0.001701, 0.005062}}],
    Polygon[{{0.518618, 0.002129, 0.006553},{0.518618, 0.003265, 0.007884},{
      0.521054, 0.003651, 0.007884},{0.521405, 0.002571, 0.006553}}],
    Polygon[{{0.518618, 0.003265, 0.007884},{0.518618, 0.004596, 0.009020},{
      0.520643, 0.004917, 0.009020},{0.521054, 0.003651, 0.007884}}],
    Polygon[{{0.518618, 0.004596, 0.009020},{0.518618, 0.006087, 0.009934},{
      0.520182, 0.006335, 0.009934},{0.520643, 0.004917, 0.009020}}],
    Polygon[{{0.518618, 0.006087, 0.009934},{0.518618, 0.007704, 0.010603},{
      0.519682, 0.007872, 0.010603},{0.520182, 0.006335, 0.009934}}],
    Polygon[{{0.518618, 0.007704, 0.010603},{0.518618, 0.009405, 0.011012},{
      0.519157, 0.009490, 0.011012},{0.519682, 0.007872, 0.010603}}],
    Polygon[{{0.519157, 0.009490, -0.011012},{0.519682, 0.007872, -0.010603},{
      0.520643, 0.008362, -0.010603},{0.519643, 0.009738, -0.011012}}],
    Polygon[{{0.519682, 0.007872, -0.010603},{0.520182, 0.006335, -0.009934},{
      0.521593, 0.007054, -0.009934},{0.520643, 0.008362, -0.010603}}],
    Polygon[{{0.520182, 0.006335, -0.009934},{0.520643, 0.004917, -0.009020},{
      0.522469, 0.005847, -0.009020},{0.521593, 0.007054, -0.009934}}],
    Polygon[{{0.520643, 0.004917, -0.009020},{0.521054, 0.003651, -0.007884},{
      0.523251, 0.004771, -0.007884},{0.522469, 0.005847, -0.009020}}],
    Polygon[{{0.521054, 0.003651, -0.007884},{0.521405, 0.002571, -0.006553},{
      0.523919, 0.003852, -0.006553},{0.523251, 0.004771, -0.007884}}],
    Polygon[{{0.521405, 0.002571, -0.006553},{0.521687, 0.001701, -0.005062},{
      0.524457, 0.003112, -0.005062},{0.523919, 0.003852, -0.006553}}],
    Polygon[{{0.521687, 0.001701, -0.005062},{0.521894, 0.001065, -0.003445},{
      0.524850, 0.002571, -0.003445},{0.524457, 0.003112, -0.005062}}],
    Polygon[{{0.521894, 0.001065, -0.003445},{0.522020, 0.000676, -0.001744},{
      0.525090, 0.002240, -0.001744},{0.524850, 0.002571, -0.003445}}],
    Polygon[{{0.522020, 0.000676, -0.001744},{0.522063, 0.000546, 0.000000},{
      0.525171, 0.002129, 0.000000},{0.525090, 0.002240, -0.001744}}],
    Polygon[{{0.522063, 0.000546, 0.000000},{0.522020, 0.000676, 0.001744},{
      0.525090, 0.002240, 0.001744},{0.525171, 0.002129, 0.000000}}],
    Polygon[{{0.522020, 0.000676, 0.001744},{0.521894, 0.001065, 0.003445},{
      0.524850, 0.002571, 0.003445},{0.525090, 0.002240, 0.001744}}],
    Polygon[{{0.521894, 0.001065, 0.003445},{0.521687, 0.001701, 0.005062},{
      0.524457, 0.003112, 0.005062},{0.524850, 0.002571, 0.003445}}],
    Polygon[{{0.521687, 0.001701, 0.005062},{0.521405, 0.002571, 0.006553},{
      0.523919, 0.003852, 0.006553},{0.524457, 0.003112, 0.005062}}],
    Polygon[{{0.521405, 0.002571, 0.006553},{0.521054, 0.003651, 0.007884},{
      0.523251, 0.004771, 0.007884},{0.523919, 0.003852, 0.006553}}],
    Polygon[{{0.521054, 0.003651, 0.007884},{0.520643, 0.004917, 0.009020},{
      0.522469, 0.005847, 0.009020},{0.523251, 0.004771, 0.007884}}],
    Polygon[{{0.520643, 0.004917, 0.009020},{0.520182, 0.006335, 0.009934},{
      0.521593, 0.007054, 0.009934},{0.522469, 0.005847, 0.009020}}],
    Polygon[{{0.520182, 0.006335, 0.009934},{0.519682, 0.007872, 0.010603},{
      0.520643, 0.008362, 0.010603},{0.521593, 0.007054, 0.009934}}],
    Polygon[{{0.519682, 0.007872, 0.010603},{0.519157, 0.009490, 0.011012},{
      0.519643, 0.009738, 0.011012},{0.520643, 0.008362, 0.010603}}],
    Polygon[{{0.519643, 0.009738, -0.011012},{0.520643, 0.008362, -0.010603},{
      0.521405, 0.009124, -0.010603},{0.520029, 0.010124, -0.011012}}],
    Polygon[{{0.520643, 0.008362, -0.010603},{0.521593, 0.007054, -0.009934},{
      0.522712, 0.008174, -0.009934},{0.521405, 0.009124, -0.010603}}],
    Polygon[{{0.521593, 0.007054, -0.009934},{0.522469, 0.005847, -0.009020},{
      0.523919, 0.007297, -0.009020},{0.522712, 0.008174, -0.009934}}],
    Polygon[{{0.522469, 0.005847, -0.009020},{0.523251, 0.004771, -0.007884},{
      0.524996, 0.006515, -0.007884},{0.523919, 0.007297, -0.009020}}],
    Polygon[{{0.523251, 0.004771, -0.007884},{0.523919, 0.003852, -0.006553},{
      0.525915, 0.005847, -0.006553},{0.524996, 0.006515, -0.007884}}],
    Polygon[{{0.523919, 0.003852, -0.006553},{0.524457, 0.003112, -0.005062},{
      0.526654, 0.005310, -0.005062},{0.525915, 0.005847, -0.006553}}],
    Polygon[{{0.524457, 0.003112, -0.005062},{0.524850, 0.002571, -0.003445},{
      0.527196, 0.004917, -0.003445},{0.526654, 0.005310, -0.005062}}],
    Polygon[{{0.524850, 0.002571, -0.003445},{0.525090, 0.002240, -0.001744},{
      0.527526, 0.004676, -0.001744},{0.527196, 0.004917, -0.003445}}],
    Polygon[{{0.525090, 0.002240, -0.001744},{0.525171, 0.002129, 0.000000},{
      0.527637, 0.004596, 0.000000},{0.527526, 0.004676, -0.001744}}],
    Polygon[{{0.525171, 0.002129, 0.000000},{0.525090, 0.002240, 0.001744},{
      0.527526, 0.004676, 0.001744},{0.527637, 0.004596, 0.000000}}],
    Polygon[{{0.525090, 0.002240, 0.001744},{0.524850, 0.002571, 0.003445},{
      0.527196, 0.004917, 0.003445},{0.527526, 0.004676, 0.001744}}],
    Polygon[{{0.524850, 0.002571, 0.003445},{0.524457, 0.003112, 0.005062},{
      0.526654, 0.005310, 0.005062},{0.527196, 0.004917, 0.003445}}],
    Polygon[{{0.524457, 0.003112, 0.005062},{0.523919, 0.003852, 0.006553},{
      0.525915, 0.005847, 0.006553},{0.526654, 0.005310, 0.005062}}],
    Polygon[{{0.523919, 0.003852, 0.006553},{0.523251, 0.004771, 0.007884},{
      0.524996, 0.006515, 0.007884},{0.525915, 0.005847, 0.006553}}],
    Polygon[{{0.523251, 0.004771, 0.007884},{0.522469, 0.005847, 0.009020},{
      0.523919, 0.007297, 0.009020},{0.524996, 0.006515, 0.007884}}],
    Polygon[{{0.522469, 0.005847, 0.009020},{0.521593, 0.007054, 0.009934},{
      0.522712, 0.008174, 0.009934},{0.523919, 0.007297, 0.009020}}],
    Polygon[{{0.521593, 0.007054, 0.009934},{0.520643, 0.008362, 0.010603},{
      0.521405, 0.009124, 0.010603},{0.522712, 0.008174, 0.009934}}],
    Polygon[{{0.520643, 0.008362, 0.010603},{0.519643, 0.009738, 0.011012},{
      0.520029, 0.010124, 0.011012},{0.521405, 0.009124, 0.010603}}],
    Polygon[{{0.520029, 0.010124, -0.011012},{0.521405, 0.009124, -0.010603},{
      0.521894, 0.010084, -0.010603},{0.520276, 0.010610, -0.011012}}],
    Polygon[{{0.521405, 0.009124, -0.010603},{0.522712, 0.008174, -0.009934},{
      0.523431, 0.009585, -0.009934},{0.521894, 0.010084, -0.010603}}],
    Polygon[{{0.522712, 0.008174, -0.009934},{0.523919, 0.007297, -0.009020},{
      0.524850, 0.009124, -0.009020},{0.523431, 0.009585, -0.009934}}],
    Polygon[{{0.523919, 0.007297, -0.009020},{0.524996, 0.006515, -0.007884},{
      0.526115, 0.008713, -0.007884},{0.524850, 0.009124, -0.009020}}],
    Polygon[{{0.524996, 0.006515, -0.007884},{0.525915, 0.005847, -0.006553},{
      0.527196, 0.008362, -0.006553},{0.526115, 0.008713, -0.007884}}],
    Polygon[{{0.525915, 0.005847, -0.006553},{0.526654, 0.005310, -0.005062},{
      0.528065, 0.008079, -0.005062},{0.527196, 0.008362, -0.006553}}],
    Polygon[{{0.526654, 0.005310, -0.005062},{0.527196, 0.004917, -0.003445},{
      0.528702, 0.007872, -0.003445},{0.528065, 0.008079, -0.005062}}],
    Polygon[{{0.527196, 0.004917, -0.003445},{0.527526, 0.004676, -0.001744},{
      0.529090, 0.007746, -0.001744},{0.528702, 0.007872, -0.003445}}],
    Polygon[{{0.527526, 0.004676, -0.001744},{0.527637, 0.004596, 0.000000},{
      0.529221, 0.007704, 0.000000},{0.529090, 0.007746, -0.001744}}],
    Polygon[{{0.527637, 0.004596, 0.000000},{0.527526, 0.004676, 0.001744},{
      0.529090, 0.007746, 0.001744},{0.529221, 0.007704, 0.000000}}],
    Polygon[{{0.527526, 0.004676, 0.001744},{0.527196, 0.004917, 0.003445},{
      0.528702, 0.007872, 0.003445},{0.529090, 0.007746, 0.001744}}],
    Polygon[{{0.527196, 0.004917, 0.003445},{0.526654, 0.005310, 0.005062},{
      0.528065, 0.008079, 0.005062},{0.528702, 0.007872, 0.003445}}],
    Polygon[{{0.526654, 0.005310, 0.005062},{0.525915, 0.005847, 0.006553},{
      0.527196, 0.008362, 0.006553},{0.528065, 0.008079, 0.005062}}],
    Polygon[{{0.525915, 0.005847, 0.006553},{0.524996, 0.006515, 0.007884},{
      0.526115, 0.008713, 0.007884},{0.527196, 0.008362, 0.006553}}],
    Polygon[{{0.524996, 0.006515, 0.007884},{0.523919, 0.007297, 0.009020},{
      0.524850, 0.009124, 0.009020},{0.526115, 0.008713, 0.007884}}],
    Polygon[{{0.523919, 0.007297, 0.009020},{0.522712, 0.008174, 0.009934},{
      0.523431, 0.009585, 0.009934},{0.524850, 0.009124, 0.009020}}],
    Polygon[{{0.522712, 0.008174, 0.009934},{0.521405, 0.009124, 0.010603},{
      0.521894, 0.010084, 0.010603},{0.523431, 0.009585, 0.009934}}],
    Polygon[{{0.521405, 0.009124, 0.010603},{0.520029, 0.010124, 0.011012},{
      0.520276, 0.010610, 0.011012},{0.521894, 0.010084, 0.010603}}],
    Polygon[{{0.520276, 0.010610, -0.011012},{0.521894, 0.010084, -0.010603},{
      0.522063, 0.011149, -0.010603},{0.520362, 0.011149, -0.011012}}],
    Polygon[{{0.521894, 0.010084, -0.010603},{0.523431, 0.009585, -0.009934},{
      0.523679, 0.011149, -0.009934},{0.522063, 0.011149, -0.010603}}],
    Polygon[{{0.523431, 0.009585, -0.009934},{0.524850, 0.009124, -0.009020},{
      0.525171, 0.011149, -0.009020},{0.523679, 0.011149, -0.009934}}],
    Polygon[{{0.524850, 0.009124, -0.009020},{0.526115, 0.008713, -0.007884},{
      0.526501, 0.011149, -0.007884},{0.525171, 0.011149, -0.009020}}],
    Polygon[{{0.526115, 0.008713, -0.007884},{0.527196, 0.008362, -0.006553},{
      0.527637, 0.011149, -0.006553},{0.526501, 0.011149, -0.007884}}],
    Polygon[{{0.527196, 0.008362, -0.006553},{0.528065, 0.008079, -0.005062},{
      0.528551, 0.011149, -0.005062},{0.527637, 0.011149, -0.006553}}],
    Polygon[{{0.528065, 0.008079, -0.005062},{0.528702, 0.007872, -0.003445},{
      0.529221, 0.011149, -0.003445},{0.528551, 0.011149, -0.005062}}],
    Polygon[{{0.528702, 0.007872, -0.003445},{0.529090, 0.007746, -0.001744},{
      0.529629, 0.011149, -0.001744},{0.529221, 0.011149, -0.003445}}],
    Polygon[{{0.529090, 0.007746, -0.001744},{0.529221, 0.007704, 0.000000},{
      0.529767, 0.011149, 0.000000},{0.529629, 0.011149, -0.001744}}],
    Polygon[{{0.529221, 0.007704, 0.000000},{0.529090, 0.007746, 0.001744},{
      0.529629, 0.011149, 0.001744},{0.529767, 0.011149, 0.000000}}],
    Polygon[{{0.529090, 0.007746, 0.001744},{0.528702, 0.007872, 0.003445},{
      0.529221, 0.011149, 0.003445},{0.529629, 0.011149, 0.001744}}],
    Polygon[{{0.528702, 0.007872, 0.003445},{0.528065, 0.008079, 0.005062},{
      0.528551, 0.011149, 0.005062},{0.529221, 0.011149, 0.003445}}],
    Polygon[{{0.528065, 0.008079, 0.005062},{0.527196, 0.008362, 0.006553},{
      0.527637, 0.011149, 0.006553},{0.528551, 0.011149, 0.005062}}],
    Polygon[{{0.527196, 0.008362, 0.006553},{0.526115, 0.008713, 0.007884},{
      0.526501, 0.011149, 0.007884},{0.527637, 0.011149, 0.006553}}],
    Polygon[{{0.526115, 0.008713, 0.007884},{0.524850, 0.009124, 0.009020},{
      0.525171, 0.011149, 0.009020},{0.526501, 0.011149, 0.007884}}],
    Polygon[{{0.524850, 0.009124, 0.009020},{0.523431, 0.009585, 0.009934},{
      0.523679, 0.011149, 0.009934},{0.525171, 0.011149, 0.009020}}],
    Polygon[{{0.523431, 0.009585, 0.009934},{0.521894, 0.010084, 0.010603},{
      0.522063, 0.011149, 0.010603},{0.523679, 0.011149, 0.009934}}],
    Polygon[{{0.521894, 0.010084, 0.010603},{0.520276, 0.010610, 0.011012},{
      0.520362, 0.011149, 0.011012},{0.522063, 0.011149, 0.010603}}],
    Polygon[{{0.492670, 0.066488, -0.009381},{0.494119, 0.066488, -0.009033},{
      0.493975, 0.067395, -0.009033},{0.492597, 0.066947, -0.009381}}],
    Polygon[{{0.494119, 0.066488, -0.009033},{0.495496, 0.066488, -0.008463},{
      0.495285, 0.067821, -0.008463},{0.493975, 0.067395, -0.009033}}],
    Polygon[{{0.495496, 0.066488, -0.008463},{0.496767, 0.066488, -0.007684},{
      0.496493, 0.068213, -0.007684},{0.495285, 0.067821, -0.008463}}],
    Polygon[{{0.496767, 0.066488, -0.007684},{0.497900, 0.066488, -0.006716},{
      0.497571, 0.068564, -0.006716},{0.496493, 0.068213, -0.007684}}],
    Polygon[{{0.497900, 0.066488, -0.006716},{0.498868, 0.066488, -0.005583},{
      0.498492, 0.068863, -0.005583},{0.497571, 0.068564, -0.006716}}],
    Polygon[{{0.498868, 0.066488, -0.005583},{0.499647, 0.066488, -0.004312},{
      0.499232, 0.069103, -0.004312},{0.498492, 0.068863, -0.005583}}],
    Polygon[{{0.499647, 0.066488, -0.004312},{0.500217, 0.066488, -0.002935},{
      0.499775, 0.069280, -0.002935},{0.499232, 0.069103, -0.004312}}],
    Polygon[{{0.500217, 0.066488, -0.002935},{0.500565, 0.066488, -0.001486},{
      0.500106, 0.069387, -0.001486},{0.499775, 0.069280, -0.002935}}],
    Polygon[{{0.500565, 0.066488, -0.001486},{0.500682, 0.066488, 0.000000},{
      0.500217, 0.069423, 0.000000},{0.500106, 0.069387, -0.001486}}],
    Polygon[{{0.500682, 0.066488, 0.000000},{0.500565, 0.066488, 0.001486},{
      0.500106, 0.069387, 0.001486},{0.500217, 0.069423, 0.000000}}],
    Polygon[{{0.500565, 0.066488, 0.001486},{0.500217, 0.066488, 0.002935},{
      0.499775, 0.069280, 0.002935},{0.500106, 0.069387, 0.001486}}],
    Polygon[{{0.500217, 0.066488, 0.002935},{0.499647, 0.066488, 0.004312},{
      0.499232, 0.069103, 0.004312},{0.499775, 0.069280, 0.002935}}],
    Polygon[{{0.499647, 0.066488, 0.004312},{0.498868, 0.066488, 0.005583},{
      0.498492, 0.068863, 0.005583},{0.499232, 0.069103, 0.004312}}],
    Polygon[{{0.498868, 0.066488, 0.005583},{0.497900, 0.066488, 0.006716},{
      0.497571, 0.068564, 0.006716},{0.498492, 0.068863, 0.005583}}],
    Polygon[{{0.497900, 0.066488, 0.006716},{0.496767, 0.066488, 0.007684},{
      0.496493, 0.068213, 0.007684},{0.497571, 0.068564, 0.006716}}],
    Polygon[{{0.496767, 0.066488, 0.007684},{0.495496, 0.066488, 0.008463},{
      0.495285, 0.067821, 0.008463},{0.496493, 0.068213, 0.007684}}],
    Polygon[{{0.495496, 0.066488, 0.008463},{0.494119, 0.066488, 0.009033},{
      0.493975, 0.067395, 0.009033},{0.495285, 0.067821, 0.008463}}],
    Polygon[{{0.494119, 0.066488, 0.009033},{0.492670, 0.066488, 0.009381},{
      0.492597, 0.066947, 0.009381},{0.493975, 0.067395, 0.009033}}],
    Polygon[{{0.492597, 0.066947, -0.009381},{0.493975, 0.067395, -0.009033},{
      0.493558, 0.068213, -0.009033},{0.492386, 0.067361, -0.009381}}],
    Polygon[{{0.493975, 0.067395, -0.009033},{0.495285, 0.067821, -0.008463},{
      0.494672, 0.069023, -0.008463},{0.493558, 0.068213, -0.009033}}],
    Polygon[{{0.495285, 0.067821, -0.008463},{0.496493, 0.068213, -0.007684},{
      0.495700, 0.069770, -0.007684},{0.494672, 0.069023, -0.008463}}],
    Polygon[{{0.496493, 0.068213, -0.007684},{0.497571, 0.068564, -0.006716},{
      0.496617, 0.070436, -0.006716},{0.495700, 0.069770, -0.007684}}],
    Polygon[{{0.497571, 0.068564, -0.006716},{0.498492, 0.068863, -0.005583},{
      0.497400, 0.071005, -0.005583},{0.496617, 0.070436, -0.006716}}],
    Polygon[{{0.498492, 0.068863, -0.005583},{0.499232, 0.069103, -0.004312},{
      0.498030, 0.071463, -0.004312},{0.497400, 0.071005, -0.005583}}],
    Polygon[{{0.499232, 0.069103, -0.004312},{0.499775, 0.069280, -0.002935},{
      0.498492, 0.071798, -0.002935},{0.498030, 0.071463, -0.004312}}],
    Polygon[{{0.499775, 0.069280, -0.002935},{0.500106, 0.069387, -0.001486},{
      0.498773, 0.072002, -0.001486},{0.498492, 0.071798, -0.002935}}],
    Polygon[{{0.500106, 0.069387, -0.001486},{0.500217, 0.069423, 0.000000},{
      0.498868, 0.072071, 0.000000},{0.498773, 0.072002, -0.001486}}],
    Polygon[{{0.500217, 0.069423, 0.000000},{0.500106, 0.069387, 0.001486},{
      0.498773, 0.072002, 0.001486},{0.498868, 0.072071, 0.000000}}],
    Polygon[{{0.500106, 0.069387, 0.001486},{0.499775, 0.069280, 0.002935},{
      0.498492, 0.071798, 0.002935},{0.498773, 0.072002, 0.001486}}],
    Polygon[{{0.499775, 0.069280, 0.002935},{0.499232, 0.069103, 0.004312},{
      0.498030, 0.071463, 0.004312},{0.498492, 0.071798, 0.002935}}],
    Polygon[{{0.499232, 0.069103, 0.004312},{0.498492, 0.068863, 0.005583},{
      0.497400, 0.071005, 0.005583},{0.498030, 0.071463, 0.004312}}],
    Polygon[{{0.498492, 0.068863, 0.005583},{0.497571, 0.068564, 0.006716},{
      0.496617, 0.070436, 0.006716},{0.497400, 0.071005, 0.005583}}],
    Polygon[{{0.497571, 0.068564, 0.006716},{0.496493, 0.068213, 0.007684},{
      0.495700, 0.069770, 0.007684},{0.496617, 0.070436, 0.006716}}],
    Polygon[{{0.496493, 0.068213, 0.007684},{0.495285, 0.067821, 0.008463},{
      0.494672, 0.069023, 0.008463},{0.495700, 0.069770, 0.007684}}],
    Polygon[{{0.495285, 0.067821, 0.008463},{0.493975, 0.067395, 0.009033},{
      0.493558, 0.068213, 0.009033},{0.494672, 0.069023, 0.008463}}],
    Polygon[{{0.493975, 0.067395, 0.009033},{0.492597, 0.066947, 0.009381},{
      0.492386, 0.067361, 0.009381},{0.493558, 0.068213, 0.009033}}],
    Polygon[{{0.492386, 0.067361, -0.009381},{0.493558, 0.068213, -0.009033},{
      0.492909, 0.068863, -0.009033},{0.492057, 0.067690, -0.009381}}],
    Polygon[{{0.493558, 0.068213, -0.009033},{0.494672, 0.069023, -0.008463},{
      0.493718, 0.069977, -0.008463},{0.492909, 0.068863, -0.009033}}],
    Polygon[{{0.494672, 0.069023, -0.008463},{0.495700, 0.069770, -0.007684},{
      0.494465, 0.071005, -0.007684},{0.493718, 0.069977, -0.008463}}],
    Polygon[{{0.495700, 0.069770, -0.007684},{0.496617, 0.070436, -0.006716},{
      0.495131, 0.071922, -0.006716},{0.494465, 0.071005, -0.007684}}],
    Polygon[{{0.496617, 0.070436, -0.006716},{0.497400, 0.071005, -0.005583},{
      0.495700, 0.072705, -0.005583},{0.495131, 0.071922, -0.006716}}],
    Polygon[{{0.497400, 0.071005, -0.005583},{0.498030, 0.071463, -0.004312},{
      0.496158, 0.073335, -0.004312},{0.495700, 0.072705, -0.005583}}],
    Polygon[{{0.498030, 0.071463, -0.004312},{0.498492, 0.071798, -0.002935},{
      0.496493, 0.073796, -0.002935},{0.496158, 0.073335, -0.004312}}],
    Polygon[{{0.498492, 0.071798, -0.002935},{0.498773, 0.072002, -0.001486},{
      0.496698, 0.074078, -0.001486},{0.496493, 0.073796, -0.002935}}],
    Polygon[{{0.498773, 0.072002, -0.001486},{0.498868, 0.072071, 0.000000},{
      0.496767, 0.074172, 0.000000},{0.496698, 0.074078, -0.001486}}],
    Polygon[{{0.498868, 0.072071, 0.000000},{0.498773, 0.072002, 0.001486},{
      0.496698, 0.074078, 0.001486},{0.496767, 0.074172, 0.000000}}],
    Polygon[{{0.498773, 0.072002, 0.001486},{0.498492, 0.071798, 0.002935},{
      0.496493, 0.073796, 0.002935},{0.496698, 0.074078, 0.001486}}],
    Polygon[{{0.498492, 0.071798, 0.002935},{0.498030, 0.071463, 0.004312},{
      0.496158, 0.073335, 0.004312},{0.496493, 0.073796, 0.002935}}],
    Polygon[{{0.498030, 0.071463, 0.004312},{0.497400, 0.071005, 0.005583},{
      0.495700, 0.072705, 0.005583},{0.496158, 0.073335, 0.004312}}],
    Polygon[{{0.497400, 0.071005, 0.005583},{0.496617, 0.070436, 0.006716},{
      0.495131, 0.071922, 0.006716},{0.495700, 0.072705, 0.005583}}],
    Polygon[{{0.496617, 0.070436, 0.006716},{0.495700, 0.069770, 0.007684},{
      0.494465, 0.071005, 0.007684},{0.495131, 0.071922, 0.006716}}],
    Polygon[{{0.495700, 0.069770, 0.007684},{0.494672, 0.069023, 0.008463},{
      0.493718, 0.069977, 0.008463},{0.494465, 0.071005, 0.007684}}],
    Polygon[{{0.494672, 0.069023, 0.008463},{0.493558, 0.068213, 0.009033},{
      0.492909, 0.068863, 0.009033},{0.493718, 0.069977, 0.008463}}],
    Polygon[{{0.493558, 0.068213, 0.009033},{0.492386, 0.067361, 0.009381},{
      0.492057, 0.067690, 0.009381},{0.492909, 0.068863, 0.009033}}],
    Polygon[{{0.492057, 0.067690, -0.009381},{0.492909, 0.068863, -0.009033},{
      0.492091, 0.069280, -0.009033},{0.491643, 0.067901, -0.009381}}],
    Polygon[{{0.492909, 0.068863, -0.009033},{0.493718, 0.069977, -0.008463},{
      0.492516, 0.070589, -0.008463},{0.492091, 0.069280, -0.009033}}],
    Polygon[{{0.493718, 0.069977, -0.008463},{0.494465, 0.071005, -0.007684},{
      0.492909, 0.071798, -0.007684},{0.492516, 0.070589, -0.008463}}],
    Polygon[{{0.494465, 0.071005, -0.007684},{0.495131, 0.071922, -0.006716},{
      0.493259, 0.072876, -0.006716},{0.492909, 0.071798, -0.007684}}],
    Polygon[{{0.495131, 0.071922, -0.006716},{0.495700, 0.072705, -0.005583},{
      0.493558, 0.073796, -0.005583},{0.493259, 0.072876, -0.006716}}],
    Polygon[{{0.495700, 0.072705, -0.005583},{0.496158, 0.073335, -0.004312},{
      0.493799, 0.074537, -0.004312},{0.493558, 0.073796, -0.005583}}],
    Polygon[{{0.496158, 0.073335, -0.004312},{0.496493, 0.073796, -0.002935},{
      0.493975, 0.075079, -0.002935},{0.493799, 0.074537, -0.004312}}],
    Polygon[{{0.496493, 0.073796, -0.002935},{0.496698, 0.074078, -0.001486},{
      0.494083, 0.075410, -0.001486},{0.493975, 0.075079, -0.002935}}],
    Polygon[{{0.496698, 0.074078, -0.001486},{0.496767, 0.074172, 0.000000},{
      0.494119, 0.075521, 0.000000},{0.494083, 0.075410, -0.001486}}],
    Polygon[{{0.496767, 0.074172, 0.000000},{0.496698, 0.074078, 0.001486},{
      0.494083, 0.075410, 0.001486},{0.494119, 0.075521, 0.000000}}],
    Polygon[{{0.496698, 0.074078, 0.001486},{0.496493, 0.073796, 0.002935},{
      0.493975, 0.075079, 0.002935},{0.494083, 0.075410, 0.001486}}],
    Polygon[{{0.496493, 0.073796, 0.002935},{0.496158, 0.073335, 0.004312},{
      0.493799, 0.074537, 0.004312},{0.493975, 0.075079, 0.002935}}],
    Polygon[{{0.496158, 0.073335, 0.004312},{0.495700, 0.072705, 0.005583},{
      0.493558, 0.073796, 0.005583},{0.493799, 0.074537, 0.004312}}],
    Polygon[{{0.495700, 0.072705, 0.005583},{0.495131, 0.071922, 0.006716},{
      0.493259, 0.072876, 0.006716},{0.493558, 0.073796, 0.005583}}],
    Polygon[{{0.495131, 0.071922, 0.006716},{0.494465, 0.071005, 0.007684},{
      0.492909, 0.071798, 0.007684},{0.493259, 0.072876, 0.006716}}],
    Polygon[{{0.494465, 0.071005, 0.007684},{0.493718, 0.069977, 0.008463},{
      0.492516, 0.070589, 0.008463},{0.492909, 0.071798, 0.007684}}],
    Polygon[{{0.493718, 0.069977, 0.008463},{0.492909, 0.068863, 0.009033},{
      0.492091, 0.069280, 0.009033},{0.492516, 0.070589, 0.008463}}],
    Polygon[{{0.492909, 0.068863, 0.009033},{0.492057, 0.067690, 0.009381},{
      0.491643, 0.067901, 0.009381},{0.492091, 0.069280, 0.009033}}],
    Polygon[{{0.491643, 0.067901, -0.009381},{0.492091, 0.069280, -0.009033},{
      0.491184, 0.069423, -0.009033},{0.491184, 0.067974, -0.009381}}],
    Polygon[{{0.492091, 0.069280, -0.009033},{0.492516, 0.070589, -0.008463},{
      0.491184, 0.070800, -0.008463},{0.491184, 0.069423, -0.009033}}],
    Polygon[{{0.492516, 0.070589, -0.008463},{0.492909, 0.071798, -0.007684},{
      0.491184, 0.072071, -0.007684},{0.491184, 0.070800, -0.008463}}],
    Polygon[{{0.492909, 0.071798, -0.007684},{0.493259, 0.072876, -0.006716},{
      0.491184, 0.073204, -0.006716},{0.491184, 0.072071, -0.007684}}],
    Polygon[{{0.493259, 0.072876, -0.006716},{0.493558, 0.073796, -0.005583},{
      0.491184, 0.074172, -0.005583},{0.491184, 0.073204, -0.006716}}],
    Polygon[{{0.493558, 0.073796, -0.005583},{0.493799, 0.074537, -0.004312},{
      0.491184, 0.074951, -0.004312},{0.491184, 0.074172, -0.005583}}],
    Polygon[{{0.493799, 0.074537, -0.004312},{0.493975, 0.075079, -0.002935},{
      0.491184, 0.075521, -0.002935},{0.491184, 0.074951, -0.004312}}],
    Polygon[{{0.493975, 0.075079, -0.002935},{0.494083, 0.075410, -0.001486},{
      0.491184, 0.075869, -0.001486},{0.491184, 0.075521, -0.002935}}],
    Polygon[{{0.494083, 0.075410, -0.001486},{0.494119, 0.075521, 0.000000},{
      0.491184, 0.075986, 0.000000},{0.491184, 0.075869, -0.001486}}],
    Polygon[{{0.494119, 0.075521, 0.000000},{0.494083, 0.075410, 0.001486},{
      0.491184, 0.075869, 0.001486},{0.491184, 0.075986, 0.000000}}],
    Polygon[{{0.494083, 0.075410, 0.001486},{0.493975, 0.075079, 0.002935},{
      0.491184, 0.075521, 0.002935},{0.491184, 0.075869, 0.001486}}],
    Polygon[{{0.493975, 0.075079, 0.002935},{0.493799, 0.074537, 0.004312},{
      0.491184, 0.074951, 0.004312},{0.491184, 0.075521, 0.002935}}],
    Polygon[{{0.493799, 0.074537, 0.004312},{0.493558, 0.073796, 0.005583},{
      0.491184, 0.074172, 0.005583},{0.491184, 0.074951, 0.004312}}],
    Polygon[{{0.493558, 0.073796, 0.005583},{0.493259, 0.072876, 0.006716},{
      0.491184, 0.073204, 0.006716},{0.491184, 0.074172, 0.005583}}],
    Polygon[{{0.493259, 0.072876, 0.006716},{0.492909, 0.071798, 0.007684},{
      0.491184, 0.072071, 0.007684},{0.491184, 0.073204, 0.006716}}],
    Polygon[{{0.492909, 0.071798, 0.007684},{0.492516, 0.070589, 0.008463},{
      0.491184, 0.070800, 0.008463},{0.491184, 0.072071, 0.007684}}],
    Polygon[{{0.492516, 0.070589, 0.008463},{0.492091, 0.069280, 0.009033},{
      0.491184, 0.069423, 0.009033},{0.491184, 0.070800, 0.008463}}],
    Polygon[{{0.492091, 0.069280, 0.009033},{0.491643, 0.067901, 0.009381},{
      0.491184, 0.067974, 0.009381},{0.491184, 0.069423, 0.009033}}],
    Polygon[{{0.491184, 0.067974, -0.009381},{0.491184, 0.069423, -0.009033},{
      0.490277, 0.069280, -0.009033},{0.490725, 0.067901, -0.009381}}],
    Polygon[{{0.491184, 0.069423, -0.009033},{0.491184, 0.070800, -0.008463},{
      0.489851, 0.070589, -0.008463},{0.490277, 0.069280, -0.009033}}],
    Polygon[{{0.491184, 0.070800, -0.008463},{0.491184, 0.072071, -0.007684},{
      0.489458, 0.071798, -0.007684},{0.489851, 0.070589, -0.008463}}],
    Polygon[{{0.491184, 0.072071, -0.007684},{0.491184, 0.073204, -0.006716},{
      0.489108, 0.072876, -0.006716},{0.489458, 0.071798, -0.007684}}],
    Polygon[{{0.491184, 0.073204, -0.006716},{0.491184, 0.074172, -0.005583},{
      0.488809, 0.073796, -0.005583},{0.489108, 0.072876, -0.006716}}],
    Polygon[{{0.491184, 0.074172, -0.005583},{0.491184, 0.074951, -0.004312},{
      0.488568, 0.074537, -0.004312},{0.488809, 0.073796, -0.005583}}],
    Polygon[{{0.491184, 0.074951, -0.004312},{0.491184, 0.075521, -0.002935},{
      0.488392, 0.075079, -0.002935},{0.488568, 0.074537, -0.004312}}],
    Polygon[{{0.491184, 0.075521, -0.002935},{0.491184, 0.075869, -0.001486},{
      0.488285, 0.075410, -0.001486},{0.488392, 0.075079, -0.002935}}],
    Polygon[{{0.491184, 0.075869, -0.001486},{0.491184, 0.075986, 0.000000},{
      0.488249, 0.075521, 0.000000},{0.488285, 0.075410, -0.001486}}],
    Polygon[{{0.491184, 0.075986, 0.000000},{0.491184, 0.075869, 0.001486},{
      0.488285, 0.075410, 0.001486},{0.488249, 0.075521, 0.000000}}],
    Polygon[{{0.491184, 0.075869, 0.001486},{0.491184, 0.075521, 0.002935},{
      0.488392, 0.075079, 0.002935},{0.488285, 0.075410, 0.001486}}],
    Polygon[{{0.491184, 0.075521, 0.002935},{0.491184, 0.074951, 0.004312},{
      0.488568, 0.074537, 0.004312},{0.488392, 0.075079, 0.002935}}],
    Polygon[{{0.491184, 0.074951, 0.004312},{0.491184, 0.074172, 0.005583},{
      0.488809, 0.073796, 0.005583},{0.488568, 0.074537, 0.004312}}],
    Polygon[{{0.491184, 0.074172, 0.005583},{0.491184, 0.073204, 0.006716},{
      0.489108, 0.072876, 0.006716},{0.488809, 0.073796, 0.005583}}],
    Polygon[{{0.491184, 0.073204, 0.006716},{0.491184, 0.072071, 0.007684},{
      0.489458, 0.071798, 0.007684},{0.489108, 0.072876, 0.006716}}],
    Polygon[{{0.491184, 0.072071, 0.007684},{0.491184, 0.070800, 0.008463},{
      0.489851, 0.070589, 0.008463},{0.489458, 0.071798, 0.007684}}],
    Polygon[{{0.491184, 0.070800, 0.008463},{0.491184, 0.069423, 0.009033},{
      0.490277, 0.069280, 0.009033},{0.489851, 0.070589, 0.008463}}],
    Polygon[{{0.491184, 0.069423, 0.009033},{0.491184, 0.067974, 0.009381},{
      0.490725, 0.067901, 0.009381},{0.490277, 0.069280, 0.009033}}],
    Polygon[{{0.490725, 0.067901, -0.009381},{0.490277, 0.069280, -0.009033},{
      0.489458, 0.068863, -0.009033},{0.490310, 0.067690, -0.009381}}],
    Polygon[{{0.490277, 0.069280, -0.009033},{0.489851, 0.070589, -0.008463},{
      0.488649, 0.069977, -0.008463},{0.489458, 0.068863, -0.009033}}],
    Polygon[{{0.489851, 0.070589, -0.008463},{0.489458, 0.071798, -0.007684},{
      0.487902, 0.071005, -0.007684},{0.488649, 0.069977, -0.008463}}],
    Polygon[{{0.489458, 0.071798, -0.007684},{0.489108, 0.072876, -0.006716},{
      0.487236, 0.071922, -0.006716},{0.487902, 0.071005, -0.007684}}],
    Polygon[{{0.489108, 0.072876, -0.006716},{0.488809, 0.073796, -0.005583},{
      0.486667, 0.072705, -0.005583},{0.487236, 0.071922, -0.006716}}],
    Polygon[{{0.488809, 0.073796, -0.005583},{0.488568, 0.074537, -0.004312},{
      0.486209, 0.073335, -0.004312},{0.486667, 0.072705, -0.005583}}],
    Polygon[{{0.488568, 0.074537, -0.004312},{0.488392, 0.075079, -0.002935},{
      0.485874, 0.073796, -0.002935},{0.486209, 0.073335, -0.004312}}],
    Polygon[{{0.488392, 0.075079, -0.002935},{0.488285, 0.075410, -0.001486},{
      0.485669, 0.074078, -0.001486},{0.485874, 0.073796, -0.002935}}],
    Polygon[{{0.488285, 0.075410, -0.001486},{0.488249, 0.075521, 0.000000},{
      0.485601, 0.074172, 0.000000},{0.485669, 0.074078, -0.001486}}],
    Polygon[{{0.488249, 0.075521, 0.000000},{0.488285, 0.075410, 0.001486},{
      0.485669, 0.074078, 0.001486},{0.485601, 0.074172, 0.000000}}],
    Polygon[{{0.488285, 0.075410, 0.001486},{0.488392, 0.075079, 0.002935},{
      0.485874, 0.073796, 0.002935},{0.485669, 0.074078, 0.001486}}],
    Polygon[{{0.488392, 0.075079, 0.002935},{0.488568, 0.074537, 0.004312},{
      0.486209, 0.073335, 0.004312},{0.485874, 0.073796, 0.002935}}],
    Polygon[{{0.488568, 0.074537, 0.004312},{0.488809, 0.073796, 0.005583},{
      0.486667, 0.072705, 0.005583},{0.486209, 0.073335, 0.004312}}],
    Polygon[{{0.488809, 0.073796, 0.005583},{0.489108, 0.072876, 0.006716},{
      0.487236, 0.071922, 0.006716},{0.486667, 0.072705, 0.005583}}],
    Polygon[{{0.489108, 0.072876, 0.006716},{0.489458, 0.071798, 0.007684},{
      0.487902, 0.071005, 0.007684},{0.487236, 0.071922, 0.006716}}],
    Polygon[{{0.489458, 0.071798, 0.007684},{0.489851, 0.070589, 0.008463},{
      0.488649, 0.069977, 0.008463},{0.487902, 0.071005, 0.007684}}],
    Polygon[{{0.489851, 0.070589, 0.008463},{0.490277, 0.069280, 0.009033},{
      0.489458, 0.068863, 0.009033},{0.488649, 0.069977, 0.008463}}],
    Polygon[{{0.490277, 0.069280, 0.009033},{0.490725, 0.067901, 0.009381},{
      0.490310, 0.067690, 0.009381},{0.489458, 0.068863, 0.009033}}],
    Polygon[{{0.490310, 0.067690, -0.009381},{0.489458, 0.068863, -0.009033},{
      0.488809, 0.068213, -0.009033},{0.489982, 0.067361, -0.009381}}],
    Polygon[{{0.489458, 0.068863, -0.009033},{0.488649, 0.069977, -0.008463},{
      0.487695, 0.069023, -0.008463},{0.488809, 0.068213, -0.009033}}],
    Polygon[{{0.488649, 0.069977, -0.008463},{0.487902, 0.071005, -0.007684},{
      0.486667, 0.069770, -0.007684},{0.487695, 0.069023, -0.008463}}],
    Polygon[{{0.487902, 0.071005, -0.007684},{0.487236, 0.071922, -0.006716},{
      0.485750, 0.070436, -0.006716},{0.486667, 0.069770, -0.007684}}],
    Polygon[{{0.487236, 0.071922, -0.006716},{0.486667, 0.072705, -0.005583},{
      0.484967, 0.071005, -0.005583},{0.485750, 0.070436, -0.006716}}],
    Polygon[{{0.486667, 0.072705, -0.005583},{0.486209, 0.073335, -0.004312},{
      0.484337, 0.071463, -0.004312},{0.484967, 0.071005, -0.005583}}],
    Polygon[{{0.486209, 0.073335, -0.004312},{0.485874, 0.073796, -0.002935},{
      0.483875, 0.071798, -0.002935},{0.484337, 0.071463, -0.004312}}],
    Polygon[{{0.485874, 0.073796, -0.002935},{0.485669, 0.074078, -0.001486},{
      0.483594, 0.072002, -0.001486},{0.483875, 0.071798, -0.002935}}],
    Polygon[{{0.485669, 0.074078, -0.001486},{0.485601, 0.074172, 0.000000},{
      0.483499, 0.072071, 0.000000},{0.483594, 0.072002, -0.001486}}],
    Polygon[{{0.485601, 0.074172, 0.000000},{0.485669, 0.074078, 0.001486},{
      0.483594, 0.072002, 0.001486},{0.483499, 0.072071, 0.000000}}],
    Polygon[{{0.485669, 0.074078, 0.001486},{0.485874, 0.073796, 0.002935},{
      0.483875, 0.071798, 0.002935},{0.483594, 0.072002, 0.001486}}],
    Polygon[{{0.485874, 0.073796, 0.002935},{0.486209, 0.073335, 0.004312},{
      0.484337, 0.071463, 0.004312},{0.483875, 0.071798, 0.002935}}],
    Polygon[{{0.486209, 0.073335, 0.004312},{0.486667, 0.072705, 0.005583},{
      0.484967, 0.071005, 0.005583},{0.484337, 0.071463, 0.004312}}],
    Polygon[{{0.486667, 0.072705, 0.005583},{0.487236, 0.071922, 0.006716},{
      0.485750, 0.070436, 0.006716},{0.484967, 0.071005, 0.005583}}],
    Polygon[{{0.487236, 0.071922, 0.006716},{0.487902, 0.071005, 0.007684},{
      0.486667, 0.069770, 0.007684},{0.485750, 0.070436, 0.006716}}],
    Polygon[{{0.487902, 0.071005, 0.007684},{0.488649, 0.069977, 0.008463},{
      0.487695, 0.069023, 0.008463},{0.486667, 0.069770, 0.007684}}],
    Polygon[{{0.488649, 0.069977, 0.008463},{0.489458, 0.068863, 0.009033},{
      0.488809, 0.068213, 0.009033},{0.487695, 0.069023, 0.008463}}],
    Polygon[{{0.489458, 0.068863, 0.009033},{0.490310, 0.067690, 0.009381},{
      0.489982, 0.067361, 0.009381},{0.488809, 0.068213, 0.009033}}],
    Polygon[{{0.489982, 0.067361, -0.009381},{0.488809, 0.068213, -0.009033},{
      0.488392, 0.067395, -0.009033},{0.489771, 0.066947, -0.009381}}],
    Polygon[{{0.488809, 0.068213, -0.009033},{0.487695, 0.069023, -0.008463},{
      0.487083, 0.067821, -0.008463},{0.488392, 0.067395, -0.009033}}],
    Polygon[{{0.487695, 0.069023, -0.008463},{0.486667, 0.069770, -0.007684},{
      0.485874, 0.068213, -0.007684},{0.487083, 0.067821, -0.008463}}],
    Polygon[{{0.486667, 0.069770, -0.007684},{0.485750, 0.070436, -0.006716},{
      0.484796, 0.068564, -0.006716},{0.485874, 0.068213, -0.007684}}],
    Polygon[{{0.485750, 0.070436, -0.006716},{0.484967, 0.071005, -0.005583},{
      0.483875, 0.068863, -0.005583},{0.484796, 0.068564, -0.006716}}],
    Polygon[{{0.484967, 0.071005, -0.005583},{0.484337, 0.071463, -0.004312},{
      0.483135, 0.069103, -0.004312},{0.483875, 0.068863, -0.005583}}],
    Polygon[{{0.484337, 0.071463, -0.004312},{0.483875, 0.071798, -0.002935},{
      0.482592, 0.069280, -0.002935},{0.483135, 0.069103, -0.004312}}],
    Polygon[{{0.483875, 0.071798, -0.002935},{0.483594, 0.072002, -0.001486},{
      0.482261, 0.069387, -0.001486},{0.482592, 0.069280, -0.002935}}],
    Polygon[{{0.483594, 0.072002, -0.001486},{0.483499, 0.072071, 0.000000},{
      0.482150, 0.069423, 0.000000},{0.482261, 0.069387, -0.001486}}],
    Polygon[{{0.483499, 0.072071, 0.000000},{0.483594, 0.072002, 0.001486},{
      0.482261, 0.069387, 0.001486},{0.482150, 0.069423, 0.000000}}],
    Polygon[{{0.483594, 0.072002, 0.001486},{0.483875, 0.071798, 0.002935},{
      0.482592, 0.069280, 0.002935},{0.482261, 0.069387, 0.001486}}],
    Polygon[{{0.483875, 0.071798, 0.002935},{0.484337, 0.071463, 0.004312},{
      0.483135, 0.069103, 0.004312},{0.482592, 0.069280, 0.002935}}],
    Polygon[{{0.484337, 0.071463, 0.004312},{0.484967, 0.071005, 0.005583},{
      0.483875, 0.068863, 0.005583},{0.483135, 0.069103, 0.004312}}],
    Polygon[{{0.484967, 0.071005, 0.005583},{0.485750, 0.070436, 0.006716},{
      0.484796, 0.068564, 0.006716},{0.483875, 0.068863, 0.005583}}],
    Polygon[{{0.485750, 0.070436, 0.006716},{0.486667, 0.069770, 0.007684},{
      0.485874, 0.068213, 0.007684},{0.484796, 0.068564, 0.006716}}],
    Polygon[{{0.486667, 0.069770, 0.007684},{0.487695, 0.069023, 0.008463},{
      0.487083, 0.067821, 0.008463},{0.485874, 0.068213, 0.007684}}],
    Polygon[{{0.487695, 0.069023, 0.008463},{0.488809, 0.068213, 0.009033},{
      0.488392, 0.067395, 0.009033},{0.487083, 0.067821, 0.008463}}],
    Polygon[{{0.488809, 0.068213, 0.009033},{0.489982, 0.067361, 0.009381},{
      0.489771, 0.066947, 0.009381},{0.488392, 0.067395, 0.009033}}],
    Polygon[{{0.489771, 0.066947, -0.009381},{0.488392, 0.067395, -0.009033},{
      0.488249, 0.066488, -0.009033},{0.489698, 0.066488, -0.009381}}],
    Polygon[{{0.488392, 0.067395, -0.009033},{0.487083, 0.067821, -0.008463},{
      0.486872, 0.066488, -0.008463},{0.488249, 0.066488, -0.009033}}],
    Polygon[{{0.487083, 0.067821, -0.008463},{0.485874, 0.068213, -0.007684},{
      0.485601, 0.066488, -0.007684},{0.486872, 0.066488, -0.008463}}],
    Polygon[{{0.485874, 0.068213, -0.007684},{0.484796, 0.068564, -0.006716},{
      0.484467, 0.066488, -0.006716},{0.485601, 0.066488, -0.007684}}],
    Polygon[{{0.484796, 0.068564, -0.006716},{0.483875, 0.068863, -0.005583},{
      0.483499, 0.066488, -0.005583},{0.484467, 0.066488, -0.006716}}],
    Polygon[{{0.483875, 0.068863, -0.005583},{0.483135, 0.069103, -0.004312},{
      0.482721, 0.066488, -0.004312},{0.483499, 0.066488, -0.005583}}],
    Polygon[{{0.483135, 0.069103, -0.004312},{0.482592, 0.069280, -0.002935},{
      0.482150, 0.066488, -0.002935},{0.482721, 0.066488, -0.004312}}],
    Polygon[{{0.482592, 0.069280, -0.002935},{0.482261, 0.069387, -0.001486},{
      0.481802, 0.066488, -0.001486},{0.482150, 0.066488, -0.002935}}],
    Polygon[{{0.482261, 0.069387, -0.001486},{0.482150, 0.069423, 0.000000},{
      0.481685, 0.066488, 0.000000},{0.481802, 0.066488, -0.001486}}],
    Polygon[{{0.482150, 0.069423, 0.000000},{0.482261, 0.069387, 0.001486},{
      0.481802, 0.066488, 0.001486},{0.481685, 0.066488, 0.000000}}],
    Polygon[{{0.482261, 0.069387, 0.001486},{0.482592, 0.069280, 0.002935},{
      0.482150, 0.066488, 0.002935},{0.481802, 0.066488, 0.001486}}],
    Polygon[{{0.482592, 0.069280, 0.002935},{0.483135, 0.069103, 0.004312},{
      0.482721, 0.066488, 0.004312},{0.482150, 0.066488, 0.002935}}],
    Polygon[{{0.483135, 0.069103, 0.004312},{0.483875, 0.068863, 0.005583},{
      0.483499, 0.066488, 0.005583},{0.482721, 0.066488, 0.004312}}],
    Polygon[{{0.483875, 0.068863, 0.005583},{0.484796, 0.068564, 0.006716},{
      0.484467, 0.066488, 0.006716},{0.483499, 0.066488, 0.005583}}],
    Polygon[{{0.484796, 0.068564, 0.006716},{0.485874, 0.068213, 0.007684},{
      0.485601, 0.066488, 0.007684},{0.484467, 0.066488, 0.006716}}],
    Polygon[{{0.485874, 0.068213, 0.007684},{0.487083, 0.067821, 0.008463},{
      0.486872, 0.066488, 0.008463},{0.485601, 0.066488, 0.007684}}],
    Polygon[{{0.487083, 0.067821, 0.008463},{0.488392, 0.067395, 0.009033},{
      0.488249, 0.066488, 0.009033},{0.486872, 0.066488, 0.008463}}],
    Polygon[{{0.488392, 0.067395, 0.009033},{0.489771, 0.066947, 0.009381},{
      0.489698, 0.066488, 0.009381},{0.488249, 0.066488, 0.009033}}],
    Polygon[{{0.489698, 0.066488, -0.009381},{0.488249, 0.066488, -0.009033},{
      0.488392, 0.065581, -0.009033},{0.489771, 0.066029, -0.009381}}],
    Polygon[{{0.488249, 0.066488, -0.009033},{0.486872, 0.066488, -0.008463},{
      0.487083, 0.065156, -0.008463},{0.488392, 0.065581, -0.009033}}],
    Polygon[{{0.486872, 0.066488, -0.008463},{0.485601, 0.066488, -0.007684},{
      0.485874, 0.064763, -0.007684},{0.487083, 0.065156, -0.008463}}],
    Polygon[{{0.485601, 0.066488, -0.007684},{0.484467, 0.066488, -0.006716},{
      0.484796, 0.064413, -0.006716},{0.485874, 0.064763, -0.007684}}],
    Polygon[{{0.484467, 0.066488, -0.006716},{0.483499, 0.066488, -0.005583},{
      0.483875, 0.064114, -0.005583},{0.484796, 0.064413, -0.006716}}],
    Polygon[{{0.483499, 0.066488, -0.005583},{0.482721, 0.066488, -0.004312},{
      0.483135, 0.063873, -0.004312},{0.483875, 0.064114, -0.005583}}],
    Polygon[{{0.482721, 0.066488, -0.004312},{0.482150, 0.066488, -0.002935},{
      0.482592, 0.063697, -0.002935},{0.483135, 0.063873, -0.004312}}],
    Polygon[{{0.482150, 0.066488, -0.002935},{0.481802, 0.066488, -0.001486},{
      0.482261, 0.063589, -0.001486},{0.482592, 0.063697, -0.002935}}],
    Polygon[{{0.481802, 0.066488, -0.001486},{0.481685, 0.066488, 0.000000},{
      0.482150, 0.063553, 0.000000},{0.482261, 0.063589, -0.001486}}],
    Polygon[{{0.481685, 0.066488, 0.000000},{0.481802, 0.066488, 0.001486},{
      0.482261, 0.063589, 0.001486},{0.482150, 0.063553, 0.000000}}],
    Polygon[{{0.481802, 0.066488, 0.001486},{0.482150, 0.066488, 0.002935},{
      0.482592, 0.063697, 0.002935},{0.482261, 0.063589, 0.001486}}],
    Polygon[{{0.482150, 0.066488, 0.002935},{0.482721, 0.066488, 0.004312},{
      0.483135, 0.063873, 0.004312},{0.482592, 0.063697, 0.002935}}],
    Polygon[{{0.482721, 0.066488, 0.004312},{0.483499, 0.066488, 0.005583},{
      0.483875, 0.064114, 0.005583},{0.483135, 0.063873, 0.004312}}],
    Polygon[{{0.483499, 0.066488, 0.005583},{0.484467, 0.066488, 0.006716},{
      0.484796, 0.064413, 0.006716},{0.483875, 0.064114, 0.005583}}],
    Polygon[{{0.484467, 0.066488, 0.006716},{0.485601, 0.066488, 0.007684},{
      0.485874, 0.064763, 0.007684},{0.484796, 0.064413, 0.006716}}],
    Polygon[{{0.485601, 0.066488, 0.007684},{0.486872, 0.066488, 0.008463},{
      0.487083, 0.065156, 0.008463},{0.485874, 0.064763, 0.007684}}],
    Polygon[{{0.486872, 0.066488, 0.008463},{0.488249, 0.066488, 0.009033},{
      0.488392, 0.065581, 0.009033},{0.487083, 0.065156, 0.008463}}],
    Polygon[{{0.488249, 0.066488, 0.009033},{0.489698, 0.066488, 0.009381},{
      0.489771, 0.066029, 0.009381},{0.488392, 0.065581, 0.009033}}],
    Polygon[{{0.489771, 0.066029, -0.009381},{0.488392, 0.065581, -0.009033},{
      0.488809, 0.064763, -0.009033},{0.489982, 0.065615, -0.009381}}],
    Polygon[{{0.488392, 0.065581, -0.009033},{0.487083, 0.065156, -0.008463},{
      0.487695, 0.063953, -0.008463},{0.488809, 0.064763, -0.009033}}],
    Polygon[{{0.487083, 0.065156, -0.008463},{0.485874, 0.064763, -0.007684},{
      0.486667, 0.063206, -0.007684},{0.487695, 0.063953, -0.008463}}],
    Polygon[{{0.485874, 0.064763, -0.007684},{0.484796, 0.064413, -0.006716},{
      0.485750, 0.062540, -0.006716},{0.486667, 0.063206, -0.007684}}],
    Polygon[{{0.484796, 0.064413, -0.006716},{0.483875, 0.064114, -0.005583},{
      0.484967, 0.061971, -0.005583},{0.485750, 0.062540, -0.006716}}],
    Polygon[{{0.483875, 0.064114, -0.005583},{0.483135, 0.063873, -0.004312},{
      0.484337, 0.061514, -0.004312},{0.484967, 0.061971, -0.005583}}],
    Polygon[{{0.483135, 0.063873, -0.004312},{0.482592, 0.063697, -0.002935},{
      0.483875, 0.061178, -0.002935},{0.484337, 0.061514, -0.004312}}],
    Polygon[{{0.482592, 0.063697, -0.002935},{0.482261, 0.063589, -0.001486},{
      0.483594, 0.060974, -0.001486},{0.483875, 0.061178, -0.002935}}],
    Polygon[{{0.482261, 0.063589, -0.001486},{0.482150, 0.063553, 0.000000},{
      0.483499, 0.060905, 0.000000},{0.483594, 0.060974, -0.001486}}],
    Polygon[{{0.482150, 0.063553, 0.000000},{0.482261, 0.063589, 0.001486},{
      0.483594, 0.060974, 0.001486},{0.483499, 0.060905, 0.000000}}],
    Polygon[{{0.482261, 0.063589, 0.001486},{0.482592, 0.063697, 0.002935},{
      0.483875, 0.061178, 0.002935},{0.483594, 0.060974, 0.001486}}],
    Polygon[{{0.482592, 0.063697, 0.002935},{0.483135, 0.063873, 0.004312},{
      0.484337, 0.061514, 0.004312},{0.483875, 0.061178, 0.002935}}],
    Polygon[{{0.483135, 0.063873, 0.004312},{0.483875, 0.064114, 0.005583},{
      0.484967, 0.061971, 0.005583},{0.484337, 0.061514, 0.004312}}],
    Polygon[{{0.483875, 0.064114, 0.005583},{0.484796, 0.064413, 0.006716},{
      0.485750, 0.062540, 0.006716},{0.484967, 0.061971, 0.005583}}],
    Polygon[{{0.484796, 0.064413, 0.006716},{0.485874, 0.064763, 0.007684},{
      0.486667, 0.063206, 0.007684},{0.485750, 0.062540, 0.006716}}],
    Polygon[{{0.485874, 0.064763, 0.007684},{0.487083, 0.065156, 0.008463},{
      0.487695, 0.063953, 0.008463},{0.486667, 0.063206, 0.007684}}],
    Polygon[{{0.487083, 0.065156, 0.008463},{0.488392, 0.065581, 0.009033},{
      0.488809, 0.064763, 0.009033},{0.487695, 0.063953, 0.008463}}],
    Polygon[{{0.488392, 0.065581, 0.009033},{0.489771, 0.066029, 0.009381},{
      0.489982, 0.065615, 0.009381},{0.488809, 0.064763, 0.009033}}],
    Polygon[{{0.489982, 0.065615, -0.009381},{0.488809, 0.064763, -0.009033},{
      0.489458, 0.064114, -0.009033},{0.490310, 0.065286, -0.009381}}],
    Polygon[{{0.488809, 0.064763, -0.009033},{0.487695, 0.063953, -0.008463},{
      0.488649, 0.062999, -0.008463},{0.489458, 0.064114, -0.009033}}],
    Polygon[{{0.487695, 0.063953, -0.008463},{0.486667, 0.063206, -0.007684},{
      0.487902, 0.061971, -0.007684},{0.488649, 0.062999, -0.008463}}],
    Polygon[{{0.486667, 0.063206, -0.007684},{0.485750, 0.062540, -0.006716},{
      0.487236, 0.061054, -0.006716},{0.487902, 0.061971, -0.007684}}],
    Polygon[{{0.485750, 0.062540, -0.006716},{0.484967, 0.061971, -0.005583},{
      0.486667, 0.060271, -0.005583},{0.487236, 0.061054, -0.006716}}],
    Polygon[{{0.484967, 0.061971, -0.005583},{0.484337, 0.061514, -0.004312},{
      0.486209, 0.059641, -0.004312},{0.486667, 0.060271, -0.005583}}],
    Polygon[{{0.484337, 0.061514, -0.004312},{0.483875, 0.061178, -0.002935},{
      0.485874, 0.059180, -0.002935},{0.486209, 0.059641, -0.004312}}],
    Polygon[{{0.483875, 0.061178, -0.002935},{0.483594, 0.060974, -0.001486},{
      0.485669, 0.058898, -0.001486},{0.485874, 0.059180, -0.002935}}],
    Polygon[{{0.483594, 0.060974, -0.001486},{0.483499, 0.060905, 0.000000},{
      0.485601, 0.058804, 0.000000},{0.485669, 0.058898, -0.001486}}],
    Polygon[{{0.483499, 0.060905, 0.000000},{0.483594, 0.060974, 0.001486},{
      0.485669, 0.058898, 0.001486},{0.485601, 0.058804, 0.000000}}],
    Polygon[{{0.483594, 0.060974, 0.001486},{0.483875, 0.061178, 0.002935},{
      0.485874, 0.059180, 0.002935},{0.485669, 0.058898, 0.001486}}],
    Polygon[{{0.483875, 0.061178, 0.002935},{0.484337, 0.061514, 0.004312},{
      0.486209, 0.059641, 0.004312},{0.485874, 0.059180, 0.002935}}],
    Polygon[{{0.484337, 0.061514, 0.004312},{0.484967, 0.061971, 0.005583},{
      0.486667, 0.060271, 0.005583},{0.486209, 0.059641, 0.004312}}],
    Polygon[{{0.484967, 0.061971, 0.005583},{0.485750, 0.062540, 0.006716},{
      0.487236, 0.061054, 0.006716},{0.486667, 0.060271, 0.005583}}],
    Polygon[{{0.485750, 0.062540, 0.006716},{0.486667, 0.063206, 0.007684},{
      0.487902, 0.061971, 0.007684},{0.487236, 0.061054, 0.006716}}],
    Polygon[{{0.486667, 0.063206, 0.007684},{0.487695, 0.063953, 0.008463},{
      0.488649, 0.062999, 0.008463},{0.487902, 0.061971, 0.007684}}],
    Polygon[{{0.487695, 0.063953, 0.008463},{0.488809, 0.064763, 0.009033},{
      0.489458, 0.064114, 0.009033},{0.488649, 0.062999, 0.008463}}],
    Polygon[{{0.488809, 0.064763, 0.009033},{0.489982, 0.065615, 0.009381},{
      0.490310, 0.065286, 0.009381},{0.489458, 0.064114, 0.009033}}],
    Polygon[{{0.490310, 0.065286, -0.009381},{0.489458, 0.064114, -0.009033},{
      0.490277, 0.063697, -0.009033},{0.490725, 0.065075, -0.009381}}],
    Polygon[{{0.489458, 0.064114, -0.009033},{0.488649, 0.062999, -0.008463},{
      0.489851, 0.062387, -0.008463},{0.490277, 0.063697, -0.009033}}],
    Polygon[{{0.488649, 0.062999, -0.008463},{0.487902, 0.061971, -0.007684},{
      0.489458, 0.061178, -0.007684},{0.489851, 0.062387, -0.008463}}],
    Polygon[{{0.487902, 0.061971, -0.007684},{0.487236, 0.061054, -0.006716},{
      0.489108, 0.060100, -0.006716},{0.489458, 0.061178, -0.007684}}],
    Polygon[{{0.487236, 0.061054, -0.006716},{0.486667, 0.060271, -0.005583},{
      0.488809, 0.059180, -0.005583},{0.489108, 0.060100, -0.006716}}],
    Polygon[{{0.486667, 0.060271, -0.005583},{0.486209, 0.059641, -0.004312},{
      0.488568, 0.058439, -0.004312},{0.488809, 0.059180, -0.005583}}],
    Polygon[{{0.486209, 0.059641, -0.004312},{0.485874, 0.059180, -0.002935},{
      0.488392, 0.057897, -0.002935},{0.488568, 0.058439, -0.004312}}],
    Polygon[{{0.485874, 0.059180, -0.002935},{0.485669, 0.058898, -0.001486},{
      0.488285, 0.057566, -0.001486},{0.488392, 0.057897, -0.002935}}],
    Polygon[{{0.485669, 0.058898, -0.001486},{0.485601, 0.058804, 0.000000},{
      0.488249, 0.057455, 0.000000},{0.488285, 0.057566, -0.001486}}],
    Polygon[{{0.485601, 0.058804, 0.000000},{0.485669, 0.058898, 0.001486},{
      0.488285, 0.057566, 0.001486},{0.488249, 0.057455, 0.000000}}],
    Polygon[{{0.485669, 0.058898, 0.001486},{0.485874, 0.059180, 0.002935},{
      0.488392, 0.057897, 0.002935},{0.488285, 0.057566, 0.001486}}],
    Polygon[{{0.485874, 0.059180, 0.002935},{0.486209, 0.059641, 0.004312},{
      0.488568, 0.058439, 0.004312},{0.488392, 0.057897, 0.002935}}],
    Polygon[{{0.486209, 0.059641, 0.004312},{0.486667, 0.060271, 0.005583},{
      0.488809, 0.059180, 0.005583},{0.488568, 0.058439, 0.004312}}],
    Polygon[{{0.486667, 0.060271, 0.005583},{0.487236, 0.061054, 0.006716},{
      0.489108, 0.060100, 0.006716},{0.488809, 0.059180, 0.005583}}],
    Polygon[{{0.487236, 0.061054, 0.006716},{0.487902, 0.061971, 0.007684},{
      0.489458, 0.061178, 0.007684},{0.489108, 0.060100, 0.006716}}],
    Polygon[{{0.487902, 0.061971, 0.007684},{0.488649, 0.062999, 0.008463},{
      0.489851, 0.062387, 0.008463},{0.489458, 0.061178, 0.007684}}],
    Polygon[{{0.488649, 0.062999, 0.008463},{0.489458, 0.064114, 0.009033},{
      0.490277, 0.063697, 0.009033},{0.489851, 0.062387, 0.008463}}],
    Polygon[{{0.489458, 0.064114, 0.009033},{0.490310, 0.065286, 0.009381},{
      0.490725, 0.065075, 0.009381},{0.490277, 0.063697, 0.009033}}],
    Polygon[{{0.490725, 0.065075, -0.009381},{0.490277, 0.063697, -0.009033},{
      0.491184, 0.063553, -0.009033},{0.491184, 0.065002, -0.009381}}],
    Polygon[{{0.490277, 0.063697, -0.009033},{0.489851, 0.062387, -0.008463},{
      0.491184, 0.062176, -0.008463},{0.491184, 0.063553, -0.009033}}],
    Polygon[{{0.489851, 0.062387, -0.008463},{0.489458, 0.061178, -0.007684},{
      0.491184, 0.060905, -0.007684},{0.491184, 0.062176, -0.008463}}],
    Polygon[{{0.489458, 0.061178, -0.007684},{0.489108, 0.060100, -0.006716},{
      0.491184, 0.059772, -0.006716},{0.491184, 0.060905, -0.007684}}],
    Polygon[{{0.489108, 0.060100, -0.006716},{0.488809, 0.059180, -0.005583},{
      0.491184, 0.058804, -0.005583},{0.491184, 0.059772, -0.006716}}],
    Polygon[{{0.488809, 0.059180, -0.005583},{0.488568, 0.058439, -0.004312},{
      0.491184, 0.058025, -0.004312},{0.491184, 0.058804, -0.005583}}],
    Polygon[{{0.488568, 0.058439, -0.004312},{0.488392, 0.057897, -0.002935},{
      0.491184, 0.057455, -0.002935},{0.491184, 0.058025, -0.004312}}],
    Polygon[{{0.488392, 0.057897, -0.002935},{0.488285, 0.057566, -0.001486},{
      0.491184, 0.057107, -0.001486},{0.491184, 0.057455, -0.002935}}],
    Polygon[{{0.488285, 0.057566, -0.001486},{0.488249, 0.057455, 0.000000},{
      0.491184, 0.056990, 0.000000},{0.491184, 0.057107, -0.001486}}],
    Polygon[{{0.488249, 0.057455, 0.000000},{0.488285, 0.057566, 0.001486},{
      0.491184, 0.057107, 0.001486},{0.491184, 0.056990, 0.000000}}],
    Polygon[{{0.488285, 0.057566, 0.001486},{0.488392, 0.057897, 0.002935},{
      0.491184, 0.057455, 0.002935},{0.491184, 0.057107, 0.001486}}],
    Polygon[{{0.488392, 0.057897, 0.002935},{0.488568, 0.058439, 0.004312},{
      0.491184, 0.058025, 0.004312},{0.491184, 0.057455, 0.002935}}],
    Polygon[{{0.488568, 0.058439, 0.004312},{0.488809, 0.059180, 0.005583},{
      0.491184, 0.058804, 0.005583},{0.491184, 0.058025, 0.004312}}],
    Polygon[{{0.488809, 0.059180, 0.005583},{0.489108, 0.060100, 0.006716},{
      0.491184, 0.059772, 0.006716},{0.491184, 0.058804, 0.005583}}],
    Polygon[{{0.489108, 0.060100, 0.006716},{0.489458, 0.061178, 0.007684},{
      0.491184, 0.060905, 0.007684},{0.491184, 0.059772, 0.006716}}],
    Polygon[{{0.489458, 0.061178, 0.007684},{0.489851, 0.062387, 0.008463},{
      0.491184, 0.062176, 0.008463},{0.491184, 0.060905, 0.007684}}],
    Polygon[{{0.489851, 0.062387, 0.008463},{0.490277, 0.063697, 0.009033},{
      0.491184, 0.063553, 0.009033},{0.491184, 0.062176, 0.008463}}],
    Polygon[{{0.490277, 0.063697, 0.009033},{0.490725, 0.065075, 0.009381},{
      0.491184, 0.065002, 0.009381},{0.491184, 0.063553, 0.009033}}],
    Polygon[{{0.491184, 0.065002, -0.009381},{0.491184, 0.063553, -0.009033},{
      0.492091, 0.063697, -0.009033},{0.491643, 0.065075, -0.009381}}],
    Polygon[{{0.491184, 0.063553, -0.009033},{0.491184, 0.062176, -0.008463},{
      0.492516, 0.062387, -0.008463},{0.492091, 0.063697, -0.009033}}],
    Polygon[{{0.491184, 0.062176, -0.008463},{0.491184, 0.060905, -0.007684},{
      0.492909, 0.061178, -0.007684},{0.492516, 0.062387, -0.008463}}],
    Polygon[{{0.491184, 0.060905, -0.007684},{0.491184, 0.059772, -0.006716},{
      0.493259, 0.060100, -0.006716},{0.492909, 0.061178, -0.007684}}],
    Polygon[{{0.491184, 0.059772, -0.006716},{0.491184, 0.058804, -0.005583},{
      0.493558, 0.059180, -0.005583},{0.493259, 0.060100, -0.006716}}],
    Polygon[{{0.491184, 0.058804, -0.005583},{0.491184, 0.058025, -0.004312},{
      0.493799, 0.058439, -0.004312},{0.493558, 0.059180, -0.005583}}],
    Polygon[{{0.491184, 0.058025, -0.004312},{0.491184, 0.057455, -0.002935},{
      0.493975, 0.057897, -0.002935},{0.493799, 0.058439, -0.004312}}],
    Polygon[{{0.491184, 0.057455, -0.002935},{0.491184, 0.057107, -0.001486},{
      0.494083, 0.057566, -0.001486},{0.493975, 0.057897, -0.002935}}],
    Polygon[{{0.491184, 0.057107, -0.001486},{0.491184, 0.056990, 0.000000},{
      0.494119, 0.057455, 0.000000},{0.494083, 0.057566, -0.001486}}],
    Polygon[{{0.491184, 0.056990, 0.000000},{0.491184, 0.057107, 0.001486},{
      0.494083, 0.057566, 0.001486},{0.494119, 0.057455, 0.000000}}],
    Polygon[{{0.491184, 0.057107, 0.001486},{0.491184, 0.057455, 0.002935},{
      0.493975, 0.057897, 0.002935},{0.494083, 0.057566, 0.001486}}],
    Polygon[{{0.491184, 0.057455, 0.002935},{0.491184, 0.058025, 0.004312},{
      0.493799, 0.058439, 0.004312},{0.493975, 0.057897, 0.002935}}],
    Polygon[{{0.491184, 0.058025, 0.004312},{0.491184, 0.058804, 0.005583},{
      0.493558, 0.059180, 0.005583},{0.493799, 0.058439, 0.004312}}],
    Polygon[{{0.491184, 0.058804, 0.005583},{0.491184, 0.059772, 0.006716},{
      0.493259, 0.060100, 0.006716},{0.493558, 0.059180, 0.005583}}],
    Polygon[{{0.491184, 0.059772, 0.006716},{0.491184, 0.060905, 0.007684},{
      0.492909, 0.061178, 0.007684},{0.493259, 0.060100, 0.006716}}],
    Polygon[{{0.491184, 0.060905, 0.007684},{0.491184, 0.062176, 0.008463},{
      0.492516, 0.062387, 0.008463},{0.492909, 0.061178, 0.007684}}],
    Polygon[{{0.491184, 0.062176, 0.008463},{0.491184, 0.063553, 0.009033},{
      0.492091, 0.063697, 0.009033},{0.492516, 0.062387, 0.008463}}],
    Polygon[{{0.491184, 0.063553, 0.009033},{0.491184, 0.065002, 0.009381},{
      0.491643, 0.065075, 0.009381},{0.492091, 0.063697, 0.009033}}],
    Polygon[{{0.491643, 0.065075, -0.009381},{0.492091, 0.063697, -0.009033},{
      0.492909, 0.064114, -0.009033},{0.492057, 0.065286, -0.009381}}],
    Polygon[{{0.492091, 0.063697, -0.009033},{0.492516, 0.062387, -0.008463},{
      0.493718, 0.062999, -0.008463},{0.492909, 0.064114, -0.009033}}],
    Polygon[{{0.492516, 0.062387, -0.008463},{0.492909, 0.061178, -0.007684},{
      0.494465, 0.061971, -0.007684},{0.493718, 0.062999, -0.008463}}],
    Polygon[{{0.492909, 0.061178, -0.007684},{0.493259, 0.060100, -0.006716},{
      0.495131, 0.061054, -0.006716},{0.494465, 0.061971, -0.007684}}],
    Polygon[{{0.493259, 0.060100, -0.006716},{0.493558, 0.059180, -0.005583},{
      0.495700, 0.060271, -0.005583},{0.495131, 0.061054, -0.006716}}],
    Polygon[{{0.493558, 0.059180, -0.005583},{0.493799, 0.058439, -0.004312},{
      0.496158, 0.059641, -0.004312},{0.495700, 0.060271, -0.005583}}],
    Polygon[{{0.493799, 0.058439, -0.004312},{0.493975, 0.057897, -0.002935},{
      0.496493, 0.059180, -0.002935},{0.496158, 0.059641, -0.004312}}],
    Polygon[{{0.493975, 0.057897, -0.002935},{0.494083, 0.057566, -0.001486},{
      0.496698, 0.058898, -0.001486},{0.496493, 0.059180, -0.002935}}],
    Polygon[{{0.494083, 0.057566, -0.001486},{0.494119, 0.057455, 0.000000},{
      0.496767, 0.058804, 0.000000},{0.496698, 0.058898, -0.001486}}],
    Polygon[{{0.494119, 0.057455, 0.000000},{0.494083, 0.057566, 0.001486},{
      0.496698, 0.058898, 0.001486},{0.496767, 0.058804, 0.000000}}],
    Polygon[{{0.494083, 0.057566, 0.001486},{0.493975, 0.057897, 0.002935},{
      0.496493, 0.059180, 0.002935},{0.496698, 0.058898, 0.001486}}],
    Polygon[{{0.493975, 0.057897, 0.002935},{0.493799, 0.058439, 0.004312},{
      0.496158, 0.059641, 0.004312},{0.496493, 0.059180, 0.002935}}],
    Polygon[{{0.493799, 0.058439, 0.004312},{0.493558, 0.059180, 0.005583},{
      0.495700, 0.060271, 0.005583},{0.496158, 0.059641, 0.004312}}],
    Polygon[{{0.493558, 0.059180, 0.005583},{0.493259, 0.060100, 0.006716},{
      0.495131, 0.061054, 0.006716},{0.495700, 0.060271, 0.005583}}],
    Polygon[{{0.493259, 0.060100, 0.006716},{0.492909, 0.061178, 0.007684},{
      0.494465, 0.061971, 0.007684},{0.495131, 0.061054, 0.006716}}],
    Polygon[{{0.492909, 0.061178, 0.007684},{0.492516, 0.062387, 0.008463},{
      0.493718, 0.062999, 0.008463},{0.494465, 0.061971, 0.007684}}],
    Polygon[{{0.492516, 0.062387, 0.008463},{0.492091, 0.063697, 0.009033},{
      0.492909, 0.064114, 0.009033},{0.493718, 0.062999, 0.008463}}],
    Polygon[{{0.492091, 0.063697, 0.009033},{0.491643, 0.065075, 0.009381},{
      0.492057, 0.065286, 0.009381},{0.492909, 0.064114, 0.009033}}],
    Polygon[{{0.492057, 0.065286, -0.009381},{0.492909, 0.064114, -0.009033},{
      0.493558, 0.064763, -0.009033},{0.492386, 0.065615, -0.009381}}],
    Polygon[{{0.492909, 0.064114, -0.009033},{0.493718, 0.062999, -0.008463},{
      0.494672, 0.063953, -0.008463},{0.493558, 0.064763, -0.009033}}],
    Polygon[{{0.493718, 0.062999, -0.008463},{0.494465, 0.061971, -0.007684},{
      0.495700, 0.063206, -0.007684},{0.494672, 0.063953, -0.008463}}],
    Polygon[{{0.494465, 0.061971, -0.007684},{0.495131, 0.061054, -0.006716},{
      0.496617, 0.062540, -0.006716},{0.495700, 0.063206, -0.007684}}],
    Polygon[{{0.495131, 0.061054, -0.006716},{0.495700, 0.060271, -0.005583},{
      0.497400, 0.061971, -0.005583},{0.496617, 0.062540, -0.006716}}],
    Polygon[{{0.495700, 0.060271, -0.005583},{0.496158, 0.059641, -0.004312},{
      0.498030, 0.061514, -0.004312},{0.497400, 0.061971, -0.005583}}],
    Polygon[{{0.496158, 0.059641, -0.004312},{0.496493, 0.059180, -0.002935},{
      0.498492, 0.061178, -0.002935},{0.498030, 0.061514, -0.004312}}],
    Polygon[{{0.496493, 0.059180, -0.002935},{0.496698, 0.058898, -0.001486},{
      0.498773, 0.060974, -0.001486},{0.498492, 0.061178, -0.002935}}],
    Polygon[{{0.496698, 0.058898, -0.001486},{0.496767, 0.058804, 0.000000},{
      0.498868, 0.060905, 0.000000},{0.498773, 0.060974, -0.001486}}],
    Polygon[{{0.496767, 0.058804, 0.000000},{0.496698, 0.058898, 0.001486},{
      0.498773, 0.060974, 0.001486},{0.498868, 0.060905, 0.000000}}],
    Polygon[{{0.496698, 0.058898, 0.001486},{0.496493, 0.059180, 0.002935},{
      0.498492, 0.061178, 0.002935},{0.498773, 0.060974, 0.001486}}],
    Polygon[{{0.496493, 0.059180, 0.002935},{0.496158, 0.059641, 0.004312},{
      0.498030, 0.061514, 0.004312},{0.498492, 0.061178, 0.002935}}],
    Polygon[{{0.496158, 0.059641, 0.004312},{0.495700, 0.060271, 0.005583},{
      0.497400, 0.061971, 0.005583},{0.498030, 0.061514, 0.004312}}],
    Polygon[{{0.495700, 0.060271, 0.005583},{0.495131, 0.061054, 0.006716},{
      0.496617, 0.062540, 0.006716},{0.497400, 0.061971, 0.005583}}],
    Polygon[{{0.495131, 0.061054, 0.006716},{0.494465, 0.061971, 0.007684},{
      0.495700, 0.063206, 0.007684},{0.496617, 0.062540, 0.006716}}],
    Polygon[{{0.494465, 0.061971, 0.007684},{0.493718, 0.062999, 0.008463},{
      0.494672, 0.063953, 0.008463},{0.495700, 0.063206, 0.007684}}],
    Polygon[{{0.493718, 0.062999, 0.008463},{0.492909, 0.064114, 0.009033},{
      0.493558, 0.064763, 0.009033},{0.494672, 0.063953, 0.008463}}],
    Polygon[{{0.492909, 0.064114, 0.009033},{0.492057, 0.065286, 0.009381},{
      0.492386, 0.065615, 0.009381},{0.493558, 0.064763, 0.009033}}],
    Polygon[{{0.492386, 0.065615, -0.009381},{0.493558, 0.064763, -0.009033},{
      0.493975, 0.065581, -0.009033},{0.492597, 0.066029, -0.009381}}],
    Polygon[{{0.493558, 0.064763, -0.009033},{0.494672, 0.063953, -0.008463},{
      0.495285, 0.065156, -0.008463},{0.493975, 0.065581, -0.009033}}],
    Polygon[{{0.494672, 0.063953, -0.008463},{0.495700, 0.063206, -0.007684},{
      0.496493, 0.064763, -0.007684},{0.495285, 0.065156, -0.008463}}],
    Polygon[{{0.495700, 0.063206, -0.007684},{0.496617, 0.062540, -0.006716},{
      0.497571, 0.064413, -0.006716},{0.496493, 0.064763, -0.007684}}],
    Polygon[{{0.496617, 0.062540, -0.006716},{0.497400, 0.061971, -0.005583},{
      0.498492, 0.064114, -0.005583},{0.497571, 0.064413, -0.006716}}],
    Polygon[{{0.497400, 0.061971, -0.005583},{0.498030, 0.061514, -0.004312},{
      0.499232, 0.063873, -0.004312},{0.498492, 0.064114, -0.005583}}],
    Polygon[{{0.498030, 0.061514, -0.004312},{0.498492, 0.061178, -0.002935},{
      0.499775, 0.063697, -0.002935},{0.499232, 0.063873, -0.004312}}],
    Polygon[{{0.498492, 0.061178, -0.002935},{0.498773, 0.060974, -0.001486},{
      0.500106, 0.063589, -0.001486},{0.499775, 0.063697, -0.002935}}],
    Polygon[{{0.498773, 0.060974, -0.001486},{0.498868, 0.060905, 0.000000},{
      0.500217, 0.063553, 0.000000},{0.500106, 0.063589, -0.001486}}],
    Polygon[{{0.498868, 0.060905, 0.000000},{0.498773, 0.060974, 0.001486},{
      0.500106, 0.063589, 0.001486},{0.500217, 0.063553, 0.000000}}],
    Polygon[{{0.498773, 0.060974, 0.001486},{0.498492, 0.061178, 0.002935},{
      0.499775, 0.063697, 0.002935},{0.500106, 0.063589, 0.001486}}],
    Polygon[{{0.498492, 0.061178, 0.002935},{0.498030, 0.061514, 0.004312},{
      0.499232, 0.063873, 0.004312},{0.499775, 0.063697, 0.002935}}],
    Polygon[{{0.498030, 0.061514, 0.004312},{0.497400, 0.061971, 0.005583},{
      0.498492, 0.064114, 0.005583},{0.499232, 0.063873, 0.004312}}],
    Polygon[{{0.497400, 0.061971, 0.005583},{0.496617, 0.062540, 0.006716},{
      0.497571, 0.064413, 0.006716},{0.498492, 0.064114, 0.005583}}],
    Polygon[{{0.496617, 0.062540, 0.006716},{0.495700, 0.063206, 0.007684},{
      0.496493, 0.064763, 0.007684},{0.497571, 0.064413, 0.006716}}],
    Polygon[{{0.495700, 0.063206, 0.007684},{0.494672, 0.063953, 0.008463},{
      0.495285, 0.065156, 0.008463},{0.496493, 0.064763, 0.007684}}],
    Polygon[{{0.494672, 0.063953, 0.008463},{0.493558, 0.064763, 0.009033},{
      0.493975, 0.065581, 0.009033},{0.495285, 0.065156, 0.008463}}],
    Polygon[{{0.493558, 0.064763, 0.009033},{0.492386, 0.065615, 0.009381},{
      0.492597, 0.066029, 0.009381},{0.493975, 0.065581, 0.009033}}],
    Polygon[{{0.492597, 0.066029, -0.009381},{0.493975, 0.065581, -0.009033},{
      0.494119, 0.066488, -0.009033},{0.492670, 0.066488, -0.009381}}],
    Polygon[{{0.493975, 0.065581, -0.009033},{0.495285, 0.065156, -0.008463},{
      0.495496, 0.066488, -0.008463},{0.494119, 0.066488, -0.009033}}],
    Polygon[{{0.495285, 0.065156, -0.008463},{0.496493, 0.064763, -0.007684},{
      0.496767, 0.066488, -0.007684},{0.495496, 0.066488, -0.008463}}],
    Polygon[{{0.496493, 0.064763, -0.007684},{0.497571, 0.064413, -0.006716},{
      0.497900, 0.066488, -0.006716},{0.496767, 0.066488, -0.007684}}],
    Polygon[{{0.497571, 0.064413, -0.006716},{0.498492, 0.064114, -0.005583},{
      0.498868, 0.066488, -0.005583},{0.497900, 0.066488, -0.006716}}],
    Polygon[{{0.498492, 0.064114, -0.005583},{0.499232, 0.063873, -0.004312},{
      0.499647, 0.066488, -0.004312},{0.498868, 0.066488, -0.005583}}],
    Polygon[{{0.499232, 0.063873, -0.004312},{0.499775, 0.063697, -0.002935},{
      0.500217, 0.066488, -0.002935},{0.499647, 0.066488, -0.004312}}],
    Polygon[{{0.499775, 0.063697, -0.002935},{0.500106, 0.063589, -0.001486},{
      0.500565, 0.066488, -0.001486},{0.500217, 0.066488, -0.002935}}],
    Polygon[{{0.500106, 0.063589, -0.001486},{0.500217, 0.063553, 0.000000},{
      0.500682, 0.066488, 0.000000},{0.500565, 0.066488, -0.001486}}],
    Polygon[{{0.500217, 0.063553, 0.000000},{0.500106, 0.063589, 0.001486},{
      0.500565, 0.066488, 0.001486},{0.500682, 0.066488, 0.000000}}],
    Polygon[{{0.500106, 0.063589, 0.001486},{0.499775, 0.063697, 0.002935},{
      0.500217, 0.066488, 0.002935},{0.500565, 0.066488, 0.001486}}],
    Polygon[{{0.499775, 0.063697, 0.002935},{0.499232, 0.063873, 0.004312},{
      0.499647, 0.066488, 0.004312},{0.500217, 0.066488, 0.002935}}],
    Polygon[{{0.499232, 0.063873, 0.004312},{0.498492, 0.064114, 0.005583},{
      0.498868, 0.066488, 0.005583},{0.499647, 0.066488, 0.004312}}],
    Polygon[{{0.498492, 0.064114, 0.005583},{0.497571, 0.064413, 0.006716},{
      0.497900, 0.066488, 0.006716},{0.498868, 0.066488, 0.005583}}],
    Polygon[{{0.497571, 0.064413, 0.006716},{0.496493, 0.064763, 0.007684},{
      0.496767, 0.066488, 0.007684},{0.497900, 0.066488, 0.006716}}],
    Polygon[{{0.496493, 0.064763, 0.007684},{0.495285, 0.065156, 0.008463},{
      0.495496, 0.066488, 0.008463},{0.496767, 0.066488, 0.007684}}],
    Polygon[{{0.495285, 0.065156, 0.008463},{0.493975, 0.065581, 0.009033},{
      0.494119, 0.066488, 0.009033},{0.495496, 0.066488, 0.008463}}],
    Polygon[{{0.493975, 0.065581, 0.009033},{0.492597, 0.066029, 0.009381},{
      0.492670, 0.066488, 0.009381},{0.494119, 0.066488, 0.009033}}],
    Polygon[{{0.554301, 0.176266, -0.024871},{0.558143, 0.176266, -0.023948},{
      0.557762, 0.178670, -0.023948},{0.554108, 0.177483, -0.024871}}],
    Polygon[{{0.558143, 0.176266, -0.023948},{0.561793, 0.176266, -0.022436},{
      0.561234, 0.179798, -0.022436},{0.557762, 0.178670, -0.023948}}],
    Polygon[{{0.561793, 0.176266, -0.022436},{0.565162, 0.176266, -0.020372},{
      0.564438, 0.180839, -0.020372},{0.561234, 0.179798, -0.022436}}],
    Polygon[{{0.565162, 0.176266, -0.020372},{0.568167, 0.176266, -0.017806},{
      0.567296, 0.181768, -0.017806},{0.564438, 0.180839, -0.020372}}],
    Polygon[{{0.568167, 0.176266, -0.017806},{0.570733, 0.176266, -0.014801},{
      0.569736, 0.182561, -0.014801},{0.567296, 0.181768, -0.017806}}],
    Polygon[{{0.570733, 0.176266, -0.014801},{0.572798, 0.176266, -0.011432},{
      0.571700, 0.183199, -0.011432},{0.569736, 0.182561, -0.014801}}],
    Polygon[{{0.572798, 0.176266, -0.011432},{0.574310, 0.176266, -0.007781},{
      0.573138, 0.183666, -0.007781},{0.571700, 0.183199, -0.011432}}],
    Polygon[{{0.574310, 0.176266, -0.007781},{0.575232, 0.176266, -0.003939},{
      0.574015, 0.183951, -0.003939},{0.573138, 0.183666, -0.007781}}],
    Polygon[{{0.575232, 0.176266, -0.003939},{0.575542, 0.176266, 0.000000},{
      0.574310, 0.184047, 0.000000},{0.574015, 0.183951, -0.003939}}],
    Polygon[{{0.575542, 0.176266, 0.000000},{0.575232, 0.176266, 0.003939},{
      0.574015, 0.183951, 0.003939},{0.574310, 0.184047, 0.000000}}],
    Polygon[{{0.575232, 0.176266, 0.003939},{0.574310, 0.176266, 0.007781},{
      0.573138, 0.183666, 0.007781},{0.574015, 0.183951, 0.003939}}],
    Polygon[{{0.574310, 0.176266, 0.007781},{0.572798, 0.176266, 0.011432},{
      0.571700, 0.183199, 0.011432},{0.573138, 0.183666, 0.007781}}],
    Polygon[{{0.572798, 0.176266, 0.011432},{0.570733, 0.176266, 0.014801},{
      0.569736, 0.182561, 0.014801},{0.571700, 0.183199, 0.011432}}],
    Polygon[{{0.570733, 0.176266, 0.014801},{0.568167, 0.176266, 0.017806},{
      0.567296, 0.181768, 0.017806},{0.569736, 0.182561, 0.014801}}],
    Polygon[{{0.568167, 0.176266, 0.017806},{0.565162, 0.176266, 0.020372},{
      0.564438, 0.180839, 0.020372},{0.567296, 0.181768, 0.017806}}],
    Polygon[{{0.565162, 0.176266, 0.020372},{0.561793, 0.176266, 0.022436},{
      0.561234, 0.179798, 0.022436},{0.564438, 0.180839, 0.020372}}],
    Polygon[{{0.561793, 0.176266, 0.022436},{0.558143, 0.176266, 0.023948},{
      0.557762, 0.178670, 0.023948},{0.561234, 0.179798, 0.022436}}],
    Polygon[{{0.558143, 0.176266, 0.023948},{0.554301, 0.176266, 0.024871},{
      0.554108, 0.177483, 0.024871},{0.557762, 0.178670, 0.023948}}],
    Polygon[{{0.554108, 0.177483, -0.024871},{0.557762, 0.178670, -0.023948},{
      0.556657, 0.180839, -0.023948},{0.553548, 0.178581, -0.024871}}],
    Polygon[{{0.557762, 0.178670, -0.023948},{0.561234, 0.179798, -0.022436},{
      0.559610, 0.182985, -0.022436},{0.556657, 0.180839, -0.023948}}],
    Polygon[{{0.561234, 0.179798, -0.022436},{0.564438, 0.180839, -0.020372},{
      0.562336, 0.184965, -0.020372},{0.559610, 0.182985, -0.022436}}],
    Polygon[{{0.564438, 0.180839, -0.020372},{0.567296, 0.181768, -0.017806},{
      0.564767, 0.186731, -0.017806},{0.562336, 0.184965, -0.020372}}],
    Polygon[{{0.567296, 0.181768, -0.017806},{0.569736, 0.182561, -0.014801},{
      0.566843, 0.188240, -0.014801},{0.564767, 0.186731, -0.017806}}],
    Polygon[{{0.569736, 0.182561, -0.014801},{0.571700, 0.183199, -0.011432},{
      0.568513, 0.189453, -0.011432},{0.566843, 0.188240, -0.014801}}],
    Polygon[{{0.571700, 0.183199, -0.011432},{0.573138, 0.183666, -0.007781},{
      0.569736, 0.190342, -0.007781},{0.568513, 0.189453, -0.011432}}],
    Polygon[{{0.573138, 0.183666, -0.007781},{0.574015, 0.183951, -0.003939},{
      0.570482, 0.190884, -0.003939},{0.569736, 0.190342, -0.007781}}],
    Polygon[{{0.574015, 0.183951, -0.003939},{0.574310, 0.184047, 0.000000},{
      0.570733, 0.191066, 0.000000},{0.570482, 0.190884, -0.003939}}],
    Polygon[{{0.574310, 0.184047, 0.000000},{0.574015, 0.183951, 0.003939},{
      0.570482, 0.190884, 0.003939},{0.570733, 0.191066, 0.000000}}],
    Polygon[{{0.574015, 0.183951, 0.003939},{0.573138, 0.183666, 0.007781},{
      0.569736, 0.190342, 0.007781},{0.570482, 0.190884, 0.003939}}],
    Polygon[{{0.573138, 0.183666, 0.007781},{0.571700, 0.183199, 0.011432},{
      0.568513, 0.189453, 0.011432},{0.569736, 0.190342, 0.007781}}],
    Polygon[{{0.571700, 0.183199, 0.011432},{0.569736, 0.182561, 0.014801},{
      0.566843, 0.188240, 0.014801},{0.568513, 0.189453, 0.011432}}],
    Polygon[{{0.569736, 0.182561, 0.014801},{0.567296, 0.181768, 0.017806},{
      0.564767, 0.186731, 0.017806},{0.566843, 0.188240, 0.014801}}],
    Polygon[{{0.567296, 0.181768, 0.017806},{0.564438, 0.180839, 0.020372},{
      0.562336, 0.184965, 0.020372},{0.564767, 0.186731, 0.017806}}],
    Polygon[{{0.564438, 0.180839, 0.020372},{0.561234, 0.179798, 0.022436},{
      0.559610, 0.182985, 0.022436},{0.562336, 0.184965, 0.020372}}],
    Polygon[{{0.561234, 0.179798, 0.022436},{0.557762, 0.178670, 0.023948},{
      0.556657, 0.180839, 0.023948},{0.559610, 0.182985, 0.022436}}],
    Polygon[{{0.557762, 0.178670, 0.023948},{0.554108, 0.177483, 0.024871},{
      0.553548, 0.178581, 0.024871},{0.556657, 0.180839, 0.023948}}],
    Polygon[{{0.553548, 0.178581, -0.024871},{0.556657, 0.180839, -0.023948},{
      0.554935, 0.182561, -0.023948},{0.552677, 0.179452, -0.024871}}],
    Polygon[{{0.556657, 0.180839, -0.023948},{0.559610, 0.182985, -0.022436},{
      0.557081, 0.185514, -0.022436},{0.554935, 0.182561, -0.023948}}],
    Polygon[{{0.559610, 0.182985, -0.022436},{0.562336, 0.184965, -0.020372},{
      0.559061, 0.188240, -0.020372},{0.557081, 0.185514, -0.022436}}],
    Polygon[{{0.562336, 0.184965, -0.020372},{0.564767, 0.186731, -0.017806},{
      0.560827, 0.190670, -0.017806},{0.559061, 0.188240, -0.020372}}],
    Polygon[{{0.564767, 0.186731, -0.017806},{0.566843, 0.188240, -0.014801},{
      0.562336, 0.192747, -0.014801},{0.560827, 0.190670, -0.017806}}],
    Polygon[{{0.566843, 0.188240, -0.014801},{0.568513, 0.189453, -0.011432},{
      0.563549, 0.194417, -0.011432},{0.562336, 0.192747, -0.014801}}],
    Polygon[{{0.568513, 0.189453, -0.011432},{0.569736, 0.190342, -0.007781},{
      0.564438, 0.195640, -0.007781},{0.563549, 0.194417, -0.011432}}],
    Polygon[{{0.569736, 0.190342, -0.007781},{0.570482, 0.190884, -0.003939},{
      0.564980, 0.196386, -0.003939},{0.564438, 0.195640, -0.007781}}],
    Polygon[{{0.570482, 0.190884, -0.003939},{0.570733, 0.191066, 0.000000},{
      0.565162, 0.196637, 0.000000},{0.564980, 0.196386, -0.003939}}],
    Polygon[{{0.570733, 0.191066, 0.000000},{0.570482, 0.190884, 0.003939},{
      0.564980, 0.196386, 0.003939},{0.565162, 0.196637, 0.000000}}],
    Polygon[{{0.570482, 0.190884, 0.003939},{0.569736, 0.190342, 0.007781},{
      0.564438, 0.195640, 0.007781},{0.564980, 0.196386, 0.003939}}],
    Polygon[{{0.569736, 0.190342, 0.007781},{0.568513, 0.189453, 0.011432},{
      0.563549, 0.194417, 0.011432},{0.564438, 0.195640, 0.007781}}],
    Polygon[{{0.568513, 0.189453, 0.011432},{0.566843, 0.188240, 0.014801},{
      0.562336, 0.192747, 0.014801},{0.563549, 0.194417, 0.011432}}],
    Polygon[{{0.566843, 0.188240, 0.014801},{0.564767, 0.186731, 0.017806},{
      0.560827, 0.190670, 0.017806},{0.562336, 0.192747, 0.014801}}],
    Polygon[{{0.564767, 0.186731, 0.017806},{0.562336, 0.184965, 0.020372},{
      0.559061, 0.188240, 0.020372},{0.560827, 0.190670, 0.017806}}],
    Polygon[{{0.562336, 0.184965, 0.020372},{0.559610, 0.182985, 0.022436},{
      0.557081, 0.185514, 0.022436},{0.559061, 0.188240, 0.020372}}],
    Polygon[{{0.559610, 0.182985, 0.022436},{0.556657, 0.180839, 0.023948},{
      0.554935, 0.182561, 0.023948},{0.557081, 0.185514, 0.022436}}],
    Polygon[{{0.556657, 0.180839, 0.023948},{0.553548, 0.178581, 0.024871},{
      0.552677, 0.179452, 0.024871},{0.554935, 0.182561, 0.023948}}],
    Polygon[{{0.552677, 0.179452, -0.024871},{0.554935, 0.182561, -0.023948},{
      0.552766, 0.183666, -0.023948},{0.551579, 0.180012, -0.024871}}],
    Polygon[{{0.554935, 0.182561, -0.023948},{0.557081, 0.185514, -0.022436},{
      0.553894, 0.187138, -0.022436},{0.552766, 0.183666, -0.023948}}],
    Polygon[{{0.557081, 0.185514, -0.022436},{0.559061, 0.188240, -0.020372},{
      0.554935, 0.190342, -0.020372},{0.553894, 0.187138, -0.022436}}],
    Polygon[{{0.559061, 0.188240, -0.020372},{0.560827, 0.190670, -0.017806},{
      0.555864, 0.193200, -0.017806},{0.554935, 0.190342, -0.020372}}],
    Polygon[{{0.560827, 0.190670, -0.017806},{0.562336, 0.192747, -0.014801},{
      0.556657, 0.195640, -0.014801},{0.555864, 0.193200, -0.017806}}],
    Polygon[{{0.562336, 0.192747, -0.014801},{0.563549, 0.194417, -0.011432},{
      0.557295, 0.197604, -0.011432},{0.556657, 0.195640, -0.014801}}],
    Polygon[{{0.563549, 0.194417, -0.011432},{0.564438, 0.195640, -0.007781},{
      0.557762, 0.199042, -0.007781},{0.557295, 0.197604, -0.011432}}],
    Polygon[{{0.564438, 0.195640, -0.007781},{0.564980, 0.196386, -0.003939},{
      0.558047, 0.199919, -0.003939},{0.557762, 0.199042, -0.007781}}],
    Polygon[{{0.564980, 0.196386, -0.003939},{0.565162, 0.196637, 0.000000},{
      0.558143, 0.200214, 0.000000},{0.558047, 0.199919, -0.003939}}],
    Polygon[{{0.565162, 0.196637, 0.000000},{0.564980, 0.196386, 0.003939},{
      0.558047, 0.199919, 0.003939},{0.558143, 0.200214, 0.000000}}],
    Polygon[{{0.564980, 0.196386, 0.003939},{0.564438, 0.195640, 0.007781},{
      0.557762, 0.199042, 0.007781},{0.558047, 0.199919, 0.003939}}],
    Polygon[{{0.564438, 0.195640, 0.007781},{0.563549, 0.194417, 0.011432},{
      0.557295, 0.197604, 0.011432},{0.557762, 0.199042, 0.007781}}],
    Polygon[{{0.563549, 0.194417, 0.011432},{0.562336, 0.192747, 0.014801},{
      0.556657, 0.195640, 0.014801},{0.557295, 0.197604, 0.011432}}],
    Polygon[{{0.562336, 0.192747, 0.014801},{0.560827, 0.190670, 0.017806},{
      0.555864, 0.193200, 0.017806},{0.556657, 0.195640, 0.014801}}],
    Polygon[{{0.560827, 0.190670, 0.017806},{0.559061, 0.188240, 0.020372},{
      0.554935, 0.190342, 0.020372},{0.555864, 0.193200, 0.017806}}],
    Polygon[{{0.559061, 0.188240, 0.020372},{0.557081, 0.185514, 0.022436},{
      0.553894, 0.187138, 0.022436},{0.554935, 0.190342, 0.020372}}],
    Polygon[{{0.557081, 0.185514, 0.022436},{0.554935, 0.182561, 0.023948},{
      0.552766, 0.183666, 0.023948},{0.553894, 0.187138, 0.022436}}],
    Polygon[{{0.554935, 0.182561, 0.023948},{0.552677, 0.179452, 0.024871},{
      0.551579, 0.180012, 0.024871},{0.552766, 0.183666, 0.023948}}],
    Polygon[{{0.551579, 0.180012, -0.024871},{0.552766, 0.183666, -0.023948},{
      0.550362, 0.184047, -0.023948},{0.550362, 0.180205, -0.024871}}],
    Polygon[{{0.552766, 0.183666, -0.023948},{0.553894, 0.187138, -0.022436},{
      0.550362, 0.187697, -0.022436},{0.550362, 0.184047, -0.023948}}],
    Polygon[{{0.553894, 0.187138, -0.022436},{0.554935, 0.190342, -0.020372},{
      0.550362, 0.191066, -0.020372},{0.550362, 0.187697, -0.022436}}],
    Polygon[{{0.554935, 0.190342, -0.020372},{0.555864, 0.193200, -0.017806},{
      0.550362, 0.194071, -0.017806},{0.550362, 0.191066, -0.020372}}],
    Polygon[{{0.555864, 0.193200, -0.017806},{0.556657, 0.195640, -0.014801},{
      0.550362, 0.196637, -0.014801},{0.550362, 0.194071, -0.017806}}],
    Polygon[{{0.556657, 0.195640, -0.014801},{0.557295, 0.197604, -0.011432},{
      0.550362, 0.198702, -0.011432},{0.550362, 0.196637, -0.014801}}],
    Polygon[{{0.557295, 0.197604, -0.011432},{0.557762, 0.199042, -0.007781},{
      0.550362, 0.200214, -0.007781},{0.550362, 0.198702, -0.011432}}],
    Polygon[{{0.557762, 0.199042, -0.007781},{0.558047, 0.199919, -0.003939},{
      0.550362, 0.201136, -0.003939},{0.550362, 0.200214, -0.007781}}],
    Polygon[{{0.558047, 0.199919, -0.003939},{0.558143, 0.200214, 0.000000},{
      0.550362, 0.201446, 0.000000},{0.550362, 0.201136, -0.003939}}],
    Polygon[{{0.558143, 0.200214, 0.000000},{0.558047, 0.199919, 0.003939},{
      0.550362, 0.201136, 0.003939},{0.550362, 0.201446, 0.000000}}],
    Polygon[{{0.558047, 0.199919, 0.003939},{0.557762, 0.199042, 0.007781},{
      0.550362, 0.200214, 0.007781},{0.550362, 0.201136, 0.003939}}],
    Polygon[{{0.557762, 0.199042, 0.007781},{0.557295, 0.197604, 0.011432},{
      0.550362, 0.198702, 0.011432},{0.550362, 0.200214, 0.007781}}],
    Polygon[{{0.557295, 0.197604, 0.011432},{0.556657, 0.195640, 0.014801},{
      0.550362, 0.196637, 0.014801},{0.550362, 0.198702, 0.011432}}],
    Polygon[{{0.556657, 0.195640, 0.014801},{0.555864, 0.193200, 0.017806},{
      0.550362, 0.194071, 0.017806},{0.550362, 0.196637, 0.014801}}],
    Polygon[{{0.555864, 0.193200, 0.017806},{0.554935, 0.190342, 0.020372},{
      0.550362, 0.191066, 0.020372},{0.550362, 0.194071, 0.017806}}],
    Polygon[{{0.554935, 0.190342, 0.020372},{0.553894, 0.187138, 0.022436},{
      0.550362, 0.187697, 0.022436},{0.550362, 0.191066, 0.020372}}],
    Polygon[{{0.553894, 0.187138, 0.022436},{0.552766, 0.183666, 0.023948},{
      0.550362, 0.184047, 0.023948},{0.550362, 0.187697, 0.022436}}],
    Polygon[{{0.552766, 0.183666, 0.023948},{0.551579, 0.180012, 0.024871},{
      0.550362, 0.180205, 0.024871},{0.550362, 0.184047, 0.023948}}],
    Polygon[{{0.550362, 0.180205, -0.024871},{0.550362, 0.184047, -0.023948},{
      0.547957, 0.183666, -0.023948},{0.549144, 0.180012, -0.024871}}],
    Polygon[{{0.550362, 0.184047, -0.023948},{0.550362, 0.187697, -0.022436},{
      0.546829, 0.187138, -0.022436},{0.547957, 0.183666, -0.023948}}],
    Polygon[{{0.550362, 0.187697, -0.022436},{0.550362, 0.191066, -0.020372},{
      0.545788, 0.190342, -0.020372},{0.546829, 0.187138, -0.022436}}],
    Polygon[{{0.550362, 0.191066, -0.020372},{0.550362, 0.194071, -0.017806},{
      0.544859, 0.193200, -0.017806},{0.545788, 0.190342, -0.020372}}],
    Polygon[{{0.550362, 0.194071, -0.017806},{0.550362, 0.196637, -0.014801},{
      0.544066, 0.195640, -0.014801},{0.544859, 0.193200, -0.017806}}],
    Polygon[{{0.550362, 0.196637, -0.014801},{0.550362, 0.198702, -0.011432},{
      0.543428, 0.197604, -0.011432},{0.544066, 0.195640, -0.014801}}],
    Polygon[{{0.550362, 0.198702, -0.011432},{0.550362, 0.200214, -0.007781},{
      0.542961, 0.199042, -0.007781},{0.543428, 0.197604, -0.011432}}],
    Polygon[{{0.550362, 0.200214, -0.007781},{0.550362, 0.201136, -0.003939},{
      0.542676, 0.199919, -0.003939},{0.542961, 0.199042, -0.007781}}],
    Polygon[{{0.550362, 0.201136, -0.003939},{0.550362, 0.201446, 0.000000},{
      0.542580, 0.200214, 0.000000},{0.542676, 0.199919, -0.003939}}],
    Polygon[{{0.550362, 0.201446, 0.000000},{0.550362, 0.201136, 0.003939},{
      0.542676, 0.199919, 0.003939},{0.542580, 0.200214, 0.000000}}],
    Polygon[{{0.550362, 0.201136, 0.003939},{0.550362, 0.200214, 0.007781},{
      0.542961, 0.199042, 0.007781},{0.542676, 0.199919, 0.003939}}],
    Polygon[{{0.550362, 0.200214, 0.007781},{0.550362, 0.198702, 0.011432},{
      0.543428, 0.197604, 0.011432},{0.542961, 0.199042, 0.007781}}],
    Polygon[{{0.550362, 0.198702, 0.011432},{0.550362, 0.196637, 0.014801},{
      0.544066, 0.195640, 0.014801},{0.543428, 0.197604, 0.011432}}],
    Polygon[{{0.550362, 0.196637, 0.014801},{0.550362, 0.194071, 0.017806},{
      0.544859, 0.193200, 0.017806},{0.544066, 0.195640, 0.014801}}],
    Polygon[{{0.550362, 0.194071, 0.017806},{0.550362, 0.191066, 0.020372},{
      0.545788, 0.190342, 0.020372},{0.544859, 0.193200, 0.017806}}],
    Polygon[{{0.550362, 0.191066, 0.020372},{0.550362, 0.187697, 0.022436},{
      0.546829, 0.187138, 0.022436},{0.545788, 0.190342, 0.020372}}],
    Polygon[{{0.550362, 0.187697, 0.022436},{0.550362, 0.184047, 0.023948},{
      0.547957, 0.183666, 0.023948},{0.546829, 0.187138, 0.022436}}],
    Polygon[{{0.550362, 0.184047, 0.023948},{0.550362, 0.180205, 0.024871},{
      0.549144, 0.180012, 0.024871},{0.547957, 0.183666, 0.023948}}],
    Polygon[{{0.549144, 0.180012, -0.024871},{0.547957, 0.183666, -0.023948},{
      0.545788, 0.182561, -0.023948},{0.548046, 0.179452, -0.024871}}],
    Polygon[{{0.547957, 0.183666, -0.023948},{0.546829, 0.187138, -0.022436},{
      0.543642, 0.185514, -0.022436},{0.545788, 0.182561, -0.023948}}],
    Polygon[{{0.546829, 0.187138, -0.022436},{0.545788, 0.190342, -0.020372},{
      0.541662, 0.188240, -0.020372},{0.543642, 0.185514, -0.022436}}],
    Polygon[{{0.545788, 0.190342, -0.020372},{0.544859, 0.193200, -0.017806},{
      0.539896, 0.190670, -0.017806},{0.541662, 0.188240, -0.020372}}],
    Polygon[{{0.544859, 0.193200, -0.017806},{0.544066, 0.195640, -0.014801},{
      0.538387, 0.192747, -0.014801},{0.539896, 0.190670, -0.017806}}],
    Polygon[{{0.544066, 0.195640, -0.014801},{0.543428, 0.197604, -0.011432},{
      0.537174, 0.194417, -0.011432},{0.538387, 0.192747, -0.014801}}],
    Polygon[{{0.543428, 0.197604, -0.011432},{0.542961, 0.199042, -0.007781},{
      0.536285, 0.195640, -0.007781},{0.537174, 0.194417, -0.011432}}],
    Polygon[{{0.542961, 0.199042, -0.007781},{0.542676, 0.199919, -0.003939},{
      0.535743, 0.196386, -0.003939},{0.536285, 0.195640, -0.007781}}],
    Polygon[{{0.542676, 0.199919, -0.003939},{0.542580, 0.200214, 0.000000},{
      0.535561, 0.196637, 0.000000},{0.535743, 0.196386, -0.003939}}],
    Polygon[{{0.542580, 0.200214, 0.000000},{0.542676, 0.199919, 0.003939},{
      0.535743, 0.196386, 0.003939},{0.535561, 0.196637, 0.000000}}],
    Polygon[{{0.542676, 0.199919, 0.003939},{0.542961, 0.199042, 0.007781},{
      0.536285, 0.195640, 0.007781},{0.535743, 0.196386, 0.003939}}],
    Polygon[{{0.542961, 0.199042, 0.007781},{0.543428, 0.197604, 0.011432},{
      0.537174, 0.194417, 0.011432},{0.536285, 0.195640, 0.007781}}],
    Polygon[{{0.543428, 0.197604, 0.011432},{0.544066, 0.195640, 0.014801},{
      0.538387, 0.192747, 0.014801},{0.537174, 0.194417, 0.011432}}],
    Polygon[{{0.544066, 0.195640, 0.014801},{0.544859, 0.193200, 0.017806},{
      0.539896, 0.190670, 0.017806},{0.538387, 0.192747, 0.014801}}],
    Polygon[{{0.544859, 0.193200, 0.017806},{0.545788, 0.190342, 0.020372},{
      0.541662, 0.188240, 0.020372},{0.539896, 0.190670, 0.017806}}],
    Polygon[{{0.545788, 0.190342, 0.020372},{0.546829, 0.187138, 0.022436},{
      0.543642, 0.185514, 0.022436},{0.541662, 0.188240, 0.020372}}],
    Polygon[{{0.546829, 0.187138, 0.022436},{0.547957, 0.183666, 0.023948},{
      0.545788, 0.182561, 0.023948},{0.543642, 0.185514, 0.022436}}],
    Polygon[{{0.547957, 0.183666, 0.023948},{0.549144, 0.180012, 0.024871},{
      0.548046, 0.179452, 0.024871},{0.545788, 0.182561, 0.023948}}],
    Polygon[{{0.548046, 0.179452, -0.024871},{0.545788, 0.182561, -0.023948},{
      0.544066, 0.180839, -0.023948},{0.547175, 0.178581, -0.024871}}],
    Polygon[{{0.545788, 0.182561, -0.023948},{0.543642, 0.185514, -0.022436},{
      0.541113, 0.182985, -0.022436},{0.544066, 0.180839, -0.023948}}],
    Polygon[{{0.543642, 0.185514, -0.022436},{0.541662, 0.188240, -0.020372},{
      0.538387, 0.184965, -0.020372},{0.541113, 0.182985, -0.022436}}],
    Polygon[{{0.541662, 0.188240, -0.020372},{0.539896, 0.190670, -0.017806},{
      0.535957, 0.186731, -0.017806},{0.538387, 0.184965, -0.020372}}],
    Polygon[{{0.539896, 0.190670, -0.017806},{0.538387, 0.192747, -0.014801},{
      0.533881, 0.188240, -0.014801},{0.535957, 0.186731, -0.017806}}],
    Polygon[{{0.538387, 0.192747, -0.014801},{0.537174, 0.194417, -0.011432},{
      0.532210, 0.189453, -0.011432},{0.533881, 0.188240, -0.014801}}],
    Polygon[{{0.537174, 0.194417, -0.011432},{0.536285, 0.195640, -0.007781},{
      0.530987, 0.190342, -0.007781},{0.532210, 0.189453, -0.011432}}],
    Polygon[{{0.536285, 0.195640, -0.007781},{0.535743, 0.196386, -0.003939},{
      0.530241, 0.190884, -0.003939},{0.530987, 0.190342, -0.007781}}],
    Polygon[{{0.535743, 0.196386, -0.003939},{0.535561, 0.196637, 0.000000},{
      0.529990, 0.191066, 0.000000},{0.530241, 0.190884, -0.003939}}],
    Polygon[{{0.535561, 0.196637, 0.000000},{0.535743, 0.196386, 0.003939},{
      0.530241, 0.190884, 0.003939},{0.529990, 0.191066, 0.000000}}],
    Polygon[{{0.535743, 0.196386, 0.003939},{0.536285, 0.195640, 0.007781},{
      0.530987, 0.190342, 0.007781},{0.530241, 0.190884, 0.003939}}],
    Polygon[{{0.536285, 0.195640, 0.007781},{0.537174, 0.194417, 0.011432},{
      0.532210, 0.189453, 0.011432},{0.530987, 0.190342, 0.007781}}],
    Polygon[{{0.537174, 0.194417, 0.011432},{0.538387, 0.192747, 0.014801},{
      0.533881, 0.188240, 0.014801},{0.532210, 0.189453, 0.011432}}],
    Polygon[{{0.538387, 0.192747, 0.014801},{0.539896, 0.190670, 0.017806},{
      0.535957, 0.186731, 0.017806},{0.533881, 0.188240, 0.014801}}],
    Polygon[{{0.539896, 0.190670, 0.017806},{0.541662, 0.188240, 0.020372},{
      0.538387, 0.184965, 0.020372},{0.535957, 0.186731, 0.017806}}],
    Polygon[{{0.541662, 0.188240, 0.020372},{0.543642, 0.185514, 0.022436},{
      0.541113, 0.182985, 0.022436},{0.538387, 0.184965, 0.020372}}],
    Polygon[{{0.543642, 0.185514, 0.022436},{0.545788, 0.182561, 0.023948},{
      0.544066, 0.180839, 0.023948},{0.541113, 0.182985, 0.022436}}],
    Polygon[{{0.545788, 0.182561, 0.023948},{0.548046, 0.179452, 0.024871},{
      0.547175, 0.178581, 0.024871},{0.544066, 0.180839, 0.023948}}],
    Polygon[{{0.547175, 0.178581, -0.024871},{0.544066, 0.180839, -0.023948},{
      0.542961, 0.178670, -0.023948},{0.546615, 0.177483, -0.024871}}],
    Polygon[{{0.544066, 0.180839, -0.023948},{0.541113, 0.182985, -0.022436},{
      0.539489, 0.179798, -0.022436},{0.542961, 0.178670, -0.023948}}],
    Polygon[{{0.541113, 0.182985, -0.022436},{0.538387, 0.184965, -0.020372},{
      0.536285, 0.180839, -0.020372},{0.539489, 0.179798, -0.022436}}],
    Polygon[{{0.538387, 0.184965, -0.020372},{0.535957, 0.186731, -0.017806},{
      0.533428, 0.181768, -0.017806},{0.536285, 0.180839, -0.020372}}],
    Polygon[{{0.535957, 0.186731, -0.017806},{0.533881, 0.188240, -0.014801},{
      0.530987, 0.182561, -0.014801},{0.533428, 0.181768, -0.017806}}],
    Polygon[{{0.533881, 0.188240, -0.014801},{0.532210, 0.189453, -0.011432},{
      0.529023, 0.183199, -0.011432},{0.530987, 0.182561, -0.014801}}],
    Polygon[{{0.532210, 0.189453, -0.011432},{0.530987, 0.190342, -0.007781},{
      0.527585, 0.183666, -0.007781},{0.529023, 0.183199, -0.011432}}],
    Polygon[{{0.530987, 0.190342, -0.007781},{0.530241, 0.190884, -0.003939},{
      0.526708, 0.183951, -0.003939},{0.527585, 0.183666, -0.007781}}],
    Polygon[{{0.530241, 0.190884, -0.003939},{0.529990, 0.191066, 0.000000},{
      0.526413, 0.184047, 0.000000},{0.526708, 0.183951, -0.003939}}],
    Polygon[{{0.529990, 0.191066, 0.000000},{0.530241, 0.190884, 0.003939},{
      0.526708, 0.183951, 0.003939},{0.526413, 0.184047, 0.000000}}],
    Polygon[{{0.530241, 0.190884, 0.003939},{0.530987, 0.190342, 0.007781},{
      0.527585, 0.183666, 0.007781},{0.526708, 0.183951, 0.003939}}],
    Polygon[{{0.530987, 0.190342, 0.007781},{0.532210, 0.189453, 0.011432},{
      0.529023, 0.183199, 0.011432},{0.527585, 0.183666, 0.007781}}],
    Polygon[{{0.532210, 0.189453, 0.011432},{0.533881, 0.188240, 0.014801},{
      0.530987, 0.182561, 0.014801},{0.529023, 0.183199, 0.011432}}],
    Polygon[{{0.533881, 0.188240, 0.014801},{0.535957, 0.186731, 0.017806},{
      0.533428, 0.181768, 0.017806},{0.530987, 0.182561, 0.014801}}],
    Polygon[{{0.535957, 0.186731, 0.017806},{0.538387, 0.184965, 0.020372},{
      0.536285, 0.180839, 0.020372},{0.533428, 0.181768, 0.017806}}],
    Polygon[{{0.538387, 0.184965, 0.020372},{0.541113, 0.182985, 0.022436},{
      0.539489, 0.179798, 0.022436},{0.536285, 0.180839, 0.020372}}],
    Polygon[{{0.541113, 0.182985, 0.022436},{0.544066, 0.180839, 0.023948},{
      0.542961, 0.178670, 0.023948},{0.539489, 0.179798, 0.022436}}],
    Polygon[{{0.544066, 0.180839, 0.023948},{0.547175, 0.178581, 0.024871},{
      0.546615, 0.177483, 0.024871},{0.542961, 0.178670, 0.023948}}],
    Polygon[{{0.546615, 0.177483, -0.024871},{0.542961, 0.178670, -0.023948},{
      0.542580, 0.176266, -0.023948},{0.546422, 0.176266, -0.024871}}],
    Polygon[{{0.542961, 0.178670, -0.023948},{0.539489, 0.179798, -0.022436},{
      0.538930, 0.176266, -0.022436},{0.542580, 0.176266, -0.023948}}],
    Polygon[{{0.539489, 0.179798, -0.022436},{0.536285, 0.180839, -0.020372},{
      0.535561, 0.176266, -0.020372},{0.538930, 0.176266, -0.022436}}],
    Polygon[{{0.536285, 0.180839, -0.020372},{0.533428, 0.181768, -0.017806},{
      0.532556, 0.176266, -0.017806},{0.535561, 0.176266, -0.020372}}],
    Polygon[{{0.533428, 0.181768, -0.017806},{0.530987, 0.182561, -0.014801},{
      0.529990, 0.176266, -0.014801},{0.532556, 0.176266, -0.017806}}],
    Polygon[{{0.530987, 0.182561, -0.014801},{0.529023, 0.183199, -0.011432},{
      0.527925, 0.176266, -0.011432},{0.529990, 0.176266, -0.014801}}],
    Polygon[{{0.529023, 0.183199, -0.011432},{0.527585, 0.183666, -0.007781},{
      0.526413, 0.176266, -0.007781},{0.527925, 0.176266, -0.011432}}],
    Polygon[{{0.527585, 0.183666, -0.007781},{0.526708, 0.183951, -0.003939},{
      0.525491, 0.176266, -0.003939},{0.526413, 0.176266, -0.007781}}],
    Polygon[{{0.526708, 0.183951, -0.003939},{0.526413, 0.184047, 0.000000},{
      0.525181, 0.176266, 0.000000},{0.525491, 0.176266, -0.003939}}],
    Polygon[{{0.526413, 0.184047, 0.000000},{0.526708, 0.183951, 0.003939},{
      0.525491, 0.176266, 0.003939},{0.525181, 0.176266, 0.000000}}],
    Polygon[{{0.526708, 0.183951, 0.003939},{0.527585, 0.183666, 0.007781},{
      0.526413, 0.176266, 0.007781},{0.525491, 0.176266, 0.003939}}],
    Polygon[{{0.527585, 0.183666, 0.007781},{0.529023, 0.183199, 0.011432},{
      0.527925, 0.176266, 0.011432},{0.526413, 0.176266, 0.007781}}],
    Polygon[{{0.529023, 0.183199, 0.011432},{0.530987, 0.182561, 0.014801},{
      0.529990, 0.176266, 0.014801},{0.527925, 0.176266, 0.011432}}],
    Polygon[{{0.530987, 0.182561, 0.014801},{0.533428, 0.181768, 0.017806},{
      0.532556, 0.176266, 0.017806},{0.529990, 0.176266, 0.014801}}],
    Polygon[{{0.533428, 0.181768, 0.017806},{0.536285, 0.180839, 0.020372},{
      0.535561, 0.176266, 0.020372},{0.532556, 0.176266, 0.017806}}],
    Polygon[{{0.536285, 0.180839, 0.020372},{0.539489, 0.179798, 0.022436},{
      0.538930, 0.176266, 0.022436},{0.535561, 0.176266, 0.020372}}],
    Polygon[{{0.539489, 0.179798, 0.022436},{0.542961, 0.178670, 0.023948},{
      0.542580, 0.176266, 0.023948},{0.538930, 0.176266, 0.022436}}],
    Polygon[{{0.542961, 0.178670, 0.023948},{0.546615, 0.177483, 0.024871},{
      0.546422, 0.176266, 0.024871},{0.542580, 0.176266, 0.023948}}],
    Polygon[{{0.546422, 0.176266, -0.024871},{0.542580, 0.176266, -0.023948},{
      0.542961, 0.173861, -0.023948},{0.546615, 0.175048, -0.024871}}],
    Polygon[{{0.542580, 0.176266, -0.023948},{0.538930, 0.176266, -0.022436},{
      0.539489, 0.172733, -0.022436},{0.542961, 0.173861, -0.023948}}],
    Polygon[{{0.538930, 0.176266, -0.022436},{0.535561, 0.176266, -0.020372},{
      0.536285, 0.171692, -0.020372},{0.539489, 0.172733, -0.022436}}],
    Polygon[{{0.535561, 0.176266, -0.020372},{0.532556, 0.176266, -0.017806},{
      0.533428, 0.170763, -0.017806},{0.536285, 0.171692, -0.020372}}],
    Polygon[{{0.532556, 0.176266, -0.017806},{0.529990, 0.176266, -0.014801},{
      0.530987, 0.169970, -0.014801},{0.533428, 0.170763, -0.017806}}],
    Polygon[{{0.529990, 0.176266, -0.014801},{0.527925, 0.176266, -0.011432},{
      0.529023, 0.169332, -0.011432},{0.530987, 0.169970, -0.014801}}],
    Polygon[{{0.527925, 0.176266, -0.011432},{0.526413, 0.176266, -0.007781},{
      0.527585, 0.168865, -0.007781},{0.529023, 0.169332, -0.011432}}],
    Polygon[{{0.526413, 0.176266, -0.007781},{0.525491, 0.176266, -0.003939},{
      0.526708, 0.168580, -0.003939},{0.527585, 0.168865, -0.007781}}],
    Polygon[{{0.525491, 0.176266, -0.003939},{0.525181, 0.176266, 0.000000},{
      0.526413, 0.168484, 0.000000},{0.526708, 0.168580, -0.003939}}],
    Polygon[{{0.525181, 0.176266, 0.000000},{0.525491, 0.176266, 0.003939},{
      0.526708, 0.168580, 0.003939},{0.526413, 0.168484, 0.000000}}],
    Polygon[{{0.525491, 0.176266, 0.003939},{0.526413, 0.176266, 0.007781},{
      0.527585, 0.168865, 0.007781},{0.526708, 0.168580, 0.003939}}],
    Polygon[{{0.526413, 0.176266, 0.007781},{0.527925, 0.176266, 0.011432},{
      0.529023, 0.169332, 0.011432},{0.527585, 0.168865, 0.007781}}],
    Polygon[{{0.527925, 0.176266, 0.011432},{0.529990, 0.176266, 0.014801},{
      0.530987, 0.169970, 0.014801},{0.529023, 0.169332, 0.011432}}],
    Polygon[{{0.529990, 0.176266, 0.014801},{0.532556, 0.176266, 0.017806},{
      0.533428, 0.170763, 0.017806},{0.530987, 0.169970, 0.014801}}],
    Polygon[{{0.532556, 0.176266, 0.017806},{0.535561, 0.176266, 0.020372},{
      0.536285, 0.171692, 0.020372},{0.533428, 0.170763, 0.017806}}],
    Polygon[{{0.535561, 0.176266, 0.020372},{0.538930, 0.176266, 0.022436},{
      0.539489, 0.172733, 0.022436},{0.536285, 0.171692, 0.020372}}],
    Polygon[{{0.538930, 0.176266, 0.022436},{0.542580, 0.176266, 0.023948},{
      0.542961, 0.173861, 0.023948},{0.539489, 0.172733, 0.022436}}],
    Polygon[{{0.542580, 0.176266, 0.023948},{0.546422, 0.176266, 0.024871},{
      0.546615, 0.175048, 0.024871},{0.542961, 0.173861, 0.023948}}],
    Polygon[{{0.546615, 0.175048, -0.024871},{0.542961, 0.173861, -0.023948},{
      0.544066, 0.171692, -0.023948},{0.547175, 0.173950, -0.024871}}],
    Polygon[{{0.542961, 0.173861, -0.023948},{0.539489, 0.172733, -0.022436},{
      0.541113, 0.169546, -0.022436},{0.544066, 0.171692, -0.023948}}],
    Polygon[{{0.539489, 0.172733, -0.022436},{0.536285, 0.171692, -0.020372},{
      0.538387, 0.167566, -0.020372},{0.541113, 0.169546, -0.022436}}],
    Polygon[{{0.536285, 0.171692, -0.020372},{0.533428, 0.170763, -0.017806},{
      0.535957, 0.165800, -0.017806},{0.538387, 0.167566, -0.020372}}],
    Polygon[{{0.533428, 0.170763, -0.017806},{0.530987, 0.169970, -0.014801},{
      0.533881, 0.164291, -0.014801},{0.535957, 0.165800, -0.017806}}],
    Polygon[{{0.530987, 0.169970, -0.014801},{0.529023, 0.169332, -0.011432},{
      0.532210, 0.163078, -0.011432},{0.533881, 0.164291, -0.014801}}],
    Polygon[{{0.529023, 0.169332, -0.011432},{0.527585, 0.168865, -0.007781},{
      0.530987, 0.162189, -0.007781},{0.532210, 0.163078, -0.011432}}],
    Polygon[{{0.527585, 0.168865, -0.007781},{0.526708, 0.168580, -0.003939},{
      0.530241, 0.161647, -0.003939},{0.530987, 0.162189, -0.007781}}],
    Polygon[{{0.526708, 0.168580, -0.003939},{0.526413, 0.168484, 0.000000},{
      0.529990, 0.161465, 0.000000},{0.530241, 0.161647, -0.003939}}],
    Polygon[{{0.526413, 0.168484, 0.000000},{0.526708, 0.168580, 0.003939},{
      0.530241, 0.161647, 0.003939},{0.529990, 0.161465, 0.000000}}],
    Polygon[{{0.526708, 0.168580, 0.003939},{0.527585, 0.168865, 0.007781},{
      0.530987, 0.162189, 0.007781},{0.530241, 0.161647, 0.003939}}],
    Polygon[{{0.527585, 0.168865, 0.007781},{0.529023, 0.169332, 0.011432},{
      0.532210, 0.163078, 0.011432},{0.530987, 0.162189, 0.007781}}],
    Polygon[{{0.529023, 0.169332, 0.011432},{0.530987, 0.169970, 0.014801},{
      0.533881, 0.164291, 0.014801},{0.532210, 0.163078, 0.011432}}],
    Polygon[{{0.530987, 0.169970, 0.014801},{0.533428, 0.170763, 0.017806},{
      0.535957, 0.165800, 0.017806},{0.533881, 0.164291, 0.014801}}],
    Polygon[{{0.533428, 0.170763, 0.017806},{0.536285, 0.171692, 0.020372},{
      0.538387, 0.167566, 0.020372},{0.535957, 0.165800, 0.017806}}],
    Polygon[{{0.536285, 0.171692, 0.020372},{0.539489, 0.172733, 0.022436},{
      0.541113, 0.169546, 0.022436},{0.538387, 0.167566, 0.020372}}],
    Polygon[{{0.539489, 0.172733, 0.022436},{0.542961, 0.173861, 0.023948},{
      0.544066, 0.171692, 0.023948},{0.541113, 0.169546, 0.022436}}],
    Polygon[{{0.542961, 0.173861, 0.023948},{0.546615, 0.175048, 0.024871},{
      0.547175, 0.173950, 0.024871},{0.544066, 0.171692, 0.023948}}],
    Polygon[{{0.547175, 0.173950, -0.024871},{0.544066, 0.171692, -0.023948},{
      0.545788, 0.169970, -0.023948},{0.548046, 0.173079, -0.024871}}],
    Polygon[{{0.544066, 0.171692, -0.023948},{0.541113, 0.169546, -0.022436},{
      0.543642, 0.167017, -0.022436},{0.545788, 0.169970, -0.023948}}],
    Polygon[{{0.541113, 0.169546, -0.022436},{0.538387, 0.167566, -0.020372},{
      0.541662, 0.164291, -0.020372},{0.543642, 0.167017, -0.022436}}],
    Polygon[{{0.538387, 0.167566, -0.020372},{0.535957, 0.165800, -0.017806},{
      0.539896, 0.161861, -0.017806},{0.541662, 0.164291, -0.020372}}],
    Polygon[{{0.535957, 0.165800, -0.017806},{0.533881, 0.164291, -0.014801},{
      0.538387, 0.159784, -0.014801},{0.539896, 0.161861, -0.017806}}],
    Polygon[{{0.533881, 0.164291, -0.014801},{0.532210, 0.163078, -0.011432},{
      0.537174, 0.158114, -0.011432},{0.538387, 0.159784, -0.014801}}],
    Polygon[{{0.532210, 0.163078, -0.011432},{0.530987, 0.162189, -0.007781},{
      0.536285, 0.156891, -0.007781},{0.537174, 0.158114, -0.011432}}],
    Polygon[{{0.530987, 0.162189, -0.007781},{0.530241, 0.161647, -0.003939},{
      0.535743, 0.156145, -0.003939},{0.536285, 0.156891, -0.007781}}],
    Polygon[{{0.530241, 0.161647, -0.003939},{0.529990, 0.161465, 0.000000},{
      0.535561, 0.155894, 0.000000},{0.535743, 0.156145, -0.003939}}],
    Polygon[{{0.529990, 0.161465, 0.000000},{0.530241, 0.161647, 0.003939},{
      0.535743, 0.156145, 0.003939},{0.535561, 0.155894, 0.000000}}],
    Polygon[{{0.530241, 0.161647, 0.003939},{0.530987, 0.162189, 0.007781},{
      0.536285, 0.156891, 0.007781},{0.535743, 0.156145, 0.003939}}],
    Polygon[{{0.530987, 0.162189, 0.007781},{0.532210, 0.163078, 0.011432},{
      0.537174, 0.158114, 0.011432},{0.536285, 0.156891, 0.007781}}],
    Polygon[{{0.532210, 0.163078, 0.011432},{0.533881, 0.164291, 0.014801},{
      0.538387, 0.159784, 0.014801},{0.537174, 0.158114, 0.011432}}],
    Polygon[{{0.533881, 0.164291, 0.014801},{0.535957, 0.165800, 0.017806},{
      0.539896, 0.161861, 0.017806},{0.538387, 0.159784, 0.014801}}],
    Polygon[{{0.535957, 0.165800, 0.017806},{0.538387, 0.167566, 0.020372},{
      0.541662, 0.164291, 0.020372},{0.539896, 0.161861, 0.017806}}],
    Polygon[{{0.538387, 0.167566, 0.020372},{0.541113, 0.169546, 0.022436},{
      0.543642, 0.167017, 0.022436},{0.541662, 0.164291, 0.020372}}],
    Polygon[{{0.541113, 0.169546, 0.022436},{0.544066, 0.171692, 0.023948},{
      0.545788, 0.169970, 0.023948},{0.543642, 0.167017, 0.022436}}],
    Polygon[{{0.544066, 0.171692, 0.023948},{0.547175, 0.173950, 0.024871},{
      0.548046, 0.173079, 0.024871},{0.545788, 0.169970, 0.023948}}],
    Polygon[{{0.548046, 0.173079, -0.024871},{0.545788, 0.169970, -0.023948},{
      0.547957, 0.168865, -0.023948},{0.549144, 0.172519, -0.024871}}],
    Polygon[{{0.545788, 0.169970, -0.023948},{0.543642, 0.167017, -0.022436},{
      0.546829, 0.165393, -0.022436},{0.547957, 0.168865, -0.023948}}],
    Polygon[{{0.543642, 0.167017, -0.022436},{0.541662, 0.164291, -0.020372},{
      0.545788, 0.162189, -0.020372},{0.546829, 0.165393, -0.022436}}],
    Polygon[{{0.541662, 0.164291, -0.020372},{0.539896, 0.161861, -0.017806},{
      0.544859, 0.159331, -0.017806},{0.545788, 0.162189, -0.020372}}],
    Polygon[{{0.539896, 0.161861, -0.017806},{0.538387, 0.159784, -0.014801},{
      0.544066, 0.156891, -0.014801},{0.544859, 0.159331, -0.017806}}],
    Polygon[{{0.538387, 0.159784, -0.014801},{0.537174, 0.158114, -0.011432},{
      0.543428, 0.154927, -0.011432},{0.544066, 0.156891, -0.014801}}],
    Polygon[{{0.537174, 0.158114, -0.011432},{0.536285, 0.156891, -0.007781},{
      0.542961, 0.153489, -0.007781},{0.543428, 0.154927, -0.011432}}],
    Polygon[{{0.536285, 0.156891, -0.007781},{0.535743, 0.156145, -0.003939},{
      0.542676, 0.152612, -0.003939},{0.542961, 0.153489, -0.007781}}],
    Polygon[{{0.535743, 0.156145, -0.003939},{0.535561, 0.155894, 0.000000},{
      0.542580, 0.152317, 0.000000},{0.542676, 0.152612, -0.003939}}],
    Polygon[{{0.535561, 0.155894, 0.000000},{0.535743, 0.156145, 0.003939},{
      0.542676, 0.152612, 0.003939},{0.542580, 0.152317, 0.000000}}],
    Polygon[{{0.535743, 0.156145, 0.003939},{0.536285, 0.156891, 0.007781},{
      0.542961, 0.153489, 0.007781},{0.542676, 0.152612, 0.003939}}],
    Polygon[{{0.536285, 0.156891, 0.007781},{0.537174, 0.158114, 0.011432},{
      0.543428, 0.154927, 0.011432},{0.542961, 0.153489, 0.007781}}],
    Polygon[{{0.537174, 0.158114, 0.011432},{0.538387, 0.159784, 0.014801},{
      0.544066, 0.156891, 0.014801},{0.543428, 0.154927, 0.011432}}],
    Polygon[{{0.538387, 0.159784, 0.014801},{0.539896, 0.161861, 0.017806},{
      0.544859, 0.159331, 0.017806},{0.544066, 0.156891, 0.014801}}],
    Polygon[{{0.539896, 0.161861, 0.017806},{0.541662, 0.164291, 0.020372},{
      0.545788, 0.162189, 0.020372},{0.544859, 0.159331, 0.017806}}],
    Polygon[{{0.541662, 0.164291, 0.020372},{0.543642, 0.167017, 0.022436},{
      0.546829, 0.165393, 0.022436},{0.545788, 0.162189, 0.020372}}],
    Polygon[{{0.543642, 0.167017, 0.022436},{0.545788, 0.169970, 0.023948},{
      0.547957, 0.168865, 0.023948},{0.546829, 0.165393, 0.022436}}],
    Polygon[{{0.545788, 0.169970, 0.023948},{0.548046, 0.173079, 0.024871},{
      0.549144, 0.172519, 0.024871},{0.547957, 0.168865, 0.023948}}],
    Polygon[{{0.549144, 0.172519, -0.024871},{0.547957, 0.168865, -0.023948},{
      0.550362, 0.168484, -0.023948},{0.550362, 0.172326, -0.024871}}],
    Polygon[{{0.547957, 0.168865, -0.023948},{0.546829, 0.165393, -0.022436},{
      0.550362, 0.164834, -0.022436},{0.550362, 0.168484, -0.023948}}],
    Polygon[{{0.546829, 0.165393, -0.022436},{0.545788, 0.162189, -0.020372},{
      0.550362, 0.161465, -0.020372},{0.550362, 0.164834, -0.022436}}],
    Polygon[{{0.545788, 0.162189, -0.020372},{0.544859, 0.159331, -0.017806},{
      0.550362, 0.158460, -0.017806},{0.550362, 0.161465, -0.020372}}],
    Polygon[{{0.544859, 0.159331, -0.017806},{0.544066, 0.156891, -0.014801},{
      0.550362, 0.155894, -0.014801},{0.550362, 0.158460, -0.017806}}],
    Polygon[{{0.544066, 0.156891, -0.014801},{0.543428, 0.154927, -0.011432},{
      0.550362, 0.153829, -0.011432},{0.550362, 0.155894, -0.014801}}],
    Polygon[{{0.543428, 0.154927, -0.011432},{0.542961, 0.153489, -0.007781},{
      0.550362, 0.152317, -0.007781},{0.550362, 0.153829, -0.011432}}],
    Polygon[{{0.542961, 0.153489, -0.007781},{0.542676, 0.152612, -0.003939},{
      0.550362, 0.151395, -0.003939},{0.550362, 0.152317, -0.007781}}],
    Polygon[{{0.542676, 0.152612, -0.003939},{0.542580, 0.152317, 0.000000},{
      0.550362, 0.151085, 0.000000},{0.550362, 0.151395, -0.003939}}],
    Polygon[{{0.542580, 0.152317, 0.000000},{0.542676, 0.152612, 0.003939},{
      0.550362, 0.151395, 0.003939},{0.550362, 0.151085, 0.000000}}],
    Polygon[{{0.542676, 0.152612, 0.003939},{0.542961, 0.153489, 0.007781},{
      0.550362, 0.152317, 0.007781},{0.550362, 0.151395, 0.003939}}],
    Polygon[{{0.542961, 0.153489, 0.007781},{0.543428, 0.154927, 0.011432},{
      0.550362, 0.153829, 0.011432},{0.550362, 0.152317, 0.007781}}],
    Polygon[{{0.543428, 0.154927, 0.011432},{0.544066, 0.156891, 0.014801},{
      0.550362, 0.155894, 0.014801},{0.550362, 0.153829, 0.011432}}],
    Polygon[{{0.544066, 0.156891, 0.014801},{0.544859, 0.159331, 0.017806},{
      0.550362, 0.158460, 0.017806},{0.550362, 0.155894, 0.014801}}],
    Polygon[{{0.544859, 0.159331, 0.017806},{0.545788, 0.162189, 0.020372},{
      0.550362, 0.161465, 0.020372},{0.550362, 0.158460, 0.017806}}],
    Polygon[{{0.545788, 0.162189, 0.020372},{0.546829, 0.165393, 0.022436},{
      0.550362, 0.164834, 0.022436},{0.550362, 0.161465, 0.020372}}],
    Polygon[{{0.546829, 0.165393, 0.022436},{0.547957, 0.168865, 0.023948},{
      0.550362, 0.168484, 0.023948},{0.550362, 0.164834, 0.022436}}],
    Polygon[{{0.547957, 0.168865, 0.023948},{0.549144, 0.172519, 0.024871},{
      0.550362, 0.172326, 0.024871},{0.550362, 0.168484, 0.023948}}],
    Polygon[{{0.550362, 0.172326, -0.024871},{0.550362, 0.168484, -0.023948},{
      0.552766, 0.168865, -0.023948},{0.551579, 0.172519, -0.024871}}],
    Polygon[{{0.550362, 0.168484, -0.023948},{0.550362, 0.164834, -0.022436},{
      0.553894, 0.165393, -0.022436},{0.552766, 0.168865, -0.023948}}],
    Polygon[{{0.550362, 0.164834, -0.022436},{0.550362, 0.161465, -0.020372},{
      0.554935, 0.162189, -0.020372},{0.553894, 0.165393, -0.022436}}],
    Polygon[{{0.550362, 0.161465, -0.020372},{0.550362, 0.158460, -0.017806},{
      0.555864, 0.159331, -0.017806},{0.554935, 0.162189, -0.020372}}],
    Polygon[{{0.550362, 0.158460, -0.017806},{0.550362, 0.155894, -0.014801},{
      0.556657, 0.156891, -0.014801},{0.555864, 0.159331, -0.017806}}],
    Polygon[{{0.550362, 0.155894, -0.014801},{0.550362, 0.153829, -0.011432},{
      0.557295, 0.154927, -0.011432},{0.556657, 0.156891, -0.014801}}],
    Polygon[{{0.550362, 0.153829, -0.011432},{0.550362, 0.152317, -0.007781},{
      0.557762, 0.153489, -0.007781},{0.557295, 0.154927, -0.011432}}],
    Polygon[{{0.550362, 0.152317, -0.007781},{0.550362, 0.151395, -0.003939},{
      0.558047, 0.152612, -0.003939},{0.557762, 0.153489, -0.007781}}],
    Polygon[{{0.550362, 0.151395, -0.003939},{0.550362, 0.151085, 0.000000},{
      0.558143, 0.152317, 0.000000},{0.558047, 0.152612, -0.003939}}],
    Polygon[{{0.550362, 0.151085, 0.000000},{0.550362, 0.151395, 0.003939},{
      0.558047, 0.152612, 0.003939},{0.558143, 0.152317, 0.000000}}],
    Polygon[{{0.550362, 0.151395, 0.003939},{0.550362, 0.152317, 0.007781},{
      0.557762, 0.153489, 0.007781},{0.558047, 0.152612, 0.003939}}],
    Polygon[{{0.550362, 0.152317, 0.007781},{0.550362, 0.153829, 0.011432},{
      0.557295, 0.154927, 0.011432},{0.557762, 0.153489, 0.007781}}],
    Polygon[{{0.550362, 0.153829, 0.011432},{0.550362, 0.155894, 0.014801},{
      0.556657, 0.156891, 0.014801},{0.557295, 0.154927, 0.011432}}],
    Polygon[{{0.550362, 0.155894, 0.014801},{0.550362, 0.158460, 0.017806},{
      0.555864, 0.159331, 0.017806},{0.556657, 0.156891, 0.014801}}],
    Polygon[{{0.550362, 0.158460, 0.017806},{0.550362, 0.161465, 0.020372},{
      0.554935, 0.162189, 0.020372},{0.555864, 0.159331, 0.017806}}],
    Polygon[{{0.550362, 0.161465, 0.020372},{0.550362, 0.164834, 0.022436},{
      0.553894, 0.165393, 0.022436},{0.554935, 0.162189, 0.020372}}],
    Polygon[{{0.550362, 0.164834, 0.022436},{0.550362, 0.168484, 0.023948},{
      0.552766, 0.168865, 0.023948},{0.553894, 0.165393, 0.022436}}],
    Polygon[{{0.550362, 0.168484, 0.023948},{0.550362, 0.172326, 0.024871},{
      0.551579, 0.172519, 0.024871},{0.552766, 0.168865, 0.023948}}],
    Polygon[{{0.551579, 0.172519, -0.024871},{0.552766, 0.168865, -0.023948},{
      0.554935, 0.169970, -0.023948},{0.552677, 0.173079, -0.024871}}],
    Polygon[{{0.552766, 0.168865, -0.023948},{0.553894, 0.165393, -0.022436},{
      0.557081, 0.167017, -0.022436},{0.554935, 0.169970, -0.023948}}],
    Polygon[{{0.553894, 0.165393, -0.022436},{0.554935, 0.162189, -0.020372},{
      0.559061, 0.164291, -0.020372},{0.557081, 0.167017, -0.022436}}],
    Polygon[{{0.554935, 0.162189, -0.020372},{0.555864, 0.159331, -0.017806},{
      0.560827, 0.161861, -0.017806},{0.559061, 0.164291, -0.020372}}],
    Polygon[{{0.555864, 0.159331, -0.017806},{0.556657, 0.156891, -0.014801},{
      0.562336, 0.159784, -0.014801},{0.560827, 0.161861, -0.017806}}],
    Polygon[{{0.556657, 0.156891, -0.014801},{0.557295, 0.154927, -0.011432},{
      0.563549, 0.158114, -0.011432},{0.562336, 0.159784, -0.014801}}],
    Polygon[{{0.557295, 0.154927, -0.011432},{0.557762, 0.153489, -0.007781},{
      0.564438, 0.156891, -0.007781},{0.563549, 0.158114, -0.011432}}],
    Polygon[{{0.557762, 0.153489, -0.007781},{0.558047, 0.152612, -0.003939},{
      0.564980, 0.156145, -0.003939},{0.564438, 0.156891, -0.007781}}],
    Polygon[{{0.558047, 0.152612, -0.003939},{0.558143, 0.152317, 0.000000},{
      0.565162, 0.155894, 0.000000},{0.564980, 0.156145, -0.003939}}],
    Polygon[{{0.558143, 0.152317, 0.000000},{0.558047, 0.152612, 0.003939},{
      0.564980, 0.156145, 0.003939},{0.565162, 0.155894, 0.000000}}],
    Polygon[{{0.558047, 0.152612, 0.003939},{0.557762, 0.153489, 0.007781},{
      0.564438, 0.156891, 0.007781},{0.564980, 0.156145, 0.003939}}],
    Polygon[{{0.557762, 0.153489, 0.007781},{0.557295, 0.154927, 0.011432},{
      0.563549, 0.158114, 0.011432},{0.564438, 0.156891, 0.007781}}],
    Polygon[{{0.557295, 0.154927, 0.011432},{0.556657, 0.156891, 0.014801},{
      0.562336, 0.159784, 0.014801},{0.563549, 0.158114, 0.011432}}],
    Polygon[{{0.556657, 0.156891, 0.014801},{0.555864, 0.159331, 0.017806},{
      0.560827, 0.161861, 0.017806},{0.562336, 0.159784, 0.014801}}],
    Polygon[{{0.555864, 0.159331, 0.017806},{0.554935, 0.162189, 0.020372},{
      0.559061, 0.164291, 0.020372},{0.560827, 0.161861, 0.017806}}],
    Polygon[{{0.554935, 0.162189, 0.020372},{0.553894, 0.165393, 0.022436},{
      0.557081, 0.167017, 0.022436},{0.559061, 0.164291, 0.020372}}],
    Polygon[{{0.553894, 0.165393, 0.022436},{0.552766, 0.168865, 0.023948},{
      0.554935, 0.169970, 0.023948},{0.557081, 0.167017, 0.022436}}],
    Polygon[{{0.552766, 0.168865, 0.023948},{0.551579, 0.172519, 0.024871},{
      0.552677, 0.173079, 0.024871},{0.554935, 0.169970, 0.023948}}],
    Polygon[{{0.552677, 0.173079, -0.024871},{0.554935, 0.169970, -0.023948},{
      0.556657, 0.171692, -0.023948},{0.553548, 0.173950, -0.024871}}],
    Polygon[{{0.554935, 0.169970, -0.023948},{0.557081, 0.167017, -0.022436},{
      0.559610, 0.169546, -0.022436},{0.556657, 0.171692, -0.023948}}],
    Polygon[{{0.557081, 0.167017, -0.022436},{0.559061, 0.164291, -0.020372},{
      0.562336, 0.167566, -0.020372},{0.559610, 0.169546, -0.022436}}],
    Polygon[{{0.559061, 0.164291, -0.020372},{0.560827, 0.161861, -0.017806},{
      0.564767, 0.165800, -0.017806},{0.562336, 0.167566, -0.020372}}],
    Polygon[{{0.560827, 0.161861, -0.017806},{0.562336, 0.159784, -0.014801},{
      0.566843, 0.164291, -0.014801},{0.564767, 0.165800, -0.017806}}],
    Polygon[{{0.562336, 0.159784, -0.014801},{0.563549, 0.158114, -0.011432},{
      0.568513, 0.163078, -0.011432},{0.566843, 0.164291, -0.014801}}],
    Polygon[{{0.563549, 0.158114, -0.011432},{0.564438, 0.156891, -0.007781},{
      0.569736, 0.162189, -0.007781},{0.568513, 0.163078, -0.011432}}],
    Polygon[{{0.564438, 0.156891, -0.007781},{0.564980, 0.156145, -0.003939},{
      0.570482, 0.161647, -0.003939},{0.569736, 0.162189, -0.007781}}],
    Polygon[{{0.564980, 0.156145, -0.003939},{0.565162, 0.155894, 0.000000},{
      0.570733, 0.161465, 0.000000},{0.570482, 0.161647, -0.003939}}],
    Polygon[{{0.565162, 0.155894, 0.000000},{0.564980, 0.156145, 0.003939},{
      0.570482, 0.161647, 0.003939},{0.570733, 0.161465, 0.000000}}],
    Polygon[{{0.564980, 0.156145, 0.003939},{0.564438, 0.156891, 0.007781},{
      0.569736, 0.162189, 0.007781},{0.570482, 0.161647, 0.003939}}],
    Polygon[{{0.564438, 0.156891, 0.007781},{0.563549, 0.158114, 0.011432},{
      0.568513, 0.163078, 0.011432},{0.569736, 0.162189, 0.007781}}],
    Polygon[{{0.563549, 0.158114, 0.011432},{0.562336, 0.159784, 0.014801},{
      0.566843, 0.164291, 0.014801},{0.568513, 0.163078, 0.011432}}],
    Polygon[{{0.562336, 0.159784, 0.014801},{0.560827, 0.161861, 0.017806},{
      0.564767, 0.165800, 0.017806},{0.566843, 0.164291, 0.014801}}],
    Polygon[{{0.560827, 0.161861, 0.017806},{0.559061, 0.164291, 0.020372},{
      0.562336, 0.167566, 0.020372},{0.564767, 0.165800, 0.017806}}],
    Polygon[{{0.559061, 0.164291, 0.020372},{0.557081, 0.167017, 0.022436},{
      0.559610, 0.169546, 0.022436},{0.562336, 0.167566, 0.020372}}],
    Polygon[{{0.557081, 0.167017, 0.022436},{0.554935, 0.169970, 0.023948},{
      0.556657, 0.171692, 0.023948},{0.559610, 0.169546, 0.022436}}],
    Polygon[{{0.554935, 0.169970, 0.023948},{0.552677, 0.173079, 0.024871},{
      0.553548, 0.173950, 0.024871},{0.556657, 0.171692, 0.023948}}],
    Polygon[{{0.553548, 0.173950, -0.024871},{0.556657, 0.171692, -0.023948},{
      0.557762, 0.173861, -0.023948},{0.554108, 0.175048, -0.024871}}],
    Polygon[{{0.556657, 0.171692, -0.023948},{0.559610, 0.169546, -0.022436},{
      0.561234, 0.172733, -0.022436},{0.557762, 0.173861, -0.023948}}],
    Polygon[{{0.559610, 0.169546, -0.022436},{0.562336, 0.167566, -0.020372},{
      0.564438, 0.171692, -0.020372},{0.561234, 0.172733, -0.022436}}],
    Polygon[{{0.562336, 0.167566, -0.020372},{0.564767, 0.165800, -0.017806},{
      0.567296, 0.170763, -0.017806},{0.564438, 0.171692, -0.020372}}],
    Polygon[{{0.564767, 0.165800, -0.017806},{0.566843, 0.164291, -0.014801},{
      0.569736, 0.169970, -0.014801},{0.567296, 0.170763, -0.017806}}],
    Polygon[{{0.566843, 0.164291, -0.014801},{0.568513, 0.163078, -0.011432},{
      0.571700, 0.169332, -0.011432},{0.569736, 0.169970, -0.014801}}],
    Polygon[{{0.568513, 0.163078, -0.011432},{0.569736, 0.162189, -0.007781},{
      0.573138, 0.168865, -0.007781},{0.571700, 0.169332, -0.011432}}],
    Polygon[{{0.569736, 0.162189, -0.007781},{0.570482, 0.161647, -0.003939},{
      0.574015, 0.168580, -0.003939},{0.573138, 0.168865, -0.007781}}],
    Polygon[{{0.570482, 0.161647, -0.003939},{0.570733, 0.161465, 0.000000},{
      0.574310, 0.168484, 0.000000},{0.574015, 0.168580, -0.003939}}],
    Polygon[{{0.570733, 0.161465, 0.000000},{0.570482, 0.161647, 0.003939},{
      0.574015, 0.168580, 0.003939},{0.574310, 0.168484, 0.000000}}],
    Polygon[{{0.570482, 0.161647, 0.003939},{0.569736, 0.162189, 0.007781},{
      0.573138, 0.168865, 0.007781},{0.574015, 0.168580, 0.003939}}],
    Polygon[{{0.569736, 0.162189, 0.007781},{0.568513, 0.163078, 0.011432},{
      0.571700, 0.169332, 0.011432},{0.573138, 0.168865, 0.007781}}],
    Polygon[{{0.568513, 0.163078, 0.011432},{0.566843, 0.164291, 0.014801},{
      0.569736, 0.169970, 0.014801},{0.571700, 0.169332, 0.011432}}],
    Polygon[{{0.566843, 0.164291, 0.014801},{0.564767, 0.165800, 0.017806},{
      0.567296, 0.170763, 0.017806},{0.569736, 0.169970, 0.014801}}],
    Polygon[{{0.564767, 0.165800, 0.017806},{0.562336, 0.167566, 0.020372},{
      0.564438, 0.171692, 0.020372},{0.567296, 0.170763, 0.017806}}],
    Polygon[{{0.562336, 0.167566, 0.020372},{0.559610, 0.169546, 0.022436},{
      0.561234, 0.172733, 0.022436},{0.564438, 0.171692, 0.020372}}],
    Polygon[{{0.559610, 0.169546, 0.022436},{0.556657, 0.171692, 0.023948},{
      0.557762, 0.173861, 0.023948},{0.561234, 0.172733, 0.022436}}],
    Polygon[{{0.556657, 0.171692, 0.023948},{0.553548, 0.173950, 0.024871},{
      0.554108, 0.175048, 0.024871},{0.557762, 0.173861, 0.023948}}],
    Polygon[{{0.554108, 0.175048, -0.024871},{0.557762, 0.173861, -0.023948},{
      0.558143, 0.176266, -0.023948},{0.554301, 0.176266, -0.024871}}],
    Polygon[{{0.557762, 0.173861, -0.023948},{0.561234, 0.172733, -0.022436},{
      0.561793, 0.176266, -0.022436},{0.558143, 0.176266, -0.023948}}],
    Polygon[{{0.561234, 0.172733, -0.022436},{0.564438, 0.171692, -0.020372},{
      0.565162, 0.176266, -0.020372},{0.561793, 0.176266, -0.022436}}],
    Polygon[{{0.564438, 0.171692, -0.020372},{0.567296, 0.170763, -0.017806},{
      0.568167, 0.176266, -0.017806},{0.565162, 0.176266, -0.020372}}],
    Polygon[{{0.567296, 0.170763, -0.017806},{0.569736, 0.169970, -0.014801},{
      0.570733, 0.176266, -0.014801},{0.568167, 0.176266, -0.017806}}],
    Polygon[{{0.569736, 0.169970, -0.014801},{0.571700, 0.169332, -0.011432},{
      0.572798, 0.176266, -0.011432},{0.570733, 0.176266, -0.014801}}],
    Polygon[{{0.571700, 0.169332, -0.011432},{0.573138, 0.168865, -0.007781},{
      0.574310, 0.176266, -0.007781},{0.572798, 0.176266, -0.011432}}],
    Polygon[{{0.573138, 0.168865, -0.007781},{0.574015, 0.168580, -0.003939},{
      0.575232, 0.176266, -0.003939},{0.574310, 0.176266, -0.007781}}],
    Polygon[{{0.574015, 0.168580, -0.003939},{0.574310, 0.168484, 0.000000},{
      0.575542, 0.176266, 0.000000},{0.575232, 0.176266, -0.003939}}],
    Polygon[{{0.574310, 0.168484, 0.000000},{0.574015, 0.168580, 0.003939},{
      0.575232, 0.176266, 0.003939},{0.575542, 0.176266, 0.000000}}],
    Polygon[{{0.574015, 0.168580, 0.003939},{0.573138, 0.168865, 0.007781},{
      0.574310, 0.176266, 0.007781},{0.575232, 0.176266, 0.003939}}],
    Polygon[{{0.573138, 0.168865, 0.007781},{0.571700, 0.169332, 0.011432},{
      0.572798, 0.176266, 0.011432},{0.574310, 0.176266, 0.007781}}],
    Polygon[{{0.571700, 0.169332, 0.011432},{0.569736, 0.169970, 0.014801},{
      0.570733, 0.176266, 0.014801},{0.572798, 0.176266, 0.011432}}],
    Polygon[{{0.569736, 0.169970, 0.014801},{0.567296, 0.170763, 0.017806},{
      0.568167, 0.176266, 0.017806},{0.570733, 0.176266, 0.014801}}],
    Polygon[{{0.567296, 0.170763, 0.017806},{0.564438, 0.171692, 0.020372},{
      0.565162, 0.176266, 0.020372},{0.568167, 0.176266, 0.017806}}],
    Polygon[{{0.564438, 0.171692, 0.020372},{0.561234, 0.172733, 0.022436},{
      0.561793, 0.176266, 0.022436},{0.565162, 0.176266, 0.020372}}],
    Polygon[{{0.561234, 0.172733, 0.022436},{0.557762, 0.173861, 0.023948},{
      0.558143, 0.176266, 0.023948},{0.561793, 0.176266, 0.022436}}],
    Polygon[{{0.557762, 0.173861, 0.023948},{0.554108, 0.175048, 0.024871},{
      0.554301, 0.176266, 0.024871},{0.558143, 0.176266, 0.023948}}],
    Polygon[{{0.539282, 0.211564, -0.012292},{0.541181, 0.211564, -0.011836},{
      0.540992, 0.212753, -0.011836},{0.539186, 0.212166, -0.012292}}],
    Polygon[{{0.541181, 0.211564, -0.011836},{0.542985, 0.211564, -0.011089},{
      0.542708, 0.213310, -0.011089},{0.540992, 0.212753, -0.011836}}],
    Polygon[{{0.542985, 0.211564, -0.011089},{0.544650, 0.211564, -0.010068},{
      0.544292, 0.213825, -0.010068},{0.542708, 0.213310, -0.011089}}],
    Polygon[{{0.544650, 0.211564, -0.010068},{0.546135, 0.211564, -0.008800},{
      0.545704, 0.214284, -0.008800},{0.544292, 0.213825, -0.010068}}],
    Polygon[{{0.546135, 0.211564, -0.008800},{0.547403, 0.211564, -0.007315},{
      0.546910, 0.214676, -0.007315},{0.545704, 0.214284, -0.008800}}],
    Polygon[{{0.547403, 0.211564, -0.007315},{0.548423, 0.211564, -0.005650},{
      0.547881, 0.214991, -0.005650},{0.546910, 0.214676, -0.007315}}],
    Polygon[{{0.548423, 0.211564, -0.005650},{0.549171, 0.211564, -0.003846},{
      0.548591, 0.215222, -0.003846},{0.547881, 0.214991, -0.005650}}],
    Polygon[{{0.549171, 0.211564, -0.003846},{0.549627, 0.211564, -0.001947},{
      0.549025, 0.215363, -0.001947},{0.548591, 0.215222, -0.003846}}],
    Polygon[{{0.549627, 0.211564, -0.001947},{0.549780, 0.211564, 0.000000},{
      0.549171, 0.215410, 0.000000},{0.549025, 0.215363, -0.001947}}],
    Polygon[{{0.549780, 0.211564, 0.000000},{0.549627, 0.211564, 0.001947},{
      0.549025, 0.215363, 0.001947},{0.549171, 0.215410, 0.000000}}],
    Polygon[{{0.549627, 0.211564, 0.001947},{0.549171, 0.211564, 0.003846},{
      0.548591, 0.215222, 0.003846},{0.549025, 0.215363, 0.001947}}],
    Polygon[{{0.549171, 0.211564, 0.003846},{0.548423, 0.211564, 0.005650},{
      0.547881, 0.214991, 0.005650},{0.548591, 0.215222, 0.003846}}],
    Polygon[{{0.548423, 0.211564, 0.005650},{0.547403, 0.211564, 0.007315},{
      0.546910, 0.214676, 0.007315},{0.547881, 0.214991, 0.005650}}],
    Polygon[{{0.547403, 0.211564, 0.007315},{0.546135, 0.211564, 0.008800},{
      0.545704, 0.214284, 0.008800},{0.546910, 0.214676, 0.007315}}],
    Polygon[{{0.546135, 0.211564, 0.008800},{0.544650, 0.211564, 0.010068},{
      0.544292, 0.213825, 0.010068},{0.545704, 0.214284, 0.008800}}],
    Polygon[{{0.544650, 0.211564, 0.010068},{0.542985, 0.211564, 0.011089},{
      0.542708, 0.213310, 0.011089},{0.544292, 0.213825, 0.010068}}],
    Polygon[{{0.542985, 0.211564, 0.011089},{0.541181, 0.211564, 0.011836},{
      0.540992, 0.212753, 0.011836},{0.542708, 0.213310, 0.011089}}],
    Polygon[{{0.541181, 0.211564, 0.011836},{0.539282, 0.211564, 0.012292},{
      0.539186, 0.212166, 0.012292},{0.540992, 0.212753, 0.011836}}],
    Polygon[{{0.539186, 0.212166, -0.012292},{0.540992, 0.212753, -0.011836},{
      0.540446, 0.213825, -0.011836},{0.538910, 0.212709, -0.012292}}],
    Polygon[{{0.540992, 0.212753, -0.011836},{0.542708, 0.213310, -0.011089},{
      0.541906, 0.214885, -0.011089},{0.540446, 0.213825, -0.011836}}],
    Polygon[{{0.542708, 0.213310, -0.011089},{0.544292, 0.213825, -0.010068},{
      0.543253, 0.215864, -0.010068},{0.541906, 0.214885, -0.011089}}],
    Polygon[{{0.544292, 0.213825, -0.010068},{0.545704, 0.214284, -0.008800},{
      0.544454, 0.216737, -0.008800},{0.543253, 0.215864, -0.010068}}],
    Polygon[{{0.545704, 0.214284, -0.008800},{0.546910, 0.214676, -0.007315},{
      0.545480, 0.217482, -0.007315},{0.544454, 0.216737, -0.008800}}],
    Polygon[{{0.546910, 0.214676, -0.007315},{0.547881, 0.214991, -0.005650},{
      0.546306, 0.218082, -0.005650},{0.545480, 0.217482, -0.007315}}],
    Polygon[{{0.547881, 0.214991, -0.005650},{0.548591, 0.215222, -0.003846},{
      0.546910, 0.218521, -0.003846},{0.546306, 0.218082, -0.005650}}],
    Polygon[{{0.548591, 0.215222, -0.003846},{0.549025, 0.215363, -0.001947},{
      0.547279, 0.218789, -0.001947},{0.546910, 0.218521, -0.003846}}],
    Polygon[{{0.549025, 0.215363, -0.001947},{0.549171, 0.215410, 0.000000},{
      0.547403, 0.218879, 0.000000},{0.547279, 0.218789, -0.001947}}],
    Polygon[{{0.549171, 0.215410, 0.000000},{0.549025, 0.215363, 0.001947},{
      0.547279, 0.218789, 0.001947},{0.547403, 0.218879, 0.000000}}],
    Polygon[{{0.549025, 0.215363, 0.001947},{0.548591, 0.215222, 0.003846},{
      0.546910, 0.218521, 0.003846},{0.547279, 0.218789, 0.001947}}],
    Polygon[{{0.548591, 0.215222, 0.003846},{0.547881, 0.214991, 0.005650},{
      0.546306, 0.218082, 0.005650},{0.546910, 0.218521, 0.003846}}],
    Polygon[{{0.547881, 0.214991, 0.005650},{0.546910, 0.214676, 0.007315},{
      0.545480, 0.217482, 0.007315},{0.546306, 0.218082, 0.005650}}],
    Polygon[{{0.546910, 0.214676, 0.007315},{0.545704, 0.214284, 0.008800},{
      0.544454, 0.216737, 0.008800},{0.545480, 0.217482, 0.007315}}],
    Polygon[{{0.545704, 0.214284, 0.008800},{0.544292, 0.213825, 0.010068},{
      0.543253, 0.215864, 0.010068},{0.544454, 0.216737, 0.008800}}],
    Polygon[{{0.544292, 0.213825, 0.010068},{0.542708, 0.213310, 0.011089},{
      0.541906, 0.214885, 0.011089},{0.543253, 0.215864, 0.010068}}],
    Polygon[{{0.542708, 0.213310, 0.011089},{0.540992, 0.212753, 0.011836},{
      0.540446, 0.213825, 0.011836},{0.541906, 0.214885, 0.011089}}],
    Polygon[{{0.540992, 0.212753, 0.011836},{0.539186, 0.212166, 0.012292},{
      0.538910, 0.212709, 0.012292},{0.540446, 0.213825, 0.011836}}],
    Polygon[{{0.538910, 0.212709, -0.012292},{0.540446, 0.213825, -0.011836},{
      0.539595, 0.214676, -0.011836},{0.538479, 0.213139, -0.012292}}],
    Polygon[{{0.540446, 0.213825, -0.011836},{0.541906, 0.214885, -0.011089},{
      0.540656, 0.216135, -0.011089},{0.539595, 0.214676, -0.011836}}],
    Polygon[{{0.541906, 0.214885, -0.011089},{0.543253, 0.215864, -0.010068},{
      0.541635, 0.217482, -0.010068},{0.540656, 0.216135, -0.011089}}],
    Polygon[{{0.543253, 0.215864, -0.010068},{0.544454, 0.216737, -0.008800},{
      0.542507, 0.218684, -0.008800},{0.541635, 0.217482, -0.010068}}],
    Polygon[{{0.544454, 0.216737, -0.008800},{0.545480, 0.217482, -0.007315},{
      0.543253, 0.219710, -0.007315},{0.542507, 0.218684, -0.008800}}],
    Polygon[{{0.545480, 0.217482, -0.007315},{0.546306, 0.218082, -0.005650},{
      0.543853, 0.220535, -0.005650},{0.543253, 0.219710, -0.007315}}],
    Polygon[{{0.546306, 0.218082, -0.005650},{0.546910, 0.218521, -0.003846},{
      0.544292, 0.221140, -0.003846},{0.543853, 0.220535, -0.005650}}],
    Polygon[{{0.546910, 0.218521, -0.003846},{0.547279, 0.218789, -0.001947},{
      0.544560, 0.221509, -0.001947},{0.544292, 0.221140, -0.003846}}],
    Polygon[{{0.547279, 0.218789, -0.001947},{0.547403, 0.218879, 0.000000},{
      0.544650, 0.221632, 0.000000},{0.544560, 0.221509, -0.001947}}],
    Polygon[{{0.547403, 0.218879, 0.000000},{0.547279, 0.218789, 0.001947},{
      0.544560, 0.221509, 0.001947},{0.544650, 0.221632, 0.000000}}],
    Polygon[{{0.547279, 0.218789, 0.001947},{0.546910, 0.218521, 0.003846},{
      0.544292, 0.221140, 0.003846},{0.544560, 0.221509, 0.001947}}],
    Polygon[{{0.546910, 0.218521, 0.003846},{0.546306, 0.218082, 0.005650},{
      0.543853, 0.220535, 0.005650},{0.544292, 0.221140, 0.003846}}],
    Polygon[{{0.546306, 0.218082, 0.005650},{0.545480, 0.217482, 0.007315},{
      0.543253, 0.219710, 0.007315},{0.543853, 0.220535, 0.005650}}],
    Polygon[{{0.545480, 0.217482, 0.007315},{0.544454, 0.216737, 0.008800},{
      0.542507, 0.218684, 0.008800},{0.543253, 0.219710, 0.007315}}],
    Polygon[{{0.544454, 0.216737, 0.008800},{0.543253, 0.215864, 0.010068},{
      0.541635, 0.217482, 0.010068},{0.542507, 0.218684, 0.008800}}],
    Polygon[{{0.543253, 0.215864, 0.010068},{0.541906, 0.214885, 0.011089},{
      0.540656, 0.216135, 0.011089},{0.541635, 0.217482, 0.010068}}],
    Polygon[{{0.541906, 0.214885, 0.011089},{0.540446, 0.213825, 0.011836},{
      0.539595, 0.214676, 0.011836},{0.540656, 0.216135, 0.011089}}],
    Polygon[{{0.540446, 0.213825, 0.011836},{0.538910, 0.212709, 0.012292},{
      0.538479, 0.213139, 0.012292},{0.539595, 0.214676, 0.011836}}],
    Polygon[{{0.538479, 0.213139, -0.012292},{0.539595, 0.214676, -0.011836},{
      0.538523, 0.215222, -0.011836},{0.537936, 0.213416, -0.012292}}],
    Polygon[{{0.539595, 0.214676, -0.011836},{0.540656, 0.216135, -0.011089},{
      0.539081, 0.216938, -0.011089},{0.538523, 0.215222, -0.011836}}],
    Polygon[{{0.540656, 0.216135, -0.011089},{0.541635, 0.217482, -0.010068},{
      0.539595, 0.218521, -0.010068},{0.539081, 0.216938, -0.011089}}],
    Polygon[{{0.541635, 0.217482, -0.010068},{0.542507, 0.218684, -0.008800},{
      0.540054, 0.219933, -0.008800},{0.539595, 0.218521, -0.010068}}],
    Polygon[{{0.542507, 0.218684, -0.008800},{0.543253, 0.219710, -0.007315},{
      0.540446, 0.221140, -0.007315},{0.540054, 0.219933, -0.008800}}],
    Polygon[{{0.543253, 0.219710, -0.007315},{0.543853, 0.220535, -0.005650},{
      0.540761, 0.222110, -0.005650},{0.540446, 0.221140, -0.007315}}],
    Polygon[{{0.543853, 0.220535, -0.005650},{0.544292, 0.221140, -0.003846},{
      0.540992, 0.222821, -0.003846},{0.540761, 0.222110, -0.005650}}],
    Polygon[{{0.544292, 0.221140, -0.003846},{0.544560, 0.221509, -0.001947},{
      0.541133, 0.223254, -0.001947},{0.540992, 0.222821, -0.003846}}],
    Polygon[{{0.544560, 0.221509, -0.001947},{0.544650, 0.221632, 0.000000},{
      0.541181, 0.223400, 0.000000},{0.541133, 0.223254, -0.001947}}],
    Polygon[{{0.544650, 0.221632, 0.000000},{0.544560, 0.221509, 0.001947},{
      0.541133, 0.223254, 0.001947},{0.541181, 0.223400, 0.000000}}],
    Polygon[{{0.544560, 0.221509, 0.001947},{0.544292, 0.221140, 0.003846},{
      0.540992, 0.222821, 0.003846},{0.541133, 0.223254, 0.001947}}],
    Polygon[{{0.544292, 0.221140, 0.003846},{0.543853, 0.220535, 0.005650},{
      0.540761, 0.222110, 0.005650},{0.540992, 0.222821, 0.003846}}],
    Polygon[{{0.543853, 0.220535, 0.005650},{0.543253, 0.219710, 0.007315},{
      0.540446, 0.221140, 0.007315},{0.540761, 0.222110, 0.005650}}],
    Polygon[{{0.543253, 0.219710, 0.007315},{0.542507, 0.218684, 0.008800},{
      0.540054, 0.219933, 0.008800},{0.540446, 0.221140, 0.007315}}],
    Polygon[{{0.542507, 0.218684, 0.008800},{0.541635, 0.217482, 0.010068},{
      0.539595, 0.218521, 0.010068},{0.540054, 0.219933, 0.008800}}],
    Polygon[{{0.541635, 0.217482, 0.010068},{0.540656, 0.216135, 0.011089},{
      0.539081, 0.216938, 0.011089},{0.539595, 0.218521, 0.010068}}],
    Polygon[{{0.540656, 0.216135, 0.011089},{0.539595, 0.214676, 0.011836},{
      0.538523, 0.215222, 0.011836},{0.539081, 0.216938, 0.011089}}],
    Polygon[{{0.539595, 0.214676, 0.011836},{0.538479, 0.213139, 0.012292},{
      0.537936, 0.213416, 0.012292},{0.538523, 0.215222, 0.011836}}],
    Polygon[{{0.537936, 0.213416, -0.012292},{0.538523, 0.215222, -0.011836},{
      0.537335, 0.215410, -0.011836},{0.537335, 0.213511, -0.012292}}],
    Polygon[{{0.538523, 0.215222, -0.011836},{0.539081, 0.216938, -0.011089},{
      0.537335, 0.217214, -0.011089},{0.537335, 0.215410, -0.011836}}],
    Polygon[{{0.539081, 0.216938, -0.011089},{0.539595, 0.218521, -0.010068},{
      0.537335, 0.218879, -0.010068},{0.537335, 0.217214, -0.011089}}],
    Polygon[{{0.539595, 0.218521, -0.010068},{0.540054, 0.219933, -0.008800},{
      0.537335, 0.220364, -0.008800},{0.537335, 0.218879, -0.010068}}],
    Polygon[{{0.540054, 0.219933, -0.008800},{0.540446, 0.221140, -0.007315},{
      0.537335, 0.221632, -0.007315},{0.537335, 0.220364, -0.008800}}],
    Polygon[{{0.540446, 0.221140, -0.007315},{0.540761, 0.222110, -0.005650},{
      0.537335, 0.222653, -0.005650},{0.537335, 0.221632, -0.007315}}],
    Polygon[{{0.540761, 0.222110, -0.005650},{0.540992, 0.222821, -0.003846},{
      0.537335, 0.223400, -0.003846},{0.537335, 0.222653, -0.005650}}],
    Polygon[{{0.540992, 0.222821, -0.003846},{0.541133, 0.223254, -0.001947},{
      0.537335, 0.223856, -0.001947},{0.537335, 0.223400, -0.003846}}],
    Polygon[{{0.541133, 0.223254, -0.001947},{0.541181, 0.223400, 0.000000},{
      0.537335, 0.224009, 0.000000},{0.537335, 0.223856, -0.001947}}],
    Polygon[{{0.541181, 0.223400, 0.000000},{0.541133, 0.223254, 0.001947},{
      0.537335, 0.223856, 0.001947},{0.537335, 0.224009, 0.000000}}],
    Polygon[{{0.541133, 0.223254, 0.001947},{0.540992, 0.222821, 0.003846},{
      0.537335, 0.223400, 0.003846},{0.537335, 0.223856, 0.001947}}],
    Polygon[{{0.540992, 0.222821, 0.003846},{0.540761, 0.222110, 0.005650},{
      0.537335, 0.222653, 0.005650},{0.537335, 0.223400, 0.003846}}],
    Polygon[{{0.540761, 0.222110, 0.005650},{0.540446, 0.221140, 0.007315},{
      0.537335, 0.221632, 0.007315},{0.537335, 0.222653, 0.005650}}],
    Polygon[{{0.540446, 0.221140, 0.007315},{0.540054, 0.219933, 0.008800},{
      0.537335, 0.220364, 0.008800},{0.537335, 0.221632, 0.007315}}],
    Polygon[{{0.540054, 0.219933, 0.008800},{0.539595, 0.218521, 0.010068},{
      0.537335, 0.218879, 0.010068},{0.537335, 0.220364, 0.008800}}],
    Polygon[{{0.539595, 0.218521, 0.010068},{0.539081, 0.216938, 0.011089},{
      0.537335, 0.217214, 0.011089},{0.537335, 0.218879, 0.010068}}],
    Polygon[{{0.539081, 0.216938, 0.011089},{0.538523, 0.215222, 0.011836},{
      0.537335, 0.215410, 0.011836},{0.537335, 0.217214, 0.011089}}],
    Polygon[{{0.538523, 0.215222, 0.011836},{0.537936, 0.213416, 0.012292},{
      0.537335, 0.213511, 0.012292},{0.537335, 0.215410, 0.011836}}],
    Polygon[{{0.537335, 0.213511, -0.012292},{0.537335, 0.215410, -0.011836},{
      0.536146, 0.215222, -0.011836},{0.536733, 0.213416, -0.012292}}],
    Polygon[{{0.537335, 0.215410, -0.011836},{0.537335, 0.217214, -0.011089},{
      0.535589, 0.216938, -0.011089},{0.536146, 0.215222, -0.011836}}],
    Polygon[{{0.537335, 0.217214, -0.011089},{0.537335, 0.218879, -0.010068},{
      0.535074, 0.218521, -0.010068},{0.535589, 0.216938, -0.011089}}],
    Polygon[{{0.537335, 0.218879, -0.010068},{0.537335, 0.220364, -0.008800},{
      0.534616, 0.219933, -0.008800},{0.535074, 0.218521, -0.010068}}],
    Polygon[{{0.537335, 0.220364, -0.008800},{0.537335, 0.221632, -0.007315},{
      0.534224, 0.221140, -0.007315},{0.534616, 0.219933, -0.008800}}],
    Polygon[{{0.537335, 0.221632, -0.007315},{0.537335, 0.222653, -0.005650},{
      0.533908, 0.222110, -0.005650},{0.534224, 0.221140, -0.007315}}],
    Polygon[{{0.537335, 0.222653, -0.005650},{0.537335, 0.223400, -0.003846},{
      0.533677, 0.222821, -0.003846},{0.533908, 0.222110, -0.005650}}],
    Polygon[{{0.537335, 0.223400, -0.003846},{0.537335, 0.223856, -0.001947},{
      0.533536, 0.223254, -0.001947},{0.533677, 0.222821, -0.003846}}],
    Polygon[{{0.537335, 0.223856, -0.001947},{0.537335, 0.224009, 0.000000},{
      0.533489, 0.223400, 0.000000},{0.533536, 0.223254, -0.001947}}],
    Polygon[{{0.537335, 0.224009, 0.000000},{0.537335, 0.223856, 0.001947},{
      0.533536, 0.223254, 0.001947},{0.533489, 0.223400, 0.000000}}],
    Polygon[{{0.537335, 0.223856, 0.001947},{0.537335, 0.223400, 0.003846},{
      0.533677, 0.222821, 0.003846},{0.533536, 0.223254, 0.001947}}],
    Polygon[{{0.537335, 0.223400, 0.003846},{0.537335, 0.222653, 0.005650},{
      0.533908, 0.222110, 0.005650},{0.533677, 0.222821, 0.003846}}],
    Polygon[{{0.537335, 0.222653, 0.005650},{0.537335, 0.221632, 0.007315},{
      0.534224, 0.221140, 0.007315},{0.533908, 0.222110, 0.005650}}],
    Polygon[{{0.537335, 0.221632, 0.007315},{0.537335, 0.220364, 0.008800},{
      0.534616, 0.219933, 0.008800},{0.534224, 0.221140, 0.007315}}],
    Polygon[{{0.537335, 0.220364, 0.008800},{0.537335, 0.218879, 0.010068},{
      0.535074, 0.218521, 0.010068},{0.534616, 0.219933, 0.008800}}],
    Polygon[{{0.537335, 0.218879, 0.010068},{0.537335, 0.217214, 0.011089},{
      0.535589, 0.216938, 0.011089},{0.535074, 0.218521, 0.010068}}],
    Polygon[{{0.537335, 0.217214, 0.011089},{0.537335, 0.215410, 0.011836},{
      0.536146, 0.215222, 0.011836},{0.535589, 0.216938, 0.011089}}],
    Polygon[{{0.537335, 0.215410, 0.011836},{0.537335, 0.213511, 0.012292},{
      0.536733, 0.213416, 0.012292},{0.536146, 0.215222, 0.011836}}],
    Polygon[{{0.536733, 0.213416, -0.012292},{0.536146, 0.215222, -0.011836},{
      0.535074, 0.214676, -0.011836},{0.536191, 0.213139, -0.012292}}],
    Polygon[{{0.536146, 0.215222, -0.011836},{0.535589, 0.216938, -0.011089},{
      0.534014, 0.216135, -0.011089},{0.535074, 0.214676, -0.011836}}],
    Polygon[{{0.535589, 0.216938, -0.011089},{0.535074, 0.218521, -0.010068},{
      0.533035, 0.217482, -0.010068},{0.534014, 0.216135, -0.011089}}],
    Polygon[{{0.535074, 0.218521, -0.010068},{0.534616, 0.219933, -0.008800},{
      0.532162, 0.218684, -0.008800},{0.533035, 0.217482, -0.010068}}],
    Polygon[{{0.534616, 0.219933, -0.008800},{0.534224, 0.221140, -0.007315},{
      0.531417, 0.219710, -0.007315},{0.532162, 0.218684, -0.008800}}],
    Polygon[{{0.534224, 0.221140, -0.007315},{0.533908, 0.222110, -0.005650},{
      0.530817, 0.220535, -0.005650},{0.531417, 0.219710, -0.007315}}],
    Polygon[{{0.533908, 0.222110, -0.005650},{0.533677, 0.222821, -0.003846},{
      0.530378, 0.221140, -0.003846},{0.530817, 0.220535, -0.005650}}],
    Polygon[{{0.533677, 0.222821, -0.003846},{0.533536, 0.223254, -0.001947},{
      0.530110, 0.221509, -0.001947},{0.530378, 0.221140, -0.003846}}],
    Polygon[{{0.533536, 0.223254, -0.001947},{0.533489, 0.223400, 0.000000},{
      0.530020, 0.221632, 0.000000},{0.530110, 0.221509, -0.001947}}],
    Polygon[{{0.533489, 0.223400, 0.000000},{0.533536, 0.223254, 0.001947},{
      0.530110, 0.221509, 0.001947},{0.530020, 0.221632, 0.000000}}],
    Polygon[{{0.533536, 0.223254, 0.001947},{0.533677, 0.222821, 0.003846},{
      0.530378, 0.221140, 0.003846},{0.530110, 0.221509, 0.001947}}],
    Polygon[{{0.533677, 0.222821, 0.003846},{0.533908, 0.222110, 0.005650},{
      0.530817, 0.220535, 0.005650},{0.530378, 0.221140, 0.003846}}],
    Polygon[{{0.533908, 0.222110, 0.005650},{0.534224, 0.221140, 0.007315},{
      0.531417, 0.219710, 0.007315},{0.530817, 0.220535, 0.005650}}],
    Polygon[{{0.534224, 0.221140, 0.007315},{0.534616, 0.219933, 0.008800},{
      0.532162, 0.218684, 0.008800},{0.531417, 0.219710, 0.007315}}],
    Polygon[{{0.534616, 0.219933, 0.008800},{0.535074, 0.218521, 0.010068},{
      0.533035, 0.217482, 0.010068},{0.532162, 0.218684, 0.008800}}],
    Polygon[{{0.535074, 0.218521, 0.010068},{0.535589, 0.216938, 0.011089},{
      0.534014, 0.216135, 0.011089},{0.533035, 0.217482, 0.010068}}],
    Polygon[{{0.535589, 0.216938, 0.011089},{0.536146, 0.215222, 0.011836},{
      0.535074, 0.214676, 0.011836},{0.534014, 0.216135, 0.011089}}],
    Polygon[{{0.536146, 0.215222, 0.011836},{0.536733, 0.213416, 0.012292},{
      0.536191, 0.213139, 0.012292},{0.535074, 0.214676, 0.011836}}],
    Polygon[{{0.536191, 0.213139, -0.012292},{0.535074, 0.214676, -0.011836},{
      0.534224, 0.213825, -0.011836},{0.535760, 0.212709, -0.012292}}],
    Polygon[{{0.535074, 0.214676, -0.011836},{0.534014, 0.216135, -0.011089},{
      0.532764, 0.214885, -0.011089},{0.534224, 0.213825, -0.011836}}],
    Polygon[{{0.534014, 0.216135, -0.011089},{0.533035, 0.217482, -0.010068},{
      0.531417, 0.215864, -0.010068},{0.532764, 0.214885, -0.011089}}],
    Polygon[{{0.533035, 0.217482, -0.010068},{0.532162, 0.218684, -0.008800},{
      0.530216, 0.216737, -0.008800},{0.531417, 0.215864, -0.010068}}],
    Polygon[{{0.532162, 0.218684, -0.008800},{0.531417, 0.219710, -0.007315},{
      0.529190, 0.217482, -0.007315},{0.530216, 0.216737, -0.008800}}],
    Polygon[{{0.531417, 0.219710, -0.007315},{0.530817, 0.220535, -0.005650},{
      0.528364, 0.218082, -0.005650},{0.529190, 0.217482, -0.007315}}],
    Polygon[{{0.530817, 0.220535, -0.005650},{0.530378, 0.221140, -0.003846},{
      0.527759, 0.218521, -0.003846},{0.528364, 0.218082, -0.005650}}],
    Polygon[{{0.530378, 0.221140, -0.003846},{0.530110, 0.221509, -0.001947},{
      0.527391, 0.218789, -0.001947},{0.527759, 0.218521, -0.003846}}],
    Polygon[{{0.530110, 0.221509, -0.001947},{0.530020, 0.221632, 0.000000},{
      0.527267, 0.218879, 0.000000},{0.527391, 0.218789, -0.001947}}],
    Polygon[{{0.530020, 0.221632, 0.000000},{0.530110, 0.221509, 0.001947},{
      0.527391, 0.218789, 0.001947},{0.527267, 0.218879, 0.000000}}],
    Polygon[{{0.530110, 0.221509, 0.001947},{0.530378, 0.221140, 0.003846},{
      0.527759, 0.218521, 0.003846},{0.527391, 0.218789, 0.001947}}],
    Polygon[{{0.530378, 0.221140, 0.003846},{0.530817, 0.220535, 0.005650},{
      0.528364, 0.218082, 0.005650},{0.527759, 0.218521, 0.003846}}],
    Polygon[{{0.530817, 0.220535, 0.005650},{0.531417, 0.219710, 0.007315},{
      0.529190, 0.217482, 0.007315},{0.528364, 0.218082, 0.005650}}],
    Polygon[{{0.531417, 0.219710, 0.007315},{0.532162, 0.218684, 0.008800},{
      0.530216, 0.216737, 0.008800},{0.529190, 0.217482, 0.007315}}],
    Polygon[{{0.532162, 0.218684, 0.008800},{0.533035, 0.217482, 0.010068},{
      0.531417, 0.215864, 0.010068},{0.530216, 0.216737, 0.008800}}],
    Polygon[{{0.533035, 0.217482, 0.010068},{0.534014, 0.216135, 0.011089},{
      0.532764, 0.214885, 0.011089},{0.531417, 0.215864, 0.010068}}],
    Polygon[{{0.534014, 0.216135, 0.011089},{0.535074, 0.214676, 0.011836},{
      0.534224, 0.213825, 0.011836},{0.532764, 0.214885, 0.011089}}],
    Polygon[{{0.535074, 0.214676, 0.011836},{0.536191, 0.213139, 0.012292},{
      0.535760, 0.212709, 0.012292},{0.534224, 0.213825, 0.011836}}],
    Polygon[{{0.535760, 0.212709, -0.012292},{0.534224, 0.213825, -0.011836},{
      0.533677, 0.212753, -0.011836},{0.535483, 0.212166, -0.012292}}],
    Polygon[{{0.534224, 0.213825, -0.011836},{0.532764, 0.214885, -0.011089},{
      0.531962, 0.213310, -0.011089},{0.533677, 0.212753, -0.011836}}],
    Polygon[{{0.532764, 0.214885, -0.011089},{0.531417, 0.215864, -0.010068},{
      0.530378, 0.213825, -0.010068},{0.531962, 0.213310, -0.011089}}],
    Polygon[{{0.531417, 0.215864, -0.010068},{0.530216, 0.216737, -0.008800},{
      0.528966, 0.214284, -0.008800},{0.530378, 0.213825, -0.010068}}],
    Polygon[{{0.530216, 0.216737, -0.008800},{0.529190, 0.217482, -0.007315},{
      0.527759, 0.214676, -0.007315},{0.528966, 0.214284, -0.008800}}],
    Polygon[{{0.529190, 0.217482, -0.007315},{0.528364, 0.218082, -0.005650},{
      0.526789, 0.214991, -0.005650},{0.527759, 0.214676, -0.007315}}],
    Polygon[{{0.528364, 0.218082, -0.005650},{0.527759, 0.218521, -0.003846},{
      0.526078, 0.215222, -0.003846},{0.526789, 0.214991, -0.005650}}],
    Polygon[{{0.527759, 0.218521, -0.003846},{0.527391, 0.218789, -0.001947},{
      0.525645, 0.215363, -0.001947},{0.526078, 0.215222, -0.003846}}],
    Polygon[{{0.527391, 0.218789, -0.001947},{0.527267, 0.218879, 0.000000},{
      0.525499, 0.215410, 0.000000},{0.525645, 0.215363, -0.001947}}],
    Polygon[{{0.527267, 0.218879, 0.000000},{0.527391, 0.218789, 0.001947},{
      0.525645, 0.215363, 0.001947},{0.525499, 0.215410, 0.000000}}],
    Polygon[{{0.527391, 0.218789, 0.001947},{0.527759, 0.218521, 0.003846},{
      0.526078, 0.215222, 0.003846},{0.525645, 0.215363, 0.001947}}],
    Polygon[{{0.527759, 0.218521, 0.003846},{0.528364, 0.218082, 0.005650},{
      0.526789, 0.214991, 0.005650},{0.526078, 0.215222, 0.003846}}],
    Polygon[{{0.528364, 0.218082, 0.005650},{0.529190, 0.217482, 0.007315},{
      0.527759, 0.214676, 0.007315},{0.526789, 0.214991, 0.005650}}],
    Polygon[{{0.529190, 0.217482, 0.007315},{0.530216, 0.216737, 0.008800},{
      0.528966, 0.214284, 0.008800},{0.527759, 0.214676, 0.007315}}],
    Polygon[{{0.530216, 0.216737, 0.008800},{0.531417, 0.215864, 0.010068},{
      0.530378, 0.213825, 0.010068},{0.528966, 0.214284, 0.008800}}],
    Polygon[{{0.531417, 0.215864, 0.010068},{0.532764, 0.214885, 0.011089},{
      0.531962, 0.213310, 0.011089},{0.530378, 0.213825, 0.010068}}],
    Polygon[{{0.532764, 0.214885, 0.011089},{0.534224, 0.213825, 0.011836},{
      0.533677, 0.212753, 0.011836},{0.531962, 0.213310, 0.011089}}],
    Polygon[{{0.534224, 0.213825, 0.011836},{0.535760, 0.212709, 0.012292},{
      0.535483, 0.212166, 0.012292},{0.533677, 0.212753, 0.011836}}],
    Polygon[{{0.535483, 0.212166, -0.012292},{0.533677, 0.212753, -0.011836},{
      0.533489, 0.211564, -0.011836},{0.535388, 0.211564, -0.012292}}],
    Polygon[{{0.533677, 0.212753, -0.011836},{0.531962, 0.213310, -0.011089},{
      0.531685, 0.211564, -0.011089},{0.533489, 0.211564, -0.011836}}],
    Polygon[{{0.531962, 0.213310, -0.011089},{0.530378, 0.213825, -0.010068},{
      0.530020, 0.211564, -0.010068},{0.531685, 0.211564, -0.011089}}],
    Polygon[{{0.530378, 0.213825, -0.010068},{0.528966, 0.214284, -0.008800},{
      0.528535, 0.211564, -0.008800},{0.530020, 0.211564, -0.010068}}],
    Polygon[{{0.528966, 0.214284, -0.008800},{0.527759, 0.214676, -0.007315},{
      0.527267, 0.211564, -0.007315},{0.528535, 0.211564, -0.008800}}],
    Polygon[{{0.527759, 0.214676, -0.007315},{0.526789, 0.214991, -0.005650},{
      0.526246, 0.211564, -0.005650},{0.527267, 0.211564, -0.007315}}],
    Polygon[{{0.526789, 0.214991, -0.005650},{0.526078, 0.215222, -0.003846},{
      0.525499, 0.211564, -0.003846},{0.526246, 0.211564, -0.005650}}],
    Polygon[{{0.526078, 0.215222, -0.003846},{0.525645, 0.215363, -0.001947},{
      0.525043, 0.211564, -0.001947},{0.525499, 0.211564, -0.003846}}],
    Polygon[{{0.525645, 0.215363, -0.001947},{0.525499, 0.215410, 0.000000},{
      0.524890, 0.211564, 0.000000},{0.525043, 0.211564, -0.001947}}],
    Polygon[{{0.525499, 0.215410, 0.000000},{0.525645, 0.215363, 0.001947},{
      0.525043, 0.211564, 0.001947},{0.524890, 0.211564, 0.000000}}],
    Polygon[{{0.525645, 0.215363, 0.001947},{0.526078, 0.215222, 0.003846},{
      0.525499, 0.211564, 0.003846},{0.525043, 0.211564, 0.001947}}],
    Polygon[{{0.526078, 0.215222, 0.003846},{0.526789, 0.214991, 0.005650},{
      0.526246, 0.211564, 0.005650},{0.525499, 0.211564, 0.003846}}],
    Polygon[{{0.526789, 0.214991, 0.005650},{0.527759, 0.214676, 0.007315},{
      0.527267, 0.211564, 0.007315},{0.526246, 0.211564, 0.005650}}],
    Polygon[{{0.527759, 0.214676, 0.007315},{0.528966, 0.214284, 0.008800},{
      0.528535, 0.211564, 0.008800},{0.527267, 0.211564, 0.007315}}],
    Polygon[{{0.528966, 0.214284, 0.008800},{0.530378, 0.213825, 0.010068},{
      0.530020, 0.211564, 0.010068},{0.528535, 0.211564, 0.008800}}],
    Polygon[{{0.530378, 0.213825, 0.010068},{0.531962, 0.213310, 0.011089},{
      0.531685, 0.211564, 0.011089},{0.530020, 0.211564, 0.010068}}],
    Polygon[{{0.531962, 0.213310, 0.011089},{0.533677, 0.212753, 0.011836},{
      0.533489, 0.211564, 0.011836},{0.531685, 0.211564, 0.011089}}],
    Polygon[{{0.533677, 0.212753, 0.011836},{0.535483, 0.212166, 0.012292},{
      0.535388, 0.211564, 0.012292},{0.533489, 0.211564, 0.011836}}],
    Polygon[{{0.535388, 0.211564, -0.012292},{0.533489, 0.211564, -0.011836},{
      0.533677, 0.210376, -0.011836},{0.535483, 0.210963, -0.012292}}],
    Polygon[{{0.533489, 0.211564, -0.011836},{0.531685, 0.211564, -0.011089},{
      0.531962, 0.209818, -0.011089},{0.533677, 0.210376, -0.011836}}],
    Polygon[{{0.531685, 0.211564, -0.011089},{0.530020, 0.211564, -0.010068},{
      0.530378, 0.209304, -0.010068},{0.531962, 0.209818, -0.011089}}],
    Polygon[{{0.530020, 0.211564, -0.010068},{0.528535, 0.211564, -0.008800},{
      0.528966, 0.208845, -0.008800},{0.530378, 0.209304, -0.010068}}],
    Polygon[{{0.528535, 0.211564, -0.008800},{0.527267, 0.211564, -0.007315},{
      0.527759, 0.208453, -0.007315},{0.528966, 0.208845, -0.008800}}],
    Polygon[{{0.527267, 0.211564, -0.007315},{0.526246, 0.211564, -0.005650},{
      0.526789, 0.208138, -0.005650},{0.527759, 0.208453, -0.007315}}],
    Polygon[{{0.526246, 0.211564, -0.005650},{0.525499, 0.211564, -0.003846},{
      0.526078, 0.207907, -0.003846},{0.526789, 0.208138, -0.005650}}],
    Polygon[{{0.525499, 0.211564, -0.003846},{0.525043, 0.211564, -0.001947},{
      0.525645, 0.207766, -0.001947},{0.526078, 0.207907, -0.003846}}],
    Polygon[{{0.525043, 0.211564, -0.001947},{0.524890, 0.211564, 0.000000},{
      0.525499, 0.207719, 0.000000},{0.525645, 0.207766, -0.001947}}],
    Polygon[{{0.524890, 0.211564, 0.000000},{0.525043, 0.211564, 0.001947},{
      0.525645, 0.207766, 0.001947},{0.525499, 0.207719, 0.000000}}],
    Polygon[{{0.525043, 0.211564, 0.001947},{0.525499, 0.211564, 0.003846},{
      0.526078, 0.207907, 0.003846},{0.525645, 0.207766, 0.001947}}],
    Polygon[{{0.525499, 0.211564, 0.003846},{0.526246, 0.211564, 0.005650},{
      0.526789, 0.208138, 0.005650},{0.526078, 0.207907, 0.003846}}],
    Polygon[{{0.526246, 0.211564, 0.005650},{0.527267, 0.211564, 0.007315},{
      0.527759, 0.208453, 0.007315},{0.526789, 0.208138, 0.005650}}],
    Polygon[{{0.527267, 0.211564, 0.007315},{0.528535, 0.211564, 0.008800},{
      0.528966, 0.208845, 0.008800},{0.527759, 0.208453, 0.007315}}],
    Polygon[{{0.528535, 0.211564, 0.008800},{0.530020, 0.211564, 0.010068},{
      0.530378, 0.209304, 0.010068},{0.528966, 0.208845, 0.008800}}],
    Polygon[{{0.530020, 0.211564, 0.010068},{0.531685, 0.211564, 0.011089},{
      0.531962, 0.209818, 0.011089},{0.530378, 0.209304, 0.010068}}],
    Polygon[{{0.531685, 0.211564, 0.011089},{0.533489, 0.211564, 0.011836},{
      0.533677, 0.210376, 0.011836},{0.531962, 0.209818, 0.011089}}],
    Polygon[{{0.533489, 0.211564, 0.011836},{0.535388, 0.211564, 0.012292},{
      0.535483, 0.210963, 0.012292},{0.533677, 0.210376, 0.011836}}],
    Polygon[{{0.535483, 0.210963, -0.012292},{0.533677, 0.210376, -0.011836},{
      0.534224, 0.209304, -0.011836},{0.535760, 0.210420, -0.012292}}],
    Polygon[{{0.533677, 0.210376, -0.011836},{0.531962, 0.209818, -0.011089},{
      0.532764, 0.208243, -0.011089},{0.534224, 0.209304, -0.011836}}],
    Polygon[{{0.531962, 0.209818, -0.011089},{0.530378, 0.209304, -0.010068},{
      0.531417, 0.207265, -0.010068},{0.532764, 0.208243, -0.011089}}],
    Polygon[{{0.530378, 0.209304, -0.010068},{0.528966, 0.208845, -0.008800},{
      0.530216, 0.206392, -0.008800},{0.531417, 0.207265, -0.010068}}],
    Polygon[{{0.528966, 0.208845, -0.008800},{0.527759, 0.208453, -0.007315},{
      0.529190, 0.205646, -0.007315},{0.530216, 0.206392, -0.008800}}],
    Polygon[{{0.527759, 0.208453, -0.007315},{0.526789, 0.208138, -0.005650},{
      0.528364, 0.205047, -0.005650},{0.529190, 0.205646, -0.007315}}],
    Polygon[{{0.526789, 0.208138, -0.005650},{0.526078, 0.207907, -0.003846},{
      0.527759, 0.204607, -0.003846},{0.528364, 0.205047, -0.005650}}],
    Polygon[{{0.526078, 0.207907, -0.003846},{0.525645, 0.207766, -0.001947},{
      0.527391, 0.204339, -0.001947},{0.527759, 0.204607, -0.003846}}],
    Polygon[{{0.525645, 0.207766, -0.001947},{0.525499, 0.207719, 0.000000},{
      0.527267, 0.204249, 0.000000},{0.527391, 0.204339, -0.001947}}],
    Polygon[{{0.525499, 0.207719, 0.000000},{0.525645, 0.207766, 0.001947},{
      0.527391, 0.204339, 0.001947},{0.527267, 0.204249, 0.000000}}],
    Polygon[{{0.525645, 0.207766, 0.001947},{0.526078, 0.207907, 0.003846},{
      0.527759, 0.204607, 0.003846},{0.527391, 0.204339, 0.001947}}],
    Polygon[{{0.526078, 0.207907, 0.003846},{0.526789, 0.208138, 0.005650},{
      0.528364, 0.205047, 0.005650},{0.527759, 0.204607, 0.003846}}],
    Polygon[{{0.526789, 0.208138, 0.005650},{0.527759, 0.208453, 0.007315},{
      0.529190, 0.205646, 0.007315},{0.528364, 0.205047, 0.005650}}],
    Polygon[{{0.527759, 0.208453, 0.007315},{0.528966, 0.208845, 0.008800},{
      0.530216, 0.206392, 0.008800},{0.529190, 0.205646, 0.007315}}],
    Polygon[{{0.528966, 0.208845, 0.008800},{0.530378, 0.209304, 0.010068},{
      0.531417, 0.207265, 0.010068},{0.530216, 0.206392, 0.008800}}],
    Polygon[{{0.530378, 0.209304, 0.010068},{0.531962, 0.209818, 0.011089},{
      0.532764, 0.208243, 0.011089},{0.531417, 0.207265, 0.010068}}],
    Polygon[{{0.531962, 0.209818, 0.011089},{0.533677, 0.210376, 0.011836},{
      0.534224, 0.209304, 0.011836},{0.532764, 0.208243, 0.011089}}],
    Polygon[{{0.533677, 0.210376, 0.011836},{0.535483, 0.210963, 0.012292},{
      0.535760, 0.210420, 0.012292},{0.534224, 0.209304, 0.011836}}],
    Polygon[{{0.535760, 0.210420, -0.012292},{0.534224, 0.209304, -0.011836},{
      0.535074, 0.208453, -0.011836},{0.536191, 0.209989, -0.012292}}],
    Polygon[{{0.534224, 0.209304, -0.011836},{0.532764, 0.208243, -0.011089},{
      0.534014, 0.206993, -0.011089},{0.535074, 0.208453, -0.011836}}],
    Polygon[{{0.532764, 0.208243, -0.011089},{0.531417, 0.207265, -0.010068},{
      0.533035, 0.205646, -0.010068},{0.534014, 0.206993, -0.011089}}],
    Polygon[{{0.531417, 0.207265, -0.010068},{0.530216, 0.206392, -0.008800},{
      0.532162, 0.204445, -0.008800},{0.533035, 0.205646, -0.010068}}],
    Polygon[{{0.530216, 0.206392, -0.008800},{0.529190, 0.205646, -0.007315},{
      0.531417, 0.203419, -0.007315},{0.532162, 0.204445, -0.008800}}],
    Polygon[{{0.529190, 0.205646, -0.007315},{0.528364, 0.205047, -0.005650},{
      0.530817, 0.202593, -0.005650},{0.531417, 0.203419, -0.007315}}],
    Polygon[{{0.528364, 0.205047, -0.005650},{0.527759, 0.204607, -0.003846},{
      0.530378, 0.201989, -0.003846},{0.530817, 0.202593, -0.005650}}],
    Polygon[{{0.527759, 0.204607, -0.003846},{0.527391, 0.204339, -0.001947},{
      0.530110, 0.201620, -0.001947},{0.530378, 0.201989, -0.003846}}],
    Polygon[{{0.527391, 0.204339, -0.001947},{0.527267, 0.204249, 0.000000},{
      0.530020, 0.201496, 0.000000},{0.530110, 0.201620, -0.001947}}],
    Polygon[{{0.527267, 0.204249, 0.000000},{0.527391, 0.204339, 0.001947},{
      0.530110, 0.201620, 0.001947},{0.530020, 0.201496, 0.000000}}],
    Polygon[{{0.527391, 0.204339, 0.001947},{0.527759, 0.204607, 0.003846},{
      0.530378, 0.201989, 0.003846},{0.530110, 0.201620, 0.001947}}],
    Polygon[{{0.527759, 0.204607, 0.003846},{0.528364, 0.205047, 0.005650},{
      0.530817, 0.202593, 0.005650},{0.530378, 0.201989, 0.003846}}],
    Polygon[{{0.528364, 0.205047, 0.005650},{0.529190, 0.205646, 0.007315},{
      0.531417, 0.203419, 0.007315},{0.530817, 0.202593, 0.005650}}],
    Polygon[{{0.529190, 0.205646, 0.007315},{0.530216, 0.206392, 0.008800},{
      0.532162, 0.204445, 0.008800},{0.531417, 0.203419, 0.007315}}],
    Polygon[{{0.530216, 0.206392, 0.008800},{0.531417, 0.207265, 0.010068},{
      0.533035, 0.205646, 0.010068},{0.532162, 0.204445, 0.008800}}],
    Polygon[{{0.531417, 0.207265, 0.010068},{0.532764, 0.208243, 0.011089},{
      0.534014, 0.206993, 0.011089},{0.533035, 0.205646, 0.010068}}],
    Polygon[{{0.532764, 0.208243, 0.011089},{0.534224, 0.209304, 0.011836},{
      0.535074, 0.208453, 0.011836},{0.534014, 0.206993, 0.011089}}],
    Polygon[{{0.534224, 0.209304, 0.011836},{0.535760, 0.210420, 0.012292},{
      0.536191, 0.209989, 0.012292},{0.535074, 0.208453, 0.011836}}],
    Polygon[{{0.536191, 0.209989, -0.012292},{0.535074, 0.208453, -0.011836},{
      0.536146, 0.207907, -0.011836},{0.536733, 0.209713, -0.012292}}],
    Polygon[{{0.535074, 0.208453, -0.011836},{0.534014, 0.206993, -0.011089},{
      0.535589, 0.206191, -0.011089},{0.536146, 0.207907, -0.011836}}],
    Polygon[{{0.534014, 0.206993, -0.011089},{0.533035, 0.205646, -0.010068},{
      0.535074, 0.204607, -0.010068},{0.535589, 0.206191, -0.011089}}],
    Polygon[{{0.533035, 0.205646, -0.010068},{0.532162, 0.204445, -0.008800},{
      0.534616, 0.203195, -0.008800},{0.535074, 0.204607, -0.010068}}],
    Polygon[{{0.532162, 0.204445, -0.008800},{0.531417, 0.203419, -0.007315},{
      0.534224, 0.201989, -0.007315},{0.534616, 0.203195, -0.008800}}],
    Polygon[{{0.531417, 0.203419, -0.007315},{0.530817, 0.202593, -0.005650},{
      0.533908, 0.201018, -0.005650},{0.534224, 0.201989, -0.007315}}],
    Polygon[{{0.530817, 0.202593, -0.005650},{0.530378, 0.201989, -0.003846},{
      0.533677, 0.200308, -0.003846},{0.533908, 0.201018, -0.005650}}],
    Polygon[{{0.530378, 0.201989, -0.003846},{0.530110, 0.201620, -0.001947},{
      0.533536, 0.199874, -0.001947},{0.533677, 0.200308, -0.003846}}],
    Polygon[{{0.530110, 0.201620, -0.001947},{0.530020, 0.201496, 0.000000},{
      0.533489, 0.199728, 0.000000},{0.533536, 0.199874, -0.001947}}],
    Polygon[{{0.530020, 0.201496, 0.000000},{0.530110, 0.201620, 0.001947},{
      0.533536, 0.199874, 0.001947},{0.533489, 0.199728, 0.000000}}],
    Polygon[{{0.530110, 0.201620, 0.001947},{0.530378, 0.201989, 0.003846},{
      0.533677, 0.200308, 0.003846},{0.533536, 0.199874, 0.001947}}],
    Polygon[{{0.530378, 0.201989, 0.003846},{0.530817, 0.202593, 0.005650},{
      0.533908, 0.201018, 0.005650},{0.533677, 0.200308, 0.003846}}],
    Polygon[{{0.530817, 0.202593, 0.005650},{0.531417, 0.203419, 0.007315},{
      0.534224, 0.201989, 0.007315},{0.533908, 0.201018, 0.005650}}],
    Polygon[{{0.531417, 0.203419, 0.007315},{0.532162, 0.204445, 0.008800},{
      0.534616, 0.203195, 0.008800},{0.534224, 0.201989, 0.007315}}],
    Polygon[{{0.532162, 0.204445, 0.008800},{0.533035, 0.205646, 0.010068},{
      0.535074, 0.204607, 0.010068},{0.534616, 0.203195, 0.008800}}],
    Polygon[{{0.533035, 0.205646, 0.010068},{0.534014, 0.206993, 0.011089},{
      0.535589, 0.206191, 0.011089},{0.535074, 0.204607, 0.010068}}],
    Polygon[{{0.534014, 0.206993, 0.011089},{0.535074, 0.208453, 0.011836},{
      0.536146, 0.207907, 0.011836},{0.535589, 0.206191, 0.011089}}],
    Polygon[{{0.535074, 0.208453, 0.011836},{0.536191, 0.209989, 0.012292},{
      0.536733, 0.209713, 0.012292},{0.536146, 0.207907, 0.011836}}],
    Polygon[{{0.536733, 0.209713, -0.012292},{0.536146, 0.207907, -0.011836},{
      0.537335, 0.207719, -0.011836},{0.537335, 0.209617, -0.012292}}],
    Polygon[{{0.536146, 0.207907, -0.011836},{0.535589, 0.206191, -0.011089},{
      0.537335, 0.205914, -0.011089},{0.537335, 0.207719, -0.011836}}],
    Polygon[{{0.535589, 0.206191, -0.011089},{0.535074, 0.204607, -0.010068},{
      0.537335, 0.204249, -0.010068},{0.537335, 0.205914, -0.011089}}],
    Polygon[{{0.535074, 0.204607, -0.010068},{0.534616, 0.203195, -0.008800},{
      0.537335, 0.202764, -0.008800},{0.537335, 0.204249, -0.010068}}],
    Polygon[{{0.534616, 0.203195, -0.008800},{0.534224, 0.201989, -0.007315},{
      0.537335, 0.201496, -0.007315},{0.537335, 0.202764, -0.008800}}],
    Polygon[{{0.534224, 0.201989, -0.007315},{0.533908, 0.201018, -0.005650},{
      0.537335, 0.200476, -0.005650},{0.537335, 0.201496, -0.007315}}],
    Polygon[{{0.533908, 0.201018, -0.005650},{0.533677, 0.200308, -0.003846},{
      0.537335, 0.199728, -0.003846},{0.537335, 0.200476, -0.005650}}],
    Polygon[{{0.533677, 0.200308, -0.003846},{0.533536, 0.199874, -0.001947},{
      0.537335, 0.199273, -0.001947},{0.537335, 0.199728, -0.003846}}],
    Polygon[{{0.533536, 0.199874, -0.001947},{0.533489, 0.199728, 0.000000},{
      0.537335, 0.199119, 0.000000},{0.537335, 0.199273, -0.001947}}],
    Polygon[{{0.533489, 0.199728, 0.000000},{0.533536, 0.199874, 0.001947},{
      0.537335, 0.199273, 0.001947},{0.537335, 0.199119, 0.000000}}],
    Polygon[{{0.533536, 0.199874, 0.001947},{0.533677, 0.200308, 0.003846},{
      0.537335, 0.199728, 0.003846},{0.537335, 0.199273, 0.001947}}],
    Polygon[{{0.533677, 0.200308, 0.003846},{0.533908, 0.201018, 0.005650},{
      0.537335, 0.200476, 0.005650},{0.537335, 0.199728, 0.003846}}],
    Polygon[{{0.533908, 0.201018, 0.005650},{0.534224, 0.201989, 0.007315},{
      0.537335, 0.201496, 0.007315},{0.537335, 0.200476, 0.005650}}],
    Polygon[{{0.534224, 0.201989, 0.007315},{0.534616, 0.203195, 0.008800},{
      0.537335, 0.202764, 0.008800},{0.537335, 0.201496, 0.007315}}],
    Polygon[{{0.534616, 0.203195, 0.008800},{0.535074, 0.204607, 0.010068},{
      0.537335, 0.204249, 0.010068},{0.537335, 0.202764, 0.008800}}],
    Polygon[{{0.535074, 0.204607, 0.010068},{0.535589, 0.206191, 0.011089},{
      0.537335, 0.205914, 0.011089},{0.537335, 0.204249, 0.010068}}],
    Polygon[{{0.535589, 0.206191, 0.011089},{0.536146, 0.207907, 0.011836},{
      0.537335, 0.207719, 0.011836},{0.537335, 0.205914, 0.011089}}],
    Polygon[{{0.536146, 0.207907, 0.011836},{0.536733, 0.209713, 0.012292},{
      0.537335, 0.209617, 0.012292},{0.537335, 0.207719, 0.011836}}],
    Polygon[{{0.537335, 0.209617, -0.012292},{0.537335, 0.207719, -0.011836},{
      0.538523, 0.207907, -0.011836},{0.537936, 0.209713, -0.012292}}],
    Polygon[{{0.537335, 0.207719, -0.011836},{0.537335, 0.205914, -0.011089},{
      0.539081, 0.206191, -0.011089},{0.538523, 0.207907, -0.011836}}],
    Polygon[{{0.537335, 0.205914, -0.011089},{0.537335, 0.204249, -0.010068},{
      0.539595, 0.204607, -0.010068},{0.539081, 0.206191, -0.011089}}],
    Polygon[{{0.537335, 0.204249, -0.010068},{0.537335, 0.202764, -0.008800},{
      0.540054, 0.203195, -0.008800},{0.539595, 0.204607, -0.010068}}],
    Polygon[{{0.537335, 0.202764, -0.008800},{0.537335, 0.201496, -0.007315},{
      0.540446, 0.201989, -0.007315},{0.540054, 0.203195, -0.008800}}],
    Polygon[{{0.537335, 0.201496, -0.007315},{0.537335, 0.200476, -0.005650},{
      0.540761, 0.201018, -0.005650},{0.540446, 0.201989, -0.007315}}],
    Polygon[{{0.537335, 0.200476, -0.005650},{0.537335, 0.199728, -0.003846},{
      0.540992, 0.200308, -0.003846},{0.540761, 0.201018, -0.005650}}],
    Polygon[{{0.537335, 0.199728, -0.003846},{0.537335, 0.199273, -0.001947},{
      0.541133, 0.199874, -0.001947},{0.540992, 0.200308, -0.003846}}],
    Polygon[{{0.537335, 0.199273, -0.001947},{0.537335, 0.199119, 0.000000},{
      0.541181, 0.199728, 0.000000},{0.541133, 0.199874, -0.001947}}],
    Polygon[{{0.537335, 0.199119, 0.000000},{0.537335, 0.199273, 0.001947},{
      0.541133, 0.199874, 0.001947},{0.541181, 0.199728, 0.000000}}],
    Polygon[{{0.537335, 0.199273, 0.001947},{0.537335, 0.199728, 0.003846},{
      0.540992, 0.200308, 0.003846},{0.541133, 0.199874, 0.001947}}],
    Polygon[{{0.537335, 0.199728, 0.003846},{0.537335, 0.200476, 0.005650},{
      0.540761, 0.201018, 0.005650},{0.540992, 0.200308, 0.003846}}],
    Polygon[{{0.537335, 0.200476, 0.005650},{0.537335, 0.201496, 0.007315},{
      0.540446, 0.201989, 0.007315},{0.540761, 0.201018, 0.005650}}],
    Polygon[{{0.537335, 0.201496, 0.007315},{0.537335, 0.202764, 0.008800},{
      0.540054, 0.203195, 0.008800},{0.540446, 0.201989, 0.007315}}],
    Polygon[{{0.537335, 0.202764, 0.008800},{0.537335, 0.204249, 0.010068},{
      0.539595, 0.204607, 0.010068},{0.540054, 0.203195, 0.008800}}],
    Polygon[{{0.537335, 0.204249, 0.010068},{0.537335, 0.205914, 0.011089},{
      0.539081, 0.206191, 0.011089},{0.539595, 0.204607, 0.010068}}],
    Polygon[{{0.537335, 0.205914, 0.011089},{0.537335, 0.207719, 0.011836},{
      0.538523, 0.207907, 0.011836},{0.539081, 0.206191, 0.011089}}],
    Polygon[{{0.537335, 0.207719, 0.011836},{0.537335, 0.209617, 0.012292},{
      0.537936, 0.209713, 0.012292},{0.538523, 0.207907, 0.011836}}],
    Polygon[{{0.537936, 0.209713, -0.012292},{0.538523, 0.207907, -0.011836},{
      0.539595, 0.208453, -0.011836},{0.538479, 0.209989, -0.012292}}],
    Polygon[{{0.538523, 0.207907, -0.011836},{0.539081, 0.206191, -0.011089},{
      0.540656, 0.206993, -0.011089},{0.539595, 0.208453, -0.011836}}],
    Polygon[{{0.539081, 0.206191, -0.011089},{0.539595, 0.204607, -0.010068},{
      0.541635, 0.205646, -0.010068},{0.540656, 0.206993, -0.011089}}],
    Polygon[{{0.539595, 0.204607, -0.010068},{0.540054, 0.203195, -0.008800},{
      0.542507, 0.204445, -0.008800},{0.541635, 0.205646, -0.010068}}],
    Polygon[{{0.540054, 0.203195, -0.008800},{0.540446, 0.201989, -0.007315},{
      0.543253, 0.203419, -0.007315},{0.542507, 0.204445, -0.008800}}],
    Polygon[{{0.540446, 0.201989, -0.007315},{0.540761, 0.201018, -0.005650},{
      0.543853, 0.202593, -0.005650},{0.543253, 0.203419, -0.007315}}],
    Polygon[{{0.540761, 0.201018, -0.005650},{0.540992, 0.200308, -0.003846},{
      0.544292, 0.201989, -0.003846},{0.543853, 0.202593, -0.005650}}],
    Polygon[{{0.540992, 0.200308, -0.003846},{0.541133, 0.199874, -0.001947},{
      0.544560, 0.201620, -0.001947},{0.544292, 0.201989, -0.003846}}],
    Polygon[{{0.541133, 0.199874, -0.001947},{0.541181, 0.199728, 0.000000},{
      0.544650, 0.201496, 0.000000},{0.544560, 0.201620, -0.001947}}],
    Polygon[{{0.541181, 0.199728, 0.000000},{0.541133, 0.199874, 0.001947},{
      0.544560, 0.201620, 0.001947},{0.544650, 0.201496, 0.000000}}],
    Polygon[{{0.541133, 0.199874, 0.001947},{0.540992, 0.200308, 0.003846},{
      0.544292, 0.201989, 0.003846},{0.544560, 0.201620, 0.001947}}],
    Polygon[{{0.540992, 0.200308, 0.003846},{0.540761, 0.201018, 0.005650},{
      0.543853, 0.202593, 0.005650},{0.544292, 0.201989, 0.003846}}],
    Polygon[{{0.540761, 0.201018, 0.005650},{0.540446, 0.201989, 0.007315},{
      0.543253, 0.203419, 0.007315},{0.543853, 0.202593, 0.005650}}],
    Polygon[{{0.540446, 0.201989, 0.007315},{0.540054, 0.203195, 0.008800},{
      0.542507, 0.204445, 0.008800},{0.543253, 0.203419, 0.007315}}],
    Polygon[{{0.540054, 0.203195, 0.008800},{0.539595, 0.204607, 0.010068},{
      0.541635, 0.205646, 0.010068},{0.542507, 0.204445, 0.008800}}],
    Polygon[{{0.539595, 0.204607, 0.010068},{0.539081, 0.206191, 0.011089},{
      0.540656, 0.206993, 0.011089},{0.541635, 0.205646, 0.010068}}],
    Polygon[{{0.539081, 0.206191, 0.011089},{0.538523, 0.207907, 0.011836},{
      0.539595, 0.208453, 0.011836},{0.540656, 0.206993, 0.011089}}],
    Polygon[{{0.538523, 0.207907, 0.011836},{0.537936, 0.209713, 0.012292},{
      0.538479, 0.209989, 0.012292},{0.539595, 0.208453, 0.011836}}],
    Polygon[{{0.538479, 0.209989, -0.012292},{0.539595, 0.208453, -0.011836},{
      0.540446, 0.209304, -0.011836},{0.538910, 0.210420, -0.012292}}],
    Polygon[{{0.539595, 0.208453, -0.011836},{0.540656, 0.206993, -0.011089},{
      0.541906, 0.208243, -0.011089},{0.540446, 0.209304, -0.011836}}],
    Polygon[{{0.540656, 0.206993, -0.011089},{0.541635, 0.205646, -0.010068},{
      0.543253, 0.207265, -0.010068},{0.541906, 0.208243, -0.011089}}],
    Polygon[{{0.541635, 0.205646, -0.010068},{0.542507, 0.204445, -0.008800},{
      0.544454, 0.206392, -0.008800},{0.543253, 0.207265, -0.010068}}],
    Polygon[{{0.542507, 0.204445, -0.008800},{0.543253, 0.203419, -0.007315},{
      0.545480, 0.205646, -0.007315},{0.544454, 0.206392, -0.008800}}],
    Polygon[{{0.543253, 0.203419, -0.007315},{0.543853, 0.202593, -0.005650},{
      0.546306, 0.205047, -0.005650},{0.545480, 0.205646, -0.007315}}],
    Polygon[{{0.543853, 0.202593, -0.005650},{0.544292, 0.201989, -0.003846},{
      0.546910, 0.204607, -0.003846},{0.546306, 0.205047, -0.005650}}],
    Polygon[{{0.544292, 0.201989, -0.003846},{0.544560, 0.201620, -0.001947},{
      0.547279, 0.204339, -0.001947},{0.546910, 0.204607, -0.003846}}],
    Polygon[{{0.544560, 0.201620, -0.001947},{0.544650, 0.201496, 0.000000},{
      0.547403, 0.204249, 0.000000},{0.547279, 0.204339, -0.001947}}],
    Polygon[{{0.544650, 0.201496, 0.000000},{0.544560, 0.201620, 0.001947},{
      0.547279, 0.204339, 0.001947},{0.547403, 0.204249, 0.000000}}],
    Polygon[{{0.544560, 0.201620, 0.001947},{0.544292, 0.201989, 0.003846},{
      0.546910, 0.204607, 0.003846},{0.547279, 0.204339, 0.001947}}],
    Polygon[{{0.544292, 0.201989, 0.003846},{0.543853, 0.202593, 0.005650},{
      0.546306, 0.205047, 0.005650},{0.546910, 0.204607, 0.003846}}],
    Polygon[{{0.543853, 0.202593, 0.005650},{0.543253, 0.203419, 0.007315},{
      0.545480, 0.205646, 0.007315},{0.546306, 0.205047, 0.005650}}],
    Polygon[{{0.543253, 0.203419, 0.007315},{0.542507, 0.204445, 0.008800},{
      0.544454, 0.206392, 0.008800},{0.545480, 0.205646, 0.007315}}],
    Polygon[{{0.542507, 0.204445, 0.008800},{0.541635, 0.205646, 0.010068},{
      0.543253, 0.207265, 0.010068},{0.544454, 0.206392, 0.008800}}],
    Polygon[{{0.541635, 0.205646, 0.010068},{0.540656, 0.206993, 0.011089},{
      0.541906, 0.208243, 0.011089},{0.543253, 0.207265, 0.010068}}],
    Polygon[{{0.540656, 0.206993, 0.011089},{0.539595, 0.208453, 0.011836},{
      0.540446, 0.209304, 0.011836},{0.541906, 0.208243, 0.011089}}],
    Polygon[{{0.539595, 0.208453, 0.011836},{0.538479, 0.209989, 0.012292},{
      0.538910, 0.210420, 0.012292},{0.540446, 0.209304, 0.011836}}],
    Polygon[{{0.538910, 0.210420, -0.012292},{0.540446, 0.209304, -0.011836},{
      0.540992, 0.210376, -0.011836},{0.539186, 0.210963, -0.012292}}],
    Polygon[{{0.540446, 0.209304, -0.011836},{0.541906, 0.208243, -0.011089},{
      0.542708, 0.209818, -0.011089},{0.540992, 0.210376, -0.011836}}],
    Polygon[{{0.541906, 0.208243, -0.011089},{0.543253, 0.207265, -0.010068},{
      0.544292, 0.209304, -0.010068},{0.542708, 0.209818, -0.011089}}],
    Polygon[{{0.543253, 0.207265, -0.010068},{0.544454, 0.206392, -0.008800},{
      0.545704, 0.208845, -0.008800},{0.544292, 0.209304, -0.010068}}],
    Polygon[{{0.544454, 0.206392, -0.008800},{0.545480, 0.205646, -0.007315},{
      0.546910, 0.208453, -0.007315},{0.545704, 0.208845, -0.008800}}],
    Polygon[{{0.545480, 0.205646, -0.007315},{0.546306, 0.205047, -0.005650},{
      0.547881, 0.208138, -0.005650},{0.546910, 0.208453, -0.007315}}],
    Polygon[{{0.546306, 0.205047, -0.005650},{0.546910, 0.204607, -0.003846},{
      0.548591, 0.207907, -0.003846},{0.547881, 0.208138, -0.005650}}],
    Polygon[{{0.546910, 0.204607, -0.003846},{0.547279, 0.204339, -0.001947},{
      0.549025, 0.207766, -0.001947},{0.548591, 0.207907, -0.003846}}],
    Polygon[{{0.547279, 0.204339, -0.001947},{0.547403, 0.204249, 0.000000},{
      0.549171, 0.207719, 0.000000},{0.549025, 0.207766, -0.001947}}],
    Polygon[{{0.547403, 0.204249, 0.000000},{0.547279, 0.204339, 0.001947},{
      0.549025, 0.207766, 0.001947},{0.549171, 0.207719, 0.000000}}],
    Polygon[{{0.547279, 0.204339, 0.001947},{0.546910, 0.204607, 0.003846},{
      0.548591, 0.207907, 0.003846},{0.549025, 0.207766, 0.001947}}],
    Polygon[{{0.546910, 0.204607, 0.003846},{0.546306, 0.205047, 0.005650},{
      0.547881, 0.208138, 0.005650},{0.548591, 0.207907, 0.003846}}],
    Polygon[{{0.546306, 0.205047, 0.005650},{0.545480, 0.205646, 0.007315},{
      0.546910, 0.208453, 0.007315},{0.547881, 0.208138, 0.005650}}],
    Polygon[{{0.545480, 0.205646, 0.007315},{0.544454, 0.206392, 0.008800},{
      0.545704, 0.208845, 0.008800},{0.546910, 0.208453, 0.007315}}],
    Polygon[{{0.544454, 0.206392, 0.008800},{0.543253, 0.207265, 0.010068},{
      0.544292, 0.209304, 0.010068},{0.545704, 0.208845, 0.008800}}],
    Polygon[{{0.543253, 0.207265, 0.010068},{0.541906, 0.208243, 0.011089},{
      0.542708, 0.209818, 0.011089},{0.544292, 0.209304, 0.010068}}],
    Polygon[{{0.541906, 0.208243, 0.011089},{0.540446, 0.209304, 0.011836},{
      0.540992, 0.210376, 0.011836},{0.542708, 0.209818, 0.011089}}],
    Polygon[{{0.540446, 0.209304, 0.011836},{0.538910, 0.210420, 0.012292},{
      0.539186, 0.210963, 0.012292},{0.540992, 0.210376, 0.011836}}],
    Polygon[{{0.539186, 0.210963, -0.012292},{0.540992, 0.210376, -0.011836},{
      0.541181, 0.211564, -0.011836},{0.539282, 0.211564, -0.012292}}],
    Polygon[{{0.540992, 0.210376, -0.011836},{0.542708, 0.209818, -0.011089},{
      0.542985, 0.211564, -0.011089},{0.541181, 0.211564, -0.011836}}],
    Polygon[{{0.542708, 0.209818, -0.011089},{0.544292, 0.209304, -0.010068},{
      0.544650, 0.211564, -0.010068},{0.542985, 0.211564, -0.011089}}],
    Polygon[{{0.544292, 0.209304, -0.010068},{0.545704, 0.208845, -0.008800},{
      0.546135, 0.211564, -0.008800},{0.544650, 0.211564, -0.010068}}],
    Polygon[{{0.545704, 0.208845, -0.008800},{0.546910, 0.208453, -0.007315},{
      0.547403, 0.211564, -0.007315},{0.546135, 0.211564, -0.008800}}],
    Polygon[{{0.546910, 0.208453, -0.007315},{0.547881, 0.208138, -0.005650},{
      0.548423, 0.211564, -0.005650},{0.547403, 0.211564, -0.007315}}],
    Polygon[{{0.547881, 0.208138, -0.005650},{0.548591, 0.207907, -0.003846},{
      0.549171, 0.211564, -0.003846},{0.548423, 0.211564, -0.005650}}],
    Polygon[{{0.548591, 0.207907, -0.003846},{0.549025, 0.207766, -0.001947},{
      0.549627, 0.211564, -0.001947},{0.549171, 0.211564, -0.003846}}],
    Polygon[{{0.549025, 0.207766, -0.001947},{0.549171, 0.207719, 0.000000},{
      0.549780, 0.211564, 0.000000},{0.549627, 0.211564, -0.001947}}],
    Polygon[{{0.549171, 0.207719, 0.000000},{0.549025, 0.207766, 0.001947},{
      0.549627, 0.211564, 0.001947},{0.549780, 0.211564, 0.000000}}],
    Polygon[{{0.549025, 0.207766, 0.001947},{0.548591, 0.207907, 0.003846},{
      0.549171, 0.211564, 0.003846},{0.549627, 0.211564, 0.001947}}],
    Polygon[{{0.548591, 0.207907, 0.003846},{0.547881, 0.208138, 0.005650},{
      0.548423, 0.211564, 0.005650},{0.549171, 0.211564, 0.003846}}],
    Polygon[{{0.547881, 0.208138, 0.005650},{0.546910, 0.208453, 0.007315},{
      0.547403, 0.211564, 0.007315},{0.548423, 0.211564, 0.005650}}],
    Polygon[{{0.546910, 0.208453, 0.007315},{0.545704, 0.208845, 0.008800},{
      0.546135, 0.211564, 0.008800},{0.547403, 0.211564, 0.007315}}],
    Polygon[{{0.545704, 0.208845, 0.008800},{0.544292, 0.209304, 0.010068},{
      0.544650, 0.211564, 0.010068},{0.546135, 0.211564, 0.008800}}],
    Polygon[{{0.544292, 0.209304, 0.010068},{0.542708, 0.209818, 0.011089},{
      0.542985, 0.211564, 0.011089},{0.544650, 0.211564, 0.010068}}],
    Polygon[{{0.542708, 0.209818, 0.011089},{0.540992, 0.210376, 0.011836},{
      0.541181, 0.211564, 0.011836},{0.542985, 0.211564, 0.011089}}],
    Polygon[{{0.540992, 0.210376, 0.011836},{0.539186, 0.210963, 0.012292},{
      0.539282, 0.211564, 0.012292},{0.541181, 0.211564, 0.011836}}],
    Polygon[{{0.584544, 0.164172, -0.009538},{0.586017, 0.164172, -0.009185},{
      0.585871, 0.165094, -0.009185},{0.584470, 0.164639, -0.009538}}],
    Polygon[{{0.586017, 0.164172, -0.009185},{0.587417, 0.164172, -0.008605},{
      0.587203, 0.165527, -0.008605},{0.585871, 0.165094, -0.009185}}],
    Polygon[{{0.587417, 0.164172, -0.008605},{0.588709, 0.164172, -0.007813},{
      0.588432, 0.165926, -0.007813},{0.587203, 0.165527, -0.008605}}],
    Polygon[{{0.588709, 0.164172, -0.007813},{0.589862, 0.164172, -0.006829},{
      0.589528, 0.166282, -0.006829},{0.588432, 0.165926, -0.007813}}],
    Polygon[{{0.589862, 0.164172, -0.006829},{0.590846, 0.164172, -0.005676},{
      0.590464, 0.166586, -0.005676},{0.589528, 0.166282, -0.006829}}],
    Polygon[{{0.590846, 0.164172, -0.005676},{0.591638, 0.164172, -0.004384},{
      0.591217, 0.166831, -0.004384},{0.590464, 0.166586, -0.005676}}],
    Polygon[{{0.591638, 0.164172, -0.004384},{0.592218, 0.164172, -0.002984},{
      0.591768, 0.167010, -0.002984},{0.591217, 0.166831, -0.004384}}],
    Polygon[{{0.592218, 0.164172, -0.002984},{0.592571, 0.164172, -0.001511},{
      0.592105, 0.167119, -0.001511},{0.591768, 0.167010, -0.002984}}],
    Polygon[{{0.592571, 0.164172, -0.001511},{0.592690, 0.164172, 0.000000},{
      0.592218, 0.167156, 0.000000},{0.592105, 0.167119, -0.001511}}],
    Polygon[{{0.592690, 0.164172, 0.000000},{0.592571, 0.164172, 0.001511},{
      0.592105, 0.167119, 0.001511},{0.592218, 0.167156, 0.000000}}],
    Polygon[{{0.592571, 0.164172, 0.001511},{0.592218, 0.164172, 0.002984},{
      0.591768, 0.167010, 0.002984},{0.592105, 0.167119, 0.001511}}],
    Polygon[{{0.592218, 0.164172, 0.002984},{0.591638, 0.164172, 0.004384},{
      0.591217, 0.166831, 0.004384},{0.591768, 0.167010, 0.002984}}],
    Polygon[{{0.591638, 0.164172, 0.004384},{0.590846, 0.164172, 0.005676},{
      0.590464, 0.166586, 0.005676},{0.591217, 0.166831, 0.004384}}],
    Polygon[{{0.590846, 0.164172, 0.005676},{0.589862, 0.164172, 0.006829},{
      0.589528, 0.166282, 0.006829},{0.590464, 0.166586, 0.005676}}],
    Polygon[{{0.589862, 0.164172, 0.006829},{0.588709, 0.164172, 0.007813},{
      0.588432, 0.165926, 0.007813},{0.589528, 0.166282, 0.006829}}],
    Polygon[{{0.588709, 0.164172, 0.007813},{0.587417, 0.164172, 0.008605},{
      0.587203, 0.165527, 0.008605},{0.588432, 0.165926, 0.007813}}],
    Polygon[{{0.587417, 0.164172, 0.008605},{0.586017, 0.164172, 0.009185},{
      0.585871, 0.165094, 0.009185},{0.587203, 0.165527, 0.008605}}],
    Polygon[{{0.586017, 0.164172, 0.009185},{0.584544, 0.164172, 0.009538},{
      0.584470, 0.164639, 0.009538},{0.585871, 0.165094, 0.009185}}],
    Polygon[{{0.584470, 0.164639, -0.009538},{0.585871, 0.165094, -0.009185},{
      0.585447, 0.165926, -0.009185},{0.584255, 0.165060, -0.009538}}],
    Polygon[{{0.585871, 0.165094, -0.009185},{0.587203, 0.165527, -0.008605},{
      0.586580, 0.166749, -0.008605},{0.585447, 0.165926, -0.009185}}],
    Polygon[{{0.587203, 0.165527, -0.008605},{0.588432, 0.165926, -0.007813},{
      0.587625, 0.167508, -0.007813},{0.586580, 0.166749, -0.008605}}],
    Polygon[{{0.588432, 0.165926, -0.007813},{0.589528, 0.166282, -0.006829},{
      0.588558, 0.168186, -0.006829},{0.587625, 0.167508, -0.007813}}],
    Polygon[{{0.589528, 0.166282, -0.006829},{0.590464, 0.166586, -0.005676},{
      0.589354, 0.168764, -0.005676},{0.588558, 0.168186, -0.006829}}],
    Polygon[{{0.590464, 0.166586, -0.005676},{0.591217, 0.166831, -0.004384},{
      0.589994, 0.169230, -0.004384},{0.589354, 0.168764, -0.005676}}],
    Polygon[{{0.591217, 0.166831, -0.004384},{0.591768, 0.167010, -0.002984},{
      0.590464, 0.169570, -0.002984},{0.589994, 0.169230, -0.004384}}],
    Polygon[{{0.591768, 0.167010, -0.002984},{0.592105, 0.167119, -0.001511},{
      0.590750, 0.169778, -0.001511},{0.590464, 0.169570, -0.002984}}],
    Polygon[{{0.592105, 0.167119, -0.001511},{0.592218, 0.167156, 0.000000},{
      0.590846, 0.169848, 0.000000},{0.590750, 0.169778, -0.001511}}],
    Polygon[{{0.592218, 0.167156, 0.000000},{0.592105, 0.167119, 0.001511},{
      0.590750, 0.169778, 0.001511},{0.590846, 0.169848, 0.000000}}],
    Polygon[{{0.592105, 0.167119, 0.001511},{0.591768, 0.167010, 0.002984},{
      0.590464, 0.169570, 0.002984},{0.590750, 0.169778, 0.001511}}],
    Polygon[{{0.591768, 0.167010, 0.002984},{0.591217, 0.166831, 0.004384},{
      0.589994, 0.169230, 0.004384},{0.590464, 0.169570, 0.002984}}],
    Polygon[{{0.591217, 0.166831, 0.004384},{0.590464, 0.166586, 0.005676},{
      0.589354, 0.168764, 0.005676},{0.589994, 0.169230, 0.004384}}],
    Polygon[{{0.590464, 0.166586, 0.005676},{0.589528, 0.166282, 0.006829},{
      0.588558, 0.168186, 0.006829},{0.589354, 0.168764, 0.005676}}],
    Polygon[{{0.589528, 0.166282, 0.006829},{0.588432, 0.165926, 0.007813},{
      0.587625, 0.167508, 0.007813},{0.588558, 0.168186, 0.006829}}],
    Polygon[{{0.588432, 0.165926, 0.007813},{0.587203, 0.165527, 0.008605},{
      0.586580, 0.166749, 0.008605},{0.587625, 0.167508, 0.007813}}],
    Polygon[{{0.587203, 0.165527, 0.008605},{0.585871, 0.165094, 0.009185},{
      0.585447, 0.165926, 0.009185},{0.586580, 0.166749, 0.008605}}],
    Polygon[{{0.585871, 0.165094, 0.009185},{0.584470, 0.164639, 0.009538},{
      0.584255, 0.165060, 0.009538},{0.585447, 0.165926, 0.009185}}],
    Polygon[{{0.584255, 0.165060, -0.009538},{0.585447, 0.165926, -0.009185},{
      0.584787, 0.166586, -0.009185},{0.583921, 0.165394, -0.009538}}],
    Polygon[{{0.585447, 0.165926, -0.009185},{0.586580, 0.166749, -0.008605},{
      0.585610, 0.167719, -0.008605},{0.584787, 0.166586, -0.009185}}],
    Polygon[{{0.586580, 0.166749, -0.008605},{0.587625, 0.167508, -0.007813},{
      0.586370, 0.168764, -0.007813},{0.585610, 0.167719, -0.008605}}],
    Polygon[{{0.587625, 0.167508, -0.007813},{0.588558, 0.168186, -0.006829},{
      0.587047, 0.169696, -0.006829},{0.586370, 0.168764, -0.007813}}],
    Polygon[{{0.588558, 0.168186, -0.006829},{0.589354, 0.168764, -0.005676},{
      0.587625, 0.170493, -0.005676},{0.587047, 0.169696, -0.006829}}],
    Polygon[{{0.589354, 0.168764, -0.005676},{0.589994, 0.169230, -0.004384},{
      0.588091, 0.171133, -0.004384},{0.587625, 0.170493, -0.005676}}],
    Polygon[{{0.589994, 0.169230, -0.004384},{0.590464, 0.169570, -0.002984},{
      0.588432, 0.171602, -0.002984},{0.588091, 0.171133, -0.004384}}],
    Polygon[{{0.590464, 0.169570, -0.002984},{0.590750, 0.169778, -0.001511},{
      0.588640, 0.171889, -0.001511},{0.588432, 0.171602, -0.002984}}],
    Polygon[{{0.590750, 0.169778, -0.001511},{0.590846, 0.169848, 0.000000},{
      0.588709, 0.171985, 0.000000},{0.588640, 0.171889, -0.001511}}],
    Polygon[{{0.590846, 0.169848, 0.000000},{0.590750, 0.169778, 0.001511},{
      0.588640, 0.171889, 0.001511},{0.588709, 0.171985, 0.000000}}],
    Polygon[{{0.590750, 0.169778, 0.001511},{0.590464, 0.169570, 0.002984},{
      0.588432, 0.171602, 0.002984},{0.588640, 0.171889, 0.001511}}],
    Polygon[{{0.590464, 0.169570, 0.002984},{0.589994, 0.169230, 0.004384},{
      0.588091, 0.171133, 0.004384},{0.588432, 0.171602, 0.002984}}],
    Polygon[{{0.589994, 0.169230, 0.004384},{0.589354, 0.168764, 0.005676},{
      0.587625, 0.170493, 0.005676},{0.588091, 0.171133, 0.004384}}],
    Polygon[{{0.589354, 0.168764, 0.005676},{0.588558, 0.168186, 0.006829},{
      0.587047, 0.169696, 0.006829},{0.587625, 0.170493, 0.005676}}],
    Polygon[{{0.588558, 0.168186, 0.006829},{0.587625, 0.167508, 0.007813},{
      0.586370, 0.168764, 0.007813},{0.587047, 0.169696, 0.006829}}],
    Polygon[{{0.587625, 0.167508, 0.007813},{0.586580, 0.166749, 0.008605},{
      0.585610, 0.167719, 0.008605},{0.586370, 0.168764, 0.007813}}],
    Polygon[{{0.586580, 0.166749, 0.008605},{0.585447, 0.165926, 0.009185},{
      0.584787, 0.166586, 0.009185},{0.585610, 0.167719, 0.008605}}],
    Polygon[{{0.585447, 0.165926, 0.009185},{0.584255, 0.165060, 0.009538},{
      0.583921, 0.165394, 0.009538},{0.584787, 0.166586, 0.009185}}],
    Polygon[{{0.583921, 0.165394, -0.009538},{0.584787, 0.166586, -0.009185},{
      0.583955, 0.167010, -0.009185},{0.583500, 0.165609, -0.009538}}],
    Polygon[{{0.584787, 0.166586, -0.009185},{0.585610, 0.167719, -0.008605},{
      0.584388, 0.168342, -0.008605},{0.583955, 0.167010, -0.009185}}],
    Polygon[{{0.585610, 0.167719, -0.008605},{0.586370, 0.168764, -0.007813},{
      0.584787, 0.169570, -0.007813},{0.584388, 0.168342, -0.008605}}],
    Polygon[{{0.586370, 0.168764, -0.007813},{0.587047, 0.169696, -0.006829},{
      0.585143, 0.170666, -0.006829},{0.584787, 0.169570, -0.007813}}],
    Polygon[{{0.587047, 0.169696, -0.006829},{0.587625, 0.170493, -0.005676},{
      0.585447, 0.171602, -0.005676},{0.585143, 0.170666, -0.006829}}],
    Polygon[{{0.587625, 0.170493, -0.005676},{0.588091, 0.171133, -0.004384},{
      0.585692, 0.172355, -0.004384},{0.585447, 0.171602, -0.005676}}],
    Polygon[{{0.588091, 0.171133, -0.004384},{0.588432, 0.171602, -0.002984},{
      0.585871, 0.172907, -0.002984},{0.585692, 0.172355, -0.004384}}],
    Polygon[{{0.588432, 0.171602, -0.002984},{0.588640, 0.171889, -0.001511},{
      0.585981, 0.173243, -0.001511},{0.585871, 0.172907, -0.002984}}],
    Polygon[{{0.588640, 0.171889, -0.001511},{0.588709, 0.171985, 0.000000},{
      0.586017, 0.173356, 0.000000},{0.585981, 0.173243, -0.001511}}],
    Polygon[{{0.588709, 0.171985, 0.000000},{0.588640, 0.171889, 0.001511},{
      0.585981, 0.173243, 0.001511},{0.586017, 0.173356, 0.000000}}],
    Polygon[{{0.588640, 0.171889, 0.001511},{0.588432, 0.171602, 0.002984},{
      0.585871, 0.172907, 0.002984},{0.585981, 0.173243, 0.001511}}],
    Polygon[{{0.588432, 0.171602, 0.002984},{0.588091, 0.171133, 0.004384},{
      0.585692, 0.172355, 0.004384},{0.585871, 0.172907, 0.002984}}],
    Polygon[{{0.588091, 0.171133, 0.004384},{0.587625, 0.170493, 0.005676},{
      0.585447, 0.171602, 0.005676},{0.585692, 0.172355, 0.004384}}],
    Polygon[{{0.587625, 0.170493, 0.005676},{0.587047, 0.169696, 0.006829},{
      0.585143, 0.170666, 0.006829},{0.585447, 0.171602, 0.005676}}],
    Polygon[{{0.587047, 0.169696, 0.006829},{0.586370, 0.168764, 0.007813},{
      0.584787, 0.169570, 0.007813},{0.585143, 0.170666, 0.006829}}],
    Polygon[{{0.586370, 0.168764, 0.007813},{0.585610, 0.167719, 0.008605},{
      0.584388, 0.168342, 0.008605},{0.584787, 0.169570, 0.007813}}],
    Polygon[{{0.585610, 0.167719, 0.008605},{0.584787, 0.166586, 0.009185},{
      0.583955, 0.167010, 0.009185},{0.584388, 0.168342, 0.008605}}],
    Polygon[{{0.584787, 0.166586, 0.009185},{0.583921, 0.165394, 0.009538},{
      0.583500, 0.165609, 0.009538},{0.583955, 0.167010, 0.009185}}],
    Polygon[{{0.583500, 0.165609, -0.009538},{0.583955, 0.167010, -0.009185},{
      0.583033, 0.167156, -0.009185},{0.583033, 0.165683, -0.009538}}],
    Polygon[{{0.583955, 0.167010, -0.009185},{0.584388, 0.168342, -0.008605},{
      0.583033, 0.168556, -0.008605},{0.583033, 0.167156, -0.009185}}],
    Polygon[{{0.584388, 0.168342, -0.008605},{0.584787, 0.169570, -0.007813},{
      0.583033, 0.169848, -0.007813},{0.583033, 0.168556, -0.008605}}],
    Polygon[{{0.584787, 0.169570, -0.007813},{0.585143, 0.170666, -0.006829},{
      0.583033, 0.171001, -0.006829},{0.583033, 0.169848, -0.007813}}],
    Polygon[{{0.585143, 0.170666, -0.006829},{0.585447, 0.171602, -0.005676},{
      0.583033, 0.171985, -0.005676},{0.583033, 0.171001, -0.006829}}],
    Polygon[{{0.585447, 0.171602, -0.005676},{0.585692, 0.172355, -0.004384},{
      0.583033, 0.172777, -0.004384},{0.583033, 0.171985, -0.005676}}],
    Polygon[{{0.585692, 0.172355, -0.004384},{0.585871, 0.172907, -0.002984},{
      0.583033, 0.173356, -0.002984},{0.583033, 0.172777, -0.004384}}],
    Polygon[{{0.585871, 0.172907, -0.002984},{0.585981, 0.173243, -0.001511},{
      0.583033, 0.173710, -0.001511},{0.583033, 0.173356, -0.002984}}],
    Polygon[{{0.585981, 0.173243, -0.001511},{0.586017, 0.173356, 0.000000},{
      0.583033, 0.173829, 0.000000},{0.583033, 0.173710, -0.001511}}],
    Polygon[{{0.586017, 0.173356, 0.000000},{0.585981, 0.173243, 0.001511},{
      0.583033, 0.173710, 0.001511},{0.583033, 0.173829, 0.000000}}],
    Polygon[{{0.585981, 0.173243, 0.001511},{0.585871, 0.172907, 0.002984},{
      0.583033, 0.173356, 0.002984},{0.583033, 0.173710, 0.001511}}],
    Polygon[{{0.585871, 0.172907, 0.002984},{0.585692, 0.172355, 0.004384},{
      0.583033, 0.172777, 0.004384},{0.583033, 0.173356, 0.002984}}],
    Polygon[{{0.585692, 0.172355, 0.004384},{0.585447, 0.171602, 0.005676},{
      0.583033, 0.171985, 0.005676},{0.583033, 0.172777, 0.004384}}],
    Polygon[{{0.585447, 0.171602, 0.005676},{0.585143, 0.170666, 0.006829},{
      0.583033, 0.171001, 0.006829},{0.583033, 0.171985, 0.005676}}],
    Polygon[{{0.585143, 0.170666, 0.006829},{0.584787, 0.169570, 0.007813},{
      0.583033, 0.169848, 0.007813},{0.583033, 0.171001, 0.006829}}],
    Polygon[{{0.584787, 0.169570, 0.007813},{0.584388, 0.168342, 0.008605},{
      0.583033, 0.168556, 0.008605},{0.583033, 0.169848, 0.007813}}],
    Polygon[{{0.584388, 0.168342, 0.008605},{0.583955, 0.167010, 0.009185},{
      0.583033, 0.167156, 0.009185},{0.583033, 0.168556, 0.008605}}],
    Polygon[{{0.583955, 0.167010, 0.009185},{0.583500, 0.165609, 0.009538},{
      0.583033, 0.165683, 0.009538},{0.583033, 0.167156, 0.009185}}],
    Polygon[{{0.583033, 0.165683, -0.009538},{0.583033, 0.167156, -0.009185},{
      0.582111, 0.167010, -0.009185},{0.582566, 0.165609, -0.009538}}],
    Polygon[{{0.583033, 0.167156, -0.009185},{0.583033, 0.168556, -0.008605},{
      0.581678, 0.168342, -0.008605},{0.582111, 0.167010, -0.009185}}],
    Polygon[{{0.583033, 0.168556, -0.008605},{0.583033, 0.169848, -0.007813},{
      0.581279, 0.169570, -0.007813},{0.581678, 0.168342, -0.008605}}],
    Polygon[{{0.583033, 0.169848, -0.007813},{0.583033, 0.171001, -0.006829},{
      0.580923, 0.170666, -0.006829},{0.581279, 0.169570, -0.007813}}],
    Polygon[{{0.583033, 0.171001, -0.006829},{0.583033, 0.171985, -0.005676},{
      0.580619, 0.171602, -0.005676},{0.580923, 0.170666, -0.006829}}],
    Polygon[{{0.583033, 0.171985, -0.005676},{0.583033, 0.172777, -0.004384},{
      0.580374, 0.172355, -0.004384},{0.580619, 0.171602, -0.005676}}],
    Polygon[{{0.583033, 0.172777, -0.004384},{0.583033, 0.173356, -0.002984},{
      0.580195, 0.172907, -0.002984},{0.580374, 0.172355, -0.004384}}],
    Polygon[{{0.583033, 0.173356, -0.002984},{0.583033, 0.173710, -0.001511},{
      0.580086, 0.173243, -0.001511},{0.580195, 0.172907, -0.002984}}],
    Polygon[{{0.583033, 0.173710, -0.001511},{0.583033, 0.173829, 0.000000},{
      0.580049, 0.173356, 0.000000},{0.580086, 0.173243, -0.001511}}],
    Polygon[{{0.583033, 0.173829, 0.000000},{0.583033, 0.173710, 0.001511},{
      0.580086, 0.173243, 0.001511},{0.580049, 0.173356, 0.000000}}],
    Polygon[{{0.583033, 0.173710, 0.001511},{0.583033, 0.173356, 0.002984},{
      0.580195, 0.172907, 0.002984},{0.580086, 0.173243, 0.001511}}],
    Polygon[{{0.583033, 0.173356, 0.002984},{0.583033, 0.172777, 0.004384},{
      0.580374, 0.172355, 0.004384},{0.580195, 0.172907, 0.002984}}],
    Polygon[{{0.583033, 0.172777, 0.004384},{0.583033, 0.171985, 0.005676},{
      0.580619, 0.171602, 0.005676},{0.580374, 0.172355, 0.004384}}],
    Polygon[{{0.583033, 0.171985, 0.005676},{0.583033, 0.171001, 0.006829},{
      0.580923, 0.170666, 0.006829},{0.580619, 0.171602, 0.005676}}],
    Polygon[{{0.583033, 0.171001, 0.006829},{0.583033, 0.169848, 0.007813},{
      0.581279, 0.169570, 0.007813},{0.580923, 0.170666, 0.006829}}],
    Polygon[{{0.583033, 0.169848, 0.007813},{0.583033, 0.168556, 0.008605},{
      0.581678, 0.168342, 0.008605},{0.581279, 0.169570, 0.007813}}],
    Polygon[{{0.583033, 0.168556, 0.008605},{0.583033, 0.167156, 0.009185},{
      0.582111, 0.167010, 0.009185},{0.581678, 0.168342, 0.008605}}],
    Polygon[{{0.583033, 0.167156, 0.009185},{0.583033, 0.165683, 0.009538},{
      0.582566, 0.165609, 0.009538},{0.582111, 0.167010, 0.009185}}],
    Polygon[{{0.582566, 0.165609, -0.009538},{0.582111, 0.167010, -0.009185},{
      0.581279, 0.166586, -0.009185},{0.582145, 0.165394, -0.009538}}],
    Polygon[{{0.582111, 0.167010, -0.009185},{0.581678, 0.168342, -0.008605},{
      0.580456, 0.167719, -0.008605},{0.581279, 0.166586, -0.009185}}],
    Polygon[{{0.581678, 0.168342, -0.008605},{0.581279, 0.169570, -0.007813},{
      0.579697, 0.168764, -0.007813},{0.580456, 0.167719, -0.008605}}],
    Polygon[{{0.581279, 0.169570, -0.007813},{0.580923, 0.170666, -0.006829},{
      0.579019, 0.169696, -0.006829},{0.579697, 0.168764, -0.007813}}],
    Polygon[{{0.580923, 0.170666, -0.006829},{0.580619, 0.171602, -0.005676},{
      0.578441, 0.170493, -0.005676},{0.579019, 0.169696, -0.006829}}],
    Polygon[{{0.580619, 0.171602, -0.005676},{0.580374, 0.172355, -0.004384},{
      0.577975, 0.171133, -0.004384},{0.578441, 0.170493, -0.005676}}],
    Polygon[{{0.580374, 0.172355, -0.004384},{0.580195, 0.172907, -0.002984},{
      0.577635, 0.171602, -0.002984},{0.577975, 0.171133, -0.004384}}],
    Polygon[{{0.580195, 0.172907, -0.002984},{0.580086, 0.173243, -0.001511},{
      0.577427, 0.171889, -0.001511},{0.577635, 0.171602, -0.002984}}],
    Polygon[{{0.580086, 0.173243, -0.001511},{0.580049, 0.173356, 0.000000},{
      0.577357, 0.171985, 0.000000},{0.577427, 0.171889, -0.001511}}],
    Polygon[{{0.580049, 0.173356, 0.000000},{0.580086, 0.173243, 0.001511},{
      0.577427, 0.171889, 0.001511},{0.577357, 0.171985, 0.000000}}],
    Polygon[{{0.580086, 0.173243, 0.001511},{0.580195, 0.172907, 0.002984},{
      0.577635, 0.171602, 0.002984},{0.577427, 0.171889, 0.001511}}],
    Polygon[{{0.580195, 0.172907, 0.002984},{0.580374, 0.172355, 0.004384},{
      0.577975, 0.171133, 0.004384},{0.577635, 0.171602, 0.002984}}],
    Polygon[{{0.580374, 0.172355, 0.004384},{0.580619, 0.171602, 0.005676},{
      0.578441, 0.170493, 0.005676},{0.577975, 0.171133, 0.004384}}],
    Polygon[{{0.580619, 0.171602, 0.005676},{0.580923, 0.170666, 0.006829},{
      0.579019, 0.169696, 0.006829},{0.578441, 0.170493, 0.005676}}],
    Polygon[{{0.580923, 0.170666, 0.006829},{0.581279, 0.169570, 0.007813},{
      0.579697, 0.168764, 0.007813},{0.579019, 0.169696, 0.006829}}],
    Polygon[{{0.581279, 0.169570, 0.007813},{0.581678, 0.168342, 0.008605},{
      0.580456, 0.167719, 0.008605},{0.579697, 0.168764, 0.007813}}],
    Polygon[{{0.581678, 0.168342, 0.008605},{0.582111, 0.167010, 0.009185},{
      0.581279, 0.166586, 0.009185},{0.580456, 0.167719, 0.008605}}],
    Polygon[{{0.582111, 0.167010, 0.009185},{0.582566, 0.165609, 0.009538},{
      0.582145, 0.165394, 0.009538},{0.581279, 0.166586, 0.009185}}],
    Polygon[{{0.582145, 0.165394, -0.009538},{0.581279, 0.166586, -0.009185},{
      0.580619, 0.165926, -0.009185},{0.581811, 0.165060, -0.009538}}],
    Polygon[{{0.581279, 0.166586, -0.009185},{0.580456, 0.167719, -0.008605},{
      0.579486, 0.166749, -0.008605},{0.580619, 0.165926, -0.009185}}],
    Polygon[{{0.580456, 0.167719, -0.008605},{0.579697, 0.168764, -0.007813},{
      0.578441, 0.167508, -0.007813},{0.579486, 0.166749, -0.008605}}],
    Polygon[{{0.579697, 0.168764, -0.007813},{0.579019, 0.169696, -0.006829},{
      0.577509, 0.168186, -0.006829},{0.578441, 0.167508, -0.007813}}],
    Polygon[{{0.579019, 0.169696, -0.006829},{0.578441, 0.170493, -0.005676},{
      0.576712, 0.168764, -0.005676},{0.577509, 0.168186, -0.006829}}],
    Polygon[{{0.578441, 0.170493, -0.005676},{0.577975, 0.171133, -0.004384},{
      0.576072, 0.169230, -0.004384},{0.576712, 0.168764, -0.005676}}],
    Polygon[{{0.577975, 0.171133, -0.004384},{0.577635, 0.171602, -0.002984},{
      0.575603, 0.169570, -0.002984},{0.576072, 0.169230, -0.004384}}],
    Polygon[{{0.577635, 0.171602, -0.002984},{0.577427, 0.171889, -0.001511},{
      0.575316, 0.169778, -0.001511},{0.575603, 0.169570, -0.002984}}],
    Polygon[{{0.577427, 0.171889, -0.001511},{0.577357, 0.171985, 0.000000},{
      0.575220, 0.169848, 0.000000},{0.575316, 0.169778, -0.001511}}],
    Polygon[{{0.577357, 0.171985, 0.000000},{0.577427, 0.171889, 0.001511},{
      0.575316, 0.169778, 0.001511},{0.575220, 0.169848, 0.000000}}],
    Polygon[{{0.577427, 0.171889, 0.001511},{0.577635, 0.171602, 0.002984},{
      0.575603, 0.169570, 0.002984},{0.575316, 0.169778, 0.001511}}],
    Polygon[{{0.577635, 0.171602, 0.002984},{0.577975, 0.171133, 0.004384},{
      0.576072, 0.169230, 0.004384},{0.575603, 0.169570, 0.002984}}],
    Polygon[{{0.577975, 0.171133, 0.004384},{0.578441, 0.170493, 0.005676},{
      0.576712, 0.168764, 0.005676},{0.576072, 0.169230, 0.004384}}],
    Polygon[{{0.578441, 0.170493, 0.005676},{0.579019, 0.169696, 0.006829},{
      0.577509, 0.168186, 0.006829},{0.576712, 0.168764, 0.005676}}],
    Polygon[{{0.579019, 0.169696, 0.006829},{0.579697, 0.168764, 0.007813},{
      0.578441, 0.167508, 0.007813},{0.577509, 0.168186, 0.006829}}],
    Polygon[{{0.579697, 0.168764, 0.007813},{0.580456, 0.167719, 0.008605},{
      0.579486, 0.166749, 0.008605},{0.578441, 0.167508, 0.007813}}],
    Polygon[{{0.580456, 0.167719, 0.008605},{0.581279, 0.166586, 0.009185},{
      0.580619, 0.165926, 0.009185},{0.579486, 0.166749, 0.008605}}],
    Polygon[{{0.581279, 0.166586, 0.009185},{0.582145, 0.165394, 0.009538},{
      0.581811, 0.165060, 0.009538},{0.580619, 0.165926, 0.009185}}],
    Polygon[{{0.581811, 0.165060, -0.009538},{0.580619, 0.165926, -0.009185},{
      0.580195, 0.165094, -0.009185},{0.581596, 0.164639, -0.009538}}],
    Polygon[{{0.580619, 0.165926, -0.009185},{0.579486, 0.166749, -0.008605},{
      0.578863, 0.165527, -0.008605},{0.580195, 0.165094, -0.009185}}],
    Polygon[{{0.579486, 0.166749, -0.008605},{0.578441, 0.167508, -0.007813},{
      0.577635, 0.165926, -0.007813},{0.578863, 0.165527, -0.008605}}],
    Polygon[{{0.578441, 0.167508, -0.007813},{0.577509, 0.168186, -0.006829},{
      0.576539, 0.166282, -0.006829},{0.577635, 0.165926, -0.007813}}],
    Polygon[{{0.577509, 0.168186, -0.006829},{0.576712, 0.168764, -0.005676},{
      0.575603, 0.166586, -0.005676},{0.576539, 0.166282, -0.006829}}],
    Polygon[{{0.576712, 0.168764, -0.005676},{0.576072, 0.169230, -0.004384},{
      0.574850, 0.166831, -0.004384},{0.575603, 0.166586, -0.005676}}],
    Polygon[{{0.576072, 0.169230, -0.004384},{0.575603, 0.169570, -0.002984},{
      0.574298, 0.167010, -0.002984},{0.574850, 0.166831, -0.004384}}],
    Polygon[{{0.575603, 0.169570, -0.002984},{0.575316, 0.169778, -0.001511},{
      0.573962, 0.167119, -0.001511},{0.574298, 0.167010, -0.002984}}],
    Polygon[{{0.575316, 0.169778, -0.001511},{0.575220, 0.169848, 0.000000},{
      0.573849, 0.167156, 0.000000},{0.573962, 0.167119, -0.001511}}],
    Polygon[{{0.575220, 0.169848, 0.000000},{0.575316, 0.169778, 0.001511},{
      0.573962, 0.167119, 0.001511},{0.573849, 0.167156, 0.000000}}],
    Polygon[{{0.575316, 0.169778, 0.001511},{0.575603, 0.169570, 0.002984},{
      0.574298, 0.167010, 0.002984},{0.573962, 0.167119, 0.001511}}],
    Polygon[{{0.575603, 0.169570, 0.002984},{0.576072, 0.169230, 0.004384},{
      0.574850, 0.166831, 0.004384},{0.574298, 0.167010, 0.002984}}],
    Polygon[{{0.576072, 0.169230, 0.004384},{0.576712, 0.168764, 0.005676},{
      0.575603, 0.166586, 0.005676},{0.574850, 0.166831, 0.004384}}],
    Polygon[{{0.576712, 0.168764, 0.005676},{0.577509, 0.168186, 0.006829},{
      0.576539, 0.166282, 0.006829},{0.575603, 0.166586, 0.005676}}],
    Polygon[{{0.577509, 0.168186, 0.006829},{0.578441, 0.167508, 0.007813},{
      0.577635, 0.165926, 0.007813},{0.576539, 0.166282, 0.006829}}],
    Polygon[{{0.578441, 0.167508, 0.007813},{0.579486, 0.166749, 0.008605},{
      0.578863, 0.165527, 0.008605},{0.577635, 0.165926, 0.007813}}],
    Polygon[{{0.579486, 0.166749, 0.008605},{0.580619, 0.165926, 0.009185},{
      0.580195, 0.165094, 0.009185},{0.578863, 0.165527, 0.008605}}],
    Polygon[{{0.580619, 0.165926, 0.009185},{0.581811, 0.165060, 0.009538},{
      0.581596, 0.164639, 0.009538},{0.580195, 0.165094, 0.009185}}],
    Polygon[{{0.581596, 0.164639, -0.009538},{0.580195, 0.165094, -0.009185},{
      0.580049, 0.164172, -0.009185},{0.581522, 0.164172, -0.009538}}],
    Polygon[{{0.580195, 0.165094, -0.009185},{0.578863, 0.165527, -0.008605},{
      0.578649, 0.164172, -0.008605},{0.580049, 0.164172, -0.009185}}],
    Polygon[{{0.578863, 0.165527, -0.008605},{0.577635, 0.165926, -0.007813},{
      0.577357, 0.164172, -0.007813},{0.578649, 0.164172, -0.008605}}],
    Polygon[{{0.577635, 0.165926, -0.007813},{0.576539, 0.166282, -0.006829},{
      0.576204, 0.164172, -0.006829},{0.577357, 0.164172, -0.007813}}],
    Polygon[{{0.576539, 0.166282, -0.006829},{0.575603, 0.166586, -0.005676},{
      0.575220, 0.164172, -0.005676},{0.576204, 0.164172, -0.006829}}],
    Polygon[{{0.575603, 0.166586, -0.005676},{0.574850, 0.166831, -0.004384},{
      0.574428, 0.164172, -0.004384},{0.575220, 0.164172, -0.005676}}],
    Polygon[{{0.574850, 0.166831, -0.004384},{0.574298, 0.167010, -0.002984},{
      0.573849, 0.164172, -0.002984},{0.574428, 0.164172, -0.004384}}],
    Polygon[{{0.574298, 0.167010, -0.002984},{0.573962, 0.167119, -0.001511},{
      0.573495, 0.164172, -0.001511},{0.573849, 0.164172, -0.002984}}],
    Polygon[{{0.573962, 0.167119, -0.001511},{0.573849, 0.167156, 0.000000},{
      0.573376, 0.164172, 0.000000},{0.573495, 0.164172, -0.001511}}],
    Polygon[{{0.573849, 0.167156, 0.000000},{0.573962, 0.167119, 0.001511},{
      0.573495, 0.164172, 0.001511},{0.573376, 0.164172, 0.000000}}],
    Polygon[{{0.573962, 0.167119, 0.001511},{0.574298, 0.167010, 0.002984},{
      0.573849, 0.164172, 0.002984},{0.573495, 0.164172, 0.001511}}],
    Polygon[{{0.574298, 0.167010, 0.002984},{0.574850, 0.166831, 0.004384},{
      0.574428, 0.164172, 0.004384},{0.573849, 0.164172, 0.002984}}],
    Polygon[{{0.574850, 0.166831, 0.004384},{0.575603, 0.166586, 0.005676},{
      0.575220, 0.164172, 0.005676},{0.574428, 0.164172, 0.004384}}],
    Polygon[{{0.575603, 0.166586, 0.005676},{0.576539, 0.166282, 0.006829},{
      0.576204, 0.164172, 0.006829},{0.575220, 0.164172, 0.005676}}],
    Polygon[{{0.576539, 0.166282, 0.006829},{0.577635, 0.165926, 0.007813},{
      0.577357, 0.164172, 0.007813},{0.576204, 0.164172, 0.006829}}],
    Polygon[{{0.577635, 0.165926, 0.007813},{0.578863, 0.165527, 0.008605},{
      0.578649, 0.164172, 0.008605},{0.577357, 0.164172, 0.007813}}],
    Polygon[{{0.578863, 0.165527, 0.008605},{0.580195, 0.165094, 0.009185},{
      0.580049, 0.164172, 0.009185},{0.578649, 0.164172, 0.008605}}],
    Polygon[{{0.580195, 0.165094, 0.009185},{0.581596, 0.164639, 0.009538},{
      0.581522, 0.164172, 0.009538},{0.580049, 0.164172, 0.009185}}],
    Polygon[{{0.581522, 0.164172, -0.009538},{0.580049, 0.164172, -0.009185},{
      0.580195, 0.163250, -0.009185},{0.581596, 0.163705, -0.009538}}],
    Polygon[{{0.580049, 0.164172, -0.009185},{0.578649, 0.164172, -0.008605},{
      0.578863, 0.162817, -0.008605},{0.580195, 0.163250, -0.009185}}],
    Polygon[{{0.578649, 0.164172, -0.008605},{0.577357, 0.164172, -0.007813},{
      0.577635, 0.162418, -0.007813},{0.578863, 0.162817, -0.008605}}],
    Polygon[{{0.577357, 0.164172, -0.007813},{0.576204, 0.164172, -0.006829},{
      0.576539, 0.162062, -0.006829},{0.577635, 0.162418, -0.007813}}],
    Polygon[{{0.576204, 0.164172, -0.006829},{0.575220, 0.164172, -0.005676},{
      0.575603, 0.161758, -0.005676},{0.576539, 0.162062, -0.006829}}],
    Polygon[{{0.575220, 0.164172, -0.005676},{0.574428, 0.164172, -0.004384},{
      0.574850, 0.161513, -0.004384},{0.575603, 0.161758, -0.005676}}],
    Polygon[{{0.574428, 0.164172, -0.004384},{0.573849, 0.164172, -0.002984},{
      0.574298, 0.161334, -0.002984},{0.574850, 0.161513, -0.004384}}],
    Polygon[{{0.573849, 0.164172, -0.002984},{0.573495, 0.164172, -0.001511},{
      0.573962, 0.161224, -0.001511},{0.574298, 0.161334, -0.002984}}],
    Polygon[{{0.573495, 0.164172, -0.001511},{0.573376, 0.164172, 0.000000},{
      0.573849, 0.161188, 0.000000},{0.573962, 0.161224, -0.001511}}],
    Polygon[{{0.573376, 0.164172, 0.000000},{0.573495, 0.164172, 0.001511},{
      0.573962, 0.161224, 0.001511},{0.573849, 0.161188, 0.000000}}],
    Polygon[{{0.573495, 0.164172, 0.001511},{0.573849, 0.164172, 0.002984},{
      0.574298, 0.161334, 0.002984},{0.573962, 0.161224, 0.001511}}],
    Polygon[{{0.573849, 0.164172, 0.002984},{0.574428, 0.164172, 0.004384},{
      0.574850, 0.161513, 0.004384},{0.574298, 0.161334, 0.002984}}],
    Polygon[{{0.574428, 0.164172, 0.004384},{0.575220, 0.164172, 0.005676},{
      0.575603, 0.161758, 0.005676},{0.574850, 0.161513, 0.004384}}],
    Polygon[{{0.575220, 0.164172, 0.005676},{0.576204, 0.164172, 0.006829},{
      0.576539, 0.162062, 0.006829},{0.575603, 0.161758, 0.005676}}],
    Polygon[{{0.576204, 0.164172, 0.006829},{0.577357, 0.164172, 0.007813},{
      0.577635, 0.162418, 0.007813},{0.576539, 0.162062, 0.006829}}],
    Polygon[{{0.577357, 0.164172, 0.007813},{0.578649, 0.164172, 0.008605},{
      0.578863, 0.162817, 0.008605},{0.577635, 0.162418, 0.007813}}],
    Polygon[{{0.578649, 0.164172, 0.008605},{0.580049, 0.164172, 0.009185},{
      0.580195, 0.163250, 0.009185},{0.578863, 0.162817, 0.008605}}],
    Polygon[{{0.580049, 0.164172, 0.009185},{0.581522, 0.164172, 0.009538},{
      0.581596, 0.163705, 0.009538},{0.580195, 0.163250, 0.009185}}],
    Polygon[{{0.581596, 0.163705, -0.009538},{0.580195, 0.163250, -0.009185},{
      0.580619, 0.162418, -0.009185},{0.581811, 0.163284, -0.009538}}],
    Polygon[{{0.580195, 0.163250, -0.009185},{0.578863, 0.162817, -0.008605},{
      0.579486, 0.161595, -0.008605},{0.580619, 0.162418, -0.009185}}],
    Polygon[{{0.578863, 0.162817, -0.008605},{0.577635, 0.162418, -0.007813},{
      0.578441, 0.160835, -0.007813},{0.579486, 0.161595, -0.008605}}],
    Polygon[{{0.577635, 0.162418, -0.007813},{0.576539, 0.162062, -0.006829},{
      0.577509, 0.160158, -0.006829},{0.578441, 0.160835, -0.007813}}],
    Polygon[{{0.576539, 0.162062, -0.006829},{0.575603, 0.161758, -0.005676},{
      0.576712, 0.159580, -0.005676},{0.577509, 0.160158, -0.006829}}],
    Polygon[{{0.575603, 0.161758, -0.005676},{0.574850, 0.161513, -0.004384},{
      0.576072, 0.159114, -0.004384},{0.576712, 0.159580, -0.005676}}],
    Polygon[{{0.574850, 0.161513, -0.004384},{0.574298, 0.161334, -0.002984},{
      0.575603, 0.158773, -0.002984},{0.576072, 0.159114, -0.004384}}],
    Polygon[{{0.574298, 0.161334, -0.002984},{0.573962, 0.161224, -0.001511},{
      0.575316, 0.158565, -0.001511},{0.575603, 0.158773, -0.002984}}],
    Polygon[{{0.573962, 0.161224, -0.001511},{0.573849, 0.161188, 0.000000},{
      0.575220, 0.158496, 0.000000},{0.575316, 0.158565, -0.001511}}],
    Polygon[{{0.573849, 0.161188, 0.000000},{0.573962, 0.161224, 0.001511},{
      0.575316, 0.158565, 0.001511},{0.575220, 0.158496, 0.000000}}],
    Polygon[{{0.573962, 0.161224, 0.001511},{0.574298, 0.161334, 0.002984},{
      0.575603, 0.158773, 0.002984},{0.575316, 0.158565, 0.001511}}],
    Polygon[{{0.574298, 0.161334, 0.002984},{0.574850, 0.161513, 0.004384},{
      0.576072, 0.159114, 0.004384},{0.575603, 0.158773, 0.002984}}],
    Polygon[{{0.574850, 0.161513, 0.004384},{0.575603, 0.161758, 0.005676},{
      0.576712, 0.159580, 0.005676},{0.576072, 0.159114, 0.004384}}],
    Polygon[{{0.575603, 0.161758, 0.005676},{0.576539, 0.162062, 0.006829},{
      0.577509, 0.160158, 0.006829},{0.576712, 0.159580, 0.005676}}],
    Polygon[{{0.576539, 0.162062, 0.006829},{0.577635, 0.162418, 0.007813},{
      0.578441, 0.160835, 0.007813},{0.577509, 0.160158, 0.006829}}],
    Polygon[{{0.577635, 0.162418, 0.007813},{0.578863, 0.162817, 0.008605},{
      0.579486, 0.161595, 0.008605},{0.578441, 0.160835, 0.007813}}],
    Polygon[{{0.578863, 0.162817, 0.008605},{0.580195, 0.163250, 0.009185},{
      0.580619, 0.162418, 0.009185},{0.579486, 0.161595, 0.008605}}],
    Polygon[{{0.580195, 0.163250, 0.009185},{0.581596, 0.163705, 0.009538},{
      0.581811, 0.163284, 0.009538},{0.580619, 0.162418, 0.009185}}],
    Polygon[{{0.581811, 0.163284, -0.009538},{0.580619, 0.162418, -0.009185},{
      0.581279, 0.161758, -0.009185},{0.582145, 0.162950, -0.009538}}],
    Polygon[{{0.580619, 0.162418, -0.009185},{0.579486, 0.161595, -0.008605},{
      0.580456, 0.160625, -0.008605},{0.581279, 0.161758, -0.009185}}],
    Polygon[{{0.579486, 0.161595, -0.008605},{0.578441, 0.160835, -0.007813},{
      0.579697, 0.159580, -0.007813},{0.580456, 0.160625, -0.008605}}],
    Polygon[{{0.578441, 0.160835, -0.007813},{0.577509, 0.160158, -0.006829},{
      0.579019, 0.158647, -0.006829},{0.579697, 0.159580, -0.007813}}],
    Polygon[{{0.577509, 0.160158, -0.006829},{0.576712, 0.159580, -0.005676},{
      0.578441, 0.157851, -0.005676},{0.579019, 0.158647, -0.006829}}],
    Polygon[{{0.576712, 0.159580, -0.005676},{0.576072, 0.159114, -0.004384},{
      0.577975, 0.157211, -0.004384},{0.578441, 0.157851, -0.005676}}],
    Polygon[{{0.576072, 0.159114, -0.004384},{0.575603, 0.158773, -0.002984},{
      0.577635, 0.156741, -0.002984},{0.577975, 0.157211, -0.004384}}],
    Polygon[{{0.575603, 0.158773, -0.002984},{0.575316, 0.158565, -0.001511},{
      0.577427, 0.156455, -0.001511},{0.577635, 0.156741, -0.002984}}],
    Polygon[{{0.575316, 0.158565, -0.001511},{0.575220, 0.158496, 0.000000},{
      0.577357, 0.156359, 0.000000},{0.577427, 0.156455, -0.001511}}],
    Polygon[{{0.575220, 0.158496, 0.000000},{0.575316, 0.158565, 0.001511},{
      0.577427, 0.156455, 0.001511},{0.577357, 0.156359, 0.000000}}],
    Polygon[{{0.575316, 0.158565, 0.001511},{0.575603, 0.158773, 0.002984},{
      0.577635, 0.156741, 0.002984},{0.577427, 0.156455, 0.001511}}],
    Polygon[{{0.575603, 0.158773, 0.002984},{0.576072, 0.159114, 0.004384},{
      0.577975, 0.157211, 0.004384},{0.577635, 0.156741, 0.002984}}],
    Polygon[{{0.576072, 0.159114, 0.004384},{0.576712, 0.159580, 0.005676},{
      0.578441, 0.157851, 0.005676},{0.577975, 0.157211, 0.004384}}],
    Polygon[{{0.576712, 0.159580, 0.005676},{0.577509, 0.160158, 0.006829},{
      0.579019, 0.158647, 0.006829},{0.578441, 0.157851, 0.005676}}],
    Polygon[{{0.577509, 0.160158, 0.006829},{0.578441, 0.160835, 0.007813},{
      0.579697, 0.159580, 0.007813},{0.579019, 0.158647, 0.006829}}],
    Polygon[{{0.578441, 0.160835, 0.007813},{0.579486, 0.161595, 0.008605},{
      0.580456, 0.160625, 0.008605},{0.579697, 0.159580, 0.007813}}],
    Polygon[{{0.579486, 0.161595, 0.008605},{0.580619, 0.162418, 0.009185},{
      0.581279, 0.161758, 0.009185},{0.580456, 0.160625, 0.008605}}],
    Polygon[{{0.580619, 0.162418, 0.009185},{0.581811, 0.163284, 0.009538},{
      0.582145, 0.162950, 0.009538},{0.581279, 0.161758, 0.009185}}],
    Polygon[{{0.582145, 0.162950, -0.009538},{0.581279, 0.161758, -0.009185},{
      0.582111, 0.161334, -0.009185},{0.582566, 0.162735, -0.009538}}],
    Polygon[{{0.581279, 0.161758, -0.009185},{0.580456, 0.160625, -0.008605},{
      0.581678, 0.160002, -0.008605},{0.582111, 0.161334, -0.009185}}],
    Polygon[{{0.580456, 0.160625, -0.008605},{0.579697, 0.159580, -0.007813},{
      0.581279, 0.158773, -0.007813},{0.581678, 0.160002, -0.008605}}],
    Polygon[{{0.579697, 0.159580, -0.007813},{0.579019, 0.158647, -0.006829},{
      0.580923, 0.157677, -0.006829},{0.581279, 0.158773, -0.007813}}],
    Polygon[{{0.579019, 0.158647, -0.006829},{0.578441, 0.157851, -0.005676},{
      0.580619, 0.156741, -0.005676},{0.580923, 0.157677, -0.006829}}],
    Polygon[{{0.578441, 0.157851, -0.005676},{0.577975, 0.157211, -0.004384},{
      0.580374, 0.155988, -0.004384},{0.580619, 0.156741, -0.005676}}],
    Polygon[{{0.577975, 0.157211, -0.004384},{0.577635, 0.156741, -0.002984},{
      0.580195, 0.155437, -0.002984},{0.580374, 0.155988, -0.004384}}],
    Polygon[{{0.577635, 0.156741, -0.002984},{0.577427, 0.156455, -0.001511},{
      0.580086, 0.155100, -0.001511},{0.580195, 0.155437, -0.002984}}],
    Polygon[{{0.577427, 0.156455, -0.001511},{0.577357, 0.156359, 0.000000},{
      0.580049, 0.154987, 0.000000},{0.580086, 0.155100, -0.001511}}],
    Polygon[{{0.577357, 0.156359, 0.000000},{0.577427, 0.156455, 0.001511},{
      0.580086, 0.155100, 0.001511},{0.580049, 0.154987, 0.000000}}],
    Polygon[{{0.577427, 0.156455, 0.001511},{0.577635, 0.156741, 0.002984},{
      0.580195, 0.155437, 0.002984},{0.580086, 0.155100, 0.001511}}],
    Polygon[{{0.577635, 0.156741, 0.002984},{0.577975, 0.157211, 0.004384},{
      0.580374, 0.155988, 0.004384},{0.580195, 0.155437, 0.002984}}],
    Polygon[{{0.577975, 0.157211, 0.004384},{0.578441, 0.157851, 0.005676},{
      0.580619, 0.156741, 0.005676},{0.580374, 0.155988, 0.004384}}],
    Polygon[{{0.578441, 0.157851, 0.005676},{0.579019, 0.158647, 0.006829},{
      0.580923, 0.157677, 0.006829},{0.580619, 0.156741, 0.005676}}],
    Polygon[{{0.579019, 0.158647, 0.006829},{0.579697, 0.159580, 0.007813},{
      0.581279, 0.158773, 0.007813},{0.580923, 0.157677, 0.006829}}],
    Polygon[{{0.579697, 0.159580, 0.007813},{0.580456, 0.160625, 0.008605},{
      0.581678, 0.160002, 0.008605},{0.581279, 0.158773, 0.007813}}],
    Polygon[{{0.580456, 0.160625, 0.008605},{0.581279, 0.161758, 0.009185},{
      0.582111, 0.161334, 0.009185},{0.581678, 0.160002, 0.008605}}],
    Polygon[{{0.581279, 0.161758, 0.009185},{0.582145, 0.162950, 0.009538},{
      0.582566, 0.162735, 0.009538},{0.582111, 0.161334, 0.009185}}],
    Polygon[{{0.582566, 0.162735, -0.009538},{0.582111, 0.161334, -0.009185},{
      0.583033, 0.161188, -0.009185},{0.583033, 0.162661, -0.009538}}],
    Polygon[{{0.582111, 0.161334, -0.009185},{0.581678, 0.160002, -0.008605},{
      0.583033, 0.159788, -0.008605},{0.583033, 0.161188, -0.009185}}],
    Polygon[{{0.581678, 0.160002, -0.008605},{0.581279, 0.158773, -0.007813},{
      0.583033, 0.158496, -0.007813},{0.583033, 0.159788, -0.008605}}],
    Polygon[{{0.581279, 0.158773, -0.007813},{0.580923, 0.157677, -0.006829},{
      0.583033, 0.157343, -0.006829},{0.583033, 0.158496, -0.007813}}],
    Polygon[{{0.580923, 0.157677, -0.006829},{0.580619, 0.156741, -0.005676},{
      0.583033, 0.156359, -0.005676},{0.583033, 0.157343, -0.006829}}],
    Polygon[{{0.580619, 0.156741, -0.005676},{0.580374, 0.155988, -0.004384},{
      0.583033, 0.155567, -0.004384},{0.583033, 0.156359, -0.005676}}],
    Polygon[{{0.580374, 0.155988, -0.004384},{0.580195, 0.155437, -0.002984},{
      0.583033, 0.154987, -0.002984},{0.583033, 0.155567, -0.004384}}],
    Polygon[{{0.580195, 0.155437, -0.002984},{0.580086, 0.155100, -0.001511},{
      0.583033, 0.154634, -0.001511},{0.583033, 0.154987, -0.002984}}],
    Polygon[{{0.580086, 0.155100, -0.001511},{0.580049, 0.154987, 0.000000},{
      0.583033, 0.154515, 0.000000},{0.583033, 0.154634, -0.001511}}],
    Polygon[{{0.580049, 0.154987, 0.000000},{0.580086, 0.155100, 0.001511},{
      0.583033, 0.154634, 0.001511},{0.583033, 0.154515, 0.000000}}],
    Polygon[{{0.580086, 0.155100, 0.001511},{0.580195, 0.155437, 0.002984},{
      0.583033, 0.154987, 0.002984},{0.583033, 0.154634, 0.001511}}],
    Polygon[{{0.580195, 0.155437, 0.002984},{0.580374, 0.155988, 0.004384},{
      0.583033, 0.155567, 0.004384},{0.583033, 0.154987, 0.002984}}],
    Polygon[{{0.580374, 0.155988, 0.004384},{0.580619, 0.156741, 0.005676},{
      0.583033, 0.156359, 0.005676},{0.583033, 0.155567, 0.004384}}],
    Polygon[{{0.580619, 0.156741, 0.005676},{0.580923, 0.157677, 0.006829},{
      0.583033, 0.157343, 0.006829},{0.583033, 0.156359, 0.005676}}],
    Polygon[{{0.580923, 0.157677, 0.006829},{0.581279, 0.158773, 0.007813},{
      0.583033, 0.158496, 0.007813},{0.583033, 0.157343, 0.006829}}],
    Polygon[{{0.581279, 0.158773, 0.007813},{0.581678, 0.160002, 0.008605},{
      0.583033, 0.159788, 0.008605},{0.583033, 0.158496, 0.007813}}],
    Polygon[{{0.581678, 0.160002, 0.008605},{0.582111, 0.161334, 0.009185},{
      0.583033, 0.161188, 0.009185},{0.583033, 0.159788, 0.008605}}],
    Polygon[{{0.582111, 0.161334, 0.009185},{0.582566, 0.162735, 0.009538},{
      0.583033, 0.162661, 0.009538},{0.583033, 0.161188, 0.009185}}],
    Polygon[{{0.583033, 0.162661, -0.009538},{0.583033, 0.161188, -0.009185},{
      0.583955, 0.161334, -0.009185},{0.583500, 0.162735, -0.009538}}],
    Polygon[{{0.583033, 0.161188, -0.009185},{0.583033, 0.159788, -0.008605},{
      0.584388, 0.160002, -0.008605},{0.583955, 0.161334, -0.009185}}],
    Polygon[{{0.583033, 0.159788, -0.008605},{0.583033, 0.158496, -0.007813},{
      0.584787, 0.158773, -0.007813},{0.584388, 0.160002, -0.008605}}],
    Polygon[{{0.583033, 0.158496, -0.007813},{0.583033, 0.157343, -0.006829},{
      0.585143, 0.157677, -0.006829},{0.584787, 0.158773, -0.007813}}],
    Polygon[{{0.583033, 0.157343, -0.006829},{0.583033, 0.156359, -0.005676},{
      0.585447, 0.156741, -0.005676},{0.585143, 0.157677, -0.006829}}],
    Polygon[{{0.583033, 0.156359, -0.005676},{0.583033, 0.155567, -0.004384},{
      0.585692, 0.155988, -0.004384},{0.585447, 0.156741, -0.005676}}],
    Polygon[{{0.583033, 0.155567, -0.004384},{0.583033, 0.154987, -0.002984},{
      0.585871, 0.155437, -0.002984},{0.585692, 0.155988, -0.004384}}],
    Polygon[{{0.583033, 0.154987, -0.002984},{0.583033, 0.154634, -0.001511},{
      0.585981, 0.155100, -0.001511},{0.585871, 0.155437, -0.002984}}],
    Polygon[{{0.583033, 0.154634, -0.001511},{0.583033, 0.154515, 0.000000},{
      0.586017, 0.154987, 0.000000},{0.585981, 0.155100, -0.001511}}],
    Polygon[{{0.583033, 0.154515, 0.000000},{0.583033, 0.154634, 0.001511},{
      0.585981, 0.155100, 0.001511},{0.586017, 0.154987, 0.000000}}],
    Polygon[{{0.583033, 0.154634, 0.001511},{0.583033, 0.154987, 0.002984},{
      0.585871, 0.155437, 0.002984},{0.585981, 0.155100, 0.001511}}],
    Polygon[{{0.583033, 0.154987, 0.002984},{0.583033, 0.155567, 0.004384},{
      0.585692, 0.155988, 0.004384},{0.585871, 0.155437, 0.002984}}],
    Polygon[{{0.583033, 0.155567, 0.004384},{0.583033, 0.156359, 0.005676},{
      0.585447, 0.156741, 0.005676},{0.585692, 0.155988, 0.004384}}],
    Polygon[{{0.583033, 0.156359, 0.005676},{0.583033, 0.157343, 0.006829},{
      0.585143, 0.157677, 0.006829},{0.585447, 0.156741, 0.005676}}],
    Polygon[{{0.583033, 0.157343, 0.006829},{0.583033, 0.158496, 0.007813},{
      0.584787, 0.158773, 0.007813},{0.585143, 0.157677, 0.006829}}],
    Polygon[{{0.583033, 0.158496, 0.007813},{0.583033, 0.159788, 0.008605},{
      0.584388, 0.160002, 0.008605},{0.584787, 0.158773, 0.007813}}],
    Polygon[{{0.583033, 0.159788, 0.008605},{0.583033, 0.161188, 0.009185},{
      0.583955, 0.161334, 0.009185},{0.584388, 0.160002, 0.008605}}],
    Polygon[{{0.583033, 0.161188, 0.009185},{0.583033, 0.162661, 0.009538},{
      0.583500, 0.162735, 0.009538},{0.583955, 0.161334, 0.009185}}],
    Polygon[{{0.583500, 0.162735, -0.009538},{0.583955, 0.161334, -0.009185},{
      0.584787, 0.161758, -0.009185},{0.583921, 0.162950, -0.009538}}],
    Polygon[{{0.583955, 0.161334, -0.009185},{0.584388, 0.160002, -0.008605},{
      0.585610, 0.160625, -0.008605},{0.584787, 0.161758, -0.009185}}],
    Polygon[{{0.584388, 0.160002, -0.008605},{0.584787, 0.158773, -0.007813},{
      0.586370, 0.159580, -0.007813},{0.585610, 0.160625, -0.008605}}],
    Polygon[{{0.584787, 0.158773, -0.007813},{0.585143, 0.157677, -0.006829},{
      0.587047, 0.158647, -0.006829},{0.586370, 0.159580, -0.007813}}],
    Polygon[{{0.585143, 0.157677, -0.006829},{0.585447, 0.156741, -0.005676},{
      0.587625, 0.157851, -0.005676},{0.587047, 0.158647, -0.006829}}],
    Polygon[{{0.585447, 0.156741, -0.005676},{0.585692, 0.155988, -0.004384},{
      0.588091, 0.157211, -0.004384},{0.587625, 0.157851, -0.005676}}],
    Polygon[{{0.585692, 0.155988, -0.004384},{0.585871, 0.155437, -0.002984},{
      0.588432, 0.156741, -0.002984},{0.588091, 0.157211, -0.004384}}],
    Polygon[{{0.585871, 0.155437, -0.002984},{0.585981, 0.155100, -0.001511},{
      0.588640, 0.156455, -0.001511},{0.588432, 0.156741, -0.002984}}],
    Polygon[{{0.585981, 0.155100, -0.001511},{0.586017, 0.154987, 0.000000},{
      0.588709, 0.156359, 0.000000},{0.588640, 0.156455, -0.001511}}],
    Polygon[{{0.586017, 0.154987, 0.000000},{0.585981, 0.155100, 0.001511},{
      0.588640, 0.156455, 0.001511},{0.588709, 0.156359, 0.000000}}],
    Polygon[{{0.585981, 0.155100, 0.001511},{0.585871, 0.155437, 0.002984},{
      0.588432, 0.156741, 0.002984},{0.588640, 0.156455, 0.001511}}],
    Polygon[{{0.585871, 0.155437, 0.002984},{0.585692, 0.155988, 0.004384},{
      0.588091, 0.157211, 0.004384},{0.588432, 0.156741, 0.002984}}],
    Polygon[{{0.585692, 0.155988, 0.004384},{0.585447, 0.156741, 0.005676},{
      0.587625, 0.157851, 0.005676},{0.588091, 0.157211, 0.004384}}],
    Polygon[{{0.585447, 0.156741, 0.005676},{0.585143, 0.157677, 0.006829},{
      0.587047, 0.158647, 0.006829},{0.587625, 0.157851, 0.005676}}],
    Polygon[{{0.585143, 0.157677, 0.006829},{0.584787, 0.158773, 0.007813},{
      0.586370, 0.159580, 0.007813},{0.587047, 0.158647, 0.006829}}],
    Polygon[{{0.584787, 0.158773, 0.007813},{0.584388, 0.160002, 0.008605},{
      0.585610, 0.160625, 0.008605},{0.586370, 0.159580, 0.007813}}],
    Polygon[{{0.584388, 0.160002, 0.008605},{0.583955, 0.161334, 0.009185},{
      0.584787, 0.161758, 0.009185},{0.585610, 0.160625, 0.008605}}],
    Polygon[{{0.583955, 0.161334, 0.009185},{0.583500, 0.162735, 0.009538},{
      0.583921, 0.162950, 0.009538},{0.584787, 0.161758, 0.009185}}],
    Polygon[{{0.583921, 0.162950, -0.009538},{0.584787, 0.161758, -0.009185},{
      0.585447, 0.162418, -0.009185},{0.584255, 0.163284, -0.009538}}],
    Polygon[{{0.584787, 0.161758, -0.009185},{0.585610, 0.160625, -0.008605},{
      0.586580, 0.161595, -0.008605},{0.585447, 0.162418, -0.009185}}],
    Polygon[{{0.585610, 0.160625, -0.008605},{0.586370, 0.159580, -0.007813},{
      0.587625, 0.160835, -0.007813},{0.586580, 0.161595, -0.008605}}],
    Polygon[{{0.586370, 0.159580, -0.007813},{0.587047, 0.158647, -0.006829},{
      0.588558, 0.160158, -0.006829},{0.587625, 0.160835, -0.007813}}],
    Polygon[{{0.587047, 0.158647, -0.006829},{0.587625, 0.157851, -0.005676},{
      0.589354, 0.159580, -0.005676},{0.588558, 0.160158, -0.006829}}],
    Polygon[{{0.587625, 0.157851, -0.005676},{0.588091, 0.157211, -0.004384},{
      0.589994, 0.159114, -0.004384},{0.589354, 0.159580, -0.005676}}],
    Polygon[{{0.588091, 0.157211, -0.004384},{0.588432, 0.156741, -0.002984},{
      0.590464, 0.158773, -0.002984},{0.589994, 0.159114, -0.004384}}],
    Polygon[{{0.588432, 0.156741, -0.002984},{0.588640, 0.156455, -0.001511},{
      0.590750, 0.158565, -0.001511},{0.590464, 0.158773, -0.002984}}],
    Polygon[{{0.588640, 0.156455, -0.001511},{0.588709, 0.156359, 0.000000},{
      0.590846, 0.158496, 0.000000},{0.590750, 0.158565, -0.001511}}],
    Polygon[{{0.588709, 0.156359, 0.000000},{0.588640, 0.156455, 0.001511},{
      0.590750, 0.158565, 0.001511},{0.590846, 0.158496, 0.000000}}],
    Polygon[{{0.588640, 0.156455, 0.001511},{0.588432, 0.156741, 0.002984},{
      0.590464, 0.158773, 0.002984},{0.590750, 0.158565, 0.001511}}],
    Polygon[{{0.588432, 0.156741, 0.002984},{0.588091, 0.157211, 0.004384},{
      0.589994, 0.159114, 0.004384},{0.590464, 0.158773, 0.002984}}],
    Polygon[{{0.588091, 0.157211, 0.004384},{0.587625, 0.157851, 0.005676},{
      0.589354, 0.159580, 0.005676},{0.589994, 0.159114, 0.004384}}],
    Polygon[{{0.587625, 0.157851, 0.005676},{0.587047, 0.158647, 0.006829},{
      0.588558, 0.160158, 0.006829},{0.589354, 0.159580, 0.005676}}],
    Polygon[{{0.587047, 0.158647, 0.006829},{0.586370, 0.159580, 0.007813},{
      0.587625, 0.160835, 0.007813},{0.588558, 0.160158, 0.006829}}],
    Polygon[{{0.586370, 0.159580, 0.007813},{0.585610, 0.160625, 0.008605},{
      0.586580, 0.161595, 0.008605},{0.587625, 0.160835, 0.007813}}],
    Polygon[{{0.585610, 0.160625, 0.008605},{0.584787, 0.161758, 0.009185},{
      0.585447, 0.162418, 0.009185},{0.586580, 0.161595, 0.008605}}],
    Polygon[{{0.584787, 0.161758, 0.009185},{0.583921, 0.162950, 0.009538},{
      0.584255, 0.163284, 0.009538},{0.585447, 0.162418, 0.009185}}],
    Polygon[{{0.584255, 0.163284, -0.009538},{0.585447, 0.162418, -0.009185},{
      0.585871, 0.163250, -0.009185},{0.584470, 0.163705, -0.009538}}],
    Polygon[{{0.585447, 0.162418, -0.009185},{0.586580, 0.161595, -0.008605},{
      0.587203, 0.162817, -0.008605},{0.585871, 0.163250, -0.009185}}],
    Polygon[{{0.586580, 0.161595, -0.008605},{0.587625, 0.160835, -0.007813},{
      0.588432, 0.162418, -0.007813},{0.587203, 0.162817, -0.008605}}],
    Polygon[{{0.587625, 0.160835, -0.007813},{0.588558, 0.160158, -0.006829},{
      0.589528, 0.162062, -0.006829},{0.588432, 0.162418, -0.007813}}],
    Polygon[{{0.588558, 0.160158, -0.006829},{0.589354, 0.159580, -0.005676},{
      0.590464, 0.161758, -0.005676},{0.589528, 0.162062, -0.006829}}],
    Polygon[{{0.589354, 0.159580, -0.005676},{0.589994, 0.159114, -0.004384},{
      0.591217, 0.161513, -0.004384},{0.590464, 0.161758, -0.005676}}],
    Polygon[{{0.589994, 0.159114, -0.004384},{0.590464, 0.158773, -0.002984},{
      0.591768, 0.161334, -0.002984},{0.591217, 0.161513, -0.004384}}],
    Polygon[{{0.590464, 0.158773, -0.002984},{0.590750, 0.158565, -0.001511},{
      0.592105, 0.161224, -0.001511},{0.591768, 0.161334, -0.002984}}],
    Polygon[{{0.590750, 0.158565, -0.001511},{0.590846, 0.158496, 0.000000},{
      0.592218, 0.161188, 0.000000},{0.592105, 0.161224, -0.001511}}],
    Polygon[{{0.590846, 0.158496, 0.000000},{0.590750, 0.158565, 0.001511},{
      0.592105, 0.161224, 0.001511},{0.592218, 0.161188, 0.000000}}],
    Polygon[{{0.590750, 0.158565, 0.001511},{0.590464, 0.158773, 0.002984},{
      0.591768, 0.161334, 0.002984},{0.592105, 0.161224, 0.001511}}],
    Polygon[{{0.590464, 0.158773, 0.002984},{0.589994, 0.159114, 0.004384},{
      0.591217, 0.161513, 0.004384},{0.591768, 0.161334, 0.002984}}],
    Polygon[{{0.589994, 0.159114, 0.004384},{0.589354, 0.159580, 0.005676},{
      0.590464, 0.161758, 0.005676},{0.591217, 0.161513, 0.004384}}],
    Polygon[{{0.589354, 0.159580, 0.005676},{0.588558, 0.160158, 0.006829},{
      0.589528, 0.162062, 0.006829},{0.590464, 0.161758, 0.005676}}],
    Polygon[{{0.588558, 0.160158, 0.006829},{0.587625, 0.160835, 0.007813},{
      0.588432, 0.162418, 0.007813},{0.589528, 0.162062, 0.006829}}],
    Polygon[{{0.587625, 0.160835, 0.007813},{0.586580, 0.161595, 0.008605},{
      0.587203, 0.162817, 0.008605},{0.588432, 0.162418, 0.007813}}],
    Polygon[{{0.586580, 0.161595, 0.008605},{0.585447, 0.162418, 0.009185},{
      0.585871, 0.163250, 0.009185},{0.587203, 0.162817, 0.008605}}],
    Polygon[{{0.585447, 0.162418, 0.009185},{0.584255, 0.163284, 0.009538},{
      0.584470, 0.163705, 0.009538},{0.585871, 0.163250, 0.009185}}],
    Polygon[{{0.584470, 0.163705, -0.009538},{0.585871, 0.163250, -0.009185},{
      0.586017, 0.164172, -0.009185},{0.584544, 0.164172, -0.009538}}],
    Polygon[{{0.585871, 0.163250, -0.009185},{0.587203, 0.162817, -0.008605},{
      0.587417, 0.164172, -0.008605},{0.586017, 0.164172, -0.009185}}],
    Polygon[{{0.587203, 0.162817, -0.008605},{0.588432, 0.162418, -0.007813},{
      0.588709, 0.164172, -0.007813},{0.587417, 0.164172, -0.008605}}],
    Polygon[{{0.588432, 0.162418, -0.007813},{0.589528, 0.162062, -0.006829},{
      0.589862, 0.164172, -0.006829},{0.588709, 0.164172, -0.007813}}],
    Polygon[{{0.589528, 0.162062, -0.006829},{0.590464, 0.161758, -0.005676},{
      0.590846, 0.164172, -0.005676},{0.589862, 0.164172, -0.006829}}],
    Polygon[{{0.590464, 0.161758, -0.005676},{0.591217, 0.161513, -0.004384},{
      0.591638, 0.164172, -0.004384},{0.590846, 0.164172, -0.005676}}],
    Polygon[{{0.591217, 0.161513, -0.004384},{0.591768, 0.161334, -0.002984},{
      0.592218, 0.164172, -0.002984},{0.591638, 0.164172, -0.004384}}],
    Polygon[{{0.591768, 0.161334, -0.002984},{0.592105, 0.161224, -0.001511},{
      0.592571, 0.164172, -0.001511},{0.592218, 0.164172, -0.002984}}],
    Polygon[{{0.592105, 0.161224, -0.001511},{0.592218, 0.161188, 0.000000},{
      0.592690, 0.164172, 0.000000},{0.592571, 0.164172, -0.001511}}],
    Polygon[{{0.592218, 0.161188, 0.000000},{0.592105, 0.161224, 0.001511},{
      0.592571, 0.164172, 0.001511},{0.592690, 0.164172, 0.000000}}],
    Polygon[{{0.592105, 0.161224, 0.001511},{0.591768, 0.161334, 0.002984},{
      0.592218, 0.164172, 0.002984},{0.592571, 0.164172, 0.001511}}],
    Polygon[{{0.591768, 0.161334, 0.002984},{0.591217, 0.161513, 0.004384},{
      0.591638, 0.164172, 0.004384},{0.592218, 0.164172, 0.002984}}],
    Polygon[{{0.591217, 0.161513, 0.004384},{0.590464, 0.161758, 0.005676},{
      0.590846, 0.164172, 0.005676},{0.591638, 0.164172, 0.004384}}],
    Polygon[{{0.590464, 0.161758, 0.005676},{0.589528, 0.162062, 0.006829},{
      0.589862, 0.164172, 0.006829},{0.590846, 0.164172, 0.005676}}],
    Polygon[{{0.589528, 0.162062, 0.006829},{0.588432, 0.162418, 0.007813},{
      0.588709, 0.164172, 0.007813},{0.589862, 0.164172, 0.006829}}],
    Polygon[{{0.588432, 0.162418, 0.007813},{0.587203, 0.162817, 0.008605},{
      0.587417, 0.164172, 0.008605},{0.588709, 0.164172, 0.007813}}],
    Polygon[{{0.587203, 0.162817, 0.008605},{0.585871, 0.163250, 0.009185},{
      0.586017, 0.164172, 0.009185},{0.587417, 0.164172, 0.008605}}],
    Polygon[{{0.585871, 0.163250, 0.009185},{0.584470, 0.163705, 0.009538},{
      0.584544, 0.164172, 0.009538},{0.586017, 0.164172, 0.009185}}],
    Polygon[{{0.531229, 0.149198, -0.008668},{0.532569, 0.149198, -0.008347},{
      0.532436, 0.150036, -0.008347},{0.531162, 0.149623, -0.008668}}],
    Polygon[{{0.532569, 0.149198, -0.008347},{0.533841, 0.149198, -0.007820},{
      0.533646, 0.150430, -0.007820},{0.532436, 0.150036, -0.008347}}],
    Polygon[{{0.533841, 0.149198, -0.007820},{0.535015, 0.149198, -0.007100},{
      0.534763, 0.150792, -0.007100},{0.533646, 0.150430, -0.007820}}],
    Polygon[{{0.535015, 0.149198, -0.007100},{0.536062, 0.149198, -0.006206},{
      0.535759, 0.151116, -0.006206},{0.534763, 0.150792, -0.007100}}],
    Polygon[{{0.536062, 0.149198, -0.006206},{0.536957, 0.149198, -0.005159},{
      0.536609, 0.151392, -0.005159},{0.535759, 0.151116, -0.006206}}],
    Polygon[{{0.536957, 0.149198, -0.005159},{0.537676, 0.149198, -0.003984},{
      0.537294, 0.151615, -0.003984},{0.536609, 0.151392, -0.005159}}],
    Polygon[{{0.537676, 0.149198, -0.003984},{0.538203, 0.149198, -0.002712},{
      0.537795, 0.151778, -0.002712},{0.537294, 0.151615, -0.003984}}],
    Polygon[{{0.538203, 0.149198, -0.002712},{0.538525, 0.149198, -0.001373},{
      0.538101, 0.151877, -0.001373},{0.537795, 0.151778, -0.002712}}],
    Polygon[{{0.538525, 0.149198, -0.001373},{0.538633, 0.149198, 0.000000},{
      0.538203, 0.151910, 0.000000},{0.538101, 0.151877, -0.001373}}],
    Polygon[{{0.538633, 0.149198, 0.000000},{0.538525, 0.149198, 0.001373},{
      0.538101, 0.151877, 0.001373},{0.538203, 0.151910, 0.000000}}],
    Polygon[{{0.538525, 0.149198, 0.001373},{0.538203, 0.149198, 0.002712},{
      0.537795, 0.151778, 0.002712},{0.538101, 0.151877, 0.001373}}],
    Polygon[{{0.538203, 0.149198, 0.002712},{0.537676, 0.149198, 0.003984},{
      0.537294, 0.151615, 0.003984},{0.537795, 0.151778, 0.002712}}],
    Polygon[{{0.537676, 0.149198, 0.003984},{0.536957, 0.149198, 0.005159},{
      0.536609, 0.151392, 0.005159},{0.537294, 0.151615, 0.003984}}],
    Polygon[{{0.536957, 0.149198, 0.005159},{0.536062, 0.149198, 0.006206},{
      0.535759, 0.151116, 0.006206},{0.536609, 0.151392, 0.005159}}],
    Polygon[{{0.536062, 0.149198, 0.006206},{0.535015, 0.149198, 0.007100},{
      0.534763, 0.150792, 0.007100},{0.535759, 0.151116, 0.006206}}],
    Polygon[{{0.535015, 0.149198, 0.007100},{0.533841, 0.149198, 0.007820},{
      0.533646, 0.150430, 0.007820},{0.534763, 0.150792, 0.007100}}],
    Polygon[{{0.533841, 0.149198, 0.007820},{0.532569, 0.149198, 0.008347},{
      0.532436, 0.150036, 0.008347},{0.533646, 0.150430, 0.007820}}],
    Polygon[{{0.532569, 0.149198, 0.008347},{0.531229, 0.149198, 0.008668},{
      0.531162, 0.149623, 0.008668},{0.532436, 0.150036, 0.008347}}],
    Polygon[{{0.531162, 0.149623, -0.008668},{0.532436, 0.150036, -0.008347},{
      0.532051, 0.150792, -0.008347},{0.530967, 0.150005, -0.008668}}],
    Polygon[{{0.532436, 0.150036, -0.008347},{0.533646, 0.150430, -0.007820},{
      0.533080, 0.151540, -0.007820},{0.532051, 0.150792, -0.008347}}],
    Polygon[{{0.533646, 0.150430, -0.007820},{0.534763, 0.150792, -0.007100},{
      0.534030, 0.152231, -0.007100},{0.533080, 0.151540, -0.007820}}],
    Polygon[{{0.534763, 0.150792, -0.007100},{0.535759, 0.151116, -0.006206},{
      0.534877, 0.152846, -0.006206},{0.534030, 0.152231, -0.007100}}],
    Polygon[{{0.535759, 0.151116, -0.006206},{0.536609, 0.151392, -0.005159},{
      0.535601, 0.153372, -0.005159},{0.534877, 0.152846, -0.006206}}],
    Polygon[{{0.536609, 0.151392, -0.005159},{0.537294, 0.151615, -0.003984},{
      0.536183, 0.153795, -0.003984},{0.535601, 0.153372, -0.005159}}],
    Polygon[{{0.537294, 0.151615, -0.003984},{0.537795, 0.151778, -0.002712},{
      0.536609, 0.154104, -0.002712},{0.536183, 0.153795, -0.003984}}],
    Polygon[{{0.537795, 0.151778, -0.002712},{0.538101, 0.151877, -0.001373},{
      0.536869, 0.154293, -0.001373},{0.536609, 0.154104, -0.002712}}],
    Polygon[{{0.538101, 0.151877, -0.001373},{0.538203, 0.151910, 0.000000},{
      0.536957, 0.154357, 0.000000},{0.536869, 0.154293, -0.001373}}],
    Polygon[{{0.538203, 0.151910, 0.000000},{0.538101, 0.151877, 0.001373},{
      0.536869, 0.154293, 0.001373},{0.536957, 0.154357, 0.000000}}],
    Polygon[{{0.538101, 0.151877, 0.001373},{0.537795, 0.151778, 0.002712},{
      0.536609, 0.154104, 0.002712},{0.536869, 0.154293, 0.001373}}],
    Polygon[{{0.537795, 0.151778, 0.002712},{0.537294, 0.151615, 0.003984},{
      0.536183, 0.153795, 0.003984},{0.536609, 0.154104, 0.002712}}],
    Polygon[{{0.537294, 0.151615, 0.003984},{0.536609, 0.151392, 0.005159},{
      0.535601, 0.153372, 0.005159},{0.536183, 0.153795, 0.003984}}],
    Polygon[{{0.536609, 0.151392, 0.005159},{0.535759, 0.151116, 0.006206},{
      0.534877, 0.152846, 0.006206},{0.535601, 0.153372, 0.005159}}],
    Polygon[{{0.535759, 0.151116, 0.006206},{0.534763, 0.150792, 0.007100},{
      0.534030, 0.152231, 0.007100},{0.534877, 0.152846, 0.006206}}],
    Polygon[{{0.534763, 0.150792, 0.007100},{0.533646, 0.150430, 0.007820},{
      0.533080, 0.151540, 0.007820},{0.534030, 0.152231, 0.007100}}],
    Polygon[{{0.533646, 0.150430, 0.007820},{0.532436, 0.150036, 0.008347},{
      0.532051, 0.150792, 0.008347},{0.533080, 0.151540, 0.007820}}],
    Polygon[{{0.532436, 0.150036, 0.008347},{0.531162, 0.149623, 0.008668},{
      0.530967, 0.150005, 0.008668},{0.532051, 0.150792, 0.008347}}],
    Polygon[{{0.530967, 0.150005, -0.008668},{0.532051, 0.150792, -0.008347},{
      0.531451, 0.151392, -0.008347},{0.530664, 0.150309, -0.008668}}],
    Polygon[{{0.532051, 0.150792, -0.008347},{0.533080, 0.151540, -0.007820},{
      0.532198, 0.152422, -0.007820},{0.531451, 0.151392, -0.008347}}],
    Polygon[{{0.533080, 0.151540, -0.007820},{0.534030, 0.152231, -0.007100},{
      0.532889, 0.153372, -0.007100},{0.532198, 0.152422, -0.007820}}],
    Polygon[{{0.534030, 0.152231, -0.007100},{0.534877, 0.152846, -0.006206},{
      0.533504, 0.154219, -0.006206},{0.532889, 0.153372, -0.007100}}],
    Polygon[{{0.534877, 0.152846, -0.006206},{0.535601, 0.153372, -0.005159},{
      0.534030, 0.154943, -0.005159},{0.533504, 0.154219, -0.006206}}],
    Polygon[{{0.535601, 0.153372, -0.005159},{0.536183, 0.153795, -0.003984},{
      0.534453, 0.155525, -0.003984},{0.534030, 0.154943, -0.005159}}],
    Polygon[{{0.536183, 0.153795, -0.003984},{0.536609, 0.154104, -0.002712},{
      0.534763, 0.155951, -0.002712},{0.534453, 0.155525, -0.003984}}],
    Polygon[{{0.536609, 0.154104, -0.002712},{0.536869, 0.154293, -0.001373},{
      0.534952, 0.156211, -0.001373},{0.534763, 0.155951, -0.002712}}],
    Polygon[{{0.536869, 0.154293, -0.001373},{0.536957, 0.154357, 0.000000},{
      0.535015, 0.156299, 0.000000},{0.534952, 0.156211, -0.001373}}],
    Polygon[{{0.536957, 0.154357, 0.000000},{0.536869, 0.154293, 0.001373},{
      0.534952, 0.156211, 0.001373},{0.535015, 0.156299, 0.000000}}],
    Polygon[{{0.536869, 0.154293, 0.001373},{0.536609, 0.154104, 0.002712},{
      0.534763, 0.155951, 0.002712},{0.534952, 0.156211, 0.001373}}],
    Polygon[{{0.536609, 0.154104, 0.002712},{0.536183, 0.153795, 0.003984},{
      0.534453, 0.155525, 0.003984},{0.534763, 0.155951, 0.002712}}],
    Polygon[{{0.536183, 0.153795, 0.003984},{0.535601, 0.153372, 0.005159},{
      0.534030, 0.154943, 0.005159},{0.534453, 0.155525, 0.003984}}],
    Polygon[{{0.535601, 0.153372, 0.005159},{0.534877, 0.152846, 0.006206},{
      0.533504, 0.154219, 0.006206},{0.534030, 0.154943, 0.005159}}],
    Polygon[{{0.534877, 0.152846, 0.006206},{0.534030, 0.152231, 0.007100},{
      0.532889, 0.153372, 0.007100},{0.533504, 0.154219, 0.006206}}],
    Polygon[{{0.534030, 0.152231, 0.007100},{0.533080, 0.151540, 0.007820},{
      0.532198, 0.152422, 0.007820},{0.532889, 0.153372, 0.007100}}],
    Polygon[{{0.533080, 0.151540, 0.007820},{0.532051, 0.150792, 0.008347},{
      0.531451, 0.151392, 0.008347},{0.532198, 0.152422, 0.007820}}],
    Polygon[{{0.532051, 0.150792, 0.008347},{0.530967, 0.150005, 0.008668},{
      0.530664, 0.150309, 0.008668},{0.531451, 0.151392, 0.008347}}],
    Polygon[{{0.530664, 0.150309, -0.008668},{0.531451, 0.151392, -0.008347},{
      0.530695, 0.151778, -0.008347},{0.530281, 0.150504, -0.008668}}],
    Polygon[{{0.531451, 0.151392, -0.008347},{0.532198, 0.152422, -0.007820},{
      0.531088, 0.152988, -0.007820},{0.530695, 0.151778, -0.008347}}],
    Polygon[{{0.532198, 0.152422, -0.007820},{0.532889, 0.153372, -0.007100},{
      0.531451, 0.154104, -0.007100},{0.531088, 0.152988, -0.007820}}],
    Polygon[{{0.532889, 0.153372, -0.007100},{0.533504, 0.154219, -0.006206},{
      0.531774, 0.155100, -0.006206},{0.531451, 0.154104, -0.007100}}],
    Polygon[{{0.533504, 0.154219, -0.006206},{0.534030, 0.154943, -0.005159},{
      0.532051, 0.155951, -0.005159},{0.531774, 0.155100, -0.006206}}],
    Polygon[{{0.534030, 0.154943, -0.005159},{0.534453, 0.155525, -0.003984},{
      0.532273, 0.156635, -0.003984},{0.532051, 0.155951, -0.005159}}],
    Polygon[{{0.534453, 0.155525, -0.003984},{0.534763, 0.155951, -0.002712},{
      0.532436, 0.157137, -0.002712},{0.532273, 0.156635, -0.003984}}],
    Polygon[{{0.534763, 0.155951, -0.002712},{0.534952, 0.156211, -0.001373},{
      0.532535, 0.157442, -0.001373},{0.532436, 0.157137, -0.002712}}],
    Polygon[{{0.534952, 0.156211, -0.001373},{0.535015, 0.156299, 0.000000},{
      0.532569, 0.157545, 0.000000},{0.532535, 0.157442, -0.001373}}],
    Polygon[{{0.535015, 0.156299, 0.000000},{0.534952, 0.156211, 0.001373},{
      0.532535, 0.157442, 0.001373},{0.532569, 0.157545, 0.000000}}],
    Polygon[{{0.534952, 0.156211, 0.001373},{0.534763, 0.155951, 0.002712},{
      0.532436, 0.157137, 0.002712},{0.532535, 0.157442, 0.001373}}],
    Polygon[{{0.534763, 0.155951, 0.002712},{0.534453, 0.155525, 0.003984},{
      0.532273, 0.156635, 0.003984},{0.532436, 0.157137, 0.002712}}],
    Polygon[{{0.534453, 0.155525, 0.003984},{0.534030, 0.154943, 0.005159},{
      0.532051, 0.155951, 0.005159},{0.532273, 0.156635, 0.003984}}],
    Polygon[{{0.534030, 0.154943, 0.005159},{0.533504, 0.154219, 0.006206},{
      0.531774, 0.155100, 0.006206},{0.532051, 0.155951, 0.005159}}],
    Polygon[{{0.533504, 0.154219, 0.006206},{0.532889, 0.153372, 0.007100},{
      0.531451, 0.154104, 0.007100},{0.531774, 0.155100, 0.006206}}],
    Polygon[{{0.532889, 0.153372, 0.007100},{0.532198, 0.152422, 0.007820},{
      0.531088, 0.152988, 0.007820},{0.531451, 0.154104, 0.007100}}],
    Polygon[{{0.532198, 0.152422, 0.007820},{0.531451, 0.151392, 0.008347},{
      0.530695, 0.151778, 0.008347},{0.531088, 0.152988, 0.007820}}],
    Polygon[{{0.531451, 0.151392, 0.008347},{0.530664, 0.150309, 0.008668},{
      0.530281, 0.150504, 0.008668},{0.530695, 0.151778, 0.008347}}],
    Polygon[{{0.530281, 0.150504, -0.008668},{0.530695, 0.151778, -0.008347},{
      0.529857, 0.151910, -0.008347},{0.529857, 0.150571, -0.008668}}],
    Polygon[{{0.530695, 0.151778, -0.008347},{0.531088, 0.152988, -0.007820},{
      0.529857, 0.153183, -0.007820},{0.529857, 0.151910, -0.008347}}],
    Polygon[{{0.531088, 0.152988, -0.007820},{0.531451, 0.154104, -0.007100},{
      0.529857, 0.154357, -0.007100},{0.529857, 0.153183, -0.007820}}],
    Polygon[{{0.531451, 0.154104, -0.007100},{0.531774, 0.155100, -0.006206},{
      0.529857, 0.155404, -0.006206},{0.529857, 0.154357, -0.007100}}],
    Polygon[{{0.531774, 0.155100, -0.006206},{0.532051, 0.155951, -0.005159},{
      0.529857, 0.156299, -0.005159},{0.529857, 0.155404, -0.006206}}],
    Polygon[{{0.532051, 0.155951, -0.005159},{0.532273, 0.156635, -0.003984},{
      0.529857, 0.157018, -0.003984},{0.529857, 0.156299, -0.005159}}],
    Polygon[{{0.532273, 0.156635, -0.003984},{0.532436, 0.157137, -0.002712},{
      0.529857, 0.157545, -0.002712},{0.529857, 0.157018, -0.003984}}],
    Polygon[{{0.532436, 0.157137, -0.002712},{0.532535, 0.157442, -0.001373},{
      0.529857, 0.157867, -0.001373},{0.529857, 0.157545, -0.002712}}],
    Polygon[{{0.532535, 0.157442, -0.001373},{0.532569, 0.157545, 0.000000},{
      0.529857, 0.157975, 0.000000},{0.529857, 0.157867, -0.001373}}],
    Polygon[{{0.532569, 0.157545, 0.000000},{0.532535, 0.157442, 0.001373},{
      0.529857, 0.157867, 0.001373},{0.529857, 0.157975, 0.000000}}],
    Polygon[{{0.532535, 0.157442, 0.001373},{0.532436, 0.157137, 0.002712},{
      0.529857, 0.157545, 0.002712},{0.529857, 0.157867, 0.001373}}],
    Polygon[{{0.532436, 0.157137, 0.002712},{0.532273, 0.156635, 0.003984},{
      0.529857, 0.157018, 0.003984},{0.529857, 0.157545, 0.002712}}],
    Polygon[{{0.532273, 0.156635, 0.003984},{0.532051, 0.155951, 0.005159},{
      0.529857, 0.156299, 0.005159},{0.529857, 0.157018, 0.003984}}],
    Polygon[{{0.532051, 0.155951, 0.005159},{0.531774, 0.155100, 0.006206},{
      0.529857, 0.155404, 0.006206},{0.529857, 0.156299, 0.005159}}],
    Polygon[{{0.531774, 0.155100, 0.006206},{0.531451, 0.154104, 0.007100},{
      0.529857, 0.154357, 0.007100},{0.529857, 0.155404, 0.006206}}],
    Polygon[{{0.531451, 0.154104, 0.007100},{0.531088, 0.152988, 0.007820},{
      0.529857, 0.153183, 0.007820},{0.529857, 0.154357, 0.007100}}],
    Polygon[{{0.531088, 0.152988, 0.007820},{0.530695, 0.151778, 0.008347},{
      0.529857, 0.151910, 0.008347},{0.529857, 0.153183, 0.007820}}],
    Polygon[{{0.530695, 0.151778, 0.008347},{0.530281, 0.150504, 0.008668},{
      0.529857, 0.150571, 0.008668},{0.529857, 0.151910, 0.008347}}],
    Polygon[{{0.529857, 0.150571, -0.008668},{0.529857, 0.151910, -0.008347},{
      0.529018, 0.151778, -0.008347},{0.529432, 0.150504, -0.008668}}],
    Polygon[{{0.529857, 0.151910, -0.008347},{0.529857, 0.153183, -0.007820},{
      0.528625, 0.152988, -0.007820},{0.529018, 0.151778, -0.008347}}],
    Polygon[{{0.529857, 0.153183, -0.007820},{0.529857, 0.154357, -0.007100},{
      0.528262, 0.154104, -0.007100},{0.528625, 0.152988, -0.007820}}],
    Polygon[{{0.529857, 0.154357, -0.007100},{0.529857, 0.155404, -0.006206},{
      0.527939, 0.155100, -0.006206},{0.528262, 0.154104, -0.007100}}],
    Polygon[{{0.529857, 0.155404, -0.006206},{0.529857, 0.156299, -0.005159},{
      0.527662, 0.155951, -0.005159},{0.527939, 0.155100, -0.006206}}],
    Polygon[{{0.529857, 0.156299, -0.005159},{0.529857, 0.157018, -0.003984},{
      0.527440, 0.156635, -0.003984},{0.527662, 0.155951, -0.005159}}],
    Polygon[{{0.529857, 0.157018, -0.003984},{0.529857, 0.157545, -0.002712},{
      0.527277, 0.157137, -0.002712},{0.527440, 0.156635, -0.003984}}],
    Polygon[{{0.529857, 0.157545, -0.002712},{0.529857, 0.157867, -0.001373},{
      0.527178, 0.157442, -0.001373},{0.527277, 0.157137, -0.002712}}],
    Polygon[{{0.529857, 0.157867, -0.001373},{0.529857, 0.157975, 0.000000},{
      0.527144, 0.157545, 0.000000},{0.527178, 0.157442, -0.001373}}],
    Polygon[{{0.529857, 0.157975, 0.000000},{0.529857, 0.157867, 0.001373},{
      0.527178, 0.157442, 0.001373},{0.527144, 0.157545, 0.000000}}],
    Polygon[{{0.529857, 0.157867, 0.001373},{0.529857, 0.157545, 0.002712},{
      0.527277, 0.157137, 0.002712},{0.527178, 0.157442, 0.001373}}],
    Polygon[{{0.529857, 0.157545, 0.002712},{0.529857, 0.157018, 0.003984},{
      0.527440, 0.156635, 0.003984},{0.527277, 0.157137, 0.002712}}],
    Polygon[{{0.529857, 0.157018, 0.003984},{0.529857, 0.156299, 0.005159},{
      0.527662, 0.155951, 0.005159},{0.527440, 0.156635, 0.003984}}],
    Polygon[{{0.529857, 0.156299, 0.005159},{0.529857, 0.155404, 0.006206},{
      0.527939, 0.155100, 0.006206},{0.527662, 0.155951, 0.005159}}],
    Polygon[{{0.529857, 0.155404, 0.006206},{0.529857, 0.154357, 0.007100},{
      0.528262, 0.154104, 0.007100},{0.527939, 0.155100, 0.006206}}],
    Polygon[{{0.529857, 0.154357, 0.007100},{0.529857, 0.153183, 0.007820},{
      0.528625, 0.152988, 0.007820},{0.528262, 0.154104, 0.007100}}],
    Polygon[{{0.529857, 0.153183, 0.007820},{0.529857, 0.151910, 0.008347},{
      0.529018, 0.151778, 0.008347},{0.528625, 0.152988, 0.007820}}],
    Polygon[{{0.529857, 0.151910, 0.008347},{0.529857, 0.150571, 0.008668},{
      0.529432, 0.150504, 0.008668},{0.529018, 0.151778, 0.008347}}],
    Polygon[{{0.529432, 0.150504, -0.008668},{0.529018, 0.151778, -0.008347},{
      0.528262, 0.151392, -0.008347},{0.529050, 0.150309, -0.008668}}],
    Polygon[{{0.529018, 0.151778, -0.008347},{0.528625, 0.152988, -0.007820},{
      0.527515, 0.152422, -0.007820},{0.528262, 0.151392, -0.008347}}],
    Polygon[{{0.528625, 0.152988, -0.007820},{0.528262, 0.154104, -0.007100},{
      0.526824, 0.153372, -0.007100},{0.527515, 0.152422, -0.007820}}],
    Polygon[{{0.528262, 0.154104, -0.007100},{0.527939, 0.155100, -0.006206},{
      0.526209, 0.154219, -0.006206},{0.526824, 0.153372, -0.007100}}],
    Polygon[{{0.527939, 0.155100, -0.006206},{0.527662, 0.155951, -0.005159},{
      0.525683, 0.154943, -0.005159},{0.526209, 0.154219, -0.006206}}],
    Polygon[{{0.527662, 0.155951, -0.005159},{0.527440, 0.156635, -0.003984},{
      0.525260, 0.155525, -0.003984},{0.525683, 0.154943, -0.005159}}],
    Polygon[{{0.527440, 0.156635, -0.003984},{0.527277, 0.157137, -0.002712},{
      0.524950, 0.155951, -0.002712},{0.525260, 0.155525, -0.003984}}],
    Polygon[{{0.527277, 0.157137, -0.002712},{0.527178, 0.157442, -0.001373},{
      0.524761, 0.156211, -0.001373},{0.524950, 0.155951, -0.002712}}],
    Polygon[{{0.527178, 0.157442, -0.001373},{0.527144, 0.157545, 0.000000},{
      0.524698, 0.156299, 0.000000},{0.524761, 0.156211, -0.001373}}],
    Polygon[{{0.527144, 0.157545, 0.000000},{0.527178, 0.157442, 0.001373},{
      0.524761, 0.156211, 0.001373},{0.524698, 0.156299, 0.000000}}],
    Polygon[{{0.527178, 0.157442, 0.001373},{0.527277, 0.157137, 0.002712},{
      0.524950, 0.155951, 0.002712},{0.524761, 0.156211, 0.001373}}],
    Polygon[{{0.527277, 0.157137, 0.002712},{0.527440, 0.156635, 0.003984},{
      0.525260, 0.155525, 0.003984},{0.524950, 0.155951, 0.002712}}],
    Polygon[{{0.527440, 0.156635, 0.003984},{0.527662, 0.155951, 0.005159},{
      0.525683, 0.154943, 0.005159},{0.525260, 0.155525, 0.003984}}],
    Polygon[{{0.527662, 0.155951, 0.005159},{0.527939, 0.155100, 0.006206},{
      0.526209, 0.154219, 0.006206},{0.525683, 0.154943, 0.005159}}],
    Polygon[{{0.527939, 0.155100, 0.006206},{0.528262, 0.154104, 0.007100},{
      0.526824, 0.153372, 0.007100},{0.526209, 0.154219, 0.006206}}],
    Polygon[{{0.528262, 0.154104, 0.007100},{0.528625, 0.152988, 0.007820},{
      0.527515, 0.152422, 0.007820},{0.526824, 0.153372, 0.007100}}],
    Polygon[{{0.528625, 0.152988, 0.007820},{0.529018, 0.151778, 0.008347},{
      0.528262, 0.151392, 0.008347},{0.527515, 0.152422, 0.007820}}],
    Polygon[{{0.529018, 0.151778, 0.008347},{0.529432, 0.150504, 0.008668},{
      0.529050, 0.150309, 0.008668},{0.528262, 0.151392, 0.008347}}],
    Polygon[{{0.529050, 0.150309, -0.008668},{0.528262, 0.151392, -0.008347},{
      0.527662, 0.150792, -0.008347},{0.528746, 0.150005, -0.008668}}],
    Polygon[{{0.528262, 0.151392, -0.008347},{0.527515, 0.152422, -0.007820},{
      0.526633, 0.151540, -0.007820},{0.527662, 0.150792, -0.008347}}],
    Polygon[{{0.527515, 0.152422, -0.007820},{0.526824, 0.153372, -0.007100},{
      0.525683, 0.152231, -0.007100},{0.526633, 0.151540, -0.007820}}],
    Polygon[{{0.526824, 0.153372, -0.007100},{0.526209, 0.154219, -0.006206},{
      0.524836, 0.152846, -0.006206},{0.525683, 0.152231, -0.007100}}],
    Polygon[{{0.526209, 0.154219, -0.006206},{0.525683, 0.154943, -0.005159},{
      0.524112, 0.153372, -0.005159},{0.524836, 0.152846, -0.006206}}],
    Polygon[{{0.525683, 0.154943, -0.005159},{0.525260, 0.155525, -0.003984},{
      0.523530, 0.153795, -0.003984},{0.524112, 0.153372, -0.005159}}],
    Polygon[{{0.525260, 0.155525, -0.003984},{0.524950, 0.155951, -0.002712},{
      0.523104, 0.154104, -0.002712},{0.523530, 0.153795, -0.003984}}],
    Polygon[{{0.524950, 0.155951, -0.002712},{0.524761, 0.156211, -0.001373},{
      0.522844, 0.154293, -0.001373},{0.523104, 0.154104, -0.002712}}],
    Polygon[{{0.524761, 0.156211, -0.001373},{0.524698, 0.156299, 0.000000},{
      0.522756, 0.154357, 0.000000},{0.522844, 0.154293, -0.001373}}],
    Polygon[{{0.524698, 0.156299, 0.000000},{0.524761, 0.156211, 0.001373},{
      0.522844, 0.154293, 0.001373},{0.522756, 0.154357, 0.000000}}],
    Polygon[{{0.524761, 0.156211, 0.001373},{0.524950, 0.155951, 0.002712},{
      0.523104, 0.154104, 0.002712},{0.522844, 0.154293, 0.001373}}],
    Polygon[{{0.524950, 0.155951, 0.002712},{0.525260, 0.155525, 0.003984},{
      0.523530, 0.153795, 0.003984},{0.523104, 0.154104, 0.002712}}],
    Polygon[{{0.525260, 0.155525, 0.003984},{0.525683, 0.154943, 0.005159},{
      0.524112, 0.153372, 0.005159},{0.523530, 0.153795, 0.003984}}],
    Polygon[{{0.525683, 0.154943, 0.005159},{0.526209, 0.154219, 0.006206},{
      0.524836, 0.152846, 0.006206},{0.524112, 0.153372, 0.005159}}],
    Polygon[{{0.526209, 0.154219, 0.006206},{0.526824, 0.153372, 0.007100},{
      0.525683, 0.152231, 0.007100},{0.524836, 0.152846, 0.006206}}],
    Polygon[{{0.526824, 0.153372, 0.007100},{0.527515, 0.152422, 0.007820},{
      0.526633, 0.151540, 0.007820},{0.525683, 0.152231, 0.007100}}],
    Polygon[{{0.527515, 0.152422, 0.007820},{0.528262, 0.151392, 0.008347},{
      0.527662, 0.150792, 0.008347},{0.526633, 0.151540, 0.007820}}],
    Polygon[{{0.528262, 0.151392, 0.008347},{0.529050, 0.150309, 0.008668},{
      0.528746, 0.150005, 0.008668},{0.527662, 0.150792, 0.008347}}],
    Polygon[{{0.528746, 0.150005, -0.008668},{0.527662, 0.150792, -0.008347},{
      0.527277, 0.150036, -0.008347},{0.528551, 0.149623, -0.008668}}],
    Polygon[{{0.527662, 0.150792, -0.008347},{0.526633, 0.151540, -0.007820},{
      0.526067, 0.150430, -0.007820},{0.527277, 0.150036, -0.008347}}],
    Polygon[{{0.526633, 0.151540, -0.007820},{0.525683, 0.152231, -0.007100},{
      0.524950, 0.150792, -0.007100},{0.526067, 0.150430, -0.007820}}],
    Polygon[{{0.525683, 0.152231, -0.007100},{0.524836, 0.152846, -0.006206},{
      0.523954, 0.151116, -0.006206},{0.524950, 0.150792, -0.007100}}],
    Polygon[{{0.524836, 0.152846, -0.006206},{0.524112, 0.153372, -0.005159},{
      0.523104, 0.151392, -0.005159},{0.523954, 0.151116, -0.006206}}],
    Polygon[{{0.524112, 0.153372, -0.005159},{0.523530, 0.153795, -0.003984},{
      0.522419, 0.151615, -0.003984},{0.523104, 0.151392, -0.005159}}],
    Polygon[{{0.523530, 0.153795, -0.003984},{0.523104, 0.154104, -0.002712},{
      0.521918, 0.151778, -0.002712},{0.522419, 0.151615, -0.003984}}],
    Polygon[{{0.523104, 0.154104, -0.002712},{0.522844, 0.154293, -0.001373},{
      0.521612, 0.151877, -0.001373},{0.521918, 0.151778, -0.002712}}],
    Polygon[{{0.522844, 0.154293, -0.001373},{0.522756, 0.154357, 0.000000},{
      0.521510, 0.151910, 0.000000},{0.521612, 0.151877, -0.001373}}],
    Polygon[{{0.522756, 0.154357, 0.000000},{0.522844, 0.154293, 0.001373},{
      0.521612, 0.151877, 0.001373},{0.521510, 0.151910, 0.000000}}],
    Polygon[{{0.522844, 0.154293, 0.001373},{0.523104, 0.154104, 0.002712},{
      0.521918, 0.151778, 0.002712},{0.521612, 0.151877, 0.001373}}],
    Polygon[{{0.523104, 0.154104, 0.002712},{0.523530, 0.153795, 0.003984},{
      0.522419, 0.151615, 0.003984},{0.521918, 0.151778, 0.002712}}],
    Polygon[{{0.523530, 0.153795, 0.003984},{0.524112, 0.153372, 0.005159},{
      0.523104, 0.151392, 0.005159},{0.522419, 0.151615, 0.003984}}],
    Polygon[{{0.524112, 0.153372, 0.005159},{0.524836, 0.152846, 0.006206},{
      0.523954, 0.151116, 0.006206},{0.523104, 0.151392, 0.005159}}],
    Polygon[{{0.524836, 0.152846, 0.006206},{0.525683, 0.152231, 0.007100},{
      0.524950, 0.150792, 0.007100},{0.523954, 0.151116, 0.006206}}],
    Polygon[{{0.525683, 0.152231, 0.007100},{0.526633, 0.151540, 0.007820},{
      0.526067, 0.150430, 0.007820},{0.524950, 0.150792, 0.007100}}],
    Polygon[{{0.526633, 0.151540, 0.007820},{0.527662, 0.150792, 0.008347},{
      0.527277, 0.150036, 0.008347},{0.526067, 0.150430, 0.007820}}],
    Polygon[{{0.527662, 0.150792, 0.008347},{0.528746, 0.150005, 0.008668},{
      0.528551, 0.149623, 0.008668},{0.527277, 0.150036, 0.008347}}],
    Polygon[{{0.528551, 0.149623, -0.008668},{0.527277, 0.150036, -0.008347},{
      0.527144, 0.149198, -0.008347},{0.528484, 0.149198, -0.008668}}],
    Polygon[{{0.527277, 0.150036, -0.008347},{0.526067, 0.150430, -0.007820},{
      0.525872, 0.149198, -0.007820},{0.527144, 0.149198, -0.008347}}],
    Polygon[{{0.526067, 0.150430, -0.007820},{0.524950, 0.150792, -0.007100},{
      0.524698, 0.149198, -0.007100},{0.525872, 0.149198, -0.007820}}],
    Polygon[{{0.524950, 0.150792, -0.007100},{0.523954, 0.151116, -0.006206},{
      0.523651, 0.149198, -0.006206},{0.524698, 0.149198, -0.007100}}],
    Polygon[{{0.523954, 0.151116, -0.006206},{0.523104, 0.151392, -0.005159},{
      0.522756, 0.149198, -0.005159},{0.523651, 0.149198, -0.006206}}],
    Polygon[{{0.523104, 0.151392, -0.005159},{0.522419, 0.151615, -0.003984},{
      0.522037, 0.149198, -0.003984},{0.522756, 0.149198, -0.005159}}],
    Polygon[{{0.522419, 0.151615, -0.003984},{0.521918, 0.151778, -0.002712},{
      0.521510, 0.149198, -0.002712},{0.522037, 0.149198, -0.003984}}],
    Polygon[{{0.521918, 0.151778, -0.002712},{0.521612, 0.151877, -0.001373},{
      0.521188, 0.149198, -0.001373},{0.521510, 0.149198, -0.002712}}],
    Polygon[{{0.521612, 0.151877, -0.001373},{0.521510, 0.151910, 0.000000},{
      0.521080, 0.149198, 0.000000},{0.521188, 0.149198, -0.001373}}],
    Polygon[{{0.521510, 0.151910, 0.000000},{0.521612, 0.151877, 0.001373},{
      0.521188, 0.149198, 0.001373},{0.521080, 0.149198, 0.000000}}],
    Polygon[{{0.521612, 0.151877, 0.001373},{0.521918, 0.151778, 0.002712},{
      0.521510, 0.149198, 0.002712},{0.521188, 0.149198, 0.001373}}],
    Polygon[{{0.521918, 0.151778, 0.002712},{0.522419, 0.151615, 0.003984},{
      0.522037, 0.149198, 0.003984},{0.521510, 0.149198, 0.002712}}],
    Polygon[{{0.522419, 0.151615, 0.003984},{0.523104, 0.151392, 0.005159},{
      0.522756, 0.149198, 0.005159},{0.522037, 0.149198, 0.003984}}],
    Polygon[{{0.523104, 0.151392, 0.005159},{0.523954, 0.151116, 0.006206},{
      0.523651, 0.149198, 0.006206},{0.522756, 0.149198, 0.005159}}],
    Polygon[{{0.523954, 0.151116, 0.006206},{0.524950, 0.150792, 0.007100},{
      0.524698, 0.149198, 0.007100},{0.523651, 0.149198, 0.006206}}],
    Polygon[{{0.524950, 0.150792, 0.007100},{0.526067, 0.150430, 0.007820},{
      0.525872, 0.149198, 0.007820},{0.524698, 0.149198, 0.007100}}],
    Polygon[{{0.526067, 0.150430, 0.007820},{0.527277, 0.150036, 0.008347},{
      0.527144, 0.149198, 0.008347},{0.525872, 0.149198, 0.007820}}],
    Polygon[{{0.527277, 0.150036, 0.008347},{0.528551, 0.149623, 0.008668},{
      0.528484, 0.149198, 0.008668},{0.527144, 0.149198, 0.008347}}],
    Polygon[{{0.528484, 0.149198, -0.008668},{0.527144, 0.149198, -0.008347},{
      0.527277, 0.148360, -0.008347},{0.528551, 0.148774, -0.008668}}],
    Polygon[{{0.527144, 0.149198, -0.008347},{0.525872, 0.149198, -0.007820},{
      0.526067, 0.147967, -0.007820},{0.527277, 0.148360, -0.008347}}],
    Polygon[{{0.525872, 0.149198, -0.007820},{0.524698, 0.149198, -0.007100},{
      0.524950, 0.147604, -0.007100},{0.526067, 0.147967, -0.007820}}],
    Polygon[{{0.524698, 0.149198, -0.007100},{0.523651, 0.149198, -0.006206},{
      0.523954, 0.147281, -0.006206},{0.524950, 0.147604, -0.007100}}],
    Polygon[{{0.523651, 0.149198, -0.006206},{0.522756, 0.149198, -0.005159},{
      0.523104, 0.147004, -0.005159},{0.523954, 0.147281, -0.006206}}],
    Polygon[{{0.522756, 0.149198, -0.005159},{0.522037, 0.149198, -0.003984},{
      0.522419, 0.146782, -0.003984},{0.523104, 0.147004, -0.005159}}],
    Polygon[{{0.522037, 0.149198, -0.003984},{0.521510, 0.149198, -0.002712},{
      0.521918, 0.146619, -0.002712},{0.522419, 0.146782, -0.003984}}],
    Polygon[{{0.521510, 0.149198, -0.002712},{0.521188, 0.149198, -0.001373},{
      0.521612, 0.146520, -0.001373},{0.521918, 0.146619, -0.002712}}],
    Polygon[{{0.521188, 0.149198, -0.001373},{0.521080, 0.149198, 0.000000},{
      0.521510, 0.146486, 0.000000},{0.521612, 0.146520, -0.001373}}],
    Polygon[{{0.521080, 0.149198, 0.000000},{0.521188, 0.149198, 0.001373},{
      0.521612, 0.146520, 0.001373},{0.521510, 0.146486, 0.000000}}],
    Polygon[{{0.521188, 0.149198, 0.001373},{0.521510, 0.149198, 0.002712},{
      0.521918, 0.146619, 0.002712},{0.521612, 0.146520, 0.001373}}],
    Polygon[{{0.521510, 0.149198, 0.002712},{0.522037, 0.149198, 0.003984},{
      0.522419, 0.146782, 0.003984},{0.521918, 0.146619, 0.002712}}],
    Polygon[{{0.522037, 0.149198, 0.003984},{0.522756, 0.149198, 0.005159},{
      0.523104, 0.147004, 0.005159},{0.522419, 0.146782, 0.003984}}],
    Polygon[{{0.522756, 0.149198, 0.005159},{0.523651, 0.149198, 0.006206},{
      0.523954, 0.147281, 0.006206},{0.523104, 0.147004, 0.005159}}],
    Polygon[{{0.523651, 0.149198, 0.006206},{0.524698, 0.149198, 0.007100},{
      0.524950, 0.147604, 0.007100},{0.523954, 0.147281, 0.006206}}],
    Polygon[{{0.524698, 0.149198, 0.007100},{0.525872, 0.149198, 0.007820},{
      0.526067, 0.147967, 0.007820},{0.524950, 0.147604, 0.007100}}],
    Polygon[{{0.525872, 0.149198, 0.007820},{0.527144, 0.149198, 0.008347},{
      0.527277, 0.148360, 0.008347},{0.526067, 0.147967, 0.007820}}],
    Polygon[{{0.527144, 0.149198, 0.008347},{0.528484, 0.149198, 0.008668},{
      0.528551, 0.148774, 0.008668},{0.527277, 0.148360, 0.008347}}],
    Polygon[{{0.528551, 0.148774, -0.008668},{0.527277, 0.148360, -0.008347},{
      0.527662, 0.147604, -0.008347},{0.528746, 0.148391, -0.008668}}],
    Polygon[{{0.527277, 0.148360, -0.008347},{0.526067, 0.147967, -0.007820},{
      0.526633, 0.146856, -0.007820},{0.527662, 0.147604, -0.008347}}],
    Polygon[{{0.526067, 0.147967, -0.007820},{0.524950, 0.147604, -0.007100},{
      0.525683, 0.146166, -0.007100},{0.526633, 0.146856, -0.007820}}],
    Polygon[{{0.524950, 0.147604, -0.007100},{0.523954, 0.147281, -0.006206},{
      0.524836, 0.145551, -0.006206},{0.525683, 0.146166, -0.007100}}],
    Polygon[{{0.523954, 0.147281, -0.006206},{0.523104, 0.147004, -0.005159},{
      0.524112, 0.145025, -0.005159},{0.524836, 0.145551, -0.006206}}],
    Polygon[{{0.523104, 0.147004, -0.005159},{0.522419, 0.146782, -0.003984},{
      0.523530, 0.144602, -0.003984},{0.524112, 0.145025, -0.005159}}],
    Polygon[{{0.522419, 0.146782, -0.003984},{0.521918, 0.146619, -0.002712},{
      0.523104, 0.144292, -0.002712},{0.523530, 0.144602, -0.003984}}],
    Polygon[{{0.521918, 0.146619, -0.002712},{0.521612, 0.146520, -0.001373},{
      0.522844, 0.144103, -0.001373},{0.523104, 0.144292, -0.002712}}],
    Polygon[{{0.521612, 0.146520, -0.001373},{0.521510, 0.146486, 0.000000},{
      0.522756, 0.144040, 0.000000},{0.522844, 0.144103, -0.001373}}],
    Polygon[{{0.521510, 0.146486, 0.000000},{0.521612, 0.146520, 0.001373},{
      0.522844, 0.144103, 0.001373},{0.522756, 0.144040, 0.000000}}],
    Polygon[{{0.521612, 0.146520, 0.001373},{0.521918, 0.146619, 0.002712},{
      0.523104, 0.144292, 0.002712},{0.522844, 0.144103, 0.001373}}],
    Polygon[{{0.521918, 0.146619, 0.002712},{0.522419, 0.146782, 0.003984},{
      0.523530, 0.144602, 0.003984},{0.523104, 0.144292, 0.002712}}],
    Polygon[{{0.522419, 0.146782, 0.003984},{0.523104, 0.147004, 0.005159},{
      0.524112, 0.145025, 0.005159},{0.523530, 0.144602, 0.003984}}],
    Polygon[{{0.523104, 0.147004, 0.005159},{0.523954, 0.147281, 0.006206},{
      0.524836, 0.145551, 0.006206},{0.524112, 0.145025, 0.005159}}],
    Polygon[{{0.523954, 0.147281, 0.006206},{0.524950, 0.147604, 0.007100},{
      0.525683, 0.146166, 0.007100},{0.524836, 0.145551, 0.006206}}],
    Polygon[{{0.524950, 0.147604, 0.007100},{0.526067, 0.147967, 0.007820},{
      0.526633, 0.146856, 0.007820},{0.525683, 0.146166, 0.007100}}],
    Polygon[{{0.526067, 0.147967, 0.007820},{0.527277, 0.148360, 0.008347},{
      0.527662, 0.147604, 0.008347},{0.526633, 0.146856, 0.007820}}],
    Polygon[{{0.527277, 0.148360, 0.008347},{0.528551, 0.148774, 0.008668},{
      0.528746, 0.148391, 0.008668},{0.527662, 0.147604, 0.008347}}],
    Polygon[{{0.528746, 0.148391, -0.008668},{0.527662, 0.147604, -0.008347},{
      0.528262, 0.147004, -0.008347},{0.529050, 0.148088, -0.008668}}],
    Polygon[{{0.527662, 0.147604, -0.008347},{0.526633, 0.146856, -0.007820},{
      0.527515, 0.145975, -0.007820},{0.528262, 0.147004, -0.008347}}],
    Polygon[{{0.526633, 0.146856, -0.007820},{0.525683, 0.146166, -0.007100},{
      0.526824, 0.145025, -0.007100},{0.527515, 0.145975, -0.007820}}],
    Polygon[{{0.525683, 0.146166, -0.007100},{0.524836, 0.145551, -0.006206},{
      0.526209, 0.144178, -0.006206},{0.526824, 0.145025, -0.007100}}],
    Polygon[{{0.524836, 0.145551, -0.006206},{0.524112, 0.145025, -0.005159},{
      0.525683, 0.143454, -0.005159},{0.526209, 0.144178, -0.006206}}],
    Polygon[{{0.524112, 0.145025, -0.005159},{0.523530, 0.144602, -0.003984},{
      0.525260, 0.142872, -0.003984},{0.525683, 0.143454, -0.005159}}],
    Polygon[{{0.523530, 0.144602, -0.003984},{0.523104, 0.144292, -0.002712},{
      0.524950, 0.142446, -0.002712},{0.525260, 0.142872, -0.003984}}],
    Polygon[{{0.523104, 0.144292, -0.002712},{0.522844, 0.144103, -0.001373},{
      0.524761, 0.142186, -0.001373},{0.524950, 0.142446, -0.002712}}],
    Polygon[{{0.522844, 0.144103, -0.001373},{0.522756, 0.144040, 0.000000},{
      0.524698, 0.142098, 0.000000},{0.524761, 0.142186, -0.001373}}],
    Polygon[{{0.522756, 0.144040, 0.000000},{0.522844, 0.144103, 0.001373},{
      0.524761, 0.142186, 0.001373},{0.524698, 0.142098, 0.000000}}],
    Polygon[{{0.522844, 0.144103, 0.001373},{0.523104, 0.144292, 0.002712},{
      0.524950, 0.142446, 0.002712},{0.524761, 0.142186, 0.001373}}],
    Polygon[{{0.523104, 0.144292, 0.002712},{0.523530, 0.144602, 0.003984},{
      0.525260, 0.142872, 0.003984},{0.524950, 0.142446, 0.002712}}],
    Polygon[{{0.523530, 0.144602, 0.003984},{0.524112, 0.145025, 0.005159},{
      0.525683, 0.143454, 0.005159},{0.525260, 0.142872, 0.003984}}],
    Polygon[{{0.524112, 0.145025, 0.005159},{0.524836, 0.145551, 0.006206},{
      0.526209, 0.144178, 0.006206},{0.525683, 0.143454, 0.005159}}],
    Polygon[{{0.524836, 0.145551, 0.006206},{0.525683, 0.146166, 0.007100},{
      0.526824, 0.145025, 0.007100},{0.526209, 0.144178, 0.006206}}],
    Polygon[{{0.525683, 0.146166, 0.007100},{0.526633, 0.146856, 0.007820},{
      0.527515, 0.145975, 0.007820},{0.526824, 0.145025, 0.007100}}],
    Polygon[{{0.526633, 0.146856, 0.007820},{0.527662, 0.147604, 0.008347},{
      0.528262, 0.147004, 0.008347},{0.527515, 0.145975, 0.007820}}],
    Polygon[{{0.527662, 0.147604, 0.008347},{0.528746, 0.148391, 0.008668},{
      0.529050, 0.148088, 0.008668},{0.528262, 0.147004, 0.008347}}],
    Polygon[{{0.529050, 0.148088, -0.008668},{0.528262, 0.147004, -0.008347},{
      0.529018, 0.146619, -0.008347},{0.529432, 0.147893, -0.008668}}],
    Polygon[{{0.528262, 0.147004, -0.008347},{0.527515, 0.145975, -0.007820},{
      0.528625, 0.145409, -0.007820},{0.529018, 0.146619, -0.008347}}],
    Polygon[{{0.527515, 0.145975, -0.007820},{0.526824, 0.145025, -0.007100},{
      0.528262, 0.144292, -0.007100},{0.528625, 0.145409, -0.007820}}],
    Polygon[{{0.526824, 0.145025, -0.007100},{0.526209, 0.144178, -0.006206},{
      0.527939, 0.143296, -0.006206},{0.528262, 0.144292, -0.007100}}],
    Polygon[{{0.526209, 0.144178, -0.006206},{0.525683, 0.143454, -0.005159},{
      0.527662, 0.142446, -0.005159},{0.527939, 0.143296, -0.006206}}],
    Polygon[{{0.525683, 0.143454, -0.005159},{0.525260, 0.142872, -0.003984},{
      0.527440, 0.141761, -0.003984},{0.527662, 0.142446, -0.005159}}],
    Polygon[{{0.525260, 0.142872, -0.003984},{0.524950, 0.142446, -0.002712},{
      0.527277, 0.141260, -0.002712},{0.527440, 0.141761, -0.003984}}],
    Polygon[{{0.524950, 0.142446, -0.002712},{0.524761, 0.142186, -0.001373},{
      0.527178, 0.140954, -0.001373},{0.527277, 0.141260, -0.002712}}],
    Polygon[{{0.524761, 0.142186, -0.001373},{0.524698, 0.142098, 0.000000},{
      0.527144, 0.140852, 0.000000},{0.527178, 0.140954, -0.001373}}],
    Polygon[{{0.524698, 0.142098, 0.000000},{0.524761, 0.142186, 0.001373},{
      0.527178, 0.140954, 0.001373},{0.527144, 0.140852, 0.000000}}],
    Polygon[{{0.524761, 0.142186, 0.001373},{0.524950, 0.142446, 0.002712},{
      0.527277, 0.141260, 0.002712},{0.527178, 0.140954, 0.001373}}],
    Polygon[{{0.524950, 0.142446, 0.002712},{0.525260, 0.142872, 0.003984},{
      0.527440, 0.141761, 0.003984},{0.527277, 0.141260, 0.002712}}],
    Polygon[{{0.525260, 0.142872, 0.003984},{0.525683, 0.143454, 0.005159},{
      0.527662, 0.142446, 0.005159},{0.527440, 0.141761, 0.003984}}],
    Polygon[{{0.525683, 0.143454, 0.005159},{0.526209, 0.144178, 0.006206},{
      0.527939, 0.143296, 0.006206},{0.527662, 0.142446, 0.005159}}],
    Polygon[{{0.526209, 0.144178, 0.006206},{0.526824, 0.145025, 0.007100},{
      0.528262, 0.144292, 0.007100},{0.527939, 0.143296, 0.006206}}],
    Polygon[{{0.526824, 0.145025, 0.007100},{0.527515, 0.145975, 0.007820},{
      0.528625, 0.145409, 0.007820},{0.528262, 0.144292, 0.007100}}],
    Polygon[{{0.527515, 0.145975, 0.007820},{0.528262, 0.147004, 0.008347},{
      0.529018, 0.146619, 0.008347},{0.528625, 0.145409, 0.007820}}],
    Polygon[{{0.528262, 0.147004, 0.008347},{0.529050, 0.148088, 0.008668},{
      0.529432, 0.147893, 0.008668},{0.529018, 0.146619, 0.008347}}],
    Polygon[{{0.529432, 0.147893, -0.008668},{0.529018, 0.146619, -0.008347},{
      0.529857, 0.146486, -0.008347},{0.529857, 0.147825, -0.008668}}],
    Polygon[{{0.529018, 0.146619, -0.008347},{0.528625, 0.145409, -0.007820},{
      0.529857, 0.145214, -0.007820},{0.529857, 0.146486, -0.008347}}],
    Polygon[{{0.528625, 0.145409, -0.007820},{0.528262, 0.144292, -0.007100},{
      0.529857, 0.144040, -0.007100},{0.529857, 0.145214, -0.007820}}],
    Polygon[{{0.528262, 0.144292, -0.007100},{0.527939, 0.143296, -0.006206},{
      0.529857, 0.142993, -0.006206},{0.529857, 0.144040, -0.007100}}],
    Polygon[{{0.527939, 0.143296, -0.006206},{0.527662, 0.142446, -0.005159},{
      0.529857, 0.142098, -0.005159},{0.529857, 0.142993, -0.006206}}],
    Polygon[{{0.527662, 0.142446, -0.005159},{0.527440, 0.141761, -0.003984},{
      0.529857, 0.141379, -0.003984},{0.529857, 0.142098, -0.005159}}],
    Polygon[{{0.527440, 0.141761, -0.003984},{0.527277, 0.141260, -0.002712},{
      0.529857, 0.140852, -0.002712},{0.529857, 0.141379, -0.003984}}],
    Polygon[{{0.527277, 0.141260, -0.002712},{0.527178, 0.140954, -0.001373},{
      0.529857, 0.140530, -0.001373},{0.529857, 0.140852, -0.002712}}],
    Polygon[{{0.527178, 0.140954, -0.001373},{0.527144, 0.140852, 0.000000},{
      0.529857, 0.140422, 0.000000},{0.529857, 0.140530, -0.001373}}],
    Polygon[{{0.527144, 0.140852, 0.000000},{0.527178, 0.140954, 0.001373},{
      0.529857, 0.140530, 0.001373},{0.529857, 0.140422, 0.000000}}],
    Polygon[{{0.527178, 0.140954, 0.001373},{0.527277, 0.141260, 0.002712},{
      0.529857, 0.140852, 0.002712},{0.529857, 0.140530, 0.001373}}],
    Polygon[{{0.527277, 0.141260, 0.002712},{0.527440, 0.141761, 0.003984},{
      0.529857, 0.141379, 0.003984},{0.529857, 0.140852, 0.002712}}],
    Polygon[{{0.527440, 0.141761, 0.003984},{0.527662, 0.142446, 0.005159},{
      0.529857, 0.142098, 0.005159},{0.529857, 0.141379, 0.003984}}],
    Polygon[{{0.527662, 0.142446, 0.005159},{0.527939, 0.143296, 0.006206},{
      0.529857, 0.142993, 0.006206},{0.529857, 0.142098, 0.005159}}],
    Polygon[{{0.527939, 0.143296, 0.006206},{0.528262, 0.144292, 0.007100},{
      0.529857, 0.144040, 0.007100},{0.529857, 0.142993, 0.006206}}],
    Polygon[{{0.528262, 0.144292, 0.007100},{0.528625, 0.145409, 0.007820},{
      0.529857, 0.145214, 0.007820},{0.529857, 0.144040, 0.007100}}],
    Polygon[{{0.528625, 0.145409, 0.007820},{0.529018, 0.146619, 0.008347},{
      0.529857, 0.146486, 0.008347},{0.529857, 0.145214, 0.007820}}],
    Polygon[{{0.529018, 0.146619, 0.008347},{0.529432, 0.147893, 0.008668},{
      0.529857, 0.147825, 0.008668},{0.529857, 0.146486, 0.008347}}],
    Polygon[{{0.529857, 0.147825, -0.008668},{0.529857, 0.146486, -0.008347},{
      0.530695, 0.146619, -0.008347},{0.530281, 0.147893, -0.008668}}],
    Polygon[{{0.529857, 0.146486, -0.008347},{0.529857, 0.145214, -0.007820},{
      0.531088, 0.145409, -0.007820},{0.530695, 0.146619, -0.008347}}],
    Polygon[{{0.529857, 0.145214, -0.007820},{0.529857, 0.144040, -0.007100},{
      0.531451, 0.144292, -0.007100},{0.531088, 0.145409, -0.007820}}],
    Polygon[{{0.529857, 0.144040, -0.007100},{0.529857, 0.142993, -0.006206},{
      0.531774, 0.143296, -0.006206},{0.531451, 0.144292, -0.007100}}],
    Polygon[{{0.529857, 0.142993, -0.006206},{0.529857, 0.142098, -0.005159},{
      0.532051, 0.142446, -0.005159},{0.531774, 0.143296, -0.006206}}],
    Polygon[{{0.529857, 0.142098, -0.005159},{0.529857, 0.141379, -0.003984},{
      0.532273, 0.141761, -0.003984},{0.532051, 0.142446, -0.005159}}],
    Polygon[{{0.529857, 0.141379, -0.003984},{0.529857, 0.140852, -0.002712},{
      0.532436, 0.141260, -0.002712},{0.532273, 0.141761, -0.003984}}],
    Polygon[{{0.529857, 0.140852, -0.002712},{0.529857, 0.140530, -0.001373},{
      0.532535, 0.140954, -0.001373},{0.532436, 0.141260, -0.002712}}],
    Polygon[{{0.529857, 0.140530, -0.001373},{0.529857, 0.140422, 0.000000},{
      0.532569, 0.140852, 0.000000},{0.532535, 0.140954, -0.001373}}],
    Polygon[{{0.529857, 0.140422, 0.000000},{0.529857, 0.140530, 0.001373},{
      0.532535, 0.140954, 0.001373},{0.532569, 0.140852, 0.000000}}],
    Polygon[{{0.529857, 0.140530, 0.001373},{0.529857, 0.140852, 0.002712},{
      0.532436, 0.141260, 0.002712},{0.532535, 0.140954, 0.001373}}],
    Polygon[{{0.529857, 0.140852, 0.002712},{0.529857, 0.141379, 0.003984},{
      0.532273, 0.141761, 0.003984},{0.532436, 0.141260, 0.002712}}],
    Polygon[{{0.529857, 0.141379, 0.003984},{0.529857, 0.142098, 0.005159},{
      0.532051, 0.142446, 0.005159},{0.532273, 0.141761, 0.003984}}],
    Polygon[{{0.529857, 0.142098, 0.005159},{0.529857, 0.142993, 0.006206},{
      0.531774, 0.143296, 0.006206},{0.532051, 0.142446, 0.005159}}],
    Polygon[{{0.529857, 0.142993, 0.006206},{0.529857, 0.144040, 0.007100},{
      0.531451, 0.144292, 0.007100},{0.531774, 0.143296, 0.006206}}],
    Polygon[{{0.529857, 0.144040, 0.007100},{0.529857, 0.145214, 0.007820},{
      0.531088, 0.145409, 0.007820},{0.531451, 0.144292, 0.007100}}],
    Polygon[{{0.529857, 0.145214, 0.007820},{0.529857, 0.146486, 0.008347},{
      0.530695, 0.146619, 0.008347},{0.531088, 0.145409, 0.007820}}],
    Polygon[{{0.529857, 0.146486, 0.008347},{0.529857, 0.147825, 0.008668},{
      0.530281, 0.147893, 0.008668},{0.530695, 0.146619, 0.008347}}],
    Polygon[{{0.530281, 0.147893, -0.008668},{0.530695, 0.146619, -0.008347},{
      0.531451, 0.147004, -0.008347},{0.530664, 0.148088, -0.008668}}],
    Polygon[{{0.530695, 0.146619, -0.008347},{0.531088, 0.145409, -0.007820},{
      0.532198, 0.145975, -0.007820},{0.531451, 0.147004, -0.008347}}],
    Polygon[{{0.531088, 0.145409, -0.007820},{0.531451, 0.144292, -0.007100},{
      0.532889, 0.145025, -0.007100},{0.532198, 0.145975, -0.007820}}],
    Polygon[{{0.531451, 0.144292, -0.007100},{0.531774, 0.143296, -0.006206},{
      0.533504, 0.144178, -0.006206},{0.532889, 0.145025, -0.007100}}],
    Polygon[{{0.531774, 0.143296, -0.006206},{0.532051, 0.142446, -0.005159},{
      0.534030, 0.143454, -0.005159},{0.533504, 0.144178, -0.006206}}],
    Polygon[{{0.532051, 0.142446, -0.005159},{0.532273, 0.141761, -0.003984},{
      0.534453, 0.142872, -0.003984},{0.534030, 0.143454, -0.005159}}],
    Polygon[{{0.532273, 0.141761, -0.003984},{0.532436, 0.141260, -0.002712},{
      0.534763, 0.142446, -0.002712},{0.534453, 0.142872, -0.003984}}],
    Polygon[{{0.532436, 0.141260, -0.002712},{0.532535, 0.140954, -0.001373},{
      0.534952, 0.142186, -0.001373},{0.534763, 0.142446, -0.002712}}],
    Polygon[{{0.532535, 0.140954, -0.001373},{0.532569, 0.140852, 0.000000},{
      0.535015, 0.142098, 0.000000},{0.534952, 0.142186, -0.001373}}],
    Polygon[{{0.532569, 0.140852, 0.000000},{0.532535, 0.140954, 0.001373},{
      0.534952, 0.142186, 0.001373},{0.535015, 0.142098, 0.000000}}],
    Polygon[{{0.532535, 0.140954, 0.001373},{0.532436, 0.141260, 0.002712},{
      0.534763, 0.142446, 0.002712},{0.534952, 0.142186, 0.001373}}],
    Polygon[{{0.532436, 0.141260, 0.002712},{0.532273, 0.141761, 0.003984},{
      0.534453, 0.142872, 0.003984},{0.534763, 0.142446, 0.002712}}],
    Polygon[{{0.532273, 0.141761, 0.003984},{0.532051, 0.142446, 0.005159},{
      0.534030, 0.143454, 0.005159},{0.534453, 0.142872, 0.003984}}],
    Polygon[{{0.532051, 0.142446, 0.005159},{0.531774, 0.143296, 0.006206},{
      0.533504, 0.144178, 0.006206},{0.534030, 0.143454, 0.005159}}],
    Polygon[{{0.531774, 0.143296, 0.006206},{0.531451, 0.144292, 0.007100},{
      0.532889, 0.145025, 0.007100},{0.533504, 0.144178, 0.006206}}],
    Polygon[{{0.531451, 0.144292, 0.007100},{0.531088, 0.145409, 0.007820},{
      0.532198, 0.145975, 0.007820},{0.532889, 0.145025, 0.007100}}],
    Polygon[{{0.531088, 0.145409, 0.007820},{0.530695, 0.146619, 0.008347},{
      0.531451, 0.147004, 0.008347},{0.532198, 0.145975, 0.007820}}],
    Polygon[{{0.530695, 0.146619, 0.008347},{0.530281, 0.147893, 0.008668},{
      0.530664, 0.148088, 0.008668},{0.531451, 0.147004, 0.008347}}],
    Polygon[{{0.530664, 0.148088, -0.008668},{0.531451, 0.147004, -0.008347},{
      0.532051, 0.147604, -0.008347},{0.530967, 0.148391, -0.008668}}],
    Polygon[{{0.531451, 0.147004, -0.008347},{0.532198, 0.145975, -0.007820},{
      0.533080, 0.146856, -0.007820},{0.532051, 0.147604, -0.008347}}],
    Polygon[{{0.532198, 0.145975, -0.007820},{0.532889, 0.145025, -0.007100},{
      0.534030, 0.146166, -0.007100},{0.533080, 0.146856, -0.007820}}],
    Polygon[{{0.532889, 0.145025, -0.007100},{0.533504, 0.144178, -0.006206},{
      0.534877, 0.145551, -0.006206},{0.534030, 0.146166, -0.007100}}],
    Polygon[{{0.533504, 0.144178, -0.006206},{0.534030, 0.143454, -0.005159},{
      0.535601, 0.145025, -0.005159},{0.534877, 0.145551, -0.006206}}],
    Polygon[{{0.534030, 0.143454, -0.005159},{0.534453, 0.142872, -0.003984},{
      0.536183, 0.144602, -0.003984},{0.535601, 0.145025, -0.005159}}],
    Polygon[{{0.534453, 0.142872, -0.003984},{0.534763, 0.142446, -0.002712},{
      0.536609, 0.144292, -0.002712},{0.536183, 0.144602, -0.003984}}],
    Polygon[{{0.534763, 0.142446, -0.002712},{0.534952, 0.142186, -0.001373},{
      0.536869, 0.144103, -0.001373},{0.536609, 0.144292, -0.002712}}],
    Polygon[{{0.534952, 0.142186, -0.001373},{0.535015, 0.142098, 0.000000},{
      0.536957, 0.144040, 0.000000},{0.536869, 0.144103, -0.001373}}],
    Polygon[{{0.535015, 0.142098, 0.000000},{0.534952, 0.142186, 0.001373},{
      0.536869, 0.144103, 0.001373},{0.536957, 0.144040, 0.000000}}],
    Polygon[{{0.534952, 0.142186, 0.001373},{0.534763, 0.142446, 0.002712},{
      0.536609, 0.144292, 0.002712},{0.536869, 0.144103, 0.001373}}],
    Polygon[{{0.534763, 0.142446, 0.002712},{0.534453, 0.142872, 0.003984},{
      0.536183, 0.144602, 0.003984},{0.536609, 0.144292, 0.002712}}],
    Polygon[{{0.534453, 0.142872, 0.003984},{0.534030, 0.143454, 0.005159},{
      0.535601, 0.145025, 0.005159},{0.536183, 0.144602, 0.003984}}],
    Polygon[{{0.534030, 0.143454, 0.005159},{0.533504, 0.144178, 0.006206},{
      0.534877, 0.145551, 0.006206},{0.535601, 0.145025, 0.005159}}],
    Polygon[{{0.533504, 0.144178, 0.006206},{0.532889, 0.145025, 0.007100},{
      0.534030, 0.146166, 0.007100},{0.534877, 0.145551, 0.006206}}],
    Polygon[{{0.532889, 0.145025, 0.007100},{0.532198, 0.145975, 0.007820},{
      0.533080, 0.146856, 0.007820},{0.534030, 0.146166, 0.007100}}],
    Polygon[{{0.532198, 0.145975, 0.007820},{0.531451, 0.147004, 0.008347},{
      0.532051, 0.147604, 0.008347},{0.533080, 0.146856, 0.007820}}],
    Polygon[{{0.531451, 0.147004, 0.008347},{0.530664, 0.148088, 0.008668},{
      0.530967, 0.148391, 0.008668},{0.532051, 0.147604, 0.008347}}],
    Polygon[{{0.530967, 0.148391, -0.008668},{0.532051, 0.147604, -0.008347},{
      0.532436, 0.148360, -0.008347},{0.531162, 0.148774, -0.008668}}],
    Polygon[{{0.532051, 0.147604, -0.008347},{0.533080, 0.146856, -0.007820},{
      0.533646, 0.147967, -0.007820},{0.532436, 0.148360, -0.008347}}],
    Polygon[{{0.533080, 0.146856, -0.007820},{0.534030, 0.146166, -0.007100},{
      0.534763, 0.147604, -0.007100},{0.533646, 0.147967, -0.007820}}],
    Polygon[{{0.534030, 0.146166, -0.007100},{0.534877, 0.145551, -0.006206},{
      0.535759, 0.147281, -0.006206},{0.534763, 0.147604, -0.007100}}],
    Polygon[{{0.534877, 0.145551, -0.006206},{0.535601, 0.145025, -0.005159},{
      0.536609, 0.147004, -0.005159},{0.535759, 0.147281, -0.006206}}],
    Polygon[{{0.535601, 0.145025, -0.005159},{0.536183, 0.144602, -0.003984},{
      0.537294, 0.146782, -0.003984},{0.536609, 0.147004, -0.005159}}],
    Polygon[{{0.536183, 0.144602, -0.003984},{0.536609, 0.144292, -0.002712},{
      0.537795, 0.146619, -0.002712},{0.537294, 0.146782, -0.003984}}],
    Polygon[{{0.536609, 0.144292, -0.002712},{0.536869, 0.144103, -0.001373},{
      0.538101, 0.146520, -0.001373},{0.537795, 0.146619, -0.002712}}],
    Polygon[{{0.536869, 0.144103, -0.001373},{0.536957, 0.144040, 0.000000},{
      0.538203, 0.146486, 0.000000},{0.538101, 0.146520, -0.001373}}],
    Polygon[{{0.536957, 0.144040, 0.000000},{0.536869, 0.144103, 0.001373},{
      0.538101, 0.146520, 0.001373},{0.538203, 0.146486, 0.000000}}],
    Polygon[{{0.536869, 0.144103, 0.001373},{0.536609, 0.144292, 0.002712},{
      0.537795, 0.146619, 0.002712},{0.538101, 0.146520, 0.001373}}],
    Polygon[{{0.536609, 0.144292, 0.002712},{0.536183, 0.144602, 0.003984},{
      0.537294, 0.146782, 0.003984},{0.537795, 0.146619, 0.002712}}],
    Polygon[{{0.536183, 0.144602, 0.003984},{0.535601, 0.145025, 0.005159},{
      0.536609, 0.147004, 0.005159},{0.537294, 0.146782, 0.003984}}],
    Polygon[{{0.535601, 0.145025, 0.005159},{0.534877, 0.145551, 0.006206},{
      0.535759, 0.147281, 0.006206},{0.536609, 0.147004, 0.005159}}],
    Polygon[{{0.534877, 0.145551, 0.006206},{0.534030, 0.146166, 0.007100},{
      0.534763, 0.147604, 0.007100},{0.535759, 0.147281, 0.006206}}],
    Polygon[{{0.534030, 0.146166, 0.007100},{0.533080, 0.146856, 0.007820},{
      0.533646, 0.147967, 0.007820},{0.534763, 0.147604, 0.007100}}],
    Polygon[{{0.533080, 0.146856, 0.007820},{0.532051, 0.147604, 0.008347},{
      0.532436, 0.148360, 0.008347},{0.533646, 0.147967, 0.007820}}],
    Polygon[{{0.532051, 0.147604, 0.008347},{0.530967, 0.148391, 0.008668},{
      0.531162, 0.148774, 0.008668},{0.532436, 0.148360, 0.008347}}],
    Polygon[{{0.531162, 0.148774, -0.008668},{0.532436, 0.148360, -0.008347},{
      0.532569, 0.149198, -0.008347},{0.531229, 0.149198, -0.008668}}],
    Polygon[{{0.532436, 0.148360, -0.008347},{0.533646, 0.147967, -0.007820},{
      0.533841, 0.149198, -0.007820},{0.532569, 0.149198, -0.008347}}],
    Polygon[{{0.533646, 0.147967, -0.007820},{0.534763, 0.147604, -0.007100},{
      0.535015, 0.149198, -0.007100},{0.533841, 0.149198, -0.007820}}],
    Polygon[{{0.534763, 0.147604, -0.007100},{0.535759, 0.147281, -0.006206},{
      0.536062, 0.149198, -0.006206},{0.535015, 0.149198, -0.007100}}],
    Polygon[{{0.535759, 0.147281, -0.006206},{0.536609, 0.147004, -0.005159},{
      0.536957, 0.149198, -0.005159},{0.536062, 0.149198, -0.006206}}],
    Polygon[{{0.536609, 0.147004, -0.005159},{0.537294, 0.146782, -0.003984},{
      0.537676, 0.149198, -0.003984},{0.536957, 0.149198, -0.005159}}],
    Polygon[{{0.537294, 0.146782, -0.003984},{0.537795, 0.146619, -0.002712},{
      0.538203, 0.149198, -0.002712},{0.537676, 0.149198, -0.003984}}],
    Polygon[{{0.537795, 0.146619, -0.002712},{0.538101, 0.146520, -0.001373},{
      0.538525, 0.149198, -0.001373},{0.538203, 0.149198, -0.002712}}],
    Polygon[{{0.538101, 0.146520, -0.001373},{0.538203, 0.146486, 0.000000},{
      0.538633, 0.149198, 0.000000},{0.538525, 0.149198, -0.001373}}],
    Polygon[{{0.538203, 0.146486, 0.000000},{0.538101, 0.146520, 0.001373},{
      0.538525, 0.149198, 0.001373},{0.538633, 0.149198, 0.000000}}],
    Polygon[{{0.538101, 0.146520, 0.001373},{0.537795, 0.146619, 0.002712},{
      0.538203, 0.149198, 0.002712},{0.538525, 0.149198, 0.001373}}],
    Polygon[{{0.537795, 0.146619, 0.002712},{0.537294, 0.146782, 0.003984},{
      0.537676, 0.149198, 0.003984},{0.538203, 0.149198, 0.002712}}],
    Polygon[{{0.537294, 0.146782, 0.003984},{0.536609, 0.147004, 0.005159},{
      0.536957, 0.149198, 0.005159},{0.537676, 0.149198, 0.003984}}],
    Polygon[{{0.536609, 0.147004, 0.005159},{0.535759, 0.147281, 0.006206},{
      0.536062, 0.149198, 0.006206},{0.536957, 0.149198, 0.005159}}],
    Polygon[{{0.535759, 0.147281, 0.006206},{0.534763, 0.147604, 0.007100},{
      0.535015, 0.149198, 0.007100},{0.536062, 0.149198, 0.006206}}],
    Polygon[{{0.534763, 0.147604, 0.007100},{0.533646, 0.147967, 0.007820},{
      0.533841, 0.149198, 0.007820},{0.535015, 0.149198, 0.007100}}],
    Polygon[{{0.533646, 0.147967, 0.007820},{0.532436, 0.148360, 0.008347},{
      0.532569, 0.149198, 0.008347},{0.533841, 0.149198, 0.007820}}],
    Polygon[{{0.532436, 0.148360, 0.008347},{0.531162, 0.148774, 0.008668},{
      0.531229, 0.149198, 0.008668},{0.532569, 0.149198, 0.008347}}],
    Polygon[{{0.367763, 0.461325, -0.076398},{0.379565, 0.461325, -0.073564},{
      0.378395, 0.468711, -0.073564},{0.367170, 0.465064, -0.076398}}],
    Polygon[{{0.379565, 0.461325, -0.073564},{0.390779, 0.461325, -0.068920},{
      0.389060, 0.472176, -0.068920},{0.378395, 0.468711, -0.073564}}],
    Polygon[{{0.390779, 0.461325, -0.068920},{0.401128, 0.461325, -0.062578},{
      0.398903, 0.475374, -0.062578},{0.389060, 0.472176, -0.068920}}],
    Polygon[{{0.401128, 0.461325, -0.062578},{0.410357, 0.461325, -0.054695},{
      0.407680, 0.478227, -0.054695},{0.398903, 0.475374, -0.062578}}],
    Polygon[{{0.410357, 0.461325, -0.054695},{0.418240, 0.461325, -0.045465},{
      0.415177, 0.480662, -0.045465},{0.407680, 0.478227, -0.054695}}],
    Polygon[{{0.418240, 0.461325, -0.045465},{0.424582, 0.461325, -0.035116},{
      0.421209, 0.482622, -0.035116},{0.415177, 0.480662, -0.045465}}],
    Polygon[{{0.424582, 0.461325, -0.035116},{0.429227, 0.461325, -0.023903},{
      0.425626, 0.484058, -0.023903},{0.421209, 0.482622, -0.035116}}],
    Polygon[{{0.429227, 0.461325, -0.023903},{0.432060, 0.461325, -0.012100},{
      0.428321, 0.484933, -0.012100},{0.425626, 0.484058, -0.023903}}],
    Polygon[{{0.432060, 0.461325, -0.012100},{0.433013, 0.461325, 0.000000},{
      0.429227, 0.485227, 0.000000},{0.428321, 0.484933, -0.012100}}],
    Polygon[{{0.433013, 0.461325, 0.000000},{0.432060, 0.461325, 0.012100},{
      0.428321, 0.484933, 0.012100},{0.429227, 0.485227, 0.000000}}],
    Polygon[{{0.432060, 0.461325, 0.012100},{0.429227, 0.461325, 0.023903},{
      0.425626, 0.484058, 0.023903},{0.428321, 0.484933, 0.012100}}],
    Polygon[{{0.429227, 0.461325, 0.023903},{0.424582, 0.461325, 0.035116},{
      0.421209, 0.482622, 0.035116},{0.425626, 0.484058, 0.023903}}],
    Polygon[{{0.424582, 0.461325, 0.035116},{0.418240, 0.461325, 0.045465},{
      0.415177, 0.480662, 0.045465},{0.421209, 0.482622, 0.035116}}],
    Polygon[{{0.418240, 0.461325, 0.045465},{0.410357, 0.461325, 0.054695},{
      0.407680, 0.478227, 0.054695},{0.415177, 0.480662, 0.045465}}],
    Polygon[{{0.410357, 0.461325, 0.054695},{0.401128, 0.461325, 0.062578},{
      0.398903, 0.475374, 0.062578},{0.407680, 0.478227, 0.054695}}],
    Polygon[{{0.401128, 0.461325, 0.062578},{0.390779, 0.461325, 0.068920},{
      0.389060, 0.472176, 0.068920},{0.398903, 0.475374, 0.062578}}],
    Polygon[{{0.390779, 0.461325, 0.068920},{0.379565, 0.461325, 0.073564},{
      0.378395, 0.468711, 0.073564},{0.389060, 0.472176, 0.068920}}],
    Polygon[{{0.379565, 0.461325, 0.073564},{0.367763, 0.461325, 0.076398},{
      0.367170, 0.465064, 0.076398},{0.378395, 0.468711, 0.073564}}],
    Polygon[{{0.367170, 0.465064, -0.076398},{0.378395, 0.468711, -0.073564},{
      0.375000, 0.475374, -0.073564},{0.365452, 0.468437, -0.076398}}],
    Polygon[{{0.378395, 0.468711, -0.073564},{0.389060, 0.472176, -0.068920},{
      0.384072, 0.481966, -0.068920},{0.375000, 0.475374, -0.073564}}],
    Polygon[{{0.389060, 0.472176, -0.068920},{0.398903, 0.475374, -0.062578},{
      0.392445, 0.488049, -0.062578},{0.384072, 0.481966, -0.068920}}],
    Polygon[{{0.398903, 0.475374, -0.062578},{0.407680, 0.478227, -0.054695},{
      0.399912, 0.493474, -0.054695},{0.392445, 0.488049, -0.062578}}],
    Polygon[{{0.407680, 0.478227, -0.054695},{0.415177, 0.480662, -0.045465},{
      0.406289, 0.498107, -0.045465},{0.399912, 0.493474, -0.054695}}],
    Polygon[{{0.415177, 0.480662, -0.045465},{0.421209, 0.482622, -0.035116},{
      0.411420, 0.501835, -0.035116},{0.406289, 0.498107, -0.045465}}],
    Polygon[{{0.421209, 0.482622, -0.035116},{0.425626, 0.484058, -0.023903},{
      0.415177, 0.504565, -0.023903},{0.411420, 0.501835, -0.035116}}],
    Polygon[{{0.425626, 0.484058, -0.023903},{0.428321, 0.484933, -0.012100},{
      0.417470, 0.506230, -0.012100},{0.415177, 0.504565, -0.023903}}],
    Polygon[{{0.428321, 0.484933, -0.012100},{0.429227, 0.485227, 0.000000},{
      0.418240, 0.506790, 0.000000},{0.417470, 0.506230, -0.012100}}],
    Polygon[{{0.429227, 0.485227, 0.000000},{0.428321, 0.484933, 0.012100},{
      0.417470, 0.506230, 0.012100},{0.418240, 0.506790, 0.000000}}],
    Polygon[{{0.428321, 0.484933, 0.012100},{0.425626, 0.484058, 0.023903},{
      0.415177, 0.504565, 0.023903},{0.417470, 0.506230, 0.012100}}],
    Polygon[{{0.425626, 0.484058, 0.023903},{0.421209, 0.482622, 0.035116},{
      0.411420, 0.501835, 0.035116},{0.415177, 0.504565, 0.023903}}],
    Polygon[{{0.421209, 0.482622, 0.035116},{0.415177, 0.480662, 0.045465},{
      0.406289, 0.498107, 0.045465},{0.411420, 0.501835, 0.035116}}],
    Polygon[{{0.415177, 0.480662, 0.045465},{0.407680, 0.478227, 0.054695},{
      0.399912, 0.493474, 0.054695},{0.406289, 0.498107, 0.045465}}],
    Polygon[{{0.407680, 0.478227, 0.054695},{0.398903, 0.475374, 0.062578},{
      0.392445, 0.488049, 0.062578},{0.399912, 0.493474, 0.054695}}],
    Polygon[{{0.398903, 0.475374, 0.062578},{0.389060, 0.472176, 0.068920},{
      0.384072, 0.481966, 0.068920},{0.392445, 0.488049, 0.062578}}],
    Polygon[{{0.389060, 0.472176, 0.068920},{0.378395, 0.468711, 0.073564},{
      0.375000, 0.475374, 0.073564},{0.384072, 0.481966, 0.068920}}],
    Polygon[{{0.378395, 0.468711, 0.073564},{0.367170, 0.465064, 0.076398},{
      0.365452, 0.468437, 0.076398},{0.375000, 0.475374, 0.073564}}],
    Polygon[{{0.365452, 0.468437, -0.076398},{0.375000, 0.475374, -0.073564},{
      0.369712, 0.480662, -0.073564},{0.362775, 0.471114, -0.076398}}],
    Polygon[{{0.375000, 0.475374, -0.073564},{0.384072, 0.481966, -0.068920},{
      0.376303, 0.489735, -0.068920},{0.369712, 0.480662, -0.073564}}],
    Polygon[{{0.384072, 0.481966, -0.068920},{0.392445, 0.488049, -0.062578},{
      0.382386, 0.498107, -0.062578},{0.376303, 0.489735, -0.068920}}],
    Polygon[{{0.392445, 0.488049, -0.062578},{0.399912, 0.493474, -0.054695},{
      0.387811, 0.505574, -0.054695},{0.382386, 0.498107, -0.062578}}],
    Polygon[{{0.399912, 0.493474, -0.054695},{0.406289, 0.498107, -0.045465},{
      0.392445, 0.511951, -0.045465},{0.387811, 0.505574, -0.054695}}],
    Polygon[{{0.406289, 0.498107, -0.045465},{0.411420, 0.501835, -0.035116},{
      0.396172, 0.517082, -0.035116},{0.392445, 0.511951, -0.045465}}],
    Polygon[{{0.411420, 0.501835, -0.035116},{0.415177, 0.504565, -0.023903},{
      0.398903, 0.520840, -0.023903},{0.396172, 0.517082, -0.035116}}],
    Polygon[{{0.415177, 0.504565, -0.023903},{0.417470, 0.506230, -0.012100},{
      0.400568, 0.523132, -0.012100},{0.398903, 0.520840, -0.023903}}],
    Polygon[{{0.417470, 0.506230, -0.012100},{0.418240, 0.506790, 0.000000},{
      0.401128, 0.523903, 0.000000},{0.400568, 0.523132, -0.012100}}],
    Polygon[{{0.418240, 0.506790, 0.000000},{0.417470, 0.506230, 0.012100},{
      0.400568, 0.523132, 0.012100},{0.401128, 0.523903, 0.000000}}],
    Polygon[{{0.417470, 0.506230, 0.012100},{0.415177, 0.504565, 0.023903},{
      0.398903, 0.520840, 0.023903},{0.400568, 0.523132, 0.012100}}],
    Polygon[{{0.415177, 0.504565, 0.023903},{0.411420, 0.501835, 0.035116},{
      0.396172, 0.517082, 0.035116},{0.398903, 0.520840, 0.023903}}],
    Polygon[{{0.411420, 0.501835, 0.035116},{0.406289, 0.498107, 0.045465},{
      0.392445, 0.511951, 0.045465},{0.396172, 0.517082, 0.035116}}],
    Polygon[{{0.406289, 0.498107, 0.045465},{0.399912, 0.493474, 0.054695},{
      0.387811, 0.505574, 0.054695},{0.392445, 0.511951, 0.045465}}],
    Polygon[{{0.399912, 0.493474, 0.054695},{0.392445, 0.488049, 0.062578},{
      0.382386, 0.498107, 0.062578},{0.387811, 0.505574, 0.054695}}],
    Polygon[{{0.392445, 0.488049, 0.062578},{0.384072, 0.481966, 0.068920},{
      0.376303, 0.489735, 0.068920},{0.382386, 0.498107, 0.062578}}],
    Polygon[{{0.384072, 0.481966, 0.068920},{0.375000, 0.475374, 0.073564},{
      0.369712, 0.480662, 0.073564},{0.376303, 0.489735, 0.068920}}],
    Polygon[{{0.375000, 0.475374, 0.073564},{0.365452, 0.468437, 0.076398},{
      0.362775, 0.471114, 0.076398},{0.369712, 0.480662, 0.073564}}],
    Polygon[{{0.362775, 0.471114, -0.076398},{0.369712, 0.480662, -0.073564},{
      0.363049, 0.484058, -0.073564},{0.359402, 0.472833, -0.076398}}],
    Polygon[{{0.369712, 0.480662, -0.073564},{0.376303, 0.489735, -0.068920},{
      0.366514, 0.494722, -0.068920},{0.363049, 0.484058, -0.073564}}],
    Polygon[{{0.376303, 0.489735, -0.068920},{0.382386, 0.498107, -0.062578},{
      0.369712, 0.504565, -0.062578},{0.366514, 0.494722, -0.068920}}],
    Polygon[{{0.382386, 0.498107, -0.062578},{0.387811, 0.505574, -0.054695},{
      0.372564, 0.513343, -0.054695},{0.369712, 0.504565, -0.062578}}],
    Polygon[{{0.387811, 0.505574, -0.054695},{0.392445, 0.511951, -0.045465},{
      0.375000, 0.520840, -0.045465},{0.372564, 0.513343, -0.054695}}],
    Polygon[{{0.392445, 0.511951, -0.045465},{0.396172, 0.517082, -0.035116},{
      0.376960, 0.526871, -0.035116},{0.375000, 0.520840, -0.045465}}],
    Polygon[{{0.396172, 0.517082, -0.035116},{0.398903, 0.520840, -0.023903},{
      0.378395, 0.531289, -0.023903},{0.376960, 0.526871, -0.035116}}],
    Polygon[{{0.398903, 0.520840, -0.023903},{0.400568, 0.523132, -0.012100},{
      0.379271, 0.533984, -0.012100},{0.378395, 0.531289, -0.023903}}],
    Polygon[{{0.400568, 0.523132, -0.012100},{0.401128, 0.523903, 0.000000},{
      0.379565, 0.534889, 0.000000},{0.379271, 0.533984, -0.012100}}],
    Polygon[{{0.401128, 0.523903, 0.000000},{0.400568, 0.523132, 0.012100},{
      0.379271, 0.533984, 0.012100},{0.379565, 0.534889, 0.000000}}],
    Polygon[{{0.400568, 0.523132, 0.012100},{0.398903, 0.520840, 0.023903},{
      0.378395, 0.531289, 0.023903},{0.379271, 0.533984, 0.012100}}],
    Polygon[{{0.398903, 0.520840, 0.023903},{0.396172, 0.517082, 0.035116},{
      0.376960, 0.526871, 0.035116},{0.378395, 0.531289, 0.023903}}],
    Polygon[{{0.396172, 0.517082, 0.035116},{0.392445, 0.511951, 0.045465},{
      0.375000, 0.520840, 0.045465},{0.376960, 0.526871, 0.035116}}],
    Polygon[{{0.392445, 0.511951, 0.045465},{0.387811, 0.505574, 0.054695},{
      0.372564, 0.513343, 0.054695},{0.375000, 0.520840, 0.045465}}],
    Polygon[{{0.387811, 0.505574, 0.054695},{0.382386, 0.498107, 0.062578},{
      0.369712, 0.504565, 0.062578},{0.372564, 0.513343, 0.054695}}],
    Polygon[{{0.382386, 0.498107, 0.062578},{0.376303, 0.489735, 0.068920},{
      0.366514, 0.494722, 0.068920},{0.369712, 0.504565, 0.062578}}],
    Polygon[{{0.376303, 0.489735, 0.068920},{0.369712, 0.480662, 0.073564},{
      0.363049, 0.484058, 0.073564},{0.366514, 0.494722, 0.068920}}],
    Polygon[{{0.369712, 0.480662, 0.073564},{0.362775, 0.471114, 0.076398},{
      0.359402, 0.472833, 0.076398},{0.363049, 0.484058, 0.073564}}],
    Polygon[{{0.359402, 0.472833, -0.076398},{0.363049, 0.484058, -0.073564},{
      0.355662, 0.485227, -0.073564},{0.355662, 0.473425, -0.076398}}],
    Polygon[{{0.363049, 0.484058, -0.073564},{0.366514, 0.494722, -0.068920},{
      0.355662, 0.496441, -0.068920},{0.355662, 0.485227, -0.073564}}],
    Polygon[{{0.366514, 0.494722, -0.068920},{0.369712, 0.504565, -0.062578},{
      0.355662, 0.506790, -0.062578},{0.355662, 0.496441, -0.068920}}],
    Polygon[{{0.369712, 0.504565, -0.062578},{0.372564, 0.513343, -0.054695},{
      0.355662, 0.516020, -0.054695},{0.355662, 0.506790, -0.062578}}],
    Polygon[{{0.372564, 0.513343, -0.054695},{0.375000, 0.520840, -0.045465},{
      0.355662, 0.523903, -0.045465},{0.355662, 0.516020, -0.054695}}],
    Polygon[{{0.375000, 0.520840, -0.045465},{0.376960, 0.526871, -0.035116},{
      0.355662, 0.530244, -0.035116},{0.355662, 0.523903, -0.045465}}],
    Polygon[{{0.376960, 0.526871, -0.035116},{0.378395, 0.531289, -0.023903},{
      0.355662, 0.534889, -0.023903},{0.355662, 0.530244, -0.035116}}],
    Polygon[{{0.378395, 0.531289, -0.023903},{0.379271, 0.533984, -0.012100},{
      0.355662, 0.537723, -0.012100},{0.355662, 0.534889, -0.023903}}],
    Polygon[{{0.379271, 0.533984, -0.012100},{0.379565, 0.534889, 0.000000},{
      0.355662, 0.538675, 0.000000},{0.355662, 0.537723, -0.012100}}],
    Polygon[{{0.379565, 0.534889, 0.000000},{0.379271, 0.533984, 0.012100},{
      0.355662, 0.537723, 0.012100},{0.355662, 0.538675, 0.000000}}],
    Polygon[{{0.379271, 0.533984, 0.012100},{0.378395, 0.531289, 0.023903},{
      0.355662, 0.534889, 0.023903},{0.355662, 0.537723, 0.012100}}],
    Polygon[{{0.378395, 0.531289, 0.023903},{0.376960, 0.526871, 0.035116},{
      0.355662, 0.530244, 0.035116},{0.355662, 0.534889, 0.023903}}],
    Polygon[{{0.376960, 0.526871, 0.035116},{0.375000, 0.520840, 0.045465},{
      0.355662, 0.523903, 0.045465},{0.355662, 0.530244, 0.035116}}],
    Polygon[{{0.375000, 0.520840, 0.045465},{0.372564, 0.513343, 0.054695},{
      0.355662, 0.516020, 0.054695},{0.355662, 0.523903, 0.045465}}],
    Polygon[{{0.372564, 0.513343, 0.054695},{0.369712, 0.504565, 0.062578},{
      0.355662, 0.506790, 0.062578},{0.355662, 0.516020, 0.054695}}],
    Polygon[{{0.369712, 0.504565, 0.062578},{0.366514, 0.494722, 0.068920},{
      0.355662, 0.496441, 0.068920},{0.355662, 0.506790, 0.062578}}],
    Polygon[{{0.366514, 0.494722, 0.068920},{0.363049, 0.484058, 0.073564},{
      0.355662, 0.485227, 0.073564},{0.355662, 0.496441, 0.068920}}],
    Polygon[{{0.363049, 0.484058, 0.073564},{0.359402, 0.472833, 0.076398},{
      0.355662, 0.473425, 0.076398},{0.355662, 0.485227, 0.073564}}],
    Polygon[{{0.355662, 0.473425, -0.076398},{0.355662, 0.485227, -0.073564},{
      0.348276, 0.484058, -0.073564},{0.351923, 0.472833, -0.076398}}],
    Polygon[{{0.355662, 0.485227, -0.073564},{0.355662, 0.496441, -0.068920},{
      0.344811, 0.494722, -0.068920},{0.348276, 0.484058, -0.073564}}],
    Polygon[{{0.355662, 0.496441, -0.068920},{0.355662, 0.506790, -0.062578},{
      0.341613, 0.504565, -0.062578},{0.344811, 0.494722, -0.068920}}],
    Polygon[{{0.355662, 0.506790, -0.062578},{0.355662, 0.516020, -0.054695},{
      0.338761, 0.513343, -0.054695},{0.341613, 0.504565, -0.062578}}],
    Polygon[{{0.355662, 0.516020, -0.054695},{0.355662, 0.523903, -0.045465},{
      0.336325, 0.520840, -0.045465},{0.338761, 0.513343, -0.054695}}],
    Polygon[{{0.355662, 0.523903, -0.045465},{0.355662, 0.530244, -0.035116},{
      0.334365, 0.526871, -0.035116},{0.336325, 0.520840, -0.045465}}],
    Polygon[{{0.355662, 0.530244, -0.035116},{0.355662, 0.534889, -0.023903},{
      0.332930, 0.531289, -0.023903},{0.334365, 0.526871, -0.035116}}],
    Polygon[{{0.355662, 0.534889, -0.023903},{0.355662, 0.537723, -0.012100},{
      0.332054, 0.533984, -0.012100},{0.332930, 0.531289, -0.023903}}],
    Polygon[{{0.355662, 0.537723, -0.012100},{0.355662, 0.538675, 0.000000},{
      0.331760, 0.534889, 0.000000},{0.332054, 0.533984, -0.012100}}],
    Polygon[{{0.355662, 0.538675, 0.000000},{0.355662, 0.537723, 0.012100},{
      0.332054, 0.533984, 0.012100},{0.331760, 0.534889, 0.000000}}],
    Polygon[{{0.355662, 0.537723, 0.012100},{0.355662, 0.534889, 0.023903},{
      0.332930, 0.531289, 0.023903},{0.332054, 0.533984, 0.012100}}],
    Polygon[{{0.355662, 0.534889, 0.023903},{0.355662, 0.530244, 0.035116},{
      0.334365, 0.526871, 0.035116},{0.332930, 0.531289, 0.023903}}],
    Polygon[{{0.355662, 0.530244, 0.035116},{0.355662, 0.523903, 0.045465},{
      0.336325, 0.520840, 0.045465},{0.334365, 0.526871, 0.035116}}],
    Polygon[{{0.355662, 0.523903, 0.045465},{0.355662, 0.516020, 0.054695},{
      0.338761, 0.513343, 0.054695},{0.336325, 0.520840, 0.045465}}],
    Polygon[{{0.355662, 0.516020, 0.054695},{0.355662, 0.506790, 0.062578},{
      0.341613, 0.504565, 0.062578},{0.338761, 0.513343, 0.054695}}],
    Polygon[{{0.355662, 0.506790, 0.062578},{0.355662, 0.496441, 0.068920},{
      0.344811, 0.494722, 0.068920},{0.341613, 0.504565, 0.062578}}],
    Polygon[{{0.355662, 0.496441, 0.068920},{0.355662, 0.485227, 0.073564},{
      0.348276, 0.484058, 0.073564},{0.344811, 0.494722, 0.068920}}],
    Polygon[{{0.355662, 0.485227, 0.073564},{0.355662, 0.473425, 0.076398},{
      0.351923, 0.472833, 0.076398},{0.348276, 0.484058, 0.073564}}],
    Polygon[{{0.351923, 0.472833, -0.076398},{0.348276, 0.484058, -0.073564},{
      0.341613, 0.480662, -0.073564},{0.348550, 0.471114, -0.076398}}],
    Polygon[{{0.348276, 0.484058, -0.073564},{0.344811, 0.494722, -0.068920},{
      0.335022, 0.489735, -0.068920},{0.341613, 0.480662, -0.073564}}],
    Polygon[{{0.344811, 0.494722, -0.068920},{0.341613, 0.504565, -0.062578},{
      0.328939, 0.498107, -0.062578},{0.335022, 0.489735, -0.068920}}],
    Polygon[{{0.341613, 0.504565, -0.062578},{0.338761, 0.513343, -0.054695},{
      0.323514, 0.505574, -0.054695},{0.328939, 0.498107, -0.062578}}],
    Polygon[{{0.338761, 0.513343, -0.054695},{0.336325, 0.520840, -0.045465},{
      0.318880, 0.511951, -0.045465},{0.323514, 0.505574, -0.054695}}],
    Polygon[{{0.336325, 0.520840, -0.045465},{0.334365, 0.526871, -0.035116},{
      0.315153, 0.517082, -0.035116},{0.318880, 0.511951, -0.045465}}],
    Polygon[{{0.334365, 0.526871, -0.035116},{0.332930, 0.531289, -0.023903},{
      0.312422, 0.520840, -0.023903},{0.315153, 0.517082, -0.035116}}],
    Polygon[{{0.332930, 0.531289, -0.023903},{0.332054, 0.533984, -0.012100},{
      0.310757, 0.523132, -0.012100},{0.312422, 0.520840, -0.023903}}],
    Polygon[{{0.332054, 0.533984, -0.012100},{0.331760, 0.534889, 0.000000},{
      0.310197, 0.523903, 0.000000},{0.310757, 0.523132, -0.012100}}],
    Polygon[{{0.331760, 0.534889, 0.000000},{0.332054, 0.533984, 0.012100},{
      0.310757, 0.523132, 0.012100},{0.310197, 0.523903, 0.000000}}],
    Polygon[{{0.332054, 0.533984, 0.012100},{0.332930, 0.531289, 0.023903},{
      0.312422, 0.520840, 0.023903},{0.310757, 0.523132, 0.012100}}],
    Polygon[{{0.332930, 0.531289, 0.023903},{0.334365, 0.526871, 0.035116},{
      0.315153, 0.517082, 0.035116},{0.312422, 0.520840, 0.023903}}],
    Polygon[{{0.334365, 0.526871, 0.035116},{0.336325, 0.520840, 0.045465},{
      0.318880, 0.511951, 0.045465},{0.315153, 0.517082, 0.035116}}],
    Polygon[{{0.336325, 0.520840, 0.045465},{0.338761, 0.513343, 0.054695},{
      0.323514, 0.505574, 0.054695},{0.318880, 0.511951, 0.045465}}],
    Polygon[{{0.338761, 0.513343, 0.054695},{0.341613, 0.504565, 0.062578},{
      0.328939, 0.498107, 0.062578},{0.323514, 0.505574, 0.054695}}],
    Polygon[{{0.341613, 0.504565, 0.062578},{0.344811, 0.494722, 0.068920},{
      0.335022, 0.489735, 0.068920},{0.328939, 0.498107, 0.062578}}],
    Polygon[{{0.344811, 0.494722, 0.068920},{0.348276, 0.484058, 0.073564},{
      0.341613, 0.480662, 0.073564},{0.335022, 0.489735, 0.068920}}],
    Polygon[{{0.348276, 0.484058, 0.073564},{0.351923, 0.472833, 0.076398},{
      0.348550, 0.471114, 0.076398},{0.341613, 0.480662, 0.073564}}],
    Polygon[{{0.348550, 0.471114, -0.076398},{0.341613, 0.480662, -0.073564},{
      0.336325, 0.475374, -0.073564},{0.345873, 0.468437, -0.076398}}],
    Polygon[{{0.341613, 0.480662, -0.073564},{0.335022, 0.489735, -0.068920},{
      0.327253, 0.481966, -0.068920},{0.336325, 0.475374, -0.073564}}],
    Polygon[{{0.335022, 0.489735, -0.068920},{0.328939, 0.498107, -0.062578},{
      0.318880, 0.488049, -0.062578},{0.327253, 0.481966, -0.068920}}],
    Polygon[{{0.328939, 0.498107, -0.062578},{0.323514, 0.505574, -0.054695},{
      0.311413, 0.493474, -0.054695},{0.318880, 0.488049, -0.062578}}],
    Polygon[{{0.323514, 0.505574, -0.054695},{0.318880, 0.511951, -0.045465},{
      0.305036, 0.498107, -0.045465},{0.311413, 0.493474, -0.054695}}],
    Polygon[{{0.318880, 0.511951, -0.045465},{0.315153, 0.517082, -0.035116},{
      0.299905, 0.501835, -0.035116},{0.305036, 0.498107, -0.045465}}],
    Polygon[{{0.315153, 0.517082, -0.035116},{0.312422, 0.520840, -0.023903},{
      0.296148, 0.504565, -0.023903},{0.299905, 0.501835, -0.035116}}],
    Polygon[{{0.312422, 0.520840, -0.023903},{0.310757, 0.523132, -0.012100},{
      0.293855, 0.506230, -0.012100},{0.296148, 0.504565, -0.023903}}],
    Polygon[{{0.310757, 0.523132, -0.012100},{0.310197, 0.523903, 0.000000},{
      0.293085, 0.506790, 0.000000},{0.293855, 0.506230, -0.012100}}],
    Polygon[{{0.310197, 0.523903, 0.000000},{0.310757, 0.523132, 0.012100},{
      0.293855, 0.506230, 0.012100},{0.293085, 0.506790, 0.000000}}],
    Polygon[{{0.310757, 0.523132, 0.012100},{0.312422, 0.520840, 0.023903},{
      0.296148, 0.504565, 0.023903},{0.293855, 0.506230, 0.012100}}],
    Polygon[{{0.312422, 0.520840, 0.023903},{0.315153, 0.517082, 0.035116},{
      0.299905, 0.501835, 0.035116},{0.296148, 0.504565, 0.023903}}],
    Polygon[{{0.315153, 0.517082, 0.035116},{0.318880, 0.511951, 0.045465},{
      0.305036, 0.498107, 0.045465},{0.299905, 0.501835, 0.035116}}],
    Polygon[{{0.318880, 0.511951, 0.045465},{0.323514, 0.505574, 0.054695},{
      0.311413, 0.493474, 0.054695},{0.305036, 0.498107, 0.045465}}],
    Polygon[{{0.323514, 0.505574, 0.054695},{0.328939, 0.498107, 0.062578},{
      0.318880, 0.488049, 0.062578},{0.311413, 0.493474, 0.054695}}],
    Polygon[{{0.328939, 0.498107, 0.062578},{0.335022, 0.489735, 0.068920},{
      0.327253, 0.481966, 0.068920},{0.318880, 0.488049, 0.062578}}],
    Polygon[{{0.335022, 0.489735, 0.068920},{0.341613, 0.480662, 0.073564},{
      0.336325, 0.475374, 0.073564},{0.327253, 0.481966, 0.068920}}],
    Polygon[{{0.341613, 0.480662, 0.073564},{0.348550, 0.471114, 0.076398},{
      0.345873, 0.468437, 0.076398},{0.336325, 0.475374, 0.073564}}],
    Polygon[{{0.345873, 0.468437, -0.076398},{0.336325, 0.475374, -0.073564},{
      0.332930, 0.468711, -0.073564},{0.344154, 0.465064, -0.076398}}],
    Polygon[{{0.336325, 0.475374, -0.073564},{0.327253, 0.481966, -0.068920},{
      0.322265, 0.472176, -0.068920},{0.332930, 0.468711, -0.073564}}],
    Polygon[{{0.327253, 0.481966, -0.068920},{0.318880, 0.488049, -0.062578},{
      0.312422, 0.475374, -0.062578},{0.322265, 0.472176, -0.068920}}],
    Polygon[{{0.318880, 0.488049, -0.062578},{0.311413, 0.493474, -0.054695},{
      0.303644, 0.478227, -0.054695},{0.312422, 0.475374, -0.062578}}],
    Polygon[{{0.311413, 0.493474, -0.054695},{0.305036, 0.498107, -0.045465},{
      0.296148, 0.480662, -0.045465},{0.303644, 0.478227, -0.054695}}],
    Polygon[{{0.305036, 0.498107, -0.045465},{0.299905, 0.501835, -0.035116},{
      0.290116, 0.482622, -0.035116},{0.296148, 0.480662, -0.045465}}],
    Polygon[{{0.299905, 0.501835, -0.035116},{0.296148, 0.504565, -0.023903},{
      0.285698, 0.484058, -0.023903},{0.290116, 0.482622, -0.035116}}],
    Polygon[{{0.296148, 0.504565, -0.023903},{0.293855, 0.506230, -0.012100},{
      0.283004, 0.484933, -0.012100},{0.285698, 0.484058, -0.023903}}],
    Polygon[{{0.293855, 0.506230, -0.012100},{0.293085, 0.506790, 0.000000},{
      0.282098, 0.485227, 0.000000},{0.283004, 0.484933, -0.012100}}],
    Polygon[{{0.293085, 0.506790, 0.000000},{0.293855, 0.506230, 0.012100},{
      0.283004, 0.484933, 0.012100},{0.282098, 0.485227, 0.000000}}],
    Polygon[{{0.293855, 0.506230, 0.012100},{0.296148, 0.504565, 0.023903},{
      0.285698, 0.484058, 0.023903},{0.283004, 0.484933, 0.012100}}],
    Polygon[{{0.296148, 0.504565, 0.023903},{0.299905, 0.501835, 0.035116},{
      0.290116, 0.482622, 0.035116},{0.285698, 0.484058, 0.023903}}],
    Polygon[{{0.299905, 0.501835, 0.035116},{0.305036, 0.498107, 0.045465},{
      0.296148, 0.480662, 0.045465},{0.290116, 0.482622, 0.035116}}],
    Polygon[{{0.305036, 0.498107, 0.045465},{0.311413, 0.493474, 0.054695},{
      0.303644, 0.478227, 0.054695},{0.296148, 0.480662, 0.045465}}],
    Polygon[{{0.311413, 0.493474, 0.054695},{0.318880, 0.488049, 0.062578},{
      0.312422, 0.475374, 0.062578},{0.303644, 0.478227, 0.054695}}],
    Polygon[{{0.318880, 0.488049, 0.062578},{0.327253, 0.481966, 0.068920},{
      0.322265, 0.472176, 0.068920},{0.312422, 0.475374, 0.062578}}],
    Polygon[{{0.327253, 0.481966, 0.068920},{0.336325, 0.475374, 0.073564},{
      0.332930, 0.468711, 0.073564},{0.322265, 0.472176, 0.068920}}],
    Polygon[{{0.336325, 0.475374, 0.073564},{0.345873, 0.468437, 0.076398},{
      0.344154, 0.465064, 0.076398},{0.332930, 0.468711, 0.073564}}],
    Polygon[{{0.344154, 0.465064, -0.076398},{0.332930, 0.468711, -0.073564},{
      0.331760, 0.461325, -0.073564},{0.343562, 0.461325, -0.076398}}],
    Polygon[{{0.332930, 0.468711, -0.073564},{0.322265, 0.472176, -0.068920},{
      0.320546, 0.461325, -0.068920},{0.331760, 0.461325, -0.073564}}],
    Polygon[{{0.322265, 0.472176, -0.068920},{0.312422, 0.475374, -0.062578},{
      0.310197, 0.461325, -0.062578},{0.320546, 0.461325, -0.068920}}],
    Polygon[{{0.312422, 0.475374, -0.062578},{0.303644, 0.478227, -0.054695},{
      0.300968, 0.461325, -0.054695},{0.310197, 0.461325, -0.062578}}],
    Polygon[{{0.303644, 0.478227, -0.054695},{0.296148, 0.480662, -0.045465},{
      0.293085, 0.461325, -0.045465},{0.300968, 0.461325, -0.054695}}],
    Polygon[{{0.296148, 0.480662, -0.045465},{0.290116, 0.482622, -0.035116},{
      0.286743, 0.461325, -0.035116},{0.293085, 0.461325, -0.045465}}],
    Polygon[{{0.290116, 0.482622, -0.035116},{0.285698, 0.484058, -0.023903},{
      0.282098, 0.461325, -0.023903},{0.286743, 0.461325, -0.035116}}],
    Polygon[{{0.285698, 0.484058, -0.023903},{0.283004, 0.484933, -0.012100},{
      0.279264, 0.461325, -0.012100},{0.282098, 0.461325, -0.023903}}],
    Polygon[{{0.283004, 0.484933, -0.012100},{0.282098, 0.485227, 0.000000},{
      0.278312, 0.461325, 0.000000},{0.279264, 0.461325, -0.012100}}],
    Polygon[{{0.282098, 0.485227, 0.000000},{0.283004, 0.484933, 0.012100},{
      0.279264, 0.461325, 0.012100},{0.278312, 0.461325, 0.000000}}],
    Polygon[{{0.283004, 0.484933, 0.012100},{0.285698, 0.484058, 0.023903},{
      0.282098, 0.461325, 0.023903},{0.279264, 0.461325, 0.012100}}],
    Polygon[{{0.285698, 0.484058, 0.023903},{0.290116, 0.482622, 0.035116},{
      0.286743, 0.461325, 0.035116},{0.282098, 0.461325, 0.023903}}],
    Polygon[{{0.290116, 0.482622, 0.035116},{0.296148, 0.480662, 0.045465},{
      0.293085, 0.461325, 0.045465},{0.286743, 0.461325, 0.035116}}],
    Polygon[{{0.296148, 0.480662, 0.045465},{0.303644, 0.478227, 0.054695},{
      0.300968, 0.461325, 0.054695},{0.293085, 0.461325, 0.045465}}],
    Polygon[{{0.303644, 0.478227, 0.054695},{0.312422, 0.475374, 0.062578},{
      0.310197, 0.461325, 0.062578},{0.300968, 0.461325, 0.054695}}],
    Polygon[{{0.312422, 0.475374, 0.062578},{0.322265, 0.472176, 0.068920},{
      0.320546, 0.461325, 0.068920},{0.310197, 0.461325, 0.062578}}],
    Polygon[{{0.322265, 0.472176, 0.068920},{0.332930, 0.468711, 0.073564},{
      0.331760, 0.461325, 0.073564},{0.320546, 0.461325, 0.068920}}],
    Polygon[{{0.332930, 0.468711, 0.073564},{0.344154, 0.465064, 0.076398},{
      0.343562, 0.461325, 0.076398},{0.331760, 0.461325, 0.073564}}],
    Polygon[{{0.343562, 0.461325, -0.076398},{0.331760, 0.461325, -0.073564},{
      0.332930, 0.453939, -0.073564},{0.344154, 0.457586, -0.076398}}],
    Polygon[{{0.331760, 0.461325, -0.073564},{0.320546, 0.461325, -0.068920},{
      0.322265, 0.450473, -0.068920},{0.332930, 0.453939, -0.073564}}],
    Polygon[{{0.320546, 0.461325, -0.068920},{0.310197, 0.461325, -0.062578},{
      0.312422, 0.447275, -0.062578},{0.322265, 0.450473, -0.068920}}],
    Polygon[{{0.310197, 0.461325, -0.062578},{0.300968, 0.461325, -0.054695},{
      0.303644, 0.444423, -0.054695},{0.312422, 0.447275, -0.062578}}],
    Polygon[{{0.300968, 0.461325, -0.054695},{0.293085, 0.461325, -0.045465},{
      0.296148, 0.441987, -0.045465},{0.303644, 0.444423, -0.054695}}],
    Polygon[{{0.293085, 0.461325, -0.045465},{0.286743, 0.461325, -0.035116},{
      0.290116, 0.440028, -0.035116},{0.296148, 0.441987, -0.045465}}],
    Polygon[{{0.286743, 0.461325, -0.035116},{0.282098, 0.461325, -0.023903},{
      0.285698, 0.438592, -0.023903},{0.290116, 0.440028, -0.035116}}],
    Polygon[{{0.282098, 0.461325, -0.023903},{0.279264, 0.461325, -0.012100},{
      0.283004, 0.437717, -0.012100},{0.285698, 0.438592, -0.023903}}],
    Polygon[{{0.279264, 0.461325, -0.012100},{0.278312, 0.461325, 0.000000},{
      0.282098, 0.437422, 0.000000},{0.283004, 0.437717, -0.012100}}],
    Polygon[{{0.278312, 0.461325, 0.000000},{0.279264, 0.461325, 0.012100},{
      0.283004, 0.437717, 0.012100},{0.282098, 0.437422, 0.000000}}],
    Polygon[{{0.279264, 0.461325, 0.012100},{0.282098, 0.461325, 0.023903},{
      0.285698, 0.438592, 0.023903},{0.283004, 0.437717, 0.012100}}],
    Polygon[{{0.282098, 0.461325, 0.023903},{0.286743, 0.461325, 0.035116},{
      0.290116, 0.440028, 0.035116},{0.285698, 0.438592, 0.023903}}],
    Polygon[{{0.286743, 0.461325, 0.035116},{0.293085, 0.461325, 0.045465},{
      0.296148, 0.441987, 0.045465},{0.290116, 0.440028, 0.035116}}],
    Polygon[{{0.293085, 0.461325, 0.045465},{0.300968, 0.461325, 0.054695},{
      0.303644, 0.444423, 0.054695},{0.296148, 0.441987, 0.045465}}],
    Polygon[{{0.300968, 0.461325, 0.054695},{0.310197, 0.461325, 0.062578},{
      0.312422, 0.447275, 0.062578},{0.303644, 0.444423, 0.054695}}],
    Polygon[{{0.310197, 0.461325, 0.062578},{0.320546, 0.461325, 0.068920},{
      0.322265, 0.450473, 0.068920},{0.312422, 0.447275, 0.062578}}],
    Polygon[{{0.320546, 0.461325, 0.068920},{0.331760, 0.461325, 0.073564},{
      0.332930, 0.453939, 0.073564},{0.322265, 0.450473, 0.068920}}],
    Polygon[{{0.331760, 0.461325, 0.073564},{0.343562, 0.461325, 0.076398},{
      0.344154, 0.457586, 0.076398},{0.332930, 0.453939, 0.073564}}],
    Polygon[{{0.344154, 0.457586, -0.076398},{0.332930, 0.453939, -0.073564},{
      0.336325, 0.447275, -0.073564},{0.345873, 0.454213, -0.076398}}],
    Polygon[{{0.332930, 0.453939, -0.073564},{0.322265, 0.450473, -0.068920},{
      0.327253, 0.440684, -0.068920},{0.336325, 0.447275, -0.073564}}],
    Polygon[{{0.322265, 0.450473, -0.068920},{0.312422, 0.447275, -0.062578},{
      0.318880, 0.434601, -0.062578},{0.327253, 0.440684, -0.068920}}],
    Polygon[{{0.312422, 0.447275, -0.062578},{0.303644, 0.444423, -0.054695},{
      0.311413, 0.429176, -0.054695},{0.318880, 0.434601, -0.062578}}],
    Polygon[{{0.303644, 0.444423, -0.054695},{0.296148, 0.441987, -0.045465},{
      0.305036, 0.424543, -0.045465},{0.311413, 0.429176, -0.054695}}],
    Polygon[{{0.296148, 0.441987, -0.045465},{0.290116, 0.440028, -0.035116},{
      0.299905, 0.420815, -0.035116},{0.305036, 0.424543, -0.045465}}],
    Polygon[{{0.290116, 0.440028, -0.035116},{0.285698, 0.438592, -0.023903},{
      0.296148, 0.418085, -0.023903},{0.299905, 0.420815, -0.035116}}],
    Polygon[{{0.285698, 0.438592, -0.023903},{0.283004, 0.437717, -0.012100},{
      0.293855, 0.416419, -0.012100},{0.296148, 0.418085, -0.023903}}],
    Polygon[{{0.283004, 0.437717, -0.012100},{0.282098, 0.437422, 0.000000},{
      0.293085, 0.415860, 0.000000},{0.293855, 0.416419, -0.012100}}],
    Polygon[{{0.282098, 0.437422, 0.000000},{0.283004, 0.437717, 0.012100},{
      0.293855, 0.416419, 0.012100},{0.293085, 0.415860, 0.000000}}],
    Polygon[{{0.283004, 0.437717, 0.012100},{0.285698, 0.438592, 0.023903},{
      0.296148, 0.418085, 0.023903},{0.293855, 0.416419, 0.012100}}],
    Polygon[{{0.285698, 0.438592, 0.023903},{0.290116, 0.440028, 0.035116},{
      0.299905, 0.420815, 0.035116},{0.296148, 0.418085, 0.023903}}],
    Polygon[{{0.290116, 0.440028, 0.035116},{0.296148, 0.441987, 0.045465},{
      0.305036, 0.424543, 0.045465},{0.299905, 0.420815, 0.035116}}],
    Polygon[{{0.296148, 0.441987, 0.045465},{0.303644, 0.444423, 0.054695},{
      0.311413, 0.429176, 0.054695},{0.305036, 0.424543, 0.045465}}],
    Polygon[{{0.303644, 0.444423, 0.054695},{0.312422, 0.447275, 0.062578},{
      0.318880, 0.434601, 0.062578},{0.311413, 0.429176, 0.054695}}],
    Polygon[{{0.312422, 0.447275, 0.062578},{0.322265, 0.450473, 0.068920},{
      0.327253, 0.440684, 0.068920},{0.318880, 0.434601, 0.062578}}],
    Polygon[{{0.322265, 0.450473, 0.068920},{0.332930, 0.453939, 0.073564},{
      0.336325, 0.447275, 0.073564},{0.327253, 0.440684, 0.068920}}],
    Polygon[{{0.332930, 0.453939, 0.073564},{0.344154, 0.457586, 0.076398},{
      0.345873, 0.454213, 0.076398},{0.336325, 0.447275, 0.073564}}],
    Polygon[{{0.345873, 0.454213, -0.076398},{0.336325, 0.447275, -0.073564},{
      0.341613, 0.441987, -0.073564},{0.348550, 0.451536, -0.076398}}],
    Polygon[{{0.336325, 0.447275, -0.073564},{0.327253, 0.440684, -0.068920},{
      0.335022, 0.432915, -0.068920},{0.341613, 0.441987, -0.073564}}],
    Polygon[{{0.327253, 0.440684, -0.068920},{0.318880, 0.434601, -0.062578},{
      0.328939, 0.424543, -0.062578},{0.335022, 0.432915, -0.068920}}],
    Polygon[{{0.318880, 0.434601, -0.062578},{0.311413, 0.429176, -0.054695},{
      0.323514, 0.417076, -0.054695},{0.328939, 0.424543, -0.062578}}],
    Polygon[{{0.311413, 0.429176, -0.054695},{0.305036, 0.424543, -0.045465},{
      0.318880, 0.410698, -0.045465},{0.323514, 0.417076, -0.054695}}],
    Polygon[{{0.305036, 0.424543, -0.045465},{0.299905, 0.420815, -0.035116},{
      0.315153, 0.405568, -0.035116},{0.318880, 0.410698, -0.045465}}],
    Polygon[{{0.299905, 0.420815, -0.035116},{0.296148, 0.418085, -0.023903},{
      0.312422, 0.401810, -0.023903},{0.315153, 0.405568, -0.035116}}],
    Polygon[{{0.296148, 0.418085, -0.023903},{0.293855, 0.416419, -0.012100},{
      0.310757, 0.399518, -0.012100},{0.312422, 0.401810, -0.023903}}],
    Polygon[{{0.293855, 0.416419, -0.012100},{0.293085, 0.415860, 0.000000},{
      0.310197, 0.398747, 0.000000},{0.310757, 0.399518, -0.012100}}],
    Polygon[{{0.293085, 0.415860, 0.000000},{0.293855, 0.416419, 0.012100},{
      0.310757, 0.399518, 0.012100},{0.310197, 0.398747, 0.000000}}],
    Polygon[{{0.293855, 0.416419, 0.012100},{0.296148, 0.418085, 0.023903},{
      0.312422, 0.401810, 0.023903},{0.310757, 0.399518, 0.012100}}],
    Polygon[{{0.296148, 0.418085, 0.023903},{0.299905, 0.420815, 0.035116},{
      0.315153, 0.405568, 0.035116},{0.312422, 0.401810, 0.023903}}],
    Polygon[{{0.299905, 0.420815, 0.035116},{0.305036, 0.424543, 0.045465},{
      0.318880, 0.410698, 0.045465},{0.315153, 0.405568, 0.035116}}],
    Polygon[{{0.305036, 0.424543, 0.045465},{0.311413, 0.429176, 0.054695},{
      0.323514, 0.417076, 0.054695},{0.318880, 0.410698, 0.045465}}],
    Polygon[{{0.311413, 0.429176, 0.054695},{0.318880, 0.434601, 0.062578},{
      0.328939, 0.424543, 0.062578},{0.323514, 0.417076, 0.054695}}],
    Polygon[{{0.318880, 0.434601, 0.062578},{0.327253, 0.440684, 0.068920},{
      0.335022, 0.432915, 0.068920},{0.328939, 0.424543, 0.062578}}],
    Polygon[{{0.327253, 0.440684, 0.068920},{0.336325, 0.447275, 0.073564},{
      0.341613, 0.441987, 0.073564},{0.335022, 0.432915, 0.068920}}],
    Polygon[{{0.336325, 0.447275, 0.073564},{0.345873, 0.454213, 0.076398},{
      0.348550, 0.451536, 0.076398},{0.341613, 0.441987, 0.073564}}],
    Polygon[{{0.348550, 0.451536, -0.076398},{0.341613, 0.441987, -0.073564},{
      0.348276, 0.438592, -0.073564},{0.351923, 0.449817, -0.076398}}],
    Polygon[{{0.341613, 0.441987, -0.073564},{0.335022, 0.432915, -0.068920},{
      0.344811, 0.427927, -0.068920},{0.348276, 0.438592, -0.073564}}],
    Polygon[{{0.335022, 0.432915, -0.068920},{0.328939, 0.424543, -0.062578},{
      0.341613, 0.418085, -0.062578},{0.344811, 0.427927, -0.068920}}],
    Polygon[{{0.328939, 0.424543, -0.062578},{0.323514, 0.417076, -0.054695},{
      0.338761, 0.409307, -0.054695},{0.341613, 0.418085, -0.062578}}],
    Polygon[{{0.323514, 0.417076, -0.054695},{0.318880, 0.410698, -0.045465},{
      0.336325, 0.401810, -0.045465},{0.338761, 0.409307, -0.054695}}],
    Polygon[{{0.318880, 0.410698, -0.045465},{0.315153, 0.405568, -0.035116},{
      0.334365, 0.395778, -0.035116},{0.336325, 0.401810, -0.045465}}],
    Polygon[{{0.315153, 0.405568, -0.035116},{0.312422, 0.401810, -0.023903},{
      0.332930, 0.391361, -0.023903},{0.334365, 0.395778, -0.035116}}],
    Polygon[{{0.312422, 0.401810, -0.023903},{0.310757, 0.399518, -0.012100},{
      0.332054, 0.388666, -0.012100},{0.332930, 0.391361, -0.023903}}],
    Polygon[{{0.310757, 0.399518, -0.012100},{0.310197, 0.398747, 0.000000},{
      0.331760, 0.387760, 0.000000},{0.332054, 0.388666, -0.012100}}],
    Polygon[{{0.310197, 0.398747, 0.000000},{0.310757, 0.399518, 0.012100},{
      0.332054, 0.388666, 0.012100},{0.331760, 0.387760, 0.000000}}],
    Polygon[{{0.310757, 0.399518, 0.012100},{0.312422, 0.401810, 0.023903},{
      0.332930, 0.391361, 0.023903},{0.332054, 0.388666, 0.012100}}],
    Polygon[{{0.312422, 0.401810, 0.023903},{0.315153, 0.405568, 0.035116},{
      0.334365, 0.395778, 0.035116},{0.332930, 0.391361, 0.023903}}],
    Polygon[{{0.315153, 0.405568, 0.035116},{0.318880, 0.410698, 0.045465},{
      0.336325, 0.401810, 0.045465},{0.334365, 0.395778, 0.035116}}],
    Polygon[{{0.318880, 0.410698, 0.045465},{0.323514, 0.417076, 0.054695},{
      0.338761, 0.409307, 0.054695},{0.336325, 0.401810, 0.045465}}],
    Polygon[{{0.323514, 0.417076, 0.054695},{0.328939, 0.424543, 0.062578},{
      0.341613, 0.418085, 0.062578},{0.338761, 0.409307, 0.054695}}],
    Polygon[{{0.328939, 0.424543, 0.062578},{0.335022, 0.432915, 0.068920},{
      0.344811, 0.427927, 0.068920},{0.341613, 0.418085, 0.062578}}],
    Polygon[{{0.335022, 0.432915, 0.068920},{0.341613, 0.441987, 0.073564},{
      0.348276, 0.438592, 0.073564},{0.344811, 0.427927, 0.068920}}],
    Polygon[{{0.341613, 0.441987, 0.073564},{0.348550, 0.451536, 0.076398},{
      0.351923, 0.449817, 0.076398},{0.348276, 0.438592, 0.073564}}],
    Polygon[{{0.351923, 0.449817, -0.076398},{0.348276, 0.438592, -0.073564},{
      0.355662, 0.437422, -0.073564},{0.355662, 0.449225, -0.076398}}],
    Polygon[{{0.348276, 0.438592, -0.073564},{0.344811, 0.427927, -0.068920},{
      0.355662, 0.426209, -0.068920},{0.355662, 0.437422, -0.073564}}],
    Polygon[{{0.344811, 0.427927, -0.068920},{0.341613, 0.418085, -0.062578},{
      0.355662, 0.415860, -0.062578},{0.355662, 0.426209, -0.068920}}],
    Polygon[{{0.341613, 0.418085, -0.062578},{0.338761, 0.409307, -0.054695},{
      0.355662, 0.406630, -0.054695},{0.355662, 0.415860, -0.062578}}],
    Polygon[{{0.338761, 0.409307, -0.054695},{0.336325, 0.401810, -0.045465},{
      0.355662, 0.398747, -0.045465},{0.355662, 0.406630, -0.054695}}],
    Polygon[{{0.336325, 0.401810, -0.045465},{0.334365, 0.395778, -0.035116},{
      0.355662, 0.392405, -0.035116},{0.355662, 0.398747, -0.045465}}],
    Polygon[{{0.334365, 0.395778, -0.035116},{0.332930, 0.391361, -0.023903},{
      0.355662, 0.387760, -0.023903},{0.355662, 0.392405, -0.035116}}],
    Polygon[{{0.332930, 0.391361, -0.023903},{0.332054, 0.388666, -0.012100},{
      0.355662, 0.384927, -0.012100},{0.355662, 0.387760, -0.023903}}],
    Polygon[{{0.332054, 0.388666, -0.012100},{0.331760, 0.387760, 0.000000},{
      0.355662, 0.383975, 0.000000},{0.355662, 0.384927, -0.012100}}],
    Polygon[{{0.331760, 0.387760, 0.000000},{0.332054, 0.388666, 0.012100},{
      0.355662, 0.384927, 0.012100},{0.355662, 0.383975, 0.000000}}],
    Polygon[{{0.332054, 0.388666, 0.012100},{0.332930, 0.391361, 0.023903},{
      0.355662, 0.387760, 0.023903},{0.355662, 0.384927, 0.012100}}],
    Polygon[{{0.332930, 0.391361, 0.023903},{0.334365, 0.395778, 0.035116},{
      0.355662, 0.392405, 0.035116},{0.355662, 0.387760, 0.023903}}],
    Polygon[{{0.334365, 0.395778, 0.035116},{0.336325, 0.401810, 0.045465},{
      0.355662, 0.398747, 0.045465},{0.355662, 0.392405, 0.035116}}],
    Polygon[{{0.336325, 0.401810, 0.045465},{0.338761, 0.409307, 0.054695},{
      0.355662, 0.406630, 0.054695},{0.355662, 0.398747, 0.045465}}],
    Polygon[{{0.338761, 0.409307, 0.054695},{0.341613, 0.418085, 0.062578},{
      0.355662, 0.415860, 0.062578},{0.355662, 0.406630, 0.054695}}],
    Polygon[{{0.341613, 0.418085, 0.062578},{0.344811, 0.427927, 0.068920},{
      0.355662, 0.426209, 0.068920},{0.355662, 0.415860, 0.062578}}],
    Polygon[{{0.344811, 0.427927, 0.068920},{0.348276, 0.438592, 0.073564},{
      0.355662, 0.437422, 0.073564},{0.355662, 0.426209, 0.068920}}],
    Polygon[{{0.348276, 0.438592, 0.073564},{0.351923, 0.449817, 0.076398},{
      0.355662, 0.449225, 0.076398},{0.355662, 0.437422, 0.073564}}],
    Polygon[{{0.355662, 0.449225, -0.076398},{0.355662, 0.437422, -0.073564},{
      0.363049, 0.438592, -0.073564},{0.359402, 0.449817, -0.076398}}],
    Polygon[{{0.355662, 0.437422, -0.073564},{0.355662, 0.426209, -0.068920},{
      0.366514, 0.427927, -0.068920},{0.363049, 0.438592, -0.073564}}],
    Polygon[{{0.355662, 0.426209, -0.068920},{0.355662, 0.415860, -0.062578},{
      0.369712, 0.418085, -0.062578},{0.366514, 0.427927, -0.068920}}],
    Polygon[{{0.355662, 0.415860, -0.062578},{0.355662, 0.406630, -0.054695},{
      0.372564, 0.409307, -0.054695},{0.369712, 0.418085, -0.062578}}],
    Polygon[{{0.355662, 0.406630, -0.054695},{0.355662, 0.398747, -0.045465},{
      0.375000, 0.401810, -0.045465},{0.372564, 0.409307, -0.054695}}],
    Polygon[{{0.355662, 0.398747, -0.045465},{0.355662, 0.392405, -0.035116},{
      0.376960, 0.395778, -0.035116},{0.375000, 0.401810, -0.045465}}],
    Polygon[{{0.355662, 0.392405, -0.035116},{0.355662, 0.387760, -0.023903},{
      0.378395, 0.391361, -0.023903},{0.376960, 0.395778, -0.035116}}],
    Polygon[{{0.355662, 0.387760, -0.023903},{0.355662, 0.384927, -0.012100},{
      0.379271, 0.388666, -0.012100},{0.378395, 0.391361, -0.023903}}],
    Polygon[{{0.355662, 0.384927, -0.012100},{0.355662, 0.383975, 0.000000},{
      0.379565, 0.387760, 0.000000},{0.379271, 0.388666, -0.012100}}],
    Polygon[{{0.355662, 0.383975, 0.000000},{0.355662, 0.384927, 0.012100},{
      0.379271, 0.388666, 0.012100},{0.379565, 0.387760, 0.000000}}],
    Polygon[{{0.355662, 0.384927, 0.012100},{0.355662, 0.387760, 0.023903},{
      0.378395, 0.391361, 0.023903},{0.379271, 0.388666, 0.012100}}],
    Polygon[{{0.355662, 0.387760, 0.023903},{0.355662, 0.392405, 0.035116},{
      0.376960, 0.395778, 0.035116},{0.378395, 0.391361, 0.023903}}],
    Polygon[{{0.355662, 0.392405, 0.035116},{0.355662, 0.398747, 0.045465},{
      0.375000, 0.401810, 0.045465},{0.376960, 0.395778, 0.035116}}],
    Polygon[{{0.355662, 0.398747, 0.045465},{0.355662, 0.406630, 0.054695},{
      0.372564, 0.409307, 0.054695},{0.375000, 0.401810, 0.045465}}],
    Polygon[{{0.355662, 0.406630, 0.054695},{0.355662, 0.415860, 0.062578},{
      0.369712, 0.418085, 0.062578},{0.372564, 0.409307, 0.054695}}],
    Polygon[{{0.355662, 0.415860, 0.062578},{0.355662, 0.426209, 0.068920},{
      0.366514, 0.427927, 0.068920},{0.369712, 0.418085, 0.062578}}],
    Polygon[{{0.355662, 0.426209, 0.068920},{0.355662, 0.437422, 0.073564},{
      0.363049, 0.438592, 0.073564},{0.366514, 0.427927, 0.068920}}],
    Polygon[{{0.355662, 0.437422, 0.073564},{0.355662, 0.449225, 0.076398},{
      0.359402, 0.449817, 0.076398},{0.363049, 0.438592, 0.073564}}],
    Polygon[{{0.359402, 0.449817, -0.076398},{0.363049, 0.438592, -0.073564},{
      0.369712, 0.441987, -0.073564},{0.362775, 0.451536, -0.076398}}],
    Polygon[{{0.363049, 0.438592, -0.073564},{0.366514, 0.427927, -0.068920},{
      0.376303, 0.432915, -0.068920},{0.369712, 0.441987, -0.073564}}],
    Polygon[{{0.366514, 0.427927, -0.068920},{0.369712, 0.418085, -0.062578},{
      0.382386, 0.424543, -0.062578},{0.376303, 0.432915, -0.068920}}],
    Polygon[{{0.369712, 0.418085, -0.062578},{0.372564, 0.409307, -0.054695},{
      0.387811, 0.417076, -0.054695},{0.382386, 0.424543, -0.062578}}],
    Polygon[{{0.372564, 0.409307, -0.054695},{0.375000, 0.401810, -0.045465},{
      0.392445, 0.410698, -0.045465},{0.387811, 0.417076, -0.054695}}],
    Polygon[{{0.375000, 0.401810, -0.045465},{0.376960, 0.395778, -0.035116},{
      0.396172, 0.405568, -0.035116},{0.392445, 0.410698, -0.045465}}],
    Polygon[{{0.376960, 0.395778, -0.035116},{0.378395, 0.391361, -0.023903},{
      0.398903, 0.401810, -0.023903},{0.396172, 0.405568, -0.035116}}],
    Polygon[{{0.378395, 0.391361, -0.023903},{0.379271, 0.388666, -0.012100},{
      0.400568, 0.399518, -0.012100},{0.398903, 0.401810, -0.023903}}],
    Polygon[{{0.379271, 0.388666, -0.012100},{0.379565, 0.387760, 0.000000},{
      0.401128, 0.398747, 0.000000},{0.400568, 0.399518, -0.012100}}],
    Polygon[{{0.379565, 0.387760, 0.000000},{0.379271, 0.388666, 0.012100},{
      0.400568, 0.399518, 0.012100},{0.401128, 0.398747, 0.000000}}],
    Polygon[{{0.379271, 0.388666, 0.012100},{0.378395, 0.391361, 0.023903},{
      0.398903, 0.401810, 0.023903},{0.400568, 0.399518, 0.012100}}],
    Polygon[{{0.378395, 0.391361, 0.023903},{0.376960, 0.395778, 0.035116},{
      0.396172, 0.405568, 0.035116},{0.398903, 0.401810, 0.023903}}],
    Polygon[{{0.376960, 0.395778, 0.035116},{0.375000, 0.401810, 0.045465},{
      0.392445, 0.410698, 0.045465},{0.396172, 0.405568, 0.035116}}],
    Polygon[{{0.375000, 0.401810, 0.045465},{0.372564, 0.409307, 0.054695},{
      0.387811, 0.417076, 0.054695},{0.392445, 0.410698, 0.045465}}],
    Polygon[{{0.372564, 0.409307, 0.054695},{0.369712, 0.418085, 0.062578},{
      0.382386, 0.424543, 0.062578},{0.387811, 0.417076, 0.054695}}],
    Polygon[{{0.369712, 0.418085, 0.062578},{0.366514, 0.427927, 0.068920},{
      0.376303, 0.432915, 0.068920},{0.382386, 0.424543, 0.062578}}],
    Polygon[{{0.366514, 0.427927, 0.068920},{0.363049, 0.438592, 0.073564},{
      0.369712, 0.441987, 0.073564},{0.376303, 0.432915, 0.068920}}],
    Polygon[{{0.363049, 0.438592, 0.073564},{0.359402, 0.449817, 0.076398},{
      0.362775, 0.451536, 0.076398},{0.369712, 0.441987, 0.073564}}],
    Polygon[{{0.362775, 0.451536, -0.076398},{0.369712, 0.441987, -0.073564},{
      0.375000, 0.447275, -0.073564},{0.365452, 0.454213, -0.076398}}],
    Polygon[{{0.369712, 0.441987, -0.073564},{0.376303, 0.432915, -0.068920},{
      0.384072, 0.440684, -0.068920},{0.375000, 0.447275, -0.073564}}],
    Polygon[{{0.376303, 0.432915, -0.068920},{0.382386, 0.424543, -0.062578},{
      0.392445, 0.434601, -0.062578},{0.384072, 0.440684, -0.068920}}],
    Polygon[{{0.382386, 0.424543, -0.062578},{0.387811, 0.417076, -0.054695},{
      0.399912, 0.429176, -0.054695},{0.392445, 0.434601, -0.062578}}],
    Polygon[{{0.387811, 0.417076, -0.054695},{0.392445, 0.410698, -0.045465},{
      0.406289, 0.424543, -0.045465},{0.399912, 0.429176, -0.054695}}],
    Polygon[{{0.392445, 0.410698, -0.045465},{0.396172, 0.405568, -0.035116},{
      0.411420, 0.420815, -0.035116},{0.406289, 0.424543, -0.045465}}],
    Polygon[{{0.396172, 0.405568, -0.035116},{0.398903, 0.401810, -0.023903},{
      0.415177, 0.418085, -0.023903},{0.411420, 0.420815, -0.035116}}],
    Polygon[{{0.398903, 0.401810, -0.023903},{0.400568, 0.399518, -0.012100},{
      0.417470, 0.416419, -0.012100},{0.415177, 0.418085, -0.023903}}],
    Polygon[{{0.400568, 0.399518, -0.012100},{0.401128, 0.398747, 0.000000},{
      0.418240, 0.415860, 0.000000},{0.417470, 0.416419, -0.012100}}],
    Polygon[{{0.401128, 0.398747, 0.000000},{0.400568, 0.399518, 0.012100},{
      0.417470, 0.416419, 0.012100},{0.418240, 0.415860, 0.000000}}],
    Polygon[{{0.400568, 0.399518, 0.012100},{0.398903, 0.401810, 0.023903},{
      0.415177, 0.418085, 0.023903},{0.417470, 0.416419, 0.012100}}],
    Polygon[{{0.398903, 0.401810, 0.023903},{0.396172, 0.405568, 0.035116},{
      0.411420, 0.420815, 0.035116},{0.415177, 0.418085, 0.023903}}],
    Polygon[{{0.396172, 0.405568, 0.035116},{0.392445, 0.410698, 0.045465},{
      0.406289, 0.424543, 0.045465},{0.411420, 0.420815, 0.035116}}],
    Polygon[{{0.392445, 0.410698, 0.045465},{0.387811, 0.417076, 0.054695},{
      0.399912, 0.429176, 0.054695},{0.406289, 0.424543, 0.045465}}],
    Polygon[{{0.387811, 0.417076, 0.054695},{0.382386, 0.424543, 0.062578},{
      0.392445, 0.434601, 0.062578},{0.399912, 0.429176, 0.054695}}],
    Polygon[{{0.382386, 0.424543, 0.062578},{0.376303, 0.432915, 0.068920},{
      0.384072, 0.440684, 0.068920},{0.392445, 0.434601, 0.062578}}],
    Polygon[{{0.376303, 0.432915, 0.068920},{0.369712, 0.441987, 0.073564},{
      0.375000, 0.447275, 0.073564},{0.384072, 0.440684, 0.068920}}],
    Polygon[{{0.369712, 0.441987, 0.073564},{0.362775, 0.451536, 0.076398},{
      0.365452, 0.454213, 0.076398},{0.375000, 0.447275, 0.073564}}],
    Polygon[{{0.365452, 0.454213, -0.076398},{0.375000, 0.447275, -0.073564},{
      0.378395, 0.453939, -0.073564},{0.367170, 0.457586, -0.076398}}],
    Polygon[{{0.375000, 0.447275, -0.073564},{0.384072, 0.440684, -0.068920},{
      0.389060, 0.450473, -0.068920},{0.378395, 0.453939, -0.073564}}],
    Polygon[{{0.384072, 0.440684, -0.068920},{0.392445, 0.434601, -0.062578},{
      0.398903, 0.447275, -0.062578},{0.389060, 0.450473, -0.068920}}],
    Polygon[{{0.392445, 0.434601, -0.062578},{0.399912, 0.429176, -0.054695},{
      0.407680, 0.444423, -0.054695},{0.398903, 0.447275, -0.062578}}],
    Polygon[{{0.399912, 0.429176, -0.054695},{0.406289, 0.424543, -0.045465},{
      0.415177, 0.441987, -0.045465},{0.407680, 0.444423, -0.054695}}],
    Polygon[{{0.406289, 0.424543, -0.045465},{0.411420, 0.420815, -0.035116},{
      0.421209, 0.440028, -0.035116},{0.415177, 0.441987, -0.045465}}],
    Polygon[{{0.411420, 0.420815, -0.035116},{0.415177, 0.418085, -0.023903},{
      0.425626, 0.438592, -0.023903},{0.421209, 0.440028, -0.035116}}],
    Polygon[{{0.415177, 0.418085, -0.023903},{0.417470, 0.416419, -0.012100},{
      0.428321, 0.437717, -0.012100},{0.425626, 0.438592, -0.023903}}],
    Polygon[{{0.417470, 0.416419, -0.012100},{0.418240, 0.415860, 0.000000},{
      0.429227, 0.437422, 0.000000},{0.428321, 0.437717, -0.012100}}],
    Polygon[{{0.418240, 0.415860, 0.000000},{0.417470, 0.416419, 0.012100},{
      0.428321, 0.437717, 0.012100},{0.429227, 0.437422, 0.000000}}],
    Polygon[{{0.417470, 0.416419, 0.012100},{0.415177, 0.418085, 0.023903},{
      0.425626, 0.438592, 0.023903},{0.428321, 0.437717, 0.012100}}],
    Polygon[{{0.415177, 0.418085, 0.023903},{0.411420, 0.420815, 0.035116},{
      0.421209, 0.440028, 0.035116},{0.425626, 0.438592, 0.023903}}],
    Polygon[{{0.411420, 0.420815, 0.035116},{0.406289, 0.424543, 0.045465},{
      0.415177, 0.441987, 0.045465},{0.421209, 0.440028, 0.035116}}],
    Polygon[{{0.406289, 0.424543, 0.045465},{0.399912, 0.429176, 0.054695},{
      0.407680, 0.444423, 0.054695},{0.415177, 0.441987, 0.045465}}],
    Polygon[{{0.399912, 0.429176, 0.054695},{0.392445, 0.434601, 0.062578},{
      0.398903, 0.447275, 0.062578},{0.407680, 0.444423, 0.054695}}],
    Polygon[{{0.392445, 0.434601, 0.062578},{0.384072, 0.440684, 0.068920},{
      0.389060, 0.450473, 0.068920},{0.398903, 0.447275, 0.062578}}],
    Polygon[{{0.384072, 0.440684, 0.068920},{0.375000, 0.447275, 0.073564},{
      0.378395, 0.453939, 0.073564},{0.389060, 0.450473, 0.068920}}],
    Polygon[{{0.375000, 0.447275, 0.073564},{0.365452, 0.454213, 0.076398},{
      0.367170, 0.457586, 0.076398},{0.378395, 0.453939, 0.073564}}],
    Polygon[{{0.367170, 0.457586, -0.076398},{0.378395, 0.453939, -0.073564},{
      0.379565, 0.461325, -0.073564},{0.367763, 0.461325, -0.076398}}],
    Polygon[{{0.378395, 0.453939, -0.073564},{0.389060, 0.450473, -0.068920},{
      0.390779, 0.461325, -0.068920},{0.379565, 0.461325, -0.073564}}],
    Polygon[{{0.389060, 0.450473, -0.068920},{0.398903, 0.447275, -0.062578},{
      0.401128, 0.461325, -0.062578},{0.390779, 0.461325, -0.068920}}],
    Polygon[{{0.398903, 0.447275, -0.062578},{0.407680, 0.444423, -0.054695},{
      0.410357, 0.461325, -0.054695},{0.401128, 0.461325, -0.062578}}],
    Polygon[{{0.407680, 0.444423, -0.054695},{0.415177, 0.441987, -0.045465},{
      0.418240, 0.461325, -0.045465},{0.410357, 0.461325, -0.054695}}],
    Polygon[{{0.415177, 0.441987, -0.045465},{0.421209, 0.440028, -0.035116},{
      0.424582, 0.461325, -0.035116},{0.418240, 0.461325, -0.045465}}],
    Polygon[{{0.421209, 0.440028, -0.035116},{0.425626, 0.438592, -0.023903},{
      0.429227, 0.461325, -0.023903},{0.424582, 0.461325, -0.035116}}],
    Polygon[{{0.425626, 0.438592, -0.023903},{0.428321, 0.437717, -0.012100},{
      0.432060, 0.461325, -0.012100},{0.429227, 0.461325, -0.023903}}],
    Polygon[{{0.428321, 0.437717, -0.012100},{0.429227, 0.437422, 0.000000},{
      0.433013, 0.461325, 0.000000},{0.432060, 0.461325, -0.012100}}],
    Polygon[{{0.429227, 0.437422, 0.000000},{0.428321, 0.437717, 0.012100},{
      0.432060, 0.461325, 0.012100},{0.433013, 0.461325, 0.000000}}],
    Polygon[{{0.428321, 0.437717, 0.012100},{0.425626, 0.438592, 0.023903},{
      0.429227, 0.461325, 0.023903},{0.432060, 0.461325, 0.012100}}],
    Polygon[{{0.425626, 0.438592, 0.023903},{0.421209, 0.440028, 0.035116},{
      0.424582, 0.461325, 0.035116},{0.429227, 0.461325, 0.023903}}],
    Polygon[{{0.421209, 0.440028, 0.035116},{0.415177, 0.441987, 0.045465},{
      0.418240, 0.461325, 0.045465},{0.424582, 0.461325, 0.035116}}],
    Polygon[{{0.415177, 0.441987, 0.045465},{0.407680, 0.444423, 0.054695},{
      0.410357, 0.461325, 0.054695},{0.418240, 0.461325, 0.045465}}],
    Polygon[{{0.407680, 0.444423, 0.054695},{0.398903, 0.447275, 0.062578},{
      0.401128, 0.461325, 0.062578},{0.410357, 0.461325, 0.054695}}],
    Polygon[{{0.398903, 0.447275, 0.062578},{0.389060, 0.450473, 0.068920},{
      0.390779, 0.461325, 0.068920},{0.401128, 0.461325, 0.062578}}],
    Polygon[{{0.389060, 0.450473, 0.068920},{0.378395, 0.453939, 0.073564},{
      0.379565, 0.461325, 0.073564},{0.390779, 0.461325, 0.068920}}],
    Polygon[{{0.378395, 0.453939, 0.073564},{0.367170, 0.457586, 0.076398},{
      0.367763, 0.461325, 0.076398},{0.379565, 0.461325, 0.073564}}],
    Polygon[{{0.387682, 0.577350, -0.040942},{0.394007, 0.577350, -0.039423},{
      0.393380, 0.581309, -0.039423},{0.387365, 0.579354, -0.040942}}],
    Polygon[{{0.394007, 0.577350, -0.039423},{0.400017, 0.577350, -0.036934},{
      0.399096, 0.583166, -0.036934},{0.393380, 0.581309, -0.039423}}],
    Polygon[{{0.400017, 0.577350, -0.036934},{0.405563, 0.577350, -0.033535},{
      0.404370, 0.584879, -0.033535},{0.399096, 0.583166, -0.036934}}],
    Polygon[{{0.405563, 0.577350, -0.033535},{0.410509, 0.577350, -0.029311},{
      0.409074, 0.586408, -0.029311},{0.404370, 0.584879, -0.033535}}],
    Polygon[{{0.410509, 0.577350, -0.029311},{0.414733, 0.577350, -0.024365},{
      0.413092, 0.587713, -0.024365},{0.409074, 0.586408, -0.029311}}],
    Polygon[{{0.414733, 0.577350, -0.024365},{0.418132, 0.577350, -0.018819},{
      0.416324, 0.588763, -0.018819},{0.413092, 0.587713, -0.024365}}],
    Polygon[{{0.418132, 0.577350, -0.018819},{0.420621, 0.577350, -0.012809},{
      0.418691, 0.589533, -0.012809},{0.416324, 0.588763, -0.018819}}],
    Polygon[{{0.420621, 0.577350, -0.012809},{0.422139, 0.577350, -0.006485},{
      0.420136, 0.590002, -0.006485},{0.418691, 0.589533, -0.012809}}],
    Polygon[{{0.422139, 0.577350, -0.006485},{0.422650, 0.577350, 0.000000},{
      0.420621, 0.590160, 0.000000},{0.420136, 0.590002, -0.006485}}],
    Polygon[{{0.422650, 0.577350, 0.000000},{0.422139, 0.577350, 0.006485},{
      0.420136, 0.590002, 0.006485},{0.420621, 0.590160, 0.000000}}],
    Polygon[{{0.422139, 0.577350, 0.006485},{0.420621, 0.577350, 0.012809},{
      0.418691, 0.589533, 0.012809},{0.420136, 0.590002, 0.006485}}],
    Polygon[{{0.420621, 0.577350, 0.012809},{0.418132, 0.577350, 0.018819},{
      0.416324, 0.588763, 0.018819},{0.418691, 0.589533, 0.012809}}],
    Polygon[{{0.418132, 0.577350, 0.018819},{0.414733, 0.577350, 0.024365},{
      0.413092, 0.587713, 0.024365},{0.416324, 0.588763, 0.018819}}],
    Polygon[{{0.414733, 0.577350, 0.024365},{0.410509, 0.577350, 0.029311},{
      0.409074, 0.586408, 0.029311},{0.413092, 0.587713, 0.024365}}],
    Polygon[{{0.410509, 0.577350, 0.029311},{0.405563, 0.577350, 0.033535},{
      0.404370, 0.584879, 0.033535},{0.409074, 0.586408, 0.029311}}],
    Polygon[{{0.405563, 0.577350, 0.033535},{0.400017, 0.577350, 0.036934},{
      0.399096, 0.583166, 0.036934},{0.404370, 0.584879, 0.033535}}],
    Polygon[{{0.400017, 0.577350, 0.036934},{0.394007, 0.577350, 0.039423},{
      0.393380, 0.581309, 0.039423},{0.399096, 0.583166, 0.036934}}],
    Polygon[{{0.394007, 0.577350, 0.039423},{0.387682, 0.577350, 0.040942},{
      0.387365, 0.579354, 0.040942},{0.393380, 0.581309, 0.039423}}],
    Polygon[{{0.387365, 0.579354, -0.040942},{0.393380, 0.581309, -0.039423},{
      0.391561, 0.584879, -0.039423},{0.386444, 0.581162, -0.040942}}],
    Polygon[{{0.393380, 0.581309, -0.039423},{0.399096, 0.583166, -0.036934},{
      0.396423, 0.588412, -0.036934},{0.391561, 0.584879, -0.039423}}],
    Polygon[{{0.399096, 0.583166, -0.036934},{0.404370, 0.584879, -0.033535},{
      0.400909, 0.591672, -0.033535},{0.396423, 0.588412, -0.036934}}],
    Polygon[{{0.404370, 0.584879, -0.033535},{0.409074, 0.586408, -0.029311},{
      0.404911, 0.594579, -0.029311},{0.400909, 0.591672, -0.033535}}],
    Polygon[{{0.409074, 0.586408, -0.029311},{0.413092, 0.587713, -0.024365},{
      0.408328, 0.597062, -0.024365},{0.404911, 0.594579, -0.029311}}],
    Polygon[{{0.413092, 0.587713, -0.024365},{0.416324, 0.588763, -0.018819},{
      0.411078, 0.599059, -0.018819},{0.408328, 0.597062, -0.024365}}],
    Polygon[{{0.416324, 0.588763, -0.018819},{0.418691, 0.589533, -0.012809},{
      0.413092, 0.600523, -0.012809},{0.411078, 0.599059, -0.018819}}],
    Polygon[{{0.418691, 0.589533, -0.012809},{0.420136, 0.590002, -0.006485},{
      0.414320, 0.601415, -0.006485},{0.413092, 0.600523, -0.012809}}],
    Polygon[{{0.420136, 0.590002, -0.006485},{0.420621, 0.590160, 0.000000},{
      0.414733, 0.601715, 0.000000},{0.414320, 0.601415, -0.006485}}],
    Polygon[{{0.420621, 0.590160, 0.000000},{0.420136, 0.590002, 0.006485},{
      0.414320, 0.601415, 0.006485},{0.414733, 0.601715, 0.000000}}],
    Polygon[{{0.420136, 0.590002, 0.006485},{0.418691, 0.589533, 0.012809},{
      0.413092, 0.600523, 0.012809},{0.414320, 0.601415, 0.006485}}],
    Polygon[{{0.418691, 0.589533, 0.012809},{0.416324, 0.588763, 0.018819},{
      0.411078, 0.599059, 0.018819},{0.413092, 0.600523, 0.012809}}],
    Polygon[{{0.416324, 0.588763, 0.018819},{0.413092, 0.587713, 0.024365},{
      0.408328, 0.597062, 0.024365},{0.411078, 0.599059, 0.018819}}],
    Polygon[{{0.413092, 0.587713, 0.024365},{0.409074, 0.586408, 0.029311},{
      0.404911, 0.594579, 0.029311},{0.408328, 0.597062, 0.024365}}],
    Polygon[{{0.409074, 0.586408, 0.029311},{0.404370, 0.584879, 0.033535},{
      0.400909, 0.591672, 0.033535},{0.404911, 0.594579, 0.029311}}],
    Polygon[{{0.404370, 0.584879, 0.033535},{0.399096, 0.583166, 0.036934},{
      0.396423, 0.588412, 0.036934},{0.400909, 0.591672, 0.033535}}],
    Polygon[{{0.399096, 0.583166, 0.036934},{0.393380, 0.581309, 0.039423},{
      0.391561, 0.584879, 0.039423},{0.396423, 0.588412, 0.036934}}],
    Polygon[{{0.393380, 0.581309, 0.039423},{0.387365, 0.579354, 0.040942},{
      0.386444, 0.581162, 0.040942},{0.391561, 0.584879, 0.039423}}],
    Polygon[{{0.386444, 0.581162, -0.040942},{0.391561, 0.584879, -0.039423},{
      0.388727, 0.587713, -0.039423},{0.385009, 0.582596, -0.040942}}],
    Polygon[{{0.391561, 0.584879, -0.039423},{0.396423, 0.588412, -0.036934},{
      0.392259, 0.592575, -0.036934},{0.388727, 0.587713, -0.039423}}],
    Polygon[{{0.396423, 0.588412, -0.036934},{0.400909, 0.591672, -0.033535},{
      0.395519, 0.597062, -0.033535},{0.392259, 0.592575, -0.036934}}],
    Polygon[{{0.400909, 0.591672, -0.033535},{0.404911, 0.594579, -0.029311},{
      0.398426, 0.601063, -0.029311},{0.395519, 0.597062, -0.033535}}],
    Polygon[{{0.404911, 0.594579, -0.029311},{0.408328, 0.597062, -0.024365},{
      0.400909, 0.604481, -0.024365},{0.398426, 0.601063, -0.029311}}],
    Polygon[{{0.408328, 0.597062, -0.024365},{0.411078, 0.599059, -0.018819},{
      0.402907, 0.607230, -0.018819},{0.400909, 0.604481, -0.024365}}],
    Polygon[{{0.411078, 0.599059, -0.018819},{0.413092, 0.600523, -0.012809},{
      0.404370, 0.609244, -0.012809},{0.402907, 0.607230, -0.018819}}],
    Polygon[{{0.413092, 0.600523, -0.012809},{0.414320, 0.601415, -0.006485},{
      0.405263, 0.610473, -0.006485},{0.404370, 0.609244, -0.012809}}],
    Polygon[{{0.414320, 0.601415, -0.006485},{0.414733, 0.601715, 0.000000},{
      0.405563, 0.610886, 0.000000},{0.405263, 0.610473, -0.006485}}],
    Polygon[{{0.414733, 0.601715, 0.000000},{0.414320, 0.601415, 0.006485},{
      0.405263, 0.610473, 0.006485},{0.405563, 0.610886, 0.000000}}],
    Polygon[{{0.414320, 0.601415, 0.006485},{0.413092, 0.600523, 0.012809},{
      0.404370, 0.609244, 0.012809},{0.405263, 0.610473, 0.006485}}],
    Polygon[{{0.413092, 0.600523, 0.012809},{0.411078, 0.599059, 0.018819},{
      0.402907, 0.607230, 0.018819},{0.404370, 0.609244, 0.012809}}],
    Polygon[{{0.411078, 0.599059, 0.018819},{0.408328, 0.597062, 0.024365},{
      0.400909, 0.604481, 0.024365},{0.402907, 0.607230, 0.018819}}],
    Polygon[{{0.408328, 0.597062, 0.024365},{0.404911, 0.594579, 0.029311},{
      0.398426, 0.601063, 0.029311},{0.400909, 0.604481, 0.024365}}],
    Polygon[{{0.404911, 0.594579, 0.029311},{0.400909, 0.591672, 0.033535},{
      0.395519, 0.597062, 0.033535},{0.398426, 0.601063, 0.029311}}],
    Polygon[{{0.400909, 0.591672, 0.033535},{0.396423, 0.588412, 0.036934},{
      0.392259, 0.592575, 0.036934},{0.395519, 0.597062, 0.033535}}],
    Polygon[{{0.396423, 0.588412, 0.036934},{0.391561, 0.584879, 0.039423},{
      0.388727, 0.587713, 0.039423},{0.392259, 0.592575, 0.036934}}],
    Polygon[{{0.391561, 0.584879, 0.039423},{0.386444, 0.581162, 0.040942},{
      0.385009, 0.582596, 0.040942},{0.388727, 0.587713, 0.039423}}],
    Polygon[{{0.385009, 0.582596, -0.040942},{0.388727, 0.587713, -0.039423},{
      0.385156, 0.589533, -0.039423},{0.383202, 0.583517, -0.040942}}],
    Polygon[{{0.388727, 0.587713, -0.039423},{0.392259, 0.592575, -0.036934},{
      0.387013, 0.595248, -0.036934},{0.385156, 0.589533, -0.039423}}],
    Polygon[{{0.392259, 0.592575, -0.036934},{0.395519, 0.597062, -0.033535},{
      0.388727, 0.600523, -0.033535},{0.387013, 0.595248, -0.036934}}],
    Polygon[{{0.395519, 0.597062, -0.033535},{0.398426, 0.601063, -0.029311},{
      0.390255, 0.605227, -0.029311},{0.388727, 0.600523, -0.033535}}],
    Polygon[{{0.398426, 0.601063, -0.029311},{0.400909, 0.604481, -0.024365},{
      0.391561, 0.609244, -0.024365},{0.390255, 0.605227, -0.029311}}],
    Polygon[{{0.400909, 0.604481, -0.024365},{0.402907, 0.607230, -0.018819},{
      0.392611, 0.612476, -0.018819},{0.391561, 0.609244, -0.024365}}],
    Polygon[{{0.402907, 0.607230, -0.018819},{0.404370, 0.609244, -0.012809},{
      0.393380, 0.614844, -0.012809},{0.392611, 0.612476, -0.018819}}],
    Polygon[{{0.404370, 0.609244, -0.012809},{0.405263, 0.610473, -0.006485},{
      0.393849, 0.616288, -0.006485},{0.393380, 0.614844, -0.012809}}],
    Polygon[{{0.405263, 0.610473, -0.006485},{0.405563, 0.610886, 0.000000},{
      0.394007, 0.616773, 0.000000},{0.393849, 0.616288, -0.006485}}],
    Polygon[{{0.405563, 0.610886, 0.000000},{0.405263, 0.610473, 0.006485},{
      0.393849, 0.616288, 0.006485},{0.394007, 0.616773, 0.000000}}],
    Polygon[{{0.405263, 0.610473, 0.006485},{0.404370, 0.609244, 0.012809},{
      0.393380, 0.614844, 0.012809},{0.393849, 0.616288, 0.006485}}],
    Polygon[{{0.404370, 0.609244, 0.012809},{0.402907, 0.607230, 0.018819},{
      0.392611, 0.612476, 0.018819},{0.393380, 0.614844, 0.012809}}],
    Polygon[{{0.402907, 0.607230, 0.018819},{0.400909, 0.604481, 0.024365},{
      0.391561, 0.609244, 0.024365},{0.392611, 0.612476, 0.018819}}],
    Polygon[{{0.400909, 0.604481, 0.024365},{0.398426, 0.601063, 0.029311},{
      0.390255, 0.605227, 0.029311},{0.391561, 0.609244, 0.024365}}],
    Polygon[{{0.398426, 0.601063, 0.029311},{0.395519, 0.597062, 0.033535},{
      0.388727, 0.600523, 0.033535},{0.390255, 0.605227, 0.029311}}],
    Polygon[{{0.395519, 0.597062, 0.033535},{0.392259, 0.592575, 0.036934},{
      0.387013, 0.595248, 0.036934},{0.388727, 0.600523, 0.033535}}],
    Polygon[{{0.392259, 0.592575, 0.036934},{0.388727, 0.587713, 0.039423},{
      0.385156, 0.589533, 0.039423},{0.387013, 0.595248, 0.036934}}],
    Polygon[{{0.388727, 0.587713, 0.039423},{0.385009, 0.582596, 0.040942},{
      0.383202, 0.583517, 0.040942},{0.385156, 0.589533, 0.039423}}],
    Polygon[{{0.383202, 0.583517, -0.040942},{0.385156, 0.589533, -0.039423},{
      0.381198, 0.590160, -0.039423},{0.381198, 0.583835, -0.040942}}],
    Polygon[{{0.385156, 0.589533, -0.039423},{0.387013, 0.595248, -0.036934},{
      0.381198, 0.596169, -0.036934},{0.381198, 0.590160, -0.039423}}],
    Polygon[{{0.387013, 0.595248, -0.036934},{0.388727, 0.600523, -0.033535},{
      0.381198, 0.601715, -0.033535},{0.381198, 0.596169, -0.036934}}],
    Polygon[{{0.388727, 0.600523, -0.033535},{0.390255, 0.605227, -0.029311},{
      0.381198, 0.606661, -0.029311},{0.381198, 0.601715, -0.033535}}],
    Polygon[{{0.390255, 0.605227, -0.029311},{0.391561, 0.609244, -0.024365},{
      0.381198, 0.610886, -0.024365},{0.381198, 0.606661, -0.029311}}],
    Polygon[{{0.391561, 0.609244, -0.024365},{0.392611, 0.612476, -0.018819},{
      0.381198, 0.614284, -0.018819},{0.381198, 0.610886, -0.024365}}],
    Polygon[{{0.392611, 0.612476, -0.018819},{0.393380, 0.614844, -0.012809},{
      0.381198, 0.616773, -0.012809},{0.381198, 0.614284, -0.018819}}],
    Polygon[{{0.393380, 0.614844, -0.012809},{0.393849, 0.616288, -0.006485},{
      0.381198, 0.618292, -0.006485},{0.381198, 0.616773, -0.012809}}],
    Polygon[{{0.393849, 0.616288, -0.006485},{0.394007, 0.616773, 0.000000},{
      0.381198, 0.618802, 0.000000},{0.381198, 0.618292, -0.006485}}],
    Polygon[{{0.394007, 0.616773, 0.000000},{0.393849, 0.616288, 0.006485},{
      0.381198, 0.618292, 0.006485},{0.381198, 0.618802, 0.000000}}],
    Polygon[{{0.393849, 0.616288, 0.006485},{0.393380, 0.614844, 0.012809},{
      0.381198, 0.616773, 0.012809},{0.381198, 0.618292, 0.006485}}],
    Polygon[{{0.393380, 0.614844, 0.012809},{0.392611, 0.612476, 0.018819},{
      0.381198, 0.614284, 0.018819},{0.381198, 0.616773, 0.012809}}],
    Polygon[{{0.392611, 0.612476, 0.018819},{0.391561, 0.609244, 0.024365},{
      0.381198, 0.610886, 0.024365},{0.381198, 0.614284, 0.018819}}],
    Polygon[{{0.391561, 0.609244, 0.024365},{0.390255, 0.605227, 0.029311},{
      0.381198, 0.606661, 0.029311},{0.381198, 0.610886, 0.024365}}],
    Polygon[{{0.390255, 0.605227, 0.029311},{0.388727, 0.600523, 0.033535},{
      0.381198, 0.601715, 0.033535},{0.381198, 0.606661, 0.029311}}],
    Polygon[{{0.388727, 0.600523, 0.033535},{0.387013, 0.595248, 0.036934},{
      0.381198, 0.596169, 0.036934},{0.381198, 0.601715, 0.033535}}],
    Polygon[{{0.387013, 0.595248, 0.036934},{0.385156, 0.589533, 0.039423},{
      0.381198, 0.590160, 0.039423},{0.381198, 0.596169, 0.036934}}],
    Polygon[{{0.385156, 0.589533, 0.039423},{0.383202, 0.583517, 0.040942},{
      0.381198, 0.583835, 0.040942},{0.381198, 0.590160, 0.039423}}],
    Polygon[{{0.381198, 0.583835, -0.040942},{0.381198, 0.590160, -0.039423},{
      0.377240, 0.589533, -0.039423},{0.379194, 0.583517, -0.040942}}],
    Polygon[{{0.381198, 0.590160, -0.039423},{0.381198, 0.596169, -0.036934},{
      0.375383, 0.595248, -0.036934},{0.377240, 0.589533, -0.039423}}],
    Polygon[{{0.381198, 0.596169, -0.036934},{0.381198, 0.601715, -0.033535},{
      0.373669, 0.600523, -0.033535},{0.375383, 0.595248, -0.036934}}],
    Polygon[{{0.381198, 0.601715, -0.033535},{0.381198, 0.606661, -0.029311},{
      0.372140, 0.605227, -0.029311},{0.373669, 0.600523, -0.033535}}],
    Polygon[{{0.381198, 0.606661, -0.029311},{0.381198, 0.610886, -0.024365},{
      0.370835, 0.609244, -0.024365},{0.372140, 0.605227, -0.029311}}],
    Polygon[{{0.381198, 0.610886, -0.024365},{0.381198, 0.614284, -0.018819},{
      0.369785, 0.612476, -0.018819},{0.370835, 0.609244, -0.024365}}],
    Polygon[{{0.381198, 0.614284, -0.018819},{0.381198, 0.616773, -0.012809},{
      0.369015, 0.614844, -0.012809},{0.369785, 0.612476, -0.018819}}],
    Polygon[{{0.381198, 0.616773, -0.012809},{0.381198, 0.618292, -0.006485},{
      0.368546, 0.616288, -0.006485},{0.369015, 0.614844, -0.012809}}],
    Polygon[{{0.381198, 0.618292, -0.006485},{0.381198, 0.618802, 0.000000},{
      0.368389, 0.616773, 0.000000},{0.368546, 0.616288, -0.006485}}],
    Polygon[{{0.381198, 0.618802, 0.000000},{0.381198, 0.618292, 0.006485},{
      0.368546, 0.616288, 0.006485},{0.368389, 0.616773, 0.000000}}],
    Polygon[{{0.381198, 0.618292, 0.006485},{0.381198, 0.616773, 0.012809},{
      0.369015, 0.614844, 0.012809},{0.368546, 0.616288, 0.006485}}],
    Polygon[{{0.381198, 0.616773, 0.012809},{0.381198, 0.614284, 0.018819},{
      0.369785, 0.612476, 0.018819},{0.369015, 0.614844, 0.012809}}],
    Polygon[{{0.381198, 0.614284, 0.018819},{0.381198, 0.610886, 0.024365},{
      0.370835, 0.609244, 0.024365},{0.369785, 0.612476, 0.018819}}],
    Polygon[{{0.381198, 0.610886, 0.024365},{0.381198, 0.606661, 0.029311},{
      0.372140, 0.605227, 0.029311},{0.370835, 0.609244, 0.024365}}],
    Polygon[{{0.381198, 0.606661, 0.029311},{0.381198, 0.601715, 0.033535},{
      0.373669, 0.600523, 0.033535},{0.372140, 0.605227, 0.029311}}],
    Polygon[{{0.381198, 0.601715, 0.033535},{0.381198, 0.596169, 0.036934},{
      0.375383, 0.595248, 0.036934},{0.373669, 0.600523, 0.033535}}],
    Polygon[{{0.381198, 0.596169, 0.036934},{0.381198, 0.590160, 0.039423},{
      0.377240, 0.589533, 0.039423},{0.375383, 0.595248, 0.036934}}],
    Polygon[{{0.381198, 0.590160, 0.039423},{0.381198, 0.583835, 0.040942},{
      0.379194, 0.583517, 0.040942},{0.377240, 0.589533, 0.039423}}],
    Polygon[{{0.379194, 0.583517, -0.040942},{0.377240, 0.589533, -0.039423},{
      0.373669, 0.587713, -0.039423},{0.377386, 0.582596, -0.040942}}],
    Polygon[{{0.377240, 0.589533, -0.039423},{0.375383, 0.595248, -0.036934},{
      0.370136, 0.592575, -0.036934},{0.373669, 0.587713, -0.039423}}],
    Polygon[{{0.375383, 0.595248, -0.036934},{0.373669, 0.600523, -0.033535},{
      0.366877, 0.597062, -0.033535},{0.370136, 0.592575, -0.036934}}],
    Polygon[{{0.373669, 0.600523, -0.033535},{0.372140, 0.605227, -0.029311},{
      0.363969, 0.601063, -0.029311},{0.366877, 0.597062, -0.033535}}],
    Polygon[{{0.372140, 0.605227, -0.029311},{0.370835, 0.609244, -0.024365},{
      0.361486, 0.604481, -0.024365},{0.363969, 0.601063, -0.029311}}],
    Polygon[{{0.370835, 0.609244, -0.024365},{0.369785, 0.612476, -0.018819},{
      0.359489, 0.607230, -0.018819},{0.361486, 0.604481, -0.024365}}],
    Polygon[{{0.369785, 0.612476, -0.018819},{0.369015, 0.614844, -0.012809},{
      0.358026, 0.609244, -0.012809},{0.359489, 0.607230, -0.018819}}],
    Polygon[{{0.369015, 0.614844, -0.012809},{0.368546, 0.616288, -0.006485},{
      0.357133, 0.610473, -0.006485},{0.358026, 0.609244, -0.012809}}],
    Polygon[{{0.368546, 0.616288, -0.006485},{0.368389, 0.616773, 0.000000},{
      0.356833, 0.610886, 0.000000},{0.357133, 0.610473, -0.006485}}],
    Polygon[{{0.368389, 0.616773, 0.000000},{0.368546, 0.616288, 0.006485},{
      0.357133, 0.610473, 0.006485},{0.356833, 0.610886, 0.000000}}],
    Polygon[{{0.368546, 0.616288, 0.006485},{0.369015, 0.614844, 0.012809},{
      0.358026, 0.609244, 0.012809},{0.357133, 0.610473, 0.006485}}],
    Polygon[{{0.369015, 0.614844, 0.012809},{0.369785, 0.612476, 0.018819},{
      0.359489, 0.607230, 0.018819},{0.358026, 0.609244, 0.012809}}],
    Polygon[{{0.369785, 0.612476, 0.018819},{0.370835, 0.609244, 0.024365},{
      0.361486, 0.604481, 0.024365},{0.359489, 0.607230, 0.018819}}],
    Polygon[{{0.370835, 0.609244, 0.024365},{0.372140, 0.605227, 0.029311},{
      0.363969, 0.601063, 0.029311},{0.361486, 0.604481, 0.024365}}],
    Polygon[{{0.372140, 0.605227, 0.029311},{0.373669, 0.600523, 0.033535},{
      0.366877, 0.597062, 0.033535},{0.363969, 0.601063, 0.029311}}],
    Polygon[{{0.373669, 0.600523, 0.033535},{0.375383, 0.595248, 0.036934},{
      0.370136, 0.592575, 0.036934},{0.366877, 0.597062, 0.033535}}],
    Polygon[{{0.375383, 0.595248, 0.036934},{0.377240, 0.589533, 0.039423},{
      0.373669, 0.587713, 0.039423},{0.370136, 0.592575, 0.036934}}],
    Polygon[{{0.377240, 0.589533, 0.039423},{0.379194, 0.583517, 0.040942},{
      0.377386, 0.582596, 0.040942},{0.373669, 0.587713, 0.039423}}],
    Polygon[{{0.377386, 0.582596, -0.040942},{0.373669, 0.587713, -0.039423},{
      0.370835, 0.584879, -0.039423},{0.375952, 0.581162, -0.040942}}],
    Polygon[{{0.373669, 0.587713, -0.039423},{0.370136, 0.592575, -0.036934},{
      0.365973, 0.588412, -0.036934},{0.370835, 0.584879, -0.039423}}],
    Polygon[{{0.370136, 0.592575, -0.036934},{0.366877, 0.597062, -0.033535},{
      0.361486, 0.591672, -0.033535},{0.365973, 0.588412, -0.036934}}],
    Polygon[{{0.366877, 0.597062, -0.033535},{0.363969, 0.601063, -0.029311},{
      0.357485, 0.594579, -0.029311},{0.361486, 0.591672, -0.033535}}],
    Polygon[{{0.363969, 0.601063, -0.029311},{0.361486, 0.604481, -0.024365},{
      0.354067, 0.597062, -0.024365},{0.357485, 0.594579, -0.029311}}],
    Polygon[{{0.361486, 0.604481, -0.024365},{0.359489, 0.607230, -0.018819},{
      0.351318, 0.599059, -0.018819},{0.354067, 0.597062, -0.024365}}],
    Polygon[{{0.359489, 0.607230, -0.018819},{0.358026, 0.609244, -0.012809},{
      0.349304, 0.600523, -0.012809},{0.351318, 0.599059, -0.018819}}],
    Polygon[{{0.358026, 0.609244, -0.012809},{0.357133, 0.610473, -0.006485},{
      0.348075, 0.601415, -0.006485},{0.349304, 0.600523, -0.012809}}],
    Polygon[{{0.357133, 0.610473, -0.006485},{0.356833, 0.610886, 0.000000},{
      0.347663, 0.601715, 0.000000},{0.348075, 0.601415, -0.006485}}],
    Polygon[{{0.356833, 0.610886, 0.000000},{0.357133, 0.610473, 0.006485},{
      0.348075, 0.601415, 0.006485},{0.347663, 0.601715, 0.000000}}],
    Polygon[{{0.357133, 0.610473, 0.006485},{0.358026, 0.609244, 0.012809},{
      0.349304, 0.600523, 0.012809},{0.348075, 0.601415, 0.006485}}],
    Polygon[{{0.358026, 0.609244, 0.012809},{0.359489, 0.607230, 0.018819},{
      0.351318, 0.599059, 0.018819},{0.349304, 0.600523, 0.012809}}],
    Polygon[{{0.359489, 0.607230, 0.018819},{0.361486, 0.604481, 0.024365},{
      0.354067, 0.597062, 0.024365},{0.351318, 0.599059, 0.018819}}],
    Polygon[{{0.361486, 0.604481, 0.024365},{0.363969, 0.601063, 0.029311},{
      0.357485, 0.594579, 0.029311},{0.354067, 0.597062, 0.024365}}],
    Polygon[{{0.363969, 0.601063, 0.029311},{0.366877, 0.597062, 0.033535},{
      0.361486, 0.591672, 0.033535},{0.357485, 0.594579, 0.029311}}],
    Polygon[{{0.366877, 0.597062, 0.033535},{0.370136, 0.592575, 0.036934},{
      0.365973, 0.588412, 0.036934},{0.361486, 0.591672, 0.033535}}],
    Polygon[{{0.370136, 0.592575, 0.036934},{0.373669, 0.587713, 0.039423},{
      0.370835, 0.584879, 0.039423},{0.365973, 0.588412, 0.036934}}],
    Polygon[{{0.373669, 0.587713, 0.039423},{0.377386, 0.582596, 0.040942},{
      0.375952, 0.581162, 0.040942},{0.370835, 0.584879, 0.039423}}],
    Polygon[{{0.375952, 0.581162, -0.040942},{0.370835, 0.584879, -0.039423},{
      0.369015, 0.581309, -0.039423},{0.375031, 0.579354, -0.040942}}],
    Polygon[{{0.370835, 0.584879, -0.039423},{0.365973, 0.588412, -0.036934},{
      0.363300, 0.583166, -0.036934},{0.369015, 0.581309, -0.039423}}],
    Polygon[{{0.365973, 0.588412, -0.036934},{0.361486, 0.591672, -0.033535},{
      0.358026, 0.584879, -0.033535},{0.363300, 0.583166, -0.036934}}],
    Polygon[{{0.361486, 0.591672, -0.033535},{0.357485, 0.594579, -0.029311},{
      0.353322, 0.586408, -0.029311},{0.358026, 0.584879, -0.033535}}],
    Polygon[{{0.357485, 0.594579, -0.029311},{0.354067, 0.597062, -0.024365},{
      0.349304, 0.587713, -0.024365},{0.353322, 0.586408, -0.029311}}],
    Polygon[{{0.354067, 0.597062, -0.024365},{0.351318, 0.599059, -0.018819},{
      0.346072, 0.588763, -0.018819},{0.349304, 0.587713, -0.024365}}],
    Polygon[{{0.351318, 0.599059, -0.018819},{0.349304, 0.600523, -0.012809},{
      0.343704, 0.589533, -0.012809},{0.346072, 0.588763, -0.018819}}],
    Polygon[{{0.349304, 0.600523, -0.012809},{0.348075, 0.601415, -0.006485},{
      0.342260, 0.590002, -0.006485},{0.343704, 0.589533, -0.012809}}],
    Polygon[{{0.348075, 0.601415, -0.006485},{0.347663, 0.601715, 0.000000},{
      0.341775, 0.590160, 0.000000},{0.342260, 0.590002, -0.006485}}],
    Polygon[{{0.347663, 0.601715, 0.000000},{0.348075, 0.601415, 0.006485},{
      0.342260, 0.590002, 0.006485},{0.341775, 0.590160, 0.000000}}],
    Polygon[{{0.348075, 0.601415, 0.006485},{0.349304, 0.600523, 0.012809},{
      0.343704, 0.589533, 0.012809},{0.342260, 0.590002, 0.006485}}],
    Polygon[{{0.349304, 0.600523, 0.012809},{0.351318, 0.599059, 0.018819},{
      0.346072, 0.588763, 0.018819},{0.343704, 0.589533, 0.012809}}],
    Polygon[{{0.351318, 0.599059, 0.018819},{0.354067, 0.597062, 0.024365},{
      0.349304, 0.587713, 0.024365},{0.346072, 0.588763, 0.018819}}],
    Polygon[{{0.354067, 0.597062, 0.024365},{0.357485, 0.594579, 0.029311},{
      0.353322, 0.586408, 0.029311},{0.349304, 0.587713, 0.024365}}],
    Polygon[{{0.357485, 0.594579, 0.029311},{0.361486, 0.591672, 0.033535},{
      0.358026, 0.584879, 0.033535},{0.353322, 0.586408, 0.029311}}],
    Polygon[{{0.361486, 0.591672, 0.033535},{0.365973, 0.588412, 0.036934},{
      0.363300, 0.583166, 0.036934},{0.358026, 0.584879, 0.033535}}],
    Polygon[{{0.365973, 0.588412, 0.036934},{0.370835, 0.584879, 0.039423},{
      0.369015, 0.581309, 0.039423},{0.363300, 0.583166, 0.036934}}],
    Polygon[{{0.370835, 0.584879, 0.039423},{0.375952, 0.581162, 0.040942},{
      0.375031, 0.579354, 0.040942},{0.369015, 0.581309, 0.039423}}],
    Polygon[{{0.375031, 0.579354, -0.040942},{0.369015, 0.581309, -0.039423},{
      0.368389, 0.577350, -0.039423},{0.374713, 0.577350, -0.040942}}],
    Polygon[{{0.369015, 0.581309, -0.039423},{0.363300, 0.583166, -0.036934},{
      0.362379, 0.577350, -0.036934},{0.368389, 0.577350, -0.039423}}],
    Polygon[{{0.363300, 0.583166, -0.036934},{0.358026, 0.584879, -0.033535},{
      0.356833, 0.577350, -0.033535},{0.362379, 0.577350, -0.036934}}],
    Polygon[{{0.358026, 0.584879, -0.033535},{0.353322, 0.586408, -0.029311},{
      0.351887, 0.577350, -0.029311},{0.356833, 0.577350, -0.033535}}],
    Polygon[{{0.353322, 0.586408, -0.029311},{0.349304, 0.587713, -0.024365},{
      0.347663, 0.577350, -0.024365},{0.351887, 0.577350, -0.029311}}],
    Polygon[{{0.349304, 0.587713, -0.024365},{0.346072, 0.588763, -0.018819},{
      0.344264, 0.577350, -0.018819},{0.347663, 0.577350, -0.024365}}],
    Polygon[{{0.346072, 0.588763, -0.018819},{0.343704, 0.589533, -0.012809},{
      0.341775, 0.577350, -0.012809},{0.344264, 0.577350, -0.018819}}],
    Polygon[{{0.343704, 0.589533, -0.012809},{0.342260, 0.590002, -0.006485},{
      0.340256, 0.577350, -0.006485},{0.341775, 0.577350, -0.012809}}],
    Polygon[{{0.342260, 0.590002, -0.006485},{0.341775, 0.590160, 0.000000},{
      0.339746, 0.577350, 0.000000},{0.340256, 0.577350, -0.006485}}],
    Polygon[{{0.341775, 0.590160, 0.000000},{0.342260, 0.590002, 0.006485},{
      0.340256, 0.577350, 0.006485},{0.339746, 0.577350, 0.000000}}],
    Polygon[{{0.342260, 0.590002, 0.006485},{0.343704, 0.589533, 0.012809},{
      0.341775, 0.577350, 0.012809},{0.340256, 0.577350, 0.006485}}],
    Polygon[{{0.343704, 0.589533, 0.012809},{0.346072, 0.588763, 0.018819},{
      0.344264, 0.577350, 0.018819},{0.341775, 0.577350, 0.012809}}],
    Polygon[{{0.346072, 0.588763, 0.018819},{0.349304, 0.587713, 0.024365},{
      0.347663, 0.577350, 0.024365},{0.344264, 0.577350, 0.018819}}],
    Polygon[{{0.349304, 0.587713, 0.024365},{0.353322, 0.586408, 0.029311},{
      0.351887, 0.577350, 0.029311},{0.347663, 0.577350, 0.024365}}],
    Polygon[{{0.353322, 0.586408, 0.029311},{0.358026, 0.584879, 0.033535},{
      0.356833, 0.577350, 0.033535},{0.351887, 0.577350, 0.029311}}],
    Polygon[{{0.358026, 0.584879, 0.033535},{0.363300, 0.583166, 0.036934},{
      0.362379, 0.577350, 0.036934},{0.356833, 0.577350, 0.033535}}],
    Polygon[{{0.363300, 0.583166, 0.036934},{0.369015, 0.581309, 0.039423},{
      0.368389, 0.577350, 0.039423},{0.362379, 0.577350, 0.036934}}],
    Polygon[{{0.369015, 0.581309, 0.039423},{0.375031, 0.579354, 0.040942},{
      0.374713, 0.577350, 0.040942},{0.368389, 0.577350, 0.039423}}],
    Polygon[{{0.374713, 0.577350, -0.040942},{0.368389, 0.577350, -0.039423},{
      0.369015, 0.573392, -0.039423},{0.375031, 0.575346, -0.040942}}],
    Polygon[{{0.368389, 0.577350, -0.039423},{0.362379, 0.577350, -0.036934},{
      0.363300, 0.571535, -0.036934},{0.369015, 0.573392, -0.039423}}],
    Polygon[{{0.362379, 0.577350, -0.036934},{0.356833, 0.577350, -0.033535},{
      0.358026, 0.569821, -0.033535},{0.363300, 0.571535, -0.036934}}],
    Polygon[{{0.356833, 0.577350, -0.033535},{0.351887, 0.577350, -0.029311},{
      0.353322, 0.568293, -0.029311},{0.358026, 0.569821, -0.033535}}],
    Polygon[{{0.351887, 0.577350, -0.029311},{0.347663, 0.577350, -0.024365},{
      0.349304, 0.566987, -0.024365},{0.353322, 0.568293, -0.029311}}],
    Polygon[{{0.347663, 0.577350, -0.024365},{0.344264, 0.577350, -0.018819},{
      0.346072, 0.565937, -0.018819},{0.349304, 0.566987, -0.024365}}],
    Polygon[{{0.344264, 0.577350, -0.018819},{0.341775, 0.577350, -0.012809},{
      0.343704, 0.565168, -0.012809},{0.346072, 0.565937, -0.018819}}],
    Polygon[{{0.341775, 0.577350, -0.012809},{0.340256, 0.577350, -0.006485},{
      0.342260, 0.564699, -0.006485},{0.343704, 0.565168, -0.012809}}],
    Polygon[{{0.340256, 0.577350, -0.006485},{0.339746, 0.577350, 0.000000},{
      0.341775, 0.564541, 0.000000},{0.342260, 0.564699, -0.006485}}],
    Polygon[{{0.339746, 0.577350, 0.000000},{0.340256, 0.577350, 0.006485},{
      0.342260, 0.564699, 0.006485},{0.341775, 0.564541, 0.000000}}],
    Polygon[{{0.340256, 0.577350, 0.006485},{0.341775, 0.577350, 0.012809},{
      0.343704, 0.565168, 0.012809},{0.342260, 0.564699, 0.006485}}],
    Polygon[{{0.341775, 0.577350, 0.012809},{0.344264, 0.577350, 0.018819},{
      0.346072, 0.565937, 0.018819},{0.343704, 0.565168, 0.012809}}],
    Polygon[{{0.344264, 0.577350, 0.018819},{0.347663, 0.577350, 0.024365},{
      0.349304, 0.566987, 0.024365},{0.346072, 0.565937, 0.018819}}],
    Polygon[{{0.347663, 0.577350, 0.024365},{0.351887, 0.577350, 0.029311},{
      0.353322, 0.568293, 0.029311},{0.349304, 0.566987, 0.024365}}],
    Polygon[{{0.351887, 0.577350, 0.029311},{0.356833, 0.577350, 0.033535},{
      0.358026, 0.569821, 0.033535},{0.353322, 0.568293, 0.029311}}],
    Polygon[{{0.356833, 0.577350, 0.033535},{0.362379, 0.577350, 0.036934},{
      0.363300, 0.571535, 0.036934},{0.358026, 0.569821, 0.033535}}],
    Polygon[{{0.362379, 0.577350, 0.036934},{0.368389, 0.577350, 0.039423},{
      0.369015, 0.573392, 0.039423},{0.363300, 0.571535, 0.036934}}],
    Polygon[{{0.368389, 0.577350, 0.039423},{0.374713, 0.577350, 0.040942},{
      0.375031, 0.575346, 0.040942},{0.369015, 0.573392, 0.039423}}],
    Polygon[{{0.375031, 0.575346, -0.040942},{0.369015, 0.573392, -0.039423},{
      0.370835, 0.569821, -0.039423},{0.375952, 0.573539, -0.040942}}],
    Polygon[{{0.369015, 0.573392, -0.039423},{0.363300, 0.571535, -0.036934},{
      0.365973, 0.566289, -0.036934},{0.370835, 0.569821, -0.039423}}],
    Polygon[{{0.363300, 0.571535, -0.036934},{0.358026, 0.569821, -0.033535},{
      0.361486, 0.563029, -0.033535},{0.365973, 0.566289, -0.036934}}],
    Polygon[{{0.358026, 0.569821, -0.033535},{0.353322, 0.568293, -0.029311},{
      0.357485, 0.560122, -0.029311},{0.361486, 0.563029, -0.033535}}],
    Polygon[{{0.353322, 0.568293, -0.029311},{0.349304, 0.566987, -0.024365},{
      0.354067, 0.557639, -0.024365},{0.357485, 0.560122, -0.029311}}],
    Polygon[{{0.349304, 0.566987, -0.024365},{0.346072, 0.565937, -0.018819},{
      0.351318, 0.555641, -0.018819},{0.354067, 0.557639, -0.024365}}],
    Polygon[{{0.346072, 0.565937, -0.018819},{0.343704, 0.565168, -0.012809},{
      0.349304, 0.554178, -0.012809},{0.351318, 0.555641, -0.018819}}],
    Polygon[{{0.343704, 0.565168, -0.012809},{0.342260, 0.564699, -0.006485},{
      0.348075, 0.553285, -0.006485},{0.349304, 0.554178, -0.012809}}],
    Polygon[{{0.342260, 0.564699, -0.006485},{0.341775, 0.564541, 0.000000},{
      0.347663, 0.552985, 0.000000},{0.348075, 0.553285, -0.006485}}],
    Polygon[{{0.341775, 0.564541, 0.000000},{0.342260, 0.564699, 0.006485},{
      0.348075, 0.553285, 0.006485},{0.347663, 0.552985, 0.000000}}],
    Polygon[{{0.342260, 0.564699, 0.006485},{0.343704, 0.565168, 0.012809},{
      0.349304, 0.554178, 0.012809},{0.348075, 0.553285, 0.006485}}],
    Polygon[{{0.343704, 0.565168, 0.012809},{0.346072, 0.565937, 0.018819},{
      0.351318, 0.555641, 0.018819},{0.349304, 0.554178, 0.012809}}],
    Polygon[{{0.346072, 0.565937, 0.018819},{0.349304, 0.566987, 0.024365},{
      0.354067, 0.557639, 0.024365},{0.351318, 0.555641, 0.018819}}],
    Polygon[{{0.349304, 0.566987, 0.024365},{0.353322, 0.568293, 0.029311},{
      0.357485, 0.560122, 0.029311},{0.354067, 0.557639, 0.024365}}],
    Polygon[{{0.353322, 0.568293, 0.029311},{0.358026, 0.569821, 0.033535},{
      0.361486, 0.563029, 0.033535},{0.357485, 0.560122, 0.029311}}],
    Polygon[{{0.358026, 0.569821, 0.033535},{0.363300, 0.571535, 0.036934},{
      0.365973, 0.566289, 0.036934},{0.361486, 0.563029, 0.033535}}],
    Polygon[{{0.363300, 0.571535, 0.036934},{0.369015, 0.573392, 0.039423},{
      0.370835, 0.569821, 0.039423},{0.365973, 0.566289, 0.036934}}],
    Polygon[{{0.369015, 0.573392, 0.039423},{0.375031, 0.575346, 0.040942},{
      0.375952, 0.573539, 0.040942},{0.370835, 0.569821, 0.039423}}],
    Polygon[{{0.375952, 0.573539, -0.040942},{0.370835, 0.569821, -0.039423},{
      0.373669, 0.566987, -0.039423},{0.377386, 0.572104, -0.040942}}],
    Polygon[{{0.370835, 0.569821, -0.039423},{0.365973, 0.566289, -0.036934},{
      0.370136, 0.562126, -0.036934},{0.373669, 0.566987, -0.039423}}],
    Polygon[{{0.365973, 0.566289, -0.036934},{0.361486, 0.563029, -0.033535},{
      0.366877, 0.557639, -0.033535},{0.370136, 0.562126, -0.036934}}],
    Polygon[{{0.361486, 0.563029, -0.033535},{0.357485, 0.560122, -0.029311},{
      0.363969, 0.553637, -0.029311},{0.366877, 0.557639, -0.033535}}],
    Polygon[{{0.357485, 0.560122, -0.029311},{0.354067, 0.557639, -0.024365},{
      0.361486, 0.550220, -0.024365},{0.363969, 0.553637, -0.029311}}],
    Polygon[{{0.354067, 0.557639, -0.024365},{0.351318, 0.555641, -0.018819},{
      0.359489, 0.547470, -0.018819},{0.361486, 0.550220, -0.024365}}],
    Polygon[{{0.351318, 0.555641, -0.018819},{0.349304, 0.554178, -0.012809},{
      0.358026, 0.545456, -0.012809},{0.359489, 0.547470, -0.018819}}],
    Polygon[{{0.349304, 0.554178, -0.012809},{0.348075, 0.553285, -0.006485},{
      0.357133, 0.544228, -0.006485},{0.358026, 0.545456, -0.012809}}],
    Polygon[{{0.348075, 0.553285, -0.006485},{0.347663, 0.552985, 0.000000},{
      0.356833, 0.543815, 0.000000},{0.357133, 0.544228, -0.006485}}],
    Polygon[{{0.347663, 0.552985, 0.000000},{0.348075, 0.553285, 0.006485},{
      0.357133, 0.544228, 0.006485},{0.356833, 0.543815, 0.000000}}],
    Polygon[{{0.348075, 0.553285, 0.006485},{0.349304, 0.554178, 0.012809},{
      0.358026, 0.545456, 0.012809},{0.357133, 0.544228, 0.006485}}],
    Polygon[{{0.349304, 0.554178, 0.012809},{0.351318, 0.555641, 0.018819},{
      0.359489, 0.547470, 0.018819},{0.358026, 0.545456, 0.012809}}],
    Polygon[{{0.351318, 0.555641, 0.018819},{0.354067, 0.557639, 0.024365},{
      0.361486, 0.550220, 0.024365},{0.359489, 0.547470, 0.018819}}],
    Polygon[{{0.354067, 0.557639, 0.024365},{0.357485, 0.560122, 0.029311},{
      0.363969, 0.553637, 0.029311},{0.361486, 0.550220, 0.024365}}],
    Polygon[{{0.357485, 0.560122, 0.029311},{0.361486, 0.563029, 0.033535},{
      0.366877, 0.557639, 0.033535},{0.363969, 0.553637, 0.029311}}],
    Polygon[{{0.361486, 0.563029, 0.033535},{0.365973, 0.566289, 0.036934},{
      0.370136, 0.562126, 0.036934},{0.366877, 0.557639, 0.033535}}],
    Polygon[{{0.365973, 0.566289, 0.036934},{0.370835, 0.569821, 0.039423},{
      0.373669, 0.566987, 0.039423},{0.370136, 0.562126, 0.036934}}],
    Polygon[{{0.370835, 0.569821, 0.039423},{0.375952, 0.573539, 0.040942},{
      0.377386, 0.572104, 0.040942},{0.373669, 0.566987, 0.039423}}],
    Polygon[{{0.377386, 0.572104, -0.040942},{0.373669, 0.566987, -0.039423},{
      0.377240, 0.565168, -0.039423},{0.379194, 0.571183, -0.040942}}],
    Polygon[{{0.373669, 0.566987, -0.039423},{0.370136, 0.562126, -0.036934},{
      0.375383, 0.559453, -0.036934},{0.377240, 0.565168, -0.039423}}],
    Polygon[{{0.370136, 0.562126, -0.036934},{0.366877, 0.557639, -0.033535},{
      0.373669, 0.554178, -0.033535},{0.375383, 0.559453, -0.036934}}],
    Polygon[{{0.366877, 0.557639, -0.033535},{0.363969, 0.553637, -0.029311},{
      0.372140, 0.549474, -0.029311},{0.373669, 0.554178, -0.033535}}],
    Polygon[{{0.363969, 0.553637, -0.029311},{0.361486, 0.550220, -0.024365},{
      0.370835, 0.545456, -0.024365},{0.372140, 0.549474, -0.029311}}],
    Polygon[{{0.361486, 0.550220, -0.024365},{0.359489, 0.547470, -0.018819},{
      0.369785, 0.542224, -0.018819},{0.370835, 0.545456, -0.024365}}],
    Polygon[{{0.359489, 0.547470, -0.018819},{0.358026, 0.545456, -0.012809},{
      0.369015, 0.539857, -0.012809},{0.369785, 0.542224, -0.018819}}],
    Polygon[{{0.358026, 0.545456, -0.012809},{0.357133, 0.544228, -0.006485},{
      0.368546, 0.538413, -0.006485},{0.369015, 0.539857, -0.012809}}],
    Polygon[{{0.357133, 0.544228, -0.006485},{0.356833, 0.543815, 0.000000},{
      0.368389, 0.537927, 0.000000},{0.368546, 0.538413, -0.006485}}],
    Polygon[{{0.356833, 0.543815, 0.000000},{0.357133, 0.544228, 0.006485},{
      0.368546, 0.538413, 0.006485},{0.368389, 0.537927, 0.000000}}],
    Polygon[{{0.357133, 0.544228, 0.006485},{0.358026, 0.545456, 0.012809},{
      0.369015, 0.539857, 0.012809},{0.368546, 0.538413, 0.006485}}],
    Polygon[{{0.358026, 0.545456, 0.012809},{0.359489, 0.547470, 0.018819},{
      0.369785, 0.542224, 0.018819},{0.369015, 0.539857, 0.012809}}],
    Polygon[{{0.359489, 0.547470, 0.018819},{0.361486, 0.550220, 0.024365},{
      0.370835, 0.545456, 0.024365},{0.369785, 0.542224, 0.018819}}],
    Polygon[{{0.361486, 0.550220, 0.024365},{0.363969, 0.553637, 0.029311},{
      0.372140, 0.549474, 0.029311},{0.370835, 0.545456, 0.024365}}],
    Polygon[{{0.363969, 0.553637, 0.029311},{0.366877, 0.557639, 0.033535},{
      0.373669, 0.554178, 0.033535},{0.372140, 0.549474, 0.029311}}],
    Polygon[{{0.366877, 0.557639, 0.033535},{0.370136, 0.562126, 0.036934},{
      0.375383, 0.559453, 0.036934},{0.373669, 0.554178, 0.033535}}],
    Polygon[{{0.370136, 0.562126, 0.036934},{0.373669, 0.566987, 0.039423},{
      0.377240, 0.565168, 0.039423},{0.375383, 0.559453, 0.036934}}],
    Polygon[{{0.373669, 0.566987, 0.039423},{0.377386, 0.572104, 0.040942},{
      0.379194, 0.571183, 0.040942},{0.377240, 0.565168, 0.039423}}],
    Polygon[{{0.379194, 0.571183, -0.040942},{0.377240, 0.565168, -0.039423},{
      0.381198, 0.564541, -0.039423},{0.381198, 0.570866, -0.040942}}],
    Polygon[{{0.377240, 0.565168, -0.039423},{0.375383, 0.559453, -0.036934},{
      0.381198, 0.558532, -0.036934},{0.381198, 0.564541, -0.039423}}],
    Polygon[{{0.375383, 0.559453, -0.036934},{0.373669, 0.554178, -0.033535},{
      0.381198, 0.552985, -0.033535},{0.381198, 0.558532, -0.036934}}],
    Polygon[{{0.373669, 0.554178, -0.033535},{0.372140, 0.549474, -0.029311},{
      0.381198, 0.548039, -0.029311},{0.381198, 0.552985, -0.033535}}],
    Polygon[{{0.372140, 0.549474, -0.029311},{0.370835, 0.545456, -0.024365},{
      0.381198, 0.543815, -0.024365},{0.381198, 0.548039, -0.029311}}],
    Polygon[{{0.370835, 0.545456, -0.024365},{0.369785, 0.542224, -0.018819},{
      0.381198, 0.540416, -0.018819},{0.381198, 0.543815, -0.024365}}],
    Polygon[{{0.369785, 0.542224, -0.018819},{0.369015, 0.539857, -0.012809},{
      0.381198, 0.537927, -0.012809},{0.381198, 0.540416, -0.018819}}],
    Polygon[{{0.369015, 0.539857, -0.012809},{0.368546, 0.538413, -0.006485},{
      0.381198, 0.536409, -0.006485},{0.381198, 0.537927, -0.012809}}],
    Polygon[{{0.368546, 0.538413, -0.006485},{0.368389, 0.537927, 0.000000},{
      0.381198, 0.535898, 0.000000},{0.381198, 0.536409, -0.006485}}],
    Polygon[{{0.368389, 0.537927, 0.000000},{0.368546, 0.538413, 0.006485},{
      0.381198, 0.536409, 0.006485},{0.381198, 0.535898, 0.000000}}],
    Polygon[{{0.368546, 0.538413, 0.006485},{0.369015, 0.539857, 0.012809},{
      0.381198, 0.537927, 0.012809},{0.381198, 0.536409, 0.006485}}],
    Polygon[{{0.369015, 0.539857, 0.012809},{0.369785, 0.542224, 0.018819},{
      0.381198, 0.540416, 0.018819},{0.381198, 0.537927, 0.012809}}],
    Polygon[{{0.369785, 0.542224, 0.018819},{0.370835, 0.545456, 0.024365},{
      0.381198, 0.543815, 0.024365},{0.381198, 0.540416, 0.018819}}],
    Polygon[{{0.370835, 0.545456, 0.024365},{0.372140, 0.549474, 0.029311},{
      0.381198, 0.548039, 0.029311},{0.381198, 0.543815, 0.024365}}],
    Polygon[{{0.372140, 0.549474, 0.029311},{0.373669, 0.554178, 0.033535},{
      0.381198, 0.552985, 0.033535},{0.381198, 0.548039, 0.029311}}],
    Polygon[{{0.373669, 0.554178, 0.033535},{0.375383, 0.559453, 0.036934},{
      0.381198, 0.558532, 0.036934},{0.381198, 0.552985, 0.033535}}],
    Polygon[{{0.375383, 0.559453, 0.036934},{0.377240, 0.565168, 0.039423},{
      0.381198, 0.564541, 0.039423},{0.381198, 0.558532, 0.036934}}],
    Polygon[{{0.377240, 0.565168, 0.039423},{0.379194, 0.571183, 0.040942},{
      0.381198, 0.570866, 0.040942},{0.381198, 0.564541, 0.039423}}],
    Polygon[{{0.381198, 0.570866, -0.040942},{0.381198, 0.564541, -0.039423},{
      0.385156, 0.565168, -0.039423},{0.383202, 0.571183, -0.040942}}],
    Polygon[{{0.381198, 0.564541, -0.039423},{0.381198, 0.558532, -0.036934},{
      0.387013, 0.559453, -0.036934},{0.385156, 0.565168, -0.039423}}],
    Polygon[{{0.381198, 0.558532, -0.036934},{0.381198, 0.552985, -0.033535},{
      0.388727, 0.554178, -0.033535},{0.387013, 0.559453, -0.036934}}],
    Polygon[{{0.381198, 0.552985, -0.033535},{0.381198, 0.548039, -0.029311},{
      0.390255, 0.549474, -0.029311},{0.388727, 0.554178, -0.033535}}],
    Polygon[{{0.381198, 0.548039, -0.029311},{0.381198, 0.543815, -0.024365},{
      0.391561, 0.545456, -0.024365},{0.390255, 0.549474, -0.029311}}],
    Polygon[{{0.381198, 0.543815, -0.024365},{0.381198, 0.540416, -0.018819},{
      0.392611, 0.542224, -0.018819},{0.391561, 0.545456, -0.024365}}],
    Polygon[{{0.381198, 0.540416, -0.018819},{0.381198, 0.537927, -0.012809},{
      0.393380, 0.539857, -0.012809},{0.392611, 0.542224, -0.018819}}],
    Polygon[{{0.381198, 0.537927, -0.012809},{0.381198, 0.536409, -0.006485},{
      0.393849, 0.538413, -0.006485},{0.393380, 0.539857, -0.012809}}],
    Polygon[{{0.381198, 0.536409, -0.006485},{0.381198, 0.535898, 0.000000},{
      0.394007, 0.537927, 0.000000},{0.393849, 0.538413, -0.006485}}],
    Polygon[{{0.381198, 0.535898, 0.000000},{0.381198, 0.536409, 0.006485},{
      0.393849, 0.538413, 0.006485},{0.394007, 0.537927, 0.000000}}],
    Polygon[{{0.381198, 0.536409, 0.006485},{0.381198, 0.537927, 0.012809},{
      0.393380, 0.539857, 0.012809},{0.393849, 0.538413, 0.006485}}],
    Polygon[{{0.381198, 0.537927, 0.012809},{0.381198, 0.540416, 0.018819},{
      0.392611, 0.542224, 0.018819},{0.393380, 0.539857, 0.012809}}],
    Polygon[{{0.381198, 0.540416, 0.018819},{0.381198, 0.543815, 0.024365},{
      0.391561, 0.545456, 0.024365},{0.392611, 0.542224, 0.018819}}],
    Polygon[{{0.381198, 0.543815, 0.024365},{0.381198, 0.548039, 0.029311},{
      0.390255, 0.549474, 0.029311},{0.391561, 0.545456, 0.024365}}],
    Polygon[{{0.381198, 0.548039, 0.029311},{0.381198, 0.552985, 0.033535},{
      0.388727, 0.554178, 0.033535},{0.390255, 0.549474, 0.029311}}],
    Polygon[{{0.381198, 0.552985, 0.033535},{0.381198, 0.558532, 0.036934},{
      0.387013, 0.559453, 0.036934},{0.388727, 0.554178, 0.033535}}],
    Polygon[{{0.381198, 0.558532, 0.036934},{0.381198, 0.564541, 0.039423},{
      0.385156, 0.565168, 0.039423},{0.387013, 0.559453, 0.036934}}],
    Polygon[{{0.381198, 0.564541, 0.039423},{0.381198, 0.570866, 0.040942},{
      0.383202, 0.571183, 0.040942},{0.385156, 0.565168, 0.039423}}],
    Polygon[{{0.383202, 0.571183, -0.040942},{0.385156, 0.565168, -0.039423},{
      0.388727, 0.566987, -0.039423},{0.385009, 0.572104, -0.040942}}],
    Polygon[{{0.385156, 0.565168, -0.039423},{0.387013, 0.559453, -0.036934},{
      0.392259, 0.562126, -0.036934},{0.388727, 0.566987, -0.039423}}],
    Polygon[{{0.387013, 0.559453, -0.036934},{0.388727, 0.554178, -0.033535},{
      0.395519, 0.557639, -0.033535},{0.392259, 0.562126, -0.036934}}],
    Polygon[{{0.388727, 0.554178, -0.033535},{0.390255, 0.549474, -0.029311},{
      0.398426, 0.553637, -0.029311},{0.395519, 0.557639, -0.033535}}],
    Polygon[{{0.390255, 0.549474, -0.029311},{0.391561, 0.545456, -0.024365},{
      0.400909, 0.550220, -0.024365},{0.398426, 0.553637, -0.029311}}],
    Polygon[{{0.391561, 0.545456, -0.024365},{0.392611, 0.542224, -0.018819},{
      0.402907, 0.547470, -0.018819},{0.400909, 0.550220, -0.024365}}],
    Polygon[{{0.392611, 0.542224, -0.018819},{0.393380, 0.539857, -0.012809},{
      0.404370, 0.545456, -0.012809},{0.402907, 0.547470, -0.018819}}],
    Polygon[{{0.393380, 0.539857, -0.012809},{0.393849, 0.538413, -0.006485},{
      0.405263, 0.544228, -0.006485},{0.404370, 0.545456, -0.012809}}],
    Polygon[{{0.393849, 0.538413, -0.006485},{0.394007, 0.537927, 0.000000},{
      0.405563, 0.543815, 0.000000},{0.405263, 0.544228, -0.006485}}],
    Polygon[{{0.394007, 0.537927, 0.000000},{0.393849, 0.538413, 0.006485},{
      0.405263, 0.544228, 0.006485},{0.405563, 0.543815, 0.000000}}],
    Polygon[{{0.393849, 0.538413, 0.006485},{0.393380, 0.539857, 0.012809},{
      0.404370, 0.545456, 0.012809},{0.405263, 0.544228, 0.006485}}],
    Polygon[{{0.393380, 0.539857, 0.012809},{0.392611, 0.542224, 0.018819},{
      0.402907, 0.547470, 0.018819},{0.404370, 0.545456, 0.012809}}],
    Polygon[{{0.392611, 0.542224, 0.018819},{0.391561, 0.545456, 0.024365},{
      0.400909, 0.550220, 0.024365},{0.402907, 0.547470, 0.018819}}],
    Polygon[{{0.391561, 0.545456, 0.024365},{0.390255, 0.549474, 0.029311},{
      0.398426, 0.553637, 0.029311},{0.400909, 0.550220, 0.024365}}],
    Polygon[{{0.390255, 0.549474, 0.029311},{0.388727, 0.554178, 0.033535},{
      0.395519, 0.557639, 0.033535},{0.398426, 0.553637, 0.029311}}],
    Polygon[{{0.388727, 0.554178, 0.033535},{0.387013, 0.559453, 0.036934},{
      0.392259, 0.562126, 0.036934},{0.395519, 0.557639, 0.033535}}],
    Polygon[{{0.387013, 0.559453, 0.036934},{0.385156, 0.565168, 0.039423},{
      0.388727, 0.566987, 0.039423},{0.392259, 0.562126, 0.036934}}],
    Polygon[{{0.385156, 0.565168, 0.039423},{0.383202, 0.571183, 0.040942},{
      0.385009, 0.572104, 0.040942},{0.388727, 0.566987, 0.039423}}],
    Polygon[{{0.385009, 0.572104, -0.040942},{0.388727, 0.566987, -0.039423},{
      0.391561, 0.569821, -0.039423},{0.386444, 0.573539, -0.040942}}],
    Polygon[{{0.388727, 0.566987, -0.039423},{0.392259, 0.562126, -0.036934},{
      0.396423, 0.566289, -0.036934},{0.391561, 0.569821, -0.039423}}],
    Polygon[{{0.392259, 0.562126, -0.036934},{0.395519, 0.557639, -0.033535},{
      0.400909, 0.563029, -0.033535},{0.396423, 0.566289, -0.036934}}],
    Polygon[{{0.395519, 0.557639, -0.033535},{0.398426, 0.553637, -0.029311},{
      0.404911, 0.560122, -0.029311},{0.400909, 0.563029, -0.033535}}],
    Polygon[{{0.398426, 0.553637, -0.029311},{0.400909, 0.550220, -0.024365},{
      0.408328, 0.557639, -0.024365},{0.404911, 0.560122, -0.029311}}],
    Polygon[{{0.400909, 0.550220, -0.024365},{0.402907, 0.547470, -0.018819},{
      0.411078, 0.555641, -0.018819},{0.408328, 0.557639, -0.024365}}],
    Polygon[{{0.402907, 0.547470, -0.018819},{0.404370, 0.545456, -0.012809},{
      0.413092, 0.554178, -0.012809},{0.411078, 0.555641, -0.018819}}],
    Polygon[{{0.404370, 0.545456, -0.012809},{0.405263, 0.544228, -0.006485},{
      0.414320, 0.553285, -0.006485},{0.413092, 0.554178, -0.012809}}],
    Polygon[{{0.405263, 0.544228, -0.006485},{0.405563, 0.543815, 0.000000},{
      0.414733, 0.552985, 0.000000},{0.414320, 0.553285, -0.006485}}],
    Polygon[{{0.405563, 0.543815, 0.000000},{0.405263, 0.544228, 0.006485},{
      0.414320, 0.553285, 0.006485},{0.414733, 0.552985, 0.000000}}],
    Polygon[{{0.405263, 0.544228, 0.006485},{0.404370, 0.545456, 0.012809},{
      0.413092, 0.554178, 0.012809},{0.414320, 0.553285, 0.006485}}],
    Polygon[{{0.404370, 0.545456, 0.012809},{0.402907, 0.547470, 0.018819},{
      0.411078, 0.555641, 0.018819},{0.413092, 0.554178, 0.012809}}],
    Polygon[{{0.402907, 0.547470, 0.018819},{0.400909, 0.550220, 0.024365},{
      0.408328, 0.557639, 0.024365},{0.411078, 0.555641, 0.018819}}],
    Polygon[{{0.400909, 0.550220, 0.024365},{0.398426, 0.553637, 0.029311},{
      0.404911, 0.560122, 0.029311},{0.408328, 0.557639, 0.024365}}],
    Polygon[{{0.398426, 0.553637, 0.029311},{0.395519, 0.557639, 0.033535},{
      0.400909, 0.563029, 0.033535},{0.404911, 0.560122, 0.029311}}],
    Polygon[{{0.395519, 0.557639, 0.033535},{0.392259, 0.562126, 0.036934},{
      0.396423, 0.566289, 0.036934},{0.400909, 0.563029, 0.033535}}],
    Polygon[{{0.392259, 0.562126, 0.036934},{0.388727, 0.566987, 0.039423},{
      0.391561, 0.569821, 0.039423},{0.396423, 0.566289, 0.036934}}],
    Polygon[{{0.388727, 0.566987, 0.039423},{0.385009, 0.572104, 0.040942},{
      0.386444, 0.573539, 0.040942},{0.391561, 0.569821, 0.039423}}],
    Polygon[{{0.386444, 0.573539, -0.040942},{0.391561, 0.569821, -0.039423},{
      0.393380, 0.573392, -0.039423},{0.387365, 0.575346, -0.040942}}],
    Polygon[{{0.391561, 0.569821, -0.039423},{0.396423, 0.566289, -0.036934},{
      0.399096, 0.571535, -0.036934},{0.393380, 0.573392, -0.039423}}],
    Polygon[{{0.396423, 0.566289, -0.036934},{0.400909, 0.563029, -0.033535},{
      0.404370, 0.569821, -0.033535},{0.399096, 0.571535, -0.036934}}],
    Polygon[{{0.400909, 0.563029, -0.033535},{0.404911, 0.560122, -0.029311},{
      0.409074, 0.568293, -0.029311},{0.404370, 0.569821, -0.033535}}],
    Polygon[{{0.404911, 0.560122, -0.029311},{0.408328, 0.557639, -0.024365},{
      0.413092, 0.566987, -0.024365},{0.409074, 0.568293, -0.029311}}],
    Polygon[{{0.408328, 0.557639, -0.024365},{0.411078, 0.555641, -0.018819},{
      0.416324, 0.565937, -0.018819},{0.413092, 0.566987, -0.024365}}],
    Polygon[{{0.411078, 0.555641, -0.018819},{0.413092, 0.554178, -0.012809},{
      0.418691, 0.565168, -0.012809},{0.416324, 0.565937, -0.018819}}],
    Polygon[{{0.413092, 0.554178, -0.012809},{0.414320, 0.553285, -0.006485},{
      0.420136, 0.564699, -0.006485},{0.418691, 0.565168, -0.012809}}],
    Polygon[{{0.414320, 0.553285, -0.006485},{0.414733, 0.552985, 0.000000},{
      0.420621, 0.564541, 0.000000},{0.420136, 0.564699, -0.006485}}],
    Polygon[{{0.414733, 0.552985, 0.000000},{0.414320, 0.553285, 0.006485},{
      0.420136, 0.564699, 0.006485},{0.420621, 0.564541, 0.000000}}],
    Polygon[{{0.414320, 0.553285, 0.006485},{0.413092, 0.554178, 0.012809},{
      0.418691, 0.565168, 0.012809},{0.420136, 0.564699, 0.006485}}],
    Polygon[{{0.413092, 0.554178, 0.012809},{0.411078, 0.555641, 0.018819},{
      0.416324, 0.565937, 0.018819},{0.418691, 0.565168, 0.012809}}],
    Polygon[{{0.411078, 0.555641, 0.018819},{0.408328, 0.557639, 0.024365},{
      0.413092, 0.566987, 0.024365},{0.416324, 0.565937, 0.018819}}],
    Polygon[{{0.408328, 0.557639, 0.024365},{0.404911, 0.560122, 0.029311},{
      0.409074, 0.568293, 0.029311},{0.413092, 0.566987, 0.024365}}],
    Polygon[{{0.404911, 0.560122, 0.029311},{0.400909, 0.563029, 0.033535},{
      0.404370, 0.569821, 0.033535},{0.409074, 0.568293, 0.029311}}],
    Polygon[{{0.400909, 0.563029, 0.033535},{0.396423, 0.566289, 0.036934},{
      0.399096, 0.571535, 0.036934},{0.404370, 0.569821, 0.033535}}],
    Polygon[{{0.396423, 0.566289, 0.036934},{0.391561, 0.569821, 0.039423},{
      0.393380, 0.573392, 0.039423},{0.399096, 0.571535, 0.036934}}],
    Polygon[{{0.391561, 0.569821, 0.039423},{0.386444, 0.573539, 0.040942},{
      0.387365, 0.575346, 0.040942},{0.393380, 0.573392, 0.039423}}],
    Polygon[{{0.387365, 0.575346, -0.040942},{0.393380, 0.573392, -0.039423},{
      0.394007, 0.577350, -0.039423},{0.387682, 0.577350, -0.040942}}],
    Polygon[{{0.393380, 0.573392, -0.039423},{0.399096, 0.571535, -0.036934},{
      0.400017, 0.577350, -0.036934},{0.394007, 0.577350, -0.039423}}],
    Polygon[{{0.399096, 0.571535, -0.036934},{0.404370, 0.569821, -0.033535},{
      0.405563, 0.577350, -0.033535},{0.400017, 0.577350, -0.036934}}],
    Polygon[{{0.404370, 0.569821, -0.033535},{0.409074, 0.568293, -0.029311},{
      0.410509, 0.577350, -0.029311},{0.405563, 0.577350, -0.033535}}],
    Polygon[{{0.409074, 0.568293, -0.029311},{0.413092, 0.566987, -0.024365},{
      0.414733, 0.577350, -0.024365},{0.410509, 0.577350, -0.029311}}],
    Polygon[{{0.413092, 0.566987, -0.024365},{0.416324, 0.565937, -0.018819},{
      0.418132, 0.577350, -0.018819},{0.414733, 0.577350, -0.024365}}],
    Polygon[{{0.416324, 0.565937, -0.018819},{0.418691, 0.565168, -0.012809},{
      0.420621, 0.577350, -0.012809},{0.418132, 0.577350, -0.018819}}],
    Polygon[{{0.418691, 0.565168, -0.012809},{0.420136, 0.564699, -0.006485},{
      0.422139, 0.577350, -0.006485},{0.420621, 0.577350, -0.012809}}],
    Polygon[{{0.420136, 0.564699, -0.006485},{0.420621, 0.564541, 0.000000},{
      0.422650, 0.577350, 0.000000},{0.422139, 0.577350, -0.006485}}],
    Polygon[{{0.420621, 0.564541, 0.000000},{0.420136, 0.564699, 0.006485},{
      0.422139, 0.577350, 0.006485},{0.422650, 0.577350, 0.000000}}],
    Polygon[{{0.420136, 0.564699, 0.006485},{0.418691, 0.565168, 0.012809},{
      0.420621, 0.577350, 0.012809},{0.422139, 0.577350, 0.006485}}],
    Polygon[{{0.418691, 0.565168, 0.012809},{0.416324, 0.565937, 0.018819},{
      0.418132, 0.577350, 0.018819},{0.420621, 0.577350, 0.012809}}],
    Polygon[{{0.416324, 0.565937, 0.018819},{0.413092, 0.566987, 0.024365},{
      0.414733, 0.577350, 0.024365},{0.418132, 0.577350, 0.018819}}],
    Polygon[{{0.413092, 0.566987, 0.024365},{0.409074, 0.568293, 0.029311},{
      0.410509, 0.577350, 0.029311},{0.414733, 0.577350, 0.024365}}],
    Polygon[{{0.409074, 0.568293, 0.029311},{0.404370, 0.569821, 0.033535},{
      0.405563, 0.577350, 0.033535},{0.410509, 0.577350, 0.029311}}],
    Polygon[{{0.404370, 0.569821, 0.033535},{0.399096, 0.571535, 0.036934},{
      0.400017, 0.577350, 0.036934},{0.405563, 0.577350, 0.033535}}],
    Polygon[{{0.399096, 0.571535, 0.036934},{0.393380, 0.573392, 0.039423},{
      0.394007, 0.577350, 0.039423},{0.400017, 0.577350, 0.036934}}],
    Polygon[{{0.393380, 0.573392, 0.039423},{0.387365, 0.575346, 0.040942},{
      0.387682, 0.577350, 0.040942},{0.394007, 0.577350, 0.039423}}],
    Polygon[{{0.404354, 0.641809, -0.025466},{0.408288, 0.641809, -0.024521},{
      0.407898, 0.644271, -0.024521},{0.404157, 0.643055, -0.025466}}],
    Polygon[{{0.408288, 0.641809, -0.024521},{0.412026, 0.641809, -0.022973},{
      0.411453, 0.645426, -0.022973},{0.407898, 0.644271, -0.024521}}],
    Polygon[{{0.412026, 0.641809, -0.022973},{0.415476, 0.641809, -0.020859},{
      0.414734, 0.646492, -0.020859},{0.411453, 0.645426, -0.022973}}],
    Polygon[{{0.415476, 0.641809, -0.020859},{0.418552, 0.641809, -0.018232},{
      0.417660, 0.647443, -0.018232},{0.414734, 0.646492, -0.020859}}],
    Polygon[{{0.418552, 0.641809, -0.018232},{0.421180, 0.641809, -0.015155},{
      0.420159, 0.648255, -0.015155},{0.417660, 0.647443, -0.018232}}],
    Polygon[{{0.421180, 0.641809, -0.015155},{0.423294, 0.641809, -0.011705},{
      0.422169, 0.648908, -0.011705},{0.420159, 0.648255, -0.015155}}],
    Polygon[{{0.423294, 0.641809, -0.011705},{0.424842, 0.641809, -0.007968},{
      0.423642, 0.649386, -0.007968},{0.422169, 0.648908, -0.011705}}],
    Polygon[{{0.424842, 0.641809, -0.007968},{0.425787, 0.641809, -0.004033},{
      0.424540, 0.649678, -0.004033},{0.423642, 0.649386, -0.007968}}],
    Polygon[{{0.425787, 0.641809, -0.004033},{0.426104, 0.641809, 0.000000},{
      0.424842, 0.649776, 0.000000},{0.424540, 0.649678, -0.004033}}],
    Polygon[{{0.426104, 0.641809, 0.000000},{0.425787, 0.641809, 0.004033},{
      0.424540, 0.649678, 0.004033},{0.424842, 0.649776, 0.000000}}],
    Polygon[{{0.425787, 0.641809, 0.004033},{0.424842, 0.641809, 0.007968},{
      0.423642, 0.649386, 0.007968},{0.424540, 0.649678, 0.004033}}],
    Polygon[{{0.424842, 0.641809, 0.007968},{0.423294, 0.641809, 0.011705},{
      0.422169, 0.648908, 0.011705},{0.423642, 0.649386, 0.007968}}],
    Polygon[{{0.423294, 0.641809, 0.011705},{0.421180, 0.641809, 0.015155},{
      0.420159, 0.648255, 0.015155},{0.422169, 0.648908, 0.011705}}],
    Polygon[{{0.421180, 0.641809, 0.015155},{0.418552, 0.641809, 0.018232},{
      0.417660, 0.647443, 0.018232},{0.420159, 0.648255, 0.015155}}],
    Polygon[{{0.418552, 0.641809, 0.018232},{0.415476, 0.641809, 0.020859},{
      0.414734, 0.646492, 0.020859},{0.417660, 0.647443, 0.018232}}],
    Polygon[{{0.415476, 0.641809, 0.020859},{0.412026, 0.641809, 0.022973},{
      0.411453, 0.645426, 0.022973},{0.414734, 0.646492, 0.020859}}],
    Polygon[{{0.412026, 0.641809, 0.022973},{0.408288, 0.641809, 0.024521},{
      0.407898, 0.644271, 0.024521},{0.411453, 0.645426, 0.022973}}],
    Polygon[{{0.408288, 0.641809, 0.024521},{0.404354, 0.641809, 0.025466},{
      0.404157, 0.643055, 0.025466},{0.407898, 0.644271, 0.024521}}],
    Polygon[{{0.404157, 0.643055, -0.025466},{0.407898, 0.644271, -0.024521},{
      0.406766, 0.646492, -0.024521},{0.403584, 0.644180, -0.025466}}],
    Polygon[{{0.407898, 0.644271, -0.024521},{0.411453, 0.645426, -0.022973},{
      0.409791, 0.648689, -0.022973},{0.406766, 0.646492, -0.024521}}],
    Polygon[{{0.411453, 0.645426, -0.022973},{0.414734, 0.646492, -0.020859},{
      0.412581, 0.650717, -0.020859},{0.409791, 0.648689, -0.022973}}],
    Polygon[{{0.414734, 0.646492, -0.020859},{0.417660, 0.647443, -0.018232},{
      0.415070, 0.652525, -0.018232},{0.412581, 0.650717, -0.020859}}],
    Polygon[{{0.417660, 0.647443, -0.018232},{0.420159, 0.648255, -0.015155},{
      0.417196, 0.654070, -0.015155},{0.415070, 0.652525, -0.018232}}],
    Polygon[{{0.420159, 0.648255, -0.015155},{0.422169, 0.648908, -0.011705},{
      0.418906, 0.655312, -0.011705},{0.417196, 0.654070, -0.015155}}],
    Polygon[{{0.422169, 0.648908, -0.011705},{0.423642, 0.649386, -0.007968},{
      0.420159, 0.656222, -0.007968},{0.418906, 0.655312, -0.011705}}],
    Polygon[{{0.423642, 0.649386, -0.007968},{0.424540, 0.649678, -0.004033},{
      0.420923, 0.656777, -0.004033},{0.420159, 0.656222, -0.007968}}],
    Polygon[{{0.424540, 0.649678, -0.004033},{0.424842, 0.649776, 0.000000},{
      0.421180, 0.656964, 0.000000},{0.420923, 0.656777, -0.004033}}],
    Polygon[{{0.424842, 0.649776, 0.000000},{0.424540, 0.649678, 0.004033},{
      0.420923, 0.656777, 0.004033},{0.421180, 0.656964, 0.000000}}],
    Polygon[{{0.424540, 0.649678, 0.004033},{0.423642, 0.649386, 0.007968},{
      0.420159, 0.656222, 0.007968},{0.420923, 0.656777, 0.004033}}],
    Polygon[{{0.423642, 0.649386, 0.007968},{0.422169, 0.648908, 0.011705},{
      0.418906, 0.655312, 0.011705},{0.420159, 0.656222, 0.007968}}],
    Polygon[{{0.422169, 0.648908, 0.011705},{0.420159, 0.648255, 0.015155},{
      0.417196, 0.654070, 0.015155},{0.418906, 0.655312, 0.011705}}],
    Polygon[{{0.420159, 0.648255, 0.015155},{0.417660, 0.647443, 0.018232},{
      0.415070, 0.652525, 0.018232},{0.417196, 0.654070, 0.015155}}],
    Polygon[{{0.417660, 0.647443, 0.018232},{0.414734, 0.646492, 0.020859},{
      0.412581, 0.650717, 0.020859},{0.415070, 0.652525, 0.018232}}],
    Polygon[{{0.414734, 0.646492, 0.020859},{0.411453, 0.645426, 0.022973},{
      0.409791, 0.648689, 0.022973},{0.412581, 0.650717, 0.020859}}],
    Polygon[{{0.411453, 0.645426, 0.022973},{0.407898, 0.644271, 0.024521},{
      0.406766, 0.646492, 0.024521},{0.409791, 0.648689, 0.022973}}],
    Polygon[{{0.407898, 0.644271, 0.024521},{0.404157, 0.643055, 0.025466},{
      0.403584, 0.644180, 0.025466},{0.406766, 0.646492, 0.024521}}],
    Polygon[{{0.403584, 0.644180, -0.025466},{0.406766, 0.646492, -0.024521},{
      0.405004, 0.648255, -0.024521},{0.402691, 0.645072, -0.025466}}],
    Polygon[{{0.406766, 0.646492, -0.024521},{0.409791, 0.648689, -0.022973},{
      0.407201, 0.651279, -0.022973},{0.405004, 0.648255, -0.024521}}],
    Polygon[{{0.409791, 0.648689, -0.022973},{0.412581, 0.650717, -0.020859},{
      0.409229, 0.654070, -0.020859},{0.407201, 0.651279, -0.022973}}],
    Polygon[{{0.412581, 0.650717, -0.020859},{0.415070, 0.652525, -0.018232},{
      0.411037, 0.656559, -0.018232},{0.409229, 0.654070, -0.020859}}],
    Polygon[{{0.415070, 0.652525, -0.018232},{0.417196, 0.654070, -0.015155},{
      0.412581, 0.658684, -0.015155},{0.411037, 0.656559, -0.018232}}],
    Polygon[{{0.417196, 0.654070, -0.015155},{0.418906, 0.655312, -0.011705},{
      0.413824, 0.660395, -0.011705},{0.412581, 0.658684, -0.015155}}],
    Polygon[{{0.418906, 0.655312, -0.011705},{0.420159, 0.656222, -0.007968},{
      0.414734, 0.661647, -0.007968},{0.413824, 0.660395, -0.011705}}],
    Polygon[{{0.420159, 0.656222, -0.007968},{0.420923, 0.656777, -0.004033},{
      0.415289, 0.662411, -0.004033},{0.414734, 0.661647, -0.007968}}],
    Polygon[{{0.420923, 0.656777, -0.004033},{0.421180, 0.656964, 0.000000},{
      0.415476, 0.662668, 0.000000},{0.415289, 0.662411, -0.004033}}],
    Polygon[{{0.421180, 0.656964, 0.000000},{0.420923, 0.656777, 0.004033},{
      0.415289, 0.662411, 0.004033},{0.415476, 0.662668, 0.000000}}],
    Polygon[{{0.420923, 0.656777, 0.004033},{0.420159, 0.656222, 0.007968},{
      0.414734, 0.661647, 0.007968},{0.415289, 0.662411, 0.004033}}],
    Polygon[{{0.420159, 0.656222, 0.007968},{0.418906, 0.655312, 0.011705},{
      0.413824, 0.660395, 0.011705},{0.414734, 0.661647, 0.007968}}],
    Polygon[{{0.418906, 0.655312, 0.011705},{0.417196, 0.654070, 0.015155},{
      0.412581, 0.658684, 0.015155},{0.413824, 0.660395, 0.011705}}],
    Polygon[{{0.417196, 0.654070, 0.015155},{0.415070, 0.652525, 0.018232},{
      0.411037, 0.656559, 0.018232},{0.412581, 0.658684, 0.015155}}],
    Polygon[{{0.415070, 0.652525, 0.018232},{0.412581, 0.650717, 0.020859},{
      0.409229, 0.654070, 0.020859},{0.411037, 0.656559, 0.018232}}],
    Polygon[{{0.412581, 0.650717, 0.020859},{0.409791, 0.648689, 0.022973},{
      0.407201, 0.651279, 0.022973},{0.409229, 0.654070, 0.020859}}],
    Polygon[{{0.409791, 0.648689, 0.022973},{0.406766, 0.646492, 0.024521},{
      0.405004, 0.648255, 0.024521},{0.407201, 0.651279, 0.022973}}],
    Polygon[{{0.406766, 0.646492, 0.024521},{0.403584, 0.644180, 0.025466},{
      0.402691, 0.645072, 0.025466},{0.405004, 0.648255, 0.024521}}],
    Polygon[{{0.402691, 0.645072, -0.025466},{0.405004, 0.648255, -0.024521},{
      0.402783, 0.649386, -0.024521},{0.401567, 0.645645, -0.025466}}],
    Polygon[{{0.405004, 0.648255, -0.024521},{0.407201, 0.651279, -0.022973},{
      0.403938, 0.652941, -0.022973},{0.402783, 0.649386, -0.024521}}],
    Polygon[{{0.407201, 0.651279, -0.022973},{0.409229, 0.654070, -0.020859},{
      0.405004, 0.656222, -0.020859},{0.403938, 0.652941, -0.022973}}],
    Polygon[{{0.409229, 0.654070, -0.020859},{0.411037, 0.656559, -0.018232},{
      0.405955, 0.659148, -0.018232},{0.405004, 0.656222, -0.020859}}],
    Polygon[{{0.411037, 0.656559, -0.018232},{0.412581, 0.658684, -0.015155},{
      0.406766, 0.661647, -0.015155},{0.405955, 0.659148, -0.018232}}],
    Polygon[{{0.412581, 0.658684, -0.015155},{0.413824, 0.660395, -0.011705},{
      0.407420, 0.663658, -0.011705},{0.406766, 0.661647, -0.015155}}],
    Polygon[{{0.413824, 0.660395, -0.011705},{0.414734, 0.661647, -0.007968},{
      0.407898, 0.665130, -0.007968},{0.407420, 0.663658, -0.011705}}],
    Polygon[{{0.414734, 0.661647, -0.007968},{0.415289, 0.662411, -0.004033},{
      0.408190, 0.666028, -0.004033},{0.407898, 0.665130, -0.007968}}],
    Polygon[{{0.415289, 0.662411, -0.004033},{0.415476, 0.662668, 0.000000},{
      0.408288, 0.666330, 0.000000},{0.408190, 0.666028, -0.004033}}],
    Polygon[{{0.415476, 0.662668, 0.000000},{0.415289, 0.662411, 0.004033},{
      0.408190, 0.666028, 0.004033},{0.408288, 0.666330, 0.000000}}],
    Polygon[{{0.415289, 0.662411, 0.004033},{0.414734, 0.661647, 0.007968},{
      0.407898, 0.665130, 0.007968},{0.408190, 0.666028, 0.004033}}],
    Polygon[{{0.414734, 0.661647, 0.007968},{0.413824, 0.660395, 0.011705},{
      0.407420, 0.663658, 0.011705},{0.407898, 0.665130, 0.007968}}],
    Polygon[{{0.413824, 0.660395, 0.011705},{0.412581, 0.658684, 0.015155},{
      0.406766, 0.661647, 0.015155},{0.407420, 0.663658, 0.011705}}],
    Polygon[{{0.412581, 0.658684, 0.015155},{0.411037, 0.656559, 0.018232},{
      0.405955, 0.659148, 0.018232},{0.406766, 0.661647, 0.015155}}],
    Polygon[{{0.411037, 0.656559, 0.018232},{0.409229, 0.654070, 0.020859},{
      0.405004, 0.656222, 0.020859},{0.405955, 0.659148, 0.018232}}],
    Polygon[{{0.409229, 0.654070, 0.020859},{0.407201, 0.651279, 0.022973},{
      0.403938, 0.652941, 0.022973},{0.405004, 0.656222, 0.020859}}],
    Polygon[{{0.407201, 0.651279, 0.022973},{0.405004, 0.648255, 0.024521},{
      0.402783, 0.649386, 0.024521},{0.403938, 0.652941, 0.022973}}],
    Polygon[{{0.405004, 0.648255, 0.024521},{0.402691, 0.645072, 0.025466},{
      0.401567, 0.645645, 0.025466},{0.402783, 0.649386, 0.024521}}],
    Polygon[{{0.401567, 0.645645, -0.025466},{0.402783, 0.649386, -0.024521},{
      0.400321, 0.649776, -0.024521},{0.400321, 0.645842, -0.025466}}],
    Polygon[{{0.402783, 0.649386, -0.024521},{0.403938, 0.652941, -0.022973},{
      0.400321, 0.653514, -0.022973},{0.400321, 0.649776, -0.024521}}],
    Polygon[{{0.403938, 0.652941, -0.022973},{0.405004, 0.656222, -0.020859},{
      0.400321, 0.656964, -0.020859},{0.400321, 0.653514, -0.022973}}],
    Polygon[{{0.405004, 0.656222, -0.020859},{0.405955, 0.659148, -0.018232},{
      0.400321, 0.660040, -0.018232},{0.400321, 0.656964, -0.020859}}],
    Polygon[{{0.405955, 0.659148, -0.018232},{0.406766, 0.661647, -0.015155},{
      0.400321, 0.662668, -0.015155},{0.400321, 0.660040, -0.018232}}],
    Polygon[{{0.406766, 0.661647, -0.015155},{0.407420, 0.663658, -0.011705},{
      0.400321, 0.664782, -0.011705},{0.400321, 0.662668, -0.015155}}],
    Polygon[{{0.407420, 0.663658, -0.011705},{0.407898, 0.665130, -0.007968},{
      0.400321, 0.666330, -0.007968},{0.400321, 0.664782, -0.011705}}],
    Polygon[{{0.407898, 0.665130, -0.007968},{0.408190, 0.666028, -0.004033},{
      0.400321, 0.667275, -0.004033},{0.400321, 0.666330, -0.007968}}],
    Polygon[{{0.408190, 0.666028, -0.004033},{0.408288, 0.666330, 0.000000},{
      0.400321, 0.667592, 0.000000},{0.400321, 0.667275, -0.004033}}],
    Polygon[{{0.408288, 0.666330, 0.000000},{0.408190, 0.666028, 0.004033},{
      0.400321, 0.667275, 0.004033},{0.400321, 0.667592, 0.000000}}],
    Polygon[{{0.408190, 0.666028, 0.004033},{0.407898, 0.665130, 0.007968},{
      0.400321, 0.666330, 0.007968},{0.400321, 0.667275, 0.004033}}],
    Polygon[{{0.407898, 0.665130, 0.007968},{0.407420, 0.663658, 0.011705},{
      0.400321, 0.664782, 0.011705},{0.400321, 0.666330, 0.007968}}],
    Polygon[{{0.407420, 0.663658, 0.011705},{0.406766, 0.661647, 0.015155},{
      0.400321, 0.662668, 0.015155},{0.400321, 0.664782, 0.011705}}],
    Polygon[{{0.406766, 0.661647, 0.015155},{0.405955, 0.659148, 0.018232},{
      0.400321, 0.660040, 0.018232},{0.400321, 0.662668, 0.015155}}],
    Polygon[{{0.405955, 0.659148, 0.018232},{0.405004, 0.656222, 0.020859},{
      0.400321, 0.656964, 0.020859},{0.400321, 0.660040, 0.018232}}],
    Polygon[{{0.405004, 0.656222, 0.020859},{0.403938, 0.652941, 0.022973},{
      0.400321, 0.653514, 0.022973},{0.400321, 0.656964, 0.020859}}],
    Polygon[{{0.403938, 0.652941, 0.022973},{0.402783, 0.649386, 0.024521},{
      0.400321, 0.649776, 0.024521},{0.400321, 0.653514, 0.022973}}],
    Polygon[{{0.402783, 0.649386, 0.024521},{0.401567, 0.645645, 0.025466},{
      0.400321, 0.645842, 0.025466},{0.400321, 0.649776, 0.024521}}],
    Polygon[{{0.400321, 0.645842, -0.025466},{0.400321, 0.649776, -0.024521},{
      0.397859, 0.649386, -0.024521},{0.399074, 0.645645, -0.025466}}],
    Polygon[{{0.400321, 0.649776, -0.024521},{0.400321, 0.653514, -0.022973},{
      0.396703, 0.652941, -0.022973},{0.397859, 0.649386, -0.024521}}],
    Polygon[{{0.400321, 0.653514, -0.022973},{0.400321, 0.656964, -0.020859},{
      0.395637, 0.656222, -0.020859},{0.396703, 0.652941, -0.022973}}],
    Polygon[{{0.400321, 0.656964, -0.020859},{0.400321, 0.660040, -0.018232},{
      0.394687, 0.659148, -0.018232},{0.395637, 0.656222, -0.020859}}],
    Polygon[{{0.400321, 0.660040, -0.018232},{0.400321, 0.662668, -0.015155},{
      0.393875, 0.661647, -0.015155},{0.394687, 0.659148, -0.018232}}],
    Polygon[{{0.400321, 0.662668, -0.015155},{0.400321, 0.664782, -0.011705},{
      0.393222, 0.663658, -0.011705},{0.393875, 0.661647, -0.015155}}],
    Polygon[{{0.400321, 0.664782, -0.011705},{0.400321, 0.666330, -0.007968},{
      0.392743, 0.665130, -0.007968},{0.393222, 0.663658, -0.011705}}],
    Polygon[{{0.400321, 0.666330, -0.007968},{0.400321, 0.667275, -0.004033},{
      0.392451, 0.666028, -0.004033},{0.392743, 0.665130, -0.007968}}],
    Polygon[{{0.400321, 0.667275, -0.004033},{0.400321, 0.667592, 0.000000},{
      0.392353, 0.666330, 0.000000},{0.392451, 0.666028, -0.004033}}],
    Polygon[{{0.400321, 0.667592, 0.000000},{0.400321, 0.667275, 0.004033},{
      0.392451, 0.666028, 0.004033},{0.392353, 0.666330, 0.000000}}],
    Polygon[{{0.400321, 0.667275, 0.004033},{0.400321, 0.666330, 0.007968},{
      0.392743, 0.665130, 0.007968},{0.392451, 0.666028, 0.004033}}],
    Polygon[{{0.400321, 0.666330, 0.007968},{0.400321, 0.664782, 0.011705},{
      0.393222, 0.663658, 0.011705},{0.392743, 0.665130, 0.007968}}],
    Polygon[{{0.400321, 0.664782, 0.011705},{0.400321, 0.662668, 0.015155},{
      0.393875, 0.661647, 0.015155},{0.393222, 0.663658, 0.011705}}],
    Polygon[{{0.400321, 0.662668, 0.015155},{0.400321, 0.660040, 0.018232},{
      0.394687, 0.659148, 0.018232},{0.393875, 0.661647, 0.015155}}],
    Polygon[{{0.400321, 0.660040, 0.018232},{0.400321, 0.656964, 0.020859},{
      0.395637, 0.656222, 0.020859},{0.394687, 0.659148, 0.018232}}],
    Polygon[{{0.400321, 0.656964, 0.020859},{0.400321, 0.653514, 0.022973},{
      0.396703, 0.652941, 0.022973},{0.395637, 0.656222, 0.020859}}],
    Polygon[{{0.400321, 0.653514, 0.022973},{0.400321, 0.649776, 0.024521},{
      0.397859, 0.649386, 0.024521},{0.396703, 0.652941, 0.022973}}],
    Polygon[{{0.400321, 0.649776, 0.024521},{0.400321, 0.645842, 0.025466},{
      0.399074, 0.645645, 0.025466},{0.397859, 0.649386, 0.024521}}],
    Polygon[{{0.399074, 0.645645, -0.025466},{0.397859, 0.649386, -0.024521},{
      0.395637, 0.648255, -0.024521},{0.397950, 0.645072, -0.025466}}],
    Polygon[{{0.397859, 0.649386, -0.024521},{0.396703, 0.652941, -0.022973},{
      0.393440, 0.651279, -0.022973},{0.395637, 0.648255, -0.024521}}],
    Polygon[{{0.396703, 0.652941, -0.022973},{0.395637, 0.656222, -0.020859},{
      0.391413, 0.654070, -0.020859},{0.393440, 0.651279, -0.022973}}],
    Polygon[{{0.395637, 0.656222, -0.020859},{0.394687, 0.659148, -0.018232},{
      0.389604, 0.656559, -0.018232},{0.391413, 0.654070, -0.020859}}],
    Polygon[{{0.394687, 0.659148, -0.018232},{0.393875, 0.661647, -0.015155},{
      0.388060, 0.658684, -0.015155},{0.389604, 0.656559, -0.018232}}],
    Polygon[{{0.393875, 0.661647, -0.015155},{0.393222, 0.663658, -0.011705},{
      0.386817, 0.660395, -0.011705},{0.388060, 0.658684, -0.015155}}],
    Polygon[{{0.393222, 0.663658, -0.011705},{0.392743, 0.665130, -0.007968},{
      0.385907, 0.661647, -0.007968},{0.386817, 0.660395, -0.011705}}],
    Polygon[{{0.392743, 0.665130, -0.007968},{0.392451, 0.666028, -0.004033},{
      0.385352, 0.662411, -0.004033},{0.385907, 0.661647, -0.007968}}],
    Polygon[{{0.392451, 0.666028, -0.004033},{0.392353, 0.666330, 0.000000},{
      0.385166, 0.662668, 0.000000},{0.385352, 0.662411, -0.004033}}],
    Polygon[{{0.392353, 0.666330, 0.000000},{0.392451, 0.666028, 0.004033},{
      0.385352, 0.662411, 0.004033},{0.385166, 0.662668, 0.000000}}],
    Polygon[{{0.392451, 0.666028, 0.004033},{0.392743, 0.665130, 0.007968},{
      0.385907, 0.661647, 0.007968},{0.385352, 0.662411, 0.004033}}],
    Polygon[{{0.392743, 0.665130, 0.007968},{0.393222, 0.663658, 0.011705},{
      0.386817, 0.660395, 0.011705},{0.385907, 0.661647, 0.007968}}],
    Polygon[{{0.393222, 0.663658, 0.011705},{0.393875, 0.661647, 0.015155},{
      0.388060, 0.658684, 0.015155},{0.386817, 0.660395, 0.011705}}],
    Polygon[{{0.393875, 0.661647, 0.015155},{0.394687, 0.659148, 0.018232},{
      0.389604, 0.656559, 0.018232},{0.388060, 0.658684, 0.015155}}],
    Polygon[{{0.394687, 0.659148, 0.018232},{0.395637, 0.656222, 0.020859},{
      0.391413, 0.654070, 0.020859},{0.389604, 0.656559, 0.018232}}],
    Polygon[{{0.395637, 0.656222, 0.020859},{0.396703, 0.652941, 0.022973},{
      0.393440, 0.651279, 0.022973},{0.391413, 0.654070, 0.020859}}],
    Polygon[{{0.396703, 0.652941, 0.022973},{0.397859, 0.649386, 0.024521},{
      0.395637, 0.648255, 0.024521},{0.393440, 0.651279, 0.022973}}],
    Polygon[{{0.397859, 0.649386, 0.024521},{0.399074, 0.645645, 0.025466},{
      0.397950, 0.645072, 0.025466},{0.395637, 0.648255, 0.024521}}],
    Polygon[{{0.397950, 0.645072, -0.025466},{0.395637, 0.648255, -0.024521},{
      0.393875, 0.646492, -0.024521},{0.397058, 0.644180, -0.025466}}],
    Polygon[{{0.395637, 0.648255, -0.024521},{0.393440, 0.651279, -0.022973},{
      0.390851, 0.648689, -0.022973},{0.393875, 0.646492, -0.024521}}],
    Polygon[{{0.393440, 0.651279, -0.022973},{0.391413, 0.654070, -0.020859},{
      0.388060, 0.650717, -0.020859},{0.390851, 0.648689, -0.022973}}],
    Polygon[{{0.391413, 0.654070, -0.020859},{0.389604, 0.656559, -0.018232},{
      0.385571, 0.652525, -0.018232},{0.388060, 0.650717, -0.020859}}],
    Polygon[{{0.389604, 0.656559, -0.018232},{0.388060, 0.658684, -0.015155},{
      0.383445, 0.654070, -0.015155},{0.385571, 0.652525, -0.018232}}],
    Polygon[{{0.388060, 0.658684, -0.015155},{0.386817, 0.660395, -0.011705},{
      0.381735, 0.655312, -0.011705},{0.383445, 0.654070, -0.015155}}],
    Polygon[{{0.386817, 0.660395, -0.011705},{0.385907, 0.661647, -0.007968},{
      0.380482, 0.656222, -0.007968},{0.381735, 0.655312, -0.011705}}],
    Polygon[{{0.385907, 0.661647, -0.007968},{0.385352, 0.662411, -0.004033},{
      0.379718, 0.656777, -0.004033},{0.380482, 0.656222, -0.007968}}],
    Polygon[{{0.385352, 0.662411, -0.004033},{0.385166, 0.662668, 0.000000},{
      0.379461, 0.656964, 0.000000},{0.379718, 0.656777, -0.004033}}],
    Polygon[{{0.385166, 0.662668, 0.000000},{0.385352, 0.662411, 0.004033},{
      0.379718, 0.656777, 0.004033},{0.379461, 0.656964, 0.000000}}],
    Polygon[{{0.385352, 0.662411, 0.004033},{0.385907, 0.661647, 0.007968},{
      0.380482, 0.656222, 0.007968},{0.379718, 0.656777, 0.004033}}],
    Polygon[{{0.385907, 0.661647, 0.007968},{0.386817, 0.660395, 0.011705},{
      0.381735, 0.655312, 0.011705},{0.380482, 0.656222, 0.007968}}],
    Polygon[{{0.386817, 0.660395, 0.011705},{0.388060, 0.658684, 0.015155},{
      0.383445, 0.654070, 0.015155},{0.381735, 0.655312, 0.011705}}],
    Polygon[{{0.388060, 0.658684, 0.015155},{0.389604, 0.656559, 0.018232},{
      0.385571, 0.652525, 0.018232},{0.383445, 0.654070, 0.015155}}],
    Polygon[{{0.389604, 0.656559, 0.018232},{0.391413, 0.654070, 0.020859},{
      0.388060, 0.650717, 0.020859},{0.385571, 0.652525, 0.018232}}],
    Polygon[{{0.391413, 0.654070, 0.020859},{0.393440, 0.651279, 0.022973},{
      0.390851, 0.648689, 0.022973},{0.388060, 0.650717, 0.020859}}],
    Polygon[{{0.393440, 0.651279, 0.022973},{0.395637, 0.648255, 0.024521},{
      0.393875, 0.646492, 0.024521},{0.390851, 0.648689, 0.022973}}],
    Polygon[{{0.395637, 0.648255, 0.024521},{0.397950, 0.645072, 0.025466},{
      0.397058, 0.644180, 0.025466},{0.393875, 0.646492, 0.024521}}],
    Polygon[{{0.397058, 0.644180, -0.025466},{0.393875, 0.646492, -0.024521},{
      0.392743, 0.644271, -0.024521},{0.396485, 0.643055, -0.025466}}],
    Polygon[{{0.393875, 0.646492, -0.024521},{0.390851, 0.648689, -0.022973},{
      0.389188, 0.645426, -0.022973},{0.392743, 0.644271, -0.024521}}],
    Polygon[{{0.390851, 0.648689, -0.022973},{0.388060, 0.650717, -0.020859},{
      0.385907, 0.646492, -0.020859},{0.389188, 0.645426, -0.022973}}],
    Polygon[{{0.388060, 0.650717, -0.020859},{0.385571, 0.652525, -0.018232},{
      0.382981, 0.647443, -0.018232},{0.385907, 0.646492, -0.020859}}],
    Polygon[{{0.385571, 0.652525, -0.018232},{0.383445, 0.654070, -0.015155},{
      0.380482, 0.648255, -0.015155},{0.382981, 0.647443, -0.018232}}],
    Polygon[{{0.383445, 0.654070, -0.015155},{0.381735, 0.655312, -0.011705},{
      0.378472, 0.648908, -0.011705},{0.380482, 0.648255, -0.015155}}],
    Polygon[{{0.381735, 0.655312, -0.011705},{0.380482, 0.656222, -0.007968},{
      0.376999, 0.649386, -0.007968},{0.378472, 0.648908, -0.011705}}],
    Polygon[{{0.380482, 0.656222, -0.007968},{0.379718, 0.656777, -0.004033},{
      0.376101, 0.649678, -0.004033},{0.376999, 0.649386, -0.007968}}],
    Polygon[{{0.379718, 0.656777, -0.004033},{0.379461, 0.656964, 0.000000},{
      0.375799, 0.649776, 0.000000},{0.376101, 0.649678, -0.004033}}],
    Polygon[{{0.379461, 0.656964, 0.000000},{0.379718, 0.656777, 0.004033},{
      0.376101, 0.649678, 0.004033},{0.375799, 0.649776, 0.000000}}],
    Polygon[{{0.379718, 0.656777, 0.004033},{0.380482, 0.656222, 0.007968},{
      0.376999, 0.649386, 0.007968},{0.376101, 0.649678, 0.004033}}],
    Polygon[{{0.380482, 0.656222, 0.007968},{0.381735, 0.655312, 0.011705},{
      0.378472, 0.648908, 0.011705},{0.376999, 0.649386, 0.007968}}],
    Polygon[{{0.381735, 0.655312, 0.011705},{0.383445, 0.654070, 0.015155},{
      0.380482, 0.648255, 0.015155},{0.378472, 0.648908, 0.011705}}],
    Polygon[{{0.383445, 0.654070, 0.015155},{0.385571, 0.652525, 0.018232},{
      0.382981, 0.647443, 0.018232},{0.380482, 0.648255, 0.015155}}],
    Polygon[{{0.385571, 0.652525, 0.018232},{0.388060, 0.650717, 0.020859},{
      0.385907, 0.646492, 0.020859},{0.382981, 0.647443, 0.018232}}],
    Polygon[{{0.388060, 0.650717, 0.020859},{0.390851, 0.648689, 0.022973},{
      0.389188, 0.645426, 0.022973},{0.385907, 0.646492, 0.020859}}],
    Polygon[{{0.390851, 0.648689, 0.022973},{0.393875, 0.646492, 0.024521},{
      0.392743, 0.644271, 0.024521},{0.389188, 0.645426, 0.022973}}],
    Polygon[{{0.393875, 0.646492, 0.024521},{0.397058, 0.644180, 0.025466},{
      0.396485, 0.643055, 0.025466},{0.392743, 0.644271, 0.024521}}],
    Polygon[{{0.396485, 0.643055, -0.025466},{0.392743, 0.644271, -0.024521},{
      0.392353, 0.641809, -0.024521},{0.396287, 0.641809, -0.025466}}],
    Polygon[{{0.392743, 0.644271, -0.024521},{0.389188, 0.645426, -0.022973},{
      0.388615, 0.641809, -0.022973},{0.392353, 0.641809, -0.024521}}],
    Polygon[{{0.389188, 0.645426, -0.022973},{0.385907, 0.646492, -0.020859},{
      0.385166, 0.641809, -0.020859},{0.388615, 0.641809, -0.022973}}],
    Polygon[{{0.385907, 0.646492, -0.020859},{0.382981, 0.647443, -0.018232},{
      0.382089, 0.641809, -0.018232},{0.385166, 0.641809, -0.020859}}],
    Polygon[{{0.382981, 0.647443, -0.018232},{0.380482, 0.648255, -0.015155},{
      0.379461, 0.641809, -0.015155},{0.382089, 0.641809, -0.018232}}],
    Polygon[{{0.380482, 0.648255, -0.015155},{0.378472, 0.648908, -0.011705},{
      0.377347, 0.641809, -0.011705},{0.379461, 0.641809, -0.015155}}],
    Polygon[{{0.378472, 0.648908, -0.011705},{0.376999, 0.649386, -0.007968},{
      0.375799, 0.641809, -0.007968},{0.377347, 0.641809, -0.011705}}],
    Polygon[{{0.376999, 0.649386, -0.007968},{0.376101, 0.649678, -0.004033},{
      0.374855, 0.641809, -0.004033},{0.375799, 0.641809, -0.007968}}],
    Polygon[{{0.376101, 0.649678, -0.004033},{0.375799, 0.649776, 0.000000},{
      0.374537, 0.641809, 0.000000},{0.374855, 0.641809, -0.004033}}],
    Polygon[{{0.375799, 0.649776, 0.000000},{0.376101, 0.649678, 0.004033},{
      0.374855, 0.641809, 0.004033},{0.374537, 0.641809, 0.000000}}],
    Polygon[{{0.376101, 0.649678, 0.004033},{0.376999, 0.649386, 0.007968},{
      0.375799, 0.641809, 0.007968},{0.374855, 0.641809, 0.004033}}],
    Polygon[{{0.376999, 0.649386, 0.007968},{0.378472, 0.648908, 0.011705},{
      0.377347, 0.641809, 0.011705},{0.375799, 0.641809, 0.007968}}],
    Polygon[{{0.378472, 0.648908, 0.011705},{0.380482, 0.648255, 0.015155},{
      0.379461, 0.641809, 0.015155},{0.377347, 0.641809, 0.011705}}],
    Polygon[{{0.380482, 0.648255, 0.015155},{0.382981, 0.647443, 0.018232},{
      0.382089, 0.641809, 0.018232},{0.379461, 0.641809, 0.015155}}],
    Polygon[{{0.382981, 0.647443, 0.018232},{0.385907, 0.646492, 0.020859},{
      0.385166, 0.641809, 0.020859},{0.382089, 0.641809, 0.018232}}],
    Polygon[{{0.385907, 0.646492, 0.020859},{0.389188, 0.645426, 0.022973},{
      0.388615, 0.641809, 0.022973},{0.385166, 0.641809, 0.020859}}],
    Polygon[{{0.389188, 0.645426, 0.022973},{0.392743, 0.644271, 0.024521},{
      0.392353, 0.641809, 0.024521},{0.388615, 0.641809, 0.022973}}],
    Polygon[{{0.392743, 0.644271, 0.024521},{0.396485, 0.643055, 0.025466},{
      0.396287, 0.641809, 0.025466},{0.392353, 0.641809, 0.024521}}],
    Polygon[{{0.396287, 0.641809, -0.025466},{0.392353, 0.641809, -0.024521},{
      0.392743, 0.639347, -0.024521},{0.396485, 0.640562, -0.025466}}],
    Polygon[{{0.392353, 0.641809, -0.024521},{0.388615, 0.641809, -0.022973},{
      0.389188, 0.638192, -0.022973},{0.392743, 0.639347, -0.024521}}],
    Polygon[{{0.388615, 0.641809, -0.022973},{0.385166, 0.641809, -0.020859},{
      0.385907, 0.637126, -0.020859},{0.389188, 0.638192, -0.022973}}],
    Polygon[{{0.385166, 0.641809, -0.020859},{0.382089, 0.641809, -0.018232},{
      0.382981, 0.636175, -0.018232},{0.385907, 0.637126, -0.020859}}],
    Polygon[{{0.382089, 0.641809, -0.018232},{0.379461, 0.641809, -0.015155},{
      0.380482, 0.635363, -0.015155},{0.382981, 0.636175, -0.018232}}],
    Polygon[{{0.379461, 0.641809, -0.015155},{0.377347, 0.641809, -0.011705},{
      0.378472, 0.634710, -0.011705},{0.380482, 0.635363, -0.015155}}],
    Polygon[{{0.377347, 0.641809, -0.011705},{0.375799, 0.641809, -0.007968},{
      0.376999, 0.634231, -0.007968},{0.378472, 0.634710, -0.011705}}],
    Polygon[{{0.375799, 0.641809, -0.007968},{0.374855, 0.641809, -0.004033},{
      0.376101, 0.633939, -0.004033},{0.376999, 0.634231, -0.007968}}],
    Polygon[{{0.374855, 0.641809, -0.004033},{0.374537, 0.641809, 0.000000},{
      0.375799, 0.633841, 0.000000},{0.376101, 0.633939, -0.004033}}],
    Polygon[{{0.374537, 0.641809, 0.000000},{0.374855, 0.641809, 0.004033},{
      0.376101, 0.633939, 0.004033},{0.375799, 0.633841, 0.000000}}],
    Polygon[{{0.374855, 0.641809, 0.004033},{0.375799, 0.641809, 0.007968},{
      0.376999, 0.634231, 0.007968},{0.376101, 0.633939, 0.004033}}],
    Polygon[{{0.375799, 0.641809, 0.007968},{0.377347, 0.641809, 0.011705},{
      0.378472, 0.634710, 0.011705},{0.376999, 0.634231, 0.007968}}],
    Polygon[{{0.377347, 0.641809, 0.011705},{0.379461, 0.641809, 0.015155},{
      0.380482, 0.635363, 0.015155},{0.378472, 0.634710, 0.011705}}],
    Polygon[{{0.379461, 0.641809, 0.015155},{0.382089, 0.641809, 0.018232},{
      0.382981, 0.636175, 0.018232},{0.380482, 0.635363, 0.015155}}],
    Polygon[{{0.382089, 0.641809, 0.018232},{0.385166, 0.641809, 0.020859},{
      0.385907, 0.637126, 0.020859},{0.382981, 0.636175, 0.018232}}],
    Polygon[{{0.385166, 0.641809, 0.020859},{0.388615, 0.641809, 0.022973},{
      0.389188, 0.638192, 0.022973},{0.385907, 0.637126, 0.020859}}],
    Polygon[{{0.388615, 0.641809, 0.022973},{0.392353, 0.641809, 0.024521},{
      0.392743, 0.639347, 0.024521},{0.389188, 0.638192, 0.022973}}],
    Polygon[{{0.392353, 0.641809, 0.024521},{0.396287, 0.641809, 0.025466},{
      0.396485, 0.640562, 0.025466},{0.392743, 0.639347, 0.024521}}],
    Polygon[{{0.396485, 0.640562, -0.025466},{0.392743, 0.639347, -0.024521},{
      0.393875, 0.637126, -0.024521},{0.397058, 0.639438, -0.025466}}],
    Polygon[{{0.392743, 0.639347, -0.024521},{0.389188, 0.638192, -0.022973},{
      0.390851, 0.634929, -0.022973},{0.393875, 0.637126, -0.024521}}],
    Polygon[{{0.389188, 0.638192, -0.022973},{0.385907, 0.637126, -0.020859},{
      0.388060, 0.632901, -0.020859},{0.390851, 0.634929, -0.022973}}],
    Polygon[{{0.385907, 0.637126, -0.020859},{0.382981, 0.636175, -0.018232},{
      0.385571, 0.631093, -0.018232},{0.388060, 0.632901, -0.020859}}],
    Polygon[{{0.382981, 0.636175, -0.018232},{0.380482, 0.635363, -0.015155},{
      0.383445, 0.629548, -0.015155},{0.385571, 0.631093, -0.018232}}],
    Polygon[{{0.380482, 0.635363, -0.015155},{0.378472, 0.634710, -0.011705},{
      0.381735, 0.628305, -0.011705},{0.383445, 0.629548, -0.015155}}],
    Polygon[{{0.378472, 0.634710, -0.011705},{0.376999, 0.634231, -0.007968},{
      0.380482, 0.627395, -0.007968},{0.381735, 0.628305, -0.011705}}],
    Polygon[{{0.376999, 0.634231, -0.007968},{0.376101, 0.633939, -0.004033},{
      0.379718, 0.626840, -0.004033},{0.380482, 0.627395, -0.007968}}],
    Polygon[{{0.376101, 0.633939, -0.004033},{0.375799, 0.633841, 0.000000},{
      0.379461, 0.626654, 0.000000},{0.379718, 0.626840, -0.004033}}],
    Polygon[{{0.375799, 0.633841, 0.000000},{0.376101, 0.633939, 0.004033},{
      0.379718, 0.626840, 0.004033},{0.379461, 0.626654, 0.000000}}],
    Polygon[{{0.376101, 0.633939, 0.004033},{0.376999, 0.634231, 0.007968},{
      0.380482, 0.627395, 0.007968},{0.379718, 0.626840, 0.004033}}],
    Polygon[{{0.376999, 0.634231, 0.007968},{0.378472, 0.634710, 0.011705},{
      0.381735, 0.628305, 0.011705},{0.380482, 0.627395, 0.007968}}],
    Polygon[{{0.378472, 0.634710, 0.011705},{0.380482, 0.635363, 0.015155},{
      0.383445, 0.629548, 0.015155},{0.381735, 0.628305, 0.011705}}],
    Polygon[{{0.380482, 0.635363, 0.015155},{0.382981, 0.636175, 0.018232},{
      0.385571, 0.631093, 0.018232},{0.383445, 0.629548, 0.015155}}],
    Polygon[{{0.382981, 0.636175, 0.018232},{0.385907, 0.637126, 0.020859},{
      0.388060, 0.632901, 0.020859},{0.385571, 0.631093, 0.018232}}],
    Polygon[{{0.385907, 0.637126, 0.020859},{0.389188, 0.638192, 0.022973},{
      0.390851, 0.634929, 0.022973},{0.388060, 0.632901, 0.020859}}],
    Polygon[{{0.389188, 0.638192, 0.022973},{0.392743, 0.639347, 0.024521},{
      0.393875, 0.637126, 0.024521},{0.390851, 0.634929, 0.022973}}],
    Polygon[{{0.392743, 0.639347, 0.024521},{0.396485, 0.640562, 0.025466},{
      0.397058, 0.639438, 0.025466},{0.393875, 0.637126, 0.024521}}],
    Polygon[{{0.397058, 0.639438, -0.025466},{0.393875, 0.637126, -0.024521},{
      0.395637, 0.635363, -0.024521},{0.397950, 0.638546, -0.025466}}],
    Polygon[{{0.393875, 0.637126, -0.024521},{0.390851, 0.634929, -0.022973},{
      0.393440, 0.632339, -0.022973},{0.395637, 0.635363, -0.024521}}],
    Polygon[{{0.390851, 0.634929, -0.022973},{0.388060, 0.632901, -0.020859},{
      0.391413, 0.629548, -0.020859},{0.393440, 0.632339, -0.022973}}],
    Polygon[{{0.388060, 0.632901, -0.020859},{0.385571, 0.631093, -0.018232},{
      0.389604, 0.627059, -0.018232},{0.391413, 0.629548, -0.020859}}],
    Polygon[{{0.385571, 0.631093, -0.018232},{0.383445, 0.629548, -0.015155},{
      0.388060, 0.624933, -0.015155},{0.389604, 0.627059, -0.018232}}],
    Polygon[{{0.383445, 0.629548, -0.015155},{0.381735, 0.628305, -0.011705},{
      0.386817, 0.623223, -0.011705},{0.388060, 0.624933, -0.015155}}],
    Polygon[{{0.381735, 0.628305, -0.011705},{0.380482, 0.627395, -0.007968},{
      0.385907, 0.621971, -0.007968},{0.386817, 0.623223, -0.011705}}],
    Polygon[{{0.380482, 0.627395, -0.007968},{0.379718, 0.626840, -0.004033},{
      0.385352, 0.621206, -0.004033},{0.385907, 0.621971, -0.007968}}],
    Polygon[{{0.379718, 0.626840, -0.004033},{0.379461, 0.626654, 0.000000},{
      0.385166, 0.620950, 0.000000},{0.385352, 0.621206, -0.004033}}],
    Polygon[{{0.379461, 0.626654, 0.000000},{0.379718, 0.626840, 0.004033},{
      0.385352, 0.621206, 0.004033},{0.385166, 0.620950, 0.000000}}],
    Polygon[{{0.379718, 0.626840, 0.004033},{0.380482, 0.627395, 0.007968},{
      0.385907, 0.621971, 0.007968},{0.385352, 0.621206, 0.004033}}],
    Polygon[{{0.380482, 0.627395, 0.007968},{0.381735, 0.628305, 0.011705},{
      0.386817, 0.623223, 0.011705},{0.385907, 0.621971, 0.007968}}],
    Polygon[{{0.381735, 0.628305, 0.011705},{0.383445, 0.629548, 0.015155},{
      0.388060, 0.624933, 0.015155},{0.386817, 0.623223, 0.011705}}],
    Polygon[{{0.383445, 0.629548, 0.015155},{0.385571, 0.631093, 0.018232},{
      0.389604, 0.627059, 0.018232},{0.388060, 0.624933, 0.015155}}],
    Polygon[{{0.385571, 0.631093, 0.018232},{0.388060, 0.632901, 0.020859},{
      0.391413, 0.629548, 0.020859},{0.389604, 0.627059, 0.018232}}],
    Polygon[{{0.388060, 0.632901, 0.020859},{0.390851, 0.634929, 0.022973},{
      0.393440, 0.632339, 0.022973},{0.391413, 0.629548, 0.020859}}],
    Polygon[{{0.390851, 0.634929, 0.022973},{0.393875, 0.637126, 0.024521},{
      0.395637, 0.635363, 0.024521},{0.393440, 0.632339, 0.022973}}],
    Polygon[{{0.393875, 0.637126, 0.024521},{0.397058, 0.639438, 0.025466},{
      0.397950, 0.638546, 0.025466},{0.395637, 0.635363, 0.024521}}],
    Polygon[{{0.397950, 0.638546, -0.025466},{0.395637, 0.635363, -0.024521},{
      0.397859, 0.634231, -0.024521},{0.399074, 0.637973, -0.025466}}],
    Polygon[{{0.395637, 0.635363, -0.024521},{0.393440, 0.632339, -0.022973},{
      0.396703, 0.630676, -0.022973},{0.397859, 0.634231, -0.024521}}],
    Polygon[{{0.393440, 0.632339, -0.022973},{0.391413, 0.629548, -0.020859},{
      0.395637, 0.627395, -0.020859},{0.396703, 0.630676, -0.022973}}],
    Polygon[{{0.391413, 0.629548, -0.020859},{0.389604, 0.627059, -0.018232},{
      0.394687, 0.624470, -0.018232},{0.395637, 0.627395, -0.020859}}],
    Polygon[{{0.389604, 0.627059, -0.018232},{0.388060, 0.624933, -0.015155},{
      0.393875, 0.621971, -0.015155},{0.394687, 0.624470, -0.018232}}],
    Polygon[{{0.388060, 0.624933, -0.015155},{0.386817, 0.623223, -0.011705},{
      0.393222, 0.619960, -0.011705},{0.393875, 0.621971, -0.015155}}],
    Polygon[{{0.386817, 0.623223, -0.011705},{0.385907, 0.621971, -0.007968},{
      0.392743, 0.618487, -0.007968},{0.393222, 0.619960, -0.011705}}],
    Polygon[{{0.385907, 0.621971, -0.007968},{0.385352, 0.621206, -0.004033},{
      0.392451, 0.617589, -0.004033},{0.392743, 0.618487, -0.007968}}],
    Polygon[{{0.385352, 0.621206, -0.004033},{0.385166, 0.620950, 0.000000},{
      0.392353, 0.617287, 0.000000},{0.392451, 0.617589, -0.004033}}],
    Polygon[{{0.385166, 0.620950, 0.000000},{0.385352, 0.621206, 0.004033},{
      0.392451, 0.617589, 0.004033},{0.392353, 0.617287, 0.000000}}],
    Polygon[{{0.385352, 0.621206, 0.004033},{0.385907, 0.621971, 0.007968},{
      0.392743, 0.618487, 0.007968},{0.392451, 0.617589, 0.004033}}],
    Polygon[{{0.385907, 0.621971, 0.007968},{0.386817, 0.623223, 0.011705},{
      0.393222, 0.619960, 0.011705},{0.392743, 0.618487, 0.007968}}],
    Polygon[{{0.386817, 0.623223, 0.011705},{0.388060, 0.624933, 0.015155},{
      0.393875, 0.621971, 0.015155},{0.393222, 0.619960, 0.011705}}],
    Polygon[{{0.388060, 0.624933, 0.015155},{0.389604, 0.627059, 0.018232},{
      0.394687, 0.624470, 0.018232},{0.393875, 0.621971, 0.015155}}],
    Polygon[{{0.389604, 0.627059, 0.018232},{0.391413, 0.629548, 0.020859},{
      0.395637, 0.627395, 0.020859},{0.394687, 0.624470, 0.018232}}],
    Polygon[{{0.391413, 0.629548, 0.020859},{0.393440, 0.632339, 0.022973},{
      0.396703, 0.630676, 0.022973},{0.395637, 0.627395, 0.020859}}],
    Polygon[{{0.393440, 0.632339, 0.022973},{0.395637, 0.635363, 0.024521},{
      0.397859, 0.634231, 0.024521},{0.396703, 0.630676, 0.022973}}],
    Polygon[{{0.395637, 0.635363, 0.024521},{0.397950, 0.638546, 0.025466},{
      0.399074, 0.637973, 0.025466},{0.397859, 0.634231, 0.024521}}],
    Polygon[{{0.399074, 0.637973, -0.025466},{0.397859, 0.634231, -0.024521},{
      0.400321, 0.633841, -0.024521},{0.400321, 0.637775, -0.025466}}],
    Polygon[{{0.397859, 0.634231, -0.024521},{0.396703, 0.630676, -0.022973},{
      0.400321, 0.630103, -0.022973},{0.400321, 0.633841, -0.024521}}],
    Polygon[{{0.396703, 0.630676, -0.022973},{0.395637, 0.627395, -0.020859},{
      0.400321, 0.626654, -0.020859},{0.400321, 0.630103, -0.022973}}],
    Polygon[{{0.395637, 0.627395, -0.020859},{0.394687, 0.624470, -0.018232},{
      0.400321, 0.623577, -0.018232},{0.400321, 0.626654, -0.020859}}],
    Polygon[{{0.394687, 0.624470, -0.018232},{0.393875, 0.621971, -0.015155},{
      0.400321, 0.620950, -0.015155},{0.400321, 0.623577, -0.018232}}],
    Polygon[{{0.393875, 0.621971, -0.015155},{0.393222, 0.619960, -0.011705},{
      0.400321, 0.618836, -0.011705},{0.400321, 0.620950, -0.015155}}],
    Polygon[{{0.393222, 0.619960, -0.011705},{0.392743, 0.618487, -0.007968},{
      0.400321, 0.617287, -0.007968},{0.400321, 0.618836, -0.011705}}],
    Polygon[{{0.392743, 0.618487, -0.007968},{0.392451, 0.617589, -0.004033},{
      0.400321, 0.616343, -0.004033},{0.400321, 0.617287, -0.007968}}],
    Polygon[{{0.392451, 0.617589, -0.004033},{0.392353, 0.617287, 0.000000},{
      0.400321, 0.616025, 0.000000},{0.400321, 0.616343, -0.004033}}],
    Polygon[{{0.392353, 0.617287, 0.000000},{0.392451, 0.617589, 0.004033},{
      0.400321, 0.616343, 0.004033},{0.400321, 0.616025, 0.000000}}],
    Polygon[{{0.392451, 0.617589, 0.004033},{0.392743, 0.618487, 0.007968},{
      0.400321, 0.617287, 0.007968},{0.400321, 0.616343, 0.004033}}],
    Polygon[{{0.392743, 0.618487, 0.007968},{0.393222, 0.619960, 0.011705},{
      0.400321, 0.618836, 0.011705},{0.400321, 0.617287, 0.007968}}],
    Polygon[{{0.393222, 0.619960, 0.011705},{0.393875, 0.621971, 0.015155},{
      0.400321, 0.620950, 0.015155},{0.400321, 0.618836, 0.011705}}],
    Polygon[{{0.393875, 0.621971, 0.015155},{0.394687, 0.624470, 0.018232},{
      0.400321, 0.623577, 0.018232},{0.400321, 0.620950, 0.015155}}],
    Polygon[{{0.394687, 0.624470, 0.018232},{0.395637, 0.627395, 0.020859},{
      0.400321, 0.626654, 0.020859},{0.400321, 0.623577, 0.018232}}],
    Polygon[{{0.395637, 0.627395, 0.020859},{0.396703, 0.630676, 0.022973},{
      0.400321, 0.630103, 0.022973},{0.400321, 0.626654, 0.020859}}],
    Polygon[{{0.396703, 0.630676, 0.022973},{0.397859, 0.634231, 0.024521},{
      0.400321, 0.633841, 0.024521},{0.400321, 0.630103, 0.022973}}],
    Polygon[{{0.397859, 0.634231, 0.024521},{0.399074, 0.637973, 0.025466},{
      0.400321, 0.637775, 0.025466},{0.400321, 0.633841, 0.024521}}],
    Polygon[{{0.400321, 0.637775, -0.025466},{0.400321, 0.633841, -0.024521},{
      0.402783, 0.634231, -0.024521},{0.401567, 0.637973, -0.025466}}],
    Polygon[{{0.400321, 0.633841, -0.024521},{0.400321, 0.630103, -0.022973},{
      0.403938, 0.630676, -0.022973},{0.402783, 0.634231, -0.024521}}],
    Polygon[{{0.400321, 0.630103, -0.022973},{0.400321, 0.626654, -0.020859},{
      0.405004, 0.627395, -0.020859},{0.403938, 0.630676, -0.022973}}],
    Polygon[{{0.400321, 0.626654, -0.020859},{0.400321, 0.623577, -0.018232},{
      0.405955, 0.624470, -0.018232},{0.405004, 0.627395, -0.020859}}],
    Polygon[{{0.400321, 0.623577, -0.018232},{0.400321, 0.620950, -0.015155},{
      0.406766, 0.621971, -0.015155},{0.405955, 0.624470, -0.018232}}],
    Polygon[{{0.400321, 0.620950, -0.015155},{0.400321, 0.618836, -0.011705},{
      0.407420, 0.619960, -0.011705},{0.406766, 0.621971, -0.015155}}],
    Polygon[{{0.400321, 0.618836, -0.011705},{0.400321, 0.617287, -0.007968},{
      0.407898, 0.618487, -0.007968},{0.407420, 0.619960, -0.011705}}],
    Polygon[{{0.400321, 0.617287, -0.007968},{0.400321, 0.616343, -0.004033},{
      0.408190, 0.617589, -0.004033},{0.407898, 0.618487, -0.007968}}],
    Polygon[{{0.400321, 0.616343, -0.004033},{0.400321, 0.616025, 0.000000},{
      0.408288, 0.617287, 0.000000},{0.408190, 0.617589, -0.004033}}],
    Polygon[{{0.400321, 0.616025, 0.000000},{0.400321, 0.616343, 0.004033},{
      0.408190, 0.617589, 0.004033},{0.408288, 0.617287, 0.000000}}],
    Polygon[{{0.400321, 0.616343, 0.004033},{0.400321, 0.617287, 0.007968},{
      0.407898, 0.618487, 0.007968},{0.408190, 0.617589, 0.004033}}],
    Polygon[{{0.400321, 0.617287, 0.007968},{0.400321, 0.618836, 0.011705},{
      0.407420, 0.619960, 0.011705},{0.407898, 0.618487, 0.007968}}],
    Polygon[{{0.400321, 0.618836, 0.011705},{0.400321, 0.620950, 0.015155},{
      0.406766, 0.621971, 0.015155},{0.407420, 0.619960, 0.011705}}],
    Polygon[{{0.400321, 0.620950, 0.015155},{0.400321, 0.623577, 0.018232},{
      0.405955, 0.624470, 0.018232},{0.406766, 0.621971, 0.015155}}],
    Polygon[{{0.400321, 0.623577, 0.018232},{0.400321, 0.626654, 0.020859},{
      0.405004, 0.627395, 0.020859},{0.405955, 0.624470, 0.018232}}],
    Polygon[{{0.400321, 0.626654, 0.020859},{0.400321, 0.630103, 0.022973},{
      0.403938, 0.630676, 0.022973},{0.405004, 0.627395, 0.020859}}],
    Polygon[{{0.400321, 0.630103, 0.022973},{0.400321, 0.633841, 0.024521},{
      0.402783, 0.634231, 0.024521},{0.403938, 0.630676, 0.022973}}],
    Polygon[{{0.400321, 0.633841, 0.024521},{0.400321, 0.637775, 0.025466},{
      0.401567, 0.637973, 0.025466},{0.402783, 0.634231, 0.024521}}],
    Polygon[{{0.401567, 0.637973, -0.025466},{0.402783, 0.634231, -0.024521},{
      0.405004, 0.635363, -0.024521},{0.402691, 0.638546, -0.025466}}],
    Polygon[{{0.402783, 0.634231, -0.024521},{0.403938, 0.630676, -0.022973},{
      0.407201, 0.632339, -0.022973},{0.405004, 0.635363, -0.024521}}],
    Polygon[{{0.403938, 0.630676, -0.022973},{0.405004, 0.627395, -0.020859},{
      0.409229, 0.629548, -0.020859},{0.407201, 0.632339, -0.022973}}],
    Polygon[{{0.405004, 0.627395, -0.020859},{0.405955, 0.624470, -0.018232},{
      0.411037, 0.627059, -0.018232},{0.409229, 0.629548, -0.020859}}],
    Polygon[{{0.405955, 0.624470, -0.018232},{0.406766, 0.621971, -0.015155},{
      0.412581, 0.624933, -0.015155},{0.411037, 0.627059, -0.018232}}],
    Polygon[{{0.406766, 0.621971, -0.015155},{0.407420, 0.619960, -0.011705},{
      0.413824, 0.623223, -0.011705},{0.412581, 0.624933, -0.015155}}],
    Polygon[{{0.407420, 0.619960, -0.011705},{0.407898, 0.618487, -0.007968},{
      0.414734, 0.621971, -0.007968},{0.413824, 0.623223, -0.011705}}],
    Polygon[{{0.407898, 0.618487, -0.007968},{0.408190, 0.617589, -0.004033},{
      0.415289, 0.621206, -0.004033},{0.414734, 0.621971, -0.007968}}],
    Polygon[{{0.408190, 0.617589, -0.004033},{0.408288, 0.617287, 0.000000},{
      0.415476, 0.620950, 0.000000},{0.415289, 0.621206, -0.004033}}],
    Polygon[{{0.408288, 0.617287, 0.000000},{0.408190, 0.617589, 0.004033},{
      0.415289, 0.621206, 0.004033},{0.415476, 0.620950, 0.000000}}],
    Polygon[{{0.408190, 0.617589, 0.004033},{0.407898, 0.618487, 0.007968},{
      0.414734, 0.621971, 0.007968},{0.415289, 0.621206, 0.004033}}],
    Polygon[{{0.407898, 0.618487, 0.007968},{0.407420, 0.619960, 0.011705},{
      0.413824, 0.623223, 0.011705},{0.414734, 0.621971, 0.007968}}],
    Polygon[{{0.407420, 0.619960, 0.011705},{0.406766, 0.621971, 0.015155},{
      0.412581, 0.624933, 0.015155},{0.413824, 0.623223, 0.011705}}],
    Polygon[{{0.406766, 0.621971, 0.015155},{0.405955, 0.624470, 0.018232},{
      0.411037, 0.627059, 0.018232},{0.412581, 0.624933, 0.015155}}],
    Polygon[{{0.405955, 0.624470, 0.018232},{0.405004, 0.627395, 0.020859},{
      0.409229, 0.629548, 0.020859},{0.411037, 0.627059, 0.018232}}],
    Polygon[{{0.405004, 0.627395, 0.020859},{0.403938, 0.630676, 0.022973},{
      0.407201, 0.632339, 0.022973},{0.409229, 0.629548, 0.020859}}],
    Polygon[{{0.403938, 0.630676, 0.022973},{0.402783, 0.634231, 0.024521},{
      0.405004, 0.635363, 0.024521},{0.407201, 0.632339, 0.022973}}],
    Polygon[{{0.402783, 0.634231, 0.024521},{0.401567, 0.637973, 0.025466},{
      0.402691, 0.638546, 0.025466},{0.405004, 0.635363, 0.024521}}],
    Polygon[{{0.402691, 0.638546, -0.025466},{0.405004, 0.635363, -0.024521},{
      0.406766, 0.637126, -0.024521},{0.403584, 0.639438, -0.025466}}],
    Polygon[{{0.405004, 0.635363, -0.024521},{0.407201, 0.632339, -0.022973},{
      0.409791, 0.634929, -0.022973},{0.406766, 0.637126, -0.024521}}],
    Polygon[{{0.407201, 0.632339, -0.022973},{0.409229, 0.629548, -0.020859},{
      0.412581, 0.632901, -0.020859},{0.409791, 0.634929, -0.022973}}],
    Polygon[{{0.409229, 0.629548, -0.020859},{0.411037, 0.627059, -0.018232},{
      0.415070, 0.631093, -0.018232},{0.412581, 0.632901, -0.020859}}],
    Polygon[{{0.411037, 0.627059, -0.018232},{0.412581, 0.624933, -0.015155},{
      0.417196, 0.629548, -0.015155},{0.415070, 0.631093, -0.018232}}],
    Polygon[{{0.412581, 0.624933, -0.015155},{0.413824, 0.623223, -0.011705},{
      0.418906, 0.628305, -0.011705},{0.417196, 0.629548, -0.015155}}],
    Polygon[{{0.413824, 0.623223, -0.011705},{0.414734, 0.621971, -0.007968},{
      0.420159, 0.627395, -0.007968},{0.418906, 0.628305, -0.011705}}],
    Polygon[{{0.414734, 0.621971, -0.007968},{0.415289, 0.621206, -0.004033},{
      0.420923, 0.626840, -0.004033},{0.420159, 0.627395, -0.007968}}],
    Polygon[{{0.415289, 0.621206, -0.004033},{0.415476, 0.620950, 0.000000},{
      0.421180, 0.626654, 0.000000},{0.420923, 0.626840, -0.004033}}],
    Polygon[{{0.415476, 0.620950, 0.000000},{0.415289, 0.621206, 0.004033},{
      0.420923, 0.626840, 0.004033},{0.421180, 0.626654, 0.000000}}],
    Polygon[{{0.415289, 0.621206, 0.004033},{0.414734, 0.621971, 0.007968},{
      0.420159, 0.627395, 0.007968},{0.420923, 0.626840, 0.004033}}],
    Polygon[{{0.414734, 0.621971, 0.007968},{0.413824, 0.623223, 0.011705},{
      0.418906, 0.628305, 0.011705},{0.420159, 0.627395, 0.007968}}],
    Polygon[{{0.413824, 0.623223, 0.011705},{0.412581, 0.624933, 0.015155},{
      0.417196, 0.629548, 0.015155},{0.418906, 0.628305, 0.011705}}],
    Polygon[{{0.412581, 0.624933, 0.015155},{0.411037, 0.627059, 0.018232},{
      0.415070, 0.631093, 0.018232},{0.417196, 0.629548, 0.015155}}],
    Polygon[{{0.411037, 0.627059, 0.018232},{0.409229, 0.629548, 0.020859},{
      0.412581, 0.632901, 0.020859},{0.415070, 0.631093, 0.018232}}],
    Polygon[{{0.409229, 0.629548, 0.020859},{0.407201, 0.632339, 0.022973},{
      0.409791, 0.634929, 0.022973},{0.412581, 0.632901, 0.020859}}],
    Polygon[{{0.407201, 0.632339, 0.022973},{0.405004, 0.635363, 0.024521},{
      0.406766, 0.637126, 0.024521},{0.409791, 0.634929, 0.022973}}],
    Polygon[{{0.405004, 0.635363, 0.024521},{0.402691, 0.638546, 0.025466},{
      0.403584, 0.639438, 0.025466},{0.406766, 0.637126, 0.024521}}],
    Polygon[{{0.403584, 0.639438, -0.025466},{0.406766, 0.637126, -0.024521},{
      0.407898, 0.639347, -0.024521},{0.404157, 0.640562, -0.025466}}],
    Polygon[{{0.406766, 0.637126, -0.024521},{0.409791, 0.634929, -0.022973},{
      0.411453, 0.638192, -0.022973},{0.407898, 0.639347, -0.024521}}],
    Polygon[{{0.409791, 0.634929, -0.022973},{0.412581, 0.632901, -0.020859},{
      0.414734, 0.637126, -0.020859},{0.411453, 0.638192, -0.022973}}],
    Polygon[{{0.412581, 0.632901, -0.020859},{0.415070, 0.631093, -0.018232},{
      0.417660, 0.636175, -0.018232},{0.414734, 0.637126, -0.020859}}],
    Polygon[{{0.415070, 0.631093, -0.018232},{0.417196, 0.629548, -0.015155},{
      0.420159, 0.635363, -0.015155},{0.417660, 0.636175, -0.018232}}],
    Polygon[{{0.417196, 0.629548, -0.015155},{0.418906, 0.628305, -0.011705},{
      0.422169, 0.634710, -0.011705},{0.420159, 0.635363, -0.015155}}],
    Polygon[{{0.418906, 0.628305, -0.011705},{0.420159, 0.627395, -0.007968},{
      0.423642, 0.634231, -0.007968},{0.422169, 0.634710, -0.011705}}],
    Polygon[{{0.420159, 0.627395, -0.007968},{0.420923, 0.626840, -0.004033},{
      0.424540, 0.633939, -0.004033},{0.423642, 0.634231, -0.007968}}],
    Polygon[{{0.420923, 0.626840, -0.004033},{0.421180, 0.626654, 0.000000},{
      0.424842, 0.633841, 0.000000},{0.424540, 0.633939, -0.004033}}],
    Polygon[{{0.421180, 0.626654, 0.000000},{0.420923, 0.626840, 0.004033},{
      0.424540, 0.633939, 0.004033},{0.424842, 0.633841, 0.000000}}],
    Polygon[{{0.420923, 0.626840, 0.004033},{0.420159, 0.627395, 0.007968},{
      0.423642, 0.634231, 0.007968},{0.424540, 0.633939, 0.004033}}],
    Polygon[{{0.420159, 0.627395, 0.007968},{0.418906, 0.628305, 0.011705},{
      0.422169, 0.634710, 0.011705},{0.423642, 0.634231, 0.007968}}],
    Polygon[{{0.418906, 0.628305, 0.011705},{0.417196, 0.629548, 0.015155},{
      0.420159, 0.635363, 0.015155},{0.422169, 0.634710, 0.011705}}],
    Polygon[{{0.417196, 0.629548, 0.015155},{0.415070, 0.631093, 0.018232},{
      0.417660, 0.636175, 0.018232},{0.420159, 0.635363, 0.015155}}],
    Polygon[{{0.415070, 0.631093, 0.018232},{0.412581, 0.632901, 0.020859},{
      0.414734, 0.637126, 0.020859},{0.417660, 0.636175, 0.018232}}],
    Polygon[{{0.412581, 0.632901, 0.020859},{0.409791, 0.634929, 0.022973},{
      0.411453, 0.638192, 0.022973},{0.414734, 0.637126, 0.020859}}],
    Polygon[{{0.409791, 0.634929, 0.022973},{0.406766, 0.637126, 0.024521},{
      0.407898, 0.639347, 0.024521},{0.411453, 0.638192, 0.022973}}],
    Polygon[{{0.406766, 0.637126, 0.024521},{0.403584, 0.639438, 0.025466},{
      0.404157, 0.640562, 0.025466},{0.407898, 0.639347, 0.024521}}],
    Polygon[{{0.404157, 0.640562, -0.025466},{0.407898, 0.639347, -0.024521},{
      0.408288, 0.641809, -0.024521},{0.404354, 0.641809, -0.025466}}],
    Polygon[{{0.407898, 0.639347, -0.024521},{0.411453, 0.638192, -0.022973},{
      0.412026, 0.641809, -0.022973},{0.408288, 0.641809, -0.024521}}],
    Polygon[{{0.411453, 0.638192, -0.022973},{0.414734, 0.637126, -0.020859},{
      0.415476, 0.641809, -0.020859},{0.412026, 0.641809, -0.022973}}],
    Polygon[{{0.414734, 0.637126, -0.020859},{0.417660, 0.636175, -0.018232},{
      0.418552, 0.641809, -0.018232},{0.415476, 0.641809, -0.020859}}],
    Polygon[{{0.417660, 0.636175, -0.018232},{0.420159, 0.635363, -0.015155},{
      0.421180, 0.641809, -0.015155},{0.418552, 0.641809, -0.018232}}],
    Polygon[{{0.420159, 0.635363, -0.015155},{0.422169, 0.634710, -0.011705},{
      0.423294, 0.641809, -0.011705},{0.421180, 0.641809, -0.015155}}],
    Polygon[{{0.422169, 0.634710, -0.011705},{0.423642, 0.634231, -0.007968},{
      0.424842, 0.641809, -0.007968},{0.423294, 0.641809, -0.011705}}],
    Polygon[{{0.423642, 0.634231, -0.007968},{0.424540, 0.633939, -0.004033},{
      0.425787, 0.641809, -0.004033},{0.424842, 0.641809, -0.007968}}],
    Polygon[{{0.424540, 0.633939, -0.004033},{0.424842, 0.633841, 0.000000},{
      0.426104, 0.641809, 0.000000},{0.425787, 0.641809, -0.004033}}],
    Polygon[{{0.424842, 0.633841, 0.000000},{0.424540, 0.633939, 0.004033},{
      0.425787, 0.641809, 0.004033},{0.426104, 0.641809, 0.000000}}],
    Polygon[{{0.424540, 0.633939, 0.004033},{0.423642, 0.634231, 0.007968},{
      0.424842, 0.641809, 0.007968},{0.425787, 0.641809, 0.004033}}],
    Polygon[{{0.423642, 0.634231, 0.007968},{0.422169, 0.634710, 0.011705},{
      0.423294, 0.641809, 0.011705},{0.424842, 0.641809, 0.007968}}],
    Polygon[{{0.422169, 0.634710, 0.011705},{0.420159, 0.635363, 0.015155},{
      0.421180, 0.641809, 0.015155},{0.423294, 0.641809, 0.011705}}],
    Polygon[{{0.420159, 0.635363, 0.015155},{0.417660, 0.636175, 0.018232},{
      0.418552, 0.641809, 0.018232},{0.421180, 0.641809, 0.015155}}],
    Polygon[{{0.417660, 0.636175, 0.018232},{0.414734, 0.637126, 0.020859},{
      0.415476, 0.641809, 0.020859},{0.418552, 0.641809, 0.018232}}],
    Polygon[{{0.414734, 0.637126, 0.020859},{0.411453, 0.638192, 0.022973},{
      0.412026, 0.641809, 0.022973},{0.415476, 0.641809, 0.020859}}],
    Polygon[{{0.411453, 0.638192, 0.022973},{0.407898, 0.639347, 0.024521},{
      0.408288, 0.641809, 0.024521},{0.412026, 0.641809, 0.022973}}],
    Polygon[{{0.407898, 0.639347, 0.024521},{0.404157, 0.640562, 0.025466},{
      0.404354, 0.641809, 0.025466},{0.408288, 0.641809, 0.024521}}],
    Polygon[{{0.335495, 0.549716, -0.013647},{0.337603, 0.549716, -0.013141},{
      0.337394, 0.551035, -0.013141},{0.335389, 0.550384, -0.013647}}],
    Polygon[{{0.337603, 0.549716, -0.013141},{0.339606, 0.549716, -0.012311},{
      0.339299, 0.551654, -0.012311},{0.337394, 0.551035, -0.013141}}],
    Polygon[{{0.339606, 0.549716, -0.012311},{0.341455, 0.549716, -0.011178},{
      0.341057, 0.552225, -0.011178},{0.339299, 0.551654, -0.012311}}],
    Polygon[{{0.341455, 0.549716, -0.011178},{0.343104, 0.549716, -0.009770},{
      0.342625, 0.552735, -0.009770},{0.341057, 0.552225, -0.011178}}],
    Polygon[{{0.343104, 0.549716, -0.009770},{0.344512, 0.549716, -0.008122},{
      0.343965, 0.553170, -0.008122},{0.342625, 0.552735, -0.009770}}],
    Polygon[{{0.344512, 0.549716, -0.008122},{0.345645, 0.549716, -0.006273},{
      0.345042, 0.553520, -0.006273},{0.343965, 0.553170, -0.008122}}],
    Polygon[{{0.345645, 0.549716, -0.006273},{0.346474, 0.549716, -0.004270},{
      0.345831, 0.553777, -0.004270},{0.345042, 0.553520, -0.006273}}],
    Polygon[{{0.346474, 0.549716, -0.004270},{0.346981, 0.549716, -0.002162},{
      0.346313, 0.553933, -0.002162},{0.345831, 0.553777, -0.004270}}],
    Polygon[{{0.346981, 0.549716, -0.002162},{0.347151, 0.549716, 0.000000},{
      0.346474, 0.553985, 0.000000},{0.346313, 0.553933, -0.002162}}],
    Polygon[{{0.347151, 0.549716, 0.000000},{0.346981, 0.549716, 0.002162},{
      0.346313, 0.553933, 0.002162},{0.346474, 0.553985, 0.000000}}],
    Polygon[{{0.346981, 0.549716, 0.002162},{0.346474, 0.549716, 0.004270},{
      0.345831, 0.553777, 0.004270},{0.346313, 0.553933, 0.002162}}],
    Polygon[{{0.346474, 0.549716, 0.004270},{0.345645, 0.549716, 0.006273},{
      0.345042, 0.553520, 0.006273},{0.345831, 0.553777, 0.004270}}],
    Polygon[{{0.345645, 0.549716, 0.006273},{0.344512, 0.549716, 0.008122},{
      0.343965, 0.553170, 0.008122},{0.345042, 0.553520, 0.006273}}],
    Polygon[{{0.344512, 0.549716, 0.008122},{0.343104, 0.549716, 0.009770},{
      0.342625, 0.552735, 0.009770},{0.343965, 0.553170, 0.008122}}],
    Polygon[{{0.343104, 0.549716, 0.009770},{0.341455, 0.549716, 0.011178},{
      0.341057, 0.552225, 0.011178},{0.342625, 0.552735, 0.009770}}],
    Polygon[{{0.341455, 0.549716, 0.011178},{0.339606, 0.549716, 0.012311},{
      0.339299, 0.551654, 0.012311},{0.341057, 0.552225, 0.011178}}],
    Polygon[{{0.339606, 0.549716, 0.012311},{0.337603, 0.549716, 0.013141},{
      0.337394, 0.551035, 0.013141},{0.339299, 0.551654, 0.012311}}],
    Polygon[{{0.337603, 0.549716, 0.013141},{0.335495, 0.549716, 0.013647},{
      0.335389, 0.550384, 0.013647},{0.337394, 0.551035, 0.013141}}],
    Polygon[{{0.335389, 0.550384, -0.013647},{0.337394, 0.551035, -0.013141},{
      0.336788, 0.552225, -0.013141},{0.335082, 0.550986, -0.013647}}],
    Polygon[{{0.337394, 0.551035, -0.013141},{0.339299, 0.551654, -0.012311},{
      0.338408, 0.553403, -0.012311},{0.336788, 0.552225, -0.013141}}],
    Polygon[{{0.339299, 0.551654, -0.012311},{0.341057, 0.552225, -0.011178},{
      0.339904, 0.554489, -0.011178},{0.338408, 0.553403, -0.012311}}],
    Polygon[{{0.341057, 0.552225, -0.011178},{0.342625, 0.552735, -0.009770},{
      0.341238, 0.555459, -0.009770},{0.339904, 0.554489, -0.011178}}],
    Polygon[{{0.342625, 0.552735, -0.009770},{0.343965, 0.553170, -0.008122},{
      0.342377, 0.556286, -0.008122},{0.341238, 0.555459, -0.009770}}],
    Polygon[{{0.343965, 0.553170, -0.008122},{0.345042, 0.553520, -0.006273},{
      0.343293, 0.556952, -0.006273},{0.342377, 0.556286, -0.008122}}],
    Polygon[{{0.345042, 0.553520, -0.006273},{0.345831, 0.553777, -0.004270},{
      0.343965, 0.557440, -0.004270},{0.343293, 0.556952, -0.006273}}],
    Polygon[{{0.345831, 0.553777, -0.004270},{0.346313, 0.553933, -0.002162},{
      0.344374, 0.557737, -0.002162},{0.343965, 0.557440, -0.004270}}],
    Polygon[{{0.346313, 0.553933, -0.002162},{0.346474, 0.553985, 0.000000},{
      0.344512, 0.557837, 0.000000},{0.344374, 0.557737, -0.002162}}],
    Polygon[{{0.346474, 0.553985, 0.000000},{0.346313, 0.553933, 0.002162},{
      0.344374, 0.557737, 0.002162},{0.344512, 0.557837, 0.000000}}],
    Polygon[{{0.346313, 0.553933, 0.002162},{0.345831, 0.553777, 0.004270},{
      0.343965, 0.557440, 0.004270},{0.344374, 0.557737, 0.002162}}],
    Polygon[{{0.345831, 0.553777, 0.004270},{0.345042, 0.553520, 0.006273},{
      0.343293, 0.556952, 0.006273},{0.343965, 0.557440, 0.004270}}],
    Polygon[{{0.345042, 0.553520, 0.006273},{0.343965, 0.553170, 0.008122},{
      0.342377, 0.556286, 0.008122},{0.343293, 0.556952, 0.006273}}],
    Polygon[{{0.343965, 0.553170, 0.008122},{0.342625, 0.552735, 0.009770},{
      0.341238, 0.555459, 0.009770},{0.342377, 0.556286, 0.008122}}],
    Polygon[{{0.342625, 0.552735, 0.009770},{0.341057, 0.552225, 0.011178},{
      0.339904, 0.554489, 0.011178},{0.341238, 0.555459, 0.009770}}],
    Polygon[{{0.341057, 0.552225, 0.011178},{0.339299, 0.551654, 0.012311},{
      0.338408, 0.553403, 0.012311},{0.339904, 0.554489, 0.011178}}],
    Polygon[{{0.339299, 0.551654, 0.012311},{0.337394, 0.551035, 0.013141},{
      0.336788, 0.552225, 0.013141},{0.338408, 0.553403, 0.012311}}],
    Polygon[{{0.337394, 0.551035, 0.013141},{0.335389, 0.550384, 0.013647},{
      0.335082, 0.550986, 0.013647},{0.336788, 0.552225, 0.013141}}],
    Polygon[{{0.335082, 0.550986, -0.013647},{0.336788, 0.552225, -0.013141},{
      0.335843, 0.553170, -0.013141},{0.334604, 0.551464, -0.013647}}],
    Polygon[{{0.336788, 0.552225, -0.013141},{0.338408, 0.553403, -0.012311},{
      0.337020, 0.554791, -0.012311},{0.335843, 0.553170, -0.013141}}],
    Polygon[{{0.338408, 0.553403, -0.012311},{0.339904, 0.554489, -0.011178},{
      0.338107, 0.556286, -0.011178},{0.337020, 0.554791, -0.012311}}],
    Polygon[{{0.339904, 0.554489, -0.011178},{0.341238, 0.555459, -0.009770},{
      0.339076, 0.557620, -0.009770},{0.338107, 0.556286, -0.011178}}],
    Polygon[{{0.341238, 0.555459, -0.009770},{0.342377, 0.556286, -0.008122},{
      0.339904, 0.558759, -0.008122},{0.339076, 0.557620, -0.009770}}],
    Polygon[{{0.342377, 0.556286, -0.008122},{0.343293, 0.556952, -0.006273},{
      0.340570, 0.559676, -0.006273},{0.339904, 0.558759, -0.008122}}],
    Polygon[{{0.343293, 0.556952, -0.006273},{0.343965, 0.557440, -0.004270},{
      0.341057, 0.560347, -0.004270},{0.340570, 0.559676, -0.006273}}],
    Polygon[{{0.343965, 0.557440, -0.004270},{0.344374, 0.557737, -0.002162},{
      0.341355, 0.560757, -0.002162},{0.341057, 0.560347, -0.004270}}],
    Polygon[{{0.344374, 0.557737, -0.002162},{0.344512, 0.557837, 0.000000},{
      0.341455, 0.560894, 0.000000},{0.341355, 0.560757, -0.002162}}],
    Polygon[{{0.344512, 0.557837, 0.000000},{0.344374, 0.557737, 0.002162},{
      0.341355, 0.560757, 0.002162},{0.341455, 0.560894, 0.000000}}],
    Polygon[{{0.344374, 0.557737, 0.002162},{0.343965, 0.557440, 0.004270},{
      0.341057, 0.560347, 0.004270},{0.341355, 0.560757, 0.002162}}],
    Polygon[{{0.343965, 0.557440, 0.004270},{0.343293, 0.556952, 0.006273},{
      0.340570, 0.559676, 0.006273},{0.341057, 0.560347, 0.004270}}],
    Polygon[{{0.343293, 0.556952, 0.006273},{0.342377, 0.556286, 0.008122},{
      0.339904, 0.558759, 0.008122},{0.340570, 0.559676, 0.006273}}],
    Polygon[{{0.342377, 0.556286, 0.008122},{0.341238, 0.555459, 0.009770},{
      0.339076, 0.557620, 0.009770},{0.339904, 0.558759, 0.008122}}],
    Polygon[{{0.341238, 0.555459, 0.009770},{0.339904, 0.554489, 0.011178},{
      0.338107, 0.556286, 0.011178},{0.339076, 0.557620, 0.009770}}],
    Polygon[{{0.339904, 0.554489, 0.011178},{0.338408, 0.553403, 0.012311},{
      0.337020, 0.554791, 0.012311},{0.338107, 0.556286, 0.011178}}],
    Polygon[{{0.338408, 0.553403, 0.012311},{0.336788, 0.552225, 0.013141},{
      0.335843, 0.553170, 0.013141},{0.337020, 0.554791, 0.012311}}],
    Polygon[{{0.336788, 0.552225, 0.013141},{0.335082, 0.550986, 0.013647},{
      0.334604, 0.551464, 0.013647},{0.335843, 0.553170, 0.013141}}],
    Polygon[{{0.334604, 0.551464, -0.013647},{0.335843, 0.553170, -0.013141},{
      0.334653, 0.553777, -0.013141},{0.334001, 0.551771, -0.013647}}],
    Polygon[{{0.335843, 0.553170, -0.013141},{0.337020, 0.554791, -0.012311},{
      0.335272, 0.555682, -0.012311},{0.334653, 0.553777, -0.013141}}],
    Polygon[{{0.337020, 0.554791, -0.012311},{0.338107, 0.556286, -0.011178},{
      0.335843, 0.557440, -0.011178},{0.335272, 0.555682, -0.012311}}],
    Polygon[{{0.338107, 0.556286, -0.011178},{0.339076, 0.557620, -0.009770},{
      0.336353, 0.559008, -0.009770},{0.335843, 0.557440, -0.011178}}],
    Polygon[{{0.339076, 0.557620, -0.009770},{0.339904, 0.558759, -0.008122},{
      0.336788, 0.560347, -0.008122},{0.336353, 0.559008, -0.009770}}],
    Polygon[{{0.339904, 0.558759, -0.008122},{0.340570, 0.559676, -0.006273},{
      0.337138, 0.561424, -0.006273},{0.336788, 0.560347, -0.008122}}],
    Polygon[{{0.340570, 0.559676, -0.006273},{0.341057, 0.560347, -0.004270},{
      0.337394, 0.562214, -0.004270},{0.337138, 0.561424, -0.006273}}],
    Polygon[{{0.341057, 0.560347, -0.004270},{0.341355, 0.560757, -0.002162},{
      0.337551, 0.562695, -0.002162},{0.337394, 0.562214, -0.004270}}],
    Polygon[{{0.341355, 0.560757, -0.002162},{0.341455, 0.560894, 0.000000},{
      0.337603, 0.562857, 0.000000},{0.337551, 0.562695, -0.002162}}],
    Polygon[{{0.341455, 0.560894, 0.000000},{0.341355, 0.560757, 0.002162},{
      0.337551, 0.562695, 0.002162},{0.337603, 0.562857, 0.000000}}],
    Polygon[{{0.341355, 0.560757, 0.002162},{0.341057, 0.560347, 0.004270},{
      0.337394, 0.562214, 0.004270},{0.337551, 0.562695, 0.002162}}],
    Polygon[{{0.341057, 0.560347, 0.004270},{0.340570, 0.559676, 0.006273},{
      0.337138, 0.561424, 0.006273},{0.337394, 0.562214, 0.004270}}],
    Polygon[{{0.340570, 0.559676, 0.006273},{0.339904, 0.558759, 0.008122},{
      0.336788, 0.560347, 0.008122},{0.337138, 0.561424, 0.006273}}],
    Polygon[{{0.339904, 0.558759, 0.008122},{0.339076, 0.557620, 0.009770},{
      0.336353, 0.559008, 0.009770},{0.336788, 0.560347, 0.008122}}],
    Polygon[{{0.339076, 0.557620, 0.009770},{0.338107, 0.556286, 0.011178},{
      0.335843, 0.557440, 0.011178},{0.336353, 0.559008, 0.009770}}],
    Polygon[{{0.338107, 0.556286, 0.011178},{0.337020, 0.554791, 0.012311},{
      0.335272, 0.555682, 0.012311},{0.335843, 0.557440, 0.011178}}],
    Polygon[{{0.337020, 0.554791, 0.012311},{0.335843, 0.553170, 0.013141},{
      0.334653, 0.553777, 0.013141},{0.335272, 0.555682, 0.012311}}],
    Polygon[{{0.335843, 0.553170, 0.013141},{0.334604, 0.551464, 0.013647},{
      0.334001, 0.551771, 0.013647},{0.334653, 0.553777, 0.013141}}],
    Polygon[{{0.334001, 0.551771, -0.013647},{0.334653, 0.553777, -0.013141},{
      0.333333, 0.553985, -0.013141},{0.333333, 0.551877, -0.013647}}],
    Polygon[{{0.334653, 0.553777, -0.013141},{0.335272, 0.555682, -0.012311},{
      0.333333, 0.555989, -0.012311},{0.333333, 0.553985, -0.013141}}],
    Polygon[{{0.335272, 0.555682, -0.012311},{0.335843, 0.557440, -0.011178},{
      0.333333, 0.557837, -0.011178},{0.333333, 0.555989, -0.012311}}],
    Polygon[{{0.335843, 0.557440, -0.011178},{0.336353, 0.559008, -0.009770},{
      0.333333, 0.559486, -0.009770},{0.333333, 0.557837, -0.011178}}],
    Polygon[{{0.336353, 0.559008, -0.009770},{0.336788, 0.560347, -0.008122},{
      0.333333, 0.560894, -0.008122},{0.333333, 0.559486, -0.009770}}],
    Polygon[{{0.336788, 0.560347, -0.008122},{0.337138, 0.561424, -0.006273},{
      0.333333, 0.562027, -0.006273},{0.333333, 0.560894, -0.008122}}],
    Polygon[{{0.337138, 0.561424, -0.006273},{0.337394, 0.562214, -0.004270},{
      0.333333, 0.562857, -0.004270},{0.333333, 0.562027, -0.006273}}],
    Polygon[{{0.337394, 0.562214, -0.004270},{0.337551, 0.562695, -0.002162},{
      0.333333, 0.563363, -0.002162},{0.333333, 0.562857, -0.004270}}],
    Polygon[{{0.337551, 0.562695, -0.002162},{0.337603, 0.562857, 0.000000},{
      0.333333, 0.563533, 0.000000},{0.333333, 0.563363, -0.002162}}],
    Polygon[{{0.337603, 0.562857, 0.000000},{0.337551, 0.562695, 0.002162},{
      0.333333, 0.563363, 0.002162},{0.333333, 0.563533, 0.000000}}],
    Polygon[{{0.337551, 0.562695, 0.002162},{0.337394, 0.562214, 0.004270},{
      0.333333, 0.562857, 0.004270},{0.333333, 0.563363, 0.002162}}],
    Polygon[{{0.337394, 0.562214, 0.004270},{0.337138, 0.561424, 0.006273},{
      0.333333, 0.562027, 0.006273},{0.333333, 0.562857, 0.004270}}],
    Polygon[{{0.337138, 0.561424, 0.006273},{0.336788, 0.560347, 0.008122},{
      0.333333, 0.560894, 0.008122},{0.333333, 0.562027, 0.006273}}],
    Polygon[{{0.336788, 0.560347, 0.008122},{0.336353, 0.559008, 0.009770},{
      0.333333, 0.559486, 0.009770},{0.333333, 0.560894, 0.008122}}],
    Polygon[{{0.336353, 0.559008, 0.009770},{0.335843, 0.557440, 0.011178},{
      0.333333, 0.557837, 0.011178},{0.333333, 0.559486, 0.009770}}],
    Polygon[{{0.335843, 0.557440, 0.011178},{0.335272, 0.555682, 0.012311},{
      0.333333, 0.555989, 0.012311},{0.333333, 0.557837, 0.011178}}],
    Polygon[{{0.335272, 0.555682, 0.012311},{0.334653, 0.553777, 0.013141},{
      0.333333, 0.553985, 0.013141},{0.333333, 0.555989, 0.012311}}],
    Polygon[{{0.334653, 0.553777, 0.013141},{0.334001, 0.551771, 0.013647},{
      0.333333, 0.551877, 0.013647},{0.333333, 0.553985, 0.013141}}],
    Polygon[{{0.333333, 0.551877, -0.013647},{0.333333, 0.553985, -0.013141},{
      0.332014, 0.553777, -0.013141},{0.332665, 0.551771, -0.013647}}],
    Polygon[{{0.333333, 0.553985, -0.013141},{0.333333, 0.555989, -0.012311},{
      0.331395, 0.555682, -0.012311},{0.332014, 0.553777, -0.013141}}],
    Polygon[{{0.333333, 0.555989, -0.012311},{0.333333, 0.557837, -0.011178},{
      0.330824, 0.557440, -0.011178},{0.331395, 0.555682, -0.012311}}],
    Polygon[{{0.333333, 0.557837, -0.011178},{0.333333, 0.559486, -0.009770},{
      0.330314, 0.559008, -0.009770},{0.330824, 0.557440, -0.011178}}],
    Polygon[{{0.333333, 0.559486, -0.009770},{0.333333, 0.560894, -0.008122},{
      0.329879, 0.560347, -0.008122},{0.330314, 0.559008, -0.009770}}],
    Polygon[{{0.333333, 0.560894, -0.008122},{0.333333, 0.562027, -0.006273},{
      0.329529, 0.561424, -0.006273},{0.329879, 0.560347, -0.008122}}],
    Polygon[{{0.333333, 0.562027, -0.006273},{0.333333, 0.562857, -0.004270},{
      0.329273, 0.562214, -0.004270},{0.329529, 0.561424, -0.006273}}],
    Polygon[{{0.333333, 0.562857, -0.004270},{0.333333, 0.563363, -0.002162},{
      0.329116, 0.562695, -0.002162},{0.329273, 0.562214, -0.004270}}],
    Polygon[{{0.333333, 0.563363, -0.002162},{0.333333, 0.563533, 0.000000},{
      0.329064, 0.562857, 0.000000},{0.329116, 0.562695, -0.002162}}],
    Polygon[{{0.333333, 0.563533, 0.000000},{0.333333, 0.563363, 0.002162},{
      0.329116, 0.562695, 0.002162},{0.329064, 0.562857, 0.000000}}],
    Polygon[{{0.333333, 0.563363, 0.002162},{0.333333, 0.562857, 0.004270},{
      0.329273, 0.562214, 0.004270},{0.329116, 0.562695, 0.002162}}],
    Polygon[{{0.333333, 0.562857, 0.004270},{0.333333, 0.562027, 0.006273},{
      0.329529, 0.561424, 0.006273},{0.329273, 0.562214, 0.004270}}],
    Polygon[{{0.333333, 0.562027, 0.006273},{0.333333, 0.560894, 0.008122},{
      0.329879, 0.560347, 0.008122},{0.329529, 0.561424, 0.006273}}],
    Polygon[{{0.333333, 0.560894, 0.008122},{0.333333, 0.559486, 0.009770},{
      0.330314, 0.559008, 0.009770},{0.329879, 0.560347, 0.008122}}],
    Polygon[{{0.333333, 0.559486, 0.009770},{0.333333, 0.557837, 0.011178},{
      0.330824, 0.557440, 0.011178},{0.330314, 0.559008, 0.009770}}],
    Polygon[{{0.333333, 0.557837, 0.011178},{0.333333, 0.555989, 0.012311},{
      0.331395, 0.555682, 0.012311},{0.330824, 0.557440, 0.011178}}],
    Polygon[{{0.333333, 0.555989, 0.012311},{0.333333, 0.553985, 0.013141},{
      0.332014, 0.553777, 0.013141},{0.331395, 0.555682, 0.012311}}],
    Polygon[{{0.333333, 0.553985, 0.013141},{0.333333, 0.551877, 0.013647},{
      0.332665, 0.551771, 0.013647},{0.332014, 0.553777, 0.013141}}],
    Polygon[{{0.332665, 0.551771, -0.013647},{0.332014, 0.553777, -0.013141},{
      0.330824, 0.553170, -0.013141},{0.332063, 0.551464, -0.013647}}],
    Polygon[{{0.332014, 0.553777, -0.013141},{0.331395, 0.555682, -0.012311},{
      0.329646, 0.554791, -0.012311},{0.330824, 0.553170, -0.013141}}],
    Polygon[{{0.331395, 0.555682, -0.012311},{0.330824, 0.557440, -0.011178},{
      0.328560, 0.556286, -0.011178},{0.329646, 0.554791, -0.012311}}],
    Polygon[{{0.330824, 0.557440, -0.011178},{0.330314, 0.559008, -0.009770},{
      0.327590, 0.557620, -0.009770},{0.328560, 0.556286, -0.011178}}],
    Polygon[{{0.330314, 0.559008, -0.009770},{0.329879, 0.560347, -0.008122},{
      0.326763, 0.558759, -0.008122},{0.327590, 0.557620, -0.009770}}],
    Polygon[{{0.329879, 0.560347, -0.008122},{0.329529, 0.561424, -0.006273},{
      0.326097, 0.559676, -0.006273},{0.326763, 0.558759, -0.008122}}],
    Polygon[{{0.329529, 0.561424, -0.006273},{0.329273, 0.562214, -0.004270},{
      0.325609, 0.560347, -0.004270},{0.326097, 0.559676, -0.006273}}],
    Polygon[{{0.329273, 0.562214, -0.004270},{0.329116, 0.562695, -0.002162},{
      0.325312, 0.560757, -0.002162},{0.325609, 0.560347, -0.004270}}],
    Polygon[{{0.329116, 0.562695, -0.002162},{0.329064, 0.562857, 0.000000},{
      0.325212, 0.560894, 0.000000},{0.325312, 0.560757, -0.002162}}],
    Polygon[{{0.329064, 0.562857, 0.000000},{0.329116, 0.562695, 0.002162},{
      0.325312, 0.560757, 0.002162},{0.325212, 0.560894, 0.000000}}],
    Polygon[{{0.329116, 0.562695, 0.002162},{0.329273, 0.562214, 0.004270},{
      0.325609, 0.560347, 0.004270},{0.325312, 0.560757, 0.002162}}],
    Polygon[{{0.329273, 0.562214, 0.004270},{0.329529, 0.561424, 0.006273},{
      0.326097, 0.559676, 0.006273},{0.325609, 0.560347, 0.004270}}],
    Polygon[{{0.329529, 0.561424, 0.006273},{0.329879, 0.560347, 0.008122},{
      0.326763, 0.558759, 0.008122},{0.326097, 0.559676, 0.006273}}],
    Polygon[{{0.329879, 0.560347, 0.008122},{0.330314, 0.559008, 0.009770},{
      0.327590, 0.557620, 0.009770},{0.326763, 0.558759, 0.008122}}],
    Polygon[{{0.330314, 0.559008, 0.009770},{0.330824, 0.557440, 0.011178},{
      0.328560, 0.556286, 0.011178},{0.327590, 0.557620, 0.009770}}],
    Polygon[{{0.330824, 0.557440, 0.011178},{0.331395, 0.555682, 0.012311},{
      0.329646, 0.554791, 0.012311},{0.328560, 0.556286, 0.011178}}],
    Polygon[{{0.331395, 0.555682, 0.012311},{0.332014, 0.553777, 0.013141},{
      0.330824, 0.553170, 0.013141},{0.329646, 0.554791, 0.012311}}],
    Polygon[{{0.332014, 0.553777, 0.013141},{0.332665, 0.551771, 0.013647},{
      0.332063, 0.551464, 0.013647},{0.330824, 0.553170, 0.013141}}],
    Polygon[{{0.332063, 0.551464, -0.013647},{0.330824, 0.553170, -0.013141},{
      0.329879, 0.552225, -0.013141},{0.331585, 0.550986, -0.013647}}],
    Polygon[{{0.330824, 0.553170, -0.013141},{0.329646, 0.554791, -0.012311},{
      0.328258, 0.553403, -0.012311},{0.329879, 0.552225, -0.013141}}],
    Polygon[{{0.329646, 0.554791, -0.012311},{0.328560, 0.556286, -0.011178},{
      0.326763, 0.554489, -0.011178},{0.328258, 0.553403, -0.012311}}],
    Polygon[{{0.328560, 0.556286, -0.011178},{0.327590, 0.557620, -0.009770},{
      0.325429, 0.555459, -0.009770},{0.326763, 0.554489, -0.011178}}],
    Polygon[{{0.327590, 0.557620, -0.009770},{0.326763, 0.558759, -0.008122},{
      0.324290, 0.556286, -0.008122},{0.325429, 0.555459, -0.009770}}],
    Polygon[{{0.326763, 0.558759, -0.008122},{0.326097, 0.559676, -0.006273},{
      0.323373, 0.556952, -0.006273},{0.324290, 0.556286, -0.008122}}],
    Polygon[{{0.326097, 0.559676, -0.006273},{0.325609, 0.560347, -0.004270},{
      0.322702, 0.557440, -0.004270},{0.323373, 0.556952, -0.006273}}],
    Polygon[{{0.325609, 0.560347, -0.004270},{0.325312, 0.560757, -0.002162},{
      0.322293, 0.557737, -0.002162},{0.322702, 0.557440, -0.004270}}],
    Polygon[{{0.325312, 0.560757, -0.002162},{0.325212, 0.560894, 0.000000},{
      0.322155, 0.557837, 0.000000},{0.322293, 0.557737, -0.002162}}],
    Polygon[{{0.325212, 0.560894, 0.000000},{0.325312, 0.560757, 0.002162},{
      0.322293, 0.557737, 0.002162},{0.322155, 0.557837, 0.000000}}],
    Polygon[{{0.325312, 0.560757, 0.002162},{0.325609, 0.560347, 0.004270},{
      0.322702, 0.557440, 0.004270},{0.322293, 0.557737, 0.002162}}],
    Polygon[{{0.325609, 0.560347, 0.004270},{0.326097, 0.559676, 0.006273},{
      0.323373, 0.556952, 0.006273},{0.322702, 0.557440, 0.004270}}],
    Polygon[{{0.326097, 0.559676, 0.006273},{0.326763, 0.558759, 0.008122},{
      0.324290, 0.556286, 0.008122},{0.323373, 0.556952, 0.006273}}],
    Polygon[{{0.326763, 0.558759, 0.008122},{0.327590, 0.557620, 0.009770},{
      0.325429, 0.555459, 0.009770},{0.324290, 0.556286, 0.008122}}],
    Polygon[{{0.327590, 0.557620, 0.009770},{0.328560, 0.556286, 0.011178},{
      0.326763, 0.554489, 0.011178},{0.325429, 0.555459, 0.009770}}],
    Polygon[{{0.328560, 0.556286, 0.011178},{0.329646, 0.554791, 0.012311},{
      0.328258, 0.553403, 0.012311},{0.326763, 0.554489, 0.011178}}],
    Polygon[{{0.329646, 0.554791, 0.012311},{0.330824, 0.553170, 0.013141},{
      0.329879, 0.552225, 0.013141},{0.328258, 0.553403, 0.012311}}],
    Polygon[{{0.330824, 0.553170, 0.013141},{0.332063, 0.551464, 0.013647},{
      0.331585, 0.550986, 0.013647},{0.329879, 0.552225, 0.013141}}],
    Polygon[{{0.331585, 0.550986, -0.013647},{0.329879, 0.552225, -0.013141},{
      0.329273, 0.551035, -0.013141},{0.331278, 0.550384, -0.013647}}],
    Polygon[{{0.329879, 0.552225, -0.013141},{0.328258, 0.553403, -0.012311},{
      0.327367, 0.551654, -0.012311},{0.329273, 0.551035, -0.013141}}],
    Polygon[{{0.328258, 0.553403, -0.012311},{0.326763, 0.554489, -0.011178},{
      0.325609, 0.552225, -0.011178},{0.327367, 0.551654, -0.012311}}],
    Polygon[{{0.326763, 0.554489, -0.011178},{0.325429, 0.555459, -0.009770},{
      0.324041, 0.552735, -0.009770},{0.325609, 0.552225, -0.011178}}],
    Polygon[{{0.325429, 0.555459, -0.009770},{0.324290, 0.556286, -0.008122},{
      0.322702, 0.553170, -0.008122},{0.324041, 0.552735, -0.009770}}],
    Polygon[{{0.324290, 0.556286, -0.008122},{0.323373, 0.556952, -0.006273},{
      0.321625, 0.553520, -0.006273},{0.322702, 0.553170, -0.008122}}],
    Polygon[{{0.323373, 0.556952, -0.006273},{0.322702, 0.557440, -0.004270},{
      0.320835, 0.553777, -0.004270},{0.321625, 0.553520, -0.006273}}],
    Polygon[{{0.322702, 0.557440, -0.004270},{0.322293, 0.557737, -0.002162},{
      0.320354, 0.553933, -0.002162},{0.320835, 0.553777, -0.004270}}],
    Polygon[{{0.322293, 0.557737, -0.002162},{0.322155, 0.557837, 0.000000},{
      0.320192, 0.553985, 0.000000},{0.320354, 0.553933, -0.002162}}],
    Polygon[{{0.322155, 0.557837, 0.000000},{0.322293, 0.557737, 0.002162},{
      0.320354, 0.553933, 0.002162},{0.320192, 0.553985, 0.000000}}],
    Polygon[{{0.322293, 0.557737, 0.002162},{0.322702, 0.557440, 0.004270},{
      0.320835, 0.553777, 0.004270},{0.320354, 0.553933, 0.002162}}],
    Polygon[{{0.322702, 0.557440, 0.004270},{0.323373, 0.556952, 0.006273},{
      0.321625, 0.553520, 0.006273},{0.320835, 0.553777, 0.004270}}],
    Polygon[{{0.323373, 0.556952, 0.006273},{0.324290, 0.556286, 0.008122},{
      0.322702, 0.553170, 0.008122},{0.321625, 0.553520, 0.006273}}],
    Polygon[{{0.324290, 0.556286, 0.008122},{0.325429, 0.555459, 0.009770},{
      0.324041, 0.552735, 0.009770},{0.322702, 0.553170, 0.008122}}],
    Polygon[{{0.325429, 0.555459, 0.009770},{0.326763, 0.554489, 0.011178},{
      0.325609, 0.552225, 0.011178},{0.324041, 0.552735, 0.009770}}],
    Polygon[{{0.326763, 0.554489, 0.011178},{0.328258, 0.553403, 0.012311},{
      0.327367, 0.551654, 0.012311},{0.325609, 0.552225, 0.011178}}],
    Polygon[{{0.328258, 0.553403, 0.012311},{0.329879, 0.552225, 0.013141},{
      0.329273, 0.551035, 0.013141},{0.327367, 0.551654, 0.012311}}],
    Polygon[{{0.329879, 0.552225, 0.013141},{0.331585, 0.550986, 0.013647},{
      0.331278, 0.550384, 0.013647},{0.329273, 0.551035, 0.013141}}],
    Polygon[{{0.331278, 0.550384, -0.013647},{0.329273, 0.551035, -0.013141},{
      0.329064, 0.549716, -0.013141},{0.331172, 0.549716, -0.013647}}],
    Polygon[{{0.329273, 0.551035, -0.013141},{0.327367, 0.551654, -0.012311},{
      0.327060, 0.549716, -0.012311},{0.329064, 0.549716, -0.013141}}],
    Polygon[{{0.327367, 0.551654, -0.012311},{0.325609, 0.552225, -0.011178},{
      0.325212, 0.549716, -0.011178},{0.327060, 0.549716, -0.012311}}],
    Polygon[{{0.325609, 0.552225, -0.011178},{0.324041, 0.552735, -0.009770},{
      0.323563, 0.549716, -0.009770},{0.325212, 0.549716, -0.011178}}],
    Polygon[{{0.324041, 0.552735, -0.009770},{0.322702, 0.553170, -0.008122},{
      0.322155, 0.549716, -0.008122},{0.323563, 0.549716, -0.009770}}],
    Polygon[{{0.322702, 0.553170, -0.008122},{0.321625, 0.553520, -0.006273},{
      0.321022, 0.549716, -0.006273},{0.322155, 0.549716, -0.008122}}],
    Polygon[{{0.321625, 0.553520, -0.006273},{0.320835, 0.553777, -0.004270},{
      0.320192, 0.549716, -0.004270},{0.321022, 0.549716, -0.006273}}],
    Polygon[{{0.320835, 0.553777, -0.004270},{0.320354, 0.553933, -0.002162},{
      0.319686, 0.549716, -0.002162},{0.320192, 0.549716, -0.004270}}],
    Polygon[{{0.320354, 0.553933, -0.002162},{0.320192, 0.553985, 0.000000},{
      0.319516, 0.549716, 0.000000},{0.319686, 0.549716, -0.002162}}],
    Polygon[{{0.320192, 0.553985, 0.000000},{0.320354, 0.553933, 0.002162},{
      0.319686, 0.549716, 0.002162},{0.319516, 0.549716, 0.000000}}],
    Polygon[{{0.320354, 0.553933, 0.002162},{0.320835, 0.553777, 0.004270},{
      0.320192, 0.549716, 0.004270},{0.319686, 0.549716, 0.002162}}],
    Polygon[{{0.320835, 0.553777, 0.004270},{0.321625, 0.553520, 0.006273},{
      0.321022, 0.549716, 0.006273},{0.320192, 0.549716, 0.004270}}],
    Polygon[{{0.321625, 0.553520, 0.006273},{0.322702, 0.553170, 0.008122},{
      0.322155, 0.549716, 0.008122},{0.321022, 0.549716, 0.006273}}],
    Polygon[{{0.322702, 0.553170, 0.008122},{0.324041, 0.552735, 0.009770},{
      0.323563, 0.549716, 0.009770},{0.322155, 0.549716, 0.008122}}],
    Polygon[{{0.324041, 0.552735, 0.009770},{0.325609, 0.552225, 0.011178},{
      0.325212, 0.549716, 0.011178},{0.323563, 0.549716, 0.009770}}],
    Polygon[{{0.325609, 0.552225, 0.011178},{0.327367, 0.551654, 0.012311},{
      0.327060, 0.549716, 0.012311},{0.325212, 0.549716, 0.011178}}],
    Polygon[{{0.327367, 0.551654, 0.012311},{0.329273, 0.551035, 0.013141},{
      0.329064, 0.549716, 0.013141},{0.327060, 0.549716, 0.012311}}],
    Polygon[{{0.329273, 0.551035, 0.013141},{0.331278, 0.550384, 0.013647},{
      0.331172, 0.549716, 0.013647},{0.329064, 0.549716, 0.013141}}],
    Polygon[{{0.331172, 0.549716, -0.013647},{0.329064, 0.549716, -0.013141},{
      0.329273, 0.548396, -0.013141},{0.331278, 0.549048, -0.013647}}],
    Polygon[{{0.329064, 0.549716, -0.013141},{0.327060, 0.549716, -0.012311},{
      0.327367, 0.547777, -0.012311},{0.329273, 0.548396, -0.013141}}],
    Polygon[{{0.327060, 0.549716, -0.012311},{0.325212, 0.549716, -0.011178},{
      0.325609, 0.547206, -0.011178},{0.327367, 0.547777, -0.012311}}],
    Polygon[{{0.325212, 0.549716, -0.011178},{0.323563, 0.549716, -0.009770},{
      0.324041, 0.546696, -0.009770},{0.325609, 0.547206, -0.011178}}],
    Polygon[{{0.323563, 0.549716, -0.009770},{0.322155, 0.549716, -0.008122},{
      0.322702, 0.546261, -0.008122},{0.324041, 0.546696, -0.009770}}],
    Polygon[{{0.322155, 0.549716, -0.008122},{0.321022, 0.549716, -0.006273},{
      0.321625, 0.545911, -0.006273},{0.322702, 0.546261, -0.008122}}],
    Polygon[{{0.321022, 0.549716, -0.006273},{0.320192, 0.549716, -0.004270},{
      0.320835, 0.545655, -0.004270},{0.321625, 0.545911, -0.006273}}],
    Polygon[{{0.320192, 0.549716, -0.004270},{0.319686, 0.549716, -0.002162},{
      0.320354, 0.545498, -0.002162},{0.320835, 0.545655, -0.004270}}],
    Polygon[{{0.319686, 0.549716, -0.002162},{0.319516, 0.549716, 0.000000},{
      0.320192, 0.545446, 0.000000},{0.320354, 0.545498, -0.002162}}],
    Polygon[{{0.319516, 0.549716, 0.000000},{0.319686, 0.549716, 0.002162},{
      0.320354, 0.545498, 0.002162},{0.320192, 0.545446, 0.000000}}],
    Polygon[{{0.319686, 0.549716, 0.002162},{0.320192, 0.549716, 0.004270},{
      0.320835, 0.545655, 0.004270},{0.320354, 0.545498, 0.002162}}],
    Polygon[{{0.320192, 0.549716, 0.004270},{0.321022, 0.549716, 0.006273},{
      0.321625, 0.545911, 0.006273},{0.320835, 0.545655, 0.004270}}],
    Polygon[{{0.321022, 0.549716, 0.006273},{0.322155, 0.549716, 0.008122},{
      0.322702, 0.546261, 0.008122},{0.321625, 0.545911, 0.006273}}],
    Polygon[{{0.322155, 0.549716, 0.008122},{0.323563, 0.549716, 0.009770},{
      0.324041, 0.546696, 0.009770},{0.322702, 0.546261, 0.008122}}],
    Polygon[{{0.323563, 0.549716, 0.009770},{0.325212, 0.549716, 0.011178},{
      0.325609, 0.547206, 0.011178},{0.324041, 0.546696, 0.009770}}],
    Polygon[{{0.325212, 0.549716, 0.011178},{0.327060, 0.549716, 0.012311},{
      0.327367, 0.547777, 0.012311},{0.325609, 0.547206, 0.011178}}],
    Polygon[{{0.327060, 0.549716, 0.012311},{0.329064, 0.549716, 0.013141},{
      0.329273, 0.548396, 0.013141},{0.327367, 0.547777, 0.012311}}],
    Polygon[{{0.329064, 0.549716, 0.013141},{0.331172, 0.549716, 0.013647},{
      0.331278, 0.549048, 0.013647},{0.329273, 0.548396, 0.013141}}],
    Polygon[{{0.331278, 0.549048, -0.013647},{0.329273, 0.548396, -0.013141},{
      0.329879, 0.547206, -0.013141},{0.331585, 0.548445, -0.013647}}],
    Polygon[{{0.329273, 0.548396, -0.013141},{0.327367, 0.547777, -0.012311},{
      0.328258, 0.546029, -0.012311},{0.329879, 0.547206, -0.013141}}],
    Polygon[{{0.327367, 0.547777, -0.012311},{0.325609, 0.547206, -0.011178},{
      0.326763, 0.544942, -0.011178},{0.328258, 0.546029, -0.012311}}],
    Polygon[{{0.325609, 0.547206, -0.011178},{0.324041, 0.546696, -0.009770},{
      0.325429, 0.543973, -0.009770},{0.326763, 0.544942, -0.011178}}],
    Polygon[{{0.324041, 0.546696, -0.009770},{0.322702, 0.546261, -0.008122},{
      0.324290, 0.543145, -0.008122},{0.325429, 0.543973, -0.009770}}],
    Polygon[{{0.322702, 0.546261, -0.008122},{0.321625, 0.545911, -0.006273},{
      0.323373, 0.542479, -0.006273},{0.324290, 0.543145, -0.008122}}],
    Polygon[{{0.321625, 0.545911, -0.006273},{0.320835, 0.545655, -0.004270},{
      0.322702, 0.541992, -0.004270},{0.323373, 0.542479, -0.006273}}],
    Polygon[{{0.320835, 0.545655, -0.004270},{0.320354, 0.545498, -0.002162},{
      0.322293, 0.541694, -0.002162},{0.322702, 0.541992, -0.004270}}],
    Polygon[{{0.320354, 0.545498, -0.002162},{0.320192, 0.545446, 0.000000},{
      0.322155, 0.541594, 0.000000},{0.322293, 0.541694, -0.002162}}],
    Polygon[{{0.320192, 0.545446, 0.000000},{0.320354, 0.545498, 0.002162},{
      0.322293, 0.541694, 0.002162},{0.322155, 0.541594, 0.000000}}],
    Polygon[{{0.320354, 0.545498, 0.002162},{0.320835, 0.545655, 0.004270},{
      0.322702, 0.541992, 0.004270},{0.322293, 0.541694, 0.002162}}],
    Polygon[{{0.320835, 0.545655, 0.004270},{0.321625, 0.545911, 0.006273},{
      0.323373, 0.542479, 0.006273},{0.322702, 0.541992, 0.004270}}],
    Polygon[{{0.321625, 0.545911, 0.006273},{0.322702, 0.546261, 0.008122},{
      0.324290, 0.543145, 0.008122},{0.323373, 0.542479, 0.006273}}],
    Polygon[{{0.322702, 0.546261, 0.008122},{0.324041, 0.546696, 0.009770},{
      0.325429, 0.543973, 0.009770},{0.324290, 0.543145, 0.008122}}],
    Polygon[{{0.324041, 0.546696, 0.009770},{0.325609, 0.547206, 0.011178},{
      0.326763, 0.544942, 0.011178},{0.325429, 0.543973, 0.009770}}],
    Polygon[{{0.325609, 0.547206, 0.011178},{0.327367, 0.547777, 0.012311},{
      0.328258, 0.546029, 0.012311},{0.326763, 0.544942, 0.011178}}],
    Polygon[{{0.327367, 0.547777, 0.012311},{0.329273, 0.548396, 0.013141},{
      0.329879, 0.547206, 0.013141},{0.328258, 0.546029, 0.012311}}],
    Polygon[{{0.329273, 0.548396, 0.013141},{0.331278, 0.549048, 0.013647},{
      0.331585, 0.548445, 0.013647},{0.329879, 0.547206, 0.013141}}],
    Polygon[{{0.331585, 0.548445, -0.013647},{0.329879, 0.547206, -0.013141},{
      0.330824, 0.546261, -0.013141},{0.332063, 0.547967, -0.013647}}],
    Polygon[{{0.329879, 0.547206, -0.013141},{0.328258, 0.546029, -0.012311},{
      0.329646, 0.544641, -0.012311},{0.330824, 0.546261, -0.013141}}],
    Polygon[{{0.328258, 0.546029, -0.012311},{0.326763, 0.544942, -0.011178},{
      0.328560, 0.543145, -0.011178},{0.329646, 0.544641, -0.012311}}],
    Polygon[{{0.326763, 0.544942, -0.011178},{0.325429, 0.543973, -0.009770},{
      0.327590, 0.541811, -0.009770},{0.328560, 0.543145, -0.011178}}],
    Polygon[{{0.325429, 0.543973, -0.009770},{0.324290, 0.543145, -0.008122},{
      0.326763, 0.540672, -0.008122},{0.327590, 0.541811, -0.009770}}],
    Polygon[{{0.324290, 0.543145, -0.008122},{0.323373, 0.542479, -0.006273},{
      0.326097, 0.539756, -0.006273},{0.326763, 0.540672, -0.008122}}],
    Polygon[{{0.323373, 0.542479, -0.006273},{0.322702, 0.541992, -0.004270},{
      0.325609, 0.539084, -0.004270},{0.326097, 0.539756, -0.006273}}],
    Polygon[{{0.322702, 0.541992, -0.004270},{0.322293, 0.541694, -0.002162},{
      0.325312, 0.538675, -0.002162},{0.325609, 0.539084, -0.004270}}],
    Polygon[{{0.322293, 0.541694, -0.002162},{0.322155, 0.541594, 0.000000},{
      0.325212, 0.538537, 0.000000},{0.325312, 0.538675, -0.002162}}],
    Polygon[{{0.322155, 0.541594, 0.000000},{0.322293, 0.541694, 0.002162},{
      0.325312, 0.538675, 0.002162},{0.325212, 0.538537, 0.000000}}],
    Polygon[{{0.322293, 0.541694, 0.002162},{0.322702, 0.541992, 0.004270},{
      0.325609, 0.539084, 0.004270},{0.325312, 0.538675, 0.002162}}],
    Polygon[{{0.322702, 0.541992, 0.004270},{0.323373, 0.542479, 0.006273},{
      0.326097, 0.539756, 0.006273},{0.325609, 0.539084, 0.004270}}],
    Polygon[{{0.323373, 0.542479, 0.006273},{0.324290, 0.543145, 0.008122},{
      0.326763, 0.540672, 0.008122},{0.326097, 0.539756, 0.006273}}],
    Polygon[{{0.324290, 0.543145, 0.008122},{0.325429, 0.543973, 0.009770},{
      0.327590, 0.541811, 0.009770},{0.326763, 0.540672, 0.008122}}],
    Polygon[{{0.325429, 0.543973, 0.009770},{0.326763, 0.544942, 0.011178},{
      0.328560, 0.543145, 0.011178},{0.327590, 0.541811, 0.009770}}],
    Polygon[{{0.326763, 0.544942, 0.011178},{0.328258, 0.546029, 0.012311},{
      0.329646, 0.544641, 0.012311},{0.328560, 0.543145, 0.011178}}],
    Polygon[{{0.328258, 0.546029, 0.012311},{0.329879, 0.547206, 0.013141},{
      0.330824, 0.546261, 0.013141},{0.329646, 0.544641, 0.012311}}],
    Polygon[{{0.329879, 0.547206, 0.013141},{0.331585, 0.548445, 0.013647},{
      0.332063, 0.547967, 0.013647},{0.330824, 0.546261, 0.013141}}],
    Polygon[{{0.332063, 0.547967, -0.013647},{0.330824, 0.546261, -0.013141},{
      0.332014, 0.545655, -0.013141},{0.332665, 0.547660, -0.013647}}],
    Polygon[{{0.330824, 0.546261, -0.013141},{0.329646, 0.544641, -0.012311},{
      0.331395, 0.543750, -0.012311},{0.332014, 0.545655, -0.013141}}],
    Polygon[{{0.329646, 0.544641, -0.012311},{0.328560, 0.543145, -0.011178},{
      0.330824, 0.541992, -0.011178},{0.331395, 0.543750, -0.012311}}],
    Polygon[{{0.328560, 0.543145, -0.011178},{0.327590, 0.541811, -0.009770},{
      0.330314, 0.540424, -0.009770},{0.330824, 0.541992, -0.011178}}],
    Polygon[{{0.327590, 0.541811, -0.009770},{0.326763, 0.540672, -0.008122},{
      0.329879, 0.539084, -0.008122},{0.330314, 0.540424, -0.009770}}],
    Polygon[{{0.326763, 0.540672, -0.008122},{0.326097, 0.539756, -0.006273},{
      0.329529, 0.538007, -0.006273},{0.329879, 0.539084, -0.008122}}],
    Polygon[{{0.326097, 0.539756, -0.006273},{0.325609, 0.539084, -0.004270},{
      0.329273, 0.537218, -0.004270},{0.329529, 0.538007, -0.006273}}],
    Polygon[{{0.325609, 0.539084, -0.004270},{0.325312, 0.538675, -0.002162},{
      0.329116, 0.536736, -0.002162},{0.329273, 0.537218, -0.004270}}],
    Polygon[{{0.325312, 0.538675, -0.002162},{0.325212, 0.538537, 0.000000},{
      0.329064, 0.536575, 0.000000},{0.329116, 0.536736, -0.002162}}],
    Polygon[{{0.325212, 0.538537, 0.000000},{0.325312, 0.538675, 0.002162},{
      0.329116, 0.536736, 0.002162},{0.329064, 0.536575, 0.000000}}],
    Polygon[{{0.325312, 0.538675, 0.002162},{0.325609, 0.539084, 0.004270},{
      0.329273, 0.537218, 0.004270},{0.329116, 0.536736, 0.002162}}],
    Polygon[{{0.325609, 0.539084, 0.004270},{0.326097, 0.539756, 0.006273},{
      0.329529, 0.538007, 0.006273},{0.329273, 0.537218, 0.004270}}],
    Polygon[{{0.326097, 0.539756, 0.006273},{0.326763, 0.540672, 0.008122},{
      0.329879, 0.539084, 0.008122},{0.329529, 0.538007, 0.006273}}],
    Polygon[{{0.326763, 0.540672, 0.008122},{0.327590, 0.541811, 0.009770},{
      0.330314, 0.540424, 0.009770},{0.329879, 0.539084, 0.008122}}],
    Polygon[{{0.327590, 0.541811, 0.009770},{0.328560, 0.543145, 0.011178},{
      0.330824, 0.541992, 0.011178},{0.330314, 0.540424, 0.009770}}],
    Polygon[{{0.328560, 0.543145, 0.011178},{0.329646, 0.544641, 0.012311},{
      0.331395, 0.543750, 0.012311},{0.330824, 0.541992, 0.011178}}],
    Polygon[{{0.329646, 0.544641, 0.012311},{0.330824, 0.546261, 0.013141},{
      0.332014, 0.545655, 0.013141},{0.331395, 0.543750, 0.012311}}],
    Polygon[{{0.330824, 0.546261, 0.013141},{0.332063, 0.547967, 0.013647},{
      0.332665, 0.547660, 0.013647},{0.332014, 0.545655, 0.013141}}],
    Polygon[{{0.332665, 0.547660, -0.013647},{0.332014, 0.545655, -0.013141},{
      0.333333, 0.545446, -0.013141},{0.333333, 0.547554, -0.013647}}],
    Polygon[{{0.332014, 0.545655, -0.013141},{0.331395, 0.543750, -0.012311},{
      0.333333, 0.543443, -0.012311},{0.333333, 0.545446, -0.013141}}],
    Polygon[{{0.331395, 0.543750, -0.012311},{0.330824, 0.541992, -0.011178},{
      0.333333, 0.541594, -0.011178},{0.333333, 0.543443, -0.012311}}],
    Polygon[{{0.330824, 0.541992, -0.011178},{0.330314, 0.540424, -0.009770},{
      0.333333, 0.539945, -0.009770},{0.333333, 0.541594, -0.011178}}],
    Polygon[{{0.330314, 0.540424, -0.009770},{0.329879, 0.539084, -0.008122},{
      0.333333, 0.538537, -0.008122},{0.333333, 0.539945, -0.009770}}],
    Polygon[{{0.329879, 0.539084, -0.008122},{0.329529, 0.538007, -0.006273},{
      0.333333, 0.537404, -0.006273},{0.333333, 0.538537, -0.008122}}],
    Polygon[{{0.329529, 0.538007, -0.006273},{0.329273, 0.537218, -0.004270},{
      0.333333, 0.536575, -0.004270},{0.333333, 0.537404, -0.006273}}],
    Polygon[{{0.329273, 0.537218, -0.004270},{0.329116, 0.536736, -0.002162},{
      0.333333, 0.536068, -0.002162},{0.333333, 0.536575, -0.004270}}],
    Polygon[{{0.329116, 0.536736, -0.002162},{0.329064, 0.536575, 0.000000},{
      0.333333, 0.535898, 0.000000},{0.333333, 0.536068, -0.002162}}],
    Polygon[{{0.329064, 0.536575, 0.000000},{0.329116, 0.536736, 0.002162},{
      0.333333, 0.536068, 0.002162},{0.333333, 0.535898, 0.000000}}],
    Polygon[{{0.329116, 0.536736, 0.002162},{0.329273, 0.537218, 0.004270},{
      0.333333, 0.536575, 0.004270},{0.333333, 0.536068, 0.002162}}],
    Polygon[{{0.329273, 0.537218, 0.004270},{0.329529, 0.538007, 0.006273},{
      0.333333, 0.537404, 0.006273},{0.333333, 0.536575, 0.004270}}],
    Polygon[{{0.329529, 0.538007, 0.006273},{0.329879, 0.539084, 0.008122},{
      0.333333, 0.538537, 0.008122},{0.333333, 0.537404, 0.006273}}],
    Polygon[{{0.329879, 0.539084, 0.008122},{0.330314, 0.540424, 0.009770},{
      0.333333, 0.539945, 0.009770},{0.333333, 0.538537, 0.008122}}],
    Polygon[{{0.330314, 0.540424, 0.009770},{0.330824, 0.541992, 0.011178},{
      0.333333, 0.541594, 0.011178},{0.333333, 0.539945, 0.009770}}],
    Polygon[{{0.330824, 0.541992, 0.011178},{0.331395, 0.543750, 0.012311},{
      0.333333, 0.543443, 0.012311},{0.333333, 0.541594, 0.011178}}],
    Polygon[{{0.331395, 0.543750, 0.012311},{0.332014, 0.545655, 0.013141},{
      0.333333, 0.545446, 0.013141},{0.333333, 0.543443, 0.012311}}],
    Polygon[{{0.332014, 0.545655, 0.013141},{0.332665, 0.547660, 0.013647},{
      0.333333, 0.547554, 0.013647},{0.333333, 0.545446, 0.013141}}],
    Polygon[{{0.333333, 0.547554, -0.013647},{0.333333, 0.545446, -0.013141},{
      0.334653, 0.545655, -0.013141},{0.334001, 0.547660, -0.013647}}],
    Polygon[{{0.333333, 0.545446, -0.013141},{0.333333, 0.543443, -0.012311},{
      0.335272, 0.543750, -0.012311},{0.334653, 0.545655, -0.013141}}],
    Polygon[{{0.333333, 0.543443, -0.012311},{0.333333, 0.541594, -0.011178},{
      0.335843, 0.541992, -0.011178},{0.335272, 0.543750, -0.012311}}],
    Polygon[{{0.333333, 0.541594, -0.011178},{0.333333, 0.539945, -0.009770},{
      0.336353, 0.540424, -0.009770},{0.335843, 0.541992, -0.011178}}],
    Polygon[{{0.333333, 0.539945, -0.009770},{0.333333, 0.538537, -0.008122},{
      0.336788, 0.539084, -0.008122},{0.336353, 0.540424, -0.009770}}],
    Polygon[{{0.333333, 0.538537, -0.008122},{0.333333, 0.537404, -0.006273},{
      0.337138, 0.538007, -0.006273},{0.336788, 0.539084, -0.008122}}],
    Polygon[{{0.333333, 0.537404, -0.006273},{0.333333, 0.536575, -0.004270},{
      0.337394, 0.537218, -0.004270},{0.337138, 0.538007, -0.006273}}],
    Polygon[{{0.333333, 0.536575, -0.004270},{0.333333, 0.536068, -0.002162},{
      0.337551, 0.536736, -0.002162},{0.337394, 0.537218, -0.004270}}],
    Polygon[{{0.333333, 0.536068, -0.002162},{0.333333, 0.535898, 0.000000},{
      0.337603, 0.536575, 0.000000},{0.337551, 0.536736, -0.002162}}],
    Polygon[{{0.333333, 0.535898, 0.000000},{0.333333, 0.536068, 0.002162},{
      0.337551, 0.536736, 0.002162},{0.337603, 0.536575, 0.000000}}],
    Polygon[{{0.333333, 0.536068, 0.002162},{0.333333, 0.536575, 0.004270},{
      0.337394, 0.537218, 0.004270},{0.337551, 0.536736, 0.002162}}],
    Polygon[{{0.333333, 0.536575, 0.004270},{0.333333, 0.537404, 0.006273},{
      0.337138, 0.538007, 0.006273},{0.337394, 0.537218, 0.004270}}],
    Polygon[{{0.333333, 0.537404, 0.006273},{0.333333, 0.538537, 0.008122},{
      0.336788, 0.539084, 0.008122},{0.337138, 0.538007, 0.006273}}],
    Polygon[{{0.333333, 0.538537, 0.008122},{0.333333, 0.539945, 0.009770},{
      0.336353, 0.540424, 0.009770},{0.336788, 0.539084, 0.008122}}],
    Polygon[{{0.333333, 0.539945, 0.009770},{0.333333, 0.541594, 0.011178},{
      0.335843, 0.541992, 0.011178},{0.336353, 0.540424, 0.009770}}],
    Polygon[{{0.333333, 0.541594, 0.011178},{0.333333, 0.543443, 0.012311},{
      0.335272, 0.543750, 0.012311},{0.335843, 0.541992, 0.011178}}],
    Polygon[{{0.333333, 0.543443, 0.012311},{0.333333, 0.545446, 0.013141},{
      0.334653, 0.545655, 0.013141},{0.335272, 0.543750, 0.012311}}],
    Polygon[{{0.333333, 0.545446, 0.013141},{0.333333, 0.547554, 0.013647},{
      0.334001, 0.547660, 0.013647},{0.334653, 0.545655, 0.013141}}],
    Polygon[{{0.334001, 0.547660, -0.013647},{0.334653, 0.545655, -0.013141},{
      0.335843, 0.546261, -0.013141},{0.334604, 0.547967, -0.013647}}],
    Polygon[{{0.334653, 0.545655, -0.013141},{0.335272, 0.543750, -0.012311},{
      0.337020, 0.544641, -0.012311},{0.335843, 0.546261, -0.013141}}],
    Polygon[{{0.335272, 0.543750, -0.012311},{0.335843, 0.541992, -0.011178},{
      0.338107, 0.543145, -0.011178},{0.337020, 0.544641, -0.012311}}],
    Polygon[{{0.335843, 0.541992, -0.011178},{0.336353, 0.540424, -0.009770},{
      0.339076, 0.541811, -0.009770},{0.338107, 0.543145, -0.011178}}],
    Polygon[{{0.336353, 0.540424, -0.009770},{0.336788, 0.539084, -0.008122},{
      0.339904, 0.540672, -0.008122},{0.339076, 0.541811, -0.009770}}],
    Polygon[{{0.336788, 0.539084, -0.008122},{0.337138, 0.538007, -0.006273},{
      0.340570, 0.539756, -0.006273},{0.339904, 0.540672, -0.008122}}],
    Polygon[{{0.337138, 0.538007, -0.006273},{0.337394, 0.537218, -0.004270},{
      0.341057, 0.539084, -0.004270},{0.340570, 0.539756, -0.006273}}],
    Polygon[{{0.337394, 0.537218, -0.004270},{0.337551, 0.536736, -0.002162},{
      0.341355, 0.538675, -0.002162},{0.341057, 0.539084, -0.004270}}],
    Polygon[{{0.337551, 0.536736, -0.002162},{0.337603, 0.536575, 0.000000},{
      0.341455, 0.538537, 0.000000},{0.341355, 0.538675, -0.002162}}],
    Polygon[{{0.337603, 0.536575, 0.000000},{0.337551, 0.536736, 0.002162},{
      0.341355, 0.538675, 0.002162},{0.341455, 0.538537, 0.000000}}],
    Polygon[{{0.337551, 0.536736, 0.002162},{0.337394, 0.537218, 0.004270},{
      0.341057, 0.539084, 0.004270},{0.341355, 0.538675, 0.002162}}],
    Polygon[{{0.337394, 0.537218, 0.004270},{0.337138, 0.538007, 0.006273},{
      0.340570, 0.539756, 0.006273},{0.341057, 0.539084, 0.004270}}],
    Polygon[{{0.337138, 0.538007, 0.006273},{0.336788, 0.539084, 0.008122},{
      0.339904, 0.540672, 0.008122},{0.340570, 0.539756, 0.006273}}],
    Polygon[{{0.336788, 0.539084, 0.008122},{0.336353, 0.540424, 0.009770},{
      0.339076, 0.541811, 0.009770},{0.339904, 0.540672, 0.008122}}],
    Polygon[{{0.336353, 0.540424, 0.009770},{0.335843, 0.541992, 0.011178},{
      0.338107, 0.543145, 0.011178},{0.339076, 0.541811, 0.009770}}],
    Polygon[{{0.335843, 0.541992, 0.011178},{0.335272, 0.543750, 0.012311},{
      0.337020, 0.544641, 0.012311},{0.338107, 0.543145, 0.011178}}],
    Polygon[{{0.335272, 0.543750, 0.012311},{0.334653, 0.545655, 0.013141},{
      0.335843, 0.546261, 0.013141},{0.337020, 0.544641, 0.012311}}],
    Polygon[{{0.334653, 0.545655, 0.013141},{0.334001, 0.547660, 0.013647},{
      0.334604, 0.547967, 0.013647},{0.335843, 0.546261, 0.013141}}],
    Polygon[{{0.334604, 0.547967, -0.013647},{0.335843, 0.546261, -0.013141},{
      0.336788, 0.547206, -0.013141},{0.335082, 0.548445, -0.013647}}],
    Polygon[{{0.335843, 0.546261, -0.013141},{0.337020, 0.544641, -0.012311},{
      0.338408, 0.546029, -0.012311},{0.336788, 0.547206, -0.013141}}],
    Polygon[{{0.337020, 0.544641, -0.012311},{0.338107, 0.543145, -0.011178},{
      0.339904, 0.544942, -0.011178},{0.338408, 0.546029, -0.012311}}],
    Polygon[{{0.338107, 0.543145, -0.011178},{0.339076, 0.541811, -0.009770},{
      0.341238, 0.543973, -0.009770},{0.339904, 0.544942, -0.011178}}],
    Polygon[{{0.339076, 0.541811, -0.009770},{0.339904, 0.540672, -0.008122},{
      0.342377, 0.543145, -0.008122},{0.341238, 0.543973, -0.009770}}],
    Polygon[{{0.339904, 0.540672, -0.008122},{0.340570, 0.539756, -0.006273},{
      0.343293, 0.542479, -0.006273},{0.342377, 0.543145, -0.008122}}],
    Polygon[{{0.340570, 0.539756, -0.006273},{0.341057, 0.539084, -0.004270},{
      0.343965, 0.541992, -0.004270},{0.343293, 0.542479, -0.006273}}],
    Polygon[{{0.341057, 0.539084, -0.004270},{0.341355, 0.538675, -0.002162},{
      0.344374, 0.541694, -0.002162},{0.343965, 0.541992, -0.004270}}],
    Polygon[{{0.341355, 0.538675, -0.002162},{0.341455, 0.538537, 0.000000},{
      0.344512, 0.541594, 0.000000},{0.344374, 0.541694, -0.002162}}],
    Polygon[{{0.341455, 0.538537, 0.000000},{0.341355, 0.538675, 0.002162},{
      0.344374, 0.541694, 0.002162},{0.344512, 0.541594, 0.000000}}],
    Polygon[{{0.341355, 0.538675, 0.002162},{0.341057, 0.539084, 0.004270},{
      0.343965, 0.541992, 0.004270},{0.344374, 0.541694, 0.002162}}],
    Polygon[{{0.341057, 0.539084, 0.004270},{0.340570, 0.539756, 0.006273},{
      0.343293, 0.542479, 0.006273},{0.343965, 0.541992, 0.004270}}],
    Polygon[{{0.340570, 0.539756, 0.006273},{0.339904, 0.540672, 0.008122},{
      0.342377, 0.543145, 0.008122},{0.343293, 0.542479, 0.006273}}],
    Polygon[{{0.339904, 0.540672, 0.008122},{0.339076, 0.541811, 0.009770},{
      0.341238, 0.543973, 0.009770},{0.342377, 0.543145, 0.008122}}],
    Polygon[{{0.339076, 0.541811, 0.009770},{0.338107, 0.543145, 0.011178},{
      0.339904, 0.544942, 0.011178},{0.341238, 0.543973, 0.009770}}],
    Polygon[{{0.338107, 0.543145, 0.011178},{0.337020, 0.544641, 0.012311},{
      0.338408, 0.546029, 0.012311},{0.339904, 0.544942, 0.011178}}],
    Polygon[{{0.337020, 0.544641, 0.012311},{0.335843, 0.546261, 0.013141},{
      0.336788, 0.547206, 0.013141},{0.338408, 0.546029, 0.012311}}],
    Polygon[{{0.335843, 0.546261, 0.013141},{0.334604, 0.547967, 0.013647},{
      0.335082, 0.548445, 0.013647},{0.336788, 0.547206, 0.013141}}],
    Polygon[{{0.335082, 0.548445, -0.013647},{0.336788, 0.547206, -0.013141},{
      0.337394, 0.548396, -0.013141},{0.335389, 0.549048, -0.013647}}],
    Polygon[{{0.336788, 0.547206, -0.013141},{0.338408, 0.546029, -0.012311},{
      0.339299, 0.547777, -0.012311},{0.337394, 0.548396, -0.013141}}],
    Polygon[{{0.338408, 0.546029, -0.012311},{0.339904, 0.544942, -0.011178},{
      0.341057, 0.547206, -0.011178},{0.339299, 0.547777, -0.012311}}],
    Polygon[{{0.339904, 0.544942, -0.011178},{0.341238, 0.543973, -0.009770},{
      0.342625, 0.546696, -0.009770},{0.341057, 0.547206, -0.011178}}],
    Polygon[{{0.341238, 0.543973, -0.009770},{0.342377, 0.543145, -0.008122},{
      0.343965, 0.546261, -0.008122},{0.342625, 0.546696, -0.009770}}],
    Polygon[{{0.342377, 0.543145, -0.008122},{0.343293, 0.542479, -0.006273},{
      0.345042, 0.545911, -0.006273},{0.343965, 0.546261, -0.008122}}],
    Polygon[{{0.343293, 0.542479, -0.006273},{0.343965, 0.541992, -0.004270},{
      0.345831, 0.545655, -0.004270},{0.345042, 0.545911, -0.006273}}],
    Polygon[{{0.343965, 0.541992, -0.004270},{0.344374, 0.541694, -0.002162},{
      0.346313, 0.545498, -0.002162},{0.345831, 0.545655, -0.004270}}],
    Polygon[{{0.344374, 0.541694, -0.002162},{0.344512, 0.541594, 0.000000},{
      0.346474, 0.545446, 0.000000},{0.346313, 0.545498, -0.002162}}],
    Polygon[{{0.344512, 0.541594, 0.000000},{0.344374, 0.541694, 0.002162},{
      0.346313, 0.545498, 0.002162},{0.346474, 0.545446, 0.000000}}],
    Polygon[{{0.344374, 0.541694, 0.002162},{0.343965, 0.541992, 0.004270},{
      0.345831, 0.545655, 0.004270},{0.346313, 0.545498, 0.002162}}],
    Polygon[{{0.343965, 0.541992, 0.004270},{0.343293, 0.542479, 0.006273},{
      0.345042, 0.545911, 0.006273},{0.345831, 0.545655, 0.004270}}],
    Polygon[{{0.343293, 0.542479, 0.006273},{0.342377, 0.543145, 0.008122},{
      0.343965, 0.546261, 0.008122},{0.345042, 0.545911, 0.006273}}],
    Polygon[{{0.342377, 0.543145, 0.008122},{0.341238, 0.543973, 0.009770},{
      0.342625, 0.546696, 0.009770},{0.343965, 0.546261, 0.008122}}],
    Polygon[{{0.341238, 0.543973, 0.009770},{0.339904, 0.544942, 0.011178},{
      0.341057, 0.547206, 0.011178},{0.342625, 0.546696, 0.009770}}],
    Polygon[{{0.339904, 0.544942, 0.011178},{0.338408, 0.546029, 0.012311},{
      0.339299, 0.547777, 0.012311},{0.341057, 0.547206, 0.011178}}],
    Polygon[{{0.338408, 0.546029, 0.012311},{0.336788, 0.547206, 0.013141},{
      0.337394, 0.548396, 0.013141},{0.339299, 0.547777, 0.012311}}],
    Polygon[{{0.336788, 0.547206, 0.013141},{0.335082, 0.548445, 0.013647},{
      0.335389, 0.549048, 0.013647},{0.337394, 0.548396, 0.013141}}],
    Polygon[{{0.335389, 0.549048, -0.013647},{0.337394, 0.548396, -0.013141},{
      0.337603, 0.549716, -0.013141},{0.335495, 0.549716, -0.013647}}],
    Polygon[{{0.337394, 0.548396, -0.013141},{0.339299, 0.547777, -0.012311},{
      0.339606, 0.549716, -0.012311},{0.337603, 0.549716, -0.013141}}],
    Polygon[{{0.339299, 0.547777, -0.012311},{0.341057, 0.547206, -0.011178},{
      0.341455, 0.549716, -0.011178},{0.339606, 0.549716, -0.012311}}],
    Polygon[{{0.341057, 0.547206, -0.011178},{0.342625, 0.546696, -0.009770},{
      0.343104, 0.549716, -0.009770},{0.341455, 0.549716, -0.011178}}],
    Polygon[{{0.342625, 0.546696, -0.009770},{0.343965, 0.546261, -0.008122},{
      0.344512, 0.549716, -0.008122},{0.343104, 0.549716, -0.009770}}],
    Polygon[{{0.343965, 0.546261, -0.008122},{0.345042, 0.545911, -0.006273},{
      0.345645, 0.549716, -0.006273},{0.344512, 0.549716, -0.008122}}],
    Polygon[{{0.345042, 0.545911, -0.006273},{0.345831, 0.545655, -0.004270},{
      0.346474, 0.549716, -0.004270},{0.345645, 0.549716, -0.006273}}],
    Polygon[{{0.345831, 0.545655, -0.004270},{0.346313, 0.545498, -0.002162},{
      0.346981, 0.549716, -0.002162},{0.346474, 0.549716, -0.004270}}],
    Polygon[{{0.346313, 0.545498, -0.002162},{0.346474, 0.545446, 0.000000},{
      0.347151, 0.549716, 0.000000},{0.346981, 0.549716, -0.002162}}],
    Polygon[{{0.346474, 0.545446, 0.000000},{0.346313, 0.545498, 0.002162},{
      0.346981, 0.549716, 0.002162},{0.347151, 0.549716, 0.000000}}],
    Polygon[{{0.346313, 0.545498, 0.002162},{0.345831, 0.545655, 0.004270},{
      0.346474, 0.549716, 0.004270},{0.346981, 0.549716, 0.002162}}],
    Polygon[{{0.345831, 0.545655, 0.004270},{0.345042, 0.545911, 0.006273},{
      0.345645, 0.549716, 0.006273},{0.346474, 0.549716, 0.004270}}],
    Polygon[{{0.345042, 0.545911, 0.006273},{0.343965, 0.546261, 0.008122},{
      0.344512, 0.549716, 0.008122},{0.345645, 0.549716, 0.006273}}],
    Polygon[{{0.343965, 0.546261, 0.008122},{0.342625, 0.546696, 0.009770},{
      0.343104, 0.549716, 0.009770},{0.344512, 0.549716, 0.008122}}],
    Polygon[{{0.342625, 0.546696, 0.009770},{0.341057, 0.547206, 0.011178},{
      0.341455, 0.549716, 0.011178},{0.343104, 0.549716, 0.009770}}],
    Polygon[{{0.341057, 0.547206, 0.011178},{0.339299, 0.547777, 0.012311},{
      0.339606, 0.549716, 0.012311},{0.341455, 0.549716, 0.011178}}],
    Polygon[{{0.339299, 0.547777, 0.012311},{0.337394, 0.548396, 0.013141},{
      0.337603, 0.549716, 0.013141},{0.339606, 0.549716, 0.012311}}],
    Polygon[{{0.337394, 0.548396, 0.013141},{0.335389, 0.549048, 0.013647},{
      0.335495, 0.549716, 0.013647},{0.337603, 0.549716, 0.013141}}],
    Polygon[{{0.413502, 0.532229, -0.012733},{0.415469, 0.532229, -0.012261},{
      0.415274, 0.533460, -0.012261},{0.413403, 0.532852, -0.012733}}],
    Polygon[{{0.415469, 0.532229, -0.012261},{0.417338, 0.532229, -0.011487},{
      0.417051, 0.534038, -0.011487},{0.415274, 0.533460, -0.012261}}],
    Polygon[{{0.417338, 0.532229, -0.011487},{0.419063, 0.532229, -0.010430},{
      0.418692, 0.534571, -0.010430},{0.417051, 0.534038, -0.011487}}],
    Polygon[{{0.419063, 0.532229, -0.010430},{0.420601, 0.532229, -0.009116},{
      0.420155, 0.535046, -0.009116},{0.418692, 0.534571, -0.010430}}],
    Polygon[{{0.420601, 0.532229, -0.009116},{0.421915, 0.532229, -0.007578},{
      0.421404, 0.535452, -0.007578},{0.420155, 0.535046, -0.009116}}],
    Polygon[{{0.421915, 0.532229, -0.007578},{0.422972, 0.532229, -0.005853},{
      0.422410, 0.535779, -0.005853},{0.421404, 0.535452, -0.007578}}],
    Polygon[{{0.422972, 0.532229, -0.005853},{0.423746, 0.532229, -0.003984},{
      0.423146, 0.536018, -0.003984},{0.422410, 0.535779, -0.005853}}],
    Polygon[{{0.423746, 0.532229, -0.003984},{0.424218, 0.532229, -0.002017},{
      0.423595, 0.536164, -0.002017},{0.423146, 0.536018, -0.003984}}],
    Polygon[{{0.424218, 0.532229, -0.002017},{0.424377, 0.532229, 0.000000},{
      0.423746, 0.536213, 0.000000},{0.423595, 0.536164, -0.002017}}],
    Polygon[{{0.424377, 0.532229, 0.000000},{0.424218, 0.532229, 0.002017},{
      0.423595, 0.536164, 0.002017},{0.423746, 0.536213, 0.000000}}],
    Polygon[{{0.424218, 0.532229, 0.002017},{0.423746, 0.532229, 0.003984},{
      0.423146, 0.536018, 0.003984},{0.423595, 0.536164, 0.002017}}],
    Polygon[{{0.423746, 0.532229, 0.003984},{0.422972, 0.532229, 0.005853},{
      0.422410, 0.535779, 0.005853},{0.423146, 0.536018, 0.003984}}],
    Polygon[{{0.422972, 0.532229, 0.005853},{0.421915, 0.532229, 0.007578},{
      0.421404, 0.535452, 0.007578},{0.422410, 0.535779, 0.005853}}],
    Polygon[{{0.421915, 0.532229, 0.007578},{0.420601, 0.532229, 0.009116},{
      0.420155, 0.535046, 0.009116},{0.421404, 0.535452, 0.007578}}],
    Polygon[{{0.420601, 0.532229, 0.009116},{0.419063, 0.532229, 0.010430},{
      0.418692, 0.534571, 0.010430},{0.420155, 0.535046, 0.009116}}],
    Polygon[{{0.419063, 0.532229, 0.010430},{0.417338, 0.532229, 0.011487},{
      0.417051, 0.534038, 0.011487},{0.418692, 0.534571, 0.010430}}],
    Polygon[{{0.417338, 0.532229, 0.011487},{0.415469, 0.532229, 0.012261},{
      0.415274, 0.533460, 0.012261},{0.417051, 0.534038, 0.011487}}],
    Polygon[{{0.415469, 0.532229, 0.012261},{0.413502, 0.532229, 0.012733},{
      0.413403, 0.532852, 0.012733},{0.415274, 0.533460, 0.012261}}],
    Polygon[{{0.413403, 0.532852, -0.012733},{0.415274, 0.533460, -0.012261},{
      0.414708, 0.534571, -0.012261},{0.413117, 0.533415, -0.012733}}],
    Polygon[{{0.415274, 0.533460, -0.012261},{0.417051, 0.534038, -0.011487},{
      0.416220, 0.535669, -0.011487},{0.414708, 0.534571, -0.012261}}],
    Polygon[{{0.417051, 0.534038, -0.011487},{0.418692, 0.534571, -0.010430},{
      0.417616, 0.536683, -0.010430},{0.416220, 0.535669, -0.011487}}],
    Polygon[{{0.418692, 0.534571, -0.010430},{0.420155, 0.535046, -0.009116},{
      0.418860, 0.537587, -0.009116},{0.417616, 0.536683, -0.010430}}],
    Polygon[{{0.420155, 0.535046, -0.009116},{0.421404, 0.535452, -0.007578},{
      0.419923, 0.538360, -0.007578},{0.418860, 0.537587, -0.009116}}],
    Polygon[{{0.421404, 0.535452, -0.007578},{0.422410, 0.535779, -0.005853},{
      0.420778, 0.538981, -0.005853},{0.419923, 0.538360, -0.007578}}],
    Polygon[{{0.422410, 0.535779, -0.005853},{0.423146, 0.536018, -0.003984},{
      0.421404, 0.539436, -0.003984},{0.420778, 0.538981, -0.005853}}],
    Polygon[{{0.423146, 0.536018, -0.003984},{0.423595, 0.536164, -0.002017},{
      0.421786, 0.539714, -0.002017},{0.421404, 0.539436, -0.003984}}],
    Polygon[{{0.423595, 0.536164, -0.002017},{0.423746, 0.536213, 0.000000},{
      0.421915, 0.539807, 0.000000},{0.421786, 0.539714, -0.002017}}],
    Polygon[{{0.423746, 0.536213, 0.000000},{0.423595, 0.536164, 0.002017},{
      0.421786, 0.539714, 0.002017},{0.421915, 0.539807, 0.000000}}],
    Polygon[{{0.423595, 0.536164, 0.002017},{0.423146, 0.536018, 0.003984},{
      0.421404, 0.539436, 0.003984},{0.421786, 0.539714, 0.002017}}],
    Polygon[{{0.423146, 0.536018, 0.003984},{0.422410, 0.535779, 0.005853},{
      0.420778, 0.538981, 0.005853},{0.421404, 0.539436, 0.003984}}],
    Polygon[{{0.422410, 0.535779, 0.005853},{0.421404, 0.535452, 0.007578},{
      0.419923, 0.538360, 0.007578},{0.420778, 0.538981, 0.005853}}],
    Polygon[{{0.421404, 0.535452, 0.007578},{0.420155, 0.535046, 0.009116},{
      0.418860, 0.537587, 0.009116},{0.419923, 0.538360, 0.007578}}],
    Polygon[{{0.420155, 0.535046, 0.009116},{0.418692, 0.534571, 0.010430},{
      0.417616, 0.536683, 0.010430},{0.418860, 0.537587, 0.009116}}],
    Polygon[{{0.418692, 0.534571, 0.010430},{0.417051, 0.534038, 0.011487},{
      0.416220, 0.535669, 0.011487},{0.417616, 0.536683, 0.010430}}],
    Polygon[{{0.417051, 0.534038, 0.011487},{0.415274, 0.533460, 0.012261},{
      0.414708, 0.534571, 0.012261},{0.416220, 0.535669, 0.011487}}],
    Polygon[{{0.415274, 0.533460, 0.012261},{0.413403, 0.532852, 0.012733},{
      0.413117, 0.533415, 0.012733},{0.414708, 0.534571, 0.012261}}],
    Polygon[{{0.413117, 0.533415, -0.012733},{0.414708, 0.534571, -0.012261},{
      0.413827, 0.535452, -0.012261},{0.412671, 0.533861, -0.012733}}],
    Polygon[{{0.414708, 0.534571, -0.012261},{0.416220, 0.535669, -0.011487},{
      0.414925, 0.536964, -0.011487},{0.413827, 0.535452, -0.012261}}],
    Polygon[{{0.416220, 0.535669, -0.011487},{0.417616, 0.536683, -0.010430},{
      0.415939, 0.538360, -0.010430},{0.414925, 0.536964, -0.011487}}],
    Polygon[{{0.417616, 0.536683, -0.010430},{0.418860, 0.537587, -0.009116},{
      0.416843, 0.539604, -0.009116},{0.415939, 0.538360, -0.010430}}],
    Polygon[{{0.418860, 0.537587, -0.009116},{0.419923, 0.538360, -0.007578},{
      0.417616, 0.540667, -0.007578},{0.416843, 0.539604, -0.009116}}],
    Polygon[{{0.419923, 0.538360, -0.007578},{0.420778, 0.538981, -0.005853},{
      0.418237, 0.541522, -0.005853},{0.417616, 0.540667, -0.007578}}],
    Polygon[{{0.420778, 0.538981, -0.005853},{0.421404, 0.539436, -0.003984},{
      0.418692, 0.542148, -0.003984},{0.418237, 0.541522, -0.005853}}],
    Polygon[{{0.421404, 0.539436, -0.003984},{0.421786, 0.539714, -0.002017},{
      0.418969, 0.542530, -0.002017},{0.418692, 0.542148, -0.003984}}],
    Polygon[{{0.421786, 0.539714, -0.002017},{0.421915, 0.539807, 0.000000},{
      0.419063, 0.542659, 0.000000},{0.418969, 0.542530, -0.002017}}],
    Polygon[{{0.421915, 0.539807, 0.000000},{0.421786, 0.539714, 0.002017},{
      0.418969, 0.542530, 0.002017},{0.419063, 0.542659, 0.000000}}],
    Polygon[{{0.421786, 0.539714, 0.002017},{0.421404, 0.539436, 0.003984},{
      0.418692, 0.542148, 0.003984},{0.418969, 0.542530, 0.002017}}],
    Polygon[{{0.421404, 0.539436, 0.003984},{0.420778, 0.538981, 0.005853},{
      0.418237, 0.541522, 0.005853},{0.418692, 0.542148, 0.003984}}],
    Polygon[{{0.420778, 0.538981, 0.005853},{0.419923, 0.538360, 0.007578},{
      0.417616, 0.540667, 0.007578},{0.418237, 0.541522, 0.005853}}],
    Polygon[{{0.419923, 0.538360, 0.007578},{0.418860, 0.537587, 0.009116},{
      0.416843, 0.539604, 0.009116},{0.417616, 0.540667, 0.007578}}],
    Polygon[{{0.418860, 0.537587, 0.009116},{0.417616, 0.536683, 0.010430},{
      0.415939, 0.538360, 0.010430},{0.416843, 0.539604, 0.009116}}],
    Polygon[{{0.417616, 0.536683, 0.010430},{0.416220, 0.535669, 0.011487},{
      0.414925, 0.536964, 0.011487},{0.415939, 0.538360, 0.010430}}],
    Polygon[{{0.416220, 0.535669, 0.011487},{0.414708, 0.534571, 0.012261},{
      0.413827, 0.535452, 0.012261},{0.414925, 0.536964, 0.011487}}],
    Polygon[{{0.414708, 0.534571, 0.012261},{0.413117, 0.533415, 0.012733},{
      0.412671, 0.533861, 0.012733},{0.413827, 0.535452, 0.012261}}],
    Polygon[{{0.412671, 0.533861, -0.012733},{0.413827, 0.535452, -0.012261},{
      0.412716, 0.536018, -0.012261},{0.412108, 0.534147, -0.012733}}],
    Polygon[{{0.413827, 0.535452, -0.012261},{0.414925, 0.536964, -0.011487},{
      0.413294, 0.537796, -0.011487},{0.412716, 0.536018, -0.012261}}],
    Polygon[{{0.414925, 0.536964, -0.011487},{0.415939, 0.538360, -0.010430},{
      0.413827, 0.539436, -0.010430},{0.413294, 0.537796, -0.011487}}],
    Polygon[{{0.415939, 0.538360, -0.010430},{0.416843, 0.539604, -0.009116},{
      0.414302, 0.540899, -0.009116},{0.413827, 0.539436, -0.010430}}],
    Polygon[{{0.416843, 0.539604, -0.009116},{0.417616, 0.540667, -0.007578},{
      0.414708, 0.542148, -0.007578},{0.414302, 0.540899, -0.009116}}],
    Polygon[{{0.417616, 0.540667, -0.007578},{0.418237, 0.541522, -0.005853},{
      0.415035, 0.543154, -0.005853},{0.414708, 0.542148, -0.007578}}],
    Polygon[{{0.418237, 0.541522, -0.005853},{0.418692, 0.542148, -0.003984},{
      0.415274, 0.543890, -0.003984},{0.415035, 0.543154, -0.005853}}],
    Polygon[{{0.418692, 0.542148, -0.003984},{0.418969, 0.542530, -0.002017},{
      0.415420, 0.544339, -0.002017},{0.415274, 0.543890, -0.003984}}],
    Polygon[{{0.418969, 0.542530, -0.002017},{0.419063, 0.542659, 0.000000},{
      0.415469, 0.544490, 0.000000},{0.415420, 0.544339, -0.002017}}],
    Polygon[{{0.419063, 0.542659, 0.000000},{0.418969, 0.542530, 0.002017},{
      0.415420, 0.544339, 0.002017},{0.415469, 0.544490, 0.000000}}],
    Polygon[{{0.418969, 0.542530, 0.002017},{0.418692, 0.542148, 0.003984},{
      0.415274, 0.543890, 0.003984},{0.415420, 0.544339, 0.002017}}],
    Polygon[{{0.418692, 0.542148, 0.003984},{0.418237, 0.541522, 0.005853},{
      0.415035, 0.543154, 0.005853},{0.415274, 0.543890, 0.003984}}],
    Polygon[{{0.418237, 0.541522, 0.005853},{0.417616, 0.540667, 0.007578},{
      0.414708, 0.542148, 0.007578},{0.415035, 0.543154, 0.005853}}],
    Polygon[{{0.417616, 0.540667, 0.007578},{0.416843, 0.539604, 0.009116},{
      0.414302, 0.540899, 0.009116},{0.414708, 0.542148, 0.007578}}],
    Polygon[{{0.416843, 0.539604, 0.009116},{0.415939, 0.538360, 0.010430},{
      0.413827, 0.539436, 0.010430},{0.414302, 0.540899, 0.009116}}],
    Polygon[{{0.415939, 0.538360, 0.010430},{0.414925, 0.536964, 0.011487},{
      0.413294, 0.537796, 0.011487},{0.413827, 0.539436, 0.010430}}],
    Polygon[{{0.414925, 0.536964, 0.011487},{0.413827, 0.535452, 0.012261},{
      0.412716, 0.536018, 0.012261},{0.413294, 0.537796, 0.011487}}],
    Polygon[{{0.413827, 0.535452, 0.012261},{0.412671, 0.533861, 0.012733},{
      0.412108, 0.534147, 0.012733},{0.412716, 0.536018, 0.012261}}],
    Polygon[{{0.412108, 0.534147, -0.012733},{0.412716, 0.536018, -0.012261},{
      0.411485, 0.536213, -0.012261},{0.411485, 0.534246, -0.012733}}],
    Polygon[{{0.412716, 0.536018, -0.012261},{0.413294, 0.537796, -0.011487},{
      0.411485, 0.538082, -0.011487},{0.411485, 0.536213, -0.012261}}],
    Polygon[{{0.413294, 0.537796, -0.011487},{0.413827, 0.539436, -0.010430},{
      0.411485, 0.539807, -0.010430},{0.411485, 0.538082, -0.011487}}],
    Polygon[{{0.413827, 0.539436, -0.010430},{0.414302, 0.540899, -0.009116},{
      0.411485, 0.541345, -0.009116},{0.411485, 0.539807, -0.010430}}],
    Polygon[{{0.414302, 0.540899, -0.009116},{0.414708, 0.542148, -0.007578},{
      0.411485, 0.542659, -0.007578},{0.411485, 0.541345, -0.009116}}],
    Polygon[{{0.414708, 0.542148, -0.007578},{0.415035, 0.543154, -0.005853},{
      0.411485, 0.543716, -0.005853},{0.411485, 0.542659, -0.007578}}],
    Polygon[{{0.415035, 0.543154, -0.005853},{0.415274, 0.543890, -0.003984},{
      0.411485, 0.544490, -0.003984},{0.411485, 0.543716, -0.005853}}],
    Polygon[{{0.415274, 0.543890, -0.003984},{0.415420, 0.544339, -0.002017},{
      0.411485, 0.544962, -0.002017},{0.411485, 0.544490, -0.003984}}],
    Polygon[{{0.415420, 0.544339, -0.002017},{0.415469, 0.544490, 0.000000},{
      0.411485, 0.545121, 0.000000},{0.411485, 0.544962, -0.002017}}],
    Polygon[{{0.415469, 0.544490, 0.000000},{0.415420, 0.544339, 0.002017},{
      0.411485, 0.544962, 0.002017},{0.411485, 0.545121, 0.000000}}],
    Polygon[{{0.415420, 0.544339, 0.002017},{0.415274, 0.543890, 0.003984},{
      0.411485, 0.544490, 0.003984},{0.411485, 0.544962, 0.002017}}],
    Polygon[{{0.415274, 0.543890, 0.003984},{0.415035, 0.543154, 0.005853},{
      0.411485, 0.543716, 0.005853},{0.411485, 0.544490, 0.003984}}],
    Polygon[{{0.415035, 0.543154, 0.005853},{0.414708, 0.542148, 0.007578},{
      0.411485, 0.542659, 0.007578},{0.411485, 0.543716, 0.005853}}],
    Polygon[{{0.414708, 0.542148, 0.007578},{0.414302, 0.540899, 0.009116},{
      0.411485, 0.541345, 0.009116},{0.411485, 0.542659, 0.007578}}],
    Polygon[{{0.414302, 0.540899, 0.009116},{0.413827, 0.539436, 0.010430},{
      0.411485, 0.539807, 0.010430},{0.411485, 0.541345, 0.009116}}],
    Polygon[{{0.413827, 0.539436, 0.010430},{0.413294, 0.537796, 0.011487},{
      0.411485, 0.538082, 0.011487},{0.411485, 0.539807, 0.010430}}],
    Polygon[{{0.413294, 0.537796, 0.011487},{0.412716, 0.536018, 0.012261},{
      0.411485, 0.536213, 0.012261},{0.411485, 0.538082, 0.011487}}],
    Polygon[{{0.412716, 0.536018, 0.012261},{0.412108, 0.534147, 0.012733},{
      0.411485, 0.534246, 0.012733},{0.411485, 0.536213, 0.012261}}],
    Polygon[{{0.411485, 0.534246, -0.012733},{0.411485, 0.536213, -0.012261},{
      0.410254, 0.536018, -0.012261},{0.410862, 0.534147, -0.012733}}],
    Polygon[{{0.411485, 0.536213, -0.012261},{0.411485, 0.538082, -0.011487},{
      0.409677, 0.537796, -0.011487},{0.410254, 0.536018, -0.012261}}],
    Polygon[{{0.411485, 0.538082, -0.011487},{0.411485, 0.539807, -0.010430},{
      0.409144, 0.539436, -0.010430},{0.409677, 0.537796, -0.011487}}],
    Polygon[{{0.411485, 0.539807, -0.010430},{0.411485, 0.541345, -0.009116},{
      0.408668, 0.540899, -0.009116},{0.409144, 0.539436, -0.010430}}],
    Polygon[{{0.411485, 0.541345, -0.009116},{0.411485, 0.542659, -0.007578},{
      0.408262, 0.542148, -0.007578},{0.408668, 0.540899, -0.009116}}],
    Polygon[{{0.411485, 0.542659, -0.007578},{0.411485, 0.543716, -0.005853},{
      0.407936, 0.543154, -0.005853},{0.408262, 0.542148, -0.007578}}],
    Polygon[{{0.411485, 0.543716, -0.005853},{0.411485, 0.544490, -0.003984},{
      0.407696, 0.543890, -0.003984},{0.407936, 0.543154, -0.005853}}],
    Polygon[{{0.411485, 0.544490, -0.003984},{0.411485, 0.544962, -0.002017},{
      0.407550, 0.544339, -0.002017},{0.407696, 0.543890, -0.003984}}],
    Polygon[{{0.411485, 0.544962, -0.002017},{0.411485, 0.545121, 0.000000},{
      0.407501, 0.544490, 0.000000},{0.407550, 0.544339, -0.002017}}],
    Polygon[{{0.411485, 0.545121, 0.000000},{0.411485, 0.544962, 0.002017},{
      0.407550, 0.544339, 0.002017},{0.407501, 0.544490, 0.000000}}],
    Polygon[{{0.411485, 0.544962, 0.002017},{0.411485, 0.544490, 0.003984},{
      0.407696, 0.543890, 0.003984},{0.407550, 0.544339, 0.002017}}],
    Polygon[{{0.411485, 0.544490, 0.003984},{0.411485, 0.543716, 0.005853},{
      0.407936, 0.543154, 0.005853},{0.407696, 0.543890, 0.003984}}],
    Polygon[{{0.411485, 0.543716, 0.005853},{0.411485, 0.542659, 0.007578},{
      0.408262, 0.542148, 0.007578},{0.407936, 0.543154, 0.005853}}],
    Polygon[{{0.411485, 0.542659, 0.007578},{0.411485, 0.541345, 0.009116},{
      0.408668, 0.540899, 0.009116},{0.408262, 0.542148, 0.007578}}],
    Polygon[{{0.411485, 0.541345, 0.009116},{0.411485, 0.539807, 0.010430},{
      0.409144, 0.539436, 0.010430},{0.408668, 0.540899, 0.009116}}],
    Polygon[{{0.411485, 0.539807, 0.010430},{0.411485, 0.538082, 0.011487},{
      0.409677, 0.537796, 0.011487},{0.409144, 0.539436, 0.010430}}],
    Polygon[{{0.411485, 0.538082, 0.011487},{0.411485, 0.536213, 0.012261},{
      0.410254, 0.536018, 0.012261},{0.409677, 0.537796, 0.011487}}],
    Polygon[{{0.411485, 0.536213, 0.012261},{0.411485, 0.534246, 0.012733},{
      0.410862, 0.534147, 0.012733},{0.410254, 0.536018, 0.012261}}],
    Polygon[{{0.410862, 0.534147, -0.012733},{0.410254, 0.536018, -0.012261},{
      0.409144, 0.535452, -0.012261},{0.410300, 0.533861, -0.012733}}],
    Polygon[{{0.410254, 0.536018, -0.012261},{0.409677, 0.537796, -0.011487},{
      0.408045, 0.536964, -0.011487},{0.409144, 0.535452, -0.012261}}],
    Polygon[{{0.409677, 0.537796, -0.011487},{0.409144, 0.539436, -0.010430},{
      0.407031, 0.538360, -0.010430},{0.408045, 0.536964, -0.011487}}],
    Polygon[{{0.409144, 0.539436, -0.010430},{0.408668, 0.540899, -0.009116},{
      0.406127, 0.539604, -0.009116},{0.407031, 0.538360, -0.010430}}],
    Polygon[{{0.408668, 0.540899, -0.009116},{0.408262, 0.542148, -0.007578},{
      0.405355, 0.540667, -0.007578},{0.406127, 0.539604, -0.009116}}],
    Polygon[{{0.408262, 0.542148, -0.007578},{0.407936, 0.543154, -0.005853},{
      0.404734, 0.541522, -0.005853},{0.405355, 0.540667, -0.007578}}],
    Polygon[{{0.407936, 0.543154, -0.005853},{0.407696, 0.543890, -0.003984},{
      0.404278, 0.542148, -0.003984},{0.404734, 0.541522, -0.005853}}],
    Polygon[{{0.407696, 0.543890, -0.003984},{0.407550, 0.544339, -0.002017},{
      0.404001, 0.542530, -0.002017},{0.404278, 0.542148, -0.003984}}],
    Polygon[{{0.407550, 0.544339, -0.002017},{0.407501, 0.544490, 0.000000},{
      0.403908, 0.542659, 0.000000},{0.404001, 0.542530, -0.002017}}],
    Polygon[{{0.407501, 0.544490, 0.000000},{0.407550, 0.544339, 0.002017},{
      0.404001, 0.542530, 0.002017},{0.403908, 0.542659, 0.000000}}],
    Polygon[{{0.407550, 0.544339, 0.002017},{0.407696, 0.543890, 0.003984},{
      0.404278, 0.542148, 0.003984},{0.404001, 0.542530, 0.002017}}],
    Polygon[{{0.407696, 0.543890, 0.003984},{0.407936, 0.543154, 0.005853},{
      0.404734, 0.541522, 0.005853},{0.404278, 0.542148, 0.003984}}],
    Polygon[{{0.407936, 0.543154, 0.005853},{0.408262, 0.542148, 0.007578},{
      0.405355, 0.540667, 0.007578},{0.404734, 0.541522, 0.005853}}],
    Polygon[{{0.408262, 0.542148, 0.007578},{0.408668, 0.540899, 0.009116},{
      0.406127, 0.539604, 0.009116},{0.405355, 0.540667, 0.007578}}],
    Polygon[{{0.408668, 0.540899, 0.009116},{0.409144, 0.539436, 0.010430},{
      0.407031, 0.538360, 0.010430},{0.406127, 0.539604, 0.009116}}],
    Polygon[{{0.409144, 0.539436, 0.010430},{0.409677, 0.537796, 0.011487},{
      0.408045, 0.536964, 0.011487},{0.407031, 0.538360, 0.010430}}],
    Polygon[{{0.409677, 0.537796, 0.011487},{0.410254, 0.536018, 0.012261},{
      0.409144, 0.535452, 0.012261},{0.408045, 0.536964, 0.011487}}],
    Polygon[{{0.410254, 0.536018, 0.012261},{0.410862, 0.534147, 0.012733},{
      0.410300, 0.533861, 0.012733},{0.409144, 0.535452, 0.012261}}],
    Polygon[{{0.410300, 0.533861, -0.012733},{0.409144, 0.535452, -0.012261},{
      0.408262, 0.534571, -0.012261},{0.409854, 0.533415, -0.012733}}],
    Polygon[{{0.409144, 0.535452, -0.012261},{0.408045, 0.536964, -0.011487},{
      0.406750, 0.535669, -0.011487},{0.408262, 0.534571, -0.012261}}],
    Polygon[{{0.408045, 0.536964, -0.011487},{0.407031, 0.538360, -0.010430},{
      0.405355, 0.536683, -0.010430},{0.406750, 0.535669, -0.011487}}],
    Polygon[{{0.407031, 0.538360, -0.010430},{0.406127, 0.539604, -0.009116},{
      0.404110, 0.537587, -0.009116},{0.405355, 0.536683, -0.010430}}],
    Polygon[{{0.406127, 0.539604, -0.009116},{0.405355, 0.540667, -0.007578},{
      0.403047, 0.538360, -0.007578},{0.404110, 0.537587, -0.009116}}],
    Polygon[{{0.405355, 0.540667, -0.007578},{0.404734, 0.541522, -0.005853},{
      0.402192, 0.538981, -0.005853},{0.403047, 0.538360, -0.007578}}],
    Polygon[{{0.404734, 0.541522, -0.005853},{0.404278, 0.542148, -0.003984},{
      0.401566, 0.539436, -0.003984},{0.402192, 0.538981, -0.005853}}],
    Polygon[{{0.404278, 0.542148, -0.003984},{0.404001, 0.542530, -0.002017},{
      0.401184, 0.539714, -0.002017},{0.401566, 0.539436, -0.003984}}],
    Polygon[{{0.404001, 0.542530, -0.002017},{0.403908, 0.542659, 0.000000},{
      0.401056, 0.539807, 0.000000},{0.401184, 0.539714, -0.002017}}],
    Polygon[{{0.403908, 0.542659, 0.000000},{0.404001, 0.542530, 0.002017},{
      0.401184, 0.539714, 0.002017},{0.401056, 0.539807, 0.000000}}],
    Polygon[{{0.404001, 0.542530, 0.002017},{0.404278, 0.542148, 0.003984},{
      0.401566, 0.539436, 0.003984},{0.401184, 0.539714, 0.002017}}],
    Polygon[{{0.404278, 0.542148, 0.003984},{0.404734, 0.541522, 0.005853},{
      0.402192, 0.538981, 0.005853},{0.401566, 0.539436, 0.003984}}],
    Polygon[{{0.404734, 0.541522, 0.005853},{0.405355, 0.540667, 0.007578},{
      0.403047, 0.538360, 0.007578},{0.402192, 0.538981, 0.005853}}],
    Polygon[{{0.405355, 0.540667, 0.007578},{0.406127, 0.539604, 0.009116},{
      0.404110, 0.537587, 0.009116},{0.403047, 0.538360, 0.007578}}],
    Polygon[{{0.406127, 0.539604, 0.009116},{0.407031, 0.538360, 0.010430},{
      0.405355, 0.536683, 0.010430},{0.404110, 0.537587, 0.009116}}],
    Polygon[{{0.407031, 0.538360, 0.010430},{0.408045, 0.536964, 0.011487},{
      0.406750, 0.535669, 0.011487},{0.405355, 0.536683, 0.010430}}],
    Polygon[{{0.408045, 0.536964, 0.011487},{0.409144, 0.535452, 0.012261},{
      0.408262, 0.534571, 0.012261},{0.406750, 0.535669, 0.011487}}],
    Polygon[{{0.409144, 0.535452, 0.012261},{0.410300, 0.533861, 0.012733},{
      0.409854, 0.533415, 0.012733},{0.408262, 0.534571, 0.012261}}],
    Polygon[{{0.409854, 0.533415, -0.012733},{0.408262, 0.534571, -0.012261},{
      0.407696, 0.533460, -0.012261},{0.409567, 0.532852, -0.012733}}],
    Polygon[{{0.408262, 0.534571, -0.012261},{0.406750, 0.535669, -0.011487},{
      0.405919, 0.534038, -0.011487},{0.407696, 0.533460, -0.012261}}],
    Polygon[{{0.406750, 0.535669, -0.011487},{0.405355, 0.536683, -0.010430},{
      0.404278, 0.534571, -0.010430},{0.405919, 0.534038, -0.011487}}],
    Polygon[{{0.405355, 0.536683, -0.010430},{0.404110, 0.537587, -0.009116},{
      0.402816, 0.535046, -0.009116},{0.404278, 0.534571, -0.010430}}],
    Polygon[{{0.404110, 0.537587, -0.009116},{0.403047, 0.538360, -0.007578},{
      0.401566, 0.535452, -0.007578},{0.402816, 0.535046, -0.009116}}],
    Polygon[{{0.403047, 0.538360, -0.007578},{0.402192, 0.538981, -0.005853},{
      0.400561, 0.535779, -0.005853},{0.401566, 0.535452, -0.007578}}],
    Polygon[{{0.402192, 0.538981, -0.005853},{0.401566, 0.539436, -0.003984},{
      0.399825, 0.536018, -0.003984},{0.400561, 0.535779, -0.005853}}],
    Polygon[{{0.401566, 0.539436, -0.003984},{0.401184, 0.539714, -0.002017},{
      0.399375, 0.536164, -0.002017},{0.399825, 0.536018, -0.003984}}],
    Polygon[{{0.401184, 0.539714, -0.002017},{0.401056, 0.539807, 0.000000},{
      0.399224, 0.536213, 0.000000},{0.399375, 0.536164, -0.002017}}],
    Polygon[{{0.401056, 0.539807, 0.000000},{0.401184, 0.539714, 0.002017},{
      0.399375, 0.536164, 0.002017},{0.399224, 0.536213, 0.000000}}],
    Polygon[{{0.401184, 0.539714, 0.002017},{0.401566, 0.539436, 0.003984},{
      0.399825, 0.536018, 0.003984},{0.399375, 0.536164, 0.002017}}],
    Polygon[{{0.401566, 0.539436, 0.003984},{0.402192, 0.538981, 0.005853},{
      0.400561, 0.535779, 0.005853},{0.399825, 0.536018, 0.003984}}],
    Polygon[{{0.402192, 0.538981, 0.005853},{0.403047, 0.538360, 0.007578},{
      0.401566, 0.535452, 0.007578},{0.400561, 0.535779, 0.005853}}],
    Polygon[{{0.403047, 0.538360, 0.007578},{0.404110, 0.537587, 0.009116},{
      0.402816, 0.535046, 0.009116},{0.401566, 0.535452, 0.007578}}],
    Polygon[{{0.404110, 0.537587, 0.009116},{0.405355, 0.536683, 0.010430},{
      0.404278, 0.534571, 0.010430},{0.402816, 0.535046, 0.009116}}],
    Polygon[{{0.405355, 0.536683, 0.010430},{0.406750, 0.535669, 0.011487},{
      0.405919, 0.534038, 0.011487},{0.404278, 0.534571, 0.010430}}],
    Polygon[{{0.406750, 0.535669, 0.011487},{0.408262, 0.534571, 0.012261},{
      0.407696, 0.533460, 0.012261},{0.405919, 0.534038, 0.011487}}],
    Polygon[{{0.408262, 0.534571, 0.012261},{0.409854, 0.533415, 0.012733},{
      0.409567, 0.532852, 0.012733},{0.407696, 0.533460, 0.012261}}],
    Polygon[{{0.409567, 0.532852, -0.012733},{0.407696, 0.533460, -0.012261},{
      0.407501, 0.532229, -0.012261},{0.409468, 0.532229, -0.012733}}],
    Polygon[{{0.407696, 0.533460, -0.012261},{0.405919, 0.534038, -0.011487},{
      0.405632, 0.532229, -0.011487},{0.407501, 0.532229, -0.012261}}],
    Polygon[{{0.405919, 0.534038, -0.011487},{0.404278, 0.534571, -0.010430},{
      0.403908, 0.532229, -0.010430},{0.405632, 0.532229, -0.011487}}],
    Polygon[{{0.404278, 0.534571, -0.010430},{0.402816, 0.535046, -0.009116},{
      0.402369, 0.532229, -0.009116},{0.403908, 0.532229, -0.010430}}],
    Polygon[{{0.402816, 0.535046, -0.009116},{0.401566, 0.535452, -0.007578},{
      0.401056, 0.532229, -0.007578},{0.402369, 0.532229, -0.009116}}],
    Polygon[{{0.401566, 0.535452, -0.007578},{0.400561, 0.535779, -0.005853},{
      0.399999, 0.532229, -0.005853},{0.401056, 0.532229, -0.007578}}],
    Polygon[{{0.400561, 0.535779, -0.005853},{0.399825, 0.536018, -0.003984},{
      0.399224, 0.532229, -0.003984},{0.399999, 0.532229, -0.005853}}],
    Polygon[{{0.399825, 0.536018, -0.003984},{0.399375, 0.536164, -0.002017},{
      0.398752, 0.532229, -0.002017},{0.399224, 0.532229, -0.003984}}],
    Polygon[{{0.399375, 0.536164, -0.002017},{0.399224, 0.536213, 0.000000},{
      0.398593, 0.532229, 0.000000},{0.398752, 0.532229, -0.002017}}],
    Polygon[{{0.399224, 0.536213, 0.000000},{0.399375, 0.536164, 0.002017},{
      0.398752, 0.532229, 0.002017},{0.398593, 0.532229, 0.000000}}],
    Polygon[{{0.399375, 0.536164, 0.002017},{0.399825, 0.536018, 0.003984},{
      0.399224, 0.532229, 0.003984},{0.398752, 0.532229, 0.002017}}],
    Polygon[{{0.399825, 0.536018, 0.003984},{0.400561, 0.535779, 0.005853},{
      0.399999, 0.532229, 0.005853},{0.399224, 0.532229, 0.003984}}],
    Polygon[{{0.400561, 0.535779, 0.005853},{0.401566, 0.535452, 0.007578},{
      0.401056, 0.532229, 0.007578},{0.399999, 0.532229, 0.005853}}],
    Polygon[{{0.401566, 0.535452, 0.007578},{0.402816, 0.535046, 0.009116},{
      0.402369, 0.532229, 0.009116},{0.401056, 0.532229, 0.007578}}],
    Polygon[{{0.402816, 0.535046, 0.009116},{0.404278, 0.534571, 0.010430},{
      0.403908, 0.532229, 0.010430},{0.402369, 0.532229, 0.009116}}],
    Polygon[{{0.404278, 0.534571, 0.010430},{0.405919, 0.534038, 0.011487},{
      0.405632, 0.532229, 0.011487},{0.403908, 0.532229, 0.010430}}],
    Polygon[{{0.405919, 0.534038, 0.011487},{0.407696, 0.533460, 0.012261},{
      0.407501, 0.532229, 0.012261},{0.405632, 0.532229, 0.011487}}],
    Polygon[{{0.407696, 0.533460, 0.012261},{0.409567, 0.532852, 0.012733},{
      0.409468, 0.532229, 0.012733},{0.407501, 0.532229, 0.012261}}],
    Polygon[{{0.409468, 0.532229, -0.012733},{0.407501, 0.532229, -0.012261},{
      0.407696, 0.530998, -0.012261},{0.409567, 0.531606, -0.012733}}],
    Polygon[{{0.407501, 0.532229, -0.012261},{0.405632, 0.532229, -0.011487},{
      0.405919, 0.530421, -0.011487},{0.407696, 0.530998, -0.012261}}],
    Polygon[{{0.405632, 0.532229, -0.011487},{0.403908, 0.532229, -0.010430},{
      0.404278, 0.529888, -0.010430},{0.405919, 0.530421, -0.011487}}],
    Polygon[{{0.403908, 0.532229, -0.010430},{0.402369, 0.532229, -0.009116},{
      0.402816, 0.529412, -0.009116},{0.404278, 0.529888, -0.010430}}],
    Polygon[{{0.402369, 0.532229, -0.009116},{0.401056, 0.532229, -0.007578},{
      0.401566, 0.529006, -0.007578},{0.402816, 0.529412, -0.009116}}],
    Polygon[{{0.401056, 0.532229, -0.007578},{0.399999, 0.532229, -0.005853},{
      0.400561, 0.528680, -0.005853},{0.401566, 0.529006, -0.007578}}],
    Polygon[{{0.399999, 0.532229, -0.005853},{0.399224, 0.532229, -0.003984},{
      0.399825, 0.528440, -0.003984},{0.400561, 0.528680, -0.005853}}],
    Polygon[{{0.399224, 0.532229, -0.003984},{0.398752, 0.532229, -0.002017},{
      0.399375, 0.528295, -0.002017},{0.399825, 0.528440, -0.003984}}],
    Polygon[{{0.398752, 0.532229, -0.002017},{0.398593, 0.532229, 0.000000},{
      0.399224, 0.528246, 0.000000},{0.399375, 0.528295, -0.002017}}],
    Polygon[{{0.398593, 0.532229, 0.000000},{0.398752, 0.532229, 0.002017},{
      0.399375, 0.528295, 0.002017},{0.399224, 0.528246, 0.000000}}],
    Polygon[{{0.398752, 0.532229, 0.002017},{0.399224, 0.532229, 0.003984},{
      0.399825, 0.528440, 0.003984},{0.399375, 0.528295, 0.002017}}],
    Polygon[{{0.399224, 0.532229, 0.003984},{0.399999, 0.532229, 0.005853},{
      0.400561, 0.528680, 0.005853},{0.399825, 0.528440, 0.003984}}],
    Polygon[{{0.399999, 0.532229, 0.005853},{0.401056, 0.532229, 0.007578},{
      0.401566, 0.529006, 0.007578},{0.400561, 0.528680, 0.005853}}],
    Polygon[{{0.401056, 0.532229, 0.007578},{0.402369, 0.532229, 0.009116},{
      0.402816, 0.529412, 0.009116},{0.401566, 0.529006, 0.007578}}],
    Polygon[{{0.402369, 0.532229, 0.009116},{0.403908, 0.532229, 0.010430},{
      0.404278, 0.529888, 0.010430},{0.402816, 0.529412, 0.009116}}],
    Polygon[{{0.403908, 0.532229, 0.010430},{0.405632, 0.532229, 0.011487},{
      0.405919, 0.530421, 0.011487},{0.404278, 0.529888, 0.010430}}],
    Polygon[{{0.405632, 0.532229, 0.011487},{0.407501, 0.532229, 0.012261},{
      0.407696, 0.530998, 0.012261},{0.405919, 0.530421, 0.011487}}],
    Polygon[{{0.407501, 0.532229, 0.012261},{0.409468, 0.532229, 0.012733},{
      0.409567, 0.531606, 0.012733},{0.407696, 0.530998, 0.012261}}],
    Polygon[{{0.409567, 0.531606, -0.012733},{0.407696, 0.530998, -0.012261},{
      0.408262, 0.529888, -0.012261},{0.409854, 0.531044, -0.012733}}],
    Polygon[{{0.407696, 0.530998, -0.012261},{0.405919, 0.530421, -0.011487},{
      0.406750, 0.528789, -0.011487},{0.408262, 0.529888, -0.012261}}],
    Polygon[{{0.405919, 0.530421, -0.011487},{0.404278, 0.529888, -0.010430},{
      0.405355, 0.527775, -0.010430},{0.406750, 0.528789, -0.011487}}],
    Polygon[{{0.404278, 0.529888, -0.010430},{0.402816, 0.529412, -0.009116},{
      0.404110, 0.526871, -0.009116},{0.405355, 0.527775, -0.010430}}],
    Polygon[{{0.402816, 0.529412, -0.009116},{0.401566, 0.529006, -0.007578},{
      0.403047, 0.526099, -0.007578},{0.404110, 0.526871, -0.009116}}],
    Polygon[{{0.401566, 0.529006, -0.007578},{0.400561, 0.528680, -0.005853},{
      0.402192, 0.525478, -0.005853},{0.403047, 0.526099, -0.007578}}],
    Polygon[{{0.400561, 0.528680, -0.005853},{0.399825, 0.528440, -0.003984},{
      0.401566, 0.525023, -0.003984},{0.402192, 0.525478, -0.005853}}],
    Polygon[{{0.399825, 0.528440, -0.003984},{0.399375, 0.528295, -0.002017},{
      0.401184, 0.524745, -0.002017},{0.401566, 0.525023, -0.003984}}],
    Polygon[{{0.399375, 0.528295, -0.002017},{0.399224, 0.528246, 0.000000},{
      0.401056, 0.524652, 0.000000},{0.401184, 0.524745, -0.002017}}],
    Polygon[{{0.399224, 0.528246, 0.000000},{0.399375, 0.528295, 0.002017},{
      0.401184, 0.524745, 0.002017},{0.401056, 0.524652, 0.000000}}],
    Polygon[{{0.399375, 0.528295, 0.002017},{0.399825, 0.528440, 0.003984},{
      0.401566, 0.525023, 0.003984},{0.401184, 0.524745, 0.002017}}],
    Polygon[{{0.399825, 0.528440, 0.003984},{0.400561, 0.528680, 0.005853},{
      0.402192, 0.525478, 0.005853},{0.401566, 0.525023, 0.003984}}],
    Polygon[{{0.400561, 0.528680, 0.005853},{0.401566, 0.529006, 0.007578},{
      0.403047, 0.526099, 0.007578},{0.402192, 0.525478, 0.005853}}],
    Polygon[{{0.401566, 0.529006, 0.007578},{0.402816, 0.529412, 0.009116},{
      0.404110, 0.526871, 0.009116},{0.403047, 0.526099, 0.007578}}],
    Polygon[{{0.402816, 0.529412, 0.009116},{0.404278, 0.529888, 0.010430},{
      0.405355, 0.527775, 0.010430},{0.404110, 0.526871, 0.009116}}],
    Polygon[{{0.404278, 0.529888, 0.010430},{0.405919, 0.530421, 0.011487},{
      0.406750, 0.528789, 0.011487},{0.405355, 0.527775, 0.010430}}],
    Polygon[{{0.405919, 0.530421, 0.011487},{0.407696, 0.530998, 0.012261},{
      0.408262, 0.529888, 0.012261},{0.406750, 0.528789, 0.011487}}],
    Polygon[{{0.407696, 0.530998, 0.012261},{0.409567, 0.531606, 0.012733},{
      0.409854, 0.531044, 0.012733},{0.408262, 0.529888, 0.012261}}],
    Polygon[{{0.409854, 0.531044, -0.012733},{0.408262, 0.529888, -0.012261},{
      0.409144, 0.529006, -0.012261},{0.410300, 0.530598, -0.012733}}],
    Polygon[{{0.408262, 0.529888, -0.012261},{0.406750, 0.528789, -0.011487},{
      0.408045, 0.527494, -0.011487},{0.409144, 0.529006, -0.012261}}],
    Polygon[{{0.406750, 0.528789, -0.011487},{0.405355, 0.527775, -0.010430},{
      0.407031, 0.526099, -0.010430},{0.408045, 0.527494, -0.011487}}],
    Polygon[{{0.405355, 0.527775, -0.010430},{0.404110, 0.526871, -0.009116},{
      0.406127, 0.524854, -0.009116},{0.407031, 0.526099, -0.010430}}],
    Polygon[{{0.404110, 0.526871, -0.009116},{0.403047, 0.526099, -0.007578},{
      0.405355, 0.523792, -0.007578},{0.406127, 0.524854, -0.009116}}],
    Polygon[{{0.403047, 0.526099, -0.007578},{0.402192, 0.525478, -0.005853},{
      0.404734, 0.522936, -0.005853},{0.405355, 0.523792, -0.007578}}],
    Polygon[{{0.402192, 0.525478, -0.005853},{0.401566, 0.525023, -0.003984},{
      0.404278, 0.522310, -0.003984},{0.404734, 0.522936, -0.005853}}],
    Polygon[{{0.401566, 0.525023, -0.003984},{0.401184, 0.524745, -0.002017},{
      0.404001, 0.521928, -0.002017},{0.404278, 0.522310, -0.003984}}],
    Polygon[{{0.401184, 0.524745, -0.002017},{0.401056, 0.524652, 0.000000},{
      0.403908, 0.521800, 0.000000},{0.404001, 0.521928, -0.002017}}],
    Polygon[{{0.401056, 0.524652, 0.000000},{0.401184, 0.524745, 0.002017},{
      0.404001, 0.521928, 0.002017},{0.403908, 0.521800, 0.000000}}],
    Polygon[{{0.401184, 0.524745, 0.002017},{0.401566, 0.525023, 0.003984},{
      0.404278, 0.522310, 0.003984},{0.404001, 0.521928, 0.002017}}],
    Polygon[{{0.401566, 0.525023, 0.003984},{0.402192, 0.525478, 0.005853},{
      0.404734, 0.522936, 0.005853},{0.404278, 0.522310, 0.003984}}],
    Polygon[{{0.402192, 0.525478, 0.005853},{0.403047, 0.526099, 0.007578},{
      0.405355, 0.523792, 0.007578},{0.404734, 0.522936, 0.005853}}],
    Polygon[{{0.403047, 0.526099, 0.007578},{0.404110, 0.526871, 0.009116},{
      0.406127, 0.524854, 0.009116},{0.405355, 0.523792, 0.007578}}],
    Polygon[{{0.404110, 0.526871, 0.009116},{0.405355, 0.527775, 0.010430},{
      0.407031, 0.526099, 0.010430},{0.406127, 0.524854, 0.009116}}],
    Polygon[{{0.405355, 0.527775, 0.010430},{0.406750, 0.528789, 0.011487},{
      0.408045, 0.527494, 0.011487},{0.407031, 0.526099, 0.010430}}],
    Polygon[{{0.406750, 0.528789, 0.011487},{0.408262, 0.529888, 0.012261},{
      0.409144, 0.529006, 0.012261},{0.408045, 0.527494, 0.011487}}],
    Polygon[{{0.408262, 0.529888, 0.012261},{0.409854, 0.531044, 0.012733},{
      0.410300, 0.530598, 0.012733},{0.409144, 0.529006, 0.012261}}],
    Polygon[{{0.410300, 0.530598, -0.012733},{0.409144, 0.529006, -0.012261},{
      0.410254, 0.528440, -0.012261},{0.410862, 0.530311, -0.012733}}],
    Polygon[{{0.409144, 0.529006, -0.012261},{0.408045, 0.527494, -0.011487},{
      0.409677, 0.526663, -0.011487},{0.410254, 0.528440, -0.012261}}],
    Polygon[{{0.408045, 0.527494, -0.011487},{0.407031, 0.526099, -0.010430},{
      0.409144, 0.525023, -0.010430},{0.409677, 0.526663, -0.011487}}],
    Polygon[{{0.407031, 0.526099, -0.010430},{0.406127, 0.524854, -0.009116},{
      0.408668, 0.523560, -0.009116},{0.409144, 0.525023, -0.010430}}],
    Polygon[{{0.406127, 0.524854, -0.009116},{0.405355, 0.523792, -0.007578},{
      0.408262, 0.522310, -0.007578},{0.408668, 0.523560, -0.009116}}],
    Polygon[{{0.405355, 0.523792, -0.007578},{0.404734, 0.522936, -0.005853},{
      0.407936, 0.521305, -0.005853},{0.408262, 0.522310, -0.007578}}],
    Polygon[{{0.404734, 0.522936, -0.005853},{0.404278, 0.522310, -0.003984},{
      0.407696, 0.520569, -0.003984},{0.407936, 0.521305, -0.005853}}],
    Polygon[{{0.404278, 0.522310, -0.003984},{0.404001, 0.521928, -0.002017},{
      0.407550, 0.520119, -0.002017},{0.407696, 0.520569, -0.003984}}],
    Polygon[{{0.404001, 0.521928, -0.002017},{0.403908, 0.521800, 0.000000},{
      0.407501, 0.519969, 0.000000},{0.407550, 0.520119, -0.002017}}],
    Polygon[{{0.403908, 0.521800, 0.000000},{0.404001, 0.521928, 0.002017},{
      0.407550, 0.520119, 0.002017},{0.407501, 0.519969, 0.000000}}],
    Polygon[{{0.404001, 0.521928, 0.002017},{0.404278, 0.522310, 0.003984},{
      0.407696, 0.520569, 0.003984},{0.407550, 0.520119, 0.002017}}],
    Polygon[{{0.404278, 0.522310, 0.003984},{0.404734, 0.522936, 0.005853},{
      0.407936, 0.521305, 0.005853},{0.407696, 0.520569, 0.003984}}],
    Polygon[{{0.404734, 0.522936, 0.005853},{0.405355, 0.523792, 0.007578},{
      0.408262, 0.522310, 0.007578},{0.407936, 0.521305, 0.005853}}],
    Polygon[{{0.405355, 0.523792, 0.007578},{0.406127, 0.524854, 0.009116},{
      0.408668, 0.523560, 0.009116},{0.408262, 0.522310, 0.007578}}],
    Polygon[{{0.406127, 0.524854, 0.009116},{0.407031, 0.526099, 0.010430},{
      0.409144, 0.525023, 0.010430},{0.408668, 0.523560, 0.009116}}],
    Polygon[{{0.407031, 0.526099, 0.010430},{0.408045, 0.527494, 0.011487},{
      0.409677, 0.526663, 0.011487},{0.409144, 0.525023, 0.010430}}],
    Polygon[{{0.408045, 0.527494, 0.011487},{0.409144, 0.529006, 0.012261},{
      0.410254, 0.528440, 0.012261},{0.409677, 0.526663, 0.011487}}],
    Polygon[{{0.409144, 0.529006, 0.012261},{0.410300, 0.530598, 0.012733},{
      0.410862, 0.530311, 0.012733},{0.410254, 0.528440, 0.012261}}],
    Polygon[{{0.410862, 0.530311, -0.012733},{0.410254, 0.528440, -0.012261},{
      0.411485, 0.528246, -0.012261},{0.411485, 0.530213, -0.012733}}],
    Polygon[{{0.410254, 0.528440, -0.012261},{0.409677, 0.526663, -0.011487},{
      0.411485, 0.526377, -0.011487},{0.411485, 0.528246, -0.012261}}],
    Polygon[{{0.409677, 0.526663, -0.011487},{0.409144, 0.525023, -0.010430},{
      0.411485, 0.524652, -0.010430},{0.411485, 0.526377, -0.011487}}],
    Polygon[{{0.409144, 0.525023, -0.010430},{0.408668, 0.523560, -0.009116},{
      0.411485, 0.523113, -0.009116},{0.411485, 0.524652, -0.010430}}],
    Polygon[{{0.408668, 0.523560, -0.009116},{0.408262, 0.522310, -0.007578},{
      0.411485, 0.521800, -0.007578},{0.411485, 0.523113, -0.009116}}],
    Polygon[{{0.408262, 0.522310, -0.007578},{0.407936, 0.521305, -0.005853},{
      0.411485, 0.520743, -0.005853},{0.411485, 0.521800, -0.007578}}],
    Polygon[{{0.407936, 0.521305, -0.005853},{0.407696, 0.520569, -0.003984},{
      0.411485, 0.519969, -0.003984},{0.411485, 0.520743, -0.005853}}],
    Polygon[{{0.407696, 0.520569, -0.003984},{0.407550, 0.520119, -0.002017},{
      0.411485, 0.519496, -0.002017},{0.411485, 0.519969, -0.003984}}],
    Polygon[{{0.407550, 0.520119, -0.002017},{0.407501, 0.519969, 0.000000},{
      0.411485, 0.519338, 0.000000},{0.411485, 0.519496, -0.002017}}],
    Polygon[{{0.407501, 0.519969, 0.000000},{0.407550, 0.520119, 0.002017},{
      0.411485, 0.519496, 0.002017},{0.411485, 0.519338, 0.000000}}],
    Polygon[{{0.407550, 0.520119, 0.002017},{0.407696, 0.520569, 0.003984},{
      0.411485, 0.519969, 0.003984},{0.411485, 0.519496, 0.002017}}],
    Polygon[{{0.407696, 0.520569, 0.003984},{0.407936, 0.521305, 0.005853},{
      0.411485, 0.520743, 0.005853},{0.411485, 0.519969, 0.003984}}],
    Polygon[{{0.407936, 0.521305, 0.005853},{0.408262, 0.522310, 0.007578},{
      0.411485, 0.521800, 0.007578},{0.411485, 0.520743, 0.005853}}],
    Polygon[{{0.408262, 0.522310, 0.007578},{0.408668, 0.523560, 0.009116},{
      0.411485, 0.523113, 0.009116},{0.411485, 0.521800, 0.007578}}],
    Polygon[{{0.408668, 0.523560, 0.009116},{0.409144, 0.525023, 0.010430},{
      0.411485, 0.524652, 0.010430},{0.411485, 0.523113, 0.009116}}],
    Polygon[{{0.409144, 0.525023, 0.010430},{0.409677, 0.526663, 0.011487},{
      0.411485, 0.526377, 0.011487},{0.411485, 0.524652, 0.010430}}],
    Polygon[{{0.409677, 0.526663, 0.011487},{0.410254, 0.528440, 0.012261},{
      0.411485, 0.528246, 0.012261},{0.411485, 0.526377, 0.011487}}],
    Polygon[{{0.410254, 0.528440, 0.012261},{0.410862, 0.530311, 0.012733},{
      0.411485, 0.530213, 0.012733},{0.411485, 0.528246, 0.012261}}],
    Polygon[{{0.411485, 0.530213, -0.012733},{0.411485, 0.528246, -0.012261},{
      0.412716, 0.528440, -0.012261},{0.412108, 0.530311, -0.012733}}],
    Polygon[{{0.411485, 0.528246, -0.012261},{0.411485, 0.526377, -0.011487},{
      0.413294, 0.526663, -0.011487},{0.412716, 0.528440, -0.012261}}],
    Polygon[{{0.411485, 0.526377, -0.011487},{0.411485, 0.524652, -0.010430},{
      0.413827, 0.525023, -0.010430},{0.413294, 0.526663, -0.011487}}],
    Polygon[{{0.411485, 0.524652, -0.010430},{0.411485, 0.523113, -0.009116},{
      0.414302, 0.523560, -0.009116},{0.413827, 0.525023, -0.010430}}],
    Polygon[{{0.411485, 0.523113, -0.009116},{0.411485, 0.521800, -0.007578},{
      0.414708, 0.522310, -0.007578},{0.414302, 0.523560, -0.009116}}],
    Polygon[{{0.411485, 0.521800, -0.007578},{0.411485, 0.520743, -0.005853},{
      0.415035, 0.521305, -0.005853},{0.414708, 0.522310, -0.007578}}],
    Polygon[{{0.411485, 0.520743, -0.005853},{0.411485, 0.519969, -0.003984},{
      0.415274, 0.520569, -0.003984},{0.415035, 0.521305, -0.005853}}],
    Polygon[{{0.411485, 0.519969, -0.003984},{0.411485, 0.519496, -0.002017},{
      0.415420, 0.520119, -0.002017},{0.415274, 0.520569, -0.003984}}],
    Polygon[{{0.411485, 0.519496, -0.002017},{0.411485, 0.519338, 0.000000},{
      0.415469, 0.519969, 0.000000},{0.415420, 0.520119, -0.002017}}],
    Polygon[{{0.411485, 0.519338, 0.000000},{0.411485, 0.519496, 0.002017},{
      0.415420, 0.520119, 0.002017},{0.415469, 0.519969, 0.000000}}],
    Polygon[{{0.411485, 0.519496, 0.002017},{0.411485, 0.519969, 0.003984},{
      0.415274, 0.520569, 0.003984},{0.415420, 0.520119, 0.002017}}],
    Polygon[{{0.411485, 0.519969, 0.003984},{0.411485, 0.520743, 0.005853},{
      0.415035, 0.521305, 0.005853},{0.415274, 0.520569, 0.003984}}],
    Polygon[{{0.411485, 0.520743, 0.005853},{0.411485, 0.521800, 0.007578},{
      0.414708, 0.522310, 0.007578},{0.415035, 0.521305, 0.005853}}],
    Polygon[{{0.411485, 0.521800, 0.007578},{0.411485, 0.523113, 0.009116},{
      0.414302, 0.523560, 0.009116},{0.414708, 0.522310, 0.007578}}],
    Polygon[{{0.411485, 0.523113, 0.009116},{0.411485, 0.524652, 0.010430},{
      0.413827, 0.525023, 0.010430},{0.414302, 0.523560, 0.009116}}],
    Polygon[{{0.411485, 0.524652, 0.010430},{0.411485, 0.526377, 0.011487},{
      0.413294, 0.526663, 0.011487},{0.413827, 0.525023, 0.010430}}],
    Polygon[{{0.411485, 0.526377, 0.011487},{0.411485, 0.528246, 0.012261},{
      0.412716, 0.528440, 0.012261},{0.413294, 0.526663, 0.011487}}],
    Polygon[{{0.411485, 0.528246, 0.012261},{0.411485, 0.530213, 0.012733},{
      0.412108, 0.530311, 0.012733},{0.412716, 0.528440, 0.012261}}],
    Polygon[{{0.412108, 0.530311, -0.012733},{0.412716, 0.528440, -0.012261},{
      0.413827, 0.529006, -0.012261},{0.412671, 0.530598, -0.012733}}],
    Polygon[{{0.412716, 0.528440, -0.012261},{0.413294, 0.526663, -0.011487},{
      0.414925, 0.527494, -0.011487},{0.413827, 0.529006, -0.012261}}],
    Polygon[{{0.413294, 0.526663, -0.011487},{0.413827, 0.525023, -0.010430},{
      0.415939, 0.526099, -0.010430},{0.414925, 0.527494, -0.011487}}],
    Polygon[{{0.413827, 0.525023, -0.010430},{0.414302, 0.523560, -0.009116},{
      0.416843, 0.524854, -0.009116},{0.415939, 0.526099, -0.010430}}],
    Polygon[{{0.414302, 0.523560, -0.009116},{0.414708, 0.522310, -0.007578},{
      0.417616, 0.523792, -0.007578},{0.416843, 0.524854, -0.009116}}],
    Polygon[{{0.414708, 0.522310, -0.007578},{0.415035, 0.521305, -0.005853},{
      0.418237, 0.522936, -0.005853},{0.417616, 0.523792, -0.007578}}],
    Polygon[{{0.415035, 0.521305, -0.005853},{0.415274, 0.520569, -0.003984},{
      0.418692, 0.522310, -0.003984},{0.418237, 0.522936, -0.005853}}],
    Polygon[{{0.415274, 0.520569, -0.003984},{0.415420, 0.520119, -0.002017},{
      0.418969, 0.521928, -0.002017},{0.418692, 0.522310, -0.003984}}],
    Polygon[{{0.415420, 0.520119, -0.002017},{0.415469, 0.519969, 0.000000},{
      0.419063, 0.521800, 0.000000},{0.418969, 0.521928, -0.002017}}],
    Polygon[{{0.415469, 0.519969, 0.000000},{0.415420, 0.520119, 0.002017},{
      0.418969, 0.521928, 0.002017},{0.419063, 0.521800, 0.000000}}],
    Polygon[{{0.415420, 0.520119, 0.002017},{0.415274, 0.520569, 0.003984},{
      0.418692, 0.522310, 0.003984},{0.418969, 0.521928, 0.002017}}],
    Polygon[{{0.415274, 0.520569, 0.003984},{0.415035, 0.521305, 0.005853},{
      0.418237, 0.522936, 0.005853},{0.418692, 0.522310, 0.003984}}],
    Polygon[{{0.415035, 0.521305, 0.005853},{0.414708, 0.522310, 0.007578},{
      0.417616, 0.523792, 0.007578},{0.418237, 0.522936, 0.005853}}],
    Polygon[{{0.414708, 0.522310, 0.007578},{0.414302, 0.523560, 0.009116},{
      0.416843, 0.524854, 0.009116},{0.417616, 0.523792, 0.007578}}],
    Polygon[{{0.414302, 0.523560, 0.009116},{0.413827, 0.525023, 0.010430},{
      0.415939, 0.526099, 0.010430},{0.416843, 0.524854, 0.009116}}],
    Polygon[{{0.413827, 0.525023, 0.010430},{0.413294, 0.526663, 0.011487},{
      0.414925, 0.527494, 0.011487},{0.415939, 0.526099, 0.010430}}],
    Polygon[{{0.413294, 0.526663, 0.011487},{0.412716, 0.528440, 0.012261},{
      0.413827, 0.529006, 0.012261},{0.414925, 0.527494, 0.011487}}],
    Polygon[{{0.412716, 0.528440, 0.012261},{0.412108, 0.530311, 0.012733},{
      0.412671, 0.530598, 0.012733},{0.413827, 0.529006, 0.012261}}],
    Polygon[{{0.412671, 0.530598, -0.012733},{0.413827, 0.529006, -0.012261},{
      0.414708, 0.529888, -0.012261},{0.413117, 0.531044, -0.012733}}],
    Polygon[{{0.413827, 0.529006, -0.012261},{0.414925, 0.527494, -0.011487},{
      0.416220, 0.528789, -0.011487},{0.414708, 0.529888, -0.012261}}],
    Polygon[{{0.414925, 0.527494, -0.011487},{0.415939, 0.526099, -0.010430},{
      0.417616, 0.527775, -0.010430},{0.416220, 0.528789, -0.011487}}],
    Polygon[{{0.415939, 0.526099, -0.010430},{0.416843, 0.524854, -0.009116},{
      0.418860, 0.526871, -0.009116},{0.417616, 0.527775, -0.010430}}],
    Polygon[{{0.416843, 0.524854, -0.009116},{0.417616, 0.523792, -0.007578},{
      0.419923, 0.526099, -0.007578},{0.418860, 0.526871, -0.009116}}],
    Polygon[{{0.417616, 0.523792, -0.007578},{0.418237, 0.522936, -0.005853},{
      0.420778, 0.525478, -0.005853},{0.419923, 0.526099, -0.007578}}],
    Polygon[{{0.418237, 0.522936, -0.005853},{0.418692, 0.522310, -0.003984},{
      0.421404, 0.525023, -0.003984},{0.420778, 0.525478, -0.005853}}],
    Polygon[{{0.418692, 0.522310, -0.003984},{0.418969, 0.521928, -0.002017},{
      0.421786, 0.524745, -0.002017},{0.421404, 0.525023, -0.003984}}],
    Polygon[{{0.418969, 0.521928, -0.002017},{0.419063, 0.521800, 0.000000},{
      0.421915, 0.524652, 0.000000},{0.421786, 0.524745, -0.002017}}],
    Polygon[{{0.419063, 0.521800, 0.000000},{0.418969, 0.521928, 0.002017},{
      0.421786, 0.524745, 0.002017},{0.421915, 0.524652, 0.000000}}],
    Polygon[{{0.418969, 0.521928, 0.002017},{0.418692, 0.522310, 0.003984},{
      0.421404, 0.525023, 0.003984},{0.421786, 0.524745, 0.002017}}],
    Polygon[{{0.418692, 0.522310, 0.003984},{0.418237, 0.522936, 0.005853},{
      0.420778, 0.525478, 0.005853},{0.421404, 0.525023, 0.003984}}],
    Polygon[{{0.418237, 0.522936, 0.005853},{0.417616, 0.523792, 0.007578},{
      0.419923, 0.526099, 0.007578},{0.420778, 0.525478, 0.005853}}],
    Polygon[{{0.417616, 0.523792, 0.007578},{0.416843, 0.524854, 0.009116},{
      0.418860, 0.526871, 0.009116},{0.419923, 0.526099, 0.007578}}],
    Polygon[{{0.416843, 0.524854, 0.009116},{0.415939, 0.526099, 0.010430},{
      0.417616, 0.527775, 0.010430},{0.418860, 0.526871, 0.009116}}],
    Polygon[{{0.415939, 0.526099, 0.010430},{0.414925, 0.527494, 0.011487},{
      0.416220, 0.528789, 0.011487},{0.417616, 0.527775, 0.010430}}],
    Polygon[{{0.414925, 0.527494, 0.011487},{0.413827, 0.529006, 0.012261},{
      0.414708, 0.529888, 0.012261},{0.416220, 0.528789, 0.011487}}],
    Polygon[{{0.413827, 0.529006, 0.012261},{0.412671, 0.530598, 0.012733},{
      0.413117, 0.531044, 0.012733},{0.414708, 0.529888, 0.012261}}],
    Polygon[{{0.413117, 0.531044, -0.012733},{0.414708, 0.529888, -0.012261},{
      0.415274, 0.530998, -0.012261},{0.413403, 0.531606, -0.012733}}],
    Polygon[{{0.414708, 0.529888, -0.012261},{0.416220, 0.528789, -0.011487},{
      0.417051, 0.530421, -0.011487},{0.415274, 0.530998, -0.012261}}],
    Polygon[{{0.416220, 0.528789, -0.011487},{0.417616, 0.527775, -0.010430},{
      0.418692, 0.529888, -0.010430},{0.417051, 0.530421, -0.011487}}],
    Polygon[{{0.417616, 0.527775, -0.010430},{0.418860, 0.526871, -0.009116},{
      0.420155, 0.529412, -0.009116},{0.418692, 0.529888, -0.010430}}],
    Polygon[{{0.418860, 0.526871, -0.009116},{0.419923, 0.526099, -0.007578},{
      0.421404, 0.529006, -0.007578},{0.420155, 0.529412, -0.009116}}],
    Polygon[{{0.419923, 0.526099, -0.007578},{0.420778, 0.525478, -0.005853},{
      0.422410, 0.528680, -0.005853},{0.421404, 0.529006, -0.007578}}],
    Polygon[{{0.420778, 0.525478, -0.005853},{0.421404, 0.525023, -0.003984},{
      0.423146, 0.528440, -0.003984},{0.422410, 0.528680, -0.005853}}],
    Polygon[{{0.421404, 0.525023, -0.003984},{0.421786, 0.524745, -0.002017},{
      0.423595, 0.528295, -0.002017},{0.423146, 0.528440, -0.003984}}],
    Polygon[{{0.421786, 0.524745, -0.002017},{0.421915, 0.524652, 0.000000},{
      0.423746, 0.528246, 0.000000},{0.423595, 0.528295, -0.002017}}],
    Polygon[{{0.421915, 0.524652, 0.000000},{0.421786, 0.524745, 0.002017},{
      0.423595, 0.528295, 0.002017},{0.423746, 0.528246, 0.000000}}],
    Polygon[{{0.421786, 0.524745, 0.002017},{0.421404, 0.525023, 0.003984},{
      0.423146, 0.528440, 0.003984},{0.423595, 0.528295, 0.002017}}],
    Polygon[{{0.421404, 0.525023, 0.003984},{0.420778, 0.525478, 0.005853},{
      0.422410, 0.528680, 0.005853},{0.423146, 0.528440, 0.003984}}],
    Polygon[{{0.420778, 0.525478, 0.005853},{0.419923, 0.526099, 0.007578},{
      0.421404, 0.529006, 0.007578},{0.422410, 0.528680, 0.005853}}],
    Polygon[{{0.419923, 0.526099, 0.007578},{0.418860, 0.526871, 0.009116},{
      0.420155, 0.529412, 0.009116},{0.421404, 0.529006, 0.007578}}],
    Polygon[{{0.418860, 0.526871, 0.009116},{0.417616, 0.527775, 0.010430},{
      0.418692, 0.529888, 0.010430},{0.420155, 0.529412, 0.009116}}],
    Polygon[{{0.417616, 0.527775, 0.010430},{0.416220, 0.528789, 0.011487},{
      0.417051, 0.530421, 0.011487},{0.418692, 0.529888, 0.010430}}],
    Polygon[{{0.416220, 0.528789, 0.011487},{0.414708, 0.529888, 0.012261},{
      0.415274, 0.530998, 0.012261},{0.417051, 0.530421, 0.011487}}],
    Polygon[{{0.414708, 0.529888, 0.012261},{0.413117, 0.531044, 0.012733},{
      0.413403, 0.531606, 0.012733},{0.415274, 0.530998, 0.012261}}],
    Polygon[{{0.413403, 0.531606, -0.012733},{0.415274, 0.530998, -0.012261},{
      0.415469, 0.532229, -0.012261},{0.413502, 0.532229, -0.012733}}],
    Polygon[{{0.415274, 0.530998, -0.012261},{0.417051, 0.530421, -0.011487},{
      0.417338, 0.532229, -0.011487},{0.415469, 0.532229, -0.012261}}],
    Polygon[{{0.417051, 0.530421, -0.011487},{0.418692, 0.529888, -0.010430},{
      0.419063, 0.532229, -0.010430},{0.417338, 0.532229, -0.011487}}],
    Polygon[{{0.418692, 0.529888, -0.010430},{0.420155, 0.529412, -0.009116},{
      0.420601, 0.532229, -0.009116},{0.419063, 0.532229, -0.010430}}],
    Polygon[{{0.420155, 0.529412, -0.009116},{0.421404, 0.529006, -0.007578},{
      0.421915, 0.532229, -0.007578},{0.420601, 0.532229, -0.009116}}],
    Polygon[{{0.421404, 0.529006, -0.007578},{0.422410, 0.528680, -0.005853},{
      0.422972, 0.532229, -0.005853},{0.421915, 0.532229, -0.007578}}],
    Polygon[{{0.422410, 0.528680, -0.005853},{0.423146, 0.528440, -0.003984},{
      0.423746, 0.532229, -0.003984},{0.422972, 0.532229, -0.005853}}],
    Polygon[{{0.423146, 0.528440, -0.003984},{0.423595, 0.528295, -0.002017},{
      0.424218, 0.532229, -0.002017},{0.423746, 0.532229, -0.003984}}],
    Polygon[{{0.423595, 0.528295, -0.002017},{0.423746, 0.528246, 0.000000},{
      0.424377, 0.532229, 0.000000},{0.424218, 0.532229, -0.002017}}],
    Polygon[{{0.423746, 0.528246, 0.000000},{0.423595, 0.528295, 0.002017},{
      0.424218, 0.532229, 0.002017},{0.424377, 0.532229, 0.000000}}],
    Polygon[{{0.423595, 0.528295, 0.002017},{0.423146, 0.528440, 0.003984},{
      0.423746, 0.532229, 0.003984},{0.424218, 0.532229, 0.002017}}],
    Polygon[{{0.423146, 0.528440, 0.003984},{0.422410, 0.528680, 0.005853},{
      0.422972, 0.532229, 0.005853},{0.423746, 0.532229, 0.003984}}],
    Polygon[{{0.422410, 0.528680, 0.005853},{0.421404, 0.529006, 0.007578},{
      0.421915, 0.532229, 0.007578},{0.422972, 0.532229, 0.005853}}],
    Polygon[{{0.421404, 0.529006, 0.007578},{0.420155, 0.529412, 0.009116},{
      0.420601, 0.532229, 0.009116},{0.421915, 0.532229, 0.007578}}],
    Polygon[{{0.420155, 0.529412, 0.009116},{0.418692, 0.529888, 0.010430},{
      0.419063, 0.532229, 0.010430},{0.420601, 0.532229, 0.009116}}],
    Polygon[{{0.418692, 0.529888, 0.010430},{0.417051, 0.530421, 0.011487},{
      0.417338, 0.532229, 0.011487},{0.419063, 0.532229, 0.010430}}],
    Polygon[{{0.417051, 0.530421, 0.011487},{0.415274, 0.530998, 0.012261},{
      0.415469, 0.532229, 0.012261},{0.417338, 0.532229, 0.011487}}],
    Polygon[{{0.415274, 0.530998, 0.012261},{0.413403, 0.531606, 0.012733},{
      0.413502, 0.532229, 0.012733},{0.415469, 0.532229, 0.012261}}],
    Polygon[{{0.270959, 0.403521, -0.028615},{0.275379, 0.403521, -0.027554},{
      0.274941, 0.406288, -0.027554},{0.270737, 0.404922, -0.028615}}],
    Polygon[{{0.275379, 0.403521, -0.027554},{0.279579, 0.403521, -0.025814},{
      0.278936, 0.407586, -0.025814},{0.274941, 0.406288, -0.027554}}],
    Polygon[{{0.279579, 0.403521, -0.025814},{0.283456, 0.403521, -0.023438},{
      0.282622, 0.408783, -0.023438},{0.278936, 0.407586, -0.025814}}],
    Polygon[{{0.283456, 0.403521, -0.023438},{0.286912, 0.403521, -0.020486},{
      0.285910, 0.409852, -0.020486},{0.282622, 0.408783, -0.023438}}],
    Polygon[{{0.286912, 0.403521, -0.020486},{0.289865, 0.403521, -0.017029},{
      0.288718, 0.410764, -0.017029},{0.285910, 0.409852, -0.020486}}],
    Polygon[{{0.289865, 0.403521, -0.017029},{0.292240, 0.403521, -0.013153},{
      0.290977, 0.411498, -0.013153},{0.288718, 0.410764, -0.017029}}],
    Polygon[{{0.292240, 0.403521, -0.013153},{0.293980, 0.403521, -0.008953},{
      0.292631, 0.412036, -0.008953},{0.290977, 0.411498, -0.013153}}],
    Polygon[{{0.293980, 0.403521, -0.008953},{0.295041, 0.403521, -0.004532},{
      0.293641, 0.412364, -0.004532},{0.292631, 0.412036, -0.008953}}],
    Polygon[{{0.295041, 0.403521, -0.004532},{0.295398, 0.403521, 0.000000},{
      0.293980, 0.412474, 0.000000},{0.293641, 0.412364, -0.004532}}],
    Polygon[{{0.295398, 0.403521, 0.000000},{0.295041, 0.403521, 0.004532},{
      0.293641, 0.412364, 0.004532},{0.293980, 0.412474, 0.000000}}],
    Polygon[{{0.295041, 0.403521, 0.004532},{0.293980, 0.403521, 0.008953},{
      0.292631, 0.412036, 0.008953},{0.293641, 0.412364, 0.004532}}],
    Polygon[{{0.293980, 0.403521, 0.008953},{0.292240, 0.403521, 0.013153},{
      0.290977, 0.411498, 0.013153},{0.292631, 0.412036, 0.008953}}],
    Polygon[{{0.292240, 0.403521, 0.013153},{0.289865, 0.403521, 0.017029},{
      0.288718, 0.410764, 0.017029},{0.290977, 0.411498, 0.013153}}],
    Polygon[{{0.289865, 0.403521, 0.017029},{0.286912, 0.403521, 0.020486},{
      0.285910, 0.409852, 0.020486},{0.288718, 0.410764, 0.017029}}],
    Polygon[{{0.286912, 0.403521, 0.020486},{0.283456, 0.403521, 0.023438},{
      0.282622, 0.408783, 0.023438},{0.285910, 0.409852, 0.020486}}],
    Polygon[{{0.283456, 0.403521, 0.023438},{0.279579, 0.403521, 0.025814},{
      0.278936, 0.407586, 0.025814},{0.282622, 0.408783, 0.023438}}],
    Polygon[{{0.279579, 0.403521, 0.025814},{0.275379, 0.403521, 0.027554},{
      0.274941, 0.406288, 0.027554},{0.278936, 0.407586, 0.025814}}],
    Polygon[{{0.275379, 0.403521, 0.027554},{0.270959, 0.403521, 0.028615},{
      0.270737, 0.404922, 0.028615},{0.274941, 0.406288, 0.027554}}],
    Polygon[{{0.270737, 0.404922, -0.028615},{0.274941, 0.406288, -0.027554},{
      0.273669, 0.408783, -0.027554},{0.270093, 0.406185, -0.028615}}],
    Polygon[{{0.274941, 0.406288, -0.027554},{0.278936, 0.407586, -0.025814},{
      0.277067, 0.411252, -0.025814},{0.273669, 0.408783, -0.027554}}],
    Polygon[{{0.278936, 0.407586, -0.025814},{0.282622, 0.408783, -0.023438},{
      0.280203, 0.413531, -0.023438},{0.277067, 0.411252, -0.025814}}],
    Polygon[{{0.282622, 0.408783, -0.023438},{0.285910, 0.409852, -0.020486},{
      0.283000, 0.415563, -0.020486},{0.280203, 0.413531, -0.023438}}],
    Polygon[{{0.285910, 0.409852, -0.020486},{0.288718, 0.410764, -0.017029},{
      0.285389, 0.417298, -0.017029},{0.283000, 0.415563, -0.020486}}],
    Polygon[{{0.288718, 0.410764, -0.017029},{0.290977, 0.411498, -0.013153},{
      0.287310, 0.418694, -0.013153},{0.285389, 0.417298, -0.017029}}],
    Polygon[{{0.290977, 0.411498, -0.013153},{0.292631, 0.412036, -0.008953},{
      0.288718, 0.419717, -0.008953},{0.287310, 0.418694, -0.013153}}],
    Polygon[{{0.292631, 0.412036, -0.008953},{0.293641, 0.412364, -0.004532},{
      0.289576, 0.420341, -0.004532},{0.288718, 0.419717, -0.008953}}],
    Polygon[{{0.293641, 0.412364, -0.004532},{0.293980, 0.412474, 0.000000},{
      0.289865, 0.420550, 0.000000},{0.289576, 0.420341, -0.004532}}],
    Polygon[{{0.293980, 0.412474, 0.000000},{0.293641, 0.412364, 0.004532},{
      0.289576, 0.420341, 0.004532},{0.289865, 0.420550, 0.000000}}],
    Polygon[{{0.293641, 0.412364, 0.004532},{0.292631, 0.412036, 0.008953},{
      0.288718, 0.419717, 0.008953},{0.289576, 0.420341, 0.004532}}],
    Polygon[{{0.292631, 0.412036, 0.008953},{0.290977, 0.411498, 0.013153},{
      0.287310, 0.418694, 0.013153},{0.288718, 0.419717, 0.008953}}],
    Polygon[{{0.290977, 0.411498, 0.013153},{0.288718, 0.410764, 0.017029},{
      0.285389, 0.417298, 0.017029},{0.287310, 0.418694, 0.013153}}],
    Polygon[{{0.288718, 0.410764, 0.017029},{0.285910, 0.409852, 0.020486},{
      0.283000, 0.415563, 0.020486},{0.285389, 0.417298, 0.017029}}],
    Polygon[{{0.285910, 0.409852, 0.020486},{0.282622, 0.408783, 0.023438},{
      0.280203, 0.413531, 0.023438},{0.283000, 0.415563, 0.020486}}],
    Polygon[{{0.282622, 0.408783, 0.023438},{0.278936, 0.407586, 0.025814},{
      0.277067, 0.411252, 0.025814},{0.280203, 0.413531, 0.023438}}],
    Polygon[{{0.278936, 0.407586, 0.025814},{0.274941, 0.406288, 0.027554},{
      0.273669, 0.408783, 0.027554},{0.277067, 0.411252, 0.025814}}],
    Polygon[{{0.274941, 0.406288, 0.027554},{0.270737, 0.404922, 0.028615},{
      0.270093, 0.406185, 0.028615},{0.273669, 0.408783, 0.027554}}],
    Polygon[{{0.270093, 0.406185, -0.028615},{0.273669, 0.408783, -0.027554},{
      0.271689, 0.410764, -0.027554},{0.269090, 0.407188, -0.028615}}],
    Polygon[{{0.273669, 0.408783, -0.027554},{0.277067, 0.411252, -0.025814},{
      0.274157, 0.414162, -0.025814},{0.271689, 0.410764, -0.027554}}],
    Polygon[{{0.277067, 0.411252, -0.025814},{0.280203, 0.413531, -0.023438},{
      0.276436, 0.417298, -0.023438},{0.274157, 0.414162, -0.025814}}],
    Polygon[{{0.280203, 0.413531, -0.023438},{0.283000, 0.415563, -0.020486},{
      0.278468, 0.420095, -0.020486},{0.276436, 0.417298, -0.023438}}],
    Polygon[{{0.283000, 0.415563, -0.020486},{0.285389, 0.417298, -0.017029},{
      0.280203, 0.422483, -0.017029},{0.278468, 0.420095, -0.020486}}],
    Polygon[{{0.285389, 0.417298, -0.017029},{0.287310, 0.418694, -0.013153},{
      0.281599, 0.424405, -0.013153},{0.280203, 0.422483, -0.017029}}],
    Polygon[{{0.287310, 0.418694, -0.013153},{0.288718, 0.419717, -0.008953},{
      0.282622, 0.425812, -0.008953},{0.281599, 0.424405, -0.013153}}],
    Polygon[{{0.288718, 0.419717, -0.008953},{0.289576, 0.420341, -0.004532},{
      0.283246, 0.426671, -0.004532},{0.282622, 0.425812, -0.008953}}],
    Polygon[{{0.289576, 0.420341, -0.004532},{0.289865, 0.420550, 0.000000},{
      0.283456, 0.426960, 0.000000},{0.283246, 0.426671, -0.004532}}],
    Polygon[{{0.289865, 0.420550, 0.000000},{0.289576, 0.420341, 0.004532},{
      0.283246, 0.426671, 0.004532},{0.283456, 0.426960, 0.000000}}],
    Polygon[{{0.289576, 0.420341, 0.004532},{0.288718, 0.419717, 0.008953},{
      0.282622, 0.425812, 0.008953},{0.283246, 0.426671, 0.004532}}],
    Polygon[{{0.288718, 0.419717, 0.008953},{0.287310, 0.418694, 0.013153},{
      0.281599, 0.424405, 0.013153},{0.282622, 0.425812, 0.008953}}],
    Polygon[{{0.287310, 0.418694, 0.013153},{0.285389, 0.417298, 0.017029},{
      0.280203, 0.422483, 0.017029},{0.281599, 0.424405, 0.013153}}],
    Polygon[{{0.285389, 0.417298, 0.017029},{0.283000, 0.415563, 0.020486},{
      0.278468, 0.420095, 0.020486},{0.280203, 0.422483, 0.017029}}],
    Polygon[{{0.283000, 0.415563, 0.020486},{0.280203, 0.413531, 0.023438},{
      0.276436, 0.417298, 0.023438},{0.278468, 0.420095, 0.020486}}],
    Polygon[{{0.280203, 0.413531, 0.023438},{0.277067, 0.411252, 0.025814},{
      0.274157, 0.414162, 0.025814},{0.276436, 0.417298, 0.023438}}],
    Polygon[{{0.277067, 0.411252, 0.025814},{0.273669, 0.408783, 0.027554},{
      0.271689, 0.410764, 0.027554},{0.274157, 0.414162, 0.025814}}],
    Polygon[{{0.273669, 0.408783, 0.027554},{0.270093, 0.406185, 0.028615},{
      0.269090, 0.407188, 0.028615},{0.271689, 0.410764, 0.027554}}],
    Polygon[{{0.269090, 0.407188, -0.028615},{0.271689, 0.410764, -0.027554},{
      0.269193, 0.412036, -0.027554},{0.267827, 0.407831, -0.028615}}],
    Polygon[{{0.271689, 0.410764, -0.027554},{0.274157, 0.414162, -0.025814},{
      0.270491, 0.416030, -0.025814},{0.269193, 0.412036, -0.027554}}],
    Polygon[{{0.274157, 0.414162, -0.025814},{0.276436, 0.417298, -0.023438},{
      0.271689, 0.419717, -0.023438},{0.270491, 0.416030, -0.025814}}],
    Polygon[{{0.276436, 0.417298, -0.023438},{0.278468, 0.420095, -0.020486},{
      0.272757, 0.423004, -0.020486},{0.271689, 0.419717, -0.023438}}],
    Polygon[{{0.278468, 0.420095, -0.020486},{0.280203, 0.422483, -0.017029},{
      0.273669, 0.425812, -0.017029},{0.272757, 0.423004, -0.020486}}],
    Polygon[{{0.280203, 0.422483, -0.017029},{0.281599, 0.424405, -0.013153},{
      0.274403, 0.428072, -0.013153},{0.273669, 0.425812, -0.017029}}],
    Polygon[{{0.281599, 0.424405, -0.013153},{0.282622, 0.425812, -0.008953},{
      0.274941, 0.429726, -0.008953},{0.274403, 0.428072, -0.013153}}],
    Polygon[{{0.282622, 0.425812, -0.008953},{0.283246, 0.426671, -0.004532},{
      0.275269, 0.430735, -0.004532},{0.274941, 0.429726, -0.008953}}],
    Polygon[{{0.283246, 0.426671, -0.004532},{0.283456, 0.426960, 0.000000},{
      0.275379, 0.431075, 0.000000},{0.275269, 0.430735, -0.004532}}],
    Polygon[{{0.283456, 0.426960, 0.000000},{0.283246, 0.426671, 0.004532},{
      0.275269, 0.430735, 0.004532},{0.275379, 0.431075, 0.000000}}],
    Polygon[{{0.283246, 0.426671, 0.004532},{0.282622, 0.425812, 0.008953},{
      0.274941, 0.429726, 0.008953},{0.275269, 0.430735, 0.004532}}],
    Polygon[{{0.282622, 0.425812, 0.008953},{0.281599, 0.424405, 0.013153},{
      0.274403, 0.428072, 0.013153},{0.274941, 0.429726, 0.008953}}],
    Polygon[{{0.281599, 0.424405, 0.013153},{0.280203, 0.422483, 0.017029},{
      0.273669, 0.425812, 0.017029},{0.274403, 0.428072, 0.013153}}],
    Polygon[{{0.280203, 0.422483, 0.017029},{0.278468, 0.420095, 0.020486},{
      0.272757, 0.423004, 0.020486},{0.273669, 0.425812, 0.017029}}],
    Polygon[{{0.278468, 0.420095, 0.020486},{0.276436, 0.417298, 0.023438},{
      0.271689, 0.419717, 0.023438},{0.272757, 0.423004, 0.020486}}],
    Polygon[{{0.276436, 0.417298, 0.023438},{0.274157, 0.414162, 0.025814},{
      0.270491, 0.416030, 0.025814},{0.271689, 0.419717, 0.023438}}],
    Polygon[{{0.274157, 0.414162, 0.025814},{0.271689, 0.410764, 0.027554},{
      0.269193, 0.412036, 0.027554},{0.270491, 0.416030, 0.025814}}],
    Polygon[{{0.271689, 0.410764, 0.027554},{0.269090, 0.407188, 0.028615},{
      0.267827, 0.407831, 0.028615},{0.269193, 0.412036, 0.027554}}],
    Polygon[{{0.267827, 0.407831, -0.028615},{0.269193, 0.412036, -0.027554},{
      0.266426, 0.412474, -0.027554},{0.266426, 0.408053, -0.028615}}],
    Polygon[{{0.269193, 0.412036, -0.027554},{0.270491, 0.416030, -0.025814},{
      0.266426, 0.416674, -0.025814},{0.266426, 0.412474, -0.027554}}],
    Polygon[{{0.270491, 0.416030, -0.025814},{0.271689, 0.419717, -0.023438},{
      0.266426, 0.420550, -0.023438},{0.266426, 0.416674, -0.025814}}],
    Polygon[{{0.271689, 0.419717, -0.023438},{0.272757, 0.423004, -0.020486},{
      0.266426, 0.424007, -0.020486},{0.266426, 0.420550, -0.023438}}],
    Polygon[{{0.272757, 0.423004, -0.020486},{0.273669, 0.425812, -0.017029},{
      0.266426, 0.426960, -0.017029},{0.266426, 0.424007, -0.020486}}],
    Polygon[{{0.273669, 0.425812, -0.017029},{0.274403, 0.428072, -0.013153},{
      0.266426, 0.429335, -0.013153},{0.266426, 0.426960, -0.017029}}],
    Polygon[{{0.274403, 0.428072, -0.013153},{0.274941, 0.429726, -0.008953},{
      0.266426, 0.431075, -0.008953},{0.266426, 0.429335, -0.013153}}],
    Polygon[{{0.274941, 0.429726, -0.008953},{0.275269, 0.430735, -0.004532},{
      0.266426, 0.432136, -0.004532},{0.266426, 0.431075, -0.008953}}],
    Polygon[{{0.275269, 0.430735, -0.004532},{0.275379, 0.431075, 0.000000},{
      0.266426, 0.432493, 0.000000},{0.266426, 0.432136, -0.004532}}],
    Polygon[{{0.275379, 0.431075, 0.000000},{0.275269, 0.430735, 0.004532},{
      0.266426, 0.432136, 0.004532},{0.266426, 0.432493, 0.000000}}],
    Polygon[{{0.275269, 0.430735, 0.004532},{0.274941, 0.429726, 0.008953},{
      0.266426, 0.431075, 0.008953},{0.266426, 0.432136, 0.004532}}],
    Polygon[{{0.274941, 0.429726, 0.008953},{0.274403, 0.428072, 0.013153},{
      0.266426, 0.429335, 0.013153},{0.266426, 0.431075, 0.008953}}],
    Polygon[{{0.274403, 0.428072, 0.013153},{0.273669, 0.425812, 0.017029},{
      0.266426, 0.426960, 0.017029},{0.266426, 0.429335, 0.013153}}],
    Polygon[{{0.273669, 0.425812, 0.017029},{0.272757, 0.423004, 0.020486},{
      0.266426, 0.424007, 0.020486},{0.266426, 0.426960, 0.017029}}],
    Polygon[{{0.272757, 0.423004, 0.020486},{0.271689, 0.419717, 0.023438},{
      0.266426, 0.420550, 0.023438},{0.266426, 0.424007, 0.020486}}],
    Polygon[{{0.271689, 0.419717, 0.023438},{0.270491, 0.416030, 0.025814},{
      0.266426, 0.416674, 0.025814},{0.266426, 0.420550, 0.023438}}],
    Polygon[{{0.270491, 0.416030, 0.025814},{0.269193, 0.412036, 0.027554},{
      0.266426, 0.412474, 0.027554},{0.266426, 0.416674, 0.025814}}],
    Polygon[{{0.269193, 0.412036, 0.027554},{0.267827, 0.407831, 0.028615},{
      0.266426, 0.408053, 0.028615},{0.266426, 0.412474, 0.027554}}],
    Polygon[{{0.266426, 0.408053, -0.028615},{0.266426, 0.412474, -0.027554},{
      0.263660, 0.412036, -0.027554},{0.265026, 0.407831, -0.028615}}],
    Polygon[{{0.266426, 0.412474, -0.027554},{0.266426, 0.416674, -0.025814},{
      0.262362, 0.416030, -0.025814},{0.263660, 0.412036, -0.027554}}],
    Polygon[{{0.266426, 0.416674, -0.025814},{0.266426, 0.420550, -0.023438},{
      0.261164, 0.419717, -0.023438},{0.262362, 0.416030, -0.025814}}],
    Polygon[{{0.266426, 0.420550, -0.023438},{0.266426, 0.424007, -0.020486},{
      0.260096, 0.423004, -0.020486},{0.261164, 0.419717, -0.023438}}],
    Polygon[{{0.266426, 0.424007, -0.020486},{0.266426, 0.426960, -0.017029},{
      0.259184, 0.425812, -0.017029},{0.260096, 0.423004, -0.020486}}],
    Polygon[{{0.266426, 0.426960, -0.017029},{0.266426, 0.429335, -0.013153},{
      0.258450, 0.428072, -0.013153},{0.259184, 0.425812, -0.017029}}],
    Polygon[{{0.266426, 0.429335, -0.013153},{0.266426, 0.431075, -0.008953},{
      0.257912, 0.429726, -0.008953},{0.258450, 0.428072, -0.013153}}],
    Polygon[{{0.266426, 0.431075, -0.008953},{0.266426, 0.432136, -0.004532},{
      0.257584, 0.430735, -0.004532},{0.257912, 0.429726, -0.008953}}],
    Polygon[{{0.266426, 0.432136, -0.004532},{0.266426, 0.432493, 0.000000},{
      0.257474, 0.431075, 0.000000},{0.257584, 0.430735, -0.004532}}],
    Polygon[{{0.266426, 0.432493, 0.000000},{0.266426, 0.432136, 0.004532},{
      0.257584, 0.430735, 0.004532},{0.257474, 0.431075, 0.000000}}],
    Polygon[{{0.266426, 0.432136, 0.004532},{0.266426, 0.431075, 0.008953},{
      0.257912, 0.429726, 0.008953},{0.257584, 0.430735, 0.004532}}],
    Polygon[{{0.266426, 0.431075, 0.008953},{0.266426, 0.429335, 0.013153},{
      0.258450, 0.428072, 0.013153},{0.257912, 0.429726, 0.008953}}],
    Polygon[{{0.266426, 0.429335, 0.013153},{0.266426, 0.426960, 0.017029},{
      0.259184, 0.425812, 0.017029},{0.258450, 0.428072, 0.013153}}],
    Polygon[{{0.266426, 0.426960, 0.017029},{0.266426, 0.424007, 0.020486},{
      0.260096, 0.423004, 0.020486},{0.259184, 0.425812, 0.017029}}],
    Polygon[{{0.266426, 0.424007, 0.020486},{0.266426, 0.420550, 0.023438},{
      0.261164, 0.419717, 0.023438},{0.260096, 0.423004, 0.020486}}],
    Polygon[{{0.266426, 0.420550, 0.023438},{0.266426, 0.416674, 0.025814},{
      0.262362, 0.416030, 0.025814},{0.261164, 0.419717, 0.023438}}],
    Polygon[{{0.266426, 0.416674, 0.025814},{0.266426, 0.412474, 0.027554},{
      0.263660, 0.412036, 0.027554},{0.262362, 0.416030, 0.025814}}],
    Polygon[{{0.266426, 0.412474, 0.027554},{0.266426, 0.408053, 0.028615},{
      0.265026, 0.407831, 0.028615},{0.263660, 0.412036, 0.027554}}],
    Polygon[{{0.265026, 0.407831, -0.028615},{0.263660, 0.412036, -0.027554},{
      0.261164, 0.410764, -0.027554},{0.263763, 0.407188, -0.028615}}],
    Polygon[{{0.263660, 0.412036, -0.027554},{0.262362, 0.416030, -0.025814},{
      0.258695, 0.414162, -0.025814},{0.261164, 0.410764, -0.027554}}],
    Polygon[{{0.262362, 0.416030, -0.025814},{0.261164, 0.419717, -0.023438},{
      0.256417, 0.417298, -0.023438},{0.258695, 0.414162, -0.025814}}],
    Polygon[{{0.261164, 0.419717, -0.023438},{0.260096, 0.423004, -0.020486},{
      0.254385, 0.420095, -0.020486},{0.256417, 0.417298, -0.023438}}],
    Polygon[{{0.260096, 0.423004, -0.020486},{0.259184, 0.425812, -0.017029},{
      0.252650, 0.422483, -0.017029},{0.254385, 0.420095, -0.020486}}],
    Polygon[{{0.259184, 0.425812, -0.017029},{0.258450, 0.428072, -0.013153},{
      0.251254, 0.424405, -0.013153},{0.252650, 0.422483, -0.017029}}],
    Polygon[{{0.258450, 0.428072, -0.013153},{0.257912, 0.429726, -0.008953},{
      0.250231, 0.425812, -0.008953},{0.251254, 0.424405, -0.013153}}],
    Polygon[{{0.257912, 0.429726, -0.008953},{0.257584, 0.430735, -0.004532},{
      0.249607, 0.426671, -0.004532},{0.250231, 0.425812, -0.008953}}],
    Polygon[{{0.257584, 0.430735, -0.004532},{0.257474, 0.431075, 0.000000},{
      0.249397, 0.426960, 0.000000},{0.249607, 0.426671, -0.004532}}],
    Polygon[{{0.257474, 0.431075, 0.000000},{0.257584, 0.430735, 0.004532},{
      0.249607, 0.426671, 0.004532},{0.249397, 0.426960, 0.000000}}],
    Polygon[{{0.257584, 0.430735, 0.004532},{0.257912, 0.429726, 0.008953},{
      0.250231, 0.425812, 0.008953},{0.249607, 0.426671, 0.004532}}],
    Polygon[{{0.257912, 0.429726, 0.008953},{0.258450, 0.428072, 0.013153},{
      0.251254, 0.424405, 0.013153},{0.250231, 0.425812, 0.008953}}],
    Polygon[{{0.258450, 0.428072, 0.013153},{0.259184, 0.425812, 0.017029},{
      0.252650, 0.422483, 0.017029},{0.251254, 0.424405, 0.013153}}],
    Polygon[{{0.259184, 0.425812, 0.017029},{0.260096, 0.423004, 0.020486},{
      0.254385, 0.420095, 0.020486},{0.252650, 0.422483, 0.017029}}],
    Polygon[{{0.260096, 0.423004, 0.020486},{0.261164, 0.419717, 0.023438},{
      0.256417, 0.417298, 0.023438},{0.254385, 0.420095, 0.020486}}],
    Polygon[{{0.261164, 0.419717, 0.023438},{0.262362, 0.416030, 0.025814},{
      0.258695, 0.414162, 0.025814},{0.256417, 0.417298, 0.023438}}],
    Polygon[{{0.262362, 0.416030, 0.025814},{0.263660, 0.412036, 0.027554},{
      0.261164, 0.410764, 0.027554},{0.258695, 0.414162, 0.025814}}],
    Polygon[{{0.263660, 0.412036, 0.027554},{0.265026, 0.407831, 0.028615},{
      0.263763, 0.407188, 0.028615},{0.261164, 0.410764, 0.027554}}],
    Polygon[{{0.263763, 0.407188, -0.028615},{0.261164, 0.410764, -0.027554},{
      0.259184, 0.408783, -0.027554},{0.262760, 0.406185, -0.028615}}],
    Polygon[{{0.261164, 0.410764, -0.027554},{0.258695, 0.414162, -0.025814},{
      0.255786, 0.411252, -0.025814},{0.259184, 0.408783, -0.027554}}],
    Polygon[{{0.258695, 0.414162, -0.025814},{0.256417, 0.417298, -0.023438},{
      0.252650, 0.413531, -0.023438},{0.255786, 0.411252, -0.025814}}],
    Polygon[{{0.256417, 0.417298, -0.023438},{0.254385, 0.420095, -0.020486},{
      0.249853, 0.415563, -0.020486},{0.252650, 0.413531, -0.023438}}],
    Polygon[{{0.254385, 0.420095, -0.020486},{0.252650, 0.422483, -0.017029},{
      0.247464, 0.417298, -0.017029},{0.249853, 0.415563, -0.020486}}],
    Polygon[{{0.252650, 0.422483, -0.017029},{0.251254, 0.424405, -0.013153},{
      0.245543, 0.418694, -0.013153},{0.247464, 0.417298, -0.017029}}],
    Polygon[{{0.251254, 0.424405, -0.013153},{0.250231, 0.425812, -0.008953},{
      0.244135, 0.419717, -0.008953},{0.245543, 0.418694, -0.013153}}],
    Polygon[{{0.250231, 0.425812, -0.008953},{0.249607, 0.426671, -0.004532},{
      0.243277, 0.420341, -0.004532},{0.244135, 0.419717, -0.008953}}],
    Polygon[{{0.249607, 0.426671, -0.004532},{0.249397, 0.426960, 0.000000},{
      0.242988, 0.420550, 0.000000},{0.243277, 0.420341, -0.004532}}],
    Polygon[{{0.249397, 0.426960, 0.000000},{0.249607, 0.426671, 0.004532},{
      0.243277, 0.420341, 0.004532},{0.242988, 0.420550, 0.000000}}],
    Polygon[{{0.249607, 0.426671, 0.004532},{0.250231, 0.425812, 0.008953},{
      0.244135, 0.419717, 0.008953},{0.243277, 0.420341, 0.004532}}],
    Polygon[{{0.250231, 0.425812, 0.008953},{0.251254, 0.424405, 0.013153},{
      0.245543, 0.418694, 0.013153},{0.244135, 0.419717, 0.008953}}],
    Polygon[{{0.251254, 0.424405, 0.013153},{0.252650, 0.422483, 0.017029},{
      0.247464, 0.417298, 0.017029},{0.245543, 0.418694, 0.013153}}],
    Polygon[{{0.252650, 0.422483, 0.017029},{0.254385, 0.420095, 0.020486},{
      0.249853, 0.415563, 0.020486},{0.247464, 0.417298, 0.017029}}],
    Polygon[{{0.254385, 0.420095, 0.020486},{0.256417, 0.417298, 0.023438},{
      0.252650, 0.413531, 0.023438},{0.249853, 0.415563, 0.020486}}],
    Polygon[{{0.256417, 0.417298, 0.023438},{0.258695, 0.414162, 0.025814},{
      0.255786, 0.411252, 0.025814},{0.252650, 0.413531, 0.023438}}],
    Polygon[{{0.258695, 0.414162, 0.025814},{0.261164, 0.410764, 0.027554},{
      0.259184, 0.408783, 0.027554},{0.255786, 0.411252, 0.025814}}],
    Polygon[{{0.261164, 0.410764, 0.027554},{0.263763, 0.407188, 0.028615},{
      0.262760, 0.406185, 0.028615},{0.259184, 0.408783, 0.027554}}],
    Polygon[{{0.262760, 0.406185, -0.028615},{0.259184, 0.408783, -0.027554},{
      0.257912, 0.406288, -0.027554},{0.262116, 0.404922, -0.028615}}],
    Polygon[{{0.259184, 0.408783, -0.027554},{0.255786, 0.411252, -0.025814},{
      0.253917, 0.407586, -0.025814},{0.257912, 0.406288, -0.027554}}],
    Polygon[{{0.255786, 0.411252, -0.025814},{0.252650, 0.413531, -0.023438},{
      0.250231, 0.408783, -0.023438},{0.253917, 0.407586, -0.025814}}],
    Polygon[{{0.252650, 0.413531, -0.023438},{0.249853, 0.415563, -0.020486},{
      0.246943, 0.409852, -0.020486},{0.250231, 0.408783, -0.023438}}],
    Polygon[{{0.249853, 0.415563, -0.020486},{0.247464, 0.417298, -0.017029},{
      0.244135, 0.410764, -0.017029},{0.246943, 0.409852, -0.020486}}],
    Polygon[{{0.247464, 0.417298, -0.017029},{0.245543, 0.418694, -0.013153},{
      0.241876, 0.411498, -0.013153},{0.244135, 0.410764, -0.017029}}],
    Polygon[{{0.245543, 0.418694, -0.013153},{0.244135, 0.419717, -0.008953},{
      0.240222, 0.412036, -0.008953},{0.241876, 0.411498, -0.013153}}],
    Polygon[{{0.244135, 0.419717, -0.008953},{0.243277, 0.420341, -0.004532},{
      0.239212, 0.412364, -0.004532},{0.240222, 0.412036, -0.008953}}],
    Polygon[{{0.243277, 0.420341, -0.004532},{0.242988, 0.420550, 0.000000},{
      0.238873, 0.412474, 0.000000},{0.239212, 0.412364, -0.004532}}],
    Polygon[{{0.242988, 0.420550, 0.000000},{0.243277, 0.420341, 0.004532},{
      0.239212, 0.412364, 0.004532},{0.238873, 0.412474, 0.000000}}],
    Polygon[{{0.243277, 0.420341, 0.004532},{0.244135, 0.419717, 0.008953},{
      0.240222, 0.412036, 0.008953},{0.239212, 0.412364, 0.004532}}],
    Polygon[{{0.244135, 0.419717, 0.008953},{0.245543, 0.418694, 0.013153},{
      0.241876, 0.411498, 0.013153},{0.240222, 0.412036, 0.008953}}],
    Polygon[{{0.245543, 0.418694, 0.013153},{0.247464, 0.417298, 0.017029},{
      0.244135, 0.410764, 0.017029},{0.241876, 0.411498, 0.013153}}],
    Polygon[{{0.247464, 0.417298, 0.017029},{0.249853, 0.415563, 0.020486},{
      0.246943, 0.409852, 0.020486},{0.244135, 0.410764, 0.017029}}],
    Polygon[{{0.249853, 0.415563, 0.020486},{0.252650, 0.413531, 0.023438},{
      0.250231, 0.408783, 0.023438},{0.246943, 0.409852, 0.020486}}],
    Polygon[{{0.252650, 0.413531, 0.023438},{0.255786, 0.411252, 0.025814},{
      0.253917, 0.407586, 0.025814},{0.250231, 0.408783, 0.023438}}],
    Polygon[{{0.255786, 0.411252, 0.025814},{0.259184, 0.408783, 0.027554},{
      0.257912, 0.406288, 0.027554},{0.253917, 0.407586, 0.025814}}],
    Polygon[{{0.259184, 0.408783, 0.027554},{0.262760, 0.406185, 0.028615},{
      0.262116, 0.404922, 0.028615},{0.257912, 0.406288, 0.027554}}],
    Polygon[{{0.262116, 0.404922, -0.028615},{0.257912, 0.406288, -0.027554},{
      0.257474, 0.403521, -0.027554},{0.261894, 0.403521, -0.028615}}],
    Polygon[{{0.257912, 0.406288, -0.027554},{0.253917, 0.407586, -0.025814},{
      0.253274, 0.403521, -0.025814},{0.257474, 0.403521, -0.027554}}],
    Polygon[{{0.253917, 0.407586, -0.025814},{0.250231, 0.408783, -0.023438},{
      0.249397, 0.403521, -0.023438},{0.253274, 0.403521, -0.025814}}],
    Polygon[{{0.250231, 0.408783, -0.023438},{0.246943, 0.409852, -0.020486},{
      0.245941, 0.403521, -0.020486},{0.249397, 0.403521, -0.023438}}],
    Polygon[{{0.246943, 0.409852, -0.020486},{0.244135, 0.410764, -0.017029},{
      0.242988, 0.403521, -0.017029},{0.245941, 0.403521, -0.020486}}],
    Polygon[{{0.244135, 0.410764, -0.017029},{0.241876, 0.411498, -0.013153},{
      0.240613, 0.403521, -0.013153},{0.242988, 0.403521, -0.017029}}],
    Polygon[{{0.241876, 0.411498, -0.013153},{0.240222, 0.412036, -0.008953},{
      0.238873, 0.403521, -0.008953},{0.240613, 0.403521, -0.013153}}],
    Polygon[{{0.240222, 0.412036, -0.008953},{0.239212, 0.412364, -0.004532},{
      0.237812, 0.403521, -0.004532},{0.238873, 0.403521, -0.008953}}],
    Polygon[{{0.239212, 0.412364, -0.004532},{0.238873, 0.412474, 0.000000},{
      0.237455, 0.403521, 0.000000},{0.237812, 0.403521, -0.004532}}],
    Polygon[{{0.238873, 0.412474, 0.000000},{0.239212, 0.412364, 0.004532},{
      0.237812, 0.403521, 0.004532},{0.237455, 0.403521, 0.000000}}],
    Polygon[{{0.239212, 0.412364, 0.004532},{0.240222, 0.412036, 0.008953},{
      0.238873, 0.403521, 0.008953},{0.237812, 0.403521, 0.004532}}],
    Polygon[{{0.240222, 0.412036, 0.008953},{0.241876, 0.411498, 0.013153},{
      0.240613, 0.403521, 0.013153},{0.238873, 0.403521, 0.008953}}],
    Polygon[{{0.241876, 0.411498, 0.013153},{0.244135, 0.410764, 0.017029},{
      0.242988, 0.403521, 0.017029},{0.240613, 0.403521, 0.013153}}],
    Polygon[{{0.244135, 0.410764, 0.017029},{0.246943, 0.409852, 0.020486},{
      0.245941, 0.403521, 0.020486},{0.242988, 0.403521, 0.017029}}],
    Polygon[{{0.246943, 0.409852, 0.020486},{0.250231, 0.408783, 0.023438},{
      0.249397, 0.403521, 0.023438},{0.245941, 0.403521, 0.020486}}],
    Polygon[{{0.250231, 0.408783, 0.023438},{0.253917, 0.407586, 0.025814},{
      0.253274, 0.403521, 0.025814},{0.249397, 0.403521, 0.023438}}],
    Polygon[{{0.253917, 0.407586, 0.025814},{0.257912, 0.406288, 0.027554},{
      0.257474, 0.403521, 0.027554},{0.253274, 0.403521, 0.025814}}],
    Polygon[{{0.257912, 0.406288, 0.027554},{0.262116, 0.404922, 0.028615},{
      0.261894, 0.403521, 0.028615},{0.257474, 0.403521, 0.027554}}],
    Polygon[{{0.261894, 0.403521, -0.028615},{0.257474, 0.403521, -0.027554},{
      0.257912, 0.400755, -0.027554},{0.262116, 0.402121, -0.028615}}],
    Polygon[{{0.257474, 0.403521, -0.027554},{0.253274, 0.403521, -0.025814},{
      0.253917, 0.399457, -0.025814},{0.257912, 0.400755, -0.027554}}],
    Polygon[{{0.253274, 0.403521, -0.025814},{0.249397, 0.403521, -0.023438},{
      0.250231, 0.398259, -0.023438},{0.253917, 0.399457, -0.025814}}],
    Polygon[{{0.249397, 0.403521, -0.023438},{0.245941, 0.403521, -0.020486},{
      0.246943, 0.397191, -0.020486},{0.250231, 0.398259, -0.023438}}],
    Polygon[{{0.245941, 0.403521, -0.020486},{0.242988, 0.403521, -0.017029},{
      0.244135, 0.396278, -0.017029},{0.246943, 0.397191, -0.020486}}],
    Polygon[{{0.242988, 0.403521, -0.017029},{0.240613, 0.403521, -0.013153},{
      0.241876, 0.395544, -0.013153},{0.244135, 0.396278, -0.017029}}],
    Polygon[{{0.240613, 0.403521, -0.013153},{0.238873, 0.403521, -0.008953},{
      0.240222, 0.395007, -0.008953},{0.241876, 0.395544, -0.013153}}],
    Polygon[{{0.238873, 0.403521, -0.008953},{0.237812, 0.403521, -0.004532},{
      0.239212, 0.394679, -0.004532},{0.240222, 0.395007, -0.008953}}],
    Polygon[{{0.237812, 0.403521, -0.004532},{0.237455, 0.403521, 0.000000},{
      0.238873, 0.394568, 0.000000},{0.239212, 0.394679, -0.004532}}],
    Polygon[{{0.237455, 0.403521, 0.000000},{0.237812, 0.403521, 0.004532},{
      0.239212, 0.394679, 0.004532},{0.238873, 0.394568, 0.000000}}],
    Polygon[{{0.237812, 0.403521, 0.004532},{0.238873, 0.403521, 0.008953},{
      0.240222, 0.395007, 0.008953},{0.239212, 0.394679, 0.004532}}],
    Polygon[{{0.238873, 0.403521, 0.008953},{0.240613, 0.403521, 0.013153},{
      0.241876, 0.395544, 0.013153},{0.240222, 0.395007, 0.008953}}],
    Polygon[{{0.240613, 0.403521, 0.013153},{0.242988, 0.403521, 0.017029},{
      0.244135, 0.396278, 0.017029},{0.241876, 0.395544, 0.013153}}],
    Polygon[{{0.242988, 0.403521, 0.017029},{0.245941, 0.403521, 0.020486},{
      0.246943, 0.397191, 0.020486},{0.244135, 0.396278, 0.017029}}],
    Polygon[{{0.245941, 0.403521, 0.020486},{0.249397, 0.403521, 0.023438},{
      0.250231, 0.398259, 0.023438},{0.246943, 0.397191, 0.020486}}],
    Polygon[{{0.249397, 0.403521, 0.023438},{0.253274, 0.403521, 0.025814},{
      0.253917, 0.399457, 0.025814},{0.250231, 0.398259, 0.023438}}],
    Polygon[{{0.253274, 0.403521, 0.025814},{0.257474, 0.403521, 0.027554},{
      0.257912, 0.400755, 0.027554},{0.253917, 0.399457, 0.025814}}],
    Polygon[{{0.257474, 0.403521, 0.027554},{0.261894, 0.403521, 0.028615},{
      0.262116, 0.402121, 0.028615},{0.257912, 0.400755, 0.027554}}],
    Polygon[{{0.262116, 0.402121, -0.028615},{0.257912, 0.400755, -0.027554},{
      0.259184, 0.398259, -0.027554},{0.262760, 0.400857, -0.028615}}],
    Polygon[{{0.257912, 0.400755, -0.027554},{0.253917, 0.399457, -0.025814},{
      0.255786, 0.395790, -0.025814},{0.259184, 0.398259, -0.027554}}],
    Polygon[{{0.253917, 0.399457, -0.025814},{0.250231, 0.398259, -0.023438},{
      0.252650, 0.393512, -0.023438},{0.255786, 0.395790, -0.025814}}],
    Polygon[{{0.250231, 0.398259, -0.023438},{0.246943, 0.397191, -0.020486},{
      0.249853, 0.391480, -0.020486},{0.252650, 0.393512, -0.023438}}],
    Polygon[{{0.246943, 0.397191, -0.020486},{0.244135, 0.396278, -0.017029},{
      0.247464, 0.389744, -0.017029},{0.249853, 0.391480, -0.020486}}],
    Polygon[{{0.244135, 0.396278, -0.017029},{0.241876, 0.395544, -0.013153},{
      0.245543, 0.388348, -0.013153},{0.247464, 0.389744, -0.017029}}],
    Polygon[{{0.241876, 0.395544, -0.013153},{0.240222, 0.395007, -0.008953},{
      0.244135, 0.387326, -0.008953},{0.245543, 0.388348, -0.013153}}],
    Polygon[{{0.240222, 0.395007, -0.008953},{0.239212, 0.394679, -0.004532},{
      0.243277, 0.386702, -0.004532},{0.244135, 0.387326, -0.008953}}],
    Polygon[{{0.239212, 0.394679, -0.004532},{0.238873, 0.394568, 0.000000},{
      0.242988, 0.386492, 0.000000},{0.243277, 0.386702, -0.004532}}],
    Polygon[{{0.238873, 0.394568, 0.000000},{0.239212, 0.394679, 0.004532},{
      0.243277, 0.386702, 0.004532},{0.242988, 0.386492, 0.000000}}],
    Polygon[{{0.239212, 0.394679, 0.004532},{0.240222, 0.395007, 0.008953},{
      0.244135, 0.387326, 0.008953},{0.243277, 0.386702, 0.004532}}],
    Polygon[{{0.240222, 0.395007, 0.008953},{0.241876, 0.395544, 0.013153},{
      0.245543, 0.388348, 0.013153},{0.244135, 0.387326, 0.008953}}],
    Polygon[{{0.241876, 0.395544, 0.013153},{0.244135, 0.396278, 0.017029},{
      0.247464, 0.389744, 0.017029},{0.245543, 0.388348, 0.013153}}],
    Polygon[{{0.244135, 0.396278, 0.017029},{0.246943, 0.397191, 0.020486},{
      0.249853, 0.391480, 0.020486},{0.247464, 0.389744, 0.017029}}],
    Polygon[{{0.246943, 0.397191, 0.020486},{0.250231, 0.398259, 0.023438},{
      0.252650, 0.393512, 0.023438},{0.249853, 0.391480, 0.020486}}],
    Polygon[{{0.250231, 0.398259, 0.023438},{0.253917, 0.399457, 0.025814},{
      0.255786, 0.395790, 0.025814},{0.252650, 0.393512, 0.023438}}],
    Polygon[{{0.253917, 0.399457, 0.025814},{0.257912, 0.400755, 0.027554},{
      0.259184, 0.398259, 0.027554},{0.255786, 0.395790, 0.025814}}],
    Polygon[{{0.257912, 0.400755, 0.027554},{0.262116, 0.402121, 0.028615},{
      0.262760, 0.400857, 0.028615},{0.259184, 0.398259, 0.027554}}],
    Polygon[{{0.262760, 0.400857, -0.028615},{0.259184, 0.398259, -0.027554},{
      0.261164, 0.396278, -0.027554},{0.263763, 0.399855, -0.028615}}],
    Polygon[{{0.259184, 0.398259, -0.027554},{0.255786, 0.395790, -0.025814},{
      0.258695, 0.392880, -0.025814},{0.261164, 0.396278, -0.027554}}],
    Polygon[{{0.255786, 0.395790, -0.025814},{0.252650, 0.393512, -0.023438},{
      0.256417, 0.389744, -0.023438},{0.258695, 0.392880, -0.025814}}],
    Polygon[{{0.252650, 0.393512, -0.023438},{0.249853, 0.391480, -0.020486},{
      0.254385, 0.386948, -0.020486},{0.256417, 0.389744, -0.023438}}],
    Polygon[{{0.249853, 0.391480, -0.020486},{0.247464, 0.389744, -0.017029},{
      0.252650, 0.384559, -0.017029},{0.254385, 0.386948, -0.020486}}],
    Polygon[{{0.247464, 0.389744, -0.017029},{0.245543, 0.388348, -0.013153},{
      0.251254, 0.382637, -0.013153},{0.252650, 0.384559, -0.017029}}],
    Polygon[{{0.245543, 0.388348, -0.013153},{0.244135, 0.387326, -0.008953},{
      0.250231, 0.381230, -0.008953},{0.251254, 0.382637, -0.013153}}],
    Polygon[{{0.244135, 0.387326, -0.008953},{0.243277, 0.386702, -0.004532},{
      0.249607, 0.380371, -0.004532},{0.250231, 0.381230, -0.008953}}],
    Polygon[{{0.243277, 0.386702, -0.004532},{0.242988, 0.386492, 0.000000},{
      0.249397, 0.380083, 0.000000},{0.249607, 0.380371, -0.004532}}],
    Polygon[{{0.242988, 0.386492, 0.000000},{0.243277, 0.386702, 0.004532},{
      0.249607, 0.380371, 0.004532},{0.249397, 0.380083, 0.000000}}],
    Polygon[{{0.243277, 0.386702, 0.004532},{0.244135, 0.387326, 0.008953},{
      0.250231, 0.381230, 0.008953},{0.249607, 0.380371, 0.004532}}],
    Polygon[{{0.244135, 0.387326, 0.008953},{0.245543, 0.388348, 0.013153},{
      0.251254, 0.382637, 0.013153},{0.250231, 0.381230, 0.008953}}],
    Polygon[{{0.245543, 0.388348, 0.013153},{0.247464, 0.389744, 0.017029},{
      0.252650, 0.384559, 0.017029},{0.251254, 0.382637, 0.013153}}],
    Polygon[{{0.247464, 0.389744, 0.017029},{0.249853, 0.391480, 0.020486},{
      0.254385, 0.386948, 0.020486},{0.252650, 0.384559, 0.017029}}],
    Polygon[{{0.249853, 0.391480, 0.020486},{0.252650, 0.393512, 0.023438},{
      0.256417, 0.389744, 0.023438},{0.254385, 0.386948, 0.020486}}],
    Polygon[{{0.252650, 0.393512, 0.023438},{0.255786, 0.395790, 0.025814},{
      0.258695, 0.392880, 0.025814},{0.256417, 0.389744, 0.023438}}],
    Polygon[{{0.255786, 0.395790, 0.025814},{0.259184, 0.398259, 0.027554},{
      0.261164, 0.396278, 0.027554},{0.258695, 0.392880, 0.025814}}],
    Polygon[{{0.259184, 0.398259, 0.027554},{0.262760, 0.400857, 0.028615},{
      0.263763, 0.399855, 0.028615},{0.261164, 0.396278, 0.027554}}],
    Polygon[{{0.263763, 0.399855, -0.028615},{0.261164, 0.396278, -0.027554},{
      0.263660, 0.395007, -0.027554},{0.265026, 0.399211, -0.028615}}],
    Polygon[{{0.261164, 0.396278, -0.027554},{0.258695, 0.392880, -0.025814},{
      0.262362, 0.391012, -0.025814},{0.263660, 0.395007, -0.027554}}],
    Polygon[{{0.258695, 0.392880, -0.025814},{0.256417, 0.389744, -0.023438},{
      0.261164, 0.387326, -0.023438},{0.262362, 0.391012, -0.025814}}],
    Polygon[{{0.256417, 0.389744, -0.023438},{0.254385, 0.386948, -0.020486},{
      0.260096, 0.384038, -0.020486},{0.261164, 0.387326, -0.023438}}],
    Polygon[{{0.254385, 0.386948, -0.020486},{0.252650, 0.384559, -0.017029},{
      0.259184, 0.381230, -0.017029},{0.260096, 0.384038, -0.020486}}],
    Polygon[{{0.252650, 0.384559, -0.017029},{0.251254, 0.382637, -0.013153},{
      0.258450, 0.378971, -0.013153},{0.259184, 0.381230, -0.017029}}],
    Polygon[{{0.251254, 0.382637, -0.013153},{0.250231, 0.381230, -0.008953},{
      0.257912, 0.377316, -0.008953},{0.258450, 0.378971, -0.013153}}],
    Polygon[{{0.250231, 0.381230, -0.008953},{0.249607, 0.380371, -0.004532},{
      0.257584, 0.376307, -0.004532},{0.257912, 0.377316, -0.008953}}],
    Polygon[{{0.249607, 0.380371, -0.004532},{0.249397, 0.380083, 0.000000},{
      0.257474, 0.375968, 0.000000},{0.257584, 0.376307, -0.004532}}],
    Polygon[{{0.249397, 0.380083, 0.000000},{0.249607, 0.380371, 0.004532},{
      0.257584, 0.376307, 0.004532},{0.257474, 0.375968, 0.000000}}],
    Polygon[{{0.249607, 0.380371, 0.004532},{0.250231, 0.381230, 0.008953},{
      0.257912, 0.377316, 0.008953},{0.257584, 0.376307, 0.004532}}],
    Polygon[{{0.250231, 0.381230, 0.008953},{0.251254, 0.382637, 0.013153},{
      0.258450, 0.378971, 0.013153},{0.257912, 0.377316, 0.008953}}],
    Polygon[{{0.251254, 0.382637, 0.013153},{0.252650, 0.384559, 0.017029},{
      0.259184, 0.381230, 0.017029},{0.258450, 0.378971, 0.013153}}],
    Polygon[{{0.252650, 0.384559, 0.017029},{0.254385, 0.386948, 0.020486},{
      0.260096, 0.384038, 0.020486},{0.259184, 0.381230, 0.017029}}],
    Polygon[{{0.254385, 0.386948, 0.020486},{0.256417, 0.389744, 0.023438},{
      0.261164, 0.387326, 0.023438},{0.260096, 0.384038, 0.020486}}],
    Polygon[{{0.256417, 0.389744, 0.023438},{0.258695, 0.392880, 0.025814},{
      0.262362, 0.391012, 0.025814},{0.261164, 0.387326, 0.023438}}],
    Polygon[{{0.258695, 0.392880, 0.025814},{0.261164, 0.396278, 0.027554},{
      0.263660, 0.395007, 0.027554},{0.262362, 0.391012, 0.025814}}],
    Polygon[{{0.261164, 0.396278, 0.027554},{0.263763, 0.399855, 0.028615},{
      0.265026, 0.399211, 0.028615},{0.263660, 0.395007, 0.027554}}],
    Polygon[{{0.265026, 0.399211, -0.028615},{0.263660, 0.395007, -0.027554},{
      0.266426, 0.394568, -0.027554},{0.266426, 0.398989, -0.028615}}],
    Polygon[{{0.263660, 0.395007, -0.027554},{0.262362, 0.391012, -0.025814},{
      0.266426, 0.390368, -0.025814},{0.266426, 0.394568, -0.027554}}],
    Polygon[{{0.262362, 0.391012, -0.025814},{0.261164, 0.387326, -0.023438},{
      0.266426, 0.386492, -0.023438},{0.266426, 0.390368, -0.025814}}],
    Polygon[{{0.261164, 0.387326, -0.023438},{0.260096, 0.384038, -0.020486},{
      0.266426, 0.383035, -0.020486},{0.266426, 0.386492, -0.023438}}],
    Polygon[{{0.260096, 0.384038, -0.020486},{0.259184, 0.381230, -0.017029},{
      0.266426, 0.380083, -0.017029},{0.266426, 0.383035, -0.020486}}],
    Polygon[{{0.259184, 0.381230, -0.017029},{0.258450, 0.378971, -0.013153},{
      0.266426, 0.377707, -0.013153},{0.266426, 0.380083, -0.017029}}],
    Polygon[{{0.258450, 0.378971, -0.013153},{0.257912, 0.377316, -0.008953},{
      0.266426, 0.375968, -0.008953},{0.266426, 0.377707, -0.013153}}],
    Polygon[{{0.257912, 0.377316, -0.008953},{0.257584, 0.376307, -0.004532},{
      0.266426, 0.374906, -0.004532},{0.266426, 0.375968, -0.008953}}],
    Polygon[{{0.257584, 0.376307, -0.004532},{0.257474, 0.375968, 0.000000},{
      0.266426, 0.374550, 0.000000},{0.266426, 0.374906, -0.004532}}],
    Polygon[{{0.257474, 0.375968, 0.000000},{0.257584, 0.376307, 0.004532},{
      0.266426, 0.374906, 0.004532},{0.266426, 0.374550, 0.000000}}],
    Polygon[{{0.257584, 0.376307, 0.004532},{0.257912, 0.377316, 0.008953},{
      0.266426, 0.375968, 0.008953},{0.266426, 0.374906, 0.004532}}],
    Polygon[{{0.257912, 0.377316, 0.008953},{0.258450, 0.378971, 0.013153},{
      0.266426, 0.377707, 0.013153},{0.266426, 0.375968, 0.008953}}],
    Polygon[{{0.258450, 0.378971, 0.013153},{0.259184, 0.381230, 0.017029},{
      0.266426, 0.380083, 0.017029},{0.266426, 0.377707, 0.013153}}],
    Polygon[{{0.259184, 0.381230, 0.017029},{0.260096, 0.384038, 0.020486},{
      0.266426, 0.383035, 0.020486},{0.266426, 0.380083, 0.017029}}],
    Polygon[{{0.260096, 0.384038, 0.020486},{0.261164, 0.387326, 0.023438},{
      0.266426, 0.386492, 0.023438},{0.266426, 0.383035, 0.020486}}],
    Polygon[{{0.261164, 0.387326, 0.023438},{0.262362, 0.391012, 0.025814},{
      0.266426, 0.390368, 0.025814},{0.266426, 0.386492, 0.023438}}],
    Polygon[{{0.262362, 0.391012, 0.025814},{0.263660, 0.395007, 0.027554},{
      0.266426, 0.394568, 0.027554},{0.266426, 0.390368, 0.025814}}],
    Polygon[{{0.263660, 0.395007, 0.027554},{0.265026, 0.399211, 0.028615},{
      0.266426, 0.398989, 0.028615},{0.266426, 0.394568, 0.027554}}],
    Polygon[{{0.266426, 0.398989, -0.028615},{0.266426, 0.394568, -0.027554},{
      0.269193, 0.395007, -0.027554},{0.267827, 0.399211, -0.028615}}],
    Polygon[{{0.266426, 0.394568, -0.027554},{0.266426, 0.390368, -0.025814},{
      0.270491, 0.391012, -0.025814},{0.269193, 0.395007, -0.027554}}],
    Polygon[{{0.266426, 0.390368, -0.025814},{0.266426, 0.386492, -0.023438},{
      0.271689, 0.387326, -0.023438},{0.270491, 0.391012, -0.025814}}],
    Polygon[{{0.266426, 0.386492, -0.023438},{0.266426, 0.383035, -0.020486},{
      0.272757, 0.384038, -0.020486},{0.271689, 0.387326, -0.023438}}],
    Polygon[{{0.266426, 0.383035, -0.020486},{0.266426, 0.380083, -0.017029},{
      0.273669, 0.381230, -0.017029},{0.272757, 0.384038, -0.020486}}],
    Polygon[{{0.266426, 0.380083, -0.017029},{0.266426, 0.377707, -0.013153},{
      0.274403, 0.378971, -0.013153},{0.273669, 0.381230, -0.017029}}],
    Polygon[{{0.266426, 0.377707, -0.013153},{0.266426, 0.375968, -0.008953},{
      0.274941, 0.377316, -0.008953},{0.274403, 0.378971, -0.013153}}],
    Polygon[{{0.266426, 0.375968, -0.008953},{0.266426, 0.374906, -0.004532},{
      0.275269, 0.376307, -0.004532},{0.274941, 0.377316, -0.008953}}],
    Polygon[{{0.266426, 0.374906, -0.004532},{0.266426, 0.374550, 0.000000},{
      0.275379, 0.375968, 0.000000},{0.275269, 0.376307, -0.004532}}],
    Polygon[{{0.266426, 0.374550, 0.000000},{0.266426, 0.374906, 0.004532},{
      0.275269, 0.376307, 0.004532},{0.275379, 0.375968, 0.000000}}],
    Polygon[{{0.266426, 0.374906, 0.004532},{0.266426, 0.375968, 0.008953},{
      0.274941, 0.377316, 0.008953},{0.275269, 0.376307, 0.004532}}],
    Polygon[{{0.266426, 0.375968, 0.008953},{0.266426, 0.377707, 0.013153},{
      0.274403, 0.378971, 0.013153},{0.274941, 0.377316, 0.008953}}],
    Polygon[{{0.266426, 0.377707, 0.013153},{0.266426, 0.380083, 0.017029},{
      0.273669, 0.381230, 0.017029},{0.274403, 0.378971, 0.013153}}],
    Polygon[{{0.266426, 0.380083, 0.017029},{0.266426, 0.383035, 0.020486},{
      0.272757, 0.384038, 0.020486},{0.273669, 0.381230, 0.017029}}],
    Polygon[{{0.266426, 0.383035, 0.020486},{0.266426, 0.386492, 0.023438},{
      0.271689, 0.387326, 0.023438},{0.272757, 0.384038, 0.020486}}],
    Polygon[{{0.266426, 0.386492, 0.023438},{0.266426, 0.390368, 0.025814},{
      0.270491, 0.391012, 0.025814},{0.271689, 0.387326, 0.023438}}],
    Polygon[{{0.266426, 0.390368, 0.025814},{0.266426, 0.394568, 0.027554},{
      0.269193, 0.395007, 0.027554},{0.270491, 0.391012, 0.025814}}],
    Polygon[{{0.266426, 0.394568, 0.027554},{0.266426, 0.398989, 0.028615},{
      0.267827, 0.399211, 0.028615},{0.269193, 0.395007, 0.027554}}],
    Polygon[{{0.267827, 0.399211, -0.028615},{0.269193, 0.395007, -0.027554},{
      0.271689, 0.396278, -0.027554},{0.269090, 0.399855, -0.028615}}],
    Polygon[{{0.269193, 0.395007, -0.027554},{0.270491, 0.391012, -0.025814},{
      0.274157, 0.392880, -0.025814},{0.271689, 0.396278, -0.027554}}],
    Polygon[{{0.270491, 0.391012, -0.025814},{0.271689, 0.387326, -0.023438},{
      0.276436, 0.389744, -0.023438},{0.274157, 0.392880, -0.025814}}],
    Polygon[{{0.271689, 0.387326, -0.023438},{0.272757, 0.384038, -0.020486},{
      0.278468, 0.386948, -0.020486},{0.276436, 0.389744, -0.023438}}],
    Polygon[{{0.272757, 0.384038, -0.020486},{0.273669, 0.381230, -0.017029},{
      0.280203, 0.384559, -0.017029},{0.278468, 0.386948, -0.020486}}],
    Polygon[{{0.273669, 0.381230, -0.017029},{0.274403, 0.378971, -0.013153},{
      0.281599, 0.382637, -0.013153},{0.280203, 0.384559, -0.017029}}],
    Polygon[{{0.274403, 0.378971, -0.013153},{0.274941, 0.377316, -0.008953},{
      0.282622, 0.381230, -0.008953},{0.281599, 0.382637, -0.013153}}],
    Polygon[{{0.274941, 0.377316, -0.008953},{0.275269, 0.376307, -0.004532},{
      0.283246, 0.380371, -0.004532},{0.282622, 0.381230, -0.008953}}],
    Polygon[{{0.275269, 0.376307, -0.004532},{0.275379, 0.375968, 0.000000},{
      0.283456, 0.380083, 0.000000},{0.283246, 0.380371, -0.004532}}],
    Polygon[{{0.275379, 0.375968, 0.000000},{0.275269, 0.376307, 0.004532},{
      0.283246, 0.380371, 0.004532},{0.283456, 0.380083, 0.000000}}],
    Polygon[{{0.275269, 0.376307, 0.004532},{0.274941, 0.377316, 0.008953},{
      0.282622, 0.381230, 0.008953},{0.283246, 0.380371, 0.004532}}],
    Polygon[{{0.274941, 0.377316, 0.008953},{0.274403, 0.378971, 0.013153},{
      0.281599, 0.382637, 0.013153},{0.282622, 0.381230, 0.008953}}],
    Polygon[{{0.274403, 0.378971, 0.013153},{0.273669, 0.381230, 0.017029},{
      0.280203, 0.384559, 0.017029},{0.281599, 0.382637, 0.013153}}],
    Polygon[{{0.273669, 0.381230, 0.017029},{0.272757, 0.384038, 0.020486},{
      0.278468, 0.386948, 0.020486},{0.280203, 0.384559, 0.017029}}],
    Polygon[{{0.272757, 0.384038, 0.020486},{0.271689, 0.387326, 0.023438},{
      0.276436, 0.389744, 0.023438},{0.278468, 0.386948, 0.020486}}],
    Polygon[{{0.271689, 0.387326, 0.023438},{0.270491, 0.391012, 0.025814},{
      0.274157, 0.392880, 0.025814},{0.276436, 0.389744, 0.023438}}],
    Polygon[{{0.270491, 0.391012, 0.025814},{0.269193, 0.395007, 0.027554},{
      0.271689, 0.396278, 0.027554},{0.274157, 0.392880, 0.025814}}],
    Polygon[{{0.269193, 0.395007, 0.027554},{0.267827, 0.399211, 0.028615},{
      0.269090, 0.399855, 0.028615},{0.271689, 0.396278, 0.027554}}],
    Polygon[{{0.269090, 0.399855, -0.028615},{0.271689, 0.396278, -0.027554},{
      0.273669, 0.398259, -0.027554},{0.270093, 0.400857, -0.028615}}],
    Polygon[{{0.271689, 0.396278, -0.027554},{0.274157, 0.392880, -0.025814},{
      0.277067, 0.395790, -0.025814},{0.273669, 0.398259, -0.027554}}],
    Polygon[{{0.274157, 0.392880, -0.025814},{0.276436, 0.389744, -0.023438},{
      0.280203, 0.393512, -0.023438},{0.277067, 0.395790, -0.025814}}],
    Polygon[{{0.276436, 0.389744, -0.023438},{0.278468, 0.386948, -0.020486},{
      0.283000, 0.391480, -0.020486},{0.280203, 0.393512, -0.023438}}],
    Polygon[{{0.278468, 0.386948, -0.020486},{0.280203, 0.384559, -0.017029},{
      0.285389, 0.389744, -0.017029},{0.283000, 0.391480, -0.020486}}],
    Polygon[{{0.280203, 0.384559, -0.017029},{0.281599, 0.382637, -0.013153},{
      0.287310, 0.388348, -0.013153},{0.285389, 0.389744, -0.017029}}],
    Polygon[{{0.281599, 0.382637, -0.013153},{0.282622, 0.381230, -0.008953},{
      0.288718, 0.387326, -0.008953},{0.287310, 0.388348, -0.013153}}],
    Polygon[{{0.282622, 0.381230, -0.008953},{0.283246, 0.380371, -0.004532},{
      0.289576, 0.386702, -0.004532},{0.288718, 0.387326, -0.008953}}],
    Polygon[{{0.283246, 0.380371, -0.004532},{0.283456, 0.380083, 0.000000},{
      0.289865, 0.386492, 0.000000},{0.289576, 0.386702, -0.004532}}],
    Polygon[{{0.283456, 0.380083, 0.000000},{0.283246, 0.380371, 0.004532},{
      0.289576, 0.386702, 0.004532},{0.289865, 0.386492, 0.000000}}],
    Polygon[{{0.283246, 0.380371, 0.004532},{0.282622, 0.381230, 0.008953},{
      0.288718, 0.387326, 0.008953},{0.289576, 0.386702, 0.004532}}],
    Polygon[{{0.282622, 0.381230, 0.008953},{0.281599, 0.382637, 0.013153},{
      0.287310, 0.388348, 0.013153},{0.288718, 0.387326, 0.008953}}],
    Polygon[{{0.281599, 0.382637, 0.013153},{0.280203, 0.384559, 0.017029},{
      0.285389, 0.389744, 0.017029},{0.287310, 0.388348, 0.013153}}],
    Polygon[{{0.280203, 0.384559, 0.017029},{0.278468, 0.386948, 0.020486},{
      0.283000, 0.391480, 0.020486},{0.285389, 0.389744, 0.017029}}],
    Polygon[{{0.278468, 0.386948, 0.020486},{0.276436, 0.389744, 0.023438},{
      0.280203, 0.393512, 0.023438},{0.283000, 0.391480, 0.020486}}],
    Polygon[{{0.276436, 0.389744, 0.023438},{0.274157, 0.392880, 0.025814},{
      0.277067, 0.395790, 0.025814},{0.280203, 0.393512, 0.023438}}],
    Polygon[{{0.274157, 0.392880, 0.025814},{0.271689, 0.396278, 0.027554},{
      0.273669, 0.398259, 0.027554},{0.277067, 0.395790, 0.025814}}],
    Polygon[{{0.271689, 0.396278, 0.027554},{0.269090, 0.399855, 0.028615},{
      0.270093, 0.400857, 0.028615},{0.273669, 0.398259, 0.027554}}],
    Polygon[{{0.270093, 0.400857, -0.028615},{0.273669, 0.398259, -0.027554},{
      0.274941, 0.400755, -0.027554},{0.270737, 0.402121, -0.028615}}],
    Polygon[{{0.273669, 0.398259, -0.027554},{0.277067, 0.395790, -0.025814},{
      0.278936, 0.399457, -0.025814},{0.274941, 0.400755, -0.027554}}],
    Polygon[{{0.277067, 0.395790, -0.025814},{0.280203, 0.393512, -0.023438},{
      0.282622, 0.398259, -0.023438},{0.278936, 0.399457, -0.025814}}],
    Polygon[{{0.280203, 0.393512, -0.023438},{0.283000, 0.391480, -0.020486},{
      0.285910, 0.397191, -0.020486},{0.282622, 0.398259, -0.023438}}],
    Polygon[{{0.283000, 0.391480, -0.020486},{0.285389, 0.389744, -0.017029},{
      0.288718, 0.396278, -0.017029},{0.285910, 0.397191, -0.020486}}],
    Polygon[{{0.285389, 0.389744, -0.017029},{0.287310, 0.388348, -0.013153},{
      0.290977, 0.395544, -0.013153},{0.288718, 0.396278, -0.017029}}],
    Polygon[{{0.287310, 0.388348, -0.013153},{0.288718, 0.387326, -0.008953},{
      0.292631, 0.395007, -0.008953},{0.290977, 0.395544, -0.013153}}],
    Polygon[{{0.288718, 0.387326, -0.008953},{0.289576, 0.386702, -0.004532},{
      0.293641, 0.394679, -0.004532},{0.292631, 0.395007, -0.008953}}],
    Polygon[{{0.289576, 0.386702, -0.004532},{0.289865, 0.386492, 0.000000},{
      0.293980, 0.394568, 0.000000},{0.293641, 0.394679, -0.004532}}],
    Polygon[{{0.289865, 0.386492, 0.000000},{0.289576, 0.386702, 0.004532},{
      0.293641, 0.394679, 0.004532},{0.293980, 0.394568, 0.000000}}],
    Polygon[{{0.289576, 0.386702, 0.004532},{0.288718, 0.387326, 0.008953},{
      0.292631, 0.395007, 0.008953},{0.293641, 0.394679, 0.004532}}],
    Polygon[{{0.288718, 0.387326, 0.008953},{0.287310, 0.388348, 0.013153},{
      0.290977, 0.395544, 0.013153},{0.292631, 0.395007, 0.008953}}],
    Polygon[{{0.287310, 0.388348, 0.013153},{0.285389, 0.389744, 0.017029},{
      0.288718, 0.396278, 0.017029},{0.290977, 0.395544, 0.013153}}],
    Polygon[{{0.285389, 0.389744, 0.017029},{0.283000, 0.391480, 0.020486},{
      0.285910, 0.397191, 0.020486},{0.288718, 0.396278, 0.017029}}],
    Polygon[{{0.283000, 0.391480, 0.020486},{0.280203, 0.393512, 0.023438},{
      0.282622, 0.398259, 0.023438},{0.285910, 0.397191, 0.020486}}],
    Polygon[{{0.280203, 0.393512, 0.023438},{0.277067, 0.395790, 0.025814},{
      0.278936, 0.399457, 0.025814},{0.282622, 0.398259, 0.023438}}],
    Polygon[{{0.277067, 0.395790, 0.025814},{0.273669, 0.398259, 0.027554},{
      0.274941, 0.400755, 0.027554},{0.278936, 0.399457, 0.025814}}],
    Polygon[{{0.273669, 0.398259, 0.027554},{0.270093, 0.400857, 0.028615},{
      0.270737, 0.402121, 0.028615},{0.274941, 0.400755, 0.027554}}],
    Polygon[{{0.270737, 0.402121, -0.028615},{0.274941, 0.400755, -0.027554},{
      0.275379, 0.403521, -0.027554},{0.270959, 0.403521, -0.028615}}],
    Polygon[{{0.274941, 0.400755, -0.027554},{0.278936, 0.399457, -0.025814},{
      0.279579, 0.403521, -0.025814},{0.275379, 0.403521, -0.027554}}],
    Polygon[{{0.278936, 0.399457, -0.025814},{0.282622, 0.398259, -0.023438},{
      0.283456, 0.403521, -0.023438},{0.279579, 0.403521, -0.025814}}],
    Polygon[{{0.282622, 0.398259, -0.023438},{0.285910, 0.397191, -0.020486},{
      0.286912, 0.403521, -0.020486},{0.283456, 0.403521, -0.023438}}],
    Polygon[{{0.285910, 0.397191, -0.020486},{0.288718, 0.396278, -0.017029},{
      0.289865, 0.403521, -0.017029},{0.286912, 0.403521, -0.020486}}],
    Polygon[{{0.288718, 0.396278, -0.017029},{0.290977, 0.395544, -0.013153},{
      0.292240, 0.403521, -0.013153},{0.289865, 0.403521, -0.017029}}],
    Polygon[{{0.290977, 0.395544, -0.013153},{0.292631, 0.395007, -0.008953},{
      0.293980, 0.403521, -0.008953},{0.292240, 0.403521, -0.013153}}],
    Polygon[{{0.292631, 0.395007, -0.008953},{0.293641, 0.394679, -0.004532},{
      0.295041, 0.403521, -0.004532},{0.293980, 0.403521, -0.008953}}],
    Polygon[{{0.293641, 0.394679, -0.004532},{0.293980, 0.394568, 0.000000},{
      0.295398, 0.403521, 0.000000},{0.295041, 0.403521, -0.004532}}],
    Polygon[{{0.293980, 0.394568, 0.000000},{0.293641, 0.394679, 0.004532},{
      0.295041, 0.403521, 0.004532},{0.295398, 0.403521, 0.000000}}],
    Polygon[{{0.293641, 0.394679, 0.004532},{0.292631, 0.395007, 0.008953},{
      0.293980, 0.403521, 0.008953},{0.295041, 0.403521, 0.004532}}],
    Polygon[{{0.292631, 0.395007, 0.008953},{0.290977, 0.395544, 0.013153},{
      0.292240, 0.403521, 0.013153},{0.293980, 0.403521, 0.008953}}],
    Polygon[{{0.290977, 0.395544, 0.013153},{0.288718, 0.396278, 0.017029},{
      0.289865, 0.403521, 0.017029},{0.292240, 0.403521, 0.013153}}],
    Polygon[{{0.288718, 0.396278, 0.017029},{0.285910, 0.397191, 0.020486},{
      0.286912, 0.403521, 0.020486},{0.289865, 0.403521, 0.017029}}],
    Polygon[{{0.285910, 0.397191, 0.020486},{0.282622, 0.398259, 0.023438},{
      0.283456, 0.403521, 0.023438},{0.286912, 0.403521, 0.020486}}],
    Polygon[{{0.282622, 0.398259, 0.023438},{0.278936, 0.399457, 0.025814},{
      0.279579, 0.403521, 0.025814},{0.283456, 0.403521, 0.023438}}],
    Polygon[{{0.278936, 0.399457, 0.025814},{0.274941, 0.400755, 0.027554},{
      0.275379, 0.403521, 0.027554},{0.279579, 0.403521, 0.025814}}],
    Polygon[{{0.274941, 0.400755, 0.027554},{0.270737, 0.402121, 0.028615},{
      0.270959, 0.403521, 0.028615},{0.275379, 0.403521, 0.027554}}],
    Polygon[{{0.235839, 0.374335, -0.014853},{0.238134, 0.374335, -0.014302},{
      0.237907, 0.375771, -0.014302},{0.235724, 0.375062, -0.014853}}],
    Polygon[{{0.238134, 0.374335, -0.014302},{0.240314, 0.374335, -0.013399},{
      0.239980, 0.376445, -0.013399},{0.237907, 0.375771, -0.014302}}],
    Polygon[{{0.240314, 0.374335, -0.013399},{0.242326, 0.374335, -0.012166},{
      0.241894, 0.377066, -0.012166},{0.239980, 0.376445, -0.013399}}],
    Polygon[{{0.242326, 0.374335, -0.012166},{0.244121, 0.374335, -0.010634},{
      0.243600, 0.377621, -0.010634},{0.241894, 0.377066, -0.012166}}],
    Polygon[{{0.244121, 0.374335, -0.010634},{0.245653, 0.374335, -0.008839},{
      0.245058, 0.378094, -0.008839},{0.243600, 0.377621, -0.010634}}],
    Polygon[{{0.245653, 0.374335, -0.008839},{0.246886, 0.374335, -0.006827},{
      0.246230, 0.378475, -0.006827},{0.245058, 0.378094, -0.008839}}],
    Polygon[{{0.246886, 0.374335, -0.006827},{0.247789, 0.374335, -0.004647},{
      0.247089, 0.378754, -0.004647},{0.246230, 0.378475, -0.006827}}],
    Polygon[{{0.247789, 0.374335, -0.004647},{0.248340, 0.374335, -0.002352},{
      0.247613, 0.378925, -0.002352},{0.247089, 0.378754, -0.004647}}],
    Polygon[{{0.248340, 0.374335, -0.002352},{0.248525, 0.374335, 0.000000},{
      0.247789, 0.378982, 0.000000},{0.247613, 0.378925, -0.002352}}],
    Polygon[{{0.248525, 0.374335, 0.000000},{0.248340, 0.374335, 0.002352},{
      0.247613, 0.378925, 0.002352},{0.247789, 0.378982, 0.000000}}],
    Polygon[{{0.248340, 0.374335, 0.002352},{0.247789, 0.374335, 0.004647},{
      0.247089, 0.378754, 0.004647},{0.247613, 0.378925, 0.002352}}],
    Polygon[{{0.247789, 0.374335, 0.004647},{0.246886, 0.374335, 0.006827},{
      0.246230, 0.378475, 0.006827},{0.247089, 0.378754, 0.004647}}],
    Polygon[{{0.246886, 0.374335, 0.006827},{0.245653, 0.374335, 0.008839},{
      0.245058, 0.378094, 0.008839},{0.246230, 0.378475, 0.006827}}],
    Polygon[{{0.245653, 0.374335, 0.008839},{0.244121, 0.374335, 0.010634},{
      0.243600, 0.377621, 0.010634},{0.245058, 0.378094, 0.008839}}],
    Polygon[{{0.244121, 0.374335, 0.010634},{0.242326, 0.374335, 0.012166},{
      0.241894, 0.377066, 0.012166},{0.243600, 0.377621, 0.010634}}],
    Polygon[{{0.242326, 0.374335, 0.012166},{0.240314, 0.374335, 0.013399},{
      0.239980, 0.376445, 0.013399},{0.241894, 0.377066, 0.012166}}],
    Polygon[{{0.240314, 0.374335, 0.013399},{0.238134, 0.374335, 0.014302},{
      0.237907, 0.375771, 0.014302},{0.239980, 0.376445, 0.013399}}],
    Polygon[{{0.238134, 0.374335, 0.014302},{0.235839, 0.374335, 0.014853},{
      0.235724, 0.375062, 0.014853},{0.237907, 0.375771, 0.014302}}],
    Polygon[{{0.235724, 0.375062, -0.014853},{0.237907, 0.375771, -0.014302},{
      0.237246, 0.377066, -0.014302},{0.235390, 0.375718, -0.014853}}],
    Polygon[{{0.237907, 0.375771, -0.014302},{0.239980, 0.376445, -0.013399},{
      0.239010, 0.378348, -0.013399},{0.237246, 0.377066, -0.014302}}],
    Polygon[{{0.239980, 0.376445, -0.013399},{0.241894, 0.377066, -0.012166},{
      0.240638, 0.379530, -0.012166},{0.239010, 0.378348, -0.013399}}],
    Polygon[{{0.241894, 0.377066, -0.012166},{0.243600, 0.377621, -0.010634},{
      0.242090, 0.380585, -0.010634},{0.240638, 0.379530, -0.012166}}],
    Polygon[{{0.243600, 0.377621, -0.010634},{0.245058, 0.378094, -0.008839},{
      0.243330, 0.381486, -0.008839},{0.242090, 0.380585, -0.010634}}],
    Polygon[{{0.245058, 0.378094, -0.008839},{0.246230, 0.378475, -0.006827},{
      0.244327, 0.382211, -0.006827},{0.243330, 0.381486, -0.008839}}],
    Polygon[{{0.246230, 0.378475, -0.006827},{0.247089, 0.378754, -0.004647},{
      0.245058, 0.382741, -0.004647},{0.244327, 0.382211, -0.006827}}],
    Polygon[{{0.247089, 0.378754, -0.004647},{0.247613, 0.378925, -0.002352},{
      0.245503, 0.383065, -0.002352},{0.245058, 0.382741, -0.004647}}],
    Polygon[{{0.247613, 0.378925, -0.002352},{0.247789, 0.378982, 0.000000},{
      0.245653, 0.383174, 0.000000},{0.245503, 0.383065, -0.002352}}],
    Polygon[{{0.247789, 0.378982, 0.000000},{0.247613, 0.378925, 0.002352},{
      0.245503, 0.383065, 0.002352},{0.245653, 0.383174, 0.000000}}],
    Polygon[{{0.247613, 0.378925, 0.002352},{0.247089, 0.378754, 0.004647},{
      0.245058, 0.382741, 0.004647},{0.245503, 0.383065, 0.002352}}],
    Polygon[{{0.247089, 0.378754, 0.004647},{0.246230, 0.378475, 0.006827},{
      0.244327, 0.382211, 0.006827},{0.245058, 0.382741, 0.004647}}],
    Polygon[{{0.246230, 0.378475, 0.006827},{0.245058, 0.378094, 0.008839},{
      0.243330, 0.381486, 0.008839},{0.244327, 0.382211, 0.006827}}],
    Polygon[{{0.245058, 0.378094, 0.008839},{0.243600, 0.377621, 0.010634},{
      0.242090, 0.380585, 0.010634},{0.243330, 0.381486, 0.008839}}],
    Polygon[{{0.243600, 0.377621, 0.010634},{0.241894, 0.377066, 0.012166},{
      0.240638, 0.379530, 0.012166},{0.242090, 0.380585, 0.010634}}],
    Polygon[{{0.241894, 0.377066, 0.012166},{0.239980, 0.376445, 0.013399},{
      0.239010, 0.378348, 0.013399},{0.240638, 0.379530, 0.012166}}],
    Polygon[{{0.239980, 0.376445, 0.013399},{0.237907, 0.375771, 0.014302},{
      0.237246, 0.377066, 0.014302},{0.239010, 0.378348, 0.013399}}],
    Polygon[{{0.237907, 0.375771, 0.014302},{0.235724, 0.375062, 0.014853},{
      0.235390, 0.375718, 0.014853},{0.237246, 0.377066, 0.014302}}],
    Polygon[{{0.235390, 0.375718, -0.014853},{0.237246, 0.377066, -0.014302},{
      0.236218, 0.378094, -0.014302},{0.234870, 0.376238, -0.014853}}],
    Polygon[{{0.237246, 0.377066, -0.014302},{0.239010, 0.378348, -0.013399},{
      0.237500, 0.379858, -0.013399},{0.236218, 0.378094, -0.014302}}],
    Polygon[{{0.239010, 0.378348, -0.013399},{0.240638, 0.379530, -0.012166},{
      0.238682, 0.381486, -0.012166},{0.237500, 0.379858, -0.013399}}],
    Polygon[{{0.240638, 0.379530, -0.012166},{0.242090, 0.380585, -0.010634},{
      0.239737, 0.382938, -0.010634},{0.238682, 0.381486, -0.012166}}],
    Polygon[{{0.242090, 0.380585, -0.010634},{0.243330, 0.381486, -0.008839},{
      0.240638, 0.384178, -0.008839},{0.239737, 0.382938, -0.010634}}],
    Polygon[{{0.243330, 0.381486, -0.008839},{0.244327, 0.382211, -0.006827},{
      0.241363, 0.385175, -0.006827},{0.240638, 0.384178, -0.008839}}],
    Polygon[{{0.244327, 0.382211, -0.006827},{0.245058, 0.382741, -0.004647},{
      0.241894, 0.385906, -0.004647},{0.241363, 0.385175, -0.006827}}],
    Polygon[{{0.245058, 0.382741, -0.004647},{0.245503, 0.383065, -0.002352},{
      0.242217, 0.386351, -0.002352},{0.241894, 0.385906, -0.004647}}],
    Polygon[{{0.245503, 0.383065, -0.002352},{0.245653, 0.383174, 0.000000},{
      0.242326, 0.386501, 0.000000},{0.242217, 0.386351, -0.002352}}],
    Polygon[{{0.245653, 0.383174, 0.000000},{0.245503, 0.383065, 0.002352},{
      0.242217, 0.386351, 0.002352},{0.242326, 0.386501, 0.000000}}],
    Polygon[{{0.245503, 0.383065, 0.002352},{0.245058, 0.382741, 0.004647},{
      0.241894, 0.385906, 0.004647},{0.242217, 0.386351, 0.002352}}],
    Polygon[{{0.245058, 0.382741, 0.004647},{0.244327, 0.382211, 0.006827},{
      0.241363, 0.385175, 0.006827},{0.241894, 0.385906, 0.004647}}],
    Polygon[{{0.244327, 0.382211, 0.006827},{0.243330, 0.381486, 0.008839},{
      0.240638, 0.384178, 0.008839},{0.241363, 0.385175, 0.006827}}],
    Polygon[{{0.243330, 0.381486, 0.008839},{0.242090, 0.380585, 0.010634},{
      0.239737, 0.382938, 0.010634},{0.240638, 0.384178, 0.008839}}],
    Polygon[{{0.242090, 0.380585, 0.010634},{0.240638, 0.379530, 0.012166},{
      0.238682, 0.381486, 0.012166},{0.239737, 0.382938, 0.010634}}],
    Polygon[{{0.240638, 0.379530, 0.012166},{0.239010, 0.378348, 0.013399},{
      0.237500, 0.379858, 0.013399},{0.238682, 0.381486, 0.012166}}],
    Polygon[{{0.239010, 0.378348, 0.013399},{0.237246, 0.377066, 0.014302},{
      0.236218, 0.378094, 0.014302},{0.237500, 0.379858, 0.013399}}],
    Polygon[{{0.237246, 0.377066, 0.014302},{0.235390, 0.375718, 0.014853},{
      0.234870, 0.376238, 0.014853},{0.236218, 0.378094, 0.014302}}],
    Polygon[{{0.234870, 0.376238, -0.014853},{0.236218, 0.378094, -0.014302},{
      0.234923, 0.378754, -0.014302},{0.234214, 0.376572, -0.014853}}],
    Polygon[{{0.236218, 0.378094, -0.014302},{0.237500, 0.379858, -0.013399},{
      0.235597, 0.380828, -0.013399},{0.234923, 0.378754, -0.014302}}],
    Polygon[{{0.237500, 0.379858, -0.013399},{0.238682, 0.381486, -0.012166},{
      0.236218, 0.382741, -0.012166},{0.235597, 0.380828, -0.013399}}],
    Polygon[{{0.238682, 0.381486, -0.012166},{0.239737, 0.382938, -0.010634},{
      0.236773, 0.384448, -0.010634},{0.236218, 0.382741, -0.012166}}],
    Polygon[{{0.239737, 0.382938, -0.010634},{0.240638, 0.384178, -0.008839},{
      0.237246, 0.385906, -0.008839},{0.236773, 0.384448, -0.010634}}],
    Polygon[{{0.240638, 0.384178, -0.008839},{0.241363, 0.385175, -0.006827},{
      0.237627, 0.387078, -0.006827},{0.237246, 0.385906, -0.008839}}],
    Polygon[{{0.241363, 0.385175, -0.006827},{0.241894, 0.385906, -0.004647},{
      0.237907, 0.387937, -0.004647},{0.237627, 0.387078, -0.006827}}],
    Polygon[{{0.241894, 0.385906, -0.004647},{0.242217, 0.386351, -0.002352},{
      0.238077, 0.388461, -0.002352},{0.237907, 0.387937, -0.004647}}],
    Polygon[{{0.242217, 0.386351, -0.002352},{0.242326, 0.386501, 0.000000},{
      0.238134, 0.388637, 0.000000},{0.238077, 0.388461, -0.002352}}],
    Polygon[{{0.242326, 0.386501, 0.000000},{0.242217, 0.386351, 0.002352},{
      0.238077, 0.388461, 0.002352},{0.238134, 0.388637, 0.000000}}],
    Polygon[{{0.242217, 0.386351, 0.002352},{0.241894, 0.385906, 0.004647},{
      0.237907, 0.387937, 0.004647},{0.238077, 0.388461, 0.002352}}],
    Polygon[{{0.241894, 0.385906, 0.004647},{0.241363, 0.385175, 0.006827},{
      0.237627, 0.387078, 0.006827},{0.237907, 0.387937, 0.004647}}],
    Polygon[{{0.241363, 0.385175, 0.006827},{0.240638, 0.384178, 0.008839},{
      0.237246, 0.385906, 0.008839},{0.237627, 0.387078, 0.006827}}],
    Polygon[{{0.240638, 0.384178, 0.008839},{0.239737, 0.382938, 0.010634},{
      0.236773, 0.384448, 0.010634},{0.237246, 0.385906, 0.008839}}],
    Polygon[{{0.239737, 0.382938, 0.010634},{0.238682, 0.381486, 0.012166},{
      0.236218, 0.382741, 0.012166},{0.236773, 0.384448, 0.010634}}],
    Polygon[{{0.238682, 0.381486, 0.012166},{0.237500, 0.379858, 0.013399},{
      0.235597, 0.380828, 0.013399},{0.236218, 0.382741, 0.012166}}],
    Polygon[{{0.237500, 0.379858, 0.013399},{0.236218, 0.378094, 0.014302},{
      0.234923, 0.378754, 0.014302},{0.235597, 0.380828, 0.013399}}],
    Polygon[{{0.236218, 0.378094, 0.014302},{0.234870, 0.376238, 0.014853},{
      0.234214, 0.376572, 0.014853},{0.234923, 0.378754, 0.014302}}],
    Polygon[{{0.234214, 0.376572, -0.014853},{0.234923, 0.378754, -0.014302},{
      0.233487, 0.378982, -0.014302},{0.233487, 0.376687, -0.014853}}],
    Polygon[{{0.234923, 0.378754, -0.014302},{0.235597, 0.380828, -0.013399},{
      0.233487, 0.381162, -0.013399},{0.233487, 0.378982, -0.014302}}],
    Polygon[{{0.235597, 0.380828, -0.013399},{0.236218, 0.382741, -0.012166},{
      0.233487, 0.383174, -0.012166},{0.233487, 0.381162, -0.013399}}],
    Polygon[{{0.236218, 0.382741, -0.012166},{0.236773, 0.384448, -0.010634},{
      0.233487, 0.384968, -0.010634},{0.233487, 0.383174, -0.012166}}],
    Polygon[{{0.236773, 0.384448, -0.010634},{0.237246, 0.385906, -0.008839},{
      0.233487, 0.386501, -0.008839},{0.233487, 0.384968, -0.010634}}],
    Polygon[{{0.237246, 0.385906, -0.008839},{0.237627, 0.387078, -0.006827},{
      0.233487, 0.387734, -0.006827},{0.233487, 0.386501, -0.008839}}],
    Polygon[{{0.237627, 0.387078, -0.006827},{0.237907, 0.387937, -0.004647},{
      0.233487, 0.388637, -0.004647},{0.233487, 0.387734, -0.006827}}],
    Polygon[{{0.237907, 0.387937, -0.004647},{0.238077, 0.388461, -0.002352},{
      0.233487, 0.389188, -0.002352},{0.233487, 0.388637, -0.004647}}],
    Polygon[{{0.238077, 0.388461, -0.002352},{0.238134, 0.388637, 0.000000},{
      0.233487, 0.389373, 0.000000},{0.233487, 0.389188, -0.002352}}],
    Polygon[{{0.238134, 0.388637, 0.000000},{0.238077, 0.388461, 0.002352},{
      0.233487, 0.389188, 0.002352},{0.233487, 0.389373, 0.000000}}],
    Polygon[{{0.238077, 0.388461, 0.002352},{0.237907, 0.387937, 0.004647},{
      0.233487, 0.388637, 0.004647},{0.233487, 0.389188, 0.002352}}],
    Polygon[{{0.237907, 0.387937, 0.004647},{0.237627, 0.387078, 0.006827},{
      0.233487, 0.387734, 0.006827},{0.233487, 0.388637, 0.004647}}],
    Polygon[{{0.237627, 0.387078, 0.006827},{0.237246, 0.385906, 0.008839},{
      0.233487, 0.386501, 0.008839},{0.233487, 0.387734, 0.006827}}],
    Polygon[{{0.237246, 0.385906, 0.008839},{0.236773, 0.384448, 0.010634},{
      0.233487, 0.384968, 0.010634},{0.233487, 0.386501, 0.008839}}],
    Polygon[{{0.236773, 0.384448, 0.010634},{0.236218, 0.382741, 0.012166},{
      0.233487, 0.383174, 0.012166},{0.233487, 0.384968, 0.010634}}],
    Polygon[{{0.236218, 0.382741, 0.012166},{0.235597, 0.380828, 0.013399},{
      0.233487, 0.381162, 0.013399},{0.233487, 0.383174, 0.012166}}],
    Polygon[{{0.235597, 0.380828, 0.013399},{0.234923, 0.378754, 0.014302},{
      0.233487, 0.378982, 0.014302},{0.233487, 0.381162, 0.013399}}],
    Polygon[{{0.234923, 0.378754, 0.014302},{0.234214, 0.376572, 0.014853},{
      0.233487, 0.376687, 0.014853},{0.233487, 0.378982, 0.014302}}],
    Polygon[{{0.233487, 0.376687, -0.014853},{0.233487, 0.378982, -0.014302},{
      0.232051, 0.378754, -0.014302},{0.232760, 0.376572, -0.014853}}],
    Polygon[{{0.233487, 0.378982, -0.014302},{0.233487, 0.381162, -0.013399},{
      0.231377, 0.380828, -0.013399},{0.232051, 0.378754, -0.014302}}],
    Polygon[{{0.233487, 0.381162, -0.013399},{0.233487, 0.383174, -0.012166},{
      0.230755, 0.382741, -0.012166},{0.231377, 0.380828, -0.013399}}],
    Polygon[{{0.233487, 0.383174, -0.012166},{0.233487, 0.384968, -0.010634},{
      0.230201, 0.384448, -0.010634},{0.230755, 0.382741, -0.012166}}],
    Polygon[{{0.233487, 0.384968, -0.010634},{0.233487, 0.386501, -0.008839},{
      0.229727, 0.385906, -0.008839},{0.230201, 0.384448, -0.010634}}],
    Polygon[{{0.233487, 0.386501, -0.008839},{0.233487, 0.387734, -0.006827},{
      0.229346, 0.387078, -0.006827},{0.229727, 0.385906, -0.008839}}],
    Polygon[{{0.233487, 0.387734, -0.006827},{0.233487, 0.388637, -0.004647},{
      0.229067, 0.387937, -0.004647},{0.229346, 0.387078, -0.006827}}],
    Polygon[{{0.233487, 0.388637, -0.004647},{0.233487, 0.389188, -0.002352},{
      0.228897, 0.388461, -0.002352},{0.229067, 0.387937, -0.004647}}],
    Polygon[{{0.233487, 0.389188, -0.002352},{0.233487, 0.389373, 0.000000},{
      0.228840, 0.388637, 0.000000},{0.228897, 0.388461, -0.002352}}],
    Polygon[{{0.233487, 0.389373, 0.000000},{0.233487, 0.389188, 0.002352},{
      0.228897, 0.388461, 0.002352},{0.228840, 0.388637, 0.000000}}],
    Polygon[{{0.233487, 0.389188, 0.002352},{0.233487, 0.388637, 0.004647},{
      0.229067, 0.387937, 0.004647},{0.228897, 0.388461, 0.002352}}],
    Polygon[{{0.233487, 0.388637, 0.004647},{0.233487, 0.387734, 0.006827},{
      0.229346, 0.387078, 0.006827},{0.229067, 0.387937, 0.004647}}],
    Polygon[{{0.233487, 0.387734, 0.006827},{0.233487, 0.386501, 0.008839},{
      0.229727, 0.385906, 0.008839},{0.229346, 0.387078, 0.006827}}],
    Polygon[{{0.233487, 0.386501, 0.008839},{0.233487, 0.384968, 0.010634},{
      0.230201, 0.384448, 0.010634},{0.229727, 0.385906, 0.008839}}],
    Polygon[{{0.233487, 0.384968, 0.010634},{0.233487, 0.383174, 0.012166},{
      0.230755, 0.382741, 0.012166},{0.230201, 0.384448, 0.010634}}],
    Polygon[{{0.233487, 0.383174, 0.012166},{0.233487, 0.381162, 0.013399},{
      0.231377, 0.380828, 0.013399},{0.230755, 0.382741, 0.012166}}],
    Polygon[{{0.233487, 0.381162, 0.013399},{0.233487, 0.378982, 0.014302},{
      0.232051, 0.378754, 0.014302},{0.231377, 0.380828, 0.013399}}],
    Polygon[{{0.233487, 0.378982, 0.014302},{0.233487, 0.376687, 0.014853},{
      0.232760, 0.376572, 0.014853},{0.232051, 0.378754, 0.014302}}],
    Polygon[{{0.232760, 0.376572, -0.014853},{0.232051, 0.378754, -0.014302},{
      0.230755, 0.378094, -0.014302},{0.232104, 0.376238, -0.014853}}],
    Polygon[{{0.232051, 0.378754, -0.014302},{0.231377, 0.380828, -0.013399},{
      0.229474, 0.379858, -0.013399},{0.230755, 0.378094, -0.014302}}],
    Polygon[{{0.231377, 0.380828, -0.013399},{0.230755, 0.382741, -0.012166},{
      0.228291, 0.381486, -0.012166},{0.229474, 0.379858, -0.013399}}],
    Polygon[{{0.230755, 0.382741, -0.012166},{0.230201, 0.384448, -0.010634},{
      0.227237, 0.382938, -0.010634},{0.228291, 0.381486, -0.012166}}],
    Polygon[{{0.230201, 0.384448, -0.010634},{0.229727, 0.385906, -0.008839},{
      0.226336, 0.384178, -0.008839},{0.227237, 0.382938, -0.010634}}],
    Polygon[{{0.229727, 0.385906, -0.008839},{0.229346, 0.387078, -0.006827},{
      0.225611, 0.385175, -0.006827},{0.226336, 0.384178, -0.008839}}],
    Polygon[{{0.229346, 0.387078, -0.006827},{0.229067, 0.387937, -0.004647},{
      0.225080, 0.385906, -0.004647},{0.225611, 0.385175, -0.006827}}],
    Polygon[{{0.229067, 0.387937, -0.004647},{0.228897, 0.388461, -0.002352},{
      0.224757, 0.386351, -0.002352},{0.225080, 0.385906, -0.004647}}],
    Polygon[{{0.228897, 0.388461, -0.002352},{0.228840, 0.388637, 0.000000},{
      0.224648, 0.386501, 0.000000},{0.224757, 0.386351, -0.002352}}],
    Polygon[{{0.228840, 0.388637, 0.000000},{0.228897, 0.388461, 0.002352},{
      0.224757, 0.386351, 0.002352},{0.224648, 0.386501, 0.000000}}],
    Polygon[{{0.228897, 0.388461, 0.002352},{0.229067, 0.387937, 0.004647},{
      0.225080, 0.385906, 0.004647},{0.224757, 0.386351, 0.002352}}],
    Polygon[{{0.229067, 0.387937, 0.004647},{0.229346, 0.387078, 0.006827},{
      0.225611, 0.385175, 0.006827},{0.225080, 0.385906, 0.004647}}],
    Polygon[{{0.229346, 0.387078, 0.006827},{0.229727, 0.385906, 0.008839},{
      0.226336, 0.384178, 0.008839},{0.225611, 0.385175, 0.006827}}],
    Polygon[{{0.229727, 0.385906, 0.008839},{0.230201, 0.384448, 0.010634},{
      0.227237, 0.382938, 0.010634},{0.226336, 0.384178, 0.008839}}],
    Polygon[{{0.230201, 0.384448, 0.010634},{0.230755, 0.382741, 0.012166},{
      0.228291, 0.381486, 0.012166},{0.227237, 0.382938, 0.010634}}],
    Polygon[{{0.230755, 0.382741, 0.012166},{0.231377, 0.380828, 0.013399},{
      0.229474, 0.379858, 0.013399},{0.228291, 0.381486, 0.012166}}],
    Polygon[{{0.231377, 0.380828, 0.013399},{0.232051, 0.378754, 0.014302},{
      0.230755, 0.378094, 0.014302},{0.229474, 0.379858, 0.013399}}],
    Polygon[{{0.232051, 0.378754, 0.014302},{0.232760, 0.376572, 0.014853},{
      0.232104, 0.376238, 0.014853},{0.230755, 0.378094, 0.014302}}],
    Polygon[{{0.232104, 0.376238, -0.014853},{0.230755, 0.378094, -0.014302},{
      0.229727, 0.377066, -0.014302},{0.231584, 0.375718, -0.014853}}],
    Polygon[{{0.230755, 0.378094, -0.014302},{0.229474, 0.379858, -0.013399},{
      0.227964, 0.378348, -0.013399},{0.229727, 0.377066, -0.014302}}],
    Polygon[{{0.229474, 0.379858, -0.013399},{0.228291, 0.381486, -0.012166},{
      0.226336, 0.379530, -0.012166},{0.227964, 0.378348, -0.013399}}],
    Polygon[{{0.228291, 0.381486, -0.012166},{0.227237, 0.382938, -0.010634},{
      0.224884, 0.380585, -0.010634},{0.226336, 0.379530, -0.012166}}],
    Polygon[{{0.227237, 0.382938, -0.010634},{0.226336, 0.384178, -0.008839},{
      0.223644, 0.381486, -0.008839},{0.224884, 0.380585, -0.010634}}],
    Polygon[{{0.226336, 0.384178, -0.008839},{0.225611, 0.385175, -0.006827},{
      0.222647, 0.382211, -0.006827},{0.223644, 0.381486, -0.008839}}],
    Polygon[{{0.225611, 0.385175, -0.006827},{0.225080, 0.385906, -0.004647},{
      0.221916, 0.382741, -0.004647},{0.222647, 0.382211, -0.006827}}],
    Polygon[{{0.225080, 0.385906, -0.004647},{0.224757, 0.386351, -0.002352},{
      0.221471, 0.383065, -0.002352},{0.221916, 0.382741, -0.004647}}],
    Polygon[{{0.224757, 0.386351, -0.002352},{0.224648, 0.386501, 0.000000},{
      0.221321, 0.383174, 0.000000},{0.221471, 0.383065, -0.002352}}],
    Polygon[{{0.224648, 0.386501, 0.000000},{0.224757, 0.386351, 0.002352},{
      0.221471, 0.383065, 0.002352},{0.221321, 0.383174, 0.000000}}],
    Polygon[{{0.224757, 0.386351, 0.002352},{0.225080, 0.385906, 0.004647},{
      0.221916, 0.382741, 0.004647},{0.221471, 0.383065, 0.002352}}],
    Polygon[{{0.225080, 0.385906, 0.004647},{0.225611, 0.385175, 0.006827},{
      0.222647, 0.382211, 0.006827},{0.221916, 0.382741, 0.004647}}],
    Polygon[{{0.225611, 0.385175, 0.006827},{0.226336, 0.384178, 0.008839},{
      0.223644, 0.381486, 0.008839},{0.222647, 0.382211, 0.006827}}],
    Polygon[{{0.226336, 0.384178, 0.008839},{0.227237, 0.382938, 0.010634},{
      0.224884, 0.380585, 0.010634},{0.223644, 0.381486, 0.008839}}],
    Polygon[{{0.227237, 0.382938, 0.010634},{0.228291, 0.381486, 0.012166},{
      0.226336, 0.379530, 0.012166},{0.224884, 0.380585, 0.010634}}],
    Polygon[{{0.228291, 0.381486, 0.012166},{0.229474, 0.379858, 0.013399},{
      0.227964, 0.378348, 0.013399},{0.226336, 0.379530, 0.012166}}],
    Polygon[{{0.229474, 0.379858, 0.013399},{0.230755, 0.378094, 0.014302},{
      0.229727, 0.377066, 0.014302},{0.227964, 0.378348, 0.013399}}],
    Polygon[{{0.230755, 0.378094, 0.014302},{0.232104, 0.376238, 0.014853},{
      0.231584, 0.375718, 0.014853},{0.229727, 0.377066, 0.014302}}],
    Polygon[{{0.231584, 0.375718, -0.014853},{0.229727, 0.377066, -0.014302},{
      0.229067, 0.375771, -0.014302},{0.231250, 0.375062, -0.014853}}],
    Polygon[{{0.229727, 0.377066, -0.014302},{0.227964, 0.378348, -0.013399},{
      0.226994, 0.376445, -0.013399},{0.229067, 0.375771, -0.014302}}],
    Polygon[{{0.227964, 0.378348, -0.013399},{0.226336, 0.379530, -0.012166},{
      0.225080, 0.377066, -0.012166},{0.226994, 0.376445, -0.013399}}],
    Polygon[{{0.226336, 0.379530, -0.012166},{0.224884, 0.380585, -0.010634},{
      0.223374, 0.377621, -0.010634},{0.225080, 0.377066, -0.012166}}],
    Polygon[{{0.224884, 0.380585, -0.010634},{0.223644, 0.381486, -0.008839},{
      0.221916, 0.378094, -0.008839},{0.223374, 0.377621, -0.010634}}],
    Polygon[{{0.223644, 0.381486, -0.008839},{0.222647, 0.382211, -0.006827},{
      0.220744, 0.378475, -0.006827},{0.221916, 0.378094, -0.008839}}],
    Polygon[{{0.222647, 0.382211, -0.006827},{0.221916, 0.382741, -0.004647},{
      0.219885, 0.378754, -0.004647},{0.220744, 0.378475, -0.006827}}],
    Polygon[{{0.221916, 0.382741, -0.004647},{0.221471, 0.383065, -0.002352},{
      0.219361, 0.378925, -0.002352},{0.219885, 0.378754, -0.004647}}],
    Polygon[{{0.221471, 0.383065, -0.002352},{0.221321, 0.383174, 0.000000},{
      0.219185, 0.378982, 0.000000},{0.219361, 0.378925, -0.002352}}],
    Polygon[{{0.221321, 0.383174, 0.000000},{0.221471, 0.383065, 0.002352},{
      0.219361, 0.378925, 0.002352},{0.219185, 0.378982, 0.000000}}],
    Polygon[{{0.221471, 0.383065, 0.002352},{0.221916, 0.382741, 0.004647},{
      0.219885, 0.378754, 0.004647},{0.219361, 0.378925, 0.002352}}],
    Polygon[{{0.221916, 0.382741, 0.004647},{0.222647, 0.382211, 0.006827},{
      0.220744, 0.378475, 0.006827},{0.219885, 0.378754, 0.004647}}],
    Polygon[{{0.222647, 0.382211, 0.006827},{0.223644, 0.381486, 0.008839},{
      0.221916, 0.378094, 0.008839},{0.220744, 0.378475, 0.006827}}],
    Polygon[{{0.223644, 0.381486, 0.008839},{0.224884, 0.380585, 0.010634},{
      0.223374, 0.377621, 0.010634},{0.221916, 0.378094, 0.008839}}],
    Polygon[{{0.224884, 0.380585, 0.010634},{0.226336, 0.379530, 0.012166},{
      0.225080, 0.377066, 0.012166},{0.223374, 0.377621, 0.010634}}],
    Polygon[{{0.226336, 0.379530, 0.012166},{0.227964, 0.378348, 0.013399},{
      0.226994, 0.376445, 0.013399},{0.225080, 0.377066, 0.012166}}],
    Polygon[{{0.227964, 0.378348, 0.013399},{0.229727, 0.377066, 0.014302},{
      0.229067, 0.375771, 0.014302},{0.226994, 0.376445, 0.013399}}],
    Polygon[{{0.229727, 0.377066, 0.014302},{0.231584, 0.375718, 0.014853},{
      0.231250, 0.375062, 0.014853},{0.229067, 0.375771, 0.014302}}],
    Polygon[{{0.231250, 0.375062, -0.014853},{0.229067, 0.375771, -0.014302},{
      0.228840, 0.374335, -0.014302},{0.231134, 0.374335, -0.014853}}],
    Polygon[{{0.229067, 0.375771, -0.014302},{0.226994, 0.376445, -0.013399},{
      0.226660, 0.374335, -0.013399},{0.228840, 0.374335, -0.014302}}],
    Polygon[{{0.226994, 0.376445, -0.013399},{0.225080, 0.377066, -0.012166},{
      0.224648, 0.374335, -0.012166},{0.226660, 0.374335, -0.013399}}],
    Polygon[{{0.225080, 0.377066, -0.012166},{0.223374, 0.377621, -0.010634},{
      0.222853, 0.374335, -0.010634},{0.224648, 0.374335, -0.012166}}],
    Polygon[{{0.223374, 0.377621, -0.010634},{0.221916, 0.378094, -0.008839},{
      0.221321, 0.374335, -0.008839},{0.222853, 0.374335, -0.010634}}],
    Polygon[{{0.221916, 0.378094, -0.008839},{0.220744, 0.378475, -0.006827},{
      0.220088, 0.374335, -0.006827},{0.221321, 0.374335, -0.008839}}],
    Polygon[{{0.220744, 0.378475, -0.006827},{0.219885, 0.378754, -0.004647},{
      0.219185, 0.374335, -0.004647},{0.220088, 0.374335, -0.006827}}],
    Polygon[{{0.219885, 0.378754, -0.004647},{0.219361, 0.378925, -0.002352},{
      0.218634, 0.374335, -0.002352},{0.219185, 0.374335, -0.004647}}],
    Polygon[{{0.219361, 0.378925, -0.002352},{0.219185, 0.378982, 0.000000},{
      0.218449, 0.374335, 0.000000},{0.218634, 0.374335, -0.002352}}],
    Polygon[{{0.219185, 0.378982, 0.000000},{0.219361, 0.378925, 0.002352},{
      0.218634, 0.374335, 0.002352},{0.218449, 0.374335, 0.000000}}],
    Polygon[{{0.219361, 0.378925, 0.002352},{0.219885, 0.378754, 0.004647},{
      0.219185, 0.374335, 0.004647},{0.218634, 0.374335, 0.002352}}],
    Polygon[{{0.219885, 0.378754, 0.004647},{0.220744, 0.378475, 0.006827},{
      0.220088, 0.374335, 0.006827},{0.219185, 0.374335, 0.004647}}],
    Polygon[{{0.220744, 0.378475, 0.006827},{0.221916, 0.378094, 0.008839},{
      0.221321, 0.374335, 0.008839},{0.220088, 0.374335, 0.006827}}],
    Polygon[{{0.221916, 0.378094, 0.008839},{0.223374, 0.377621, 0.010634},{
      0.222853, 0.374335, 0.010634},{0.221321, 0.374335, 0.008839}}],
    Polygon[{{0.223374, 0.377621, 0.010634},{0.225080, 0.377066, 0.012166},{
      0.224648, 0.374335, 0.012166},{0.222853, 0.374335, 0.010634}}],
    Polygon[{{0.225080, 0.377066, 0.012166},{0.226994, 0.376445, 0.013399},{
      0.226660, 0.374335, 0.013399},{0.224648, 0.374335, 0.012166}}],
    Polygon[{{0.226994, 0.376445, 0.013399},{0.229067, 0.375771, 0.014302},{
      0.228840, 0.374335, 0.014302},{0.226660, 0.374335, 0.013399}}],
    Polygon[{{0.229067, 0.375771, 0.014302},{0.231250, 0.375062, 0.014853},{
      0.231134, 0.374335, 0.014853},{0.228840, 0.374335, 0.014302}}],
    Polygon[{{0.231134, 0.374335, -0.014853},{0.228840, 0.374335, -0.014302},{
      0.229067, 0.372899, -0.014302},{0.231250, 0.373608, -0.014853}}],
    Polygon[{{0.228840, 0.374335, -0.014302},{0.226660, 0.374335, -0.013399},{
      0.226994, 0.372225, -0.013399},{0.229067, 0.372899, -0.014302}}],
    Polygon[{{0.226660, 0.374335, -0.013399},{0.224648, 0.374335, -0.012166},{
      0.225080, 0.371603, -0.012166},{0.226994, 0.372225, -0.013399}}],
    Polygon[{{0.224648, 0.374335, -0.012166},{0.222853, 0.374335, -0.010634},{
      0.223374, 0.371049, -0.010634},{0.225080, 0.371603, -0.012166}}],
    Polygon[{{0.222853, 0.374335, -0.010634},{0.221321, 0.374335, -0.008839},{
      0.221916, 0.370575, -0.008839},{0.223374, 0.371049, -0.010634}}],
    Polygon[{{0.221321, 0.374335, -0.008839},{0.220088, 0.374335, -0.006827},{
      0.220744, 0.370194, -0.006827},{0.221916, 0.370575, -0.008839}}],
    Polygon[{{0.220088, 0.374335, -0.006827},{0.219185, 0.374335, -0.004647},{
      0.219885, 0.369915, -0.004647},{0.220744, 0.370194, -0.006827}}],
    Polygon[{{0.219185, 0.374335, -0.004647},{0.218634, 0.374335, -0.002352},{
      0.219361, 0.369745, -0.002352},{0.219885, 0.369915, -0.004647}}],
    Polygon[{{0.218634, 0.374335, -0.002352},{0.218449, 0.374335, 0.000000},{
      0.219185, 0.369688, 0.000000},{0.219361, 0.369745, -0.002352}}],
    Polygon[{{0.218449, 0.374335, 0.000000},{0.218634, 0.374335, 0.002352},{
      0.219361, 0.369745, 0.002352},{0.219185, 0.369688, 0.000000}}],
    Polygon[{{0.218634, 0.374335, 0.002352},{0.219185, 0.374335, 0.004647},{
      0.219885, 0.369915, 0.004647},{0.219361, 0.369745, 0.002352}}],
    Polygon[{{0.219185, 0.374335, 0.004647},{0.220088, 0.374335, 0.006827},{
      0.220744, 0.370194, 0.006827},{0.219885, 0.369915, 0.004647}}],
    Polygon[{{0.220088, 0.374335, 0.006827},{0.221321, 0.374335, 0.008839},{
      0.221916, 0.370575, 0.008839},{0.220744, 0.370194, 0.006827}}],
    Polygon[{{0.221321, 0.374335, 0.008839},{0.222853, 0.374335, 0.010634},{
      0.223374, 0.371049, 0.010634},{0.221916, 0.370575, 0.008839}}],
    Polygon[{{0.222853, 0.374335, 0.010634},{0.224648, 0.374335, 0.012166},{
      0.225080, 0.371603, 0.012166},{0.223374, 0.371049, 0.010634}}],
    Polygon[{{0.224648, 0.374335, 0.012166},{0.226660, 0.374335, 0.013399},{
      0.226994, 0.372225, 0.013399},{0.225080, 0.371603, 0.012166}}],
    Polygon[{{0.226660, 0.374335, 0.013399},{0.228840, 0.374335, 0.014302},{
      0.229067, 0.372899, 0.014302},{0.226994, 0.372225, 0.013399}}],
    Polygon[{{0.228840, 0.374335, 0.014302},{0.231134, 0.374335, 0.014853},{
      0.231250, 0.373608, 0.014853},{0.229067, 0.372899, 0.014302}}],
    Polygon[{{0.231250, 0.373608, -0.014853},{0.229067, 0.372899, -0.014302},{
      0.229727, 0.371603, -0.014302},{0.231584, 0.372952, -0.014853}}],
    Polygon[{{0.229067, 0.372899, -0.014302},{0.226994, 0.372225, -0.013399},{
      0.227964, 0.370322, -0.013399},{0.229727, 0.371603, -0.014302}}],
    Polygon[{{0.226994, 0.372225, -0.013399},{0.225080, 0.371603, -0.012166},{
      0.226336, 0.369139, -0.012166},{0.227964, 0.370322, -0.013399}}],
    Polygon[{{0.225080, 0.371603, -0.012166},{0.223374, 0.371049, -0.010634},{
      0.224884, 0.368085, -0.010634},{0.226336, 0.369139, -0.012166}}],
    Polygon[{{0.223374, 0.371049, -0.010634},{0.221916, 0.370575, -0.008839},{
      0.223644, 0.367184, -0.008839},{0.224884, 0.368085, -0.010634}}],
    Polygon[{{0.221916, 0.370575, -0.008839},{0.220744, 0.370194, -0.006827},{
      0.222647, 0.366459, -0.006827},{0.223644, 0.367184, -0.008839}}],
    Polygon[{{0.220744, 0.370194, -0.006827},{0.219885, 0.369915, -0.004647},{
      0.221916, 0.365928, -0.004647},{0.222647, 0.366459, -0.006827}}],
    Polygon[{{0.219885, 0.369915, -0.004647},{0.219361, 0.369745, -0.002352},{
      0.221471, 0.365604, -0.002352},{0.221916, 0.365928, -0.004647}}],
    Polygon[{{0.219361, 0.369745, -0.002352},{0.219185, 0.369688, 0.000000},{
      0.221321, 0.365496, 0.000000},{0.221471, 0.365604, -0.002352}}],
    Polygon[{{0.219185, 0.369688, 0.000000},{0.219361, 0.369745, 0.002352},{
      0.221471, 0.365604, 0.002352},{0.221321, 0.365496, 0.000000}}],
    Polygon[{{0.219361, 0.369745, 0.002352},{0.219885, 0.369915, 0.004647},{
      0.221916, 0.365928, 0.004647},{0.221471, 0.365604, 0.002352}}],
    Polygon[{{0.219885, 0.369915, 0.004647},{0.220744, 0.370194, 0.006827},{
      0.222647, 0.366459, 0.006827},{0.221916, 0.365928, 0.004647}}],
    Polygon[{{0.220744, 0.370194, 0.006827},{0.221916, 0.370575, 0.008839},{
      0.223644, 0.367184, 0.008839},{0.222647, 0.366459, 0.006827}}],
    Polygon[{{0.221916, 0.370575, 0.008839},{0.223374, 0.371049, 0.010634},{
      0.224884, 0.368085, 0.010634},{0.223644, 0.367184, 0.008839}}],
    Polygon[{{0.223374, 0.371049, 0.010634},{0.225080, 0.371603, 0.012166},{
      0.226336, 0.369139, 0.012166},{0.224884, 0.368085, 0.010634}}],
    Polygon[{{0.225080, 0.371603, 0.012166},{0.226994, 0.372225, 0.013399},{
      0.227964, 0.370322, 0.013399},{0.226336, 0.369139, 0.012166}}],
    Polygon[{{0.226994, 0.372225, 0.013399},{0.229067, 0.372899, 0.014302},{
      0.229727, 0.371603, 0.014302},{0.227964, 0.370322, 0.013399}}],
    Polygon[{{0.229067, 0.372899, 0.014302},{0.231250, 0.373608, 0.014853},{
      0.231584, 0.372952, 0.014853},{0.229727, 0.371603, 0.014302}}],
    Polygon[{{0.231584, 0.372952, -0.014853},{0.229727, 0.371603, -0.014302},{
      0.230755, 0.370575, -0.014302},{0.232104, 0.372432, -0.014853}}],
    Polygon[{{0.229727, 0.371603, -0.014302},{0.227964, 0.370322, -0.013399},{
      0.229474, 0.368812, -0.013399},{0.230755, 0.370575, -0.014302}}],
    Polygon[{{0.227964, 0.370322, -0.013399},{0.226336, 0.369139, -0.012166},{
      0.228291, 0.367184, -0.012166},{0.229474, 0.368812, -0.013399}}],
    Polygon[{{0.226336, 0.369139, -0.012166},{0.224884, 0.368085, -0.010634},{
      0.227237, 0.365732, -0.010634},{0.228291, 0.367184, -0.012166}}],
    Polygon[{{0.224884, 0.368085, -0.010634},{0.223644, 0.367184, -0.008839},{
      0.226336, 0.364492, -0.008839},{0.227237, 0.365732, -0.010634}}],
    Polygon[{{0.223644, 0.367184, -0.008839},{0.222647, 0.366459, -0.006827},{
      0.225611, 0.363495, -0.006827},{0.226336, 0.364492, -0.008839}}],
    Polygon[{{0.222647, 0.366459, -0.006827},{0.221916, 0.365928, -0.004647},{
      0.225080, 0.362764, -0.004647},{0.225611, 0.363495, -0.006827}}],
    Polygon[{{0.221916, 0.365928, -0.004647},{0.221471, 0.365604, -0.002352},{
      0.224757, 0.362319, -0.002352},{0.225080, 0.362764, -0.004647}}],
    Polygon[{{0.221471, 0.365604, -0.002352},{0.221321, 0.365496, 0.000000},{
      0.224648, 0.362169, 0.000000},{0.224757, 0.362319, -0.002352}}],
    Polygon[{{0.221321, 0.365496, 0.000000},{0.221471, 0.365604, 0.002352},{
      0.224757, 0.362319, 0.002352},{0.224648, 0.362169, 0.000000}}],
    Polygon[{{0.221471, 0.365604, 0.002352},{0.221916, 0.365928, 0.004647},{
      0.225080, 0.362764, 0.004647},{0.224757, 0.362319, 0.002352}}],
    Polygon[{{0.221916, 0.365928, 0.004647},{0.222647, 0.366459, 0.006827},{
      0.225611, 0.363495, 0.006827},{0.225080, 0.362764, 0.004647}}],
    Polygon[{{0.222647, 0.366459, 0.006827},{0.223644, 0.367184, 0.008839},{
      0.226336, 0.364492, 0.008839},{0.225611, 0.363495, 0.006827}}],
    Polygon[{{0.223644, 0.367184, 0.008839},{0.224884, 0.368085, 0.010634},{
      0.227237, 0.365732, 0.010634},{0.226336, 0.364492, 0.008839}}],
    Polygon[{{0.224884, 0.368085, 0.010634},{0.226336, 0.369139, 0.012166},{
      0.228291, 0.367184, 0.012166},{0.227237, 0.365732, 0.010634}}],
    Polygon[{{0.226336, 0.369139, 0.012166},{0.227964, 0.370322, 0.013399},{
      0.229474, 0.368812, 0.013399},{0.228291, 0.367184, 0.012166}}],
    Polygon[{{0.227964, 0.370322, 0.013399},{0.229727, 0.371603, 0.014302},{
      0.230755, 0.370575, 0.014302},{0.229474, 0.368812, 0.013399}}],
    Polygon[{{0.229727, 0.371603, 0.014302},{0.231584, 0.372952, 0.014853},{
      0.232104, 0.372432, 0.014853},{0.230755, 0.370575, 0.014302}}],
    Polygon[{{0.232104, 0.372432, -0.014853},{0.230755, 0.370575, -0.014302},{
      0.232051, 0.369915, -0.014302},{0.232760, 0.372098, -0.014853}}],
    Polygon[{{0.230755, 0.370575, -0.014302},{0.229474, 0.368812, -0.013399},{
      0.231377, 0.367842, -0.013399},{0.232051, 0.369915, -0.014302}}],
    Polygon[{{0.229474, 0.368812, -0.013399},{0.228291, 0.367184, -0.012166},{
      0.230755, 0.365928, -0.012166},{0.231377, 0.367842, -0.013399}}],
    Polygon[{{0.228291, 0.367184, -0.012166},{0.227237, 0.365732, -0.010634},{
      0.230201, 0.364222, -0.010634},{0.230755, 0.365928, -0.012166}}],
    Polygon[{{0.227237, 0.365732, -0.010634},{0.226336, 0.364492, -0.008839},{
      0.229727, 0.362764, -0.008839},{0.230201, 0.364222, -0.010634}}],
    Polygon[{{0.226336, 0.364492, -0.008839},{0.225611, 0.363495, -0.006827},{
      0.229346, 0.361592, -0.006827},{0.229727, 0.362764, -0.008839}}],
    Polygon[{{0.225611, 0.363495, -0.006827},{0.225080, 0.362764, -0.004647},{
      0.229067, 0.360733, -0.004647},{0.229346, 0.361592, -0.006827}}],
    Polygon[{{0.225080, 0.362764, -0.004647},{0.224757, 0.362319, -0.002352},{
      0.228897, 0.360209, -0.002352},{0.229067, 0.360733, -0.004647}}],
    Polygon[{{0.224757, 0.362319, -0.002352},{0.224648, 0.362169, 0.000000},{
      0.228840, 0.360033, 0.000000},{0.228897, 0.360209, -0.002352}}],
    Polygon[{{0.224648, 0.362169, 0.000000},{0.224757, 0.362319, 0.002352},{
      0.228897, 0.360209, 0.002352},{0.228840, 0.360033, 0.000000}}],
    Polygon[{{0.224757, 0.362319, 0.002352},{0.225080, 0.362764, 0.004647},{
      0.229067, 0.360733, 0.004647},{0.228897, 0.360209, 0.002352}}],
    Polygon[{{0.225080, 0.362764, 0.004647},{0.225611, 0.363495, 0.006827},{
      0.229346, 0.361592, 0.006827},{0.229067, 0.360733, 0.004647}}],
    Polygon[{{0.225611, 0.363495, 0.006827},{0.226336, 0.364492, 0.008839},{
      0.229727, 0.362764, 0.008839},{0.229346, 0.361592, 0.006827}}],
    Polygon[{{0.226336, 0.364492, 0.008839},{0.227237, 0.365732, 0.010634},{
      0.230201, 0.364222, 0.010634},{0.229727, 0.362764, 0.008839}}],
    Polygon[{{0.227237, 0.365732, 0.010634},{0.228291, 0.367184, 0.012166},{
      0.230755, 0.365928, 0.012166},{0.230201, 0.364222, 0.010634}}],
    Polygon[{{0.228291, 0.367184, 0.012166},{0.229474, 0.368812, 0.013399},{
      0.231377, 0.367842, 0.013399},{0.230755, 0.365928, 0.012166}}],
    Polygon[{{0.229474, 0.368812, 0.013399},{0.230755, 0.370575, 0.014302},{
      0.232051, 0.369915, 0.014302},{0.231377, 0.367842, 0.013399}}],
    Polygon[{{0.230755, 0.370575, 0.014302},{0.232104, 0.372432, 0.014853},{
      0.232760, 0.372098, 0.014853},{0.232051, 0.369915, 0.014302}}],
    Polygon[{{0.232760, 0.372098, -0.014853},{0.232051, 0.369915, -0.014302},{
      0.233487, 0.369688, -0.014302},{0.233487, 0.371982, -0.014853}}],
    Polygon[{{0.232051, 0.369915, -0.014302},{0.231377, 0.367842, -0.013399},{
      0.233487, 0.367508, -0.013399},{0.233487, 0.369688, -0.014302}}],
    Polygon[{{0.231377, 0.367842, -0.013399},{0.230755, 0.365928, -0.012166},{
      0.233487, 0.365496, -0.012166},{0.233487, 0.367508, -0.013399}}],
    Polygon[{{0.230755, 0.365928, -0.012166},{0.230201, 0.364222, -0.010634},{
      0.233487, 0.363701, -0.010634},{0.233487, 0.365496, -0.012166}}],
    Polygon[{{0.230201, 0.364222, -0.010634},{0.229727, 0.362764, -0.008839},{
      0.233487, 0.362169, -0.008839},{0.233487, 0.363701, -0.010634}}],
    Polygon[{{0.229727, 0.362764, -0.008839},{0.229346, 0.361592, -0.006827},{
      0.233487, 0.360936, -0.006827},{0.233487, 0.362169, -0.008839}}],
    Polygon[{{0.229346, 0.361592, -0.006827},{0.229067, 0.360733, -0.004647},{
      0.233487, 0.360033, -0.004647},{0.233487, 0.360936, -0.006827}}],
    Polygon[{{0.229067, 0.360733, -0.004647},{0.228897, 0.360209, -0.002352},{
      0.233487, 0.359482, -0.002352},{0.233487, 0.360033, -0.004647}}],
    Polygon[{{0.228897, 0.360209, -0.002352},{0.228840, 0.360033, 0.000000},{
      0.233487, 0.359297, 0.000000},{0.233487, 0.359482, -0.002352}}],
    Polygon[{{0.228840, 0.360033, 0.000000},{0.228897, 0.360209, 0.002352},{
      0.233487, 0.359482, 0.002352},{0.233487, 0.359297, 0.000000}}],
    Polygon[{{0.228897, 0.360209, 0.002352},{0.229067, 0.360733, 0.004647},{
      0.233487, 0.360033, 0.004647},{0.233487, 0.359482, 0.002352}}],
    Polygon[{{0.229067, 0.360733, 0.004647},{0.229346, 0.361592, 0.006827},{
      0.233487, 0.360936, 0.006827},{0.233487, 0.360033, 0.004647}}],
    Polygon[{{0.229346, 0.361592, 0.006827},{0.229727, 0.362764, 0.008839},{
      0.233487, 0.362169, 0.008839},{0.233487, 0.360936, 0.006827}}],
    Polygon[{{0.229727, 0.362764, 0.008839},{0.230201, 0.364222, 0.010634},{
      0.233487, 0.363701, 0.010634},{0.233487, 0.362169, 0.008839}}],
    Polygon[{{0.230201, 0.364222, 0.010634},{0.230755, 0.365928, 0.012166},{
      0.233487, 0.365496, 0.012166},{0.233487, 0.363701, 0.010634}}],
    Polygon[{{0.230755, 0.365928, 0.012166},{0.231377, 0.367842, 0.013399},{
      0.233487, 0.367508, 0.013399},{0.233487, 0.365496, 0.012166}}],
    Polygon[{{0.231377, 0.367842, 0.013399},{0.232051, 0.369915, 0.014302},{
      0.233487, 0.369688, 0.014302},{0.233487, 0.367508, 0.013399}}],
    Polygon[{{0.232051, 0.369915, 0.014302},{0.232760, 0.372098, 0.014853},{
      0.233487, 0.371982, 0.014853},{0.233487, 0.369688, 0.014302}}],
    Polygon[{{0.233487, 0.371982, -0.014853},{0.233487, 0.369688, -0.014302},{
      0.234923, 0.369915, -0.014302},{0.234214, 0.372098, -0.014853}}],
    Polygon[{{0.233487, 0.369688, -0.014302},{0.233487, 0.367508, -0.013399},{
      0.235597, 0.367842, -0.013399},{0.234923, 0.369915, -0.014302}}],
    Polygon[{{0.233487, 0.367508, -0.013399},{0.233487, 0.365496, -0.012166},{
      0.236218, 0.365928, -0.012166},{0.235597, 0.367842, -0.013399}}],
    Polygon[{{0.233487, 0.365496, -0.012166},{0.233487, 0.363701, -0.010634},{
      0.236773, 0.364222, -0.010634},{0.236218, 0.365928, -0.012166}}],
    Polygon[{{0.233487, 0.363701, -0.010634},{0.233487, 0.362169, -0.008839},{
      0.237246, 0.362764, -0.008839},{0.236773, 0.364222, -0.010634}}],
    Polygon[{{0.233487, 0.362169, -0.008839},{0.233487, 0.360936, -0.006827},{
      0.237627, 0.361592, -0.006827},{0.237246, 0.362764, -0.008839}}],
    Polygon[{{0.233487, 0.360936, -0.006827},{0.233487, 0.360033, -0.004647},{
      0.237907, 0.360733, -0.004647},{0.237627, 0.361592, -0.006827}}],
    Polygon[{{0.233487, 0.360033, -0.004647},{0.233487, 0.359482, -0.002352},{
      0.238077, 0.360209, -0.002352},{0.237907, 0.360733, -0.004647}}],
    Polygon[{{0.233487, 0.359482, -0.002352},{0.233487, 0.359297, 0.000000},{
      0.238134, 0.360033, 0.000000},{0.238077, 0.360209, -0.002352}}],
    Polygon[{{0.233487, 0.359297, 0.000000},{0.233487, 0.359482, 0.002352},{
      0.238077, 0.360209, 0.002352},{0.238134, 0.360033, 0.000000}}],
    Polygon[{{0.233487, 0.359482, 0.002352},{0.233487, 0.360033, 0.004647},{
      0.237907, 0.360733, 0.004647},{0.238077, 0.360209, 0.002352}}],
    Polygon[{{0.233487, 0.360033, 0.004647},{0.233487, 0.360936, 0.006827},{
      0.237627, 0.361592, 0.006827},{0.237907, 0.360733, 0.004647}}],
    Polygon[{{0.233487, 0.360936, 0.006827},{0.233487, 0.362169, 0.008839},{
      0.237246, 0.362764, 0.008839},{0.237627, 0.361592, 0.006827}}],
    Polygon[{{0.233487, 0.362169, 0.008839},{0.233487, 0.363701, 0.010634},{
      0.236773, 0.364222, 0.010634},{0.237246, 0.362764, 0.008839}}],
    Polygon[{{0.233487, 0.363701, 0.010634},{0.233487, 0.365496, 0.012166},{
      0.236218, 0.365928, 0.012166},{0.236773, 0.364222, 0.010634}}],
    Polygon[{{0.233487, 0.365496, 0.012166},{0.233487, 0.367508, 0.013399},{
      0.235597, 0.367842, 0.013399},{0.236218, 0.365928, 0.012166}}],
    Polygon[{{0.233487, 0.367508, 0.013399},{0.233487, 0.369688, 0.014302},{
      0.234923, 0.369915, 0.014302},{0.235597, 0.367842, 0.013399}}],
    Polygon[{{0.233487, 0.369688, 0.014302},{0.233487, 0.371982, 0.014853},{
      0.234214, 0.372098, 0.014853},{0.234923, 0.369915, 0.014302}}],
    Polygon[{{0.234214, 0.372098, -0.014853},{0.234923, 0.369915, -0.014302},{
      0.236218, 0.370575, -0.014302},{0.234870, 0.372432, -0.014853}}],
    Polygon[{{0.234923, 0.369915, -0.014302},{0.235597, 0.367842, -0.013399},{
      0.237500, 0.368812, -0.013399},{0.236218, 0.370575, -0.014302}}],
    Polygon[{{0.235597, 0.367842, -0.013399},{0.236218, 0.365928, -0.012166},{
      0.238682, 0.367184, -0.012166},{0.237500, 0.368812, -0.013399}}],
    Polygon[{{0.236218, 0.365928, -0.012166},{0.236773, 0.364222, -0.010634},{
      0.239737, 0.365732, -0.010634},{0.238682, 0.367184, -0.012166}}],
    Polygon[{{0.236773, 0.364222, -0.010634},{0.237246, 0.362764, -0.008839},{
      0.240638, 0.364492, -0.008839},{0.239737, 0.365732, -0.010634}}],
    Polygon[{{0.237246, 0.362764, -0.008839},{0.237627, 0.361592, -0.006827},{
      0.241363, 0.363495, -0.006827},{0.240638, 0.364492, -0.008839}}],
    Polygon[{{0.237627, 0.361592, -0.006827},{0.237907, 0.360733, -0.004647},{
      0.241894, 0.362764, -0.004647},{0.241363, 0.363495, -0.006827}}],
    Polygon[{{0.237907, 0.360733, -0.004647},{0.238077, 0.360209, -0.002352},{
      0.242217, 0.362319, -0.002352},{0.241894, 0.362764, -0.004647}}],
    Polygon[{{0.238077, 0.360209, -0.002352},{0.238134, 0.360033, 0.000000},{
      0.242326, 0.362169, 0.000000},{0.242217, 0.362319, -0.002352}}],
    Polygon[{{0.238134, 0.360033, 0.000000},{0.238077, 0.360209, 0.002352},{
      0.242217, 0.362319, 0.002352},{0.242326, 0.362169, 0.000000}}],
    Polygon[{{0.238077, 0.360209, 0.002352},{0.237907, 0.360733, 0.004647},{
      0.241894, 0.362764, 0.004647},{0.242217, 0.362319, 0.002352}}],
    Polygon[{{0.237907, 0.360733, 0.004647},{0.237627, 0.361592, 0.006827},{
      0.241363, 0.363495, 0.006827},{0.241894, 0.362764, 0.004647}}],
    Polygon[{{0.237627, 0.361592, 0.006827},{0.237246, 0.362764, 0.008839},{
      0.240638, 0.364492, 0.008839},{0.241363, 0.363495, 0.006827}}],
    Polygon[{{0.237246, 0.362764, 0.008839},{0.236773, 0.364222, 0.010634},{
      0.239737, 0.365732, 0.010634},{0.240638, 0.364492, 0.008839}}],
    Polygon[{{0.236773, 0.364222, 0.010634},{0.236218, 0.365928, 0.012166},{
      0.238682, 0.367184, 0.012166},{0.239737, 0.365732, 0.010634}}],
    Polygon[{{0.236218, 0.365928, 0.012166},{0.235597, 0.367842, 0.013399},{
      0.237500, 0.368812, 0.013399},{0.238682, 0.367184, 0.012166}}],
    Polygon[{{0.235597, 0.367842, 0.013399},{0.234923, 0.369915, 0.014302},{
      0.236218, 0.370575, 0.014302},{0.237500, 0.368812, 0.013399}}],
    Polygon[{{0.234923, 0.369915, 0.014302},{0.234214, 0.372098, 0.014853},{
      0.234870, 0.372432, 0.014853},{0.236218, 0.370575, 0.014302}}],
    Polygon[{{0.234870, 0.372432, -0.014853},{0.236218, 0.370575, -0.014302},{
      0.237246, 0.371603, -0.014302},{0.235390, 0.372952, -0.014853}}],
    Polygon[{{0.236218, 0.370575, -0.014302},{0.237500, 0.368812, -0.013399},{
      0.239010, 0.370322, -0.013399},{0.237246, 0.371603, -0.014302}}],
    Polygon[{{0.237500, 0.368812, -0.013399},{0.238682, 0.367184, -0.012166},{
      0.240638, 0.369139, -0.012166},{0.239010, 0.370322, -0.013399}}],
    Polygon[{{0.238682, 0.367184, -0.012166},{0.239737, 0.365732, -0.010634},{
      0.242090, 0.368085, -0.010634},{0.240638, 0.369139, -0.012166}}],
    Polygon[{{0.239737, 0.365732, -0.010634},{0.240638, 0.364492, -0.008839},{
      0.243330, 0.367184, -0.008839},{0.242090, 0.368085, -0.010634}}],
    Polygon[{{0.240638, 0.364492, -0.008839},{0.241363, 0.363495, -0.006827},{
      0.244327, 0.366459, -0.006827},{0.243330, 0.367184, -0.008839}}],
    Polygon[{{0.241363, 0.363495, -0.006827},{0.241894, 0.362764, -0.004647},{
      0.245058, 0.365928, -0.004647},{0.244327, 0.366459, -0.006827}}],
    Polygon[{{0.241894, 0.362764, -0.004647},{0.242217, 0.362319, -0.002352},{
      0.245503, 0.365604, -0.002352},{0.245058, 0.365928, -0.004647}}],
    Polygon[{{0.242217, 0.362319, -0.002352},{0.242326, 0.362169, 0.000000},{
      0.245653, 0.365496, 0.000000},{0.245503, 0.365604, -0.002352}}],
    Polygon[{{0.242326, 0.362169, 0.000000},{0.242217, 0.362319, 0.002352},{
      0.245503, 0.365604, 0.002352},{0.245653, 0.365496, 0.000000}}],
    Polygon[{{0.242217, 0.362319, 0.002352},{0.241894, 0.362764, 0.004647},{
      0.245058, 0.365928, 0.004647},{0.245503, 0.365604, 0.002352}}],
    Polygon[{{0.241894, 0.362764, 0.004647},{0.241363, 0.363495, 0.006827},{
      0.244327, 0.366459, 0.006827},{0.245058, 0.365928, 0.004647}}],
    Polygon[{{0.241363, 0.363495, 0.006827},{0.240638, 0.364492, 0.008839},{
      0.243330, 0.367184, 0.008839},{0.244327, 0.366459, 0.006827}}],
    Polygon[{{0.240638, 0.364492, 0.008839},{0.239737, 0.365732, 0.010634},{
      0.242090, 0.368085, 0.010634},{0.243330, 0.367184, 0.008839}}],
    Polygon[{{0.239737, 0.365732, 0.010634},{0.238682, 0.367184, 0.012166},{
      0.240638, 0.369139, 0.012166},{0.242090, 0.368085, 0.010634}}],
    Polygon[{{0.238682, 0.367184, 0.012166},{0.237500, 0.368812, 0.013399},{
      0.239010, 0.370322, 0.013399},{0.240638, 0.369139, 0.012166}}],
    Polygon[{{0.237500, 0.368812, 0.013399},{0.236218, 0.370575, 0.014302},{
      0.237246, 0.371603, 0.014302},{0.239010, 0.370322, 0.013399}}],
    Polygon[{{0.236218, 0.370575, 0.014302},{0.234870, 0.372432, 0.014853},{
      0.235390, 0.372952, 0.014853},{0.237246, 0.371603, 0.014302}}],
    Polygon[{{0.235390, 0.372952, -0.014853},{0.237246, 0.371603, -0.014302},{
      0.237907, 0.372899, -0.014302},{0.235724, 0.373608, -0.014853}}],
    Polygon[{{0.237246, 0.371603, -0.014302},{0.239010, 0.370322, -0.013399},{
      0.239980, 0.372225, -0.013399},{0.237907, 0.372899, -0.014302}}],
    Polygon[{{0.239010, 0.370322, -0.013399},{0.240638, 0.369139, -0.012166},{
      0.241894, 0.371603, -0.012166},{0.239980, 0.372225, -0.013399}}],
    Polygon[{{0.240638, 0.369139, -0.012166},{0.242090, 0.368085, -0.010634},{
      0.243600, 0.371049, -0.010634},{0.241894, 0.371603, -0.012166}}],
    Polygon[{{0.242090, 0.368085, -0.010634},{0.243330, 0.367184, -0.008839},{
      0.245058, 0.370575, -0.008839},{0.243600, 0.371049, -0.010634}}],
    Polygon[{{0.243330, 0.367184, -0.008839},{0.244327, 0.366459, -0.006827},{
      0.246230, 0.370194, -0.006827},{0.245058, 0.370575, -0.008839}}],
    Polygon[{{0.244327, 0.366459, -0.006827},{0.245058, 0.365928, -0.004647},{
      0.247089, 0.369915, -0.004647},{0.246230, 0.370194, -0.006827}}],
    Polygon[{{0.245058, 0.365928, -0.004647},{0.245503, 0.365604, -0.002352},{
      0.247613, 0.369745, -0.002352},{0.247089, 0.369915, -0.004647}}],
    Polygon[{{0.245503, 0.365604, -0.002352},{0.245653, 0.365496, 0.000000},{
      0.247789, 0.369688, 0.000000},{0.247613, 0.369745, -0.002352}}],
    Polygon[{{0.245653, 0.365496, 0.000000},{0.245503, 0.365604, 0.002352},{
      0.247613, 0.369745, 0.002352},{0.247789, 0.369688, 0.000000}}],
    Polygon[{{0.245503, 0.365604, 0.002352},{0.245058, 0.365928, 0.004647},{
      0.247089, 0.369915, 0.004647},{0.247613, 0.369745, 0.002352}}],
    Polygon[{{0.245058, 0.365928, 0.004647},{0.244327, 0.366459, 0.006827},{
      0.246230, 0.370194, 0.006827},{0.247089, 0.369915, 0.004647}}],
    Polygon[{{0.244327, 0.366459, 0.006827},{0.243330, 0.367184, 0.008839},{
      0.245058, 0.370575, 0.008839},{0.246230, 0.370194, 0.006827}}],
    Polygon[{{0.243330, 0.367184, 0.008839},{0.242090, 0.368085, 0.010634},{
      0.243600, 0.371049, 0.010634},{0.245058, 0.370575, 0.008839}}],
    Polygon[{{0.242090, 0.368085, 0.010634},{0.240638, 0.369139, 0.012166},{
      0.241894, 0.371603, 0.012166},{0.243600, 0.371049, 0.010634}}],
    Polygon[{{0.240638, 0.369139, 0.012166},{0.239010, 0.370322, 0.013399},{
      0.239980, 0.372225, 0.013399},{0.241894, 0.371603, 0.012166}}],
    Polygon[{{0.239010, 0.370322, 0.013399},{0.237246, 0.371603, 0.014302},{
      0.237907, 0.372899, 0.014302},{0.239980, 0.372225, 0.013399}}],
    Polygon[{{0.237246, 0.371603, 0.014302},{0.235390, 0.372952, 0.014853},{
      0.235724, 0.373608, 0.014853},{0.237907, 0.372899, 0.014302}}],
    Polygon[{{0.235724, 0.373608, -0.014853},{0.237907, 0.372899, -0.014302},{
      0.238134, 0.374335, -0.014302},{0.235839, 0.374335, -0.014853}}],
    Polygon[{{0.237907, 0.372899, -0.014302},{0.239980, 0.372225, -0.013399},{
      0.240314, 0.374335, -0.013399},{0.238134, 0.374335, -0.014302}}],
    Polygon[{{0.239980, 0.372225, -0.013399},{0.241894, 0.371603, -0.012166},{
      0.242326, 0.374335, -0.012166},{0.240314, 0.374335, -0.013399}}],
    Polygon[{{0.241894, 0.371603, -0.012166},{0.243600, 0.371049, -0.010634},{
      0.244121, 0.374335, -0.010634},{0.242326, 0.374335, -0.012166}}],
    Polygon[{{0.243600, 0.371049, -0.010634},{0.245058, 0.370575, -0.008839},{
      0.245653, 0.374335, -0.008839},{0.244121, 0.374335, -0.010634}}],
    Polygon[{{0.245058, 0.370575, -0.008839},{0.246230, 0.370194, -0.006827},{
      0.246886, 0.374335, -0.006827},{0.245653, 0.374335, -0.008839}}],
    Polygon[{{0.246230, 0.370194, -0.006827},{0.247089, 0.369915, -0.004647},{
      0.247789, 0.374335, -0.004647},{0.246886, 0.374335, -0.006827}}],
    Polygon[{{0.247089, 0.369915, -0.004647},{0.247613, 0.369745, -0.002352},{
      0.248340, 0.374335, -0.002352},{0.247789, 0.374335, -0.004647}}],
    Polygon[{{0.247613, 0.369745, -0.002352},{0.247789, 0.369688, 0.000000},{
      0.248525, 0.374335, 0.000000},{0.248340, 0.374335, -0.002352}}],
    Polygon[{{0.247789, 0.369688, 0.000000},{0.247613, 0.369745, 0.002352},{
      0.248340, 0.374335, 0.002352},{0.248525, 0.374335, 0.000000}}],
    Polygon[{{0.247613, 0.369745, 0.002352},{0.247089, 0.369915, 0.004647},{
      0.247789, 0.374335, 0.004647},{0.248340, 0.374335, 0.002352}}],
    Polygon[{{0.247089, 0.369915, 0.004647},{0.246230, 0.370194, 0.006827},{
      0.246886, 0.374335, 0.006827},{0.247789, 0.374335, 0.004647}}],
    Polygon[{{0.246230, 0.370194, 0.006827},{0.245058, 0.370575, 0.008839},{
      0.245653, 0.374335, 0.008839},{0.246886, 0.374335, 0.006827}}],
    Polygon[{{0.245058, 0.370575, 0.008839},{0.243600, 0.371049, 0.010634},{
      0.244121, 0.374335, 0.010634},{0.245653, 0.374335, 0.008839}}],
    Polygon[{{0.243600, 0.371049, 0.010634},{0.241894, 0.371603, 0.012166},{
      0.242326, 0.374335, 0.012166},{0.244121, 0.374335, 0.010634}}],
    Polygon[{{0.241894, 0.371603, 0.012166},{0.239980, 0.372225, 0.013399},{
      0.240314, 0.374335, 0.013399},{0.242326, 0.374335, 0.012166}}],
    Polygon[{{0.239980, 0.372225, 0.013399},{0.237907, 0.372899, 0.014302},{
      0.238134, 0.374335, 0.014302},{0.240314, 0.374335, 0.013399}}],
    Polygon[{{0.237907, 0.372899, 0.014302},{0.235724, 0.373608, 0.014853},{
      0.235839, 0.374335, 0.014853},{0.238134, 0.374335, 0.014302}}],
    Polygon[{{0.270708, 0.443561, -0.011012},{0.272409, 0.443561, -0.010603},{
      0.272241, 0.444626, -0.010603},{0.270623, 0.444100, -0.011012}}],
    Polygon[{{0.272409, 0.443561, -0.010603},{0.274026, 0.443561, -0.009934},{
      0.273778, 0.445126, -0.009934},{0.272241, 0.444626, -0.010603}}],
    Polygon[{{0.274026, 0.443561, -0.009934},{0.275517, 0.443561, -0.009020},{
      0.275197, 0.445587, -0.009020},{0.273778, 0.445126, -0.009934}}],
    Polygon[{{0.275517, 0.443561, -0.009020},{0.276848, 0.443561, -0.007884},{
      0.276462, 0.445998, -0.007884},{0.275197, 0.445587, -0.009020}}],
    Polygon[{{0.276848, 0.443561, -0.007884},{0.277984, 0.443561, -0.006553},{
      0.277542, 0.446349, -0.006553},{0.276462, 0.445998, -0.007884}}],
    Polygon[{{0.277984, 0.443561, -0.006553},{0.278898, 0.443561, -0.005062},{
      0.278412, 0.446631, -0.005062},{0.277542, 0.446349, -0.006553}}],
    Polygon[{{0.278898, 0.443561, -0.005062},{0.279568, 0.443561, -0.003445},{
      0.279049, 0.446838, -0.003445},{0.278412, 0.446631, -0.005062}}],
    Polygon[{{0.279568, 0.443561, -0.003445},{0.279976, 0.443561, -0.001744},{
      0.279437, 0.446964, -0.001744},{0.279049, 0.446838, -0.003445}}],
    Polygon[{{0.279976, 0.443561, -0.001744},{0.280113, 0.443561, 0.000000},{
      0.279568, 0.447007, 0.000000},{0.279437, 0.446964, -0.001744}}],
    Polygon[{{0.280113, 0.443561, 0.000000},{0.279976, 0.443561, 0.001744},{
      0.279437, 0.446964, 0.001744},{0.279568, 0.447007, 0.000000}}],
    Polygon[{{0.279976, 0.443561, 0.001744},{0.279568, 0.443561, 0.003445},{
      0.279049, 0.446838, 0.003445},{0.279437, 0.446964, 0.001744}}],
    Polygon[{{0.279568, 0.443561, 0.003445},{0.278898, 0.443561, 0.005062},{
      0.278412, 0.446631, 0.005062},{0.279049, 0.446838, 0.003445}}],
    Polygon[{{0.278898, 0.443561, 0.005062},{0.277984, 0.443561, 0.006553},{
      0.277542, 0.446349, 0.006553},{0.278412, 0.446631, 0.005062}}],
    Polygon[{{0.277984, 0.443561, 0.006553},{0.276848, 0.443561, 0.007884},{
      0.276462, 0.445998, 0.007884},{0.277542, 0.446349, 0.006553}}],
    Polygon[{{0.276848, 0.443561, 0.007884},{0.275517, 0.443561, 0.009020},{
      0.275197, 0.445587, 0.009020},{0.276462, 0.445998, 0.007884}}],
    Polygon[{{0.275517, 0.443561, 0.009020},{0.274026, 0.443561, 0.009934},{
      0.273778, 0.445126, 0.009934},{0.275197, 0.445587, 0.009020}}],
    Polygon[{{0.274026, 0.443561, 0.009934},{0.272409, 0.443561, 0.010603},{
      0.272241, 0.444626, 0.010603},{0.273778, 0.445126, 0.009934}}],
    Polygon[{{0.272409, 0.443561, 0.010603},{0.270708, 0.443561, 0.011012},{
      0.270623, 0.444100, 0.011012},{0.272241, 0.444626, 0.010603}}],
    Polygon[{{0.270623, 0.444100, -0.011012},{0.272241, 0.444626, -0.010603},{
      0.271751, 0.445587, -0.010603},{0.270375, 0.444587, -0.011012}}],
    Polygon[{{0.272241, 0.444626, -0.010603},{0.273778, 0.445126, -0.009934},{
      0.273059, 0.446537, -0.009934},{0.271751, 0.445587, -0.010603}}],
    Polygon[{{0.273778, 0.445126, -0.009934},{0.275197, 0.445587, -0.009020},{
      0.274266, 0.447413, -0.009020},{0.273059, 0.446537, -0.009934}}],
    Polygon[{{0.275197, 0.445587, -0.009020},{0.276462, 0.445998, -0.007884},{
      0.275342, 0.448195, -0.007884},{0.274266, 0.447413, -0.009020}}],
    Polygon[{{0.276462, 0.445998, -0.007884},{0.277542, 0.446349, -0.006553},{
      0.276261, 0.448863, -0.006553},{0.275342, 0.448195, -0.007884}}],
    Polygon[{{0.277542, 0.446349, -0.006553},{0.278412, 0.446631, -0.005062},{
      0.277001, 0.449400, -0.005062},{0.276261, 0.448863, -0.006553}}],
    Polygon[{{0.278412, 0.446631, -0.005062},{0.279049, 0.446838, -0.003445},{
      0.277542, 0.449794, -0.003445},{0.277001, 0.449400, -0.005062}}],
    Polygon[{{0.279049, 0.446838, -0.003445},{0.279437, 0.446964, -0.001744},{
      0.277873, 0.450034, -0.001744},{0.277542, 0.449794, -0.003445}}],
    Polygon[{{0.279437, 0.446964, -0.001744},{0.279568, 0.447007, 0.000000},{
      0.277984, 0.450115, 0.000000},{0.277873, 0.450034, -0.001744}}],
    Polygon[{{0.279568, 0.447007, 0.000000},{0.279437, 0.446964, 0.001744},{
      0.277873, 0.450034, 0.001744},{0.277984, 0.450115, 0.000000}}],
    Polygon[{{0.279437, 0.446964, 0.001744},{0.279049, 0.446838, 0.003445},{
      0.277542, 0.449794, 0.003445},{0.277873, 0.450034, 0.001744}}],
    Polygon[{{0.279049, 0.446838, 0.003445},{0.278412, 0.446631, 0.005062},{
      0.277001, 0.449400, 0.005062},{0.277542, 0.449794, 0.003445}}],
    Polygon[{{0.278412, 0.446631, 0.005062},{0.277542, 0.446349, 0.006553},{
      0.276261, 0.448863, 0.006553},{0.277001, 0.449400, 0.005062}}],
    Polygon[{{0.277542, 0.446349, 0.006553},{0.276462, 0.445998, 0.007884},{
      0.275342, 0.448195, 0.007884},{0.276261, 0.448863, 0.006553}}],
    Polygon[{{0.276462, 0.445998, 0.007884},{0.275197, 0.445587, 0.009020},{
      0.274266, 0.447413, 0.009020},{0.275342, 0.448195, 0.007884}}],
    Polygon[{{0.275197, 0.445587, 0.009020},{0.273778, 0.445126, 0.009934},{
      0.273059, 0.446537, 0.009934},{0.274266, 0.447413, 0.009020}}],
    Polygon[{{0.273778, 0.445126, 0.009934},{0.272241, 0.444626, 0.010603},{
      0.271751, 0.445587, 0.010603},{0.273059, 0.446537, 0.009934}}],
    Polygon[{{0.272241, 0.444626, 0.010603},{0.270623, 0.444100, 0.011012},{
      0.270375, 0.444587, 0.011012},{0.271751, 0.445587, 0.010603}}],
    Polygon[{{0.270375, 0.444587, -0.011012},{0.271751, 0.445587, -0.010603},{
      0.270989, 0.446349, -0.010603},{0.269989, 0.444972, -0.011012}}],
    Polygon[{{0.271751, 0.445587, -0.010603},{0.273059, 0.446537, -0.009934},{
      0.271939, 0.447656, -0.009934},{0.270989, 0.446349, -0.010603}}],
    Polygon[{{0.273059, 0.446537, -0.009934},{0.274266, 0.447413, -0.009020},{
      0.272816, 0.448863, -0.009020},{0.271939, 0.447656, -0.009934}}],
    Polygon[{{0.274266, 0.447413, -0.009020},{0.275342, 0.448195, -0.007884},{
      0.273598, 0.449939, -0.007884},{0.272816, 0.448863, -0.009020}}],
    Polygon[{{0.275342, 0.448195, -0.007884},{0.276261, 0.448863, -0.006553},{
      0.274266, 0.450859, -0.006553},{0.273598, 0.449939, -0.007884}}],
    Polygon[{{0.276261, 0.448863, -0.006553},{0.277001, 0.449400, -0.005062},{
      0.274803, 0.451598, -0.005062},{0.274266, 0.450859, -0.006553}}],
    Polygon[{{0.277001, 0.449400, -0.005062},{0.277542, 0.449794, -0.003445},{
      0.275197, 0.452140, -0.003445},{0.274803, 0.451598, -0.005062}}],
    Polygon[{{0.277542, 0.449794, -0.003445},{0.277873, 0.450034, -0.001744},{
      0.275437, 0.452470, -0.001744},{0.275197, 0.452140, -0.003445}}],
    Polygon[{{0.277873, 0.450034, -0.001744},{0.277984, 0.450115, 0.000000},{
      0.275517, 0.452581, 0.000000},{0.275437, 0.452470, -0.001744}}],
    Polygon[{{0.277984, 0.450115, 0.000000},{0.277873, 0.450034, 0.001744},{
      0.275437, 0.452470, 0.001744},{0.275517, 0.452581, 0.000000}}],
    Polygon[{{0.277873, 0.450034, 0.001744},{0.277542, 0.449794, 0.003445},{
      0.275197, 0.452140, 0.003445},{0.275437, 0.452470, 0.001744}}],
    Polygon[{{0.277542, 0.449794, 0.003445},{0.277001, 0.449400, 0.005062},{
      0.274803, 0.451598, 0.005062},{0.275197, 0.452140, 0.003445}}],
    Polygon[{{0.277001, 0.449400, 0.005062},{0.276261, 0.448863, 0.006553},{
      0.274266, 0.450859, 0.006553},{0.274803, 0.451598, 0.005062}}],
    Polygon[{{0.276261, 0.448863, 0.006553},{0.275342, 0.448195, 0.007884},{
      0.273598, 0.449939, 0.007884},{0.274266, 0.450859, 0.006553}}],
    Polygon[{{0.275342, 0.448195, 0.007884},{0.274266, 0.447413, 0.009020},{
      0.272816, 0.448863, 0.009020},{0.273598, 0.449939, 0.007884}}],
    Polygon[{{0.274266, 0.447413, 0.009020},{0.273059, 0.446537, 0.009934},{
      0.271939, 0.447656, 0.009934},{0.272816, 0.448863, 0.009020}}],
    Polygon[{{0.273059, 0.446537, 0.009934},{0.271751, 0.445587, 0.010603},{
      0.270989, 0.446349, 0.010603},{0.271939, 0.447656, 0.009934}}],
    Polygon[{{0.271751, 0.445587, 0.010603},{0.270375, 0.444587, 0.011012},{
      0.269989, 0.444972, 0.011012},{0.270989, 0.446349, 0.010603}}],
    Polygon[{{0.269989, 0.444972, -0.011012},{0.270989, 0.446349, -0.010603},{
      0.270029, 0.446838, -0.010603},{0.269503, 0.445220, -0.011012}}],
    Polygon[{{0.270989, 0.446349, -0.010603},{0.271939, 0.447656, -0.009934},{
      0.270528, 0.448375, -0.009934},{0.270029, 0.446838, -0.010603}}],
    Polygon[{{0.271939, 0.447656, -0.009934},{0.272816, 0.448863, -0.009020},{
      0.270989, 0.449794, -0.009020},{0.270528, 0.448375, -0.009934}}],
    Polygon[{{0.272816, 0.448863, -0.009020},{0.273598, 0.449939, -0.007884},{
      0.271400, 0.451059, -0.007884},{0.270989, 0.449794, -0.009020}}],
    Polygon[{{0.273598, 0.449939, -0.007884},{0.274266, 0.450859, -0.006553},{
      0.271751, 0.452140, -0.006553},{0.271400, 0.451059, -0.007884}}],
    Polygon[{{0.274266, 0.450859, -0.006553},{0.274803, 0.451598, -0.005062},{
      0.272034, 0.453009, -0.005062},{0.271751, 0.452140, -0.006553}}],
    Polygon[{{0.274803, 0.451598, -0.005062},{0.275197, 0.452140, -0.003445},{
      0.272241, 0.453646, -0.003445},{0.272034, 0.453009, -0.005062}}],
    Polygon[{{0.275197, 0.452140, -0.003445},{0.275437, 0.452470, -0.001744},{
      0.272367, 0.454034, -0.001744},{0.272241, 0.453646, -0.003445}}],
    Polygon[{{0.275437, 0.452470, -0.001744},{0.275517, 0.452581, 0.000000},{
      0.272409, 0.454165, 0.000000},{0.272367, 0.454034, -0.001744}}],
    Polygon[{{0.275517, 0.452581, 0.000000},{0.275437, 0.452470, 0.001744},{
      0.272367, 0.454034, 0.001744},{0.272409, 0.454165, 0.000000}}],
    Polygon[{{0.275437, 0.452470, 0.001744},{0.275197, 0.452140, 0.003445},{
      0.272241, 0.453646, 0.003445},{0.272367, 0.454034, 0.001744}}],
    Polygon[{{0.275197, 0.452140, 0.003445},{0.274803, 0.451598, 0.005062},{
      0.272034, 0.453009, 0.005062},{0.272241, 0.453646, 0.003445}}],
    Polygon[{{0.274803, 0.451598, 0.005062},{0.274266, 0.450859, 0.006553},{
      0.271751, 0.452140, 0.006553},{0.272034, 0.453009, 0.005062}}],
    Polygon[{{0.274266, 0.450859, 0.006553},{0.273598, 0.449939, 0.007884},{
      0.271400, 0.451059, 0.007884},{0.271751, 0.452140, 0.006553}}],
    Polygon[{{0.273598, 0.449939, 0.007884},{0.272816, 0.448863, 0.009020},{
      0.270989, 0.449794, 0.009020},{0.271400, 0.451059, 0.007884}}],
    Polygon[{{0.272816, 0.448863, 0.009020},{0.271939, 0.447656, 0.009934},{
      0.270528, 0.448375, 0.009934},{0.270989, 0.449794, 0.009020}}],
    Polygon[{{0.271939, 0.447656, 0.009934},{0.270989, 0.446349, 0.010603},{
      0.270029, 0.446838, 0.010603},{0.270528, 0.448375, 0.009934}}],
    Polygon[{{0.270989, 0.446349, 0.010603},{0.269989, 0.444972, 0.011012},{
      0.269503, 0.445220, 0.011012},{0.270029, 0.446838, 0.010603}}],
    Polygon[{{0.269503, 0.445220, -0.011012},{0.270029, 0.446838, -0.010603},{
      0.268964, 0.447007, -0.010603},{0.268964, 0.445306, -0.011012}}],
    Polygon[{{0.270029, 0.446838, -0.010603},{0.270528, 0.448375, -0.009934},{
      0.268964, 0.448623, -0.009934},{0.268964, 0.447007, -0.010603}}],
    Polygon[{{0.270528, 0.448375, -0.009934},{0.270989, 0.449794, -0.009020},{
      0.268964, 0.450115, -0.009020},{0.268964, 0.448623, -0.009934}}],
    Polygon[{{0.270989, 0.449794, -0.009020},{0.271400, 0.451059, -0.007884},{
      0.268964, 0.451445, -0.007884},{0.268964, 0.450115, -0.009020}}],
    Polygon[{{0.271400, 0.451059, -0.007884},{0.271751, 0.452140, -0.006553},{
      0.268964, 0.452581, -0.006553},{0.268964, 0.451445, -0.007884}}],
    Polygon[{{0.271751, 0.452140, -0.006553},{0.272034, 0.453009, -0.005062},{
      0.268964, 0.453495, -0.005062},{0.268964, 0.452581, -0.006553}}],
    Polygon[{{0.272034, 0.453009, -0.005062},{0.272241, 0.453646, -0.003445},{
      0.268964, 0.454165, -0.003445},{0.268964, 0.453495, -0.005062}}],
    Polygon[{{0.272241, 0.453646, -0.003445},{0.272367, 0.454034, -0.001744},{
      0.268964, 0.454573, -0.001744},{0.268964, 0.454165, -0.003445}}],
    Polygon[{{0.272367, 0.454034, -0.001744},{0.272409, 0.454165, 0.000000},{
      0.268964, 0.454710, 0.000000},{0.268964, 0.454573, -0.001744}}],
    Polygon[{{0.272409, 0.454165, 0.000000},{0.272367, 0.454034, 0.001744},{
      0.268964, 0.454573, 0.001744},{0.268964, 0.454710, 0.000000}}],
    Polygon[{{0.272367, 0.454034, 0.001744},{0.272241, 0.453646, 0.003445},{
      0.268964, 0.454165, 0.003445},{0.268964, 0.454573, 0.001744}}],
    Polygon[{{0.272241, 0.453646, 0.003445},{0.272034, 0.453009, 0.005062},{
      0.268964, 0.453495, 0.005062},{0.268964, 0.454165, 0.003445}}],
    Polygon[{{0.272034, 0.453009, 0.005062},{0.271751, 0.452140, 0.006553},{
      0.268964, 0.452581, 0.006553},{0.268964, 0.453495, 0.005062}}],
    Polygon[{{0.271751, 0.452140, 0.006553},{0.271400, 0.451059, 0.007884},{
      0.268964, 0.451445, 0.007884},{0.268964, 0.452581, 0.006553}}],
    Polygon[{{0.271400, 0.451059, 0.007884},{0.270989, 0.449794, 0.009020},{
      0.268964, 0.450115, 0.009020},{0.268964, 0.451445, 0.007884}}],
    Polygon[{{0.270989, 0.449794, 0.009020},{0.270528, 0.448375, 0.009934},{
      0.268964, 0.448623, 0.009934},{0.268964, 0.450115, 0.009020}}],
    Polygon[{{0.270528, 0.448375, 0.009934},{0.270029, 0.446838, 0.010603},{
      0.268964, 0.447007, 0.010603},{0.268964, 0.448623, 0.009934}}],
    Polygon[{{0.270029, 0.446838, 0.010603},{0.269503, 0.445220, 0.011012},{
      0.268964, 0.445306, 0.011012},{0.268964, 0.447007, 0.010603}}],
    Polygon[{{0.268964, 0.445306, -0.011012},{0.268964, 0.447007, -0.010603},{
      0.267900, 0.446838, -0.010603},{0.268425, 0.445220, -0.011012}}],
    Polygon[{{0.268964, 0.447007, -0.010603},{0.268964, 0.448623, -0.009934},{
      0.267400, 0.448375, -0.009934},{0.267900, 0.446838, -0.010603}}],
    Polygon[{{0.268964, 0.448623, -0.009934},{0.268964, 0.450115, -0.009020},{
      0.266939, 0.449794, -0.009020},{0.267400, 0.448375, -0.009934}}],
    Polygon[{{0.268964, 0.450115, -0.009020},{0.268964, 0.451445, -0.007884},{
      0.266528, 0.451059, -0.007884},{0.266939, 0.449794, -0.009020}}],
    Polygon[{{0.268964, 0.451445, -0.007884},{0.268964, 0.452581, -0.006553},{
      0.266177, 0.452140, -0.006553},{0.266528, 0.451059, -0.007884}}],
    Polygon[{{0.268964, 0.452581, -0.006553},{0.268964, 0.453495, -0.005062},{
      0.265894, 0.453009, -0.005062},{0.266177, 0.452140, -0.006553}}],
    Polygon[{{0.268964, 0.453495, -0.005062},{0.268964, 0.454165, -0.003445},{
      0.265688, 0.453646, -0.003445},{0.265894, 0.453009, -0.005062}}],
    Polygon[{{0.268964, 0.454165, -0.003445},{0.268964, 0.454573, -0.001744},{
      0.265561, 0.454034, -0.001744},{0.265688, 0.453646, -0.003445}}],
    Polygon[{{0.268964, 0.454573, -0.001744},{0.268964, 0.454710, 0.000000},{
      0.265519, 0.454165, 0.000000},{0.265561, 0.454034, -0.001744}}],
    Polygon[{{0.268964, 0.454710, 0.000000},{0.268964, 0.454573, 0.001744},{
      0.265561, 0.454034, 0.001744},{0.265519, 0.454165, 0.000000}}],
    Polygon[{{0.268964, 0.454573, 0.001744},{0.268964, 0.454165, 0.003445},{
      0.265688, 0.453646, 0.003445},{0.265561, 0.454034, 0.001744}}],
    Polygon[{{0.268964, 0.454165, 0.003445},{0.268964, 0.453495, 0.005062},{
      0.265894, 0.453009, 0.005062},{0.265688, 0.453646, 0.003445}}],
    Polygon[{{0.268964, 0.453495, 0.005062},{0.268964, 0.452581, 0.006553},{
      0.266177, 0.452140, 0.006553},{0.265894, 0.453009, 0.005062}}],
    Polygon[{{0.268964, 0.452581, 0.006553},{0.268964, 0.451445, 0.007884},{
      0.266528, 0.451059, 0.007884},{0.266177, 0.452140, 0.006553}}],
    Polygon[{{0.268964, 0.451445, 0.007884},{0.268964, 0.450115, 0.009020},{
      0.266939, 0.449794, 0.009020},{0.266528, 0.451059, 0.007884}}],
    Polygon[{{0.268964, 0.450115, 0.009020},{0.268964, 0.448623, 0.009934},{
      0.267400, 0.448375, 0.009934},{0.266939, 0.449794, 0.009020}}],
    Polygon[{{0.268964, 0.448623, 0.009934},{0.268964, 0.447007, 0.010603},{
      0.267900, 0.446838, 0.010603},{0.267400, 0.448375, 0.009934}}],
    Polygon[{{0.268964, 0.447007, 0.010603},{0.268964, 0.445306, 0.011012},{
      0.268425, 0.445220, 0.011012},{0.267900, 0.446838, 0.010603}}],
    Polygon[{{0.268425, 0.445220, -0.011012},{0.267900, 0.446838, -0.010603},{
      0.266939, 0.446349, -0.010603},{0.267939, 0.444972, -0.011012}}],
    Polygon[{{0.267900, 0.446838, -0.010603},{0.267400, 0.448375, -0.009934},{
      0.265989, 0.447656, -0.009934},{0.266939, 0.446349, -0.010603}}],
    Polygon[{{0.267400, 0.448375, -0.009934},{0.266939, 0.449794, -0.009020},{
      0.265112, 0.448863, -0.009020},{0.265989, 0.447656, -0.009934}}],
    Polygon[{{0.266939, 0.449794, -0.009020},{0.266528, 0.451059, -0.007884},{
      0.264330, 0.449939, -0.007884},{0.265112, 0.448863, -0.009020}}],
    Polygon[{{0.266528, 0.451059, -0.007884},{0.266177, 0.452140, -0.006553},{
      0.263662, 0.450859, -0.006553},{0.264330, 0.449939, -0.007884}}],
    Polygon[{{0.266177, 0.452140, -0.006553},{0.265894, 0.453009, -0.005062},{
      0.263125, 0.451598, -0.005062},{0.263662, 0.450859, -0.006553}}],
    Polygon[{{0.265894, 0.453009, -0.005062},{0.265688, 0.453646, -0.003445},{
      0.262732, 0.452140, -0.003445},{0.263125, 0.451598, -0.005062}}],
    Polygon[{{0.265688, 0.453646, -0.003445},{0.265561, 0.454034, -0.001744},{
      0.262492, 0.452470, -0.001744},{0.262732, 0.452140, -0.003445}}],
    Polygon[{{0.265561, 0.454034, -0.001744},{0.265519, 0.454165, 0.000000},{
      0.262411, 0.452581, 0.000000},{0.262492, 0.452470, -0.001744}}],
    Polygon[{{0.265519, 0.454165, 0.000000},{0.265561, 0.454034, 0.001744},{
      0.262492, 0.452470, 0.001744},{0.262411, 0.452581, 0.000000}}],
    Polygon[{{0.265561, 0.454034, 0.001744},{0.265688, 0.453646, 0.003445},{
      0.262732, 0.452140, 0.003445},{0.262492, 0.452470, 0.001744}}],
    Polygon[{{0.265688, 0.453646, 0.003445},{0.265894, 0.453009, 0.005062},{
      0.263125, 0.451598, 0.005062},{0.262732, 0.452140, 0.003445}}],
    Polygon[{{0.265894, 0.453009, 0.005062},{0.266177, 0.452140, 0.006553},{
      0.263662, 0.450859, 0.006553},{0.263125, 0.451598, 0.005062}}],
    Polygon[{{0.266177, 0.452140, 0.006553},{0.266528, 0.451059, 0.007884},{
      0.264330, 0.449939, 0.007884},{0.263662, 0.450859, 0.006553}}],
    Polygon[{{0.266528, 0.451059, 0.007884},{0.266939, 0.449794, 0.009020},{
      0.265112, 0.448863, 0.009020},{0.264330, 0.449939, 0.007884}}],
    Polygon[{{0.266939, 0.449794, 0.009020},{0.267400, 0.448375, 0.009934},{
      0.265989, 0.447656, 0.009934},{0.265112, 0.448863, 0.009020}}],
    Polygon[{{0.267400, 0.448375, 0.009934},{0.267900, 0.446838, 0.010603},{
      0.266939, 0.446349, 0.010603},{0.265989, 0.447656, 0.009934}}],
    Polygon[{{0.267900, 0.446838, 0.010603},{0.268425, 0.445220, 0.011012},{
      0.267939, 0.444972, 0.011012},{0.266939, 0.446349, 0.010603}}],
    Polygon[{{0.267939, 0.444972, -0.011012},{0.266939, 0.446349, -0.010603},{
      0.266177, 0.445587, -0.010603},{0.267553, 0.444587, -0.011012}}],
    Polygon[{{0.266939, 0.446349, -0.010603},{0.265989, 0.447656, -0.009934},{
      0.264869, 0.446537, -0.009934},{0.266177, 0.445587, -0.010603}}],
    Polygon[{{0.265989, 0.447656, -0.009934},{0.265112, 0.448863, -0.009020},{
      0.263662, 0.447413, -0.009020},{0.264869, 0.446537, -0.009934}}],
    Polygon[{{0.265112, 0.448863, -0.009020},{0.264330, 0.449939, -0.007884},{
      0.262586, 0.448195, -0.007884},{0.263662, 0.447413, -0.009020}}],
    Polygon[{{0.264330, 0.449939, -0.007884},{0.263662, 0.450859, -0.006553},{
      0.261667, 0.448863, -0.006553},{0.262586, 0.448195, -0.007884}}],
    Polygon[{{0.263662, 0.450859, -0.006553},{0.263125, 0.451598, -0.005062},{
      0.260927, 0.449400, -0.005062},{0.261667, 0.448863, -0.006553}}],
    Polygon[{{0.263125, 0.451598, -0.005062},{0.262732, 0.452140, -0.003445},{
      0.260386, 0.449794, -0.003445},{0.260927, 0.449400, -0.005062}}],
    Polygon[{{0.262732, 0.452140, -0.003445},{0.262492, 0.452470, -0.001744},{
      0.260055, 0.450034, -0.001744},{0.260386, 0.449794, -0.003445}}],
    Polygon[{{0.262492, 0.452470, -0.001744},{0.262411, 0.452581, 0.000000},{
      0.259944, 0.450115, 0.000000},{0.260055, 0.450034, -0.001744}}],
    Polygon[{{0.262411, 0.452581, 0.000000},{0.262492, 0.452470, 0.001744},{
      0.260055, 0.450034, 0.001744},{0.259944, 0.450115, 0.000000}}],
    Polygon[{{0.262492, 0.452470, 0.001744},{0.262732, 0.452140, 0.003445},{
      0.260386, 0.449794, 0.003445},{0.260055, 0.450034, 0.001744}}],
    Polygon[{{0.262732, 0.452140, 0.003445},{0.263125, 0.451598, 0.005062},{
      0.260927, 0.449400, 0.005062},{0.260386, 0.449794, 0.003445}}],
    Polygon[{{0.263125, 0.451598, 0.005062},{0.263662, 0.450859, 0.006553},{
      0.261667, 0.448863, 0.006553},{0.260927, 0.449400, 0.005062}}],
    Polygon[{{0.263662, 0.450859, 0.006553},{0.264330, 0.449939, 0.007884},{
      0.262586, 0.448195, 0.007884},{0.261667, 0.448863, 0.006553}}],
    Polygon[{{0.264330, 0.449939, 0.007884},{0.265112, 0.448863, 0.009020},{
      0.263662, 0.447413, 0.009020},{0.262586, 0.448195, 0.007884}}],
    Polygon[{{0.265112, 0.448863, 0.009020},{0.265989, 0.447656, 0.009934},{
      0.264869, 0.446537, 0.009934},{0.263662, 0.447413, 0.009020}}],
    Polygon[{{0.265989, 0.447656, 0.009934},{0.266939, 0.446349, 0.010603},{
      0.266177, 0.445587, 0.010603},{0.264869, 0.446537, 0.009934}}],
    Polygon[{{0.266939, 0.446349, 0.010603},{0.267939, 0.444972, 0.011012},{
      0.267553, 0.444587, 0.011012},{0.266177, 0.445587, 0.010603}}],
    Polygon[{{0.267553, 0.444587, -0.011012},{0.266177, 0.445587, -0.010603},{
      0.265688, 0.444626, -0.010603},{0.267305, 0.444100, -0.011012}}],
    Polygon[{{0.266177, 0.445587, -0.010603},{0.264869, 0.446537, -0.009934},{
      0.264150, 0.445126, -0.009934},{0.265688, 0.444626, -0.010603}}],
    Polygon[{{0.264869, 0.446537, -0.009934},{0.263662, 0.447413, -0.009020},{
      0.262732, 0.445587, -0.009020},{0.264150, 0.445126, -0.009934}}],
    Polygon[{{0.263662, 0.447413, -0.009020},{0.262586, 0.448195, -0.007884},{
      0.261466, 0.445998, -0.007884},{0.262732, 0.445587, -0.009020}}],
    Polygon[{{0.262586, 0.448195, -0.007884},{0.261667, 0.448863, -0.006553},{
      0.260386, 0.446349, -0.006553},{0.261466, 0.445998, -0.007884}}],
    Polygon[{{0.261667, 0.448863, -0.006553},{0.260927, 0.449400, -0.005062},{
      0.259516, 0.446631, -0.005062},{0.260386, 0.446349, -0.006553}}],
    Polygon[{{0.260927, 0.449400, -0.005062},{0.260386, 0.449794, -0.003445},{
      0.258880, 0.446838, -0.003445},{0.259516, 0.446631, -0.005062}}],
    Polygon[{{0.260386, 0.449794, -0.003445},{0.260055, 0.450034, -0.001744},{
      0.258491, 0.446964, -0.001744},{0.258880, 0.446838, -0.003445}}],
    Polygon[{{0.260055, 0.450034, -0.001744},{0.259944, 0.450115, 0.000000},{
      0.258361, 0.447007, 0.000000},{0.258491, 0.446964, -0.001744}}],
    Polygon[{{0.259944, 0.450115, 0.000000},{0.260055, 0.450034, 0.001744},{
      0.258491, 0.446964, 0.001744},{0.258361, 0.447007, 0.000000}}],
    Polygon[{{0.260055, 0.450034, 0.001744},{0.260386, 0.449794, 0.003445},{
      0.258880, 0.446838, 0.003445},{0.258491, 0.446964, 0.001744}}],
    Polygon[{{0.260386, 0.449794, 0.003445},{0.260927, 0.449400, 0.005062},{
      0.259516, 0.446631, 0.005062},{0.258880, 0.446838, 0.003445}}],
    Polygon[{{0.260927, 0.449400, 0.005062},{0.261667, 0.448863, 0.006553},{
      0.260386, 0.446349, 0.006553},{0.259516, 0.446631, 0.005062}}],
    Polygon[{{0.261667, 0.448863, 0.006553},{0.262586, 0.448195, 0.007884},{
      0.261466, 0.445998, 0.007884},{0.260386, 0.446349, 0.006553}}],
    Polygon[{{0.262586, 0.448195, 0.007884},{0.263662, 0.447413, 0.009020},{
      0.262732, 0.445587, 0.009020},{0.261466, 0.445998, 0.007884}}],
    Polygon[{{0.263662, 0.447413, 0.009020},{0.264869, 0.446537, 0.009934},{
      0.264150, 0.445126, 0.009934},{0.262732, 0.445587, 0.009020}}],
    Polygon[{{0.264869, 0.446537, 0.009934},{0.266177, 0.445587, 0.010603},{
      0.265688, 0.444626, 0.010603},{0.264150, 0.445126, 0.009934}}],
    Polygon[{{0.266177, 0.445587, 0.010603},{0.267553, 0.444587, 0.011012},{
      0.267305, 0.444100, 0.011012},{0.265688, 0.444626, 0.010603}}],
    Polygon[{{0.267305, 0.444100, -0.011012},{0.265688, 0.444626, -0.010603},{
      0.265519, 0.443561, -0.010603},{0.267220, 0.443561, -0.011012}}],
    Polygon[{{0.265688, 0.444626, -0.010603},{0.264150, 0.445126, -0.009934},{
      0.263903, 0.443561, -0.009934},{0.265519, 0.443561, -0.010603}}],
    Polygon[{{0.264150, 0.445126, -0.009934},{0.262732, 0.445587, -0.009020},{
      0.262411, 0.443561, -0.009020},{0.263903, 0.443561, -0.009934}}],
    Polygon[{{0.262732, 0.445587, -0.009020},{0.261466, 0.445998, -0.007884},{
      0.261081, 0.443561, -0.007884},{0.262411, 0.443561, -0.009020}}],
    Polygon[{{0.261466, 0.445998, -0.007884},{0.260386, 0.446349, -0.006553},{
      0.259944, 0.443561, -0.006553},{0.261081, 0.443561, -0.007884}}],
    Polygon[{{0.260386, 0.446349, -0.006553},{0.259516, 0.446631, -0.005062},{
      0.259030, 0.443561, -0.005062},{0.259944, 0.443561, -0.006553}}],
    Polygon[{{0.259516, 0.446631, -0.005062},{0.258880, 0.446838, -0.003445},{
      0.258361, 0.443561, -0.003445},{0.259030, 0.443561, -0.005062}}],
    Polygon[{{0.258880, 0.446838, -0.003445},{0.258491, 0.446964, -0.001744},{
      0.257952, 0.443561, -0.001744},{0.258361, 0.443561, -0.003445}}],
    Polygon[{{0.258491, 0.446964, -0.001744},{0.258361, 0.447007, 0.000000},{
      0.257815, 0.443561, 0.000000},{0.257952, 0.443561, -0.001744}}],
    Polygon[{{0.258361, 0.447007, 0.000000},{0.258491, 0.446964, 0.001744},{
      0.257952, 0.443561, 0.001744},{0.257815, 0.443561, 0.000000}}],
    Polygon[{{0.258491, 0.446964, 0.001744},{0.258880, 0.446838, 0.003445},{
      0.258361, 0.443561, 0.003445},{0.257952, 0.443561, 0.001744}}],
    Polygon[{{0.258880, 0.446838, 0.003445},{0.259516, 0.446631, 0.005062},{
      0.259030, 0.443561, 0.005062},{0.258361, 0.443561, 0.003445}}],
    Polygon[{{0.259516, 0.446631, 0.005062},{0.260386, 0.446349, 0.006553},{
      0.259944, 0.443561, 0.006553},{0.259030, 0.443561, 0.005062}}],
    Polygon[{{0.260386, 0.446349, 0.006553},{0.261466, 0.445998, 0.007884},{
      0.261081, 0.443561, 0.007884},{0.259944, 0.443561, 0.006553}}],
    Polygon[{{0.261466, 0.445998, 0.007884},{0.262732, 0.445587, 0.009020},{
      0.262411, 0.443561, 0.009020},{0.261081, 0.443561, 0.007884}}],
    Polygon[{{0.262732, 0.445587, 0.009020},{0.264150, 0.445126, 0.009934},{
      0.263903, 0.443561, 0.009934},{0.262411, 0.443561, 0.009020}}],
    Polygon[{{0.264150, 0.445126, 0.009934},{0.265688, 0.444626, 0.010603},{
      0.265519, 0.443561, 0.010603},{0.263903, 0.443561, 0.009934}}],
    Polygon[{{0.265688, 0.444626, 0.010603},{0.267305, 0.444100, 0.011012},{
      0.267220, 0.443561, 0.011012},{0.265519, 0.443561, 0.010603}}],
    Polygon[{{0.267220, 0.443561, -0.011012},{0.265519, 0.443561, -0.010603},{
      0.265688, 0.442497, -0.010603},{0.267305, 0.443022, -0.011012}}],
    Polygon[{{0.265519, 0.443561, -0.010603},{0.263903, 0.443561, -0.009934},{
      0.264150, 0.441997, -0.009934},{0.265688, 0.442497, -0.010603}}],
    Polygon[{{0.263903, 0.443561, -0.009934},{0.262411, 0.443561, -0.009020},{
      0.262732, 0.441536, -0.009020},{0.264150, 0.441997, -0.009934}}],
    Polygon[{{0.262411, 0.443561, -0.009020},{0.261081, 0.443561, -0.007884},{
      0.261466, 0.441125, -0.007884},{0.262732, 0.441536, -0.009020}}],
    Polygon[{{0.261081, 0.443561, -0.007884},{0.259944, 0.443561, -0.006553},{
      0.260386, 0.440774, -0.006553},{0.261466, 0.441125, -0.007884}}],
    Polygon[{{0.259944, 0.443561, -0.006553},{0.259030, 0.443561, -0.005062},{
      0.259516, 0.440492, -0.005062},{0.260386, 0.440774, -0.006553}}],
    Polygon[{{0.259030, 0.443561, -0.005062},{0.258361, 0.443561, -0.003445},{
      0.258880, 0.440285, -0.003445},{0.259516, 0.440492, -0.005062}}],
    Polygon[{{0.258361, 0.443561, -0.003445},{0.257952, 0.443561, -0.001744},{
      0.258491, 0.440159, -0.001744},{0.258880, 0.440285, -0.003445}}],
    Polygon[{{0.257952, 0.443561, -0.001744},{0.257815, 0.443561, 0.000000},{
      0.258361, 0.440116, 0.000000},{0.258491, 0.440159, -0.001744}}],
    Polygon[{{0.257815, 0.443561, 0.000000},{0.257952, 0.443561, 0.001744},{
      0.258491, 0.440159, 0.001744},{0.258361, 0.440116, 0.000000}}],
    Polygon[{{0.257952, 0.443561, 0.001744},{0.258361, 0.443561, 0.003445},{
      0.258880, 0.440285, 0.003445},{0.258491, 0.440159, 0.001744}}],
    Polygon[{{0.258361, 0.443561, 0.003445},{0.259030, 0.443561, 0.005062},{
      0.259516, 0.440492, 0.005062},{0.258880, 0.440285, 0.003445}}],
    Polygon[{{0.259030, 0.443561, 0.005062},{0.259944, 0.443561, 0.006553},{
      0.260386, 0.440774, 0.006553},{0.259516, 0.440492, 0.005062}}],
    Polygon[{{0.259944, 0.443561, 0.006553},{0.261081, 0.443561, 0.007884},{
      0.261466, 0.441125, 0.007884},{0.260386, 0.440774, 0.006553}}],
    Polygon[{{0.261081, 0.443561, 0.007884},{0.262411, 0.443561, 0.009020},{
      0.262732, 0.441536, 0.009020},{0.261466, 0.441125, 0.007884}}],
    Polygon[{{0.262411, 0.443561, 0.009020},{0.263903, 0.443561, 0.009934},{
      0.264150, 0.441997, 0.009934},{0.262732, 0.441536, 0.009020}}],
    Polygon[{{0.263903, 0.443561, 0.009934},{0.265519, 0.443561, 0.010603},{
      0.265688, 0.442497, 0.010603},{0.264150, 0.441997, 0.009934}}],
    Polygon[{{0.265519, 0.443561, 0.010603},{0.267220, 0.443561, 0.011012},{
      0.267305, 0.443022, 0.011012},{0.265688, 0.442497, 0.010603}}],
    Polygon[{{0.267305, 0.443022, -0.011012},{0.265688, 0.442497, -0.010603},{
      0.266177, 0.441536, -0.010603},{0.267553, 0.442536, -0.011012}}],
    Polygon[{{0.265688, 0.442497, -0.010603},{0.264150, 0.441997, -0.009934},{
      0.264869, 0.440586, -0.009934},{0.266177, 0.441536, -0.010603}}],
    Polygon[{{0.264150, 0.441997, -0.009934},{0.262732, 0.441536, -0.009020},{
      0.263662, 0.439710, -0.009020},{0.264869, 0.440586, -0.009934}}],
    Polygon[{{0.262732, 0.441536, -0.009020},{0.261466, 0.441125, -0.007884},{
      0.262586, 0.438928, -0.007884},{0.263662, 0.439710, -0.009020}}],
    Polygon[{{0.261466, 0.441125, -0.007884},{0.260386, 0.440774, -0.006553},{
      0.261667, 0.438260, -0.006553},{0.262586, 0.438928, -0.007884}}],
    Polygon[{{0.260386, 0.440774, -0.006553},{0.259516, 0.440492, -0.005062},{
      0.260927, 0.437722, -0.005062},{0.261667, 0.438260, -0.006553}}],
    Polygon[{{0.259516, 0.440492, -0.005062},{0.258880, 0.440285, -0.003445},{
      0.260386, 0.437329, -0.003445},{0.260927, 0.437722, -0.005062}}],
    Polygon[{{0.258880, 0.440285, -0.003445},{0.258491, 0.440159, -0.001744},{
      0.260055, 0.437089, -0.001744},{0.260386, 0.437329, -0.003445}}],
    Polygon[{{0.258491, 0.440159, -0.001744},{0.258361, 0.440116, 0.000000},{
      0.259944, 0.437008, 0.000000},{0.260055, 0.437089, -0.001744}}],
    Polygon[{{0.258361, 0.440116, 0.000000},{0.258491, 0.440159, 0.001744},{
      0.260055, 0.437089, 0.001744},{0.259944, 0.437008, 0.000000}}],
    Polygon[{{0.258491, 0.440159, 0.001744},{0.258880, 0.440285, 0.003445},{
      0.260386, 0.437329, 0.003445},{0.260055, 0.437089, 0.001744}}],
    Polygon[{{0.258880, 0.440285, 0.003445},{0.259516, 0.440492, 0.005062},{
      0.260927, 0.437722, 0.005062},{0.260386, 0.437329, 0.003445}}],
    Polygon[{{0.259516, 0.440492, 0.005062},{0.260386, 0.440774, 0.006553},{
      0.261667, 0.438260, 0.006553},{0.260927, 0.437722, 0.005062}}],
    Polygon[{{0.260386, 0.440774, 0.006553},{0.261466, 0.441125, 0.007884},{
      0.262586, 0.438928, 0.007884},{0.261667, 0.438260, 0.006553}}],
    Polygon[{{0.261466, 0.441125, 0.007884},{0.262732, 0.441536, 0.009020},{
      0.263662, 0.439710, 0.009020},{0.262586, 0.438928, 0.007884}}],
    Polygon[{{0.262732, 0.441536, 0.009020},{0.264150, 0.441997, 0.009934},{
      0.264869, 0.440586, 0.009934},{0.263662, 0.439710, 0.009020}}],
    Polygon[{{0.264150, 0.441997, 0.009934},{0.265688, 0.442497, 0.010603},{
      0.266177, 0.441536, 0.010603},{0.264869, 0.440586, 0.009934}}],
    Polygon[{{0.265688, 0.442497, 0.010603},{0.267305, 0.443022, 0.011012},{
      0.267553, 0.442536, 0.011012},{0.266177, 0.441536, 0.010603}}],
    Polygon[{{0.267553, 0.442536, -0.011012},{0.266177, 0.441536, -0.010603},{
      0.266939, 0.440774, -0.010603},{0.267939, 0.442150, -0.011012}}],
    Polygon[{{0.266177, 0.441536, -0.010603},{0.264869, 0.440586, -0.009934},{
      0.265989, 0.439467, -0.009934},{0.266939, 0.440774, -0.010603}}],
    Polygon[{{0.264869, 0.440586, -0.009934},{0.263662, 0.439710, -0.009020},{
      0.265112, 0.438260, -0.009020},{0.265989, 0.439467, -0.009934}}],
    Polygon[{{0.263662, 0.439710, -0.009020},{0.262586, 0.438928, -0.007884},{
      0.264330, 0.437183, -0.007884},{0.265112, 0.438260, -0.009020}}],
    Polygon[{{0.262586, 0.438928, -0.007884},{0.261667, 0.438260, -0.006553},{
      0.263662, 0.436264, -0.006553},{0.264330, 0.437183, -0.007884}}],
    Polygon[{{0.261667, 0.438260, -0.006553},{0.260927, 0.437722, -0.005062},{
      0.263125, 0.435525, -0.005062},{0.263662, 0.436264, -0.006553}}],
    Polygon[{{0.260927, 0.437722, -0.005062},{0.260386, 0.437329, -0.003445},{
      0.262732, 0.434983, -0.003445},{0.263125, 0.435525, -0.005062}}],
    Polygon[{{0.260386, 0.437329, -0.003445},{0.260055, 0.437089, -0.001744},{
      0.262492, 0.434653, -0.001744},{0.262732, 0.434983, -0.003445}}],
    Polygon[{{0.260055, 0.437089, -0.001744},{0.259944, 0.437008, 0.000000},{
      0.262411, 0.434542, 0.000000},{0.262492, 0.434653, -0.001744}}],
    Polygon[{{0.259944, 0.437008, 0.000000},{0.260055, 0.437089, 0.001744},{
      0.262492, 0.434653, 0.001744},{0.262411, 0.434542, 0.000000}}],
    Polygon[{{0.260055, 0.437089, 0.001744},{0.260386, 0.437329, 0.003445},{
      0.262732, 0.434983, 0.003445},{0.262492, 0.434653, 0.001744}}],
    Polygon[{{0.260386, 0.437329, 0.003445},{0.260927, 0.437722, 0.005062},{
      0.263125, 0.435525, 0.005062},{0.262732, 0.434983, 0.003445}}],
    Polygon[{{0.260927, 0.437722, 0.005062},{0.261667, 0.438260, 0.006553},{
      0.263662, 0.436264, 0.006553},{0.263125, 0.435525, 0.005062}}],
    Polygon[{{0.261667, 0.438260, 0.006553},{0.262586, 0.438928, 0.007884},{
      0.264330, 0.437183, 0.007884},{0.263662, 0.436264, 0.006553}}],
    Polygon[{{0.262586, 0.438928, 0.007884},{0.263662, 0.439710, 0.009020},{
      0.265112, 0.438260, 0.009020},{0.264330, 0.437183, 0.007884}}],
    Polygon[{{0.263662, 0.439710, 0.009020},{0.264869, 0.440586, 0.009934},{
      0.265989, 0.439467, 0.009934},{0.265112, 0.438260, 0.009020}}],
    Polygon[{{0.264869, 0.440586, 0.009934},{0.266177, 0.441536, 0.010603},{
      0.266939, 0.440774, 0.010603},{0.265989, 0.439467, 0.009934}}],
    Polygon[{{0.266177, 0.441536, 0.010603},{0.267553, 0.442536, 0.011012},{
      0.267939, 0.442150, 0.011012},{0.266939, 0.440774, 0.010603}}],
    Polygon[{{0.267939, 0.442150, -0.011012},{0.266939, 0.440774, -0.010603},{
      0.267900, 0.440285, -0.010603},{0.268425, 0.441903, -0.011012}}],
    Polygon[{{0.266939, 0.440774, -0.010603},{0.265989, 0.439467, -0.009934},{
      0.267400, 0.438748, -0.009934},{0.267900, 0.440285, -0.010603}}],
    Polygon[{{0.265989, 0.439467, -0.009934},{0.265112, 0.438260, -0.009020},{
      0.266939, 0.437329, -0.009020},{0.267400, 0.438748, -0.009934}}],
    Polygon[{{0.265112, 0.438260, -0.009020},{0.264330, 0.437183, -0.007884},{
      0.266528, 0.436064, -0.007884},{0.266939, 0.437329, -0.009020}}],
    Polygon[{{0.264330, 0.437183, -0.007884},{0.263662, 0.436264, -0.006553},{
      0.266177, 0.434983, -0.006553},{0.266528, 0.436064, -0.007884}}],
    Polygon[{{0.263662, 0.436264, -0.006553},{0.263125, 0.435525, -0.005062},{
      0.265894, 0.434114, -0.005062},{0.266177, 0.434983, -0.006553}}],
    Polygon[{{0.263125, 0.435525, -0.005062},{0.262732, 0.434983, -0.003445},{
      0.265688, 0.433477, -0.003445},{0.265894, 0.434114, -0.005062}}],
    Polygon[{{0.262732, 0.434983, -0.003445},{0.262492, 0.434653, -0.001744},{
      0.265561, 0.433089, -0.001744},{0.265688, 0.433477, -0.003445}}],
    Polygon[{{0.262492, 0.434653, -0.001744},{0.262411, 0.434542, 0.000000},{
      0.265519, 0.432958, 0.000000},{0.265561, 0.433089, -0.001744}}],
    Polygon[{{0.262411, 0.434542, 0.000000},{0.262492, 0.434653, 0.001744},{
      0.265561, 0.433089, 0.001744},{0.265519, 0.432958, 0.000000}}],
    Polygon[{{0.262492, 0.434653, 0.001744},{0.262732, 0.434983, 0.003445},{
      0.265688, 0.433477, 0.003445},{0.265561, 0.433089, 0.001744}}],
    Polygon[{{0.262732, 0.434983, 0.003445},{0.263125, 0.435525, 0.005062},{
      0.265894, 0.434114, 0.005062},{0.265688, 0.433477, 0.003445}}],
    Polygon[{{0.263125, 0.435525, 0.005062},{0.263662, 0.436264, 0.006553},{
      0.266177, 0.434983, 0.006553},{0.265894, 0.434114, 0.005062}}],
    Polygon[{{0.263662, 0.436264, 0.006553},{0.264330, 0.437183, 0.007884},{
      0.266528, 0.436064, 0.007884},{0.266177, 0.434983, 0.006553}}],
    Polygon[{{0.264330, 0.437183, 0.007884},{0.265112, 0.438260, 0.009020},{
      0.266939, 0.437329, 0.009020},{0.266528, 0.436064, 0.007884}}],
    Polygon[{{0.265112, 0.438260, 0.009020},{0.265989, 0.439467, 0.009934},{
      0.267400, 0.438748, 0.009934},{0.266939, 0.437329, 0.009020}}],
    Polygon[{{0.265989, 0.439467, 0.009934},{0.266939, 0.440774, 0.010603},{
      0.267900, 0.440285, 0.010603},{0.267400, 0.438748, 0.009934}}],
    Polygon[{{0.266939, 0.440774, 0.010603},{0.267939, 0.442150, 0.011012},{
      0.268425, 0.441903, 0.011012},{0.267900, 0.440285, 0.010603}}],
    Polygon[{{0.268425, 0.441903, -0.011012},{0.267900, 0.440285, -0.010603},{
      0.268964, 0.440116, -0.010603},{0.268964, 0.441817, -0.011012}}],
    Polygon[{{0.267900, 0.440285, -0.010603},{0.267400, 0.438748, -0.009934},{
      0.268964, 0.438500, -0.009934},{0.268964, 0.440116, -0.010603}}],
    Polygon[{{0.267400, 0.438748, -0.009934},{0.266939, 0.437329, -0.009020},{
      0.268964, 0.437008, -0.009020},{0.268964, 0.438500, -0.009934}}],
    Polygon[{{0.266939, 0.437329, -0.009020},{0.266528, 0.436064, -0.007884},{
      0.268964, 0.435678, -0.007884},{0.268964, 0.437008, -0.009020}}],
    Polygon[{{0.266528, 0.436064, -0.007884},{0.266177, 0.434983, -0.006553},{
      0.268964, 0.434542, -0.006553},{0.268964, 0.435678, -0.007884}}],
    Polygon[{{0.266177, 0.434983, -0.006553},{0.265894, 0.434114, -0.005062},{
      0.268964, 0.433628, -0.005062},{0.268964, 0.434542, -0.006553}}],
    Polygon[{{0.265894, 0.434114, -0.005062},{0.265688, 0.433477, -0.003445},{
      0.268964, 0.432958, -0.003445},{0.268964, 0.433628, -0.005062}}],
    Polygon[{{0.265688, 0.433477, -0.003445},{0.265561, 0.433089, -0.001744},{
      0.268964, 0.432550, -0.001744},{0.268964, 0.432958, -0.003445}}],
    Polygon[{{0.265561, 0.433089, -0.001744},{0.265519, 0.432958, 0.000000},{
      0.268964, 0.432412, 0.000000},{0.268964, 0.432550, -0.001744}}],
    Polygon[{{0.265519, 0.432958, 0.000000},{0.265561, 0.433089, 0.001744},{
      0.268964, 0.432550, 0.001744},{0.268964, 0.432412, 0.000000}}],
    Polygon[{{0.265561, 0.433089, 0.001744},{0.265688, 0.433477, 0.003445},{
      0.268964, 0.432958, 0.003445},{0.268964, 0.432550, 0.001744}}],
    Polygon[{{0.265688, 0.433477, 0.003445},{0.265894, 0.434114, 0.005062},{
      0.268964, 0.433628, 0.005062},{0.268964, 0.432958, 0.003445}}],
    Polygon[{{0.265894, 0.434114, 0.005062},{0.266177, 0.434983, 0.006553},{
      0.268964, 0.434542, 0.006553},{0.268964, 0.433628, 0.005062}}],
    Polygon[{{0.266177, 0.434983, 0.006553},{0.266528, 0.436064, 0.007884},{
      0.268964, 0.435678, 0.007884},{0.268964, 0.434542, 0.006553}}],
    Polygon[{{0.266528, 0.436064, 0.007884},{0.266939, 0.437329, 0.009020},{
      0.268964, 0.437008, 0.009020},{0.268964, 0.435678, 0.007884}}],
    Polygon[{{0.266939, 0.437329, 0.009020},{0.267400, 0.438748, 0.009934},{
      0.268964, 0.438500, 0.009934},{0.268964, 0.437008, 0.009020}}],
    Polygon[{{0.267400, 0.438748, 0.009934},{0.267900, 0.440285, 0.010603},{
      0.268964, 0.440116, 0.010603},{0.268964, 0.438500, 0.009934}}],
    Polygon[{{0.267900, 0.440285, 0.010603},{0.268425, 0.441903, 0.011012},{
      0.268964, 0.441817, 0.011012},{0.268964, 0.440116, 0.010603}}],
    Polygon[{{0.268964, 0.441817, -0.011012},{0.268964, 0.440116, -0.010603},{
      0.270029, 0.440285, -0.010603},{0.269503, 0.441903, -0.011012}}],
    Polygon[{{0.268964, 0.440116, -0.010603},{0.268964, 0.438500, -0.009934},{
      0.270528, 0.438748, -0.009934},{0.270029, 0.440285, -0.010603}}],
    Polygon[{{0.268964, 0.438500, -0.009934},{0.268964, 0.437008, -0.009020},{
      0.270989, 0.437329, -0.009020},{0.270528, 0.438748, -0.009934}}],
    Polygon[{{0.268964, 0.437008, -0.009020},{0.268964, 0.435678, -0.007884},{
      0.271400, 0.436064, -0.007884},{0.270989, 0.437329, -0.009020}}],
    Polygon[{{0.268964, 0.435678, -0.007884},{0.268964, 0.434542, -0.006553},{
      0.271751, 0.434983, -0.006553},{0.271400, 0.436064, -0.007884}}],
    Polygon[{{0.268964, 0.434542, -0.006553},{0.268964, 0.433628, -0.005062},{
      0.272034, 0.434114, -0.005062},{0.271751, 0.434983, -0.006553}}],
    Polygon[{{0.268964, 0.433628, -0.005062},{0.268964, 0.432958, -0.003445},{
      0.272241, 0.433477, -0.003445},{0.272034, 0.434114, -0.005062}}],
    Polygon[{{0.268964, 0.432958, -0.003445},{0.268964, 0.432550, -0.001744},{
      0.272367, 0.433089, -0.001744},{0.272241, 0.433477, -0.003445}}],
    Polygon[{{0.268964, 0.432550, -0.001744},{0.268964, 0.432412, 0.000000},{
      0.272409, 0.432958, 0.000000},{0.272367, 0.433089, -0.001744}}],
    Polygon[{{0.268964, 0.432412, 0.000000},{0.268964, 0.432550, 0.001744},{
      0.272367, 0.433089, 0.001744},{0.272409, 0.432958, 0.000000}}],
    Polygon[{{0.268964, 0.432550, 0.001744},{0.268964, 0.432958, 0.003445},{
      0.272241, 0.433477, 0.003445},{0.272367, 0.433089, 0.001744}}],
    Polygon[{{0.268964, 0.432958, 0.003445},{0.268964, 0.433628, 0.005062},{
      0.272034, 0.434114, 0.005062},{0.272241, 0.433477, 0.003445}}],
    Polygon[{{0.268964, 0.433628, 0.005062},{0.268964, 0.434542, 0.006553},{
      0.271751, 0.434983, 0.006553},{0.272034, 0.434114, 0.005062}}],
    Polygon[{{0.268964, 0.434542, 0.006553},{0.268964, 0.435678, 0.007884},{
      0.271400, 0.436064, 0.007884},{0.271751, 0.434983, 0.006553}}],
    Polygon[{{0.268964, 0.435678, 0.007884},{0.268964, 0.437008, 0.009020},{
      0.270989, 0.437329, 0.009020},{0.271400, 0.436064, 0.007884}}],
    Polygon[{{0.268964, 0.437008, 0.009020},{0.268964, 0.438500, 0.009934},{
      0.270528, 0.438748, 0.009934},{0.270989, 0.437329, 0.009020}}],
    Polygon[{{0.268964, 0.438500, 0.009934},{0.268964, 0.440116, 0.010603},{
      0.270029, 0.440285, 0.010603},{0.270528, 0.438748, 0.009934}}],
    Polygon[{{0.268964, 0.440116, 0.010603},{0.268964, 0.441817, 0.011012},{
      0.269503, 0.441903, 0.011012},{0.270029, 0.440285, 0.010603}}],
    Polygon[{{0.269503, 0.441903, -0.011012},{0.270029, 0.440285, -0.010603},{
      0.270989, 0.440774, -0.010603},{0.269989, 0.442150, -0.011012}}],
    Polygon[{{0.270029, 0.440285, -0.010603},{0.270528, 0.438748, -0.009934},{
      0.271939, 0.439467, -0.009934},{0.270989, 0.440774, -0.010603}}],
    Polygon[{{0.270528, 0.438748, -0.009934},{0.270989, 0.437329, -0.009020},{
      0.272816, 0.438260, -0.009020},{0.271939, 0.439467, -0.009934}}],
    Polygon[{{0.270989, 0.437329, -0.009020},{0.271400, 0.436064, -0.007884},{
      0.273598, 0.437183, -0.007884},{0.272816, 0.438260, -0.009020}}],
    Polygon[{{0.271400, 0.436064, -0.007884},{0.271751, 0.434983, -0.006553},{
      0.274266, 0.436264, -0.006553},{0.273598, 0.437183, -0.007884}}],
    Polygon[{{0.271751, 0.434983, -0.006553},{0.272034, 0.434114, -0.005062},{
      0.274803, 0.435525, -0.005062},{0.274266, 0.436264, -0.006553}}],
    Polygon[{{0.272034, 0.434114, -0.005062},{0.272241, 0.433477, -0.003445},{
      0.275197, 0.434983, -0.003445},{0.274803, 0.435525, -0.005062}}],
    Polygon[{{0.272241, 0.433477, -0.003445},{0.272367, 0.433089, -0.001744},{
      0.275437, 0.434653, -0.001744},{0.275197, 0.434983, -0.003445}}],
    Polygon[{{0.272367, 0.433089, -0.001744},{0.272409, 0.432958, 0.000000},{
      0.275517, 0.434542, 0.000000},{0.275437, 0.434653, -0.001744}}],
    Polygon[{{0.272409, 0.432958, 0.000000},{0.272367, 0.433089, 0.001744},{
      0.275437, 0.434653, 0.001744},{0.275517, 0.434542, 0.000000}}],
    Polygon[{{0.272367, 0.433089, 0.001744},{0.272241, 0.433477, 0.003445},{
      0.275197, 0.434983, 0.003445},{0.275437, 0.434653, 0.001744}}],
    Polygon[{{0.272241, 0.433477, 0.003445},{0.272034, 0.434114, 0.005062},{
      0.274803, 0.435525, 0.005062},{0.275197, 0.434983, 0.003445}}],
    Polygon[{{0.272034, 0.434114, 0.005062},{0.271751, 0.434983, 0.006553},{
      0.274266, 0.436264, 0.006553},{0.274803, 0.435525, 0.005062}}],
    Polygon[{{0.271751, 0.434983, 0.006553},{0.271400, 0.436064, 0.007884},{
      0.273598, 0.437183, 0.007884},{0.274266, 0.436264, 0.006553}}],
    Polygon[{{0.271400, 0.436064, 0.007884},{0.270989, 0.437329, 0.009020},{
      0.272816, 0.438260, 0.009020},{0.273598, 0.437183, 0.007884}}],
    Polygon[{{0.270989, 0.437329, 0.009020},{0.270528, 0.438748, 0.009934},{
      0.271939, 0.439467, 0.009934},{0.272816, 0.438260, 0.009020}}],
    Polygon[{{0.270528, 0.438748, 0.009934},{0.270029, 0.440285, 0.010603},{
      0.270989, 0.440774, 0.010603},{0.271939, 0.439467, 0.009934}}],
    Polygon[{{0.270029, 0.440285, 0.010603},{0.269503, 0.441903, 0.011012},{
      0.269989, 0.442150, 0.011012},{0.270989, 0.440774, 0.010603}}],
    Polygon[{{0.269989, 0.442150, -0.011012},{0.270989, 0.440774, -0.010603},{
      0.271751, 0.441536, -0.010603},{0.270375, 0.442536, -0.011012}}],
    Polygon[{{0.270989, 0.440774, -0.010603},{0.271939, 0.439467, -0.009934},{
      0.273059, 0.440586, -0.009934},{0.271751, 0.441536, -0.010603}}],
    Polygon[{{0.271939, 0.439467, -0.009934},{0.272816, 0.438260, -0.009020},{
      0.274266, 0.439710, -0.009020},{0.273059, 0.440586, -0.009934}}],
    Polygon[{{0.272816, 0.438260, -0.009020},{0.273598, 0.437183, -0.007884},{
      0.275342, 0.438928, -0.007884},{0.274266, 0.439710, -0.009020}}],
    Polygon[{{0.273598, 0.437183, -0.007884},{0.274266, 0.436264, -0.006553},{
      0.276261, 0.438260, -0.006553},{0.275342, 0.438928, -0.007884}}],
    Polygon[{{0.274266, 0.436264, -0.006553},{0.274803, 0.435525, -0.005062},{
      0.277001, 0.437722, -0.005062},{0.276261, 0.438260, -0.006553}}],
    Polygon[{{0.274803, 0.435525, -0.005062},{0.275197, 0.434983, -0.003445},{
      0.277542, 0.437329, -0.003445},{0.277001, 0.437722, -0.005062}}],
    Polygon[{{0.275197, 0.434983, -0.003445},{0.275437, 0.434653, -0.001744},{
      0.277873, 0.437089, -0.001744},{0.277542, 0.437329, -0.003445}}],
    Polygon[{{0.275437, 0.434653, -0.001744},{0.275517, 0.434542, 0.000000},{
      0.277984, 0.437008, 0.000000},{0.277873, 0.437089, -0.001744}}],
    Polygon[{{0.275517, 0.434542, 0.000000},{0.275437, 0.434653, 0.001744},{
      0.277873, 0.437089, 0.001744},{0.277984, 0.437008, 0.000000}}],
    Polygon[{{0.275437, 0.434653, 0.001744},{0.275197, 0.434983, 0.003445},{
      0.277542, 0.437329, 0.003445},{0.277873, 0.437089, 0.001744}}],
    Polygon[{{0.275197, 0.434983, 0.003445},{0.274803, 0.435525, 0.005062},{
      0.277001, 0.437722, 0.005062},{0.277542, 0.437329, 0.003445}}],
    Polygon[{{0.274803, 0.435525, 0.005062},{0.274266, 0.436264, 0.006553},{
      0.276261, 0.438260, 0.006553},{0.277001, 0.437722, 0.005062}}],
    Polygon[{{0.274266, 0.436264, 0.006553},{0.273598, 0.437183, 0.007884},{
      0.275342, 0.438928, 0.007884},{0.276261, 0.438260, 0.006553}}],
    Polygon[{{0.273598, 0.437183, 0.007884},{0.272816, 0.438260, 0.009020},{
      0.274266, 0.439710, 0.009020},{0.275342, 0.438928, 0.007884}}],
    Polygon[{{0.272816, 0.438260, 0.009020},{0.271939, 0.439467, 0.009934},{
      0.273059, 0.440586, 0.009934},{0.274266, 0.439710, 0.009020}}],
    Polygon[{{0.271939, 0.439467, 0.009934},{0.270989, 0.440774, 0.010603},{
      0.271751, 0.441536, 0.010603},{0.273059, 0.440586, 0.009934}}],
    Polygon[{{0.270989, 0.440774, 0.010603},{0.269989, 0.442150, 0.011012},{
      0.270375, 0.442536, 0.011012},{0.271751, 0.441536, 0.010603}}],
    Polygon[{{0.270375, 0.442536, -0.011012},{0.271751, 0.441536, -0.010603},{
      0.272241, 0.442497, -0.010603},{0.270623, 0.443022, -0.011012}}],
    Polygon[{{0.271751, 0.441536, -0.010603},{0.273059, 0.440586, -0.009934},{
      0.273778, 0.441997, -0.009934},{0.272241, 0.442497, -0.010603}}],
    Polygon[{{0.273059, 0.440586, -0.009934},{0.274266, 0.439710, -0.009020},{
      0.275197, 0.441536, -0.009020},{0.273778, 0.441997, -0.009934}}],
    Polygon[{{0.274266, 0.439710, -0.009020},{0.275342, 0.438928, -0.007884},{
      0.276462, 0.441125, -0.007884},{0.275197, 0.441536, -0.009020}}],
    Polygon[{{0.275342, 0.438928, -0.007884},{0.276261, 0.438260, -0.006553},{
      0.277542, 0.440774, -0.006553},{0.276462, 0.441125, -0.007884}}],
    Polygon[{{0.276261, 0.438260, -0.006553},{0.277001, 0.437722, -0.005062},{
      0.278412, 0.440492, -0.005062},{0.277542, 0.440774, -0.006553}}],
    Polygon[{{0.277001, 0.437722, -0.005062},{0.277542, 0.437329, -0.003445},{
      0.279049, 0.440285, -0.003445},{0.278412, 0.440492, -0.005062}}],
    Polygon[{{0.277542, 0.437329, -0.003445},{0.277873, 0.437089, -0.001744},{
      0.279437, 0.440159, -0.001744},{0.279049, 0.440285, -0.003445}}],
    Polygon[{{0.277873, 0.437089, -0.001744},{0.277984, 0.437008, 0.000000},{
      0.279568, 0.440116, 0.000000},{0.279437, 0.440159, -0.001744}}],
    Polygon[{{0.277984, 0.437008, 0.000000},{0.277873, 0.437089, 0.001744},{
      0.279437, 0.440159, 0.001744},{0.279568, 0.440116, 0.000000}}],
    Polygon[{{0.277873, 0.437089, 0.001744},{0.277542, 0.437329, 0.003445},{
      0.279049, 0.440285, 0.003445},{0.279437, 0.440159, 0.001744}}],
    Polygon[{{0.277542, 0.437329, 0.003445},{0.277001, 0.437722, 0.005062},{
      0.278412, 0.440492, 0.005062},{0.279049, 0.440285, 0.003445}}],
    Polygon[{{0.277001, 0.437722, 0.005062},{0.276261, 0.438260, 0.006553},{
      0.277542, 0.440774, 0.006553},{0.278412, 0.440492, 0.005062}}],
    Polygon[{{0.276261, 0.438260, 0.006553},{0.275342, 0.438928, 0.007884},{
      0.276462, 0.441125, 0.007884},{0.277542, 0.440774, 0.006553}}],
    Polygon[{{0.275342, 0.438928, 0.007884},{0.274266, 0.439710, 0.009020},{
      0.275197, 0.441536, 0.009020},{0.276462, 0.441125, 0.007884}}],
    Polygon[{{0.274266, 0.439710, 0.009020},{0.273059, 0.440586, 0.009934},{
      0.273778, 0.441997, 0.009934},{0.275197, 0.441536, 0.009020}}],
    Polygon[{{0.273059, 0.440586, 0.009934},{0.271751, 0.441536, 0.010603},{
      0.272241, 0.442497, 0.010603},{0.273778, 0.441997, 0.009934}}],
    Polygon[{{0.271751, 0.441536, 0.010603},{0.270375, 0.442536, 0.011012},{
      0.270623, 0.443022, 0.011012},{0.272241, 0.442497, 0.010603}}],
    Polygon[{{0.270623, 0.443022, -0.011012},{0.272241, 0.442497, -0.010603},{
      0.272409, 0.443561, -0.010603},{0.270708, 0.443561, -0.011012}}],
    Polygon[{{0.272241, 0.442497, -0.010603},{0.273778, 0.441997, -0.009934},{
      0.274026, 0.443561, -0.009934},{0.272409, 0.443561, -0.010603}}],
    Polygon[{{0.273778, 0.441997, -0.009934},{0.275197, 0.441536, -0.009020},{
      0.275517, 0.443561, -0.009020},{0.274026, 0.443561, -0.009934}}],
    Polygon[{{0.275197, 0.441536, -0.009020},{0.276462, 0.441125, -0.007884},{
      0.276848, 0.443561, -0.007884},{0.275517, 0.443561, -0.009020}}],
    Polygon[{{0.276462, 0.441125, -0.007884},{0.277542, 0.440774, -0.006553},{
      0.277984, 0.443561, -0.006553},{0.276848, 0.443561, -0.007884}}],
    Polygon[{{0.277542, 0.440774, -0.006553},{0.278412, 0.440492, -0.005062},{
      0.278898, 0.443561, -0.005062},{0.277984, 0.443561, -0.006553}}],
    Polygon[{{0.278412, 0.440492, -0.005062},{0.279049, 0.440285, -0.003445},{
      0.279568, 0.443561, -0.003445},{0.278898, 0.443561, -0.005062}}],
    Polygon[{{0.279049, 0.440285, -0.003445},{0.279437, 0.440159, -0.001744},{
      0.279976, 0.443561, -0.001744},{0.279568, 0.443561, -0.003445}}],
    Polygon[{{0.279437, 0.440159, -0.001744},{0.279568, 0.440116, 0.000000},{
      0.280113, 0.443561, 0.000000},{0.279976, 0.443561, -0.001744}}],
    Polygon[{{0.279568, 0.440116, 0.000000},{0.279437, 0.440159, 0.001744},{
      0.279976, 0.443561, 0.001744},{0.280113, 0.443561, 0.000000}}],
    Polygon[{{0.279437, 0.440159, 0.001744},{0.279049, 0.440285, 0.003445},{
      0.279568, 0.443561, 0.003445},{0.279976, 0.443561, 0.001744}}],
    Polygon[{{0.279049, 0.440285, 0.003445},{0.278412, 0.440492, 0.005062},{
      0.278898, 0.443561, 0.005062},{0.279568, 0.443561, 0.003445}}],
    Polygon[{{0.278412, 0.440492, 0.005062},{0.277542, 0.440774, 0.006553},{
      0.277984, 0.443561, 0.006553},{0.278898, 0.443561, 0.005062}}],
    Polygon[{{0.277542, 0.440774, 0.006553},{0.276462, 0.441125, 0.007884},{
      0.276848, 0.443561, 0.007884},{0.277984, 0.443561, 0.006553}}],
    Polygon[{{0.276462, 0.441125, 0.007884},{0.275197, 0.441536, 0.009020},{
      0.275517, 0.443561, 0.009020},{0.276848, 0.443561, 0.007884}}],
    Polygon[{{0.275197, 0.441536, 0.009020},{0.273778, 0.441997, 0.009934},{
      0.274026, 0.443561, 0.009934},{0.275517, 0.443561, 0.009020}}],
    Polygon[{{0.273778, 0.441997, 0.009934},{0.272241, 0.442497, 0.010603},{
      0.272409, 0.443561, 0.010603},{0.274026, 0.443561, 0.009934}}],
    Polygon[{{0.272241, 0.442497, 0.010603},{0.270623, 0.443022, 0.011012},{
      0.270708, 0.443561, 0.011012},{0.272409, 0.443561, 0.010603}}],
    Polygon[{{0.304658, 0.392133, -0.009381},{0.306107, 0.392133, -0.009033},{
      0.305964, 0.393040, -0.009033},{0.304585, 0.392593, -0.009381}}],
    Polygon[{{0.306107, 0.392133, -0.009033},{0.307484, 0.392133, -0.008463},{
      0.307273, 0.393466, -0.008463},{0.305964, 0.393040, -0.009033}}],
    Polygon[{{0.307484, 0.392133, -0.008463},{0.308755, 0.392133, -0.007684},{
      0.308482, 0.393859, -0.007684},{0.307273, 0.393466, -0.008463}}],
    Polygon[{{0.308755, 0.392133, -0.007684},{0.309889, 0.392133, -0.006716},{
      0.309560, 0.394209, -0.006716},{0.308482, 0.393859, -0.007684}}],
    Polygon[{{0.309889, 0.392133, -0.006716},{0.310856, 0.392133, -0.005583},{
      0.310480, 0.394508, -0.005583},{0.309560, 0.394209, -0.006716}}],
    Polygon[{{0.310856, 0.392133, -0.005583},{0.311635, 0.392133, -0.004312},{
      0.311221, 0.394749, -0.004312},{0.310480, 0.394508, -0.005583}}],
    Polygon[{{0.311635, 0.392133, -0.004312},{0.312206, 0.392133, -0.002935},{
      0.311763, 0.394925, -0.002935},{0.311221, 0.394749, -0.004312}}],
    Polygon[{{0.312206, 0.392133, -0.002935},{0.312554, 0.392133, -0.001486},{
      0.312094, 0.395032, -0.001486},{0.311763, 0.394925, -0.002935}}],
    Polygon[{{0.312554, 0.392133, -0.001486},{0.312670, 0.392133, 0.000000},{
      0.312206, 0.395069, 0.000000},{0.312094, 0.395032, -0.001486}}],
    Polygon[{{0.312670, 0.392133, 0.000000},{0.312554, 0.392133, 0.001486},{
      0.312094, 0.395032, 0.001486},{0.312206, 0.395069, 0.000000}}],
    Polygon[{{0.312554, 0.392133, 0.001486},{0.312206, 0.392133, 0.002935},{
      0.311763, 0.394925, 0.002935},{0.312094, 0.395032, 0.001486}}],
    Polygon[{{0.312206, 0.392133, 0.002935},{0.311635, 0.392133, 0.004312},{
      0.311221, 0.394749, 0.004312},{0.311763, 0.394925, 0.002935}}],
    Polygon[{{0.311635, 0.392133, 0.004312},{0.310856, 0.392133, 0.005583},{
      0.310480, 0.394508, 0.005583},{0.311221, 0.394749, 0.004312}}],
    Polygon[{{0.310856, 0.392133, 0.005583},{0.309889, 0.392133, 0.006716},{
      0.309560, 0.394209, 0.006716},{0.310480, 0.394508, 0.005583}}],
    Polygon[{{0.309889, 0.392133, 0.006716},{0.308755, 0.392133, 0.007684},{
      0.308482, 0.393859, 0.007684},{0.309560, 0.394209, 0.006716}}],
    Polygon[{{0.308755, 0.392133, 0.007684},{0.307484, 0.392133, 0.008463},{
      0.307273, 0.393466, 0.008463},{0.308482, 0.393859, 0.007684}}],
    Polygon[{{0.307484, 0.392133, 0.008463},{0.306107, 0.392133, 0.009033},{
      0.305964, 0.393040, 0.009033},{0.307273, 0.393466, 0.008463}}],
    Polygon[{{0.306107, 0.392133, 0.009033},{0.304658, 0.392133, 0.009381},{
      0.304585, 0.392593, 0.009381},{0.305964, 0.393040, 0.009033}}],
    Polygon[{{0.304585, 0.392593, -0.009381},{0.305964, 0.393040, -0.009033},{
      0.305547, 0.393859, -0.009033},{0.304374, 0.393007, -0.009381}}],
    Polygon[{{0.305964, 0.393040, -0.009033},{0.307273, 0.393466, -0.008463},{
      0.306661, 0.394668, -0.008463},{0.305547, 0.393859, -0.009033}}],
    Polygon[{{0.307273, 0.393466, -0.008463},{0.308482, 0.393859, -0.007684},{
      0.307689, 0.395415, -0.007684},{0.306661, 0.394668, -0.008463}}],
    Polygon[{{0.308482, 0.393859, -0.007684},{0.309560, 0.394209, -0.006716},{
      0.308606, 0.396081, -0.006716},{0.307689, 0.395415, -0.007684}}],
    Polygon[{{0.309560, 0.394209, -0.006716},{0.310480, 0.394508, -0.005583},{
      0.309389, 0.396650, -0.005583},{0.308606, 0.396081, -0.006716}}],
    Polygon[{{0.310480, 0.394508, -0.005583},{0.311221, 0.394749, -0.004312},{
      0.310019, 0.397108, -0.004312},{0.309389, 0.396650, -0.005583}}],
    Polygon[{{0.311221, 0.394749, -0.004312},{0.311763, 0.394925, -0.002935},{
      0.310480, 0.397443, -0.002935},{0.310019, 0.397108, -0.004312}}],
    Polygon[{{0.311763, 0.394925, -0.002935},{0.312094, 0.395032, -0.001486},{
      0.310762, 0.397648, -0.001486},{0.310480, 0.397443, -0.002935}}],
    Polygon[{{0.312094, 0.395032, -0.001486},{0.312206, 0.395069, 0.000000},{
      0.310856, 0.397716, 0.000000},{0.310762, 0.397648, -0.001486}}],
    Polygon[{{0.312206, 0.395069, 0.000000},{0.312094, 0.395032, 0.001486},{
      0.310762, 0.397648, 0.001486},{0.310856, 0.397716, 0.000000}}],
    Polygon[{{0.312094, 0.395032, 0.001486},{0.311763, 0.394925, 0.002935},{
      0.310480, 0.397443, 0.002935},{0.310762, 0.397648, 0.001486}}],
    Polygon[{{0.311763, 0.394925, 0.002935},{0.311221, 0.394749, 0.004312},{
      0.310019, 0.397108, 0.004312},{0.310480, 0.397443, 0.002935}}],
    Polygon[{{0.311221, 0.394749, 0.004312},{0.310480, 0.394508, 0.005583},{
      0.309389, 0.396650, 0.005583},{0.310019, 0.397108, 0.004312}}],
    Polygon[{{0.310480, 0.394508, 0.005583},{0.309560, 0.394209, 0.006716},{
      0.308606, 0.396081, 0.006716},{0.309389, 0.396650, 0.005583}}],
    Polygon[{{0.309560, 0.394209, 0.006716},{0.308482, 0.393859, 0.007684},{
      0.307689, 0.395415, 0.007684},{0.308606, 0.396081, 0.006716}}],
    Polygon[{{0.308482, 0.393859, 0.007684},{0.307273, 0.393466, 0.008463},{
      0.306661, 0.394668, 0.008463},{0.307689, 0.395415, 0.007684}}],
    Polygon[{{0.307273, 0.393466, 0.008463},{0.305964, 0.393040, 0.009033},{
      0.305547, 0.393859, 0.009033},{0.306661, 0.394668, 0.008463}}],
    Polygon[{{0.305964, 0.393040, 0.009033},{0.304585, 0.392593, 0.009381},{
      0.304374, 0.393007, 0.009381},{0.305547, 0.393859, 0.009033}}],
    Polygon[{{0.304374, 0.393007, -0.009381},{0.305547, 0.393859, -0.009033},{
      0.304897, 0.394508, -0.009033},{0.304046, 0.393336, -0.009381}}],
    Polygon[{{0.305547, 0.393859, -0.009033},{0.306661, 0.394668, -0.008463},{
      0.305707, 0.395622, -0.008463},{0.304897, 0.394508, -0.009033}}],
    Polygon[{{0.306661, 0.394668, -0.008463},{0.307689, 0.395415, -0.007684},{
      0.306454, 0.396650, -0.007684},{0.305707, 0.395622, -0.008463}}],
    Polygon[{{0.307689, 0.395415, -0.007684},{0.308606, 0.396081, -0.006716},{
      0.307120, 0.397567, -0.006716},{0.306454, 0.396650, -0.007684}}],
    Polygon[{{0.308606, 0.396081, -0.006716},{0.309389, 0.396650, -0.005583},{
      0.307689, 0.398350, -0.005583},{0.307120, 0.397567, -0.006716}}],
    Polygon[{{0.309389, 0.396650, -0.005583},{0.310019, 0.397108, -0.004312},{
      0.308147, 0.398980, -0.004312},{0.307689, 0.398350, -0.005583}}],
    Polygon[{{0.310019, 0.397108, -0.004312},{0.310480, 0.397443, -0.002935},{
      0.308482, 0.399442, -0.002935},{0.308147, 0.398980, -0.004312}}],
    Polygon[{{0.310480, 0.397443, -0.002935},{0.310762, 0.397648, -0.001486},{
      0.308686, 0.399723, -0.001486},{0.308482, 0.399442, -0.002935}}],
    Polygon[{{0.310762, 0.397648, -0.001486},{0.310856, 0.397716, 0.000000},{
      0.308755, 0.399818, 0.000000},{0.308686, 0.399723, -0.001486}}],
    Polygon[{{0.310856, 0.397716, 0.000000},{0.310762, 0.397648, 0.001486},{
      0.308686, 0.399723, 0.001486},{0.308755, 0.399818, 0.000000}}],
    Polygon[{{0.310762, 0.397648, 0.001486},{0.310480, 0.397443, 0.002935},{
      0.308482, 0.399442, 0.002935},{0.308686, 0.399723, 0.001486}}],
    Polygon[{{0.310480, 0.397443, 0.002935},{0.310019, 0.397108, 0.004312},{
      0.308147, 0.398980, 0.004312},{0.308482, 0.399442, 0.002935}}],
    Polygon[{{0.310019, 0.397108, 0.004312},{0.309389, 0.396650, 0.005583},{
      0.307689, 0.398350, 0.005583},{0.308147, 0.398980, 0.004312}}],
    Polygon[{{0.309389, 0.396650, 0.005583},{0.308606, 0.396081, 0.006716},{
      0.307120, 0.397567, 0.006716},{0.307689, 0.398350, 0.005583}}],
    Polygon[{{0.308606, 0.396081, 0.006716},{0.307689, 0.395415, 0.007684},{
      0.306454, 0.396650, 0.007684},{0.307120, 0.397567, 0.006716}}],
    Polygon[{{0.307689, 0.395415, 0.007684},{0.306661, 0.394668, 0.008463},{
      0.305707, 0.395622, 0.008463},{0.306454, 0.396650, 0.007684}}],
    Polygon[{{0.306661, 0.394668, 0.008463},{0.305547, 0.393859, 0.009033},{
      0.304897, 0.394508, 0.009033},{0.305707, 0.395622, 0.008463}}],
    Polygon[{{0.305547, 0.393859, 0.009033},{0.304374, 0.393007, 0.009381},{
      0.304046, 0.393336, 0.009381},{0.304897, 0.394508, 0.009033}}],
    Polygon[{{0.304046, 0.393336, -0.009381},{0.304897, 0.394508, -0.009033},{
      0.304079, 0.394925, -0.009033},{0.303631, 0.393547, -0.009381}}],
    Polygon[{{0.304897, 0.394508, -0.009033},{0.305707, 0.395622, -0.008463},{
      0.304505, 0.396235, -0.008463},{0.304079, 0.394925, -0.009033}}],
    Polygon[{{0.305707, 0.395622, -0.008463},{0.306454, 0.396650, -0.007684},{
      0.304897, 0.397443, -0.007684},{0.304505, 0.396235, -0.008463}}],
    Polygon[{{0.306454, 0.396650, -0.007684},{0.307120, 0.397567, -0.006716},{
      0.305248, 0.398521, -0.006716},{0.304897, 0.397443, -0.007684}}],
    Polygon[{{0.307120, 0.397567, -0.006716},{0.307689, 0.398350, -0.005583},{
      0.305547, 0.399442, -0.005583},{0.305248, 0.398521, -0.006716}}],
    Polygon[{{0.307689, 0.398350, -0.005583},{0.308147, 0.398980, -0.004312},{
      0.305787, 0.400182, -0.004312},{0.305547, 0.399442, -0.005583}}],
    Polygon[{{0.308147, 0.398980, -0.004312},{0.308482, 0.399442, -0.002935},{
      0.305964, 0.400725, -0.002935},{0.305787, 0.400182, -0.004312}}],
    Polygon[{{0.308482, 0.399442, -0.002935},{0.308686, 0.399723, -0.001486},{
      0.306071, 0.401056, -0.001486},{0.305964, 0.400725, -0.002935}}],
    Polygon[{{0.308686, 0.399723, -0.001486},{0.308755, 0.399818, 0.000000},{
      0.306107, 0.401167, 0.000000},{0.306071, 0.401056, -0.001486}}],
    Polygon[{{0.308755, 0.399818, 0.000000},{0.308686, 0.399723, 0.001486},{
      0.306071, 0.401056, 0.001486},{0.306107, 0.401167, 0.000000}}],
    Polygon[{{0.308686, 0.399723, 0.001486},{0.308482, 0.399442, 0.002935},{
      0.305964, 0.400725, 0.002935},{0.306071, 0.401056, 0.001486}}],
    Polygon[{{0.308482, 0.399442, 0.002935},{0.308147, 0.398980, 0.004312},{
      0.305787, 0.400182, 0.004312},{0.305964, 0.400725, 0.002935}}],
    Polygon[{{0.308147, 0.398980, 0.004312},{0.307689, 0.398350, 0.005583},{
      0.305547, 0.399442, 0.005583},{0.305787, 0.400182, 0.004312}}],
    Polygon[{{0.307689, 0.398350, 0.005583},{0.307120, 0.397567, 0.006716},{
      0.305248, 0.398521, 0.006716},{0.305547, 0.399442, 0.005583}}],
    Polygon[{{0.307120, 0.397567, 0.006716},{0.306454, 0.396650, 0.007684},{
      0.304897, 0.397443, 0.007684},{0.305248, 0.398521, 0.006716}}],
    Polygon[{{0.306454, 0.396650, 0.007684},{0.305707, 0.395622, 0.008463},{
      0.304505, 0.396235, 0.008463},{0.304897, 0.397443, 0.007684}}],
    Polygon[{{0.305707, 0.395622, 0.008463},{0.304897, 0.394508, 0.009033},{
      0.304079, 0.394925, 0.009033},{0.304505, 0.396235, 0.008463}}],
    Polygon[{{0.304897, 0.394508, 0.009033},{0.304046, 0.393336, 0.009381},{
      0.303631, 0.393547, 0.009381},{0.304079, 0.394925, 0.009033}}],
    Polygon[{{0.303631, 0.393547, -0.009381},{0.304079, 0.394925, -0.009033},{
      0.303172, 0.395069, -0.009033},{0.303172, 0.393619, -0.009381}}],
    Polygon[{{0.304079, 0.394925, -0.009033},{0.304505, 0.396235, -0.008463},{
      0.303172, 0.396446, -0.008463},{0.303172, 0.395069, -0.009033}}],
    Polygon[{{0.304505, 0.396235, -0.008463},{0.304897, 0.397443, -0.007684},{
      0.303172, 0.397716, -0.007684},{0.303172, 0.396446, -0.008463}}],
    Polygon[{{0.304897, 0.397443, -0.007684},{0.305248, 0.398521, -0.006716},{
      0.303172, 0.398850, -0.006716},{0.303172, 0.397716, -0.007684}}],
    Polygon[{{0.305248, 0.398521, -0.006716},{0.305547, 0.399442, -0.005583},{
      0.303172, 0.399818, -0.005583},{0.303172, 0.398850, -0.006716}}],
    Polygon[{{0.305547, 0.399442, -0.005583},{0.305787, 0.400182, -0.004312},{
      0.303172, 0.400597, -0.004312},{0.303172, 0.399818, -0.005583}}],
    Polygon[{{0.305787, 0.400182, -0.004312},{0.305964, 0.400725, -0.002935},{
      0.303172, 0.401167, -0.002935},{0.303172, 0.400597, -0.004312}}],
    Polygon[{{0.305964, 0.400725, -0.002935},{0.306071, 0.401056, -0.001486},{
      0.303172, 0.401515, -0.001486},{0.303172, 0.401167, -0.002935}}],
    Polygon[{{0.306071, 0.401056, -0.001486},{0.306107, 0.401167, 0.000000},{
      0.303172, 0.401632, 0.000000},{0.303172, 0.401515, -0.001486}}],
    Polygon[{{0.306107, 0.401167, 0.000000},{0.306071, 0.401056, 0.001486},{
      0.303172, 0.401515, 0.001486},{0.303172, 0.401632, 0.000000}}],
    Polygon[{{0.306071, 0.401056, 0.001486},{0.305964, 0.400725, 0.002935},{
      0.303172, 0.401167, 0.002935},{0.303172, 0.401515, 0.001486}}],
    Polygon[{{0.305964, 0.400725, 0.002935},{0.305787, 0.400182, 0.004312},{
      0.303172, 0.400597, 0.004312},{0.303172, 0.401167, 0.002935}}],
    Polygon[{{0.305787, 0.400182, 0.004312},{0.305547, 0.399442, 0.005583},{
      0.303172, 0.399818, 0.005583},{0.303172, 0.400597, 0.004312}}],
    Polygon[{{0.305547, 0.399442, 0.005583},{0.305248, 0.398521, 0.006716},{
      0.303172, 0.398850, 0.006716},{0.303172, 0.399818, 0.005583}}],
    Polygon[{{0.305248, 0.398521, 0.006716},{0.304897, 0.397443, 0.007684},{
      0.303172, 0.397716, 0.007684},{0.303172, 0.398850, 0.006716}}],
    Polygon[{{0.304897, 0.397443, 0.007684},{0.304505, 0.396235, 0.008463},{
      0.303172, 0.396446, 0.008463},{0.303172, 0.397716, 0.007684}}],
    Polygon[{{0.304505, 0.396235, 0.008463},{0.304079, 0.394925, 0.009033},{
      0.303172, 0.395069, 0.009033},{0.303172, 0.396446, 0.008463}}],
    Polygon[{{0.304079, 0.394925, 0.009033},{0.303631, 0.393547, 0.009381},{
      0.303172, 0.393619, 0.009381},{0.303172, 0.395069, 0.009033}}],
    Polygon[{{0.303172, 0.393619, -0.009381},{0.303172, 0.395069, -0.009033},{
      0.302265, 0.394925, -0.009033},{0.302713, 0.393547, -0.009381}}],
    Polygon[{{0.303172, 0.395069, -0.009033},{0.303172, 0.396446, -0.008463},{
      0.301840, 0.396235, -0.008463},{0.302265, 0.394925, -0.009033}}],
    Polygon[{{0.303172, 0.396446, -0.008463},{0.303172, 0.397716, -0.007684},{
      0.301447, 0.397443, -0.007684},{0.301840, 0.396235, -0.008463}}],
    Polygon[{{0.303172, 0.397716, -0.007684},{0.303172, 0.398850, -0.006716},{
      0.301097, 0.398521, -0.006716},{0.301447, 0.397443, -0.007684}}],
    Polygon[{{0.303172, 0.398850, -0.006716},{0.303172, 0.399818, -0.005583},{
      0.300798, 0.399442, -0.005583},{0.301097, 0.398521, -0.006716}}],
    Polygon[{{0.303172, 0.399818, -0.005583},{0.303172, 0.400597, -0.004312},{
      0.300557, 0.400182, -0.004312},{0.300798, 0.399442, -0.005583}}],
    Polygon[{{0.303172, 0.400597, -0.004312},{0.303172, 0.401167, -0.002935},{
      0.300381, 0.400725, -0.002935},{0.300557, 0.400182, -0.004312}}],
    Polygon[{{0.303172, 0.401167, -0.002935},{0.303172, 0.401515, -0.001486},{
      0.300273, 0.401056, -0.001486},{0.300381, 0.400725, -0.002935}}],
    Polygon[{{0.303172, 0.401515, -0.001486},{0.303172, 0.401632, 0.000000},{
      0.300237, 0.401167, 0.000000},{0.300273, 0.401056, -0.001486}}],
    Polygon[{{0.303172, 0.401632, 0.000000},{0.303172, 0.401515, 0.001486},{
      0.300273, 0.401056, 0.001486},{0.300237, 0.401167, 0.000000}}],
    Polygon[{{0.303172, 0.401515, 0.001486},{0.303172, 0.401167, 0.002935},{
      0.300381, 0.400725, 0.002935},{0.300273, 0.401056, 0.001486}}],
    Polygon[{{0.303172, 0.401167, 0.002935},{0.303172, 0.400597, 0.004312},{
      0.300557, 0.400182, 0.004312},{0.300381, 0.400725, 0.002935}}],
    Polygon[{{0.303172, 0.400597, 0.004312},{0.303172, 0.399818, 0.005583},{
      0.300798, 0.399442, 0.005583},{0.300557, 0.400182, 0.004312}}],
    Polygon[{{0.303172, 0.399818, 0.005583},{0.303172, 0.398850, 0.006716},{
      0.301097, 0.398521, 0.006716},{0.300798, 0.399442, 0.005583}}],
    Polygon[{{0.303172, 0.398850, 0.006716},{0.303172, 0.397716, 0.007684},{
      0.301447, 0.397443, 0.007684},{0.301097, 0.398521, 0.006716}}],
    Polygon[{{0.303172, 0.397716, 0.007684},{0.303172, 0.396446, 0.008463},{
      0.301840, 0.396235, 0.008463},{0.301447, 0.397443, 0.007684}}],
    Polygon[{{0.303172, 0.396446, 0.008463},{0.303172, 0.395069, 0.009033},{
      0.302265, 0.394925, 0.009033},{0.301840, 0.396235, 0.008463}}],
    Polygon[{{0.303172, 0.395069, 0.009033},{0.303172, 0.393619, 0.009381},{
      0.302713, 0.393547, 0.009381},{0.302265, 0.394925, 0.009033}}],
    Polygon[{{0.302713, 0.393547, -0.009381},{0.302265, 0.394925, -0.009033},{
      0.301447, 0.394508, -0.009033},{0.302299, 0.393336, -0.009381}}],
    Polygon[{{0.302265, 0.394925, -0.009033},{0.301840, 0.396235, -0.008463},{
      0.300638, 0.395622, -0.008463},{0.301447, 0.394508, -0.009033}}],
    Polygon[{{0.301840, 0.396235, -0.008463},{0.301447, 0.397443, -0.007684},{
      0.299891, 0.396650, -0.007684},{0.300638, 0.395622, -0.008463}}],
    Polygon[{{0.301447, 0.397443, -0.007684},{0.301097, 0.398521, -0.006716},{
      0.299224, 0.397567, -0.006716},{0.299891, 0.396650, -0.007684}}],
    Polygon[{{0.301097, 0.398521, -0.006716},{0.300798, 0.399442, -0.005583},{
      0.298655, 0.398350, -0.005583},{0.299224, 0.397567, -0.006716}}],
    Polygon[{{0.300798, 0.399442, -0.005583},{0.300557, 0.400182, -0.004312},{
      0.298198, 0.398980, -0.004312},{0.298655, 0.398350, -0.005583}}],
    Polygon[{{0.300557, 0.400182, -0.004312},{0.300381, 0.400725, -0.002935},{
      0.297862, 0.399442, -0.002935},{0.298198, 0.398980, -0.004312}}],
    Polygon[{{0.300381, 0.400725, -0.002935},{0.300273, 0.401056, -0.001486},{
      0.297658, 0.399723, -0.001486},{0.297862, 0.399442, -0.002935}}],
    Polygon[{{0.300273, 0.401056, -0.001486},{0.300237, 0.401167, 0.000000},{
      0.297589, 0.399818, 0.000000},{0.297658, 0.399723, -0.001486}}],
    Polygon[{{0.300237, 0.401167, 0.000000},{0.300273, 0.401056, 0.001486},{
      0.297658, 0.399723, 0.001486},{0.297589, 0.399818, 0.000000}}],
    Polygon[{{0.300273, 0.401056, 0.001486},{0.300381, 0.400725, 0.002935},{
      0.297862, 0.399442, 0.002935},{0.297658, 0.399723, 0.001486}}],
    Polygon[{{0.300381, 0.400725, 0.002935},{0.300557, 0.400182, 0.004312},{
      0.298198, 0.398980, 0.004312},{0.297862, 0.399442, 0.002935}}],
    Polygon[{{0.300557, 0.400182, 0.004312},{0.300798, 0.399442, 0.005583},{
      0.298655, 0.398350, 0.005583},{0.298198, 0.398980, 0.004312}}],
    Polygon[{{0.300798, 0.399442, 0.005583},{0.301097, 0.398521, 0.006716},{
      0.299224, 0.397567, 0.006716},{0.298655, 0.398350, 0.005583}}],
    Polygon[{{0.301097, 0.398521, 0.006716},{0.301447, 0.397443, 0.007684},{
      0.299891, 0.396650, 0.007684},{0.299224, 0.397567, 0.006716}}],
    Polygon[{{0.301447, 0.397443, 0.007684},{0.301840, 0.396235, 0.008463},{
      0.300638, 0.395622, 0.008463},{0.299891, 0.396650, 0.007684}}],
    Polygon[{{0.301840, 0.396235, 0.008463},{0.302265, 0.394925, 0.009033},{
      0.301447, 0.394508, 0.009033},{0.300638, 0.395622, 0.008463}}],
    Polygon[{{0.302265, 0.394925, 0.009033},{0.302713, 0.393547, 0.009381},{
      0.302299, 0.393336, 0.009381},{0.301447, 0.394508, 0.009033}}],
    Polygon[{{0.302299, 0.393336, -0.009381},{0.301447, 0.394508, -0.009033},{
      0.300798, 0.393859, -0.009033},{0.301970, 0.393007, -0.009381}}],
    Polygon[{{0.301447, 0.394508, -0.009033},{0.300638, 0.395622, -0.008463},{
      0.299684, 0.394668, -0.008463},{0.300798, 0.393859, -0.009033}}],
    Polygon[{{0.300638, 0.395622, -0.008463},{0.299891, 0.396650, -0.007684},{
      0.298655, 0.395415, -0.007684},{0.299684, 0.394668, -0.008463}}],
    Polygon[{{0.299891, 0.396650, -0.007684},{0.299224, 0.397567, -0.006716},{
      0.297739, 0.396081, -0.006716},{0.298655, 0.395415, -0.007684}}],
    Polygon[{{0.299224, 0.397567, -0.006716},{0.298655, 0.398350, -0.005583},{
      0.296955, 0.396650, -0.005583},{0.297739, 0.396081, -0.006716}}],
    Polygon[{{0.298655, 0.398350, -0.005583},{0.298198, 0.398980, -0.004312},{
      0.296325, 0.397108, -0.004312},{0.296955, 0.396650, -0.005583}}],
    Polygon[{{0.298198, 0.398980, -0.004312},{0.297862, 0.399442, -0.002935},{
      0.295864, 0.397443, -0.002935},{0.296325, 0.397108, -0.004312}}],
    Polygon[{{0.297862, 0.399442, -0.002935},{0.297658, 0.399723, -0.001486},{
      0.295583, 0.397648, -0.001486},{0.295864, 0.397443, -0.002935}}],
    Polygon[{{0.297658, 0.399723, -0.001486},{0.297589, 0.399818, 0.000000},{
      0.295488, 0.397716, 0.000000},{0.295583, 0.397648, -0.001486}}],
    Polygon[{{0.297589, 0.399818, 0.000000},{0.297658, 0.399723, 0.001486},{
      0.295583, 0.397648, 0.001486},{0.295488, 0.397716, 0.000000}}],
    Polygon[{{0.297658, 0.399723, 0.001486},{0.297862, 0.399442, 0.002935},{
      0.295864, 0.397443, 0.002935},{0.295583, 0.397648, 0.001486}}],
    Polygon[{{0.297862, 0.399442, 0.002935},{0.298198, 0.398980, 0.004312},{
      0.296325, 0.397108, 0.004312},{0.295864, 0.397443, 0.002935}}],
    Polygon[{{0.298198, 0.398980, 0.004312},{0.298655, 0.398350, 0.005583},{
      0.296955, 0.396650, 0.005583},{0.296325, 0.397108, 0.004312}}],
    Polygon[{{0.298655, 0.398350, 0.005583},{0.299224, 0.397567, 0.006716},{
      0.297739, 0.396081, 0.006716},{0.296955, 0.396650, 0.005583}}],
    Polygon[{{0.299224, 0.397567, 0.006716},{0.299891, 0.396650, 0.007684},{
      0.298655, 0.395415, 0.007684},{0.297739, 0.396081, 0.006716}}],
    Polygon[{{0.299891, 0.396650, 0.007684},{0.300638, 0.395622, 0.008463},{
      0.299684, 0.394668, 0.008463},{0.298655, 0.395415, 0.007684}}],
    Polygon[{{0.300638, 0.395622, 0.008463},{0.301447, 0.394508, 0.009033},{
      0.300798, 0.393859, 0.009033},{0.299684, 0.394668, 0.008463}}],
    Polygon[{{0.301447, 0.394508, 0.009033},{0.302299, 0.393336, 0.009381},{
      0.301970, 0.393007, 0.009381},{0.300798, 0.393859, 0.009033}}],
    Polygon[{{0.301970, 0.393007, -0.009381},{0.300798, 0.393859, -0.009033},{
      0.300381, 0.393040, -0.009033},{0.301759, 0.392593, -0.009381}}],
    Polygon[{{0.300798, 0.393859, -0.009033},{0.299684, 0.394668, -0.008463},{
      0.299071, 0.393466, -0.008463},{0.300381, 0.393040, -0.009033}}],
    Polygon[{{0.299684, 0.394668, -0.008463},{0.298655, 0.395415, -0.007684},{
      0.297862, 0.393859, -0.007684},{0.299071, 0.393466, -0.008463}}],
    Polygon[{{0.298655, 0.395415, -0.007684},{0.297739, 0.396081, -0.006716},{
      0.296785, 0.394209, -0.006716},{0.297862, 0.393859, -0.007684}}],
    Polygon[{{0.297739, 0.396081, -0.006716},{0.296955, 0.396650, -0.005583},{
      0.295864, 0.394508, -0.005583},{0.296785, 0.394209, -0.006716}}],
    Polygon[{{0.296955, 0.396650, -0.005583},{0.296325, 0.397108, -0.004312},{
      0.295123, 0.394749, -0.004312},{0.295864, 0.394508, -0.005583}}],
    Polygon[{{0.296325, 0.397108, -0.004312},{0.295864, 0.397443, -0.002935},{
      0.294581, 0.394925, -0.002935},{0.295123, 0.394749, -0.004312}}],
    Polygon[{{0.295864, 0.397443, -0.002935},{0.295583, 0.397648, -0.001486},{
      0.294250, 0.395032, -0.001486},{0.294581, 0.394925, -0.002935}}],
    Polygon[{{0.295583, 0.397648, -0.001486},{0.295488, 0.397716, 0.000000},{
      0.294139, 0.395069, 0.000000},{0.294250, 0.395032, -0.001486}}],
    Polygon[{{0.295488, 0.397716, 0.000000},{0.295583, 0.397648, 0.001486},{
      0.294250, 0.395032, 0.001486},{0.294139, 0.395069, 0.000000}}],
    Polygon[{{0.295583, 0.397648, 0.001486},{0.295864, 0.397443, 0.002935},{
      0.294581, 0.394925, 0.002935},{0.294250, 0.395032, 0.001486}}],
    Polygon[{{0.295864, 0.397443, 0.002935},{0.296325, 0.397108, 0.004312},{
      0.295123, 0.394749, 0.004312},{0.294581, 0.394925, 0.002935}}],
    Polygon[{{0.296325, 0.397108, 0.004312},{0.296955, 0.396650, 0.005583},{
      0.295864, 0.394508, 0.005583},{0.295123, 0.394749, 0.004312}}],
    Polygon[{{0.296955, 0.396650, 0.005583},{0.297739, 0.396081, 0.006716},{
      0.296785, 0.394209, 0.006716},{0.295864, 0.394508, 0.005583}}],
    Polygon[{{0.297739, 0.396081, 0.006716},{0.298655, 0.395415, 0.007684},{
      0.297862, 0.393859, 0.007684},{0.296785, 0.394209, 0.006716}}],
    Polygon[{{0.298655, 0.395415, 0.007684},{0.299684, 0.394668, 0.008463},{
      0.299071, 0.393466, 0.008463},{0.297862, 0.393859, 0.007684}}],
    Polygon[{{0.299684, 0.394668, 0.008463},{0.300798, 0.393859, 0.009033},{
      0.300381, 0.393040, 0.009033},{0.299071, 0.393466, 0.008463}}],
    Polygon[{{0.300798, 0.393859, 0.009033},{0.301970, 0.393007, 0.009381},{
      0.301759, 0.392593, 0.009381},{0.300381, 0.393040, 0.009033}}],
    Polygon[{{0.301759, 0.392593, -0.009381},{0.300381, 0.393040, -0.009033},{
      0.300237, 0.392133, -0.009033},{0.301686, 0.392133, -0.009381}}],
    Polygon[{{0.300381, 0.393040, -0.009033},{0.299071, 0.393466, -0.008463},{
      0.298860, 0.392133, -0.008463},{0.300237, 0.392133, -0.009033}}],
    Polygon[{{0.299071, 0.393466, -0.008463},{0.297862, 0.393859, -0.007684},{
      0.297589, 0.392133, -0.007684},{0.298860, 0.392133, -0.008463}}],
    Polygon[{{0.297862, 0.393859, -0.007684},{0.296785, 0.394209, -0.006716},{
      0.296456, 0.392133, -0.006716},{0.297589, 0.392133, -0.007684}}],
    Polygon[{{0.296785, 0.394209, -0.006716},{0.295864, 0.394508, -0.005583},{
      0.295488, 0.392133, -0.005583},{0.296456, 0.392133, -0.006716}}],
    Polygon[{{0.295864, 0.394508, -0.005583},{0.295123, 0.394749, -0.004312},{
      0.294709, 0.392133, -0.004312},{0.295488, 0.392133, -0.005583}}],
    Polygon[{{0.295123, 0.394749, -0.004312},{0.294581, 0.394925, -0.002935},{
      0.294139, 0.392133, -0.002935},{0.294709, 0.392133, -0.004312}}],
    Polygon[{{0.294581, 0.394925, -0.002935},{0.294250, 0.395032, -0.001486},{
      0.293791, 0.392133, -0.001486},{0.294139, 0.392133, -0.002935}}],
    Polygon[{{0.294250, 0.395032, -0.001486},{0.294139, 0.395069, 0.000000},{
      0.293674, 0.392133, 0.000000},{0.293791, 0.392133, -0.001486}}],
    Polygon[{{0.294139, 0.395069, 0.000000},{0.294250, 0.395032, 0.001486},{
      0.293791, 0.392133, 0.001486},{0.293674, 0.392133, 0.000000}}],
    Polygon[{{0.294250, 0.395032, 0.001486},{0.294581, 0.394925, 0.002935},{
      0.294139, 0.392133, 0.002935},{0.293791, 0.392133, 0.001486}}],
    Polygon[{{0.294581, 0.394925, 0.002935},{0.295123, 0.394749, 0.004312},{
      0.294709, 0.392133, 0.004312},{0.294139, 0.392133, 0.002935}}],
    Polygon[{{0.295123, 0.394749, 0.004312},{0.295864, 0.394508, 0.005583},{
      0.295488, 0.392133, 0.005583},{0.294709, 0.392133, 0.004312}}],
    Polygon[{{0.295864, 0.394508, 0.005583},{0.296785, 0.394209, 0.006716},{
      0.296456, 0.392133, 0.006716},{0.295488, 0.392133, 0.005583}}],
    Polygon[{{0.296785, 0.394209, 0.006716},{0.297862, 0.393859, 0.007684},{
      0.297589, 0.392133, 0.007684},{0.296456, 0.392133, 0.006716}}],
    Polygon[{{0.297862, 0.393859, 0.007684},{0.299071, 0.393466, 0.008463},{
      0.298860, 0.392133, 0.008463},{0.297589, 0.392133, 0.007684}}],
    Polygon[{{0.299071, 0.393466, 0.008463},{0.300381, 0.393040, 0.009033},{
      0.300237, 0.392133, 0.009033},{0.298860, 0.392133, 0.008463}}],
    Polygon[{{0.300381, 0.393040, 0.009033},{0.301759, 0.392593, 0.009381},{
      0.301686, 0.392133, 0.009381},{0.300237, 0.392133, 0.009033}}],
    Polygon[{{0.301686, 0.392133, -0.009381},{0.300237, 0.392133, -0.009033},{
      0.300381, 0.391226, -0.009033},{0.301759, 0.391674, -0.009381}}],
    Polygon[{{0.300237, 0.392133, -0.009033},{0.298860, 0.392133, -0.008463},{
      0.299071, 0.390801, -0.008463},{0.300381, 0.391226, -0.009033}}],
    Polygon[{{0.298860, 0.392133, -0.008463},{0.297589, 0.392133, -0.007684},{
      0.297862, 0.390408, -0.007684},{0.299071, 0.390801, -0.008463}}],
    Polygon[{{0.297589, 0.392133, -0.007684},{0.296456, 0.392133, -0.006716},{
      0.296785, 0.390058, -0.006716},{0.297862, 0.390408, -0.007684}}],
    Polygon[{{0.296456, 0.392133, -0.006716},{0.295488, 0.392133, -0.005583},{
      0.295864, 0.389759, -0.005583},{0.296785, 0.390058, -0.006716}}],
    Polygon[{{0.295488, 0.392133, -0.005583},{0.294709, 0.392133, -0.004312},{
      0.295123, 0.389518, -0.004312},{0.295864, 0.389759, -0.005583}}],
    Polygon[{{0.294709, 0.392133, -0.004312},{0.294139, 0.392133, -0.002935},{
      0.294581, 0.389342, -0.002935},{0.295123, 0.389518, -0.004312}}],
    Polygon[{{0.294139, 0.392133, -0.002935},{0.293791, 0.392133, -0.001486},{
      0.294250, 0.389234, -0.001486},{0.294581, 0.389342, -0.002935}}],
    Polygon[{{0.293791, 0.392133, -0.001486},{0.293674, 0.392133, 0.000000},{
      0.294139, 0.389198, 0.000000},{0.294250, 0.389234, -0.001486}}],
    Polygon[{{0.293674, 0.392133, 0.000000},{0.293791, 0.392133, 0.001486},{
      0.294250, 0.389234, 0.001486},{0.294139, 0.389198, 0.000000}}],
    Polygon[{{0.293791, 0.392133, 0.001486},{0.294139, 0.392133, 0.002935},{
      0.294581, 0.389342, 0.002935},{0.294250, 0.389234, 0.001486}}],
    Polygon[{{0.294139, 0.392133, 0.002935},{0.294709, 0.392133, 0.004312},{
      0.295123, 0.389518, 0.004312},{0.294581, 0.389342, 0.002935}}],
    Polygon[{{0.294709, 0.392133, 0.004312},{0.295488, 0.392133, 0.005583},{
      0.295864, 0.389759, 0.005583},{0.295123, 0.389518, 0.004312}}],
    Polygon[{{0.295488, 0.392133, 0.005583},{0.296456, 0.392133, 0.006716},{
      0.296785, 0.390058, 0.006716},{0.295864, 0.389759, 0.005583}}],
    Polygon[{{0.296456, 0.392133, 0.006716},{0.297589, 0.392133, 0.007684},{
      0.297862, 0.390408, 0.007684},{0.296785, 0.390058, 0.006716}}],
    Polygon[{{0.297589, 0.392133, 0.007684},{0.298860, 0.392133, 0.008463},{
      0.299071, 0.390801, 0.008463},{0.297862, 0.390408, 0.007684}}],
    Polygon[{{0.298860, 0.392133, 0.008463},{0.300237, 0.392133, 0.009033},{
      0.300381, 0.391226, 0.009033},{0.299071, 0.390801, 0.008463}}],
    Polygon[{{0.300237, 0.392133, 0.009033},{0.301686, 0.392133, 0.009381},{
      0.301759, 0.391674, 0.009381},{0.300381, 0.391226, 0.009033}}],
    Polygon[{{0.301759, 0.391674, -0.009381},{0.300381, 0.391226, -0.009033},{
      0.300798, 0.390408, -0.009033},{0.301970, 0.391260, -0.009381}}],
    Polygon[{{0.300381, 0.391226, -0.009033},{0.299071, 0.390801, -0.008463},{
      0.299684, 0.389599, -0.008463},{0.300798, 0.390408, -0.009033}}],
    Polygon[{{0.299071, 0.390801, -0.008463},{0.297862, 0.390408, -0.007684},{
      0.298655, 0.388852, -0.007684},{0.299684, 0.389599, -0.008463}}],
    Polygon[{{0.297862, 0.390408, -0.007684},{0.296785, 0.390058, -0.006716},{
      0.297739, 0.388186, -0.006716},{0.298655, 0.388852, -0.007684}}],
    Polygon[{{0.296785, 0.390058, -0.006716},{0.295864, 0.389759, -0.005583},{
      0.296955, 0.387617, -0.005583},{0.297739, 0.388186, -0.006716}}],
    Polygon[{{0.295864, 0.389759, -0.005583},{0.295123, 0.389518, -0.004312},{
      0.296325, 0.387159, -0.004312},{0.296955, 0.387617, -0.005583}}],
    Polygon[{{0.295123, 0.389518, -0.004312},{0.294581, 0.389342, -0.002935},{
      0.295864, 0.386824, -0.002935},{0.296325, 0.387159, -0.004312}}],
    Polygon[{{0.294581, 0.389342, -0.002935},{0.294250, 0.389234, -0.001486},{
      0.295583, 0.386619, -0.001486},{0.295864, 0.386824, -0.002935}}],
    Polygon[{{0.294250, 0.389234, -0.001486},{0.294139, 0.389198, 0.000000},{
      0.295488, 0.386551, 0.000000},{0.295583, 0.386619, -0.001486}}],
    Polygon[{{0.294139, 0.389198, 0.000000},{0.294250, 0.389234, 0.001486},{
      0.295583, 0.386619, 0.001486},{0.295488, 0.386551, 0.000000}}],
    Polygon[{{0.294250, 0.389234, 0.001486},{0.294581, 0.389342, 0.002935},{
      0.295864, 0.386824, 0.002935},{0.295583, 0.386619, 0.001486}}],
    Polygon[{{0.294581, 0.389342, 0.002935},{0.295123, 0.389518, 0.004312},{
      0.296325, 0.387159, 0.004312},{0.295864, 0.386824, 0.002935}}],
    Polygon[{{0.295123, 0.389518, 0.004312},{0.295864, 0.389759, 0.005583},{
      0.296955, 0.387617, 0.005583},{0.296325, 0.387159, 0.004312}}],
    Polygon[{{0.295864, 0.389759, 0.005583},{0.296785, 0.390058, 0.006716},{
      0.297739, 0.388186, 0.006716},{0.296955, 0.387617, 0.005583}}],
    Polygon[{{0.296785, 0.390058, 0.006716},{0.297862, 0.390408, 0.007684},{
      0.298655, 0.388852, 0.007684},{0.297739, 0.388186, 0.006716}}],
    Polygon[{{0.297862, 0.390408, 0.007684},{0.299071, 0.390801, 0.008463},{
      0.299684, 0.389599, 0.008463},{0.298655, 0.388852, 0.007684}}],
    Polygon[{{0.299071, 0.390801, 0.008463},{0.300381, 0.391226, 0.009033},{
      0.300798, 0.390408, 0.009033},{0.299684, 0.389599, 0.008463}}],
    Polygon[{{0.300381, 0.391226, 0.009033},{0.301759, 0.391674, 0.009381},{
      0.301970, 0.391260, 0.009381},{0.300798, 0.390408, 0.009033}}],
    Polygon[{{0.301970, 0.391260, -0.009381},{0.300798, 0.390408, -0.009033},{
      0.301447, 0.389759, -0.009033},{0.302299, 0.390931, -0.009381}}],
    Polygon[{{0.300798, 0.390408, -0.009033},{0.299684, 0.389599, -0.008463},{
      0.300638, 0.388645, -0.008463},{0.301447, 0.389759, -0.009033}}],
    Polygon[{{0.299684, 0.389599, -0.008463},{0.298655, 0.388852, -0.007684},{
      0.299891, 0.387617, -0.007684},{0.300638, 0.388645, -0.008463}}],
    Polygon[{{0.298655, 0.388852, -0.007684},{0.297739, 0.388186, -0.006716},{
      0.299224, 0.386700, -0.006716},{0.299891, 0.387617, -0.007684}}],
    Polygon[{{0.297739, 0.388186, -0.006716},{0.296955, 0.387617, -0.005583},{
      0.298655, 0.385917, -0.005583},{0.299224, 0.386700, -0.006716}}],
    Polygon[{{0.296955, 0.387617, -0.005583},{0.296325, 0.387159, -0.004312},{
      0.298198, 0.385287, -0.004312},{0.298655, 0.385917, -0.005583}}],
    Polygon[{{0.296325, 0.387159, -0.004312},{0.295864, 0.386824, -0.002935},{
      0.297862, 0.384825, -0.002935},{0.298198, 0.385287, -0.004312}}],
    Polygon[{{0.295864, 0.386824, -0.002935},{0.295583, 0.386619, -0.001486},{
      0.297658, 0.384544, -0.001486},{0.297862, 0.384825, -0.002935}}],
    Polygon[{{0.295583, 0.386619, -0.001486},{0.295488, 0.386551, 0.000000},{
      0.297589, 0.384449, 0.000000},{0.297658, 0.384544, -0.001486}}],
    Polygon[{{0.295488, 0.386551, 0.000000},{0.295583, 0.386619, 0.001486},{
      0.297658, 0.384544, 0.001486},{0.297589, 0.384449, 0.000000}}],
    Polygon[{{0.295583, 0.386619, 0.001486},{0.295864, 0.386824, 0.002935},{
      0.297862, 0.384825, 0.002935},{0.297658, 0.384544, 0.001486}}],
    Polygon[{{0.295864, 0.386824, 0.002935},{0.296325, 0.387159, 0.004312},{
      0.298198, 0.385287, 0.004312},{0.297862, 0.384825, 0.002935}}],
    Polygon[{{0.296325, 0.387159, 0.004312},{0.296955, 0.387617, 0.005583},{
      0.298655, 0.385917, 0.005583},{0.298198, 0.385287, 0.004312}}],
    Polygon[{{0.296955, 0.387617, 0.005583},{0.297739, 0.388186, 0.006716},{
      0.299224, 0.386700, 0.006716},{0.298655, 0.385917, 0.005583}}],
    Polygon[{{0.297739, 0.388186, 0.006716},{0.298655, 0.388852, 0.007684},{
      0.299891, 0.387617, 0.007684},{0.299224, 0.386700, 0.006716}}],
    Polygon[{{0.298655, 0.388852, 0.007684},{0.299684, 0.389599, 0.008463},{
      0.300638, 0.388645, 0.008463},{0.299891, 0.387617, 0.007684}}],
    Polygon[{{0.299684, 0.389599, 0.008463},{0.300798, 0.390408, 0.009033},{
      0.301447, 0.389759, 0.009033},{0.300638, 0.388645, 0.008463}}],
    Polygon[{{0.300798, 0.390408, 0.009033},{0.301970, 0.391260, 0.009381},{
      0.302299, 0.390931, 0.009381},{0.301447, 0.389759, 0.009033}}],
    Polygon[{{0.302299, 0.390931, -0.009381},{0.301447, 0.389759, -0.009033},{
      0.302265, 0.389342, -0.009033},{0.302713, 0.390720, -0.009381}}],
    Polygon[{{0.301447, 0.389759, -0.009033},{0.300638, 0.388645, -0.008463},{
      0.301840, 0.388032, -0.008463},{0.302265, 0.389342, -0.009033}}],
    Polygon[{{0.300638, 0.388645, -0.008463},{0.299891, 0.387617, -0.007684},{
      0.301447, 0.386824, -0.007684},{0.301840, 0.388032, -0.008463}}],
    Polygon[{{0.299891, 0.387617, -0.007684},{0.299224, 0.386700, -0.006716},{
      0.301097, 0.385746, -0.006716},{0.301447, 0.386824, -0.007684}}],
    Polygon[{{0.299224, 0.386700, -0.006716},{0.298655, 0.385917, -0.005583},{
      0.300798, 0.384825, -0.005583},{0.301097, 0.385746, -0.006716}}],
    Polygon[{{0.298655, 0.385917, -0.005583},{0.298198, 0.385287, -0.004312},{
      0.300557, 0.384085, -0.004312},{0.300798, 0.384825, -0.005583}}],
    Polygon[{{0.298198, 0.385287, -0.004312},{0.297862, 0.384825, -0.002935},{
      0.300381, 0.383542, -0.002935},{0.300557, 0.384085, -0.004312}}],
    Polygon[{{0.297862, 0.384825, -0.002935},{0.297658, 0.384544, -0.001486},{
      0.300273, 0.383211, -0.001486},{0.300381, 0.383542, -0.002935}}],
    Polygon[{{0.297658, 0.384544, -0.001486},{0.297589, 0.384449, 0.000000},{
      0.300237, 0.383100, 0.000000},{0.300273, 0.383211, -0.001486}}],
    Polygon[{{0.297589, 0.384449, 0.000000},{0.297658, 0.384544, 0.001486},{
      0.300273, 0.383211, 0.001486},{0.300237, 0.383100, 0.000000}}],
    Polygon[{{0.297658, 0.384544, 0.001486},{0.297862, 0.384825, 0.002935},{
      0.300381, 0.383542, 0.002935},{0.300273, 0.383211, 0.001486}}],
    Polygon[{{0.297862, 0.384825, 0.002935},{0.298198, 0.385287, 0.004312},{
      0.300557, 0.384085, 0.004312},{0.300381, 0.383542, 0.002935}}],
    Polygon[{{0.298198, 0.385287, 0.004312},{0.298655, 0.385917, 0.005583},{
      0.300798, 0.384825, 0.005583},{0.300557, 0.384085, 0.004312}}],
    Polygon[{{0.298655, 0.385917, 0.005583},{0.299224, 0.386700, 0.006716},{
      0.301097, 0.385746, 0.006716},{0.300798, 0.384825, 0.005583}}],
    Polygon[{{0.299224, 0.386700, 0.006716},{0.299891, 0.387617, 0.007684},{
      0.301447, 0.386824, 0.007684},{0.301097, 0.385746, 0.006716}}],
    Polygon[{{0.299891, 0.387617, 0.007684},{0.300638, 0.388645, 0.008463},{
      0.301840, 0.388032, 0.008463},{0.301447, 0.386824, 0.007684}}],
    Polygon[{{0.300638, 0.388645, 0.008463},{0.301447, 0.389759, 0.009033},{
      0.302265, 0.389342, 0.009033},{0.301840, 0.388032, 0.008463}}],
    Polygon[{{0.301447, 0.389759, 0.009033},{0.302299, 0.390931, 0.009381},{
      0.302713, 0.390720, 0.009381},{0.302265, 0.389342, 0.009033}}],
    Polygon[{{0.302713, 0.390720, -0.009381},{0.302265, 0.389342, -0.009033},{
      0.303172, 0.389198, -0.009033},{0.303172, 0.390648, -0.009381}}],
    Polygon[{{0.302265, 0.389342, -0.009033},{0.301840, 0.388032, -0.008463},{
      0.303172, 0.387821, -0.008463},{0.303172, 0.389198, -0.009033}}],
    Polygon[{{0.301840, 0.388032, -0.008463},{0.301447, 0.386824, -0.007684},{
      0.303172, 0.386551, -0.007684},{0.303172, 0.387821, -0.008463}}],
    Polygon[{{0.301447, 0.386824, -0.007684},{0.301097, 0.385746, -0.006716},{
      0.303172, 0.385417, -0.006716},{0.303172, 0.386551, -0.007684}}],
    Polygon[{{0.301097, 0.385746, -0.006716},{0.300798, 0.384825, -0.005583},{
      0.303172, 0.384449, -0.005583},{0.303172, 0.385417, -0.006716}}],
    Polygon[{{0.300798, 0.384825, -0.005583},{0.300557, 0.384085, -0.004312},{
      0.303172, 0.383670, -0.004312},{0.303172, 0.384449, -0.005583}}],
    Polygon[{{0.300557, 0.384085, -0.004312},{0.300381, 0.383542, -0.002935},{
      0.303172, 0.383100, -0.002935},{0.303172, 0.383670, -0.004312}}],
    Polygon[{{0.300381, 0.383542, -0.002935},{0.300273, 0.383211, -0.001486},{
      0.303172, 0.382752, -0.001486},{0.303172, 0.383100, -0.002935}}],
    Polygon[{{0.300273, 0.383211, -0.001486},{0.300237, 0.383100, 0.000000},{
      0.303172, 0.382635, 0.000000},{0.303172, 0.382752, -0.001486}}],
    Polygon[{{0.300237, 0.383100, 0.000000},{0.300273, 0.383211, 0.001486},{
      0.303172, 0.382752, 0.001486},{0.303172, 0.382635, 0.000000}}],
    Polygon[{{0.300273, 0.383211, 0.001486},{0.300381, 0.383542, 0.002935},{
      0.303172, 0.383100, 0.002935},{0.303172, 0.382752, 0.001486}}],
    Polygon[{{0.300381, 0.383542, 0.002935},{0.300557, 0.384085, 0.004312},{
      0.303172, 0.383670, 0.004312},{0.303172, 0.383100, 0.002935}}],
    Polygon[{{0.300557, 0.384085, 0.004312},{0.300798, 0.384825, 0.005583},{
      0.303172, 0.384449, 0.005583},{0.303172, 0.383670, 0.004312}}],
    Polygon[{{0.300798, 0.384825, 0.005583},{0.301097, 0.385746, 0.006716},{
      0.303172, 0.385417, 0.006716},{0.303172, 0.384449, 0.005583}}],
    Polygon[{{0.301097, 0.385746, 0.006716},{0.301447, 0.386824, 0.007684},{
      0.303172, 0.386551, 0.007684},{0.303172, 0.385417, 0.006716}}],
    Polygon[{{0.301447, 0.386824, 0.007684},{0.301840, 0.388032, 0.008463},{
      0.303172, 0.387821, 0.008463},{0.303172, 0.386551, 0.007684}}],
    Polygon[{{0.301840, 0.388032, 0.008463},{0.302265, 0.389342, 0.009033},{
      0.303172, 0.389198, 0.009033},{0.303172, 0.387821, 0.008463}}],
    Polygon[{{0.302265, 0.389342, 0.009033},{0.302713, 0.390720, 0.009381},{
      0.303172, 0.390648, 0.009381},{0.303172, 0.389198, 0.009033}}],
    Polygon[{{0.303172, 0.390648, -0.009381},{0.303172, 0.389198, -0.009033},{
      0.304079, 0.389342, -0.009033},{0.303631, 0.390720, -0.009381}}],
    Polygon[{{0.303172, 0.389198, -0.009033},{0.303172, 0.387821, -0.008463},{
      0.304505, 0.388032, -0.008463},{0.304079, 0.389342, -0.009033}}],
    Polygon[{{0.303172, 0.387821, -0.008463},{0.303172, 0.386551, -0.007684},{
      0.304897, 0.386824, -0.007684},{0.304505, 0.388032, -0.008463}}],
    Polygon[{{0.303172, 0.386551, -0.007684},{0.303172, 0.385417, -0.006716},{
      0.305248, 0.385746, -0.006716},{0.304897, 0.386824, -0.007684}}],
    Polygon[{{0.303172, 0.385417, -0.006716},{0.303172, 0.384449, -0.005583},{
      0.305547, 0.384825, -0.005583},{0.305248, 0.385746, -0.006716}}],
    Polygon[{{0.303172, 0.384449, -0.005583},{0.303172, 0.383670, -0.004312},{
      0.305787, 0.384085, -0.004312},{0.305547, 0.384825, -0.005583}}],
    Polygon[{{0.303172, 0.383670, -0.004312},{0.303172, 0.383100, -0.002935},{
      0.305964, 0.383542, -0.002935},{0.305787, 0.384085, -0.004312}}],
    Polygon[{{0.303172, 0.383100, -0.002935},{0.303172, 0.382752, -0.001486},{
      0.306071, 0.383211, -0.001486},{0.305964, 0.383542, -0.002935}}],
    Polygon[{{0.303172, 0.382752, -0.001486},{0.303172, 0.382635, 0.000000},{
      0.306107, 0.383100, 0.000000},{0.306071, 0.383211, -0.001486}}],
    Polygon[{{0.303172, 0.382635, 0.000000},{0.303172, 0.382752, 0.001486},{
      0.306071, 0.383211, 0.001486},{0.306107, 0.383100, 0.000000}}],
    Polygon[{{0.303172, 0.382752, 0.001486},{0.303172, 0.383100, 0.002935},{
      0.305964, 0.383542, 0.002935},{0.306071, 0.383211, 0.001486}}],
    Polygon[{{0.303172, 0.383100, 0.002935},{0.303172, 0.383670, 0.004312},{
      0.305787, 0.384085, 0.004312},{0.305964, 0.383542, 0.002935}}],
    Polygon[{{0.303172, 0.383670, 0.004312},{0.303172, 0.384449, 0.005583},{
      0.305547, 0.384825, 0.005583},{0.305787, 0.384085, 0.004312}}],
    Polygon[{{0.303172, 0.384449, 0.005583},{0.303172, 0.385417, 0.006716},{
      0.305248, 0.385746, 0.006716},{0.305547, 0.384825, 0.005583}}],
    Polygon[{{0.303172, 0.385417, 0.006716},{0.303172, 0.386551, 0.007684},{
      0.304897, 0.386824, 0.007684},{0.305248, 0.385746, 0.006716}}],
    Polygon[{{0.303172, 0.386551, 0.007684},{0.303172, 0.387821, 0.008463},{
      0.304505, 0.388032, 0.008463},{0.304897, 0.386824, 0.007684}}],
    Polygon[{{0.303172, 0.387821, 0.008463},{0.303172, 0.389198, 0.009033},{
      0.304079, 0.389342, 0.009033},{0.304505, 0.388032, 0.008463}}],
    Polygon[{{0.303172, 0.389198, 0.009033},{0.303172, 0.390648, 0.009381},{
      0.303631, 0.390720, 0.009381},{0.304079, 0.389342, 0.009033}}],
    Polygon[{{0.303631, 0.390720, -0.009381},{0.304079, 0.389342, -0.009033},{
      0.304897, 0.389759, -0.009033},{0.304046, 0.390931, -0.009381}}],
    Polygon[{{0.304079, 0.389342, -0.009033},{0.304505, 0.388032, -0.008463},{
      0.305707, 0.388645, -0.008463},{0.304897, 0.389759, -0.009033}}],
    Polygon[{{0.304505, 0.388032, -0.008463},{0.304897, 0.386824, -0.007684},{
      0.306454, 0.387617, -0.007684},{0.305707, 0.388645, -0.008463}}],
    Polygon[{{0.304897, 0.386824, -0.007684},{0.305248, 0.385746, -0.006716},{
      0.307120, 0.386700, -0.006716},{0.306454, 0.387617, -0.007684}}],
    Polygon[{{0.305248, 0.385746, -0.006716},{0.305547, 0.384825, -0.005583},{
      0.307689, 0.385917, -0.005583},{0.307120, 0.386700, -0.006716}}],
    Polygon[{{0.305547, 0.384825, -0.005583},{0.305787, 0.384085, -0.004312},{
      0.308147, 0.385287, -0.004312},{0.307689, 0.385917, -0.005583}}],
    Polygon[{{0.305787, 0.384085, -0.004312},{0.305964, 0.383542, -0.002935},{
      0.308482, 0.384825, -0.002935},{0.308147, 0.385287, -0.004312}}],
    Polygon[{{0.305964, 0.383542, -0.002935},{0.306071, 0.383211, -0.001486},{
      0.308686, 0.384544, -0.001486},{0.308482, 0.384825, -0.002935}}],
    Polygon[{{0.306071, 0.383211, -0.001486},{0.306107, 0.383100, 0.000000},{
      0.308755, 0.384449, 0.000000},{0.308686, 0.384544, -0.001486}}],
    Polygon[{{0.306107, 0.383100, 0.000000},{0.306071, 0.383211, 0.001486},{
      0.308686, 0.384544, 0.001486},{0.308755, 0.384449, 0.000000}}],
    Polygon[{{0.306071, 0.383211, 0.001486},{0.305964, 0.383542, 0.002935},{
      0.308482, 0.384825, 0.002935},{0.308686, 0.384544, 0.001486}}],
    Polygon[{{0.305964, 0.383542, 0.002935},{0.305787, 0.384085, 0.004312},{
      0.308147, 0.385287, 0.004312},{0.308482, 0.384825, 0.002935}}],
    Polygon[{{0.305787, 0.384085, 0.004312},{0.305547, 0.384825, 0.005583},{
      0.307689, 0.385917, 0.005583},{0.308147, 0.385287, 0.004312}}],
    Polygon[{{0.305547, 0.384825, 0.005583},{0.305248, 0.385746, 0.006716},{
      0.307120, 0.386700, 0.006716},{0.307689, 0.385917, 0.005583}}],
    Polygon[{{0.305248, 0.385746, 0.006716},{0.304897, 0.386824, 0.007684},{
      0.306454, 0.387617, 0.007684},{0.307120, 0.386700, 0.006716}}],
    Polygon[{{0.304897, 0.386824, 0.007684},{0.304505, 0.388032, 0.008463},{
      0.305707, 0.388645, 0.008463},{0.306454, 0.387617, 0.007684}}],
    Polygon[{{0.304505, 0.388032, 0.008463},{0.304079, 0.389342, 0.009033},{
      0.304897, 0.389759, 0.009033},{0.305707, 0.388645, 0.008463}}],
    Polygon[{{0.304079, 0.389342, 0.009033},{0.303631, 0.390720, 0.009381},{
      0.304046, 0.390931, 0.009381},{0.304897, 0.389759, 0.009033}}],
    Polygon[{{0.304046, 0.390931, -0.009381},{0.304897, 0.389759, -0.009033},{
      0.305547, 0.390408, -0.009033},{0.304374, 0.391260, -0.009381}}],
    Polygon[{{0.304897, 0.389759, -0.009033},{0.305707, 0.388645, -0.008463},{
      0.306661, 0.389599, -0.008463},{0.305547, 0.390408, -0.009033}}],
    Polygon[{{0.305707, 0.388645, -0.008463},{0.306454, 0.387617, -0.007684},{
      0.307689, 0.388852, -0.007684},{0.306661, 0.389599, -0.008463}}],
    Polygon[{{0.306454, 0.387617, -0.007684},{0.307120, 0.386700, -0.006716},{
      0.308606, 0.388186, -0.006716},{0.307689, 0.388852, -0.007684}}],
    Polygon[{{0.307120, 0.386700, -0.006716},{0.307689, 0.385917, -0.005583},{
      0.309389, 0.387617, -0.005583},{0.308606, 0.388186, -0.006716}}],
    Polygon[{{0.307689, 0.385917, -0.005583},{0.308147, 0.385287, -0.004312},{
      0.310019, 0.387159, -0.004312},{0.309389, 0.387617, -0.005583}}],
    Polygon[{{0.308147, 0.385287, -0.004312},{0.308482, 0.384825, -0.002935},{
      0.310480, 0.386824, -0.002935},{0.310019, 0.387159, -0.004312}}],
    Polygon[{{0.308482, 0.384825, -0.002935},{0.308686, 0.384544, -0.001486},{
      0.310762, 0.386619, -0.001486},{0.310480, 0.386824, -0.002935}}],
    Polygon[{{0.308686, 0.384544, -0.001486},{0.308755, 0.384449, 0.000000},{
      0.310856, 0.386551, 0.000000},{0.310762, 0.386619, -0.001486}}],
    Polygon[{{0.308755, 0.384449, 0.000000},{0.308686, 0.384544, 0.001486},{
      0.310762, 0.386619, 0.001486},{0.310856, 0.386551, 0.000000}}],
    Polygon[{{0.308686, 0.384544, 0.001486},{0.308482, 0.384825, 0.002935},{
      0.310480, 0.386824, 0.002935},{0.310762, 0.386619, 0.001486}}],
    Polygon[{{0.308482, 0.384825, 0.002935},{0.308147, 0.385287, 0.004312},{
      0.310019, 0.387159, 0.004312},{0.310480, 0.386824, 0.002935}}],
    Polygon[{{0.308147, 0.385287, 0.004312},{0.307689, 0.385917, 0.005583},{
      0.309389, 0.387617, 0.005583},{0.310019, 0.387159, 0.004312}}],
    Polygon[{{0.307689, 0.385917, 0.005583},{0.307120, 0.386700, 0.006716},{
      0.308606, 0.388186, 0.006716},{0.309389, 0.387617, 0.005583}}],
    Polygon[{{0.307120, 0.386700, 0.006716},{0.306454, 0.387617, 0.007684},{
      0.307689, 0.388852, 0.007684},{0.308606, 0.388186, 0.006716}}],
    Polygon[{{0.306454, 0.387617, 0.007684},{0.305707, 0.388645, 0.008463},{
      0.306661, 0.389599, 0.008463},{0.307689, 0.388852, 0.007684}}],
    Polygon[{{0.305707, 0.388645, 0.008463},{0.304897, 0.389759, 0.009033},{
      0.305547, 0.390408, 0.009033},{0.306661, 0.389599, 0.008463}}],
    Polygon[{{0.304897, 0.389759, 0.009033},{0.304046, 0.390931, 0.009381},{
      0.304374, 0.391260, 0.009381},{0.305547, 0.390408, 0.009033}}],
    Polygon[{{0.304374, 0.391260, -0.009381},{0.305547, 0.390408, -0.009033},{
      0.305964, 0.391226, -0.009033},{0.304585, 0.391674, -0.009381}}],
    Polygon[{{0.305547, 0.390408, -0.009033},{0.306661, 0.389599, -0.008463},{
      0.307273, 0.390801, -0.008463},{0.305964, 0.391226, -0.009033}}],
    Polygon[{{0.306661, 0.389599, -0.008463},{0.307689, 0.388852, -0.007684},{
      0.308482, 0.390408, -0.007684},{0.307273, 0.390801, -0.008463}}],
    Polygon[{{0.307689, 0.388852, -0.007684},{0.308606, 0.388186, -0.006716},{
      0.309560, 0.390058, -0.006716},{0.308482, 0.390408, -0.007684}}],
    Polygon[{{0.308606, 0.388186, -0.006716},{0.309389, 0.387617, -0.005583},{
      0.310480, 0.389759, -0.005583},{0.309560, 0.390058, -0.006716}}],
    Polygon[{{0.309389, 0.387617, -0.005583},{0.310019, 0.387159, -0.004312},{
      0.311221, 0.389518, -0.004312},{0.310480, 0.389759, -0.005583}}],
    Polygon[{{0.310019, 0.387159, -0.004312},{0.310480, 0.386824, -0.002935},{
      0.311763, 0.389342, -0.002935},{0.311221, 0.389518, -0.004312}}],
    Polygon[{{0.310480, 0.386824, -0.002935},{0.310762, 0.386619, -0.001486},{
      0.312094, 0.389234, -0.001486},{0.311763, 0.389342, -0.002935}}],
    Polygon[{{0.310762, 0.386619, -0.001486},{0.310856, 0.386551, 0.000000},{
      0.312206, 0.389198, 0.000000},{0.312094, 0.389234, -0.001486}}],
    Polygon[{{0.310856, 0.386551, 0.000000},{0.310762, 0.386619, 0.001486},{
      0.312094, 0.389234, 0.001486},{0.312206, 0.389198, 0.000000}}],
    Polygon[{{0.310762, 0.386619, 0.001486},{0.310480, 0.386824, 0.002935},{
      0.311763, 0.389342, 0.002935},{0.312094, 0.389234, 0.001486}}],
    Polygon[{{0.310480, 0.386824, 0.002935},{0.310019, 0.387159, 0.004312},{
      0.311221, 0.389518, 0.004312},{0.311763, 0.389342, 0.002935}}],
    Polygon[{{0.310019, 0.387159, 0.004312},{0.309389, 0.387617, 0.005583},{
      0.310480, 0.389759, 0.005583},{0.311221, 0.389518, 0.004312}}],
    Polygon[{{0.309389, 0.387617, 0.005583},{0.308606, 0.388186, 0.006716},{
      0.309560, 0.390058, 0.006716},{0.310480, 0.389759, 0.005583}}],
    Polygon[{{0.308606, 0.388186, 0.006716},{0.307689, 0.388852, 0.007684},{
      0.308482, 0.390408, 0.007684},{0.309560, 0.390058, 0.006716}}],
    Polygon[{{0.307689, 0.388852, 0.007684},{0.306661, 0.389599, 0.008463},{
      0.307273, 0.390801, 0.008463},{0.308482, 0.390408, 0.007684}}],
    Polygon[{{0.306661, 0.389599, 0.008463},{0.305547, 0.390408, 0.009033},{
      0.305964, 0.391226, 0.009033},{0.307273, 0.390801, 0.008463}}],
    Polygon[{{0.305547, 0.390408, 0.009033},{0.304374, 0.391260, 0.009381},{
      0.304585, 0.391674, 0.009381},{0.305964, 0.391226, 0.009033}}],
    Polygon[{{0.304585, 0.391674, -0.009381},{0.305964, 0.391226, -0.009033},{
      0.306107, 0.392133, -0.009033},{0.304658, 0.392133, -0.009381}}],
    Polygon[{{0.305964, 0.391226, -0.009033},{0.307273, 0.390801, -0.008463},{
      0.307484, 0.392133, -0.008463},{0.306107, 0.392133, -0.009033}}],
    Polygon[{{0.307273, 0.390801, -0.008463},{0.308482, 0.390408, -0.007684},{
      0.308755, 0.392133, -0.007684},{0.307484, 0.392133, -0.008463}}],
    Polygon[{{0.308482, 0.390408, -0.007684},{0.309560, 0.390058, -0.006716},{
      0.309889, 0.392133, -0.006716},{0.308755, 0.392133, -0.007684}}],
    Polygon[{{0.309560, 0.390058, -0.006716},{0.310480, 0.389759, -0.005583},{
      0.310856, 0.392133, -0.005583},{0.309889, 0.392133, -0.006716}}],
    Polygon[{{0.310480, 0.389759, -0.005583},{0.311221, 0.389518, -0.004312},{
      0.311635, 0.392133, -0.004312},{0.310856, 0.392133, -0.005583}}],
    Polygon[{{0.311221, 0.389518, -0.004312},{0.311763, 0.389342, -0.002935},{
      0.312206, 0.392133, -0.002935},{0.311635, 0.392133, -0.004312}}],
    Polygon[{{0.311763, 0.389342, -0.002935},{0.312094, 0.389234, -0.001486},{
      0.312554, 0.392133, -0.001486},{0.312206, 0.392133, -0.002935}}],
    Polygon[{{0.312094, 0.389234, -0.001486},{0.312206, 0.389198, 0.000000},{
      0.312670, 0.392133, 0.000000},{0.312554, 0.392133, -0.001486}}],
    Polygon[{{0.312206, 0.389198, 0.000000},{0.312094, 0.389234, 0.001486},{
      0.312554, 0.392133, 0.001486},{0.312670, 0.392133, 0.000000}}],
    Polygon[{{0.312094, 0.389234, 0.001486},{0.311763, 0.389342, 0.002935},{
      0.312206, 0.392133, 0.002935},{0.312554, 0.392133, 0.001486}}],
    Polygon[{{0.311763, 0.389342, 0.002935},{0.311221, 0.389518, 0.004312},{
      0.311635, 0.392133, 0.004312},{0.312206, 0.392133, 0.002935}}],
    Polygon[{{0.311221, 0.389518, 0.004312},{0.310480, 0.389759, 0.005583},{
      0.310856, 0.392133, 0.005583},{0.311635, 0.392133, 0.004312}}],
    Polygon[{{0.310480, 0.389759, 0.005583},{0.309560, 0.390058, 0.006716},{
      0.309889, 0.392133, 0.006716},{0.310856, 0.392133, 0.005583}}],
    Polygon[{{0.309560, 0.390058, 0.006716},{0.308482, 0.390408, 0.007684},{
      0.308755, 0.392133, 0.007684},{0.309889, 0.392133, 0.006716}}],
    Polygon[{{0.308482, 0.390408, 0.007684},{0.307273, 0.390801, 0.008463},{
      0.307484, 0.392133, 0.008463},{0.308755, 0.392133, 0.007684}}],
    Polygon[{{0.307273, 0.390801, 0.008463},{0.305964, 0.391226, 0.009033},{
      0.306107, 0.392133, 0.009033},{0.307484, 0.392133, 0.008463}}],
    Polygon[{{0.305964, 0.391226, 0.009033},{0.304585, 0.391674, 0.009381},{
      0.304658, 0.392133, 0.009381},{0.306107, 0.392133, 0.009033}}],
    Polygon[{{0.431770, 0.388494, -0.024871},{0.435612, 0.388494, -0.023948},{
      0.435232, 0.390899, -0.023948},{0.431578, 0.389712, -0.024871}}],
    Polygon[{{0.435612, 0.388494, -0.023948},{0.439263, 0.388494, -0.022436},{
      0.438704, 0.392027, -0.022436},{0.435232, 0.390899, -0.023948}}],
    Polygon[{{0.439263, 0.388494, -0.022436},{0.442632, 0.388494, -0.020372},{
      0.441908, 0.393068, -0.020372},{0.438704, 0.392027, -0.022436}}],
    Polygon[{{0.442632, 0.388494, -0.020372},{0.445637, 0.388494, -0.017806},{
      0.444765, 0.393997, -0.017806},{0.441908, 0.393068, -0.020372}}],
    Polygon[{{0.445637, 0.388494, -0.017806},{0.448203, 0.388494, -0.014801},{
      0.447206, 0.394790, -0.014801},{0.444765, 0.393997, -0.017806}}],
    Polygon[{{0.448203, 0.388494, -0.014801},{0.450267, 0.388494, -0.011432},{
      0.449169, 0.395428, -0.011432},{0.447206, 0.394790, -0.014801}}],
    Polygon[{{0.450267, 0.388494, -0.011432},{0.451780, 0.388494, -0.007781},{
      0.450607, 0.395895, -0.007781},{0.449169, 0.395428, -0.011432}}],
    Polygon[{{0.451780, 0.388494, -0.007781},{0.452702, 0.388494, -0.003939},{
      0.451485, 0.396180, -0.003939},{0.450607, 0.395895, -0.007781}}],
    Polygon[{{0.452702, 0.388494, -0.003939},{0.453012, 0.388494, 0.000000},{
      0.451780, 0.396276, 0.000000},{0.451485, 0.396180, -0.003939}}],
    Polygon[{{0.453012, 0.388494, 0.000000},{0.452702, 0.388494, 0.003939},{
      0.451485, 0.396180, 0.003939},{0.451780, 0.396276, 0.000000}}],
    Polygon[{{0.452702, 0.388494, 0.003939},{0.451780, 0.388494, 0.007781},{
      0.450607, 0.395895, 0.007781},{0.451485, 0.396180, 0.003939}}],
    Polygon[{{0.451780, 0.388494, 0.007781},{0.450267, 0.388494, 0.011432},{
      0.449169, 0.395428, 0.011432},{0.450607, 0.395895, 0.007781}}],
    Polygon[{{0.450267, 0.388494, 0.011432},{0.448203, 0.388494, 0.014801},{
      0.447206, 0.394790, 0.014801},{0.449169, 0.395428, 0.011432}}],
    Polygon[{{0.448203, 0.388494, 0.014801},{0.445637, 0.388494, 0.017806},{
      0.444765, 0.393997, 0.017806},{0.447206, 0.394790, 0.014801}}],
    Polygon[{{0.445637, 0.388494, 0.017806},{0.442632, 0.388494, 0.020372},{
      0.441908, 0.393068, 0.020372},{0.444765, 0.393997, 0.017806}}],
    Polygon[{{0.442632, 0.388494, 0.020372},{0.439263, 0.388494, 0.022436},{
      0.438704, 0.392027, 0.022436},{0.441908, 0.393068, 0.020372}}],
    Polygon[{{0.439263, 0.388494, 0.022436},{0.435612, 0.388494, 0.023948},{
      0.435232, 0.390899, 0.023948},{0.438704, 0.392027, 0.022436}}],
    Polygon[{{0.435612, 0.388494, 0.023948},{0.431770, 0.388494, 0.024871},{
      0.431578, 0.389712, 0.024871},{0.435232, 0.390899, 0.023948}}],
    Polygon[{{0.431578, 0.389712, -0.024871},{0.435232, 0.390899, -0.023948},{
      0.434126, 0.393068, -0.023948},{0.431018, 0.390810, -0.024871}}],
    Polygon[{{0.435232, 0.390899, -0.023948},{0.438704, 0.392027, -0.022436},{
      0.437080, 0.395214, -0.022436},{0.434126, 0.393068, -0.023948}}],
    Polygon[{{0.438704, 0.392027, -0.022436},{0.441908, 0.393068, -0.020372},{
      0.439805, 0.397194, -0.020372},{0.437080, 0.395214, -0.022436}}],
    Polygon[{{0.441908, 0.393068, -0.020372},{0.444765, 0.393997, -0.017806},{
      0.442236, 0.398960, -0.017806},{0.439805, 0.397194, -0.020372}}],
    Polygon[{{0.444765, 0.393997, -0.017806},{0.447206, 0.394790, -0.014801},{
      0.444312, 0.400469, -0.014801},{0.442236, 0.398960, -0.017806}}],
    Polygon[{{0.447206, 0.394790, -0.014801},{0.449169, 0.395428, -0.011432},{
      0.445983, 0.401682, -0.011432},{0.444312, 0.400469, -0.014801}}],
    Polygon[{{0.449169, 0.395428, -0.011432},{0.450607, 0.395895, -0.007781},{
      0.447206, 0.402571, -0.007781},{0.445983, 0.401682, -0.011432}}],
    Polygon[{{0.450607, 0.395895, -0.007781},{0.451485, 0.396180, -0.003939},{
      0.447952, 0.403113, -0.003939},{0.447206, 0.402571, -0.007781}}],
    Polygon[{{0.451485, 0.396180, -0.003939},{0.451780, 0.396276, 0.000000},{
      0.448203, 0.403295, 0.000000},{0.447952, 0.403113, -0.003939}}],
    Polygon[{{0.451780, 0.396276, 0.000000},{0.451485, 0.396180, 0.003939},{
      0.447952, 0.403113, 0.003939},{0.448203, 0.403295, 0.000000}}],
    Polygon[{{0.451485, 0.396180, 0.003939},{0.450607, 0.395895, 0.007781},{
      0.447206, 0.402571, 0.007781},{0.447952, 0.403113, 0.003939}}],
    Polygon[{{0.450607, 0.395895, 0.007781},{0.449169, 0.395428, 0.011432},{
      0.445983, 0.401682, 0.011432},{0.447206, 0.402571, 0.007781}}],
    Polygon[{{0.449169, 0.395428, 0.011432},{0.447206, 0.394790, 0.014801},{
      0.444312, 0.400469, 0.014801},{0.445983, 0.401682, 0.011432}}],
    Polygon[{{0.447206, 0.394790, 0.014801},{0.444765, 0.393997, 0.017806},{
      0.442236, 0.398960, 0.017806},{0.444312, 0.400469, 0.014801}}],
    Polygon[{{0.444765, 0.393997, 0.017806},{0.441908, 0.393068, 0.020372},{
      0.439805, 0.397194, 0.020372},{0.442236, 0.398960, 0.017806}}],
    Polygon[{{0.441908, 0.393068, 0.020372},{0.438704, 0.392027, 0.022436},{
      0.437080, 0.395214, 0.022436},{0.439805, 0.397194, 0.020372}}],
    Polygon[{{0.438704, 0.392027, 0.022436},{0.435232, 0.390899, 0.023948},{
      0.434126, 0.393068, 0.023948},{0.437080, 0.395214, 0.022436}}],
    Polygon[{{0.435232, 0.390899, 0.023948},{0.431578, 0.389712, 0.024871},{
      0.431018, 0.390810, 0.024871},{0.434126, 0.393068, 0.023948}}],
    Polygon[{{0.431018, 0.390810, -0.024871},{0.434126, 0.393068, -0.023948},{
      0.432405, 0.394790, -0.023948},{0.430147, 0.391681, -0.024871}}],
    Polygon[{{0.434126, 0.393068, -0.023948},{0.437080, 0.395214, -0.022436},{
      0.434551, 0.397743, -0.022436},{0.432405, 0.394790, -0.023948}}],
    Polygon[{{0.437080, 0.395214, -0.022436},{0.439805, 0.397194, -0.020372},{
      0.436531, 0.400469, -0.020372},{0.434551, 0.397743, -0.022436}}],
    Polygon[{{0.439805, 0.397194, -0.020372},{0.442236, 0.398960, -0.017806},{
      0.438297, 0.402899, -0.017806},{0.436531, 0.400469, -0.020372}}],
    Polygon[{{0.442236, 0.398960, -0.017806},{0.444312, 0.400469, -0.014801},{
      0.439805, 0.404975, -0.014801},{0.438297, 0.402899, -0.017806}}],
    Polygon[{{0.444312, 0.400469, -0.014801},{0.445983, 0.401682, -0.011432},{
      0.441019, 0.406646, -0.011432},{0.439805, 0.404975, -0.014801}}],
    Polygon[{{0.445983, 0.401682, -0.011432},{0.447206, 0.402571, -0.007781},{
      0.441908, 0.407869, -0.007781},{0.441019, 0.406646, -0.011432}}],
    Polygon[{{0.447206, 0.402571, -0.007781},{0.447952, 0.403113, -0.003939},{
      0.442450, 0.408615, -0.003939},{0.441908, 0.407869, -0.007781}}],
    Polygon[{{0.447952, 0.403113, -0.003939},{0.448203, 0.403295, 0.000000},{
      0.442632, 0.408866, 0.000000},{0.442450, 0.408615, -0.003939}}],
    Polygon[{{0.448203, 0.403295, 0.000000},{0.447952, 0.403113, 0.003939},{
      0.442450, 0.408615, 0.003939},{0.442632, 0.408866, 0.000000}}],
    Polygon[{{0.447952, 0.403113, 0.003939},{0.447206, 0.402571, 0.007781},{
      0.441908, 0.407869, 0.007781},{0.442450, 0.408615, 0.003939}}],
    Polygon[{{0.447206, 0.402571, 0.007781},{0.445983, 0.401682, 0.011432},{
      0.441019, 0.406646, 0.011432},{0.441908, 0.407869, 0.007781}}],
    Polygon[{{0.445983, 0.401682, 0.011432},{0.444312, 0.400469, 0.014801},{
      0.439805, 0.404975, 0.014801},{0.441019, 0.406646, 0.011432}}],
    Polygon[{{0.444312, 0.400469, 0.014801},{0.442236, 0.398960, 0.017806},{
      0.438297, 0.402899, 0.017806},{0.439805, 0.404975, 0.014801}}],
    Polygon[{{0.442236, 0.398960, 0.017806},{0.439805, 0.397194, 0.020372},{
      0.436531, 0.400469, 0.020372},{0.438297, 0.402899, 0.017806}}],
    Polygon[{{0.439805, 0.397194, 0.020372},{0.437080, 0.395214, 0.022436},{
      0.434551, 0.397743, 0.022436},{0.436531, 0.400469, 0.020372}}],
    Polygon[{{0.437080, 0.395214, 0.022436},{0.434126, 0.393068, 0.023948},{
      0.432405, 0.394790, 0.023948},{0.434551, 0.397743, 0.022436}}],
    Polygon[{{0.434126, 0.393068, 0.023948},{0.431018, 0.390810, 0.024871},{
      0.430147, 0.391681, 0.024871},{0.432405, 0.394790, 0.023948}}],
    Polygon[{{0.430147, 0.391681, -0.024871},{0.432405, 0.394790, -0.023948},{
      0.430236, 0.395895, -0.023948},{0.429048, 0.392241, -0.024871}}],
    Polygon[{{0.432405, 0.394790, -0.023948},{0.434551, 0.397743, -0.022436},{
      0.431364, 0.399367, -0.022436},{0.430236, 0.395895, -0.023948}}],
    Polygon[{{0.434551, 0.397743, -0.022436},{0.436531, 0.400469, -0.020372},{
      0.432405, 0.402571, -0.020372},{0.431364, 0.399367, -0.022436}}],
    Polygon[{{0.436531, 0.400469, -0.020372},{0.438297, 0.402899, -0.017806},{
      0.433333, 0.405428, -0.017806},{0.432405, 0.402571, -0.020372}}],
    Polygon[{{0.438297, 0.402899, -0.017806},{0.439805, 0.404975, -0.014801},{
      0.434126, 0.407869, -0.014801},{0.433333, 0.405428, -0.017806}}],
    Polygon[{{0.439805, 0.404975, -0.014801},{0.441019, 0.406646, -0.011432},{
      0.434764, 0.409832, -0.011432},{0.434126, 0.407869, -0.014801}}],
    Polygon[{{0.441019, 0.406646, -0.011432},{0.441908, 0.407869, -0.007781},{
      0.435232, 0.411271, -0.007781},{0.434764, 0.409832, -0.011432}}],
    Polygon[{{0.441908, 0.407869, -0.007781},{0.442450, 0.408615, -0.003939},{
      0.435517, 0.412148, -0.003939},{0.435232, 0.411271, -0.007781}}],
    Polygon[{{0.442450, 0.408615, -0.003939},{0.442632, 0.408866, 0.000000},{
      0.435612, 0.412443, 0.000000},{0.435517, 0.412148, -0.003939}}],
    Polygon[{{0.442632, 0.408866, 0.000000},{0.442450, 0.408615, 0.003939},{
      0.435517, 0.412148, 0.003939},{0.435612, 0.412443, 0.000000}}],
    Polygon[{{0.442450, 0.408615, 0.003939},{0.441908, 0.407869, 0.007781},{
      0.435232, 0.411271, 0.007781},{0.435517, 0.412148, 0.003939}}],
    Polygon[{{0.441908, 0.407869, 0.007781},{0.441019, 0.406646, 0.011432},{
      0.434764, 0.409832, 0.011432},{0.435232, 0.411271, 0.007781}}],
    Polygon[{{0.441019, 0.406646, 0.011432},{0.439805, 0.404975, 0.014801},{
      0.434126, 0.407869, 0.014801},{0.434764, 0.409832, 0.011432}}],
    Polygon[{{0.439805, 0.404975, 0.014801},{0.438297, 0.402899, 0.017806},{
      0.433333, 0.405428, 0.017806},{0.434126, 0.407869, 0.014801}}],
    Polygon[{{0.438297, 0.402899, 0.017806},{0.436531, 0.400469, 0.020372},{
      0.432405, 0.402571, 0.020372},{0.433333, 0.405428, 0.017806}}],
    Polygon[{{0.436531, 0.400469, 0.020372},{0.434551, 0.397743, 0.022436},{
      0.431364, 0.399367, 0.022436},{0.432405, 0.402571, 0.020372}}],
    Polygon[{{0.434551, 0.397743, 0.022436},{0.432405, 0.394790, 0.023948},{
      0.430236, 0.395895, 0.023948},{0.431364, 0.399367, 0.022436}}],
    Polygon[{{0.432405, 0.394790, 0.023948},{0.430147, 0.391681, 0.024871},{
      0.429048, 0.392241, 0.024871},{0.430236, 0.395895, 0.023948}}],
    Polygon[{{0.429048, 0.392241, -0.024871},{0.430236, 0.395895, -0.023948},{
      0.427831, 0.396276, -0.023948},{0.427831, 0.392433, -0.024871}}],
    Polygon[{{0.430236, 0.395895, -0.023948},{0.431364, 0.399367, -0.022436},{
      0.427831, 0.399926, -0.022436},{0.427831, 0.396276, -0.023948}}],
    Polygon[{{0.431364, 0.399367, -0.022436},{0.432405, 0.402571, -0.020372},{
      0.427831, 0.403295, -0.020372},{0.427831, 0.399926, -0.022436}}],
    Polygon[{{0.432405, 0.402571, -0.020372},{0.433333, 0.405428, -0.017806},{
      0.427831, 0.406300, -0.017806},{0.427831, 0.403295, -0.020372}}],
    Polygon[{{0.433333, 0.405428, -0.017806},{0.434126, 0.407869, -0.014801},{
      0.427831, 0.408866, -0.014801},{0.427831, 0.406300, -0.017806}}],
    Polygon[{{0.434126, 0.407869, -0.014801},{0.434764, 0.409832, -0.011432},{
      0.427831, 0.410931, -0.011432},{0.427831, 0.408866, -0.014801}}],
    Polygon[{{0.434764, 0.409832, -0.011432},{0.435232, 0.411271, -0.007781},{
      0.427831, 0.412443, -0.007781},{0.427831, 0.410931, -0.011432}}],
    Polygon[{{0.435232, 0.411271, -0.007781},{0.435517, 0.412148, -0.003939},{
      0.427831, 0.413365, -0.003939},{0.427831, 0.412443, -0.007781}}],
    Polygon[{{0.435517, 0.412148, -0.003939},{0.435612, 0.412443, 0.000000},{
      0.427831, 0.413675, 0.000000},{0.427831, 0.413365, -0.003939}}],
    Polygon[{{0.435612, 0.412443, 0.000000},{0.435517, 0.412148, 0.003939},{
      0.427831, 0.413365, 0.003939},{0.427831, 0.413675, 0.000000}}],
    Polygon[{{0.435517, 0.412148, 0.003939},{0.435232, 0.411271, 0.007781},{
      0.427831, 0.412443, 0.007781},{0.427831, 0.413365, 0.003939}}],
    Polygon[{{0.435232, 0.411271, 0.007781},{0.434764, 0.409832, 0.011432},{
      0.427831, 0.410931, 0.011432},{0.427831, 0.412443, 0.007781}}],
    Polygon[{{0.434764, 0.409832, 0.011432},{0.434126, 0.407869, 0.014801},{
      0.427831, 0.408866, 0.014801},{0.427831, 0.410931, 0.011432}}],
    Polygon[{{0.434126, 0.407869, 0.014801},{0.433333, 0.405428, 0.017806},{
      0.427831, 0.406300, 0.017806},{0.427831, 0.408866, 0.014801}}],
    Polygon[{{0.433333, 0.405428, 0.017806},{0.432405, 0.402571, 0.020372},{
      0.427831, 0.403295, 0.020372},{0.427831, 0.406300, 0.017806}}],
    Polygon[{{0.432405, 0.402571, 0.020372},{0.431364, 0.399367, 0.022436},{
      0.427831, 0.399926, 0.022436},{0.427831, 0.403295, 0.020372}}],
    Polygon[{{0.431364, 0.399367, 0.022436},{0.430236, 0.395895, 0.023948},{
      0.427831, 0.396276, 0.023948},{0.427831, 0.399926, 0.022436}}],
    Polygon[{{0.430236, 0.395895, 0.023948},{0.429048, 0.392241, 0.024871},{
      0.427831, 0.392433, 0.024871},{0.427831, 0.396276, 0.023948}}],
    Polygon[{{0.427831, 0.392433, -0.024871},{0.427831, 0.396276, -0.023948},{
      0.425427, 0.395895, -0.023948},{0.426614, 0.392241, -0.024871}}],
    Polygon[{{0.427831, 0.396276, -0.023948},{0.427831, 0.399926, -0.022436},{
      0.424299, 0.399367, -0.022436},{0.425427, 0.395895, -0.023948}}],
    Polygon[{{0.427831, 0.399926, -0.022436},{0.427831, 0.403295, -0.020372},{
      0.423257, 0.402571, -0.020372},{0.424299, 0.399367, -0.022436}}],
    Polygon[{{0.427831, 0.403295, -0.020372},{0.427831, 0.406300, -0.017806},{
      0.422329, 0.405428, -0.017806},{0.423257, 0.402571, -0.020372}}],
    Polygon[{{0.427831, 0.406300, -0.017806},{0.427831, 0.408866, -0.014801},{
      0.421536, 0.407869, -0.014801},{0.422329, 0.405428, -0.017806}}],
    Polygon[{{0.427831, 0.408866, -0.014801},{0.427831, 0.410931, -0.011432},{
      0.420898, 0.409832, -0.011432},{0.421536, 0.407869, -0.014801}}],
    Polygon[{{0.427831, 0.410931, -0.011432},{0.427831, 0.412443, -0.007781},{
      0.420431, 0.411271, -0.007781},{0.420898, 0.409832, -0.011432}}],
    Polygon[{{0.427831, 0.412443, -0.007781},{0.427831, 0.413365, -0.003939},{
      0.420146, 0.412148, -0.003939},{0.420431, 0.411271, -0.007781}}],
    Polygon[{{0.427831, 0.413365, -0.003939},{0.427831, 0.413675, 0.000000},{
      0.420050, 0.412443, 0.000000},{0.420146, 0.412148, -0.003939}}],
    Polygon[{{0.427831, 0.413675, 0.000000},{0.427831, 0.413365, 0.003939},{
      0.420146, 0.412148, 0.003939},{0.420050, 0.412443, 0.000000}}],
    Polygon[{{0.427831, 0.413365, 0.003939},{0.427831, 0.412443, 0.007781},{
      0.420431, 0.411271, 0.007781},{0.420146, 0.412148, 0.003939}}],
    Polygon[{{0.427831, 0.412443, 0.007781},{0.427831, 0.410931, 0.011432},{
      0.420898, 0.409832, 0.011432},{0.420431, 0.411271, 0.007781}}],
    Polygon[{{0.427831, 0.410931, 0.011432},{0.427831, 0.408866, 0.014801},{
      0.421536, 0.407869, 0.014801},{0.420898, 0.409832, 0.011432}}],
    Polygon[{{0.427831, 0.408866, 0.014801},{0.427831, 0.406300, 0.017806},{
      0.422329, 0.405428, 0.017806},{0.421536, 0.407869, 0.014801}}],
    Polygon[{{0.427831, 0.406300, 0.017806},{0.427831, 0.403295, 0.020372},{
      0.423257, 0.402571, 0.020372},{0.422329, 0.405428, 0.017806}}],
    Polygon[{{0.427831, 0.403295, 0.020372},{0.427831, 0.399926, 0.022436},{
      0.424299, 0.399367, 0.022436},{0.423257, 0.402571, 0.020372}}],
    Polygon[{{0.427831, 0.399926, 0.022436},{0.427831, 0.396276, 0.023948},{
      0.425427, 0.395895, 0.023948},{0.424299, 0.399367, 0.022436}}],
    Polygon[{{0.427831, 0.396276, 0.023948},{0.427831, 0.392433, 0.024871},{
      0.426614, 0.392241, 0.024871},{0.425427, 0.395895, 0.023948}}],
    Polygon[{{0.426614, 0.392241, -0.024871},{0.425427, 0.395895, -0.023948},{
      0.423257, 0.394790, -0.023948},{0.425516, 0.391681, -0.024871}}],
    Polygon[{{0.425427, 0.395895, -0.023948},{0.424299, 0.399367, -0.022436},{
      0.421112, 0.397743, -0.022436},{0.423257, 0.394790, -0.023948}}],
    Polygon[{{0.424299, 0.399367, -0.022436},{0.423257, 0.402571, -0.020372},{
      0.419131, 0.400469, -0.020372},{0.421112, 0.397743, -0.022436}}],
    Polygon[{{0.423257, 0.402571, -0.020372},{0.422329, 0.405428, -0.017806},{
      0.417365, 0.402899, -0.017806},{0.419131, 0.400469, -0.020372}}],
    Polygon[{{0.422329, 0.405428, -0.017806},{0.421536, 0.407869, -0.014801},{
      0.415857, 0.404975, -0.014801},{0.417365, 0.402899, -0.017806}}],
    Polygon[{{0.421536, 0.407869, -0.014801},{0.420898, 0.409832, -0.011432},{
      0.414644, 0.406646, -0.011432},{0.415857, 0.404975, -0.014801}}],
    Polygon[{{0.420898, 0.409832, -0.011432},{0.420431, 0.411271, -0.007781},{
      0.413755, 0.407869, -0.007781},{0.414644, 0.406646, -0.011432}}],
    Polygon[{{0.420431, 0.411271, -0.007781},{0.420146, 0.412148, -0.003939},{
      0.413213, 0.408615, -0.003939},{0.413755, 0.407869, -0.007781}}],
    Polygon[{{0.420146, 0.412148, -0.003939},{0.420050, 0.412443, 0.000000},{
      0.413030, 0.408866, 0.000000},{0.413213, 0.408615, -0.003939}}],
    Polygon[{{0.420050, 0.412443, 0.000000},{0.420146, 0.412148, 0.003939},{
      0.413213, 0.408615, 0.003939},{0.413030, 0.408866, 0.000000}}],
    Polygon[{{0.420146, 0.412148, 0.003939},{0.420431, 0.411271, 0.007781},{
      0.413755, 0.407869, 0.007781},{0.413213, 0.408615, 0.003939}}],
    Polygon[{{0.420431, 0.411271, 0.007781},{0.420898, 0.409832, 0.011432},{
      0.414644, 0.406646, 0.011432},{0.413755, 0.407869, 0.007781}}],
    Polygon[{{0.420898, 0.409832, 0.011432},{0.421536, 0.407869, 0.014801},{
      0.415857, 0.404975, 0.014801},{0.414644, 0.406646, 0.011432}}],
    Polygon[{{0.421536, 0.407869, 0.014801},{0.422329, 0.405428, 0.017806},{
      0.417365, 0.402899, 0.017806},{0.415857, 0.404975, 0.014801}}],
    Polygon[{{0.422329, 0.405428, 0.017806},{0.423257, 0.402571, 0.020372},{
      0.419131, 0.400469, 0.020372},{0.417365, 0.402899, 0.017806}}],
    Polygon[{{0.423257, 0.402571, 0.020372},{0.424299, 0.399367, 0.022436},{
      0.421112, 0.397743, 0.022436},{0.419131, 0.400469, 0.020372}}],
    Polygon[{{0.424299, 0.399367, 0.022436},{0.425427, 0.395895, 0.023948},{
      0.423257, 0.394790, 0.023948},{0.421112, 0.397743, 0.022436}}],
    Polygon[{{0.425427, 0.395895, 0.023948},{0.426614, 0.392241, 0.024871},{
      0.425516, 0.391681, 0.024871},{0.423257, 0.394790, 0.023948}}],
    Polygon[{{0.425516, 0.391681, -0.024871},{0.423257, 0.394790, -0.023948},{
      0.421536, 0.393068, -0.023948},{0.424644, 0.390810, -0.024871}}],
    Polygon[{{0.423257, 0.394790, -0.023948},{0.421112, 0.397743, -0.022436},{
      0.418583, 0.395214, -0.022436},{0.421536, 0.393068, -0.023948}}],
    Polygon[{{0.421112, 0.397743, -0.022436},{0.419131, 0.400469, -0.020372},{
      0.415857, 0.397194, -0.020372},{0.418583, 0.395214, -0.022436}}],
    Polygon[{{0.419131, 0.400469, -0.020372},{0.417365, 0.402899, -0.017806},{
      0.413426, 0.398960, -0.017806},{0.415857, 0.397194, -0.020372}}],
    Polygon[{{0.417365, 0.402899, -0.017806},{0.415857, 0.404975, -0.014801},{
      0.411350, 0.400469, -0.014801},{0.413426, 0.398960, -0.017806}}],
    Polygon[{{0.415857, 0.404975, -0.014801},{0.414644, 0.406646, -0.011432},{
      0.409680, 0.401682, -0.011432},{0.411350, 0.400469, -0.014801}}],
    Polygon[{{0.414644, 0.406646, -0.011432},{0.413755, 0.407869, -0.007781},{
      0.408457, 0.402571, -0.007781},{0.409680, 0.401682, -0.011432}}],
    Polygon[{{0.413755, 0.407869, -0.007781},{0.413213, 0.408615, -0.003939},{
      0.407710, 0.403113, -0.003939},{0.408457, 0.402571, -0.007781}}],
    Polygon[{{0.413213, 0.408615, -0.003939},{0.413030, 0.408866, 0.000000},{
      0.407460, 0.403295, 0.000000},{0.407710, 0.403113, -0.003939}}],
    Polygon[{{0.413030, 0.408866, 0.000000},{0.413213, 0.408615, 0.003939},{
      0.407710, 0.403113, 0.003939},{0.407460, 0.403295, 0.000000}}],
    Polygon[{{0.413213, 0.408615, 0.003939},{0.413755, 0.407869, 0.007781},{
      0.408457, 0.402571, 0.007781},{0.407710, 0.403113, 0.003939}}],
    Polygon[{{0.413755, 0.407869, 0.007781},{0.414644, 0.406646, 0.011432},{
      0.409680, 0.401682, 0.011432},{0.408457, 0.402571, 0.007781}}],
    Polygon[{{0.414644, 0.406646, 0.011432},{0.415857, 0.404975, 0.014801},{
      0.411350, 0.400469, 0.014801},{0.409680, 0.401682, 0.011432}}],
    Polygon[{{0.415857, 0.404975, 0.014801},{0.417365, 0.402899, 0.017806},{
      0.413426, 0.398960, 0.017806},{0.411350, 0.400469, 0.014801}}],
    Polygon[{{0.417365, 0.402899, 0.017806},{0.419131, 0.400469, 0.020372},{
      0.415857, 0.397194, 0.020372},{0.413426, 0.398960, 0.017806}}],
    Polygon[{{0.419131, 0.400469, 0.020372},{0.421112, 0.397743, 0.022436},{
      0.418583, 0.395214, 0.022436},{0.415857, 0.397194, 0.020372}}],
    Polygon[{{0.421112, 0.397743, 0.022436},{0.423257, 0.394790, 0.023948},{
      0.421536, 0.393068, 0.023948},{0.418583, 0.395214, 0.022436}}],
    Polygon[{{0.423257, 0.394790, 0.023948},{0.425516, 0.391681, 0.024871},{
      0.424644, 0.390810, 0.024871},{0.421536, 0.393068, 0.023948}}],
    Polygon[{{0.424644, 0.390810, -0.024871},{0.421536, 0.393068, -0.023948},{
      0.420431, 0.390899, -0.023948},{0.424085, 0.389712, -0.024871}}],
    Polygon[{{0.421536, 0.393068, -0.023948},{0.418583, 0.395214, -0.022436},{
      0.416959, 0.392027, -0.022436},{0.420431, 0.390899, -0.023948}}],
    Polygon[{{0.418583, 0.395214, -0.022436},{0.415857, 0.397194, -0.020372},{
      0.413755, 0.393068, -0.020372},{0.416959, 0.392027, -0.022436}}],
    Polygon[{{0.415857, 0.397194, -0.020372},{0.413426, 0.398960, -0.017806},{
      0.410897, 0.393997, -0.017806},{0.413755, 0.393068, -0.020372}}],
    Polygon[{{0.413426, 0.398960, -0.017806},{0.411350, 0.400469, -0.014801},{
      0.408457, 0.394790, -0.014801},{0.410897, 0.393997, -0.017806}}],
    Polygon[{{0.411350, 0.400469, -0.014801},{0.409680, 0.401682, -0.011432},{
      0.406493, 0.395428, -0.011432},{0.408457, 0.394790, -0.014801}}],
    Polygon[{{0.409680, 0.401682, -0.011432},{0.408457, 0.402571, -0.007781},{
      0.405055, 0.395895, -0.007781},{0.406493, 0.395428, -0.011432}}],
    Polygon[{{0.408457, 0.402571, -0.007781},{0.407710, 0.403113, -0.003939},{
      0.404178, 0.396180, -0.003939},{0.405055, 0.395895, -0.007781}}],
    Polygon[{{0.407710, 0.403113, -0.003939},{0.407460, 0.403295, 0.000000},{
      0.403883, 0.396276, 0.000000},{0.404178, 0.396180, -0.003939}}],
    Polygon[{{0.407460, 0.403295, 0.000000},{0.407710, 0.403113, 0.003939},{
      0.404178, 0.396180, 0.003939},{0.403883, 0.396276, 0.000000}}],
    Polygon[{{0.407710, 0.403113, 0.003939},{0.408457, 0.402571, 0.007781},{
      0.405055, 0.395895, 0.007781},{0.404178, 0.396180, 0.003939}}],
    Polygon[{{0.408457, 0.402571, 0.007781},{0.409680, 0.401682, 0.011432},{
      0.406493, 0.395428, 0.011432},{0.405055, 0.395895, 0.007781}}],
    Polygon[{{0.409680, 0.401682, 0.011432},{0.411350, 0.400469, 0.014801},{
      0.408457, 0.394790, 0.014801},{0.406493, 0.395428, 0.011432}}],
    Polygon[{{0.411350, 0.400469, 0.014801},{0.413426, 0.398960, 0.017806},{
      0.410897, 0.393997, 0.017806},{0.408457, 0.394790, 0.014801}}],
    Polygon[{{0.413426, 0.398960, 0.017806},{0.415857, 0.397194, 0.020372},{
      0.413755, 0.393068, 0.020372},{0.410897, 0.393997, 0.017806}}],
    Polygon[{{0.415857, 0.397194, 0.020372},{0.418583, 0.395214, 0.022436},{
      0.416959, 0.392027, 0.022436},{0.413755, 0.393068, 0.020372}}],
    Polygon[{{0.418583, 0.395214, 0.022436},{0.421536, 0.393068, 0.023948},{
      0.420431, 0.390899, 0.023948},{0.416959, 0.392027, 0.022436}}],
    Polygon[{{0.421536, 0.393068, 0.023948},{0.424644, 0.390810, 0.024871},{
      0.424085, 0.389712, 0.024871},{0.420431, 0.390899, 0.023948}}],
    Polygon[{{0.424085, 0.389712, -0.024871},{0.420431, 0.390899, -0.023948},{
      0.420050, 0.388494, -0.023948},{0.423892, 0.388494, -0.024871}}],
    Polygon[{{0.420431, 0.390899, -0.023948},{0.416959, 0.392027, -0.022436},{
      0.416399, 0.388494, -0.022436},{0.420050, 0.388494, -0.023948}}],
    Polygon[{{0.416959, 0.392027, -0.022436},{0.413755, 0.393068, -0.020372},{
      0.413030, 0.388494, -0.020372},{0.416399, 0.388494, -0.022436}}],
    Polygon[{{0.413755, 0.393068, -0.020372},{0.410897, 0.393997, -0.017806},{
      0.410026, 0.388494, -0.017806},{0.413030, 0.388494, -0.020372}}],
    Polygon[{{0.410897, 0.393997, -0.017806},{0.408457, 0.394790, -0.014801},{
      0.407460, 0.388494, -0.014801},{0.410026, 0.388494, -0.017806}}],
    Polygon[{{0.408457, 0.394790, -0.014801},{0.406493, 0.395428, -0.011432},{
      0.405395, 0.388494, -0.011432},{0.407460, 0.388494, -0.014801}}],
    Polygon[{{0.406493, 0.395428, -0.011432},{0.405055, 0.395895, -0.007781},{
      0.403883, 0.388494, -0.007781},{0.405395, 0.388494, -0.011432}}],
    Polygon[{{0.405055, 0.395895, -0.007781},{0.404178, 0.396180, -0.003939},{
      0.402960, 0.388494, -0.003939},{0.403883, 0.388494, -0.007781}}],
    Polygon[{{0.404178, 0.396180, -0.003939},{0.403883, 0.396276, 0.000000},{
      0.402650, 0.388494, 0.000000},{0.402960, 0.388494, -0.003939}}],
    Polygon[{{0.403883, 0.396276, 0.000000},{0.404178, 0.396180, 0.003939},{
      0.402960, 0.388494, 0.003939},{0.402650, 0.388494, 0.000000}}],
    Polygon[{{0.404178, 0.396180, 0.003939},{0.405055, 0.395895, 0.007781},{
      0.403883, 0.388494, 0.007781},{0.402960, 0.388494, 0.003939}}],
    Polygon[{{0.405055, 0.395895, 0.007781},{0.406493, 0.395428, 0.011432},{
      0.405395, 0.388494, 0.011432},{0.403883, 0.388494, 0.007781}}],
    Polygon[{{0.406493, 0.395428, 0.011432},{0.408457, 0.394790, 0.014801},{
      0.407460, 0.388494, 0.014801},{0.405395, 0.388494, 0.011432}}],
    Polygon[{{0.408457, 0.394790, 0.014801},{0.410897, 0.393997, 0.017806},{
      0.410026, 0.388494, 0.017806},{0.407460, 0.388494, 0.014801}}],
    Polygon[{{0.410897, 0.393997, 0.017806},{0.413755, 0.393068, 0.020372},{
      0.413030, 0.388494, 0.020372},{0.410026, 0.388494, 0.017806}}],
    Polygon[{{0.413755, 0.393068, 0.020372},{0.416959, 0.392027, 0.022436},{
      0.416399, 0.388494, 0.022436},{0.413030, 0.388494, 0.020372}}],
    Polygon[{{0.416959, 0.392027, 0.022436},{0.420431, 0.390899, 0.023948},{
      0.420050, 0.388494, 0.023948},{0.416399, 0.388494, 0.022436}}],
    Polygon[{{0.420431, 0.390899, 0.023948},{0.424085, 0.389712, 0.024871},{
      0.423892, 0.388494, 0.024871},{0.420050, 0.388494, 0.023948}}],
    Polygon[{{0.423892, 0.388494, -0.024871},{0.420050, 0.388494, -0.023948},{
      0.420431, 0.386090, -0.023948},{0.424085, 0.387277, -0.024871}}],
    Polygon[{{0.420050, 0.388494, -0.023948},{0.416399, 0.388494, -0.022436},{
      0.416959, 0.384962, -0.022436},{0.420431, 0.386090, -0.023948}}],
    Polygon[{{0.416399, 0.388494, -0.022436},{0.413030, 0.388494, -0.020372},{
      0.413755, 0.383921, -0.020372},{0.416959, 0.384962, -0.022436}}],
    Polygon[{{0.413030, 0.388494, -0.020372},{0.410026, 0.388494, -0.017806},{
      0.410897, 0.382992, -0.017806},{0.413755, 0.383921, -0.020372}}],
    Polygon[{{0.410026, 0.388494, -0.017806},{0.407460, 0.388494, -0.014801},{
      0.408457, 0.382199, -0.014801},{0.410897, 0.382992, -0.017806}}],
    Polygon[{{0.407460, 0.388494, -0.014801},{0.405395, 0.388494, -0.011432},{
      0.406493, 0.381561, -0.011432},{0.408457, 0.382199, -0.014801}}],
    Polygon[{{0.405395, 0.388494, -0.011432},{0.403883, 0.388494, -0.007781},{
      0.405055, 0.381094, -0.007781},{0.406493, 0.381561, -0.011432}}],
    Polygon[{{0.403883, 0.388494, -0.007781},{0.402960, 0.388494, -0.003939},{
      0.404178, 0.380809, -0.003939},{0.405055, 0.381094, -0.007781}}],
    Polygon[{{0.402960, 0.388494, -0.003939},{0.402650, 0.388494, 0.000000},{
      0.403883, 0.380713, 0.000000},{0.404178, 0.380809, -0.003939}}],
    Polygon[{{0.402650, 0.388494, 0.000000},{0.402960, 0.388494, 0.003939},{
      0.404178, 0.380809, 0.003939},{0.403883, 0.380713, 0.000000}}],
    Polygon[{{0.402960, 0.388494, 0.003939},{0.403883, 0.388494, 0.007781},{
      0.405055, 0.381094, 0.007781},{0.404178, 0.380809, 0.003939}}],
    Polygon[{{0.403883, 0.388494, 0.007781},{0.405395, 0.388494, 0.011432},{
      0.406493, 0.381561, 0.011432},{0.405055, 0.381094, 0.007781}}],
    Polygon[{{0.405395, 0.388494, 0.011432},{0.407460, 0.388494, 0.014801},{
      0.408457, 0.382199, 0.014801},{0.406493, 0.381561, 0.011432}}],
    Polygon[{{0.407460, 0.388494, 0.014801},{0.410026, 0.388494, 0.017806},{
      0.410897, 0.382992, 0.017806},{0.408457, 0.382199, 0.014801}}],
    Polygon[{{0.410026, 0.388494, 0.017806},{0.413030, 0.388494, 0.020372},{
      0.413755, 0.383921, 0.020372},{0.410897, 0.382992, 0.017806}}],
    Polygon[{{0.413030, 0.388494, 0.020372},{0.416399, 0.388494, 0.022436},{
      0.416959, 0.384962, 0.022436},{0.413755, 0.383921, 0.020372}}],
    Polygon[{{0.416399, 0.388494, 0.022436},{0.420050, 0.388494, 0.023948},{
      0.420431, 0.386090, 0.023948},{0.416959, 0.384962, 0.022436}}],
    Polygon[{{0.420050, 0.388494, 0.023948},{0.423892, 0.388494, 0.024871},{
      0.424085, 0.387277, 0.024871},{0.420431, 0.386090, 0.023948}}],
    Polygon[{{0.424085, 0.387277, -0.024871},{0.420431, 0.386090, -0.023948},{
      0.421536, 0.383921, -0.023948},{0.424644, 0.386179, -0.024871}}],
    Polygon[{{0.420431, 0.386090, -0.023948},{0.416959, 0.384962, -0.022436},{
      0.418583, 0.381775, -0.022436},{0.421536, 0.383921, -0.023948}}],
    Polygon[{{0.416959, 0.384962, -0.022436},{0.413755, 0.383921, -0.020372},{
      0.415857, 0.379795, -0.020372},{0.418583, 0.381775, -0.022436}}],
    Polygon[{{0.413755, 0.383921, -0.020372},{0.410897, 0.382992, -0.017806},{
      0.413426, 0.378029, -0.017806},{0.415857, 0.379795, -0.020372}}],
    Polygon[{{0.410897, 0.382992, -0.017806},{0.408457, 0.382199, -0.014801},{
      0.411350, 0.376520, -0.014801},{0.413426, 0.378029, -0.017806}}],
    Polygon[{{0.408457, 0.382199, -0.014801},{0.406493, 0.381561, -0.011432},{
      0.409680, 0.375307, -0.011432},{0.411350, 0.376520, -0.014801}}],
    Polygon[{{0.406493, 0.381561, -0.011432},{0.405055, 0.381094, -0.007781},{
      0.408457, 0.374418, -0.007781},{0.409680, 0.375307, -0.011432}}],
    Polygon[{{0.405055, 0.381094, -0.007781},{0.404178, 0.380809, -0.003939},{
      0.407710, 0.373876, -0.003939},{0.408457, 0.374418, -0.007781}}],
    Polygon[{{0.404178, 0.380809, -0.003939},{0.403883, 0.380713, 0.000000},{
      0.407460, 0.373693, 0.000000},{0.407710, 0.373876, -0.003939}}],
    Polygon[{{0.403883, 0.380713, 0.000000},{0.404178, 0.380809, 0.003939},{
      0.407710, 0.373876, 0.003939},{0.407460, 0.373693, 0.000000}}],
    Polygon[{{0.404178, 0.380809, 0.003939},{0.405055, 0.381094, 0.007781},{
      0.408457, 0.374418, 0.007781},{0.407710, 0.373876, 0.003939}}],
    Polygon[{{0.405055, 0.381094, 0.007781},{0.406493, 0.381561, 0.011432},{
      0.409680, 0.375307, 0.011432},{0.408457, 0.374418, 0.007781}}],
    Polygon[{{0.406493, 0.381561, 0.011432},{0.408457, 0.382199, 0.014801},{
      0.411350, 0.376520, 0.014801},{0.409680, 0.375307, 0.011432}}],
    Polygon[{{0.408457, 0.382199, 0.014801},{0.410897, 0.382992, 0.017806},{
      0.413426, 0.378029, 0.017806},{0.411350, 0.376520, 0.014801}}],
    Polygon[{{0.410897, 0.382992, 0.017806},{0.413755, 0.383921, 0.020372},{
      0.415857, 0.379795, 0.020372},{0.413426, 0.378029, 0.017806}}],
    Polygon[{{0.413755, 0.383921, 0.020372},{0.416959, 0.384962, 0.022436},{
      0.418583, 0.381775, 0.022436},{0.415857, 0.379795, 0.020372}}],
    Polygon[{{0.416959, 0.384962, 0.022436},{0.420431, 0.386090, 0.023948},{
      0.421536, 0.383921, 0.023948},{0.418583, 0.381775, 0.022436}}],
    Polygon[{{0.420431, 0.386090, 0.023948},{0.424085, 0.387277, 0.024871},{
      0.424644, 0.386179, 0.024871},{0.421536, 0.383921, 0.023948}}],
    Polygon[{{0.424644, 0.386179, -0.024871},{0.421536, 0.383921, -0.023948},{
      0.423257, 0.382199, -0.023948},{0.425516, 0.385308, -0.024871}}],
    Polygon[{{0.421536, 0.383921, -0.023948},{0.418583, 0.381775, -0.022436},{
      0.421112, 0.379246, -0.022436},{0.423257, 0.382199, -0.023948}}],
    Polygon[{{0.418583, 0.381775, -0.022436},{0.415857, 0.379795, -0.020372},{
      0.419131, 0.376520, -0.020372},{0.421112, 0.379246, -0.022436}}],
    Polygon[{{0.415857, 0.379795, -0.020372},{0.413426, 0.378029, -0.017806},{
      0.417365, 0.374089, -0.017806},{0.419131, 0.376520, -0.020372}}],
    Polygon[{{0.413426, 0.378029, -0.017806},{0.411350, 0.376520, -0.014801},{
      0.415857, 0.372013, -0.014801},{0.417365, 0.374089, -0.017806}}],
    Polygon[{{0.411350, 0.376520, -0.014801},{0.409680, 0.375307, -0.011432},{
      0.414644, 0.370343, -0.011432},{0.415857, 0.372013, -0.014801}}],
    Polygon[{{0.409680, 0.375307, -0.011432},{0.408457, 0.374418, -0.007781},{
      0.413755, 0.369120, -0.007781},{0.414644, 0.370343, -0.011432}}],
    Polygon[{{0.408457, 0.374418, -0.007781},{0.407710, 0.373876, -0.003939},{
      0.413213, 0.368373, -0.003939},{0.413755, 0.369120, -0.007781}}],
    Polygon[{{0.407710, 0.373876, -0.003939},{0.407460, 0.373693, 0.000000},{
      0.413030, 0.368123, 0.000000},{0.413213, 0.368373, -0.003939}}],
    Polygon[{{0.407460, 0.373693, 0.000000},{0.407710, 0.373876, 0.003939},{
      0.413213, 0.368373, 0.003939},{0.413030, 0.368123, 0.000000}}],
    Polygon[{{0.407710, 0.373876, 0.003939},{0.408457, 0.374418, 0.007781},{
      0.413755, 0.369120, 0.007781},{0.413213, 0.368373, 0.003939}}],
    Polygon[{{0.408457, 0.374418, 0.007781},{0.409680, 0.375307, 0.011432},{
      0.414644, 0.370343, 0.011432},{0.413755, 0.369120, 0.007781}}],
    Polygon[{{0.409680, 0.375307, 0.011432},{0.411350, 0.376520, 0.014801},{
      0.415857, 0.372013, 0.014801},{0.414644, 0.370343, 0.011432}}],
    Polygon[{{0.411350, 0.376520, 0.014801},{0.413426, 0.378029, 0.017806},{
      0.417365, 0.374089, 0.017806},{0.415857, 0.372013, 0.014801}}],
    Polygon[{{0.413426, 0.378029, 0.017806},{0.415857, 0.379795, 0.020372},{
      0.419131, 0.376520, 0.020372},{0.417365, 0.374089, 0.017806}}],
    Polygon[{{0.415857, 0.379795, 0.020372},{0.418583, 0.381775, 0.022436},{
      0.421112, 0.379246, 0.022436},{0.419131, 0.376520, 0.020372}}],
    Polygon[{{0.418583, 0.381775, 0.022436},{0.421536, 0.383921, 0.023948},{
      0.423257, 0.382199, 0.023948},{0.421112, 0.379246, 0.022436}}],
    Polygon[{{0.421536, 0.383921, 0.023948},{0.424644, 0.386179, 0.024871},{
      0.425516, 0.385308, 0.024871},{0.423257, 0.382199, 0.023948}}],
    Polygon[{{0.425516, 0.385308, -0.024871},{0.423257, 0.382199, -0.023948},{
      0.425427, 0.381094, -0.023948},{0.426614, 0.384748, -0.024871}}],
    Polygon[{{0.423257, 0.382199, -0.023948},{0.421112, 0.379246, -0.022436},{
      0.424299, 0.377622, -0.022436},{0.425427, 0.381094, -0.023948}}],
    Polygon[{{0.421112, 0.379246, -0.022436},{0.419131, 0.376520, -0.020372},{
      0.423257, 0.374418, -0.020372},{0.424299, 0.377622, -0.022436}}],
    Polygon[{{0.419131, 0.376520, -0.020372},{0.417365, 0.374089, -0.017806},{
      0.422329, 0.371560, -0.017806},{0.423257, 0.374418, -0.020372}}],
    Polygon[{{0.417365, 0.374089, -0.017806},{0.415857, 0.372013, -0.014801},{
      0.421536, 0.369120, -0.014801},{0.422329, 0.371560, -0.017806}}],
    Polygon[{{0.415857, 0.372013, -0.014801},{0.414644, 0.370343, -0.011432},{
      0.420898, 0.367156, -0.011432},{0.421536, 0.369120, -0.014801}}],
    Polygon[{{0.414644, 0.370343, -0.011432},{0.413755, 0.369120, -0.007781},{
      0.420431, 0.365718, -0.007781},{0.420898, 0.367156, -0.011432}}],
    Polygon[{{0.413755, 0.369120, -0.007781},{0.413213, 0.368373, -0.003939},{
      0.420146, 0.364841, -0.003939},{0.420431, 0.365718, -0.007781}}],
    Polygon[{{0.413213, 0.368373, -0.003939},{0.413030, 0.368123, 0.000000},{
      0.420050, 0.364546, 0.000000},{0.420146, 0.364841, -0.003939}}],
    Polygon[{{0.413030, 0.368123, 0.000000},{0.413213, 0.368373, 0.003939},{
      0.420146, 0.364841, 0.003939},{0.420050, 0.364546, 0.000000}}],
    Polygon[{{0.413213, 0.368373, 0.003939},{0.413755, 0.369120, 0.007781},{
      0.420431, 0.365718, 0.007781},{0.420146, 0.364841, 0.003939}}],
    Polygon[{{0.413755, 0.369120, 0.007781},{0.414644, 0.370343, 0.011432},{
      0.420898, 0.367156, 0.011432},{0.420431, 0.365718, 0.007781}}],
    Polygon[{{0.414644, 0.370343, 0.011432},{0.415857, 0.372013, 0.014801},{
      0.421536, 0.369120, 0.014801},{0.420898, 0.367156, 0.011432}}],
    Polygon[{{0.415857, 0.372013, 0.014801},{0.417365, 0.374089, 0.017806},{
      0.422329, 0.371560, 0.017806},{0.421536, 0.369120, 0.014801}}],
    Polygon[{{0.417365, 0.374089, 0.017806},{0.419131, 0.376520, 0.020372},{
      0.423257, 0.374418, 0.020372},{0.422329, 0.371560, 0.017806}}],
    Polygon[{{0.419131, 0.376520, 0.020372},{0.421112, 0.379246, 0.022436},{
      0.424299, 0.377622, 0.022436},{0.423257, 0.374418, 0.020372}}],
    Polygon[{{0.421112, 0.379246, 0.022436},{0.423257, 0.382199, 0.023948},{
      0.425427, 0.381094, 0.023948},{0.424299, 0.377622, 0.022436}}],
    Polygon[{{0.423257, 0.382199, 0.023948},{0.425516, 0.385308, 0.024871},{
      0.426614, 0.384748, 0.024871},{0.425427, 0.381094, 0.023948}}],
    Polygon[{{0.426614, 0.384748, -0.024871},{0.425427, 0.381094, -0.023948},{
      0.427831, 0.380713, -0.023948},{0.427831, 0.384555, -0.024871}}],
    Polygon[{{0.425427, 0.381094, -0.023948},{0.424299, 0.377622, -0.022436},{
      0.427831, 0.377062, -0.022436},{0.427831, 0.380713, -0.023948}}],
    Polygon[{{0.424299, 0.377622, -0.022436},{0.423257, 0.374418, -0.020372},{
      0.427831, 0.373693, -0.020372},{0.427831, 0.377062, -0.022436}}],
    Polygon[{{0.423257, 0.374418, -0.020372},{0.422329, 0.371560, -0.017806},{
      0.427831, 0.370689, -0.017806},{0.427831, 0.373693, -0.020372}}],
    Polygon[{{0.422329, 0.371560, -0.017806},{0.421536, 0.369120, -0.014801},{
      0.427831, 0.368123, -0.014801},{0.427831, 0.370689, -0.017806}}],
    Polygon[{{0.421536, 0.369120, -0.014801},{0.420898, 0.367156, -0.011432},{
      0.427831, 0.366058, -0.011432},{0.427831, 0.368123, -0.014801}}],
    Polygon[{{0.420898, 0.367156, -0.011432},{0.420431, 0.365718, -0.007781},{
      0.427831, 0.364546, -0.007781},{0.427831, 0.366058, -0.011432}}],
    Polygon[{{0.420431, 0.365718, -0.007781},{0.420146, 0.364841, -0.003939},{
      0.427831, 0.363624, -0.003939},{0.427831, 0.364546, -0.007781}}],
    Polygon[{{0.420146, 0.364841, -0.003939},{0.420050, 0.364546, 0.000000},{
      0.427831, 0.363314, 0.000000},{0.427831, 0.363624, -0.003939}}],
    Polygon[{{0.420050, 0.364546, 0.000000},{0.420146, 0.364841, 0.003939},{
      0.427831, 0.363624, 0.003939},{0.427831, 0.363314, 0.000000}}],
    Polygon[{{0.420146, 0.364841, 0.003939},{0.420431, 0.365718, 0.007781},{
      0.427831, 0.364546, 0.007781},{0.427831, 0.363624, 0.003939}}],
    Polygon[{{0.420431, 0.365718, 0.007781},{0.420898, 0.367156, 0.011432},{
      0.427831, 0.366058, 0.011432},{0.427831, 0.364546, 0.007781}}],
    Polygon[{{0.420898, 0.367156, 0.011432},{0.421536, 0.369120, 0.014801},{
      0.427831, 0.368123, 0.014801},{0.427831, 0.366058, 0.011432}}],
    Polygon[{{0.421536, 0.369120, 0.014801},{0.422329, 0.371560, 0.017806},{
      0.427831, 0.370689, 0.017806},{0.427831, 0.368123, 0.014801}}],
    Polygon[{{0.422329, 0.371560, 0.017806},{0.423257, 0.374418, 0.020372},{
      0.427831, 0.373693, 0.020372},{0.427831, 0.370689, 0.017806}}],
    Polygon[{{0.423257, 0.374418, 0.020372},{0.424299, 0.377622, 0.022436},{
      0.427831, 0.377062, 0.022436},{0.427831, 0.373693, 0.020372}}],
    Polygon[{{0.424299, 0.377622, 0.022436},{0.425427, 0.381094, 0.023948},{
      0.427831, 0.380713, 0.023948},{0.427831, 0.377062, 0.022436}}],
    Polygon[{{0.425427, 0.381094, 0.023948},{0.426614, 0.384748, 0.024871},{
      0.427831, 0.384555, 0.024871},{0.427831, 0.380713, 0.023948}}],
    Polygon[{{0.427831, 0.384555, -0.024871},{0.427831, 0.380713, -0.023948},{
      0.430236, 0.381094, -0.023948},{0.429048, 0.384748, -0.024871}}],
    Polygon[{{0.427831, 0.380713, -0.023948},{0.427831, 0.377062, -0.022436},{
      0.431364, 0.377622, -0.022436},{0.430236, 0.381094, -0.023948}}],
    Polygon[{{0.427831, 0.377062, -0.022436},{0.427831, 0.373693, -0.020372},{
      0.432405, 0.374418, -0.020372},{0.431364, 0.377622, -0.022436}}],
    Polygon[{{0.427831, 0.373693, -0.020372},{0.427831, 0.370689, -0.017806},{
      0.433333, 0.371560, -0.017806},{0.432405, 0.374418, -0.020372}}],
    Polygon[{{0.427831, 0.370689, -0.017806},{0.427831, 0.368123, -0.014801},{
      0.434126, 0.369120, -0.014801},{0.433333, 0.371560, -0.017806}}],
    Polygon[{{0.427831, 0.368123, -0.014801},{0.427831, 0.366058, -0.011432},{
      0.434764, 0.367156, -0.011432},{0.434126, 0.369120, -0.014801}}],
    Polygon[{{0.427831, 0.366058, -0.011432},{0.427831, 0.364546, -0.007781},{
      0.435232, 0.365718, -0.007781},{0.434764, 0.367156, -0.011432}}],
    Polygon[{{0.427831, 0.364546, -0.007781},{0.427831, 0.363624, -0.003939},{
      0.435517, 0.364841, -0.003939},{0.435232, 0.365718, -0.007781}}],
    Polygon[{{0.427831, 0.363624, -0.003939},{0.427831, 0.363314, 0.000000},{
      0.435612, 0.364546, 0.000000},{0.435517, 0.364841, -0.003939}}],
    Polygon[{{0.427831, 0.363314, 0.000000},{0.427831, 0.363624, 0.003939},{
      0.435517, 0.364841, 0.003939},{0.435612, 0.364546, 0.000000}}],
    Polygon[{{0.427831, 0.363624, 0.003939},{0.427831, 0.364546, 0.007781},{
      0.435232, 0.365718, 0.007781},{0.435517, 0.364841, 0.003939}}],
    Polygon[{{0.427831, 0.364546, 0.007781},{0.427831, 0.366058, 0.011432},{
      0.434764, 0.367156, 0.011432},{0.435232, 0.365718, 0.007781}}],
    Polygon[{{0.427831, 0.366058, 0.011432},{0.427831, 0.368123, 0.014801},{
      0.434126, 0.369120, 0.014801},{0.434764, 0.367156, 0.011432}}],
    Polygon[{{0.427831, 0.368123, 0.014801},{0.427831, 0.370689, 0.017806},{
      0.433333, 0.371560, 0.017806},{0.434126, 0.369120, 0.014801}}],
    Polygon[{{0.427831, 0.370689, 0.017806},{0.427831, 0.373693, 0.020372},{
      0.432405, 0.374418, 0.020372},{0.433333, 0.371560, 0.017806}}],
    Polygon[{{0.427831, 0.373693, 0.020372},{0.427831, 0.377062, 0.022436},{
      0.431364, 0.377622, 0.022436},{0.432405, 0.374418, 0.020372}}],
    Polygon[{{0.427831, 0.377062, 0.022436},{0.427831, 0.380713, 0.023948},{
      0.430236, 0.381094, 0.023948},{0.431364, 0.377622, 0.022436}}],
    Polygon[{{0.427831, 0.380713, 0.023948},{0.427831, 0.384555, 0.024871},{
      0.429048, 0.384748, 0.024871},{0.430236, 0.381094, 0.023948}}],
    Polygon[{{0.429048, 0.384748, -0.024871},{0.430236, 0.381094, -0.023948},{
      0.432405, 0.382199, -0.023948},{0.430147, 0.385308, -0.024871}}],
    Polygon[{{0.430236, 0.381094, -0.023948},{0.431364, 0.377622, -0.022436},{
      0.434551, 0.379246, -0.022436},{0.432405, 0.382199, -0.023948}}],
    Polygon[{{0.431364, 0.377622, -0.022436},{0.432405, 0.374418, -0.020372},{
      0.436531, 0.376520, -0.020372},{0.434551, 0.379246, -0.022436}}],
    Polygon[{{0.432405, 0.374418, -0.020372},{0.433333, 0.371560, -0.017806},{
      0.438297, 0.374089, -0.017806},{0.436531, 0.376520, -0.020372}}],
    Polygon[{{0.433333, 0.371560, -0.017806},{0.434126, 0.369120, -0.014801},{
      0.439805, 0.372013, -0.014801},{0.438297, 0.374089, -0.017806}}],
    Polygon[{{0.434126, 0.369120, -0.014801},{0.434764, 0.367156, -0.011432},{
      0.441019, 0.370343, -0.011432},{0.439805, 0.372013, -0.014801}}],
    Polygon[{{0.434764, 0.367156, -0.011432},{0.435232, 0.365718, -0.007781},{
      0.441908, 0.369120, -0.007781},{0.441019, 0.370343, -0.011432}}],
    Polygon[{{0.435232, 0.365718, -0.007781},{0.435517, 0.364841, -0.003939},{
      0.442450, 0.368373, -0.003939},{0.441908, 0.369120, -0.007781}}],
    Polygon[{{0.435517, 0.364841, -0.003939},{0.435612, 0.364546, 0.000000},{
      0.442632, 0.368123, 0.000000},{0.442450, 0.368373, -0.003939}}],
    Polygon[{{0.435612, 0.364546, 0.000000},{0.435517, 0.364841, 0.003939},{
      0.442450, 0.368373, 0.003939},{0.442632, 0.368123, 0.000000}}],
    Polygon[{{0.435517, 0.364841, 0.003939},{0.435232, 0.365718, 0.007781},{
      0.441908, 0.369120, 0.007781},{0.442450, 0.368373, 0.003939}}],
    Polygon[{{0.435232, 0.365718, 0.007781},{0.434764, 0.367156, 0.011432},{
      0.441019, 0.370343, 0.011432},{0.441908, 0.369120, 0.007781}}],
    Polygon[{{0.434764, 0.367156, 0.011432},{0.434126, 0.369120, 0.014801},{
      0.439805, 0.372013, 0.014801},{0.441019, 0.370343, 0.011432}}],
    Polygon[{{0.434126, 0.369120, 0.014801},{0.433333, 0.371560, 0.017806},{
      0.438297, 0.374089, 0.017806},{0.439805, 0.372013, 0.014801}}],
    Polygon[{{0.433333, 0.371560, 0.017806},{0.432405, 0.374418, 0.020372},{
      0.436531, 0.376520, 0.020372},{0.438297, 0.374089, 0.017806}}],
    Polygon[{{0.432405, 0.374418, 0.020372},{0.431364, 0.377622, 0.022436},{
      0.434551, 0.379246, 0.022436},{0.436531, 0.376520, 0.020372}}],
    Polygon[{{0.431364, 0.377622, 0.022436},{0.430236, 0.381094, 0.023948},{
      0.432405, 0.382199, 0.023948},{0.434551, 0.379246, 0.022436}}],
    Polygon[{{0.430236, 0.381094, 0.023948},{0.429048, 0.384748, 0.024871},{
      0.430147, 0.385308, 0.024871},{0.432405, 0.382199, 0.023948}}],
    Polygon[{{0.430147, 0.385308, -0.024871},{0.432405, 0.382199, -0.023948},{
      0.434126, 0.383921, -0.023948},{0.431018, 0.386179, -0.024871}}],
    Polygon[{{0.432405, 0.382199, -0.023948},{0.434551, 0.379246, -0.022436},{
      0.437080, 0.381775, -0.022436},{0.434126, 0.383921, -0.023948}}],
    Polygon[{{0.434551, 0.379246, -0.022436},{0.436531, 0.376520, -0.020372},{
      0.439805, 0.379795, -0.020372},{0.437080, 0.381775, -0.022436}}],
    Polygon[{{0.436531, 0.376520, -0.020372},{0.438297, 0.374089, -0.017806},{
      0.442236, 0.378029, -0.017806},{0.439805, 0.379795, -0.020372}}],
    Polygon[{{0.438297, 0.374089, -0.017806},{0.439805, 0.372013, -0.014801},{
      0.444312, 0.376520, -0.014801},{0.442236, 0.378029, -0.017806}}],
    Polygon[{{0.439805, 0.372013, -0.014801},{0.441019, 0.370343, -0.011432},{
      0.445983, 0.375307, -0.011432},{0.444312, 0.376520, -0.014801}}],
    Polygon[{{0.441019, 0.370343, -0.011432},{0.441908, 0.369120, -0.007781},{
      0.447206, 0.374418, -0.007781},{0.445983, 0.375307, -0.011432}}],
    Polygon[{{0.441908, 0.369120, -0.007781},{0.442450, 0.368373, -0.003939},{
      0.447952, 0.373876, -0.003939},{0.447206, 0.374418, -0.007781}}],
    Polygon[{{0.442450, 0.368373, -0.003939},{0.442632, 0.368123, 0.000000},{
      0.448203, 0.373693, 0.000000},{0.447952, 0.373876, -0.003939}}],
    Polygon[{{0.442632, 0.368123, 0.000000},{0.442450, 0.368373, 0.003939},{
      0.447952, 0.373876, 0.003939},{0.448203, 0.373693, 0.000000}}],
    Polygon[{{0.442450, 0.368373, 0.003939},{0.441908, 0.369120, 0.007781},{
      0.447206, 0.374418, 0.007781},{0.447952, 0.373876, 0.003939}}],
    Polygon[{{0.441908, 0.369120, 0.007781},{0.441019, 0.370343, 0.011432},{
      0.445983, 0.375307, 0.011432},{0.447206, 0.374418, 0.007781}}],
    Polygon[{{0.441019, 0.370343, 0.011432},{0.439805, 0.372013, 0.014801},{
      0.444312, 0.376520, 0.014801},{0.445983, 0.375307, 0.011432}}],
    Polygon[{{0.439805, 0.372013, 0.014801},{0.438297, 0.374089, 0.017806},{
      0.442236, 0.378029, 0.017806},{0.444312, 0.376520, 0.014801}}],
    Polygon[{{0.438297, 0.374089, 0.017806},{0.436531, 0.376520, 0.020372},{
      0.439805, 0.379795, 0.020372},{0.442236, 0.378029, 0.017806}}],
    Polygon[{{0.436531, 0.376520, 0.020372},{0.434551, 0.379246, 0.022436},{
      0.437080, 0.381775, 0.022436},{0.439805, 0.379795, 0.020372}}],
    Polygon[{{0.434551, 0.379246, 0.022436},{0.432405, 0.382199, 0.023948},{
      0.434126, 0.383921, 0.023948},{0.437080, 0.381775, 0.022436}}],
    Polygon[{{0.432405, 0.382199, 0.023948},{0.430147, 0.385308, 0.024871},{
      0.431018, 0.386179, 0.024871},{0.434126, 0.383921, 0.023948}}],
    Polygon[{{0.431018, 0.386179, -0.024871},{0.434126, 0.383921, -0.023948},{
      0.435232, 0.386090, -0.023948},{0.431578, 0.387277, -0.024871}}],
    Polygon[{{0.434126, 0.383921, -0.023948},{0.437080, 0.381775, -0.022436},{
      0.438704, 0.384962, -0.022436},{0.435232, 0.386090, -0.023948}}],
    Polygon[{{0.437080, 0.381775, -0.022436},{0.439805, 0.379795, -0.020372},{
      0.441908, 0.383921, -0.020372},{0.438704, 0.384962, -0.022436}}],
    Polygon[{{0.439805, 0.379795, -0.020372},{0.442236, 0.378029, -0.017806},{
      0.444765, 0.382992, -0.017806},{0.441908, 0.383921, -0.020372}}],
    Polygon[{{0.442236, 0.378029, -0.017806},{0.444312, 0.376520, -0.014801},{
      0.447206, 0.382199, -0.014801},{0.444765, 0.382992, -0.017806}}],
    Polygon[{{0.444312, 0.376520, -0.014801},{0.445983, 0.375307, -0.011432},{
      0.449169, 0.381561, -0.011432},{0.447206, 0.382199, -0.014801}}],
    Polygon[{{0.445983, 0.375307, -0.011432},{0.447206, 0.374418, -0.007781},{
      0.450607, 0.381094, -0.007781},{0.449169, 0.381561, -0.011432}}],
    Polygon[{{0.447206, 0.374418, -0.007781},{0.447952, 0.373876, -0.003939},{
      0.451485, 0.380809, -0.003939},{0.450607, 0.381094, -0.007781}}],
    Polygon[{{0.447952, 0.373876, -0.003939},{0.448203, 0.373693, 0.000000},{
      0.451780, 0.380713, 0.000000},{0.451485, 0.380809, -0.003939}}],
    Polygon[{{0.448203, 0.373693, 0.000000},{0.447952, 0.373876, 0.003939},{
      0.451485, 0.380809, 0.003939},{0.451780, 0.380713, 0.000000}}],
    Polygon[{{0.447952, 0.373876, 0.003939},{0.447206, 0.374418, 0.007781},{
      0.450607, 0.381094, 0.007781},{0.451485, 0.380809, 0.003939}}],
    Polygon[{{0.447206, 0.374418, 0.007781},{0.445983, 0.375307, 0.011432},{
      0.449169, 0.381561, 0.011432},{0.450607, 0.381094, 0.007781}}],
    Polygon[{{0.445983, 0.375307, 0.011432},{0.444312, 0.376520, 0.014801},{
      0.447206, 0.382199, 0.014801},{0.449169, 0.381561, 0.011432}}],
    Polygon[{{0.444312, 0.376520, 0.014801},{0.442236, 0.378029, 0.017806},{
      0.444765, 0.382992, 0.017806},{0.447206, 0.382199, 0.014801}}],
    Polygon[{{0.442236, 0.378029, 0.017806},{0.439805, 0.379795, 0.020372},{
      0.441908, 0.383921, 0.020372},{0.444765, 0.382992, 0.017806}}],
    Polygon[{{0.439805, 0.379795, 0.020372},{0.437080, 0.381775, 0.022436},{
      0.438704, 0.384962, 0.022436},{0.441908, 0.383921, 0.020372}}],
    Polygon[{{0.437080, 0.381775, 0.022436},{0.434126, 0.383921, 0.023948},{
      0.435232, 0.386090, 0.023948},{0.438704, 0.384962, 0.022436}}],
    Polygon[{{0.434126, 0.383921, 0.023948},{0.431018, 0.386179, 0.024871},{
      0.431578, 0.387277, 0.024871},{0.435232, 0.386090, 0.023948}}],
    Polygon[{{0.431578, 0.387277, -0.024871},{0.435232, 0.386090, -0.023948},{
      0.435612, 0.388494, -0.023948},{0.431770, 0.388494, -0.024871}}],
    Polygon[{{0.435232, 0.386090, -0.023948},{0.438704, 0.384962, -0.022436},{
      0.439263, 0.388494, -0.022436},{0.435612, 0.388494, -0.023948}}],
    Polygon[{{0.438704, 0.384962, -0.022436},{0.441908, 0.383921, -0.020372},{
      0.442632, 0.388494, -0.020372},{0.439263, 0.388494, -0.022436}}],
    Polygon[{{0.441908, 0.383921, -0.020372},{0.444765, 0.382992, -0.017806},{
      0.445637, 0.388494, -0.017806},{0.442632, 0.388494, -0.020372}}],
    Polygon[{{0.444765, 0.382992, -0.017806},{0.447206, 0.382199, -0.014801},{
      0.448203, 0.388494, -0.014801},{0.445637, 0.388494, -0.017806}}],
    Polygon[{{0.447206, 0.382199, -0.014801},{0.449169, 0.381561, -0.011432},{
      0.450267, 0.388494, -0.011432},{0.448203, 0.388494, -0.014801}}],
    Polygon[{{0.449169, 0.381561, -0.011432},{0.450607, 0.381094, -0.007781},{
      0.451780, 0.388494, -0.007781},{0.450267, 0.388494, -0.011432}}],
    Polygon[{{0.450607, 0.381094, -0.007781},{0.451485, 0.380809, -0.003939},{
      0.452702, 0.388494, -0.003939},{0.451780, 0.388494, -0.007781}}],
    Polygon[{{0.451485, 0.380809, -0.003939},{0.451780, 0.380713, 0.000000},{
      0.453012, 0.388494, 0.000000},{0.452702, 0.388494, -0.003939}}],
    Polygon[{{0.451780, 0.380713, 0.000000},{0.451485, 0.380809, 0.003939},{
      0.452702, 0.388494, 0.003939},{0.453012, 0.388494, 0.000000}}],
    Polygon[{{0.451485, 0.380809, 0.003939},{0.450607, 0.381094, 0.007781},{
      0.451780, 0.388494, 0.007781},{0.452702, 0.388494, 0.003939}}],
    Polygon[{{0.450607, 0.381094, 0.007781},{0.449169, 0.381561, 0.011432},{
      0.450267, 0.388494, 0.011432},{0.451780, 0.388494, 0.007781}}],
    Polygon[{{0.449169, 0.381561, 0.011432},{0.447206, 0.382199, 0.014801},{
      0.448203, 0.388494, 0.014801},{0.450267, 0.388494, 0.011432}}],
    Polygon[{{0.447206, 0.382199, 0.014801},{0.444765, 0.382992, 0.017806},{
      0.445637, 0.388494, 0.017806},{0.448203, 0.388494, 0.014801}}],
    Polygon[{{0.444765, 0.382992, 0.017806},{0.441908, 0.383921, 0.020372},{
      0.442632, 0.388494, 0.020372},{0.445637, 0.388494, 0.017806}}],
    Polygon[{{0.441908, 0.383921, 0.020372},{0.438704, 0.384962, 0.022436},{
      0.439263, 0.388494, 0.022436},{0.442632, 0.388494, 0.020372}}],
    Polygon[{{0.438704, 0.384962, 0.022436},{0.435232, 0.386090, 0.023948},{
      0.435612, 0.388494, 0.023948},{0.439263, 0.388494, 0.022436}}],
    Polygon[{{0.435232, 0.386090, 0.023948},{0.431578, 0.387277, 0.024871},{
      0.431770, 0.388494, 0.024871},{0.435612, 0.388494, 0.023948}}],
    Polygon[{{0.453834, 0.359563, -0.012292},{0.455733, 0.359563, -0.011836},{
      0.455545, 0.360752, -0.011836},{0.453739, 0.360165, -0.012292}}],
    Polygon[{{0.455733, 0.359563, -0.011836},{0.457537, 0.359563, -0.011089},{
      0.457261, 0.361309, -0.011089},{0.455545, 0.360752, -0.011836}}],
    Polygon[{{0.457537, 0.359563, -0.011089},{0.459202, 0.359563, -0.010068},{
      0.458844, 0.361824, -0.010068},{0.457261, 0.361309, -0.011089}}],
    Polygon[{{0.459202, 0.359563, -0.010068},{0.460687, 0.359563, -0.008800},{
      0.460257, 0.362283, -0.008800},{0.458844, 0.361824, -0.010068}}],
    Polygon[{{0.460687, 0.359563, -0.008800},{0.461956, 0.359563, -0.007315},{
      0.461463, 0.362675, -0.007315},{0.460257, 0.362283, -0.008800}}],
    Polygon[{{0.461956, 0.359563, -0.007315},{0.462976, 0.359563, -0.005650},{
      0.462433, 0.362990, -0.005650},{0.461463, 0.362675, -0.007315}}],
    Polygon[{{0.462976, 0.359563, -0.005650},{0.463723, 0.359563, -0.003846},{
      0.463144, 0.363221, -0.003846},{0.462433, 0.362990, -0.005650}}],
    Polygon[{{0.463723, 0.359563, -0.003846},{0.464179, 0.359563, -0.001947},{
      0.463578, 0.363362, -0.001947},{0.463144, 0.363221, -0.003846}}],
    Polygon[{{0.464179, 0.359563, -0.001947},{0.464332, 0.359563, 0.000000},{
      0.463723, 0.363409, 0.000000},{0.463578, 0.363362, -0.001947}}],
    Polygon[{{0.464332, 0.359563, 0.000000},{0.464179, 0.359563, 0.001947},{
      0.463578, 0.363362, 0.001947},{0.463723, 0.363409, 0.000000}}],
    Polygon[{{0.464179, 0.359563, 0.001947},{0.463723, 0.359563, 0.003846},{
      0.463144, 0.363221, 0.003846},{0.463578, 0.363362, 0.001947}}],
    Polygon[{{0.463723, 0.359563, 0.003846},{0.462976, 0.359563, 0.005650},{
      0.462433, 0.362990, 0.005650},{0.463144, 0.363221, 0.003846}}],
    Polygon[{{0.462976, 0.359563, 0.005650},{0.461956, 0.359563, 0.007315},{
      0.461463, 0.362675, 0.007315},{0.462433, 0.362990, 0.005650}}],
    Polygon[{{0.461956, 0.359563, 0.007315},{0.460687, 0.359563, 0.008800},{
      0.460257, 0.362283, 0.008800},{0.461463, 0.362675, 0.007315}}],
    Polygon[{{0.460687, 0.359563, 0.008800},{0.459202, 0.359563, 0.010068},{
      0.458844, 0.361824, 0.010068},{0.460257, 0.362283, 0.008800}}],
    Polygon[{{0.459202, 0.359563, 0.010068},{0.457537, 0.359563, 0.011089},{
      0.457261, 0.361309, 0.011089},{0.458844, 0.361824, 0.010068}}],
    Polygon[{{0.457537, 0.359563, 0.011089},{0.455733, 0.359563, 0.011836},{
      0.455545, 0.360752, 0.011836},{0.457261, 0.361309, 0.011089}}],
    Polygon[{{0.455733, 0.359563, 0.011836},{0.453834, 0.359563, 0.012292},{
      0.453739, 0.360165, 0.012292},{0.455545, 0.360752, 0.011836}}],
    Polygon[{{0.453739, 0.360165, -0.012292},{0.455545, 0.360752, -0.011836},{
      0.454999, 0.361824, -0.011836},{0.453462, 0.360708, -0.012292}}],
    Polygon[{{0.455545, 0.360752, -0.011836},{0.457261, 0.361309, -0.011089},{
      0.456458, 0.362884, -0.011089},{0.454999, 0.361824, -0.011836}}],
    Polygon[{{0.457261, 0.361309, -0.011089},{0.458844, 0.361824, -0.010068},{
      0.457805, 0.363863, -0.010068},{0.456458, 0.362884, -0.011089}}],
    Polygon[{{0.458844, 0.361824, -0.010068},{0.460257, 0.362283, -0.008800},{
      0.459007, 0.364736, -0.008800},{0.457805, 0.363863, -0.010068}}],
    Polygon[{{0.460257, 0.362283, -0.008800},{0.461463, 0.362675, -0.007315},{
      0.460033, 0.365481, -0.007315},{0.459007, 0.364736, -0.008800}}],
    Polygon[{{0.461463, 0.362675, -0.007315},{0.462433, 0.362990, -0.005650},{
      0.460858, 0.366081, -0.005650},{0.460033, 0.365481, -0.007315}}],
    Polygon[{{0.462433, 0.362990, -0.005650},{0.463144, 0.363221, -0.003846},{
      0.461463, 0.366520, -0.003846},{0.460858, 0.366081, -0.005650}}],
    Polygon[{{0.463144, 0.363221, -0.003846},{0.463578, 0.363362, -0.001947},{
      0.461832, 0.366788, -0.001947},{0.461463, 0.366520, -0.003846}}],
    Polygon[{{0.463578, 0.363362, -0.001947},{0.463723, 0.363409, 0.000000},{
      0.461956, 0.366878, 0.000000},{0.461832, 0.366788, -0.001947}}],
    Polygon[{{0.463723, 0.363409, 0.000000},{0.463578, 0.363362, 0.001947},{
      0.461832, 0.366788, 0.001947},{0.461956, 0.366878, 0.000000}}],
    Polygon[{{0.463578, 0.363362, 0.001947},{0.463144, 0.363221, 0.003846},{
      0.461463, 0.366520, 0.003846},{0.461832, 0.366788, 0.001947}}],
    Polygon[{{0.463144, 0.363221, 0.003846},{0.462433, 0.362990, 0.005650},{
      0.460858, 0.366081, 0.005650},{0.461463, 0.366520, 0.003846}}],
    Polygon[{{0.462433, 0.362990, 0.005650},{0.461463, 0.362675, 0.007315},{
      0.460033, 0.365481, 0.007315},{0.460858, 0.366081, 0.005650}}],
    Polygon[{{0.461463, 0.362675, 0.007315},{0.460257, 0.362283, 0.008800},{
      0.459007, 0.364736, 0.008800},{0.460033, 0.365481, 0.007315}}],
    Polygon[{{0.460257, 0.362283, 0.008800},{0.458844, 0.361824, 0.010068},{
      0.457805, 0.363863, 0.010068},{0.459007, 0.364736, 0.008800}}],
    Polygon[{{0.458844, 0.361824, 0.010068},{0.457261, 0.361309, 0.011089},{
      0.456458, 0.362884, 0.011089},{0.457805, 0.363863, 0.010068}}],
    Polygon[{{0.457261, 0.361309, 0.011089},{0.455545, 0.360752, 0.011836},{
      0.454999, 0.361824, 0.011836},{0.456458, 0.362884, 0.011089}}],
    Polygon[{{0.455545, 0.360752, 0.011836},{0.453739, 0.360165, 0.012292},{
      0.453462, 0.360708, 0.012292},{0.454999, 0.361824, 0.011836}}],
    Polygon[{{0.453462, 0.360708, -0.012292},{0.454999, 0.361824, -0.011836},{
      0.454148, 0.362675, -0.011836},{0.453032, 0.361139, -0.012292}}],
    Polygon[{{0.454999, 0.361824, -0.011836},{0.456458, 0.362884, -0.011089},{
      0.455208, 0.364134, -0.011089},{0.454148, 0.362675, -0.011836}}],
    Polygon[{{0.456458, 0.362884, -0.011089},{0.457805, 0.363863, -0.010068},{
      0.456187, 0.365481, -0.010068},{0.455208, 0.364134, -0.011089}}],
    Polygon[{{0.457805, 0.363863, -0.010068},{0.459007, 0.364736, -0.008800},{
      0.457060, 0.366683, -0.008800},{0.456187, 0.365481, -0.010068}}],
    Polygon[{{0.459007, 0.364736, -0.008800},{0.460033, 0.365481, -0.007315},{
      0.457805, 0.367709, -0.007315},{0.457060, 0.366683, -0.008800}}],
    Polygon[{{0.460033, 0.365481, -0.007315},{0.460858, 0.366081, -0.005650},{
      0.458405, 0.368534, -0.005650},{0.457805, 0.367709, -0.007315}}],
    Polygon[{{0.460858, 0.366081, -0.005650},{0.461463, 0.366520, -0.003846},{
      0.458844, 0.369139, -0.003846},{0.458405, 0.368534, -0.005650}}],
    Polygon[{{0.461463, 0.366520, -0.003846},{0.461832, 0.366788, -0.001947},{
      0.459112, 0.369508, -0.001947},{0.458844, 0.369139, -0.003846}}],
    Polygon[{{0.461832, 0.366788, -0.001947},{0.461956, 0.366878, 0.000000},{
      0.459202, 0.369632, 0.000000},{0.459112, 0.369508, -0.001947}}],
    Polygon[{{0.461956, 0.366878, 0.000000},{0.461832, 0.366788, 0.001947},{
      0.459112, 0.369508, 0.001947},{0.459202, 0.369632, 0.000000}}],
    Polygon[{{0.461832, 0.366788, 0.001947},{0.461463, 0.366520, 0.003846},{
      0.458844, 0.369139, 0.003846},{0.459112, 0.369508, 0.001947}}],
    Polygon[{{0.461463, 0.366520, 0.003846},{0.460858, 0.366081, 0.005650},{
      0.458405, 0.368534, 0.005650},{0.458844, 0.369139, 0.003846}}],
    Polygon[{{0.460858, 0.366081, 0.005650},{0.460033, 0.365481, 0.007315},{
      0.457805, 0.367709, 0.007315},{0.458405, 0.368534, 0.005650}}],
    Polygon[{{0.460033, 0.365481, 0.007315},{0.459007, 0.364736, 0.008800},{
      0.457060, 0.366683, 0.008800},{0.457805, 0.367709, 0.007315}}],
    Polygon[{{0.459007, 0.364736, 0.008800},{0.457805, 0.363863, 0.010068},{
      0.456187, 0.365481, 0.010068},{0.457060, 0.366683, 0.008800}}],
    Polygon[{{0.457805, 0.363863, 0.010068},{0.456458, 0.362884, 0.011089},{
      0.455208, 0.364134, 0.011089},{0.456187, 0.365481, 0.010068}}],
    Polygon[{{0.456458, 0.362884, 0.011089},{0.454999, 0.361824, 0.011836},{
      0.454148, 0.362675, 0.011836},{0.455208, 0.364134, 0.011089}}],
    Polygon[{{0.454999, 0.361824, 0.011836},{0.453462, 0.360708, 0.012292},{
      0.453032, 0.361139, 0.012292},{0.454148, 0.362675, 0.011836}}],
    Polygon[{{0.453032, 0.361139, -0.012292},{0.454148, 0.362675, -0.011836},{
      0.453076, 0.363221, -0.011836},{0.452489, 0.361415, -0.012292}}],
    Polygon[{{0.454148, 0.362675, -0.011836},{0.455208, 0.364134, -0.011089},{
      0.453633, 0.364937, -0.011089},{0.453076, 0.363221, -0.011836}}],
    Polygon[{{0.455208, 0.364134, -0.011089},{0.456187, 0.365481, -0.010068},{
      0.454148, 0.366520, -0.010068},{0.453633, 0.364937, -0.011089}}],
    Polygon[{{0.456187, 0.365481, -0.010068},{0.457060, 0.366683, -0.008800},{
      0.454607, 0.367933, -0.008800},{0.454148, 0.366520, -0.010068}}],
    Polygon[{{0.457060, 0.366683, -0.008800},{0.457805, 0.367709, -0.007315},{
      0.454999, 0.369139, -0.007315},{0.454607, 0.367933, -0.008800}}],
    Polygon[{{0.457805, 0.367709, -0.007315},{0.458405, 0.368534, -0.005650},{
      0.455314, 0.370109, -0.005650},{0.454999, 0.369139, -0.007315}}],
    Polygon[{{0.458405, 0.368534, -0.005650},{0.458844, 0.369139, -0.003846},{
      0.455545, 0.370820, -0.003846},{0.455314, 0.370109, -0.005650}}],
    Polygon[{{0.458844, 0.369139, -0.003846},{0.459112, 0.369508, -0.001947},{
      0.455686, 0.371254, -0.001947},{0.455545, 0.370820, -0.003846}}],
    Polygon[{{0.459112, 0.369508, -0.001947},{0.459202, 0.369632, 0.000000},{
      0.455733, 0.371399, 0.000000},{0.455686, 0.371254, -0.001947}}],
    Polygon[{{0.459202, 0.369632, 0.000000},{0.459112, 0.369508, 0.001947},{
      0.455686, 0.371254, 0.001947},{0.455733, 0.371399, 0.000000}}],
    Polygon[{{0.459112, 0.369508, 0.001947},{0.458844, 0.369139, 0.003846},{
      0.455545, 0.370820, 0.003846},{0.455686, 0.371254, 0.001947}}],
    Polygon[{{0.458844, 0.369139, 0.003846},{0.458405, 0.368534, 0.005650},{
      0.455314, 0.370109, 0.005650},{0.455545, 0.370820, 0.003846}}],
    Polygon[{{0.458405, 0.368534, 0.005650},{0.457805, 0.367709, 0.007315},{
      0.454999, 0.369139, 0.007315},{0.455314, 0.370109, 0.005650}}],
    Polygon[{{0.457805, 0.367709, 0.007315},{0.457060, 0.366683, 0.008800},{
      0.454607, 0.367933, 0.008800},{0.454999, 0.369139, 0.007315}}],
    Polygon[{{0.457060, 0.366683, 0.008800},{0.456187, 0.365481, 0.010068},{
      0.454148, 0.366520, 0.010068},{0.454607, 0.367933, 0.008800}}],
    Polygon[{{0.456187, 0.365481, 0.010068},{0.455208, 0.364134, 0.011089},{
      0.453633, 0.364937, 0.011089},{0.454148, 0.366520, 0.010068}}],
    Polygon[{{0.455208, 0.364134, 0.011089},{0.454148, 0.362675, 0.011836},{
      0.453076, 0.363221, 0.011836},{0.453633, 0.364937, 0.011089}}],
    Polygon[{{0.454148, 0.362675, 0.011836},{0.453032, 0.361139, 0.012292},{
      0.452489, 0.361415, 0.012292},{0.453076, 0.363221, 0.011836}}],
    Polygon[{{0.452489, 0.361415, -0.012292},{0.453076, 0.363221, -0.011836},{
      0.451887, 0.363409, -0.011836},{0.451887, 0.361510, -0.012292}}],
    Polygon[{{0.453076, 0.363221, -0.011836},{0.453633, 0.364937, -0.011089},{
      0.451887, 0.365213, -0.011089},{0.451887, 0.363409, -0.011836}}],
    Polygon[{{0.453633, 0.364937, -0.011089},{0.454148, 0.366520, -0.010068},{
      0.451887, 0.366878, -0.010068},{0.451887, 0.365213, -0.011089}}],
    Polygon[{{0.454148, 0.366520, -0.010068},{0.454607, 0.367933, -0.008800},{
      0.451887, 0.368363, -0.008800},{0.451887, 0.366878, -0.010068}}],
    Polygon[{{0.454607, 0.367933, -0.008800},{0.454999, 0.369139, -0.007315},{
      0.451887, 0.369632, -0.007315},{0.451887, 0.368363, -0.008800}}],
    Polygon[{{0.454999, 0.369139, -0.007315},{0.455314, 0.370109, -0.005650},{
      0.451887, 0.370652, -0.005650},{0.451887, 0.369632, -0.007315}}],
    Polygon[{{0.455314, 0.370109, -0.005650},{0.455545, 0.370820, -0.003846},{
      0.451887, 0.371399, -0.003846},{0.451887, 0.370652, -0.005650}}],
    Polygon[{{0.455545, 0.370820, -0.003846},{0.455686, 0.371254, -0.001947},{
      0.451887, 0.371855, -0.001947},{0.451887, 0.371399, -0.003846}}],
    Polygon[{{0.455686, 0.371254, -0.001947},{0.455733, 0.371399, 0.000000},{
      0.451887, 0.372008, 0.000000},{0.451887, 0.371855, -0.001947}}],
    Polygon[{{0.455733, 0.371399, 0.000000},{0.455686, 0.371254, 0.001947},{
      0.451887, 0.371855, 0.001947},{0.451887, 0.372008, 0.000000}}],
    Polygon[{{0.455686, 0.371254, 0.001947},{0.455545, 0.370820, 0.003846},{
      0.451887, 0.371399, 0.003846},{0.451887, 0.371855, 0.001947}}],
    Polygon[{{0.455545, 0.370820, 0.003846},{0.455314, 0.370109, 0.005650},{
      0.451887, 0.370652, 0.005650},{0.451887, 0.371399, 0.003846}}],
    Polygon[{{0.455314, 0.370109, 0.005650},{0.454999, 0.369139, 0.007315},{
      0.451887, 0.369632, 0.007315},{0.451887, 0.370652, 0.005650}}],
    Polygon[{{0.454999, 0.369139, 0.007315},{0.454607, 0.367933, 0.008800},{
      0.451887, 0.368363, 0.008800},{0.451887, 0.369632, 0.007315}}],
    Polygon[{{0.454607, 0.367933, 0.008800},{0.454148, 0.366520, 0.010068},{
      0.451887, 0.366878, 0.010068},{0.451887, 0.368363, 0.008800}}],
    Polygon[{{0.454148, 0.366520, 0.010068},{0.453633, 0.364937, 0.011089},{
      0.451887, 0.365213, 0.011089},{0.451887, 0.366878, 0.010068}}],
    Polygon[{{0.453633, 0.364937, 0.011089},{0.453076, 0.363221, 0.011836},{
      0.451887, 0.363409, 0.011836},{0.451887, 0.365213, 0.011089}}],
    Polygon[{{0.453076, 0.363221, 0.011836},{0.452489, 0.361415, 0.012292},{
      0.451887, 0.361510, 0.012292},{0.451887, 0.363409, 0.011836}}],
    Polygon[{{0.451887, 0.361510, -0.012292},{0.451887, 0.363409, -0.011836},{
      0.450699, 0.363221, -0.011836},{0.451286, 0.361415, -0.012292}}],
    Polygon[{{0.451887, 0.363409, -0.011836},{0.451887, 0.365213, -0.011089},{
      0.450142, 0.364937, -0.011089},{0.450699, 0.363221, -0.011836}}],
    Polygon[{{0.451887, 0.365213, -0.011089},{0.451887, 0.366878, -0.010068},{
      0.449627, 0.366520, -0.010068},{0.450142, 0.364937, -0.011089}}],
    Polygon[{{0.451887, 0.366878, -0.010068},{0.451887, 0.368363, -0.008800},{
      0.449168, 0.367933, -0.008800},{0.449627, 0.366520, -0.010068}}],
    Polygon[{{0.451887, 0.368363, -0.008800},{0.451887, 0.369632, -0.007315},{
      0.448776, 0.369139, -0.007315},{0.449168, 0.367933, -0.008800}}],
    Polygon[{{0.451887, 0.369632, -0.007315},{0.451887, 0.370652, -0.005650},{
      0.448461, 0.370109, -0.005650},{0.448776, 0.369139, -0.007315}}],
    Polygon[{{0.451887, 0.370652, -0.005650},{0.451887, 0.371399, -0.003846},{
      0.448230, 0.370820, -0.003846},{0.448461, 0.370109, -0.005650}}],
    Polygon[{{0.451887, 0.371399, -0.003846},{0.451887, 0.371855, -0.001947},{
      0.448089, 0.371254, -0.001947},{0.448230, 0.370820, -0.003846}}],
    Polygon[{{0.451887, 0.371855, -0.001947},{0.451887, 0.372008, 0.000000},{
      0.448042, 0.371399, 0.000000},{0.448089, 0.371254, -0.001947}}],
    Polygon[{{0.451887, 0.372008, 0.000000},{0.451887, 0.371855, 0.001947},{
      0.448089, 0.371254, 0.001947},{0.448042, 0.371399, 0.000000}}],
    Polygon[{{0.451887, 0.371855, 0.001947},{0.451887, 0.371399, 0.003846},{
      0.448230, 0.370820, 0.003846},{0.448089, 0.371254, 0.001947}}],
    Polygon[{{0.451887, 0.371399, 0.003846},{0.451887, 0.370652, 0.005650},{
      0.448461, 0.370109, 0.005650},{0.448230, 0.370820, 0.003846}}],
    Polygon[{{0.451887, 0.370652, 0.005650},{0.451887, 0.369632, 0.007315},{
      0.448776, 0.369139, 0.007315},{0.448461, 0.370109, 0.005650}}],
    Polygon[{{0.451887, 0.369632, 0.007315},{0.451887, 0.368363, 0.008800},{
      0.449168, 0.367933, 0.008800},{0.448776, 0.369139, 0.007315}}],
    Polygon[{{0.451887, 0.368363, 0.008800},{0.451887, 0.366878, 0.010068},{
      0.449627, 0.366520, 0.010068},{0.449168, 0.367933, 0.008800}}],
    Polygon[{{0.451887, 0.366878, 0.010068},{0.451887, 0.365213, 0.011089},{
      0.450142, 0.364937, 0.011089},{0.449627, 0.366520, 0.010068}}],
    Polygon[{{0.451887, 0.365213, 0.011089},{0.451887, 0.363409, 0.011836},{
      0.450699, 0.363221, 0.011836},{0.450142, 0.364937, 0.011089}}],
    Polygon[{{0.451887, 0.363409, 0.011836},{0.451887, 0.361510, 0.012292},{
      0.451286, 0.361415, 0.012292},{0.450699, 0.363221, 0.011836}}],
    Polygon[{{0.451286, 0.361415, -0.012292},{0.450699, 0.363221, -0.011836},{
      0.449627, 0.362675, -0.011836},{0.450743, 0.361139, -0.012292}}],
    Polygon[{{0.450699, 0.363221, -0.011836},{0.450142, 0.364937, -0.011089},{
      0.448567, 0.364134, -0.011089},{0.449627, 0.362675, -0.011836}}],
    Polygon[{{0.450142, 0.364937, -0.011089},{0.449627, 0.366520, -0.010068},{
      0.447588, 0.365481, -0.010068},{0.448567, 0.364134, -0.011089}}],
    Polygon[{{0.449627, 0.366520, -0.010068},{0.449168, 0.367933, -0.008800},{
      0.446715, 0.366683, -0.008800},{0.447588, 0.365481, -0.010068}}],
    Polygon[{{0.449168, 0.367933, -0.008800},{0.448776, 0.369139, -0.007315},{
      0.445970, 0.367709, -0.007315},{0.446715, 0.366683, -0.008800}}],
    Polygon[{{0.448776, 0.369139, -0.007315},{0.448461, 0.370109, -0.005650},{
      0.445370, 0.368534, -0.005650},{0.445970, 0.367709, -0.007315}}],
    Polygon[{{0.448461, 0.370109, -0.005650},{0.448230, 0.370820, -0.003846},{
      0.444931, 0.369139, -0.003846},{0.445370, 0.368534, -0.005650}}],
    Polygon[{{0.448230, 0.370820, -0.003846},{0.448089, 0.371254, -0.001947},{
      0.444663, 0.369508, -0.001947},{0.444931, 0.369139, -0.003846}}],
    Polygon[{{0.448089, 0.371254, -0.001947},{0.448042, 0.371399, 0.000000},{
      0.444573, 0.369632, 0.000000},{0.444663, 0.369508, -0.001947}}],
    Polygon[{{0.448042, 0.371399, 0.000000},{0.448089, 0.371254, 0.001947},{
      0.444663, 0.369508, 0.001947},{0.444573, 0.369632, 0.000000}}],
    Polygon[{{0.448089, 0.371254, 0.001947},{0.448230, 0.370820, 0.003846},{
      0.444931, 0.369139, 0.003846},{0.444663, 0.369508, 0.001947}}],
    Polygon[{{0.448230, 0.370820, 0.003846},{0.448461, 0.370109, 0.005650},{
      0.445370, 0.368534, 0.005650},{0.444931, 0.369139, 0.003846}}],
    Polygon[{{0.448461, 0.370109, 0.005650},{0.448776, 0.369139, 0.007315},{
      0.445970, 0.367709, 0.007315},{0.445370, 0.368534, 0.005650}}],
    Polygon[{{0.448776, 0.369139, 0.007315},{0.449168, 0.367933, 0.008800},{
      0.446715, 0.366683, 0.008800},{0.445970, 0.367709, 0.007315}}],
    Polygon[{{0.449168, 0.367933, 0.008800},{0.449627, 0.366520, 0.010068},{
      0.447588, 0.365481, 0.010068},{0.446715, 0.366683, 0.008800}}],
    Polygon[{{0.449627, 0.366520, 0.010068},{0.450142, 0.364937, 0.011089},{
      0.448567, 0.364134, 0.011089},{0.447588, 0.365481, 0.010068}}],
    Polygon[{{0.450142, 0.364937, 0.011089},{0.450699, 0.363221, 0.011836},{
      0.449627, 0.362675, 0.011836},{0.448567, 0.364134, 0.011089}}],
    Polygon[{{0.450699, 0.363221, 0.011836},{0.451286, 0.361415, 0.012292},{
      0.450743, 0.361139, 0.012292},{0.449627, 0.362675, 0.011836}}],
    Polygon[{{0.450743, 0.361139, -0.012292},{0.449627, 0.362675, -0.011836},{
      0.448776, 0.361824, -0.011836},{0.450312, 0.360708, -0.012292}}],
    Polygon[{{0.449627, 0.362675, -0.011836},{0.448567, 0.364134, -0.011089},{
      0.447317, 0.362884, -0.011089},{0.448776, 0.361824, -0.011836}}],
    Polygon[{{0.448567, 0.364134, -0.011089},{0.447588, 0.365481, -0.010068},{
      0.445970, 0.363863, -0.010068},{0.447317, 0.362884, -0.011089}}],
    Polygon[{{0.447588, 0.365481, -0.010068},{0.446715, 0.366683, -0.008800},{
      0.444768, 0.364736, -0.008800},{0.445970, 0.363863, -0.010068}}],
    Polygon[{{0.446715, 0.366683, -0.008800},{0.445970, 0.367709, -0.007315},{
      0.443742, 0.365481, -0.007315},{0.444768, 0.364736, -0.008800}}],
    Polygon[{{0.445970, 0.367709, -0.007315},{0.445370, 0.368534, -0.005650},{
      0.442917, 0.366081, -0.005650},{0.443742, 0.365481, -0.007315}}],
    Polygon[{{0.445370, 0.368534, -0.005650},{0.444931, 0.369139, -0.003846},{
      0.442312, 0.366520, -0.003846},{0.442917, 0.366081, -0.005650}}],
    Polygon[{{0.444931, 0.369139, -0.003846},{0.444663, 0.369508, -0.001947},{
      0.441943, 0.366788, -0.001947},{0.442312, 0.366520, -0.003846}}],
    Polygon[{{0.444663, 0.369508, -0.001947},{0.444573, 0.369632, 0.000000},{
      0.441819, 0.366878, 0.000000},{0.441943, 0.366788, -0.001947}}],
    Polygon[{{0.444573, 0.369632, 0.000000},{0.444663, 0.369508, 0.001947},{
      0.441943, 0.366788, 0.001947},{0.441819, 0.366878, 0.000000}}],
    Polygon[{{0.444663, 0.369508, 0.001947},{0.444931, 0.369139, 0.003846},{
      0.442312, 0.366520, 0.003846},{0.441943, 0.366788, 0.001947}}],
    Polygon[{{0.444931, 0.369139, 0.003846},{0.445370, 0.368534, 0.005650},{
      0.442917, 0.366081, 0.005650},{0.442312, 0.366520, 0.003846}}],
    Polygon[{{0.445370, 0.368534, 0.005650},{0.445970, 0.367709, 0.007315},{
      0.443742, 0.365481, 0.007315},{0.442917, 0.366081, 0.005650}}],
    Polygon[{{0.445970, 0.367709, 0.007315},{0.446715, 0.366683, 0.008800},{
      0.444768, 0.364736, 0.008800},{0.443742, 0.365481, 0.007315}}],
    Polygon[{{0.446715, 0.366683, 0.008800},{0.447588, 0.365481, 0.010068},{
      0.445970, 0.363863, 0.010068},{0.444768, 0.364736, 0.008800}}],
    Polygon[{{0.447588, 0.365481, 0.010068},{0.448567, 0.364134, 0.011089},{
      0.447317, 0.362884, 0.011089},{0.445970, 0.363863, 0.010068}}],
    Polygon[{{0.448567, 0.364134, 0.011089},{0.449627, 0.362675, 0.011836},{
      0.448776, 0.361824, 0.011836},{0.447317, 0.362884, 0.011089}}],
    Polygon[{{0.449627, 0.362675, 0.011836},{0.450743, 0.361139, 0.012292},{
      0.450312, 0.360708, 0.012292},{0.448776, 0.361824, 0.011836}}],
    Polygon[{{0.450312, 0.360708, -0.012292},{0.448776, 0.361824, -0.011836},{
      0.448230, 0.360752, -0.011836},{0.450036, 0.360165, -0.012292}}],
    Polygon[{{0.448776, 0.361824, -0.011836},{0.447317, 0.362884, -0.011089},{
      0.446514, 0.361309, -0.011089},{0.448230, 0.360752, -0.011836}}],
    Polygon[{{0.447317, 0.362884, -0.011089},{0.445970, 0.363863, -0.010068},{
      0.444931, 0.361824, -0.010068},{0.446514, 0.361309, -0.011089}}],
    Polygon[{{0.445970, 0.363863, -0.010068},{0.444768, 0.364736, -0.008800},{
      0.443518, 0.362283, -0.008800},{0.444931, 0.361824, -0.010068}}],
    Polygon[{{0.444768, 0.364736, -0.008800},{0.443742, 0.365481, -0.007315},{
      0.442312, 0.362675, -0.007315},{0.443518, 0.362283, -0.008800}}],
    Polygon[{{0.443742, 0.365481, -0.007315},{0.442917, 0.366081, -0.005650},{
      0.441342, 0.362990, -0.005650},{0.442312, 0.362675, -0.007315}}],
    Polygon[{{0.442917, 0.366081, -0.005650},{0.442312, 0.366520, -0.003846},{
      0.440631, 0.363221, -0.003846},{0.441342, 0.362990, -0.005650}}],
    Polygon[{{0.442312, 0.366520, -0.003846},{0.441943, 0.366788, -0.001947},{
      0.440197, 0.363362, -0.001947},{0.440631, 0.363221, -0.003846}}],
    Polygon[{{0.441943, 0.366788, -0.001947},{0.441819, 0.366878, 0.000000},{
      0.440052, 0.363409, 0.000000},{0.440197, 0.363362, -0.001947}}],
    Polygon[{{0.441819, 0.366878, 0.000000},{0.441943, 0.366788, 0.001947},{
      0.440197, 0.363362, 0.001947},{0.440052, 0.363409, 0.000000}}],
    Polygon[{{0.441943, 0.366788, 0.001947},{0.442312, 0.366520, 0.003846},{
      0.440631, 0.363221, 0.003846},{0.440197, 0.363362, 0.001947}}],
    Polygon[{{0.442312, 0.366520, 0.003846},{0.442917, 0.366081, 0.005650},{
      0.441342, 0.362990, 0.005650},{0.440631, 0.363221, 0.003846}}],
    Polygon[{{0.442917, 0.366081, 0.005650},{0.443742, 0.365481, 0.007315},{
      0.442312, 0.362675, 0.007315},{0.441342, 0.362990, 0.005650}}],
    Polygon[{{0.443742, 0.365481, 0.007315},{0.444768, 0.364736, 0.008800},{
      0.443518, 0.362283, 0.008800},{0.442312, 0.362675, 0.007315}}],
    Polygon[{{0.444768, 0.364736, 0.008800},{0.445970, 0.363863, 0.010068},{
      0.444931, 0.361824, 0.010068},{0.443518, 0.362283, 0.008800}}],
    Polygon[{{0.445970, 0.363863, 0.010068},{0.447317, 0.362884, 0.011089},{
      0.446514, 0.361309, 0.011089},{0.444931, 0.361824, 0.010068}}],
    Polygon[{{0.447317, 0.362884, 0.011089},{0.448776, 0.361824, 0.011836},{
      0.448230, 0.360752, 0.011836},{0.446514, 0.361309, 0.011089}}],
    Polygon[{{0.448776, 0.361824, 0.011836},{0.450312, 0.360708, 0.012292},{
      0.450036, 0.360165, 0.012292},{0.448230, 0.360752, 0.011836}}],
    Polygon[{{0.450036, 0.360165, -0.012292},{0.448230, 0.360752, -0.011836},{
      0.448042, 0.359563, -0.011836},{0.449941, 0.359563, -0.012292}}],
    Polygon[{{0.448230, 0.360752, -0.011836},{0.446514, 0.361309, -0.011089},{
      0.446238, 0.359563, -0.011089},{0.448042, 0.359563, -0.011836}}],
    Polygon[{{0.446514, 0.361309, -0.011089},{0.444931, 0.361824, -0.010068},{
      0.444573, 0.359563, -0.010068},{0.446238, 0.359563, -0.011089}}],
    Polygon[{{0.444931, 0.361824, -0.010068},{0.443518, 0.362283, -0.008800},{
      0.443088, 0.359563, -0.008800},{0.444573, 0.359563, -0.010068}}],
    Polygon[{{0.443518, 0.362283, -0.008800},{0.442312, 0.362675, -0.007315},{
      0.441819, 0.359563, -0.007315},{0.443088, 0.359563, -0.008800}}],
    Polygon[{{0.442312, 0.362675, -0.007315},{0.441342, 0.362990, -0.005650},{
      0.440799, 0.359563, -0.005650},{0.441819, 0.359563, -0.007315}}],
    Polygon[{{0.441342, 0.362990, -0.005650},{0.440631, 0.363221, -0.003846},{
      0.440052, 0.359563, -0.003846},{0.440799, 0.359563, -0.005650}}],
    Polygon[{{0.440631, 0.363221, -0.003846},{0.440197, 0.363362, -0.001947},{
      0.439596, 0.359563, -0.001947},{0.440052, 0.359563, -0.003846}}],
    Polygon[{{0.440197, 0.363362, -0.001947},{0.440052, 0.363409, 0.000000},{
      0.439443, 0.359563, 0.000000},{0.439596, 0.359563, -0.001947}}],
    Polygon[{{0.440052, 0.363409, 0.000000},{0.440197, 0.363362, 0.001947},{
      0.439596, 0.359563, 0.001947},{0.439443, 0.359563, 0.000000}}],
    Polygon[{{0.440197, 0.363362, 0.001947},{0.440631, 0.363221, 0.003846},{
      0.440052, 0.359563, 0.003846},{0.439596, 0.359563, 0.001947}}],
    Polygon[{{0.440631, 0.363221, 0.003846},{0.441342, 0.362990, 0.005650},{
      0.440799, 0.359563, 0.005650},{0.440052, 0.359563, 0.003846}}],
    Polygon[{{0.441342, 0.362990, 0.005650},{0.442312, 0.362675, 0.007315},{
      0.441819, 0.359563, 0.007315},{0.440799, 0.359563, 0.005650}}],
    Polygon[{{0.442312, 0.362675, 0.007315},{0.443518, 0.362283, 0.008800},{
      0.443088, 0.359563, 0.008800},{0.441819, 0.359563, 0.007315}}],
    Polygon[{{0.443518, 0.362283, 0.008800},{0.444931, 0.361824, 0.010068},{
      0.444573, 0.359563, 0.010068},{0.443088, 0.359563, 0.008800}}],
    Polygon[{{0.444931, 0.361824, 0.010068},{0.446514, 0.361309, 0.011089},{
      0.446238, 0.359563, 0.011089},{0.444573, 0.359563, 0.010068}}],
    Polygon[{{0.446514, 0.361309, 0.011089},{0.448230, 0.360752, 0.011836},{
      0.448042, 0.359563, 0.011836},{0.446238, 0.359563, 0.011089}}],
    Polygon[{{0.448230, 0.360752, 0.011836},{0.450036, 0.360165, 0.012292},{
      0.449941, 0.359563, 0.012292},{0.448042, 0.359563, 0.011836}}],
    Polygon[{{0.449941, 0.359563, -0.012292},{0.448042, 0.359563, -0.011836},{
      0.448230, 0.358375, -0.011836},{0.450036, 0.358962, -0.012292}}],
    Polygon[{{0.448042, 0.359563, -0.011836},{0.446238, 0.359563, -0.011089},{
      0.446514, 0.357818, -0.011089},{0.448230, 0.358375, -0.011836}}],
    Polygon[{{0.446238, 0.359563, -0.011089},{0.444573, 0.359563, -0.010068},{
      0.444931, 0.357303, -0.010068},{0.446514, 0.357818, -0.011089}}],
    Polygon[{{0.444573, 0.359563, -0.010068},{0.443088, 0.359563, -0.008800},{
      0.443518, 0.356844, -0.008800},{0.444931, 0.357303, -0.010068}}],
    Polygon[{{0.443088, 0.359563, -0.008800},{0.441819, 0.359563, -0.007315},{
      0.442312, 0.356452, -0.007315},{0.443518, 0.356844, -0.008800}}],
    Polygon[{{0.441819, 0.359563, -0.007315},{0.440799, 0.359563, -0.005650},{
      0.441342, 0.356137, -0.005650},{0.442312, 0.356452, -0.007315}}],
    Polygon[{{0.440799, 0.359563, -0.005650},{0.440052, 0.359563, -0.003846},{
      0.440631, 0.355906, -0.003846},{0.441342, 0.356137, -0.005650}}],
    Polygon[{{0.440052, 0.359563, -0.003846},{0.439596, 0.359563, -0.001947},{
      0.440197, 0.355765, -0.001947},{0.440631, 0.355906, -0.003846}}],
    Polygon[{{0.439596, 0.359563, -0.001947},{0.439443, 0.359563, 0.000000},{
      0.440052, 0.355718, 0.000000},{0.440197, 0.355765, -0.001947}}],
    Polygon[{{0.439443, 0.359563, 0.000000},{0.439596, 0.359563, 0.001947},{
      0.440197, 0.355765, 0.001947},{0.440052, 0.355718, 0.000000}}],
    Polygon[{{0.439596, 0.359563, 0.001947},{0.440052, 0.359563, 0.003846},{
      0.440631, 0.355906, 0.003846},{0.440197, 0.355765, 0.001947}}],
    Polygon[{{0.440052, 0.359563, 0.003846},{0.440799, 0.359563, 0.005650},{
      0.441342, 0.356137, 0.005650},{0.440631, 0.355906, 0.003846}}],
    Polygon[{{0.440799, 0.359563, 0.005650},{0.441819, 0.359563, 0.007315},{
      0.442312, 0.356452, 0.007315},{0.441342, 0.356137, 0.005650}}],
    Polygon[{{0.441819, 0.359563, 0.007315},{0.443088, 0.359563, 0.008800},{
      0.443518, 0.356844, 0.008800},{0.442312, 0.356452, 0.007315}}],
    Polygon[{{0.443088, 0.359563, 0.008800},{0.444573, 0.359563, 0.010068},{
      0.444931, 0.357303, 0.010068},{0.443518, 0.356844, 0.008800}}],
    Polygon[{{0.444573, 0.359563, 0.010068},{0.446238, 0.359563, 0.011089},{
      0.446514, 0.357818, 0.011089},{0.444931, 0.357303, 0.010068}}],
    Polygon[{{0.446238, 0.359563, 0.011089},{0.448042, 0.359563, 0.011836},{
      0.448230, 0.358375, 0.011836},{0.446514, 0.357818, 0.011089}}],
    Polygon[{{0.448042, 0.359563, 0.011836},{0.449941, 0.359563, 0.012292},{
      0.450036, 0.358962, 0.012292},{0.448230, 0.358375, 0.011836}}],
    Polygon[{{0.450036, 0.358962, -0.012292},{0.448230, 0.358375, -0.011836},{
      0.448776, 0.357303, -0.011836},{0.450312, 0.358419, -0.012292}}],
    Polygon[{{0.448230, 0.358375, -0.011836},{0.446514, 0.357818, -0.011089},{
      0.447317, 0.356243, -0.011089},{0.448776, 0.357303, -0.011836}}],
    Polygon[{{0.446514, 0.357818, -0.011089},{0.444931, 0.357303, -0.010068},{
      0.445970, 0.355264, -0.010068},{0.447317, 0.356243, -0.011089}}],
    Polygon[{{0.444931, 0.357303, -0.010068},{0.443518, 0.356844, -0.008800},{
      0.444768, 0.354391, -0.008800},{0.445970, 0.355264, -0.010068}}],
    Polygon[{{0.443518, 0.356844, -0.008800},{0.442312, 0.356452, -0.007315},{
      0.443742, 0.353646, -0.007315},{0.444768, 0.354391, -0.008800}}],
    Polygon[{{0.442312, 0.356452, -0.007315},{0.441342, 0.356137, -0.005650},{
      0.442917, 0.353046, -0.005650},{0.443742, 0.353646, -0.007315}}],
    Polygon[{{0.441342, 0.356137, -0.005650},{0.440631, 0.355906, -0.003846},{
      0.442312, 0.352607, -0.003846},{0.442917, 0.353046, -0.005650}}],
    Polygon[{{0.440631, 0.355906, -0.003846},{0.440197, 0.355765, -0.001947},{
      0.441943, 0.352339, -0.001947},{0.442312, 0.352607, -0.003846}}],
    Polygon[{{0.440197, 0.355765, -0.001947},{0.440052, 0.355718, 0.000000},{
      0.441819, 0.352249, 0.000000},{0.441943, 0.352339, -0.001947}}],
    Polygon[{{0.440052, 0.355718, 0.000000},{0.440197, 0.355765, 0.001947},{
      0.441943, 0.352339, 0.001947},{0.441819, 0.352249, 0.000000}}],
    Polygon[{{0.440197, 0.355765, 0.001947},{0.440631, 0.355906, 0.003846},{
      0.442312, 0.352607, 0.003846},{0.441943, 0.352339, 0.001947}}],
    Polygon[{{0.440631, 0.355906, 0.003846},{0.441342, 0.356137, 0.005650},{
      0.442917, 0.353046, 0.005650},{0.442312, 0.352607, 0.003846}}],
    Polygon[{{0.441342, 0.356137, 0.005650},{0.442312, 0.356452, 0.007315},{
      0.443742, 0.353646, 0.007315},{0.442917, 0.353046, 0.005650}}],
    Polygon[{{0.442312, 0.356452, 0.007315},{0.443518, 0.356844, 0.008800},{
      0.444768, 0.354391, 0.008800},{0.443742, 0.353646, 0.007315}}],
    Polygon[{{0.443518, 0.356844, 0.008800},{0.444931, 0.357303, 0.010068},{
      0.445970, 0.355264, 0.010068},{0.444768, 0.354391, 0.008800}}],
    Polygon[{{0.444931, 0.357303, 0.010068},{0.446514, 0.357818, 0.011089},{
      0.447317, 0.356243, 0.011089},{0.445970, 0.355264, 0.010068}}],
    Polygon[{{0.446514, 0.357818, 0.011089},{0.448230, 0.358375, 0.011836},{
      0.448776, 0.357303, 0.011836},{0.447317, 0.356243, 0.011089}}],
    Polygon[{{0.448230, 0.358375, 0.011836},{0.450036, 0.358962, 0.012292},{
      0.450312, 0.358419, 0.012292},{0.448776, 0.357303, 0.011836}}],
    Polygon[{{0.450312, 0.358419, -0.012292},{0.448776, 0.357303, -0.011836},{
      0.449627, 0.356452, -0.011836},{0.450743, 0.357989, -0.012292}}],
    Polygon[{{0.448776, 0.357303, -0.011836},{0.447317, 0.356243, -0.011089},{
      0.448567, 0.354993, -0.011089},{0.449627, 0.356452, -0.011836}}],
    Polygon[{{0.447317, 0.356243, -0.011089},{0.445970, 0.355264, -0.010068},{
      0.447588, 0.353646, -0.010068},{0.448567, 0.354993, -0.011089}}],
    Polygon[{{0.445970, 0.355264, -0.010068},{0.444768, 0.354391, -0.008800},{
      0.446715, 0.352444, -0.008800},{0.447588, 0.353646, -0.010068}}],
    Polygon[{{0.444768, 0.354391, -0.008800},{0.443742, 0.353646, -0.007315},{
      0.445970, 0.351418, -0.007315},{0.446715, 0.352444, -0.008800}}],
    Polygon[{{0.443742, 0.353646, -0.007315},{0.442917, 0.353046, -0.005650},{
      0.445370, 0.350593, -0.005650},{0.445970, 0.351418, -0.007315}}],
    Polygon[{{0.442917, 0.353046, -0.005650},{0.442312, 0.352607, -0.003846},{
      0.444931, 0.349988, -0.003846},{0.445370, 0.350593, -0.005650}}],
    Polygon[{{0.442312, 0.352607, -0.003846},{0.441943, 0.352339, -0.001947},{
      0.444663, 0.349619, -0.001947},{0.444931, 0.349988, -0.003846}}],
    Polygon[{{0.441943, 0.352339, -0.001947},{0.441819, 0.352249, 0.000000},{
      0.444573, 0.349495, 0.000000},{0.444663, 0.349619, -0.001947}}],
    Polygon[{{0.441819, 0.352249, 0.000000},{0.441943, 0.352339, 0.001947},{
      0.444663, 0.349619, 0.001947},{0.444573, 0.349495, 0.000000}}],
    Polygon[{{0.441943, 0.352339, 0.001947},{0.442312, 0.352607, 0.003846},{
      0.444931, 0.349988, 0.003846},{0.444663, 0.349619, 0.001947}}],
    Polygon[{{0.442312, 0.352607, 0.003846},{0.442917, 0.353046, 0.005650},{
      0.445370, 0.350593, 0.005650},{0.444931, 0.349988, 0.003846}}],
    Polygon[{{0.442917, 0.353046, 0.005650},{0.443742, 0.353646, 0.007315},{
      0.445970, 0.351418, 0.007315},{0.445370, 0.350593, 0.005650}}],
    Polygon[{{0.443742, 0.353646, 0.007315},{0.444768, 0.354391, 0.008800},{
      0.446715, 0.352444, 0.008800},{0.445970, 0.351418, 0.007315}}],
    Polygon[{{0.444768, 0.354391, 0.008800},{0.445970, 0.355264, 0.010068},{
      0.447588, 0.353646, 0.010068},{0.446715, 0.352444, 0.008800}}],
    Polygon[{{0.445970, 0.355264, 0.010068},{0.447317, 0.356243, 0.011089},{
      0.448567, 0.354993, 0.011089},{0.447588, 0.353646, 0.010068}}],
    Polygon[{{0.447317, 0.356243, 0.011089},{0.448776, 0.357303, 0.011836},{
      0.449627, 0.356452, 0.011836},{0.448567, 0.354993, 0.011089}}],
    Polygon[{{0.448776, 0.357303, 0.011836},{0.450312, 0.358419, 0.012292},{
      0.450743, 0.357989, 0.012292},{0.449627, 0.356452, 0.011836}}],
    Polygon[{{0.450743, 0.357989, -0.012292},{0.449627, 0.356452, -0.011836},{
      0.450699, 0.355906, -0.011836},{0.451286, 0.357712, -0.012292}}],
    Polygon[{{0.449627, 0.356452, -0.011836},{0.448567, 0.354993, -0.011089},{
      0.450142, 0.354190, -0.011089},{0.450699, 0.355906, -0.011836}}],
    Polygon[{{0.448567, 0.354993, -0.011089},{0.447588, 0.353646, -0.010068},{
      0.449627, 0.352607, -0.010068},{0.450142, 0.354190, -0.011089}}],
    Polygon[{{0.447588, 0.353646, -0.010068},{0.446715, 0.352444, -0.008800},{
      0.449168, 0.351194, -0.008800},{0.449627, 0.352607, -0.010068}}],
    Polygon[{{0.446715, 0.352444, -0.008800},{0.445970, 0.351418, -0.007315},{
      0.448776, 0.349988, -0.007315},{0.449168, 0.351194, -0.008800}}],
    Polygon[{{0.445970, 0.351418, -0.007315},{0.445370, 0.350593, -0.005650},{
      0.448461, 0.349018, -0.005650},{0.448776, 0.349988, -0.007315}}],
    Polygon[{{0.445370, 0.350593, -0.005650},{0.444931, 0.349988, -0.003846},{
      0.448230, 0.348307, -0.003846},{0.448461, 0.349018, -0.005650}}],
    Polygon[{{0.444931, 0.349988, -0.003846},{0.444663, 0.349619, -0.001947},{
      0.448089, 0.347873, -0.001947},{0.448230, 0.348307, -0.003846}}],
    Polygon[{{0.444663, 0.349619, -0.001947},{0.444573, 0.349495, 0.000000},{
      0.448042, 0.347728, 0.000000},{0.448089, 0.347873, -0.001947}}],
    Polygon[{{0.444573, 0.349495, 0.000000},{0.444663, 0.349619, 0.001947},{
      0.448089, 0.347873, 0.001947},{0.448042, 0.347728, 0.000000}}],
    Polygon[{{0.444663, 0.349619, 0.001947},{0.444931, 0.349988, 0.003846},{
      0.448230, 0.348307, 0.003846},{0.448089, 0.347873, 0.001947}}],
    Polygon[{{0.444931, 0.349988, 0.003846},{0.445370, 0.350593, 0.005650},{
      0.448461, 0.349018, 0.005650},{0.448230, 0.348307, 0.003846}}],
    Polygon[{{0.445370, 0.350593, 0.005650},{0.445970, 0.351418, 0.007315},{
      0.448776, 0.349988, 0.007315},{0.448461, 0.349018, 0.005650}}],
    Polygon[{{0.445970, 0.351418, 0.007315},{0.446715, 0.352444, 0.008800},{
      0.449168, 0.351194, 0.008800},{0.448776, 0.349988, 0.007315}}],
    Polygon[{{0.446715, 0.352444, 0.008800},{0.447588, 0.353646, 0.010068},{
      0.449627, 0.352607, 0.010068},{0.449168, 0.351194, 0.008800}}],
    Polygon[{{0.447588, 0.353646, 0.010068},{0.448567, 0.354993, 0.011089},{
      0.450142, 0.354190, 0.011089},{0.449627, 0.352607, 0.010068}}],
    Polygon[{{0.448567, 0.354993, 0.011089},{0.449627, 0.356452, 0.011836},{
      0.450699, 0.355906, 0.011836},{0.450142, 0.354190, 0.011089}}],
    Polygon[{{0.449627, 0.356452, 0.011836},{0.450743, 0.357989, 0.012292},{
      0.451286, 0.357712, 0.012292},{0.450699, 0.355906, 0.011836}}],
    Polygon[{{0.451286, 0.357712, -0.012292},{0.450699, 0.355906, -0.011836},{
      0.451887, 0.355718, -0.011836},{0.451887, 0.357617, -0.012292}}],
    Polygon[{{0.450699, 0.355906, -0.011836},{0.450142, 0.354190, -0.011089},{
      0.451887, 0.353914, -0.011089},{0.451887, 0.355718, -0.011836}}],
    Polygon[{{0.450142, 0.354190, -0.011089},{0.449627, 0.352607, -0.010068},{
      0.451887, 0.352249, -0.010068},{0.451887, 0.353914, -0.011089}}],
    Polygon[{{0.449627, 0.352607, -0.010068},{0.449168, 0.351194, -0.008800},{
      0.451887, 0.350764, -0.008800},{0.451887, 0.352249, -0.010068}}],
    Polygon[{{0.449168, 0.351194, -0.008800},{0.448776, 0.349988, -0.007315},{
      0.451887, 0.349495, -0.007315},{0.451887, 0.350764, -0.008800}}],
    Polygon[{{0.448776, 0.349988, -0.007315},{0.448461, 0.349018, -0.005650},{
      0.451887, 0.348475, -0.005650},{0.451887, 0.349495, -0.007315}}],
    Polygon[{{0.448461, 0.349018, -0.005650},{0.448230, 0.348307, -0.003846},{
      0.451887, 0.347728, -0.003846},{0.451887, 0.348475, -0.005650}}],
    Polygon[{{0.448230, 0.348307, -0.003846},{0.448089, 0.347873, -0.001947},{
      0.451887, 0.347272, -0.001947},{0.451887, 0.347728, -0.003846}}],
    Polygon[{{0.448089, 0.347873, -0.001947},{0.448042, 0.347728, 0.000000},{
      0.451887, 0.347119, 0.000000},{0.451887, 0.347272, -0.001947}}],
    Polygon[{{0.448042, 0.347728, 0.000000},{0.448089, 0.347873, 0.001947},{
      0.451887, 0.347272, 0.001947},{0.451887, 0.347119, 0.000000}}],
    Polygon[{{0.448089, 0.347873, 0.001947},{0.448230, 0.348307, 0.003846},{
      0.451887, 0.347728, 0.003846},{0.451887, 0.347272, 0.001947}}],
    Polygon[{{0.448230, 0.348307, 0.003846},{0.448461, 0.349018, 0.005650},{
      0.451887, 0.348475, 0.005650},{0.451887, 0.347728, 0.003846}}],
    Polygon[{{0.448461, 0.349018, 0.005650},{0.448776, 0.349988, 0.007315},{
      0.451887, 0.349495, 0.007315},{0.451887, 0.348475, 0.005650}}],
    Polygon[{{0.448776, 0.349988, 0.007315},{0.449168, 0.351194, 0.008800},{
      0.451887, 0.350764, 0.008800},{0.451887, 0.349495, 0.007315}}],
    Polygon[{{0.449168, 0.351194, 0.008800},{0.449627, 0.352607, 0.010068},{
      0.451887, 0.352249, 0.010068},{0.451887, 0.350764, 0.008800}}],
    Polygon[{{0.449627, 0.352607, 0.010068},{0.450142, 0.354190, 0.011089},{
      0.451887, 0.353914, 0.011089},{0.451887, 0.352249, 0.010068}}],
    Polygon[{{0.450142, 0.354190, 0.011089},{0.450699, 0.355906, 0.011836},{
      0.451887, 0.355718, 0.011836},{0.451887, 0.353914, 0.011089}}],
    Polygon[{{0.450699, 0.355906, 0.011836},{0.451286, 0.357712, 0.012292},{
      0.451887, 0.357617, 0.012292},{0.451887, 0.355718, 0.011836}}],
    Polygon[{{0.451887, 0.357617, -0.012292},{0.451887, 0.355718, -0.011836},{
      0.453076, 0.355906, -0.011836},{0.452489, 0.357712, -0.012292}}],
    Polygon[{{0.451887, 0.355718, -0.011836},{0.451887, 0.353914, -0.011089},{
      0.453633, 0.354190, -0.011089},{0.453076, 0.355906, -0.011836}}],
    Polygon[{{0.451887, 0.353914, -0.011089},{0.451887, 0.352249, -0.010068},{
      0.454148, 0.352607, -0.010068},{0.453633, 0.354190, -0.011089}}],
    Polygon[{{0.451887, 0.352249, -0.010068},{0.451887, 0.350764, -0.008800},{
      0.454607, 0.351194, -0.008800},{0.454148, 0.352607, -0.010068}}],
    Polygon[{{0.451887, 0.350764, -0.008800},{0.451887, 0.349495, -0.007315},{
      0.454999, 0.349988, -0.007315},{0.454607, 0.351194, -0.008800}}],
    Polygon[{{0.451887, 0.349495, -0.007315},{0.451887, 0.348475, -0.005650},{
      0.455314, 0.349018, -0.005650},{0.454999, 0.349988, -0.007315}}],
    Polygon[{{0.451887, 0.348475, -0.005650},{0.451887, 0.347728, -0.003846},{
      0.455545, 0.348307, -0.003846},{0.455314, 0.349018, -0.005650}}],
    Polygon[{{0.451887, 0.347728, -0.003846},{0.451887, 0.347272, -0.001947},{
      0.455686, 0.347873, -0.001947},{0.455545, 0.348307, -0.003846}}],
    Polygon[{{0.451887, 0.347272, -0.001947},{0.451887, 0.347119, 0.000000},{
      0.455733, 0.347728, 0.000000},{0.455686, 0.347873, -0.001947}}],
    Polygon[{{0.451887, 0.347119, 0.000000},{0.451887, 0.347272, 0.001947},{
      0.455686, 0.347873, 0.001947},{0.455733, 0.347728, 0.000000}}],
    Polygon[{{0.451887, 0.347272, 0.001947},{0.451887, 0.347728, 0.003846},{
      0.455545, 0.348307, 0.003846},{0.455686, 0.347873, 0.001947}}],
    Polygon[{{0.451887, 0.347728, 0.003846},{0.451887, 0.348475, 0.005650},{
      0.455314, 0.349018, 0.005650},{0.455545, 0.348307, 0.003846}}],
    Polygon[{{0.451887, 0.348475, 0.005650},{0.451887, 0.349495, 0.007315},{
      0.454999, 0.349988, 0.007315},{0.455314, 0.349018, 0.005650}}],
    Polygon[{{0.451887, 0.349495, 0.007315},{0.451887, 0.350764, 0.008800},{
      0.454607, 0.351194, 0.008800},{0.454999, 0.349988, 0.007315}}],
    Polygon[{{0.451887, 0.350764, 0.008800},{0.451887, 0.352249, 0.010068},{
      0.454148, 0.352607, 0.010068},{0.454607, 0.351194, 0.008800}}],
    Polygon[{{0.451887, 0.352249, 0.010068},{0.451887, 0.353914, 0.011089},{
      0.453633, 0.354190, 0.011089},{0.454148, 0.352607, 0.010068}}],
    Polygon[{{0.451887, 0.353914, 0.011089},{0.451887, 0.355718, 0.011836},{
      0.453076, 0.355906, 0.011836},{0.453633, 0.354190, 0.011089}}],
    Polygon[{{0.451887, 0.355718, 0.011836},{0.451887, 0.357617, 0.012292},{
      0.452489, 0.357712, 0.012292},{0.453076, 0.355906, 0.011836}}],
    Polygon[{{0.452489, 0.357712, -0.012292},{0.453076, 0.355906, -0.011836},{
      0.454148, 0.356452, -0.011836},{0.453032, 0.357989, -0.012292}}],
    Polygon[{{0.453076, 0.355906, -0.011836},{0.453633, 0.354190, -0.011089},{
      0.455208, 0.354993, -0.011089},{0.454148, 0.356452, -0.011836}}],
    Polygon[{{0.453633, 0.354190, -0.011089},{0.454148, 0.352607, -0.010068},{
      0.456187, 0.353646, -0.010068},{0.455208, 0.354993, -0.011089}}],
    Polygon[{{0.454148, 0.352607, -0.010068},{0.454607, 0.351194, -0.008800},{
      0.457060, 0.352444, -0.008800},{0.456187, 0.353646, -0.010068}}],
    Polygon[{{0.454607, 0.351194, -0.008800},{0.454999, 0.349988, -0.007315},{
      0.457805, 0.351418, -0.007315},{0.457060, 0.352444, -0.008800}}],
    Polygon[{{0.454999, 0.349988, -0.007315},{0.455314, 0.349018, -0.005650},{
      0.458405, 0.350593, -0.005650},{0.457805, 0.351418, -0.007315}}],
    Polygon[{{0.455314, 0.349018, -0.005650},{0.455545, 0.348307, -0.003846},{
      0.458844, 0.349988, -0.003846},{0.458405, 0.350593, -0.005650}}],
    Polygon[{{0.455545, 0.348307, -0.003846},{0.455686, 0.347873, -0.001947},{
      0.459112, 0.349619, -0.001947},{0.458844, 0.349988, -0.003846}}],
    Polygon[{{0.455686, 0.347873, -0.001947},{0.455733, 0.347728, 0.000000},{
      0.459202, 0.349495, 0.000000},{0.459112, 0.349619, -0.001947}}],
    Polygon[{{0.455733, 0.347728, 0.000000},{0.455686, 0.347873, 0.001947},{
      0.459112, 0.349619, 0.001947},{0.459202, 0.349495, 0.000000}}],
    Polygon[{{0.455686, 0.347873, 0.001947},{0.455545, 0.348307, 0.003846},{
      0.458844, 0.349988, 0.003846},{0.459112, 0.349619, 0.001947}}],
    Polygon[{{0.455545, 0.348307, 0.003846},{0.455314, 0.349018, 0.005650},{
      0.458405, 0.350593, 0.005650},{0.458844, 0.349988, 0.003846}}],
    Polygon[{{0.455314, 0.349018, 0.005650},{0.454999, 0.349988, 0.007315},{
      0.457805, 0.351418, 0.007315},{0.458405, 0.350593, 0.005650}}],
    Polygon[{{0.454999, 0.349988, 0.007315},{0.454607, 0.351194, 0.008800},{
      0.457060, 0.352444, 0.008800},{0.457805, 0.351418, 0.007315}}],
    Polygon[{{0.454607, 0.351194, 0.008800},{0.454148, 0.352607, 0.010068},{
      0.456187, 0.353646, 0.010068},{0.457060, 0.352444, 0.008800}}],
    Polygon[{{0.454148, 0.352607, 0.010068},{0.453633, 0.354190, 0.011089},{
      0.455208, 0.354993, 0.011089},{0.456187, 0.353646, 0.010068}}],
    Polygon[{{0.453633, 0.354190, 0.011089},{0.453076, 0.355906, 0.011836},{
      0.454148, 0.356452, 0.011836},{0.455208, 0.354993, 0.011089}}],
    Polygon[{{0.453076, 0.355906, 0.011836},{0.452489, 0.357712, 0.012292},{
      0.453032, 0.357989, 0.012292},{0.454148, 0.356452, 0.011836}}],
    Polygon[{{0.453032, 0.357989, -0.012292},{0.454148, 0.356452, -0.011836},{
      0.454999, 0.357303, -0.011836},{0.453462, 0.358419, -0.012292}}],
    Polygon[{{0.454148, 0.356452, -0.011836},{0.455208, 0.354993, -0.011089},{
      0.456458, 0.356243, -0.011089},{0.454999, 0.357303, -0.011836}}],
    Polygon[{{0.455208, 0.354993, -0.011089},{0.456187, 0.353646, -0.010068},{
      0.457805, 0.355264, -0.010068},{0.456458, 0.356243, -0.011089}}],
    Polygon[{{0.456187, 0.353646, -0.010068},{0.457060, 0.352444, -0.008800},{
      0.459007, 0.354391, -0.008800},{0.457805, 0.355264, -0.010068}}],
    Polygon[{{0.457060, 0.352444, -0.008800},{0.457805, 0.351418, -0.007315},{
      0.460033, 0.353646, -0.007315},{0.459007, 0.354391, -0.008800}}],
    Polygon[{{0.457805, 0.351418, -0.007315},{0.458405, 0.350593, -0.005650},{
      0.460858, 0.353046, -0.005650},{0.460033, 0.353646, -0.007315}}],
    Polygon[{{0.458405, 0.350593, -0.005650},{0.458844, 0.349988, -0.003846},{
      0.461463, 0.352607, -0.003846},{0.460858, 0.353046, -0.005650}}],
    Polygon[{{0.458844, 0.349988, -0.003846},{0.459112, 0.349619, -0.001947},{
      0.461832, 0.352339, -0.001947},{0.461463, 0.352607, -0.003846}}],
    Polygon[{{0.459112, 0.349619, -0.001947},{0.459202, 0.349495, 0.000000},{
      0.461956, 0.352249, 0.000000},{0.461832, 0.352339, -0.001947}}],
    Polygon[{{0.459202, 0.349495, 0.000000},{0.459112, 0.349619, 0.001947},{
      0.461832, 0.352339, 0.001947},{0.461956, 0.352249, 0.000000}}],
    Polygon[{{0.459112, 0.349619, 0.001947},{0.458844, 0.349988, 0.003846},{
      0.461463, 0.352607, 0.003846},{0.461832, 0.352339, 0.001947}}],
    Polygon[{{0.458844, 0.349988, 0.003846},{0.458405, 0.350593, 0.005650},{
      0.460858, 0.353046, 0.005650},{0.461463, 0.352607, 0.003846}}],
    Polygon[{{0.458405, 0.350593, 0.005650},{0.457805, 0.351418, 0.007315},{
      0.460033, 0.353646, 0.007315},{0.460858, 0.353046, 0.005650}}],
    Polygon[{{0.457805, 0.351418, 0.007315},{0.457060, 0.352444, 0.008800},{
      0.459007, 0.354391, 0.008800},{0.460033, 0.353646, 0.007315}}],
    Polygon[{{0.457060, 0.352444, 0.008800},{0.456187, 0.353646, 0.010068},{
      0.457805, 0.355264, 0.010068},{0.459007, 0.354391, 0.008800}}],
    Polygon[{{0.456187, 0.353646, 0.010068},{0.455208, 0.354993, 0.011089},{
      0.456458, 0.356243, 0.011089},{0.457805, 0.355264, 0.010068}}],
    Polygon[{{0.455208, 0.354993, 0.011089},{0.454148, 0.356452, 0.011836},{
      0.454999, 0.357303, 0.011836},{0.456458, 0.356243, 0.011089}}],
    Polygon[{{0.454148, 0.356452, 0.011836},{0.453032, 0.357989, 0.012292},{
      0.453462, 0.358419, 0.012292},{0.454999, 0.357303, 0.011836}}],
    Polygon[{{0.453462, 0.358419, -0.012292},{0.454999, 0.357303, -0.011836},{
      0.455545, 0.358375, -0.011836},{0.453739, 0.358962, -0.012292}}],
    Polygon[{{0.454999, 0.357303, -0.011836},{0.456458, 0.356243, -0.011089},{
      0.457261, 0.357818, -0.011089},{0.455545, 0.358375, -0.011836}}],
    Polygon[{{0.456458, 0.356243, -0.011089},{0.457805, 0.355264, -0.010068},{
      0.458844, 0.357303, -0.010068},{0.457261, 0.357818, -0.011089}}],
    Polygon[{{0.457805, 0.355264, -0.010068},{0.459007, 0.354391, -0.008800},{
      0.460257, 0.356844, -0.008800},{0.458844, 0.357303, -0.010068}}],
    Polygon[{{0.459007, 0.354391, -0.008800},{0.460033, 0.353646, -0.007315},{
      0.461463, 0.356452, -0.007315},{0.460257, 0.356844, -0.008800}}],
    Polygon[{{0.460033, 0.353646, -0.007315},{0.460858, 0.353046, -0.005650},{
      0.462433, 0.356137, -0.005650},{0.461463, 0.356452, -0.007315}}],
    Polygon[{{0.460858, 0.353046, -0.005650},{0.461463, 0.352607, -0.003846},{
      0.463144, 0.355906, -0.003846},{0.462433, 0.356137, -0.005650}}],
    Polygon[{{0.461463, 0.352607, -0.003846},{0.461832, 0.352339, -0.001947},{
      0.463578, 0.355765, -0.001947},{0.463144, 0.355906, -0.003846}}],
    Polygon[{{0.461832, 0.352339, -0.001947},{0.461956, 0.352249, 0.000000},{
      0.463723, 0.355718, 0.000000},{0.463578, 0.355765, -0.001947}}],
    Polygon[{{0.461956, 0.352249, 0.000000},{0.461832, 0.352339, 0.001947},{
      0.463578, 0.355765, 0.001947},{0.463723, 0.355718, 0.000000}}],
    Polygon[{{0.461832, 0.352339, 0.001947},{0.461463, 0.352607, 0.003846},{
      0.463144, 0.355906, 0.003846},{0.463578, 0.355765, 0.001947}}],
    Polygon[{{0.461463, 0.352607, 0.003846},{0.460858, 0.353046, 0.005650},{
      0.462433, 0.356137, 0.005650},{0.463144, 0.355906, 0.003846}}],
    Polygon[{{0.460858, 0.353046, 0.005650},{0.460033, 0.353646, 0.007315},{
      0.461463, 0.356452, 0.007315},{0.462433, 0.356137, 0.005650}}],
    Polygon[{{0.460033, 0.353646, 0.007315},{0.459007, 0.354391, 0.008800},{
      0.460257, 0.356844, 0.008800},{0.461463, 0.356452, 0.007315}}],
    Polygon[{{0.459007, 0.354391, 0.008800},{0.457805, 0.355264, 0.010068},{
      0.458844, 0.357303, 0.010068},{0.460257, 0.356844, 0.008800}}],
    Polygon[{{0.457805, 0.355264, 0.010068},{0.456458, 0.356243, 0.011089},{
      0.457261, 0.357818, 0.011089},{0.458844, 0.357303, 0.010068}}],
    Polygon[{{0.456458, 0.356243, 0.011089},{0.454999, 0.357303, 0.011836},{
      0.455545, 0.358375, 0.011836},{0.457261, 0.357818, 0.011089}}],
    Polygon[{{0.454999, 0.357303, 0.011836},{0.453462, 0.358419, 0.012292},{
      0.453739, 0.358962, 0.012292},{0.455545, 0.358375, 0.011836}}],
    Polygon[{{0.453739, 0.358962, -0.012292},{0.455545, 0.358375, -0.011836},{
      0.455733, 0.359563, -0.011836},{0.453834, 0.359563, -0.012292}}],
    Polygon[{{0.455545, 0.358375, -0.011836},{0.457261, 0.357818, -0.011089},{
      0.457537, 0.359563, -0.011089},{0.455733, 0.359563, -0.011836}}],
    Polygon[{{0.457261, 0.357818, -0.011089},{0.458844, 0.357303, -0.010068},{
      0.459202, 0.359563, -0.010068},{0.457537, 0.359563, -0.011089}}],
    Polygon[{{0.458844, 0.357303, -0.010068},{0.460257, 0.356844, -0.008800},{
      0.460687, 0.359563, -0.008800},{0.459202, 0.359563, -0.010068}}],
    Polygon[{{0.460257, 0.356844, -0.008800},{0.461463, 0.356452, -0.007315},{
      0.461956, 0.359563, -0.007315},{0.460687, 0.359563, -0.008800}}],
    Polygon[{{0.461463, 0.356452, -0.007315},{0.462433, 0.356137, -0.005650},{
      0.462976, 0.359563, -0.005650},{0.461956, 0.359563, -0.007315}}],
    Polygon[{{0.462433, 0.356137, -0.005650},{0.463144, 0.355906, -0.003846},{
      0.463723, 0.359563, -0.003846},{0.462976, 0.359563, -0.005650}}],
    Polygon[{{0.463144, 0.355906, -0.003846},{0.463578, 0.355765, -0.001947},{
      0.464179, 0.359563, -0.001947},{0.463723, 0.359563, -0.003846}}],
    Polygon[{{0.463578, 0.355765, -0.001947},{0.463723, 0.355718, 0.000000},{
      0.464332, 0.359563, 0.000000},{0.464179, 0.359563, -0.001947}}],
    Polygon[{{0.463723, 0.355718, 0.000000},{0.463578, 0.355765, 0.001947},{
      0.464179, 0.359563, 0.001947},{0.464332, 0.359563, 0.000000}}],
    Polygon[{{0.463578, 0.355765, 0.001947},{0.463144, 0.355906, 0.003846},{
      0.463723, 0.359563, 0.003846},{0.464179, 0.359563, 0.001947}}],
    Polygon[{{0.463144, 0.355906, 0.003846},{0.462433, 0.356137, 0.005650},{
      0.462976, 0.359563, 0.005650},{0.463723, 0.359563, 0.003846}}],
    Polygon[{{0.462433, 0.356137, 0.005650},{0.461463, 0.356452, 0.007315},{
      0.461956, 0.359563, 0.007315},{0.462976, 0.359563, 0.005650}}],
    Polygon[{{0.461463, 0.356452, 0.007315},{0.460257, 0.356844, 0.008800},{
      0.460687, 0.359563, 0.008800},{0.461956, 0.359563, 0.007315}}],
    Polygon[{{0.460257, 0.356844, 0.008800},{0.458844, 0.357303, 0.010068},{
      0.459202, 0.359563, 0.010068},{0.460687, 0.359563, 0.008800}}],
    Polygon[{{0.458844, 0.357303, 0.010068},{0.457261, 0.357818, 0.011089},{
      0.457537, 0.359563, 0.011089},{0.459202, 0.359563, 0.010068}}],
    Polygon[{{0.457261, 0.357818, 0.011089},{0.455545, 0.358375, 0.011836},{
      0.455733, 0.359563, 0.011836},{0.457537, 0.359563, 0.011089}}],
    Polygon[{{0.455545, 0.358375, 0.011836},{0.453739, 0.358962, 0.012292},{
      0.453834, 0.359563, 0.012292},{0.455733, 0.359563, 0.011836}}],
    Polygon[{{0.435204, 0.422836, -0.009538},{0.436678, 0.422836, -0.009185},{
      0.436532, 0.423758, -0.009185},{0.435130, 0.423302, -0.009538}}],
    Polygon[{{0.436678, 0.422836, -0.009185},{0.438078, 0.422836, -0.008605},{
      0.437863, 0.424190, -0.008605},{0.436532, 0.423758, -0.009185}}],
    Polygon[{{0.438078, 0.422836, -0.008605},{0.439370, 0.422836, -0.007813},{
      0.439092, 0.424590, -0.007813},{0.437863, 0.424190, -0.008605}}],
    Polygon[{{0.439370, 0.422836, -0.007813},{0.440522, 0.422836, -0.006829},{
      0.440188, 0.424946, -0.006829},{0.439092, 0.424590, -0.007813}}],
    Polygon[{{0.440522, 0.422836, -0.006829},{0.441506, 0.422836, -0.005676},{
      0.441124, 0.425250, -0.005676},{0.440188, 0.424946, -0.006829}}],
    Polygon[{{0.441506, 0.422836, -0.005676},{0.442298, 0.422836, -0.004384},{
      0.441877, 0.425494, -0.004384},{0.441124, 0.425250, -0.005676}}],
    Polygon[{{0.442298, 0.422836, -0.004384},{0.442878, 0.422836, -0.002984},{
      0.442429, 0.425674, -0.002984},{0.441877, 0.425494, -0.004384}}],
    Polygon[{{0.442878, 0.422836, -0.002984},{0.443232, 0.422836, -0.001511},{
      0.442765, 0.425783, -0.001511},{0.442429, 0.425674, -0.002984}}],
    Polygon[{{0.443232, 0.422836, -0.001511},{0.443351, 0.422836, 0.000000},{
      0.442878, 0.425820, 0.000000},{0.442765, 0.425783, -0.001511}}],
    Polygon[{{0.443351, 0.422836, 0.000000},{0.443232, 0.422836, 0.001511},{
      0.442765, 0.425783, 0.001511},{0.442878, 0.425820, 0.000000}}],
    Polygon[{{0.443232, 0.422836, 0.001511},{0.442878, 0.422836, 0.002984},{
      0.442429, 0.425674, 0.002984},{0.442765, 0.425783, 0.001511}}],
    Polygon[{{0.442878, 0.422836, 0.002984},{0.442298, 0.422836, 0.004384},{
      0.441877, 0.425494, 0.004384},{0.442429, 0.425674, 0.002984}}],
    Polygon[{{0.442298, 0.422836, 0.004384},{0.441506, 0.422836, 0.005676},{
      0.441124, 0.425250, 0.005676},{0.441877, 0.425494, 0.004384}}],
    Polygon[{{0.441506, 0.422836, 0.005676},{0.440522, 0.422836, 0.006829},{
      0.440188, 0.424946, 0.006829},{0.441124, 0.425250, 0.005676}}],
    Polygon[{{0.440522, 0.422836, 0.006829},{0.439370, 0.422836, 0.007813},{
      0.439092, 0.424590, 0.007813},{0.440188, 0.424946, 0.006829}}],
    Polygon[{{0.439370, 0.422836, 0.007813},{0.438078, 0.422836, 0.008605},{
      0.437863, 0.424190, 0.008605},{0.439092, 0.424590, 0.007813}}],
    Polygon[{{0.438078, 0.422836, 0.008605},{0.436678, 0.422836, 0.009185},{
      0.436532, 0.423758, 0.009185},{0.437863, 0.424190, 0.008605}}],
    Polygon[{{0.436678, 0.422836, 0.009185},{0.435204, 0.422836, 0.009538},{
      0.435130, 0.423302, 0.009538},{0.436532, 0.423758, 0.009185}}],
    Polygon[{{0.435130, 0.423302, -0.009538},{0.436532, 0.423758, -0.009185},{
      0.436108, 0.424590, -0.009185},{0.434916, 0.423723, -0.009538}}],
    Polygon[{{0.436532, 0.423758, -0.009185},{0.437863, 0.424190, -0.008605},{
      0.437241, 0.425413, -0.008605},{0.436108, 0.424590, -0.009185}}],
    Polygon[{{0.437863, 0.424190, -0.008605},{0.439092, 0.424590, -0.007813},{
      0.438286, 0.426172, -0.007813},{0.437241, 0.425413, -0.008605}}],
    Polygon[{{0.439092, 0.424590, -0.007813},{0.440188, 0.424946, -0.006829},{
      0.439218, 0.426849, -0.006829},{0.438286, 0.426172, -0.007813}}],
    Polygon[{{0.440188, 0.424946, -0.006829},{0.441124, 0.425250, -0.005676},{
      0.440014, 0.427428, -0.005676},{0.439218, 0.426849, -0.006829}}],
    Polygon[{{0.441124, 0.425250, -0.005676},{0.441877, 0.425494, -0.004384},{
      0.440655, 0.427893, -0.004384},{0.440014, 0.427428, -0.005676}}],
    Polygon[{{0.441877, 0.425494, -0.004384},{0.442429, 0.425674, -0.002984},{
      0.441124, 0.428234, -0.002984},{0.440655, 0.427893, -0.004384}}],
    Polygon[{{0.442429, 0.425674, -0.002984},{0.442765, 0.425783, -0.001511},{
      0.441410, 0.428442, -0.001511},{0.441124, 0.428234, -0.002984}}],
    Polygon[{{0.442765, 0.425783, -0.001511},{0.442878, 0.425820, 0.000000},{
      0.441506, 0.428512, 0.000000},{0.441410, 0.428442, -0.001511}}],
    Polygon[{{0.442878, 0.425820, 0.000000},{0.442765, 0.425783, 0.001511},{
      0.441410, 0.428442, 0.001511},{0.441506, 0.428512, 0.000000}}],
    Polygon[{{0.442765, 0.425783, 0.001511},{0.442429, 0.425674, 0.002984},{
      0.441124, 0.428234, 0.002984},{0.441410, 0.428442, 0.001511}}],
    Polygon[{{0.442429, 0.425674, 0.002984},{0.441877, 0.425494, 0.004384},{
      0.440655, 0.427893, 0.004384},{0.441124, 0.428234, 0.002984}}],
    Polygon[{{0.441877, 0.425494, 0.004384},{0.441124, 0.425250, 0.005676},{
      0.440014, 0.427428, 0.005676},{0.440655, 0.427893, 0.004384}}],
    Polygon[{{0.441124, 0.425250, 0.005676},{0.440188, 0.424946, 0.006829},{
      0.439218, 0.426849, 0.006829},{0.440014, 0.427428, 0.005676}}],
    Polygon[{{0.440188, 0.424946, 0.006829},{0.439092, 0.424590, 0.007813},{
      0.438286, 0.426172, 0.007813},{0.439218, 0.426849, 0.006829}}],
    Polygon[{{0.439092, 0.424590, 0.007813},{0.437863, 0.424190, 0.008605},{
      0.437241, 0.425413, 0.008605},{0.438286, 0.426172, 0.007813}}],
    Polygon[{{0.437863, 0.424190, 0.008605},{0.436532, 0.423758, 0.009185},{
      0.436108, 0.424590, 0.009185},{0.437241, 0.425413, 0.008605}}],
    Polygon[{{0.436532, 0.423758, 0.009185},{0.435130, 0.423302, 0.009538},{
      0.434916, 0.423723, 0.009538},{0.436108, 0.424590, 0.009185}}],
    Polygon[{{0.434916, 0.423723, -0.009538},{0.436108, 0.424590, -0.009185},{
      0.435448, 0.425250, -0.009185},{0.434582, 0.424058, -0.009538}}],
    Polygon[{{0.436108, 0.424590, -0.009185},{0.437241, 0.425413, -0.008605},{
      0.436271, 0.426382, -0.008605},{0.435448, 0.425250, -0.009185}}],
    Polygon[{{0.437241, 0.425413, -0.008605},{0.438286, 0.426172, -0.007813},{
      0.437030, 0.427428, -0.007813},{0.436271, 0.426382, -0.008605}}],
    Polygon[{{0.438286, 0.426172, -0.007813},{0.439218, 0.426849, -0.006829},{
      0.437707, 0.428360, -0.006829},{0.437030, 0.427428, -0.007813}}],
    Polygon[{{0.439218, 0.426849, -0.006829},{0.440014, 0.427428, -0.005676},{
      0.438286, 0.429156, -0.005676},{0.437707, 0.428360, -0.006829}}],
    Polygon[{{0.440014, 0.427428, -0.005676},{0.440655, 0.427893, -0.004384},{
      0.438751, 0.429797, -0.004384},{0.438286, 0.429156, -0.005676}}],
    Polygon[{{0.440655, 0.427893, -0.004384},{0.441124, 0.428234, -0.002984},{
      0.439092, 0.430266, -0.002984},{0.438751, 0.429797, -0.004384}}],
    Polygon[{{0.441124, 0.428234, -0.002984},{0.441410, 0.428442, -0.001511},{
      0.439300, 0.430552, -0.001511},{0.439092, 0.430266, -0.002984}}],
    Polygon[{{0.441410, 0.428442, -0.001511},{0.441506, 0.428512, 0.000000},{
      0.439370, 0.430648, 0.000000},{0.439300, 0.430552, -0.001511}}],
    Polygon[{{0.441506, 0.428512, 0.000000},{0.441410, 0.428442, 0.001511},{
      0.439300, 0.430552, 0.001511},{0.439370, 0.430648, 0.000000}}],
    Polygon[{{0.441410, 0.428442, 0.001511},{0.441124, 0.428234, 0.002984},{
      0.439092, 0.430266, 0.002984},{0.439300, 0.430552, 0.001511}}],
    Polygon[{{0.441124, 0.428234, 0.002984},{0.440655, 0.427893, 0.004384},{
      0.438751, 0.429797, 0.004384},{0.439092, 0.430266, 0.002984}}],
    Polygon[{{0.440655, 0.427893, 0.004384},{0.440014, 0.427428, 0.005676},{
      0.438286, 0.429156, 0.005676},{0.438751, 0.429797, 0.004384}}],
    Polygon[{{0.440014, 0.427428, 0.005676},{0.439218, 0.426849, 0.006829},{
      0.437707, 0.428360, 0.006829},{0.438286, 0.429156, 0.005676}}],
    Polygon[{{0.439218, 0.426849, 0.006829},{0.438286, 0.426172, 0.007813},{
      0.437030, 0.427428, 0.007813},{0.437707, 0.428360, 0.006829}}],
    Polygon[{{0.438286, 0.426172, 0.007813},{0.437241, 0.425413, 0.008605},{
      0.436271, 0.426382, 0.008605},{0.437030, 0.427428, 0.007813}}],
    Polygon[{{0.437241, 0.425413, 0.008605},{0.436108, 0.424590, 0.009185},{
      0.435448, 0.425250, 0.009185},{0.436271, 0.426382, 0.008605}}],
    Polygon[{{0.436108, 0.424590, 0.009185},{0.434916, 0.423723, 0.009538},{
      0.434582, 0.424058, 0.009538},{0.435448, 0.425250, 0.009185}}],
    Polygon[{{0.434582, 0.424058, -0.009538},{0.435448, 0.425250, -0.009185},{
      0.434616, 0.425674, -0.009185},{0.434160, 0.424272, -0.009538}}],
    Polygon[{{0.435448, 0.425250, -0.009185},{0.436271, 0.426382, -0.008605},{
      0.435048, 0.427005, -0.008605},{0.434616, 0.425674, -0.009185}}],
    Polygon[{{0.436271, 0.426382, -0.008605},{0.437030, 0.427428, -0.007813},{
      0.435448, 0.428234, -0.007813},{0.435048, 0.427005, -0.008605}}],
    Polygon[{{0.437030, 0.427428, -0.007813},{0.437707, 0.428360, -0.006829},{
      0.435804, 0.429330, -0.006829},{0.435448, 0.428234, -0.007813}}],
    Polygon[{{0.437707, 0.428360, -0.006829},{0.438286, 0.429156, -0.005676},{
      0.436108, 0.430266, -0.005676},{0.435804, 0.429330, -0.006829}}],
    Polygon[{{0.438286, 0.429156, -0.005676},{0.438751, 0.429797, -0.004384},{
      0.436353, 0.431019, -0.004384},{0.436108, 0.430266, -0.005676}}],
    Polygon[{{0.438751, 0.429797, -0.004384},{0.439092, 0.430266, -0.002984},{
      0.436532, 0.431571, -0.002984},{0.436353, 0.431019, -0.004384}}],
    Polygon[{{0.439092, 0.430266, -0.002984},{0.439300, 0.430552, -0.001511},{
      0.436641, 0.431907, -0.001511},{0.436532, 0.431571, -0.002984}}],
    Polygon[{{0.439300, 0.430552, -0.001511},{0.439370, 0.430648, 0.000000},{
      0.436678, 0.432020, 0.000000},{0.436641, 0.431907, -0.001511}}],
    Polygon[{{0.439370, 0.430648, 0.000000},{0.439300, 0.430552, 0.001511},{
      0.436641, 0.431907, 0.001511},{0.436678, 0.432020, 0.000000}}],
    Polygon[{{0.439300, 0.430552, 0.001511},{0.439092, 0.430266, 0.002984},{
      0.436532, 0.431571, 0.002984},{0.436641, 0.431907, 0.001511}}],
    Polygon[{{0.439092, 0.430266, 0.002984},{0.438751, 0.429797, 0.004384},{
      0.436353, 0.431019, 0.004384},{0.436532, 0.431571, 0.002984}}],
    Polygon[{{0.438751, 0.429797, 0.004384},{0.438286, 0.429156, 0.005676},{
      0.436108, 0.430266, 0.005676},{0.436353, 0.431019, 0.004384}}],
    Polygon[{{0.438286, 0.429156, 0.005676},{0.437707, 0.428360, 0.006829},{
      0.435804, 0.429330, 0.006829},{0.436108, 0.430266, 0.005676}}],
    Polygon[{{0.437707, 0.428360, 0.006829},{0.437030, 0.427428, 0.007813},{
      0.435448, 0.428234, 0.007813},{0.435804, 0.429330, 0.006829}}],
    Polygon[{{0.437030, 0.427428, 0.007813},{0.436271, 0.426382, 0.008605},{
      0.435048, 0.427005, 0.008605},{0.435448, 0.428234, 0.007813}}],
    Polygon[{{0.436271, 0.426382, 0.008605},{0.435448, 0.425250, 0.009185},{
      0.434616, 0.425674, 0.009185},{0.435048, 0.427005, 0.008605}}],
    Polygon[{{0.435448, 0.425250, 0.009185},{0.434582, 0.424058, 0.009538},{
      0.434160, 0.424272, 0.009538},{0.434616, 0.425674, 0.009185}}],
    Polygon[{{0.434160, 0.424272, -0.009538},{0.434616, 0.425674, -0.009185},{
      0.433694, 0.425820, -0.009185},{0.433694, 0.424346, -0.009538}}],
    Polygon[{{0.434616, 0.425674, -0.009185},{0.435048, 0.427005, -0.008605},{
      0.433694, 0.427220, -0.008605},{0.433694, 0.425820, -0.009185}}],
    Polygon[{{0.435048, 0.427005, -0.008605},{0.435448, 0.428234, -0.007813},{
      0.433694, 0.428512, -0.007813},{0.433694, 0.427220, -0.008605}}],
    Polygon[{{0.435448, 0.428234, -0.007813},{0.435804, 0.429330, -0.006829},{
      0.433694, 0.429664, -0.006829},{0.433694, 0.428512, -0.007813}}],
    Polygon[{{0.435804, 0.429330, -0.006829},{0.436108, 0.430266, -0.005676},{
      0.433694, 0.430648, -0.005676},{0.433694, 0.429664, -0.006829}}],
    Polygon[{{0.436108, 0.430266, -0.005676},{0.436353, 0.431019, -0.004384},{
      0.433694, 0.431440, -0.004384},{0.433694, 0.430648, -0.005676}}],
    Polygon[{{0.436353, 0.431019, -0.004384},{0.436532, 0.431571, -0.002984},{
      0.433694, 0.432020, -0.002984},{0.433694, 0.431440, -0.004384}}],
    Polygon[{{0.436532, 0.431571, -0.002984},{0.436641, 0.431907, -0.001511},{
      0.433694, 0.432374, -0.001511},{0.433694, 0.432020, -0.002984}}],
    Polygon[{{0.436641, 0.431907, -0.001511},{0.436678, 0.432020, 0.000000},{
      0.433694, 0.432493, 0.000000},{0.433694, 0.432374, -0.001511}}],
    Polygon[{{0.436678, 0.432020, 0.000000},{0.436641, 0.431907, 0.001511},{
      0.433694, 0.432374, 0.001511},{0.433694, 0.432493, 0.000000}}],
    Polygon[{{0.436641, 0.431907, 0.001511},{0.436532, 0.431571, 0.002984},{
      0.433694, 0.432020, 0.002984},{0.433694, 0.432374, 0.001511}}],
    Polygon[{{0.436532, 0.431571, 0.002984},{0.436353, 0.431019, 0.004384},{
      0.433694, 0.431440, 0.004384},{0.433694, 0.432020, 0.002984}}],
    Polygon[{{0.436353, 0.431019, 0.004384},{0.436108, 0.430266, 0.005676},{
      0.433694, 0.430648, 0.005676},{0.433694, 0.431440, 0.004384}}],
    Polygon[{{0.436108, 0.430266, 0.005676},{0.435804, 0.429330, 0.006829},{
      0.433694, 0.429664, 0.006829},{0.433694, 0.430648, 0.005676}}],
    Polygon[{{0.435804, 0.429330, 0.006829},{0.435448, 0.428234, 0.007813},{
      0.433694, 0.428512, 0.007813},{0.433694, 0.429664, 0.006829}}],
    Polygon[{{0.435448, 0.428234, 0.007813},{0.435048, 0.427005, 0.008605},{
      0.433694, 0.427220, 0.008605},{0.433694, 0.428512, 0.007813}}],
    Polygon[{{0.435048, 0.427005, 0.008605},{0.434616, 0.425674, 0.009185},{
      0.433694, 0.425820, 0.009185},{0.433694, 0.427220, 0.008605}}],
    Polygon[{{0.434616, 0.425674, 0.009185},{0.434160, 0.424272, 0.009538},{
      0.433694, 0.424346, 0.009538},{0.433694, 0.425820, 0.009185}}],
    Polygon[{{0.433694, 0.424346, -0.009538},{0.433694, 0.425820, -0.009185},{
      0.432771, 0.425674, -0.009185},{0.433227, 0.424272, -0.009538}}],
    Polygon[{{0.433694, 0.425820, -0.009185},{0.433694, 0.427220, -0.008605},{
      0.432339, 0.427005, -0.008605},{0.432771, 0.425674, -0.009185}}],
    Polygon[{{0.433694, 0.427220, -0.008605},{0.433694, 0.428512, -0.007813},{
      0.431940, 0.428234, -0.007813},{0.432339, 0.427005, -0.008605}}],
    Polygon[{{0.433694, 0.428512, -0.007813},{0.433694, 0.429664, -0.006829},{
      0.431583, 0.429330, -0.006829},{0.431940, 0.428234, -0.007813}}],
    Polygon[{{0.433694, 0.429664, -0.006829},{0.433694, 0.430648, -0.005676},{
      0.431279, 0.430266, -0.005676},{0.431583, 0.429330, -0.006829}}],
    Polygon[{{0.433694, 0.430648, -0.005676},{0.433694, 0.431440, -0.004384},{
      0.431035, 0.431019, -0.004384},{0.431279, 0.430266, -0.005676}}],
    Polygon[{{0.433694, 0.431440, -0.004384},{0.433694, 0.432020, -0.002984},{
      0.430855, 0.431571, -0.002984},{0.431035, 0.431019, -0.004384}}],
    Polygon[{{0.433694, 0.432020, -0.002984},{0.433694, 0.432374, -0.001511},{
      0.430746, 0.431907, -0.001511},{0.430855, 0.431571, -0.002984}}],
    Polygon[{{0.433694, 0.432374, -0.001511},{0.433694, 0.432493, 0.000000},{
      0.430709, 0.432020, 0.000000},{0.430746, 0.431907, -0.001511}}],
    Polygon[{{0.433694, 0.432493, 0.000000},{0.433694, 0.432374, 0.001511},{
      0.430746, 0.431907, 0.001511},{0.430709, 0.432020, 0.000000}}],
    Polygon[{{0.433694, 0.432374, 0.001511},{0.433694, 0.432020, 0.002984},{
      0.430855, 0.431571, 0.002984},{0.430746, 0.431907, 0.001511}}],
    Polygon[{{0.433694, 0.432020, 0.002984},{0.433694, 0.431440, 0.004384},{
      0.431035, 0.431019, 0.004384},{0.430855, 0.431571, 0.002984}}],
    Polygon[{{0.433694, 0.431440, 0.004384},{0.433694, 0.430648, 0.005676},{
      0.431279, 0.430266, 0.005676},{0.431035, 0.431019, 0.004384}}],
    Polygon[{{0.433694, 0.430648, 0.005676},{0.433694, 0.429664, 0.006829},{
      0.431583, 0.429330, 0.006829},{0.431279, 0.430266, 0.005676}}],
    Polygon[{{0.433694, 0.429664, 0.006829},{0.433694, 0.428512, 0.007813},{
      0.431940, 0.428234, 0.007813},{0.431583, 0.429330, 0.006829}}],
    Polygon[{{0.433694, 0.428512, 0.007813},{0.433694, 0.427220, 0.008605},{
      0.432339, 0.427005, 0.008605},{0.431940, 0.428234, 0.007813}}],
    Polygon[{{0.433694, 0.427220, 0.008605},{0.433694, 0.425820, 0.009185},{
      0.432771, 0.425674, 0.009185},{0.432339, 0.427005, 0.008605}}],
    Polygon[{{0.433694, 0.425820, 0.009185},{0.433694, 0.424346, 0.009538},{
      0.433227, 0.424272, 0.009538},{0.432771, 0.425674, 0.009185}}],
    Polygon[{{0.433227, 0.424272, -0.009538},{0.432771, 0.425674, -0.009185},{
      0.431940, 0.425250, -0.009185},{0.432806, 0.424058, -0.009538}}],
    Polygon[{{0.432771, 0.425674, -0.009185},{0.432339, 0.427005, -0.008605},{
      0.431117, 0.426382, -0.008605},{0.431940, 0.425250, -0.009185}}],
    Polygon[{{0.432339, 0.427005, -0.008605},{0.431940, 0.428234, -0.007813},{
      0.430357, 0.427428, -0.007813},{0.431117, 0.426382, -0.008605}}],
    Polygon[{{0.431940, 0.428234, -0.007813},{0.431583, 0.429330, -0.006829},{
      0.429680, 0.428360, -0.006829},{0.430357, 0.427428, -0.007813}}],
    Polygon[{{0.431583, 0.429330, -0.006829},{0.431279, 0.430266, -0.005676},{
      0.429101, 0.429156, -0.005676},{0.429680, 0.428360, -0.006829}}],
    Polygon[{{0.431279, 0.430266, -0.005676},{0.431035, 0.431019, -0.004384},{
      0.428636, 0.429797, -0.004384},{0.429101, 0.429156, -0.005676}}],
    Polygon[{{0.431035, 0.431019, -0.004384},{0.430855, 0.431571, -0.002984},{
      0.428295, 0.430266, -0.002984},{0.428636, 0.429797, -0.004384}}],
    Polygon[{{0.430855, 0.431571, -0.002984},{0.430746, 0.431907, -0.001511},{
      0.428087, 0.430552, -0.001511},{0.428295, 0.430266, -0.002984}}],
    Polygon[{{0.430746, 0.431907, -0.001511},{0.430709, 0.432020, 0.000000},{
      0.428017, 0.430648, 0.000000},{0.428087, 0.430552, -0.001511}}],
    Polygon[{{0.430709, 0.432020, 0.000000},{0.430746, 0.431907, 0.001511},{
      0.428087, 0.430552, 0.001511},{0.428017, 0.430648, 0.000000}}],
    Polygon[{{0.430746, 0.431907, 0.001511},{0.430855, 0.431571, 0.002984},{
      0.428295, 0.430266, 0.002984},{0.428087, 0.430552, 0.001511}}],
    Polygon[{{0.430855, 0.431571, 0.002984},{0.431035, 0.431019, 0.004384},{
      0.428636, 0.429797, 0.004384},{0.428295, 0.430266, 0.002984}}],
    Polygon[{{0.431035, 0.431019, 0.004384},{0.431279, 0.430266, 0.005676},{
      0.429101, 0.429156, 0.005676},{0.428636, 0.429797, 0.004384}}],
    Polygon[{{0.431279, 0.430266, 0.005676},{0.431583, 0.429330, 0.006829},{
      0.429680, 0.428360, 0.006829},{0.429101, 0.429156, 0.005676}}],
    Polygon[{{0.431583, 0.429330, 0.006829},{0.431940, 0.428234, 0.007813},{
      0.430357, 0.427428, 0.007813},{0.429680, 0.428360, 0.006829}}],
    Polygon[{{0.431940, 0.428234, 0.007813},{0.432339, 0.427005, 0.008605},{
      0.431117, 0.426382, 0.008605},{0.430357, 0.427428, 0.007813}}],
    Polygon[{{0.432339, 0.427005, 0.008605},{0.432771, 0.425674, 0.009185},{
      0.431940, 0.425250, 0.009185},{0.431117, 0.426382, 0.008605}}],
    Polygon[{{0.432771, 0.425674, 0.009185},{0.433227, 0.424272, 0.009538},{
      0.432806, 0.424058, 0.009538},{0.431940, 0.425250, 0.009185}}],
    Polygon[{{0.432806, 0.424058, -0.009538},{0.431940, 0.425250, -0.009185},{
      0.431279, 0.424590, -0.009185},{0.432471, 0.423723, -0.009538}}],
    Polygon[{{0.431940, 0.425250, -0.009185},{0.431117, 0.426382, -0.008605},{
      0.430147, 0.425413, -0.008605},{0.431279, 0.424590, -0.009185}}],
    Polygon[{{0.431117, 0.426382, -0.008605},{0.430357, 0.427428, -0.007813},{
      0.429101, 0.426172, -0.007813},{0.430147, 0.425413, -0.008605}}],
    Polygon[{{0.430357, 0.427428, -0.007813},{0.429680, 0.428360, -0.006829},{
      0.428169, 0.426849, -0.006829},{0.429101, 0.426172, -0.007813}}],
    Polygon[{{0.429680, 0.428360, -0.006829},{0.429101, 0.429156, -0.005676},{
      0.427373, 0.427428, -0.005676},{0.428169, 0.426849, -0.006829}}],
    Polygon[{{0.429101, 0.429156, -0.005676},{0.428636, 0.429797, -0.004384},{
      0.426732, 0.427893, -0.004384},{0.427373, 0.427428, -0.005676}}],
    Polygon[{{0.428636, 0.429797, -0.004384},{0.428295, 0.430266, -0.002984},{
      0.426263, 0.428234, -0.002984},{0.426732, 0.427893, -0.004384}}],
    Polygon[{{0.428295, 0.430266, -0.002984},{0.428087, 0.430552, -0.001511},{
      0.425977, 0.428442, -0.001511},{0.426263, 0.428234, -0.002984}}],
    Polygon[{{0.428087, 0.430552, -0.001511},{0.428017, 0.430648, 0.000000},{
      0.425881, 0.428512, 0.000000},{0.425977, 0.428442, -0.001511}}],
    Polygon[{{0.428017, 0.430648, 0.000000},{0.428087, 0.430552, 0.001511},{
      0.425977, 0.428442, 0.001511},{0.425881, 0.428512, 0.000000}}],
    Polygon[{{0.428087, 0.430552, 0.001511},{0.428295, 0.430266, 0.002984},{
      0.426263, 0.428234, 0.002984},{0.425977, 0.428442, 0.001511}}],
    Polygon[{{0.428295, 0.430266, 0.002984},{0.428636, 0.429797, 0.004384},{
      0.426732, 0.427893, 0.004384},{0.426263, 0.428234, 0.002984}}],
    Polygon[{{0.428636, 0.429797, 0.004384},{0.429101, 0.429156, 0.005676},{
      0.427373, 0.427428, 0.005676},{0.426732, 0.427893, 0.004384}}],
    Polygon[{{0.429101, 0.429156, 0.005676},{0.429680, 0.428360, 0.006829},{
      0.428169, 0.426849, 0.006829},{0.427373, 0.427428, 0.005676}}],
    Polygon[{{0.429680, 0.428360, 0.006829},{0.430357, 0.427428, 0.007813},{
      0.429101, 0.426172, 0.007813},{0.428169, 0.426849, 0.006829}}],
    Polygon[{{0.430357, 0.427428, 0.007813},{0.431117, 0.426382, 0.008605},{
      0.430147, 0.425413, 0.008605},{0.429101, 0.426172, 0.007813}}],
    Polygon[{{0.431117, 0.426382, 0.008605},{0.431940, 0.425250, 0.009185},{
      0.431279, 0.424590, 0.009185},{0.430147, 0.425413, 0.008605}}],
    Polygon[{{0.431940, 0.425250, 0.009185},{0.432806, 0.424058, 0.009538},{
      0.432471, 0.423723, 0.009538},{0.431279, 0.424590, 0.009185}}],
    Polygon[{{0.432471, 0.423723, -0.009538},{0.431279, 0.424590, -0.009185},{
      0.430855, 0.423758, -0.009185},{0.432257, 0.423302, -0.009538}}],
    Polygon[{{0.431279, 0.424590, -0.009185},{0.430147, 0.425413, -0.008605},{
      0.429524, 0.424190, -0.008605},{0.430855, 0.423758, -0.009185}}],
    Polygon[{{0.430147, 0.425413, -0.008605},{0.429101, 0.426172, -0.007813},{
      0.428295, 0.424590, -0.007813},{0.429524, 0.424190, -0.008605}}],
    Polygon[{{0.429101, 0.426172, -0.007813},{0.428169, 0.426849, -0.006829},{
      0.427199, 0.424946, -0.006829},{0.428295, 0.424590, -0.007813}}],
    Polygon[{{0.428169, 0.426849, -0.006829},{0.427373, 0.427428, -0.005676},{
      0.426263, 0.425250, -0.005676},{0.427199, 0.424946, -0.006829}}],
    Polygon[{{0.427373, 0.427428, -0.005676},{0.426732, 0.427893, -0.004384},{
      0.425510, 0.425494, -0.004384},{0.426263, 0.425250, -0.005676}}],
    Polygon[{{0.426732, 0.427893, -0.004384},{0.426263, 0.428234, -0.002984},{
      0.424959, 0.425674, -0.002984},{0.425510, 0.425494, -0.004384}}],
    Polygon[{{0.426263, 0.428234, -0.002984},{0.425977, 0.428442, -0.001511},{
      0.424622, 0.425783, -0.001511},{0.424959, 0.425674, -0.002984}}],
    Polygon[{{0.425977, 0.428442, -0.001511},{0.425881, 0.428512, 0.000000},{
      0.424509, 0.425820, 0.000000},{0.424622, 0.425783, -0.001511}}],
    Polygon[{{0.425881, 0.428512, 0.000000},{0.425977, 0.428442, 0.001511},{
      0.424622, 0.425783, 0.001511},{0.424509, 0.425820, 0.000000}}],
    Polygon[{{0.425977, 0.428442, 0.001511},{0.426263, 0.428234, 0.002984},{
      0.424959, 0.425674, 0.002984},{0.424622, 0.425783, 0.001511}}],
    Polygon[{{0.426263, 0.428234, 0.002984},{0.426732, 0.427893, 0.004384},{
      0.425510, 0.425494, 0.004384},{0.424959, 0.425674, 0.002984}}],
    Polygon[{{0.426732, 0.427893, 0.004384},{0.427373, 0.427428, 0.005676},{
      0.426263, 0.425250, 0.005676},{0.425510, 0.425494, 0.004384}}],
    Polygon[{{0.427373, 0.427428, 0.005676},{0.428169, 0.426849, 0.006829},{
      0.427199, 0.424946, 0.006829},{0.426263, 0.425250, 0.005676}}],
    Polygon[{{0.428169, 0.426849, 0.006829},{0.429101, 0.426172, 0.007813},{
      0.428295, 0.424590, 0.007813},{0.427199, 0.424946, 0.006829}}],
    Polygon[{{0.429101, 0.426172, 0.007813},{0.430147, 0.425413, 0.008605},{
      0.429524, 0.424190, 0.008605},{0.428295, 0.424590, 0.007813}}],
    Polygon[{{0.430147, 0.425413, 0.008605},{0.431279, 0.424590, 0.009185},{
      0.430855, 0.423758, 0.009185},{0.429524, 0.424190, 0.008605}}],
    Polygon[{{0.431279, 0.424590, 0.009185},{0.432471, 0.423723, 0.009538},{
      0.432257, 0.423302, 0.009538},{0.430855, 0.423758, 0.009185}}],
    Polygon[{{0.432257, 0.423302, -0.009538},{0.430855, 0.423758, -0.009185},{
      0.430709, 0.422836, -0.009185},{0.432183, 0.422836, -0.009538}}],
    Polygon[{{0.430855, 0.423758, -0.009185},{0.429524, 0.424190, -0.008605},{
      0.429309, 0.422836, -0.008605},{0.430709, 0.422836, -0.009185}}],
    Polygon[{{0.429524, 0.424190, -0.008605},{0.428295, 0.424590, -0.007813},{
      0.428017, 0.422836, -0.007813},{0.429309, 0.422836, -0.008605}}],
    Polygon[{{0.428295, 0.424590, -0.007813},{0.427199, 0.424946, -0.006829},{
      0.426865, 0.422836, -0.006829},{0.428017, 0.422836, -0.007813}}],
    Polygon[{{0.427199, 0.424946, -0.006829},{0.426263, 0.425250, -0.005676},{
      0.425881, 0.422836, -0.005676},{0.426865, 0.422836, -0.006829}}],
    Polygon[{{0.426263, 0.425250, -0.005676},{0.425510, 0.425494, -0.004384},{
      0.425089, 0.422836, -0.004384},{0.425881, 0.422836, -0.005676}}],
    Polygon[{{0.425510, 0.425494, -0.004384},{0.424959, 0.425674, -0.002984},{
      0.424509, 0.422836, -0.002984},{0.425089, 0.422836, -0.004384}}],
    Polygon[{{0.424959, 0.425674, -0.002984},{0.424622, 0.425783, -0.001511},{
      0.424155, 0.422836, -0.001511},{0.424509, 0.422836, -0.002984}}],
    Polygon[{{0.424622, 0.425783, -0.001511},{0.424509, 0.425820, 0.000000},{
      0.424036, 0.422836, 0.000000},{0.424155, 0.422836, -0.001511}}],
    Polygon[{{0.424509, 0.425820, 0.000000},{0.424622, 0.425783, 0.001511},{
      0.424155, 0.422836, 0.001511},{0.424036, 0.422836, 0.000000}}],
    Polygon[{{0.424622, 0.425783, 0.001511},{0.424959, 0.425674, 0.002984},{
      0.424509, 0.422836, 0.002984},{0.424155, 0.422836, 0.001511}}],
    Polygon[{{0.424959, 0.425674, 0.002984},{0.425510, 0.425494, 0.004384},{
      0.425089, 0.422836, 0.004384},{0.424509, 0.422836, 0.002984}}],
    Polygon[{{0.425510, 0.425494, 0.004384},{0.426263, 0.425250, 0.005676},{
      0.425881, 0.422836, 0.005676},{0.425089, 0.422836, 0.004384}}],
    Polygon[{{0.426263, 0.425250, 0.005676},{0.427199, 0.424946, 0.006829},{
      0.426865, 0.422836, 0.006829},{0.425881, 0.422836, 0.005676}}],
    Polygon[{{0.427199, 0.424946, 0.006829},{0.428295, 0.424590, 0.007813},{
      0.428017, 0.422836, 0.007813},{0.426865, 0.422836, 0.006829}}],
    Polygon[{{0.428295, 0.424590, 0.007813},{0.429524, 0.424190, 0.008605},{
      0.429309, 0.422836, 0.008605},{0.428017, 0.422836, 0.007813}}],
    Polygon[{{0.429524, 0.424190, 0.008605},{0.430855, 0.423758, 0.009185},{
      0.430709, 0.422836, 0.009185},{0.429309, 0.422836, 0.008605}}],
    Polygon[{{0.430855, 0.423758, 0.009185},{0.432257, 0.423302, 0.009538},{
      0.432183, 0.422836, 0.009538},{0.430709, 0.422836, 0.009185}}],
    Polygon[{{0.432183, 0.422836, -0.009538},{0.430709, 0.422836, -0.009185},{
      0.430855, 0.421913, -0.009185},{0.432257, 0.422369, -0.009538}}],
    Polygon[{{0.430709, 0.422836, -0.009185},{0.429309, 0.422836, -0.008605},{
      0.429524, 0.421481, -0.008605},{0.430855, 0.421913, -0.009185}}],
    Polygon[{{0.429309, 0.422836, -0.008605},{0.428017, 0.422836, -0.007813},{
      0.428295, 0.421081, -0.007813},{0.429524, 0.421481, -0.008605}}],
    Polygon[{{0.428017, 0.422836, -0.007813},{0.426865, 0.422836, -0.006829},{
      0.427199, 0.420725, -0.006829},{0.428295, 0.421081, -0.007813}}],
    Polygon[{{0.426865, 0.422836, -0.006829},{0.425881, 0.422836, -0.005676},{
      0.426263, 0.420421, -0.005676},{0.427199, 0.420725, -0.006829}}],
    Polygon[{{0.425881, 0.422836, -0.005676},{0.425089, 0.422836, -0.004384},{
      0.425510, 0.420177, -0.004384},{0.426263, 0.420421, -0.005676}}],
    Polygon[{{0.425089, 0.422836, -0.004384},{0.424509, 0.422836, -0.002984},{
      0.424959, 0.419997, -0.002984},{0.425510, 0.420177, -0.004384}}],
    Polygon[{{0.424509, 0.422836, -0.002984},{0.424155, 0.422836, -0.001511},{
      0.424622, 0.419888, -0.001511},{0.424959, 0.419997, -0.002984}}],
    Polygon[{{0.424155, 0.422836, -0.001511},{0.424036, 0.422836, 0.000000},{
      0.424509, 0.419851, 0.000000},{0.424622, 0.419888, -0.001511}}],
    Polygon[{{0.424036, 0.422836, 0.000000},{0.424155, 0.422836, 0.001511},{
      0.424622, 0.419888, 0.001511},{0.424509, 0.419851, 0.000000}}],
    Polygon[{{0.424155, 0.422836, 0.001511},{0.424509, 0.422836, 0.002984},{
      0.424959, 0.419997, 0.002984},{0.424622, 0.419888, 0.001511}}],
    Polygon[{{0.424509, 0.422836, 0.002984},{0.425089, 0.422836, 0.004384},{
      0.425510, 0.420177, 0.004384},{0.424959, 0.419997, 0.002984}}],
    Polygon[{{0.425089, 0.422836, 0.004384},{0.425881, 0.422836, 0.005676},{
      0.426263, 0.420421, 0.005676},{0.425510, 0.420177, 0.004384}}],
    Polygon[{{0.425881, 0.422836, 0.005676},{0.426865, 0.422836, 0.006829},{
      0.427199, 0.420725, 0.006829},{0.426263, 0.420421, 0.005676}}],
    Polygon[{{0.426865, 0.422836, 0.006829},{0.428017, 0.422836, 0.007813},{
      0.428295, 0.421081, 0.007813},{0.427199, 0.420725, 0.006829}}],
    Polygon[{{0.428017, 0.422836, 0.007813},{0.429309, 0.422836, 0.008605},{
      0.429524, 0.421481, 0.008605},{0.428295, 0.421081, 0.007813}}],
    Polygon[{{0.429309, 0.422836, 0.008605},{0.430709, 0.422836, 0.009185},{
      0.430855, 0.421913, 0.009185},{0.429524, 0.421481, 0.008605}}],
    Polygon[{{0.430709, 0.422836, 0.009185},{0.432183, 0.422836, 0.009538},{
      0.432257, 0.422369, 0.009538},{0.430855, 0.421913, 0.009185}}],
    Polygon[{{0.432257, 0.422369, -0.009538},{0.430855, 0.421913, -0.009185},{
      0.431279, 0.421081, -0.009185},{0.432471, 0.421948, -0.009538}}],
    Polygon[{{0.430855, 0.421913, -0.009185},{0.429524, 0.421481, -0.008605},{
      0.430147, 0.420259, -0.008605},{0.431279, 0.421081, -0.009185}}],
    Polygon[{{0.429524, 0.421481, -0.008605},{0.428295, 0.421081, -0.007813},{
      0.429101, 0.419499, -0.007813},{0.430147, 0.420259, -0.008605}}],
    Polygon[{{0.428295, 0.421081, -0.007813},{0.427199, 0.420725, -0.006829},{
      0.428169, 0.418822, -0.006829},{0.429101, 0.419499, -0.007813}}],
    Polygon[{{0.427199, 0.420725, -0.006829},{0.426263, 0.420421, -0.005676},{
      0.427373, 0.418243, -0.005676},{0.428169, 0.418822, -0.006829}}],
    Polygon[{{0.426263, 0.420421, -0.005676},{0.425510, 0.420177, -0.004384},{
      0.426732, 0.417778, -0.004384},{0.427373, 0.418243, -0.005676}}],
    Polygon[{{0.425510, 0.420177, -0.004384},{0.424959, 0.419997, -0.002984},{
      0.426263, 0.417437, -0.002984},{0.426732, 0.417778, -0.004384}}],
    Polygon[{{0.424959, 0.419997, -0.002984},{0.424622, 0.419888, -0.001511},{
      0.425977, 0.417229, -0.001511},{0.426263, 0.417437, -0.002984}}],
    Polygon[{{0.424622, 0.419888, -0.001511},{0.424509, 0.419851, 0.000000},{
      0.425881, 0.417159, 0.000000},{0.425977, 0.417229, -0.001511}}],
    Polygon[{{0.424509, 0.419851, 0.000000},{0.424622, 0.419888, 0.001511},{
      0.425977, 0.417229, 0.001511},{0.425881, 0.417159, 0.000000}}],
    Polygon[{{0.424622, 0.419888, 0.001511},{0.424959, 0.419997, 0.002984},{
      0.426263, 0.417437, 0.002984},{0.425977, 0.417229, 0.001511}}],
    Polygon[{{0.424959, 0.419997, 0.002984},{0.425510, 0.420177, 0.004384},{
      0.426732, 0.417778, 0.004384},{0.426263, 0.417437, 0.002984}}],
    Polygon[{{0.425510, 0.420177, 0.004384},{0.426263, 0.420421, 0.005676},{
      0.427373, 0.418243, 0.005676},{0.426732, 0.417778, 0.004384}}],
    Polygon[{{0.426263, 0.420421, 0.005676},{0.427199, 0.420725, 0.006829},{
      0.428169, 0.418822, 0.006829},{0.427373, 0.418243, 0.005676}}],
    Polygon[{{0.427199, 0.420725, 0.006829},{0.428295, 0.421081, 0.007813},{
      0.429101, 0.419499, 0.007813},{0.428169, 0.418822, 0.006829}}],
    Polygon[{{0.428295, 0.421081, 0.007813},{0.429524, 0.421481, 0.008605},{
      0.430147, 0.420259, 0.008605},{0.429101, 0.419499, 0.007813}}],
    Polygon[{{0.429524, 0.421481, 0.008605},{0.430855, 0.421913, 0.009185},{
      0.431279, 0.421081, 0.009185},{0.430147, 0.420259, 0.008605}}],
    Polygon[{{0.430855, 0.421913, 0.009185},{0.432257, 0.422369, 0.009538},{
      0.432471, 0.421948, 0.009538},{0.431279, 0.421081, 0.009185}}],
    Polygon[{{0.432471, 0.421948, -0.009538},{0.431279, 0.421081, -0.009185},{
      0.431940, 0.420421, -0.009185},{0.432806, 0.421613, -0.009538}}],
    Polygon[{{0.431279, 0.421081, -0.009185},{0.430147, 0.420259, -0.008605},{
      0.431117, 0.419289, -0.008605},{0.431940, 0.420421, -0.009185}}],
    Polygon[{{0.430147, 0.420259, -0.008605},{0.429101, 0.419499, -0.007813},{
      0.430357, 0.418243, -0.007813},{0.431117, 0.419289, -0.008605}}],
    Polygon[{{0.429101, 0.419499, -0.007813},{0.428169, 0.418822, -0.006829},{
      0.429680, 0.417311, -0.006829},{0.430357, 0.418243, -0.007813}}],
    Polygon[{{0.428169, 0.418822, -0.006829},{0.427373, 0.418243, -0.005676},{
      0.429101, 0.416515, -0.005676},{0.429680, 0.417311, -0.006829}}],
    Polygon[{{0.427373, 0.418243, -0.005676},{0.426732, 0.417778, -0.004384},{
      0.428636, 0.415874, -0.004384},{0.429101, 0.416515, -0.005676}}],
    Polygon[{{0.426732, 0.417778, -0.004384},{0.426263, 0.417437, -0.002984},{
      0.428295, 0.415405, -0.002984},{0.428636, 0.415874, -0.004384}}],
    Polygon[{{0.426263, 0.417437, -0.002984},{0.425977, 0.417229, -0.001511},{
      0.428087, 0.415119, -0.001511},{0.428295, 0.415405, -0.002984}}],
    Polygon[{{0.425977, 0.417229, -0.001511},{0.425881, 0.417159, 0.000000},{
      0.428017, 0.415023, 0.000000},{0.428087, 0.415119, -0.001511}}],
    Polygon[{{0.425881, 0.417159, 0.000000},{0.425977, 0.417229, 0.001511},{
      0.428087, 0.415119, 0.001511},{0.428017, 0.415023, 0.000000}}],
    Polygon[{{0.425977, 0.417229, 0.001511},{0.426263, 0.417437, 0.002984},{
      0.428295, 0.415405, 0.002984},{0.428087, 0.415119, 0.001511}}],
    Polygon[{{0.426263, 0.417437, 0.002984},{0.426732, 0.417778, 0.004384},{
      0.428636, 0.415874, 0.004384},{0.428295, 0.415405, 0.002984}}],
    Polygon[{{0.426732, 0.417778, 0.004384},{0.427373, 0.418243, 0.005676},{
      0.429101, 0.416515, 0.005676},{0.428636, 0.415874, 0.004384}}],
    Polygon[{{0.427373, 0.418243, 0.005676},{0.428169, 0.418822, 0.006829},{
      0.429680, 0.417311, 0.006829},{0.429101, 0.416515, 0.005676}}],
    Polygon[{{0.428169, 0.418822, 0.006829},{0.429101, 0.419499, 0.007813},{
      0.430357, 0.418243, 0.007813},{0.429680, 0.417311, 0.006829}}],
    Polygon[{{0.429101, 0.419499, 0.007813},{0.430147, 0.420259, 0.008605},{
      0.431117, 0.419289, 0.008605},{0.430357, 0.418243, 0.007813}}],
    Polygon[{{0.430147, 0.420259, 0.008605},{0.431279, 0.421081, 0.009185},{
      0.431940, 0.420421, 0.009185},{0.431117, 0.419289, 0.008605}}],
    Polygon[{{0.431279, 0.421081, 0.009185},{0.432471, 0.421948, 0.009538},{
      0.432806, 0.421613, 0.009538},{0.431940, 0.420421, 0.009185}}],
    Polygon[{{0.432806, 0.421613, -0.009538},{0.431940, 0.420421, -0.009185},{
      0.432771, 0.419997, -0.009185},{0.433227, 0.421399, -0.009538}}],
    Polygon[{{0.431940, 0.420421, -0.009185},{0.431117, 0.419289, -0.008605},{
      0.432339, 0.418666, -0.008605},{0.432771, 0.419997, -0.009185}}],
    Polygon[{{0.431117, 0.419289, -0.008605},{0.430357, 0.418243, -0.007813},{
      0.431940, 0.417437, -0.007813},{0.432339, 0.418666, -0.008605}}],
    Polygon[{{0.430357, 0.418243, -0.007813},{0.429680, 0.417311, -0.006829},{
      0.431583, 0.416341, -0.006829},{0.431940, 0.417437, -0.007813}}],
    Polygon[{{0.429680, 0.417311, -0.006829},{0.429101, 0.416515, -0.005676},{
      0.431279, 0.415405, -0.005676},{0.431583, 0.416341, -0.006829}}],
    Polygon[{{0.429101, 0.416515, -0.005676},{0.428636, 0.415874, -0.004384},{
      0.431035, 0.414652, -0.004384},{0.431279, 0.415405, -0.005676}}],
    Polygon[{{0.428636, 0.415874, -0.004384},{0.428295, 0.415405, -0.002984},{
      0.430855, 0.414101, -0.002984},{0.431035, 0.414652, -0.004384}}],
    Polygon[{{0.428295, 0.415405, -0.002984},{0.428087, 0.415119, -0.001511},{
      0.430746, 0.413764, -0.001511},{0.430855, 0.414101, -0.002984}}],
    Polygon[{{0.428087, 0.415119, -0.001511},{0.428017, 0.415023, 0.000000},{
      0.430709, 0.413651, 0.000000},{0.430746, 0.413764, -0.001511}}],
    Polygon[{{0.428017, 0.415023, 0.000000},{0.428087, 0.415119, 0.001511},{
      0.430746, 0.413764, 0.001511},{0.430709, 0.413651, 0.000000}}],
    Polygon[{{0.428087, 0.415119, 0.001511},{0.428295, 0.415405, 0.002984},{
      0.430855, 0.414101, 0.002984},{0.430746, 0.413764, 0.001511}}],
    Polygon[{{0.428295, 0.415405, 0.002984},{0.428636, 0.415874, 0.004384},{
      0.431035, 0.414652, 0.004384},{0.430855, 0.414101, 0.002984}}],
    Polygon[{{0.428636, 0.415874, 0.004384},{0.429101, 0.416515, 0.005676},{
      0.431279, 0.415405, 0.005676},{0.431035, 0.414652, 0.004384}}],
    Polygon[{{0.429101, 0.416515, 0.005676},{0.429680, 0.417311, 0.006829},{
      0.431583, 0.416341, 0.006829},{0.431279, 0.415405, 0.005676}}],
    Polygon[{{0.429680, 0.417311, 0.006829},{0.430357, 0.418243, 0.007813},{
      0.431940, 0.417437, 0.007813},{0.431583, 0.416341, 0.006829}}],
    Polygon[{{0.430357, 0.418243, 0.007813},{0.431117, 0.419289, 0.008605},{
      0.432339, 0.418666, 0.008605},{0.431940, 0.417437, 0.007813}}],
    Polygon[{{0.431117, 0.419289, 0.008605},{0.431940, 0.420421, 0.009185},{
      0.432771, 0.419997, 0.009185},{0.432339, 0.418666, 0.008605}}],
    Polygon[{{0.431940, 0.420421, 0.009185},{0.432806, 0.421613, 0.009538},{
      0.433227, 0.421399, 0.009538},{0.432771, 0.419997, 0.009185}}],
    Polygon[{{0.433227, 0.421399, -0.009538},{0.432771, 0.419997, -0.009185},{
      0.433694, 0.419851, -0.009185},{0.433694, 0.421325, -0.009538}}],
    Polygon[{{0.432771, 0.419997, -0.009185},{0.432339, 0.418666, -0.008605},{
      0.433694, 0.418451, -0.008605},{0.433694, 0.419851, -0.009185}}],
    Polygon[{{0.432339, 0.418666, -0.008605},{0.431940, 0.417437, -0.007813},{
      0.433694, 0.417159, -0.007813},{0.433694, 0.418451, -0.008605}}],
    Polygon[{{0.431940, 0.417437, -0.007813},{0.431583, 0.416341, -0.006829},{
      0.433694, 0.416007, -0.006829},{0.433694, 0.417159, -0.007813}}],
    Polygon[{{0.431583, 0.416341, -0.006829},{0.431279, 0.415405, -0.005676},{
      0.433694, 0.415023, -0.005676},{0.433694, 0.416007, -0.006829}}],
    Polygon[{{0.431279, 0.415405, -0.005676},{0.431035, 0.414652, -0.004384},{
      0.433694, 0.414231, -0.004384},{0.433694, 0.415023, -0.005676}}],
    Polygon[{{0.431035, 0.414652, -0.004384},{0.430855, 0.414101, -0.002984},{
      0.433694, 0.413651, -0.002984},{0.433694, 0.414231, -0.004384}}],
    Polygon[{{0.430855, 0.414101, -0.002984},{0.430746, 0.413764, -0.001511},{
      0.433694, 0.413297, -0.001511},{0.433694, 0.413651, -0.002984}}],
    Polygon[{{0.430746, 0.413764, -0.001511},{0.430709, 0.413651, 0.000000},{
      0.433694, 0.413178, 0.000000},{0.433694, 0.413297, -0.001511}}],
    Polygon[{{0.430709, 0.413651, 0.000000},{0.430746, 0.413764, 0.001511},{
      0.433694, 0.413297, 0.001511},{0.433694, 0.413178, 0.000000}}],
    Polygon[{{0.430746, 0.413764, 0.001511},{0.430855, 0.414101, 0.002984},{
      0.433694, 0.413651, 0.002984},{0.433694, 0.413297, 0.001511}}],
    Polygon[{{0.430855, 0.414101, 0.002984},{0.431035, 0.414652, 0.004384},{
      0.433694, 0.414231, 0.004384},{0.433694, 0.413651, 0.002984}}],
    Polygon[{{0.431035, 0.414652, 0.004384},{0.431279, 0.415405, 0.005676},{
      0.433694, 0.415023, 0.005676},{0.433694, 0.414231, 0.004384}}],
    Polygon[{{0.431279, 0.415405, 0.005676},{0.431583, 0.416341, 0.006829},{
      0.433694, 0.416007, 0.006829},{0.433694, 0.415023, 0.005676}}],
    Polygon[{{0.431583, 0.416341, 0.006829},{0.431940, 0.417437, 0.007813},{
      0.433694, 0.417159, 0.007813},{0.433694, 0.416007, 0.006829}}],
    Polygon[{{0.431940, 0.417437, 0.007813},{0.432339, 0.418666, 0.008605},{
      0.433694, 0.418451, 0.008605},{0.433694, 0.417159, 0.007813}}],
    Polygon[{{0.432339, 0.418666, 0.008605},{0.432771, 0.419997, 0.009185},{
      0.433694, 0.419851, 0.009185},{0.433694, 0.418451, 0.008605}}],
    Polygon[{{0.432771, 0.419997, 0.009185},{0.433227, 0.421399, 0.009538},{
      0.433694, 0.421325, 0.009538},{0.433694, 0.419851, 0.009185}}],
    Polygon[{{0.433694, 0.421325, -0.009538},{0.433694, 0.419851, -0.009185},{
      0.434616, 0.419997, -0.009185},{0.434160, 0.421399, -0.009538}}],
    Polygon[{{0.433694, 0.419851, -0.009185},{0.433694, 0.418451, -0.008605},{
      0.435048, 0.418666, -0.008605},{0.434616, 0.419997, -0.009185}}],
    Polygon[{{0.433694, 0.418451, -0.008605},{0.433694, 0.417159, -0.007813},{
      0.435448, 0.417437, -0.007813},{0.435048, 0.418666, -0.008605}}],
    Polygon[{{0.433694, 0.417159, -0.007813},{0.433694, 0.416007, -0.006829},{
      0.435804, 0.416341, -0.006829},{0.435448, 0.417437, -0.007813}}],
    Polygon[{{0.433694, 0.416007, -0.006829},{0.433694, 0.415023, -0.005676},{
      0.436108, 0.415405, -0.005676},{0.435804, 0.416341, -0.006829}}],
    Polygon[{{0.433694, 0.415023, -0.005676},{0.433694, 0.414231, -0.004384},{
      0.436353, 0.414652, -0.004384},{0.436108, 0.415405, -0.005676}}],
    Polygon[{{0.433694, 0.414231, -0.004384},{0.433694, 0.413651, -0.002984},{
      0.436532, 0.414101, -0.002984},{0.436353, 0.414652, -0.004384}}],
    Polygon[{{0.433694, 0.413651, -0.002984},{0.433694, 0.413297, -0.001511},{
      0.436641, 0.413764, -0.001511},{0.436532, 0.414101, -0.002984}}],
    Polygon[{{0.433694, 0.413297, -0.001511},{0.433694, 0.413178, 0.000000},{
      0.436678, 0.413651, 0.000000},{0.436641, 0.413764, -0.001511}}],
    Polygon[{{0.433694, 0.413178, 0.000000},{0.433694, 0.413297, 0.001511},{
      0.436641, 0.413764, 0.001511},{0.436678, 0.413651, 0.000000}}],
    Polygon[{{0.433694, 0.413297, 0.001511},{0.433694, 0.413651, 0.002984},{
      0.436532, 0.414101, 0.002984},{0.436641, 0.413764, 0.001511}}],
    Polygon[{{0.433694, 0.413651, 0.002984},{0.433694, 0.414231, 0.004384},{
      0.436353, 0.414652, 0.004384},{0.436532, 0.414101, 0.002984}}],
    Polygon[{{0.433694, 0.414231, 0.004384},{0.433694, 0.415023, 0.005676},{
      0.436108, 0.415405, 0.005676},{0.436353, 0.414652, 0.004384}}],
    Polygon[{{0.433694, 0.415023, 0.005676},{0.433694, 0.416007, 0.006829},{
      0.435804, 0.416341, 0.006829},{0.436108, 0.415405, 0.005676}}],
    Polygon[{{0.433694, 0.416007, 0.006829},{0.433694, 0.417159, 0.007813},{
      0.435448, 0.417437, 0.007813},{0.435804, 0.416341, 0.006829}}],
    Polygon[{{0.433694, 0.417159, 0.007813},{0.433694, 0.418451, 0.008605},{
      0.435048, 0.418666, 0.008605},{0.435448, 0.417437, 0.007813}}],
    Polygon[{{0.433694, 0.418451, 0.008605},{0.433694, 0.419851, 0.009185},{
      0.434616, 0.419997, 0.009185},{0.435048, 0.418666, 0.008605}}],
    Polygon[{{0.433694, 0.419851, 0.009185},{0.433694, 0.421325, 0.009538},{
      0.434160, 0.421399, 0.009538},{0.434616, 0.419997, 0.009185}}],
    Polygon[{{0.434160, 0.421399, -0.009538},{0.434616, 0.419997, -0.009185},{
      0.435448, 0.420421, -0.009185},{0.434582, 0.421613, -0.009538}}],
    Polygon[{{0.434616, 0.419997, -0.009185},{0.435048, 0.418666, -0.008605},{
      0.436271, 0.419289, -0.008605},{0.435448, 0.420421, -0.009185}}],
    Polygon[{{0.435048, 0.418666, -0.008605},{0.435448, 0.417437, -0.007813},{
      0.437030, 0.418243, -0.007813},{0.436271, 0.419289, -0.008605}}],
    Polygon[{{0.435448, 0.417437, -0.007813},{0.435804, 0.416341, -0.006829},{
      0.437707, 0.417311, -0.006829},{0.437030, 0.418243, -0.007813}}],
    Polygon[{{0.435804, 0.416341, -0.006829},{0.436108, 0.415405, -0.005676},{
      0.438286, 0.416515, -0.005676},{0.437707, 0.417311, -0.006829}}],
    Polygon[{{0.436108, 0.415405, -0.005676},{0.436353, 0.414652, -0.004384},{
      0.438751, 0.415874, -0.004384},{0.438286, 0.416515, -0.005676}}],
    Polygon[{{0.436353, 0.414652, -0.004384},{0.436532, 0.414101, -0.002984},{
      0.439092, 0.415405, -0.002984},{0.438751, 0.415874, -0.004384}}],
    Polygon[{{0.436532, 0.414101, -0.002984},{0.436641, 0.413764, -0.001511},{
      0.439300, 0.415119, -0.001511},{0.439092, 0.415405, -0.002984}}],
    Polygon[{{0.436641, 0.413764, -0.001511},{0.436678, 0.413651, 0.000000},{
      0.439370, 0.415023, 0.000000},{0.439300, 0.415119, -0.001511}}],
    Polygon[{{0.436678, 0.413651, 0.000000},{0.436641, 0.413764, 0.001511},{
      0.439300, 0.415119, 0.001511},{0.439370, 0.415023, 0.000000}}],
    Polygon[{{0.436641, 0.413764, 0.001511},{0.436532, 0.414101, 0.002984},{
      0.439092, 0.415405, 0.002984},{0.439300, 0.415119, 0.001511}}],
    Polygon[{{0.436532, 0.414101, 0.002984},{0.436353, 0.414652, 0.004384},{
      0.438751, 0.415874, 0.004384},{0.439092, 0.415405, 0.002984}}],
    Polygon[{{0.436353, 0.414652, 0.004384},{0.436108, 0.415405, 0.005676},{
      0.438286, 0.416515, 0.005676},{0.438751, 0.415874, 0.004384}}],
    Polygon[{{0.436108, 0.415405, 0.005676},{0.435804, 0.416341, 0.006829},{
      0.437707, 0.417311, 0.006829},{0.438286, 0.416515, 0.005676}}],
    Polygon[{{0.435804, 0.416341, 0.006829},{0.435448, 0.417437, 0.007813},{
      0.437030, 0.418243, 0.007813},{0.437707, 0.417311, 0.006829}}],
    Polygon[{{0.435448, 0.417437, 0.007813},{0.435048, 0.418666, 0.008605},{
      0.436271, 0.419289, 0.008605},{0.437030, 0.418243, 0.007813}}],
    Polygon[{{0.435048, 0.418666, 0.008605},{0.434616, 0.419997, 0.009185},{
      0.435448, 0.420421, 0.009185},{0.436271, 0.419289, 0.008605}}],
    Polygon[{{0.434616, 0.419997, 0.009185},{0.434160, 0.421399, 0.009538},{
      0.434582, 0.421613, 0.009538},{0.435448, 0.420421, 0.009185}}],
    Polygon[{{0.434582, 0.421613, -0.009538},{0.435448, 0.420421, -0.009185},{
      0.436108, 0.421081, -0.009185},{0.434916, 0.421948, -0.009538}}],
    Polygon[{{0.435448, 0.420421, -0.009185},{0.436271, 0.419289, -0.008605},{
      0.437241, 0.420259, -0.008605},{0.436108, 0.421081, -0.009185}}],
    Polygon[{{0.436271, 0.419289, -0.008605},{0.437030, 0.418243, -0.007813},{
      0.438286, 0.419499, -0.007813},{0.437241, 0.420259, -0.008605}}],
    Polygon[{{0.437030, 0.418243, -0.007813},{0.437707, 0.417311, -0.006829},{
      0.439218, 0.418822, -0.006829},{0.438286, 0.419499, -0.007813}}],
    Polygon[{{0.437707, 0.417311, -0.006829},{0.438286, 0.416515, -0.005676},{
      0.440014, 0.418243, -0.005676},{0.439218, 0.418822, -0.006829}}],
    Polygon[{{0.438286, 0.416515, -0.005676},{0.438751, 0.415874, -0.004384},{
      0.440655, 0.417778, -0.004384},{0.440014, 0.418243, -0.005676}}],
    Polygon[{{0.438751, 0.415874, -0.004384},{0.439092, 0.415405, -0.002984},{
      0.441124, 0.417437, -0.002984},{0.440655, 0.417778, -0.004384}}],
    Polygon[{{0.439092, 0.415405, -0.002984},{0.439300, 0.415119, -0.001511},{
      0.441410, 0.417229, -0.001511},{0.441124, 0.417437, -0.002984}}],
    Polygon[{{0.439300, 0.415119, -0.001511},{0.439370, 0.415023, 0.000000},{
      0.441506, 0.417159, 0.000000},{0.441410, 0.417229, -0.001511}}],
    Polygon[{{0.439370, 0.415023, 0.000000},{0.439300, 0.415119, 0.001511},{
      0.441410, 0.417229, 0.001511},{0.441506, 0.417159, 0.000000}}],
    Polygon[{{0.439300, 0.415119, 0.001511},{0.439092, 0.415405, 0.002984},{
      0.441124, 0.417437, 0.002984},{0.441410, 0.417229, 0.001511}}],
    Polygon[{{0.439092, 0.415405, 0.002984},{0.438751, 0.415874, 0.004384},{
      0.440655, 0.417778, 0.004384},{0.441124, 0.417437, 0.002984}}],
    Polygon[{{0.438751, 0.415874, 0.004384},{0.438286, 0.416515, 0.005676},{
      0.440014, 0.418243, 0.005676},{0.440655, 0.417778, 0.004384}}],
    Polygon[{{0.438286, 0.416515, 0.005676},{0.437707, 0.417311, 0.006829},{
      0.439218, 0.418822, 0.006829},{0.440014, 0.418243, 0.005676}}],
    Polygon[{{0.437707, 0.417311, 0.006829},{0.437030, 0.418243, 0.007813},{
      0.438286, 0.419499, 0.007813},{0.439218, 0.418822, 0.006829}}],
    Polygon[{{0.437030, 0.418243, 0.007813},{0.436271, 0.419289, 0.008605},{
      0.437241, 0.420259, 0.008605},{0.438286, 0.419499, 0.007813}}],
    Polygon[{{0.436271, 0.419289, 0.008605},{0.435448, 0.420421, 0.009185},{
      0.436108, 0.421081, 0.009185},{0.437241, 0.420259, 0.008605}}],
    Polygon[{{0.435448, 0.420421, 0.009185},{0.434582, 0.421613, 0.009538},{
      0.434916, 0.421948, 0.009538},{0.436108, 0.421081, 0.009185}}],
    Polygon[{{0.434916, 0.421948, -0.009538},{0.436108, 0.421081, -0.009185},{
      0.436532, 0.421913, -0.009185},{0.435130, 0.422369, -0.009538}}],
    Polygon[{{0.436108, 0.421081, -0.009185},{0.437241, 0.420259, -0.008605},{
      0.437863, 0.421481, -0.008605},{0.436532, 0.421913, -0.009185}}],
    Polygon[{{0.437241, 0.420259, -0.008605},{0.438286, 0.419499, -0.007813},{
      0.439092, 0.421081, -0.007813},{0.437863, 0.421481, -0.008605}}],
    Polygon[{{0.438286, 0.419499, -0.007813},{0.439218, 0.418822, -0.006829},{
      0.440188, 0.420725, -0.006829},{0.439092, 0.421081, -0.007813}}],
    Polygon[{{0.439218, 0.418822, -0.006829},{0.440014, 0.418243, -0.005676},{
      0.441124, 0.420421, -0.005676},{0.440188, 0.420725, -0.006829}}],
    Polygon[{{0.440014, 0.418243, -0.005676},{0.440655, 0.417778, -0.004384},{
      0.441877, 0.420177, -0.004384},{0.441124, 0.420421, -0.005676}}],
    Polygon[{{0.440655, 0.417778, -0.004384},{0.441124, 0.417437, -0.002984},{
      0.442429, 0.419997, -0.002984},{0.441877, 0.420177, -0.004384}}],
    Polygon[{{0.441124, 0.417437, -0.002984},{0.441410, 0.417229, -0.001511},{
      0.442765, 0.419888, -0.001511},{0.442429, 0.419997, -0.002984}}],
    Polygon[{{0.441410, 0.417229, -0.001511},{0.441506, 0.417159, 0.000000},{
      0.442878, 0.419851, 0.000000},{0.442765, 0.419888, -0.001511}}],
    Polygon[{{0.441506, 0.417159, 0.000000},{0.441410, 0.417229, 0.001511},{
      0.442765, 0.419888, 0.001511},{0.442878, 0.419851, 0.000000}}],
    Polygon[{{0.441410, 0.417229, 0.001511},{0.441124, 0.417437, 0.002984},{
      0.442429, 0.419997, 0.002984},{0.442765, 0.419888, 0.001511}}],
    Polygon[{{0.441124, 0.417437, 0.002984},{0.440655, 0.417778, 0.004384},{
      0.441877, 0.420177, 0.004384},{0.442429, 0.419997, 0.002984}}],
    Polygon[{{0.440655, 0.417778, 0.004384},{0.440014, 0.418243, 0.005676},{
      0.441124, 0.420421, 0.005676},{0.441877, 0.420177, 0.004384}}],
    Polygon[{{0.440014, 0.418243, 0.005676},{0.439218, 0.418822, 0.006829},{
      0.440188, 0.420725, 0.006829},{0.441124, 0.420421, 0.005676}}],
    Polygon[{{0.439218, 0.418822, 0.006829},{0.438286, 0.419499, 0.007813},{
      0.439092, 0.421081, 0.007813},{0.440188, 0.420725, 0.006829}}],
    Polygon[{{0.438286, 0.419499, 0.007813},{0.437241, 0.420259, 0.008605},{
      0.437863, 0.421481, 0.008605},{0.439092, 0.421081, 0.007813}}],
    Polygon[{{0.437241, 0.420259, 0.008605},{0.436108, 0.421081, 0.009185},{
      0.436532, 0.421913, 0.009185},{0.437863, 0.421481, 0.008605}}],
    Polygon[{{0.436108, 0.421081, 0.009185},{0.434916, 0.421948, 0.009538},{
      0.435130, 0.422369, 0.009538},{0.436532, 0.421913, 0.009185}}],
    Polygon[{{0.435130, 0.422369, -0.009538},{0.436532, 0.421913, -0.009185},{
      0.436678, 0.422836, -0.009185},{0.435204, 0.422836, -0.009538}}],
    Polygon[{{0.436532, 0.421913, -0.009185},{0.437863, 0.421481, -0.008605},{
      0.438078, 0.422836, -0.008605},{0.436678, 0.422836, -0.009185}}],
    Polygon[{{0.437863, 0.421481, -0.008605},{0.439092, 0.421081, -0.007813},{
      0.439370, 0.422836, -0.007813},{0.438078, 0.422836, -0.008605}}],
    Polygon[{{0.439092, 0.421081, -0.007813},{0.440188, 0.420725, -0.006829},{
      0.440522, 0.422836, -0.006829},{0.439370, 0.422836, -0.007813}}],
    Polygon[{{0.440188, 0.420725, -0.006829},{0.441124, 0.420421, -0.005676},{
      0.441506, 0.422836, -0.005676},{0.440522, 0.422836, -0.006829}}],
    Polygon[{{0.441124, 0.420421, -0.005676},{0.441877, 0.420177, -0.004384},{
      0.442298, 0.422836, -0.004384},{0.441506, 0.422836, -0.005676}}],
    Polygon[{{0.441877, 0.420177, -0.004384},{0.442429, 0.419997, -0.002984},{
      0.442878, 0.422836, -0.002984},{0.442298, 0.422836, -0.004384}}],
    Polygon[{{0.442429, 0.419997, -0.002984},{0.442765, 0.419888, -0.001511},{
      0.443232, 0.422836, -0.001511},{0.442878, 0.422836, -0.002984}}],
    Polygon[{{0.442765, 0.419888, -0.001511},{0.442878, 0.419851, 0.000000},{
      0.443351, 0.422836, 0.000000},{0.443232, 0.422836, -0.001511}}],
    Polygon[{{0.442878, 0.419851, 0.000000},{0.442765, 0.419888, 0.001511},{
      0.443232, 0.422836, 0.001511},{0.443351, 0.422836, 0.000000}}],
    Polygon[{{0.442765, 0.419888, 0.001511},{0.442429, 0.419997, 0.002984},{
      0.442878, 0.422836, 0.002984},{0.443232, 0.422836, 0.001511}}],
    Polygon[{{0.442429, 0.419997, 0.002984},{0.441877, 0.420177, 0.004384},{
      0.442298, 0.422836, 0.004384},{0.442878, 0.422836, 0.002984}}],
    Polygon[{{0.441877, 0.420177, 0.004384},{0.441124, 0.420421, 0.005676},{
      0.441506, 0.422836, 0.005676},{0.442298, 0.422836, 0.004384}}],
    Polygon[{{0.441124, 0.420421, 0.005676},{0.440188, 0.420725, 0.006829},{
      0.440522, 0.422836, 0.006829},{0.441506, 0.422836, 0.005676}}],
    Polygon[{{0.440188, 0.420725, 0.006829},{0.439092, 0.421081, 0.007813},{
      0.439370, 0.422836, 0.007813},{0.440522, 0.422836, 0.006829}}],
    Polygon[{{0.439092, 0.421081, 0.007813},{0.437863, 0.421481, 0.008605},{
      0.438078, 0.422836, 0.008605},{0.439370, 0.422836, 0.007813}}],
    Polygon[{{0.437863, 0.421481, 0.008605},{0.436532, 0.421913, 0.009185},{
      0.436678, 0.422836, 0.009185},{0.438078, 0.422836, 0.008605}}],
    Polygon[{{0.436532, 0.421913, 0.009185},{0.435130, 0.422369, 0.009538},{
      0.435204, 0.422836, 0.009538},{0.436678, 0.422836, 0.009185}}],
    Polygon[{{0.395511, 0.384270, -0.008668},{0.396850, 0.384270, -0.008347},{
      0.396717, 0.385108, -0.008347},{0.395444, 0.384694, -0.008668}}],
    Polygon[{{0.396850, 0.384270, -0.008347},{0.398122, 0.384270, -0.007820},{
      0.397927, 0.385501, -0.007820},{0.396717, 0.385108, -0.008347}}],
    Polygon[{{0.398122, 0.384270, -0.007820},{0.399296, 0.384270, -0.007100},{
      0.399044, 0.385864, -0.007100},{0.397927, 0.385501, -0.007820}}],
    Polygon[{{0.399296, 0.384270, -0.007100},{0.400344, 0.384270, -0.006206},{
      0.400040, 0.386188, -0.006206},{0.399044, 0.385864, -0.007100}}],
    Polygon[{{0.400344, 0.384270, -0.006206},{0.401238, 0.384270, -0.005159},{
      0.400891, 0.386464, -0.005159},{0.400040, 0.386188, -0.006206}}],
    Polygon[{{0.401238, 0.384270, -0.005159},{0.401958, 0.384270, -0.003984},{
      0.401575, 0.386687, -0.003984},{0.400891, 0.386464, -0.005159}}],
    Polygon[{{0.401958, 0.384270, -0.003984},{0.402485, 0.384270, -0.002712},{
      0.402076, 0.386849, -0.002712},{0.401575, 0.386687, -0.003984}}],
    Polygon[{{0.402485, 0.384270, -0.002712},{0.402806, 0.384270, -0.001373},{
      0.402382, 0.386949, -0.001373},{0.402076, 0.386849, -0.002712}}],
    Polygon[{{0.402806, 0.384270, -0.001373},{0.402914, 0.384270, 0.000000},{
      0.402485, 0.386982, 0.000000},{0.402382, 0.386949, -0.001373}}],
    Polygon[{{0.402914, 0.384270, 0.000000},{0.402806, 0.384270, 0.001373},{
      0.402382, 0.386949, 0.001373},{0.402485, 0.386982, 0.000000}}],
    Polygon[{{0.402806, 0.384270, 0.001373},{0.402485, 0.384270, 0.002712},{
      0.402076, 0.386849, 0.002712},{0.402382, 0.386949, 0.001373}}],
    Polygon[{{0.402485, 0.384270, 0.002712},{0.401958, 0.384270, 0.003984},{
      0.401575, 0.386687, 0.003984},{0.402076, 0.386849, 0.002712}}],
    Polygon[{{0.401958, 0.384270, 0.003984},{0.401238, 0.384270, 0.005159},{
      0.400891, 0.386464, 0.005159},{0.401575, 0.386687, 0.003984}}],
    Polygon[{{0.401238, 0.384270, 0.005159},{0.400344, 0.384270, 0.006206},{
      0.400040, 0.386188, 0.006206},{0.400891, 0.386464, 0.005159}}],
    Polygon[{{0.400344, 0.384270, 0.006206},{0.399296, 0.384270, 0.007100},{
      0.399044, 0.385864, 0.007100},{0.400040, 0.386188, 0.006206}}],
    Polygon[{{0.399296, 0.384270, 0.007100},{0.398122, 0.384270, 0.007820},{
      0.397927, 0.385501, 0.007820},{0.399044, 0.385864, 0.007100}}],
    Polygon[{{0.398122, 0.384270, 0.007820},{0.396850, 0.384270, 0.008347},{
      0.396717, 0.385108, 0.008347},{0.397927, 0.385501, 0.007820}}],
    Polygon[{{0.396850, 0.384270, 0.008347},{0.395511, 0.384270, 0.008668},{
      0.395444, 0.384694, 0.008668},{0.396717, 0.385108, 0.008347}}],
    Polygon[{{0.395444, 0.384694, -0.008668},{0.396717, 0.385108, -0.008347},{
      0.396332, 0.385864, -0.008347},{0.395249, 0.385077, -0.008668}}],
    Polygon[{{0.396717, 0.385108, -0.008347},{0.397927, 0.385501, -0.007820},{
      0.397361, 0.386612, -0.007820},{0.396332, 0.385864, -0.008347}}],
    Polygon[{{0.397927, 0.385501, -0.007820},{0.399044, 0.385864, -0.007100},{
      0.398311, 0.387302, -0.007100},{0.397361, 0.386612, -0.007820}}],
    Polygon[{{0.399044, 0.385864, -0.007100},{0.400040, 0.386188, -0.006206},{
      0.399158, 0.387918, -0.006206},{0.398311, 0.387302, -0.007100}}],
    Polygon[{{0.400040, 0.386188, -0.006206},{0.400891, 0.386464, -0.005159},{
      0.399882, 0.388443, -0.005159},{0.399158, 0.387918, -0.006206}}],
    Polygon[{{0.400891, 0.386464, -0.005159},{0.401575, 0.386687, -0.003984},{
      0.400464, 0.388866, -0.003984},{0.399882, 0.388443, -0.005159}}],
    Polygon[{{0.401575, 0.386687, -0.003984},{0.402076, 0.386849, -0.002712},{
      0.400891, 0.389176, -0.002712},{0.400464, 0.388866, -0.003984}}],
    Polygon[{{0.402076, 0.386849, -0.002712},{0.402382, 0.386949, -0.001373},{
      0.401151, 0.389365, -0.001373},{0.400891, 0.389176, -0.002712}}],
    Polygon[{{0.402382, 0.386949, -0.001373},{0.402485, 0.386982, 0.000000},{
      0.401238, 0.389429, 0.000000},{0.401151, 0.389365, -0.001373}}],
    Polygon[{{0.402485, 0.386982, 0.000000},{0.402382, 0.386949, 0.001373},{
      0.401151, 0.389365, 0.001373},{0.401238, 0.389429, 0.000000}}],
    Polygon[{{0.402382, 0.386949, 0.001373},{0.402076, 0.386849, 0.002712},{
      0.400891, 0.389176, 0.002712},{0.401151, 0.389365, 0.001373}}],
    Polygon[{{0.402076, 0.386849, 0.002712},{0.401575, 0.386687, 0.003984},{
      0.400464, 0.388866, 0.003984},{0.400891, 0.389176, 0.002712}}],
    Polygon[{{0.401575, 0.386687, 0.003984},{0.400891, 0.386464, 0.005159},{
      0.399882, 0.388443, 0.005159},{0.400464, 0.388866, 0.003984}}],
    Polygon[{{0.400891, 0.386464, 0.005159},{0.400040, 0.386188, 0.006206},{
      0.399158, 0.387918, 0.006206},{0.399882, 0.388443, 0.005159}}],
    Polygon[{{0.400040, 0.386188, 0.006206},{0.399044, 0.385864, 0.007100},{
      0.398311, 0.387302, 0.007100},{0.399158, 0.387918, 0.006206}}],
    Polygon[{{0.399044, 0.385864, 0.007100},{0.397927, 0.385501, 0.007820},{
      0.397361, 0.386612, 0.007820},{0.398311, 0.387302, 0.007100}}],
    Polygon[{{0.397927, 0.385501, 0.007820},{0.396717, 0.385108, 0.008347},{
      0.396332, 0.385864, 0.008347},{0.397361, 0.386612, 0.007820}}],
    Polygon[{{0.396717, 0.385108, 0.008347},{0.395444, 0.384694, 0.008668},{
      0.395249, 0.385077, 0.008668},{0.396332, 0.385864, 0.008347}}],
    Polygon[{{0.395249, 0.385077, -0.008668},{0.396332, 0.385864, -0.008347},{
      0.395732, 0.386464, -0.008347},{0.394945, 0.385381, -0.008668}}],
    Polygon[{{0.396332, 0.385864, -0.008347},{0.397361, 0.386612, -0.007820},{
      0.396480, 0.387493, -0.007820},{0.395732, 0.386464, -0.008347}}],
    Polygon[{{0.397361, 0.386612, -0.007820},{0.398311, 0.387302, -0.007100},{
      0.397170, 0.388443, -0.007100},{0.396480, 0.387493, -0.007820}}],
    Polygon[{{0.398311, 0.387302, -0.007100},{0.399158, 0.387918, -0.006206},{
      0.397786, 0.389291, -0.006206},{0.397170, 0.388443, -0.007100}}],
    Polygon[{{0.399158, 0.387918, -0.006206},{0.399882, 0.388443, -0.005159},{
      0.398311, 0.390014, -0.005159},{0.397786, 0.389291, -0.006206}}],
    Polygon[{{0.399882, 0.388443, -0.005159},{0.400464, 0.388866, -0.003984},{
      0.398734, 0.390596, -0.003984},{0.398311, 0.390014, -0.005159}}],
    Polygon[{{0.400464, 0.388866, -0.003984},{0.400891, 0.389176, -0.002712},{
      0.399044, 0.391023, -0.002712},{0.398734, 0.390596, -0.003984}}],
    Polygon[{{0.400891, 0.389176, -0.002712},{0.401151, 0.389365, -0.001373},{
      0.399233, 0.391283, -0.001373},{0.399044, 0.391023, -0.002712}}],
    Polygon[{{0.401151, 0.389365, -0.001373},{0.401238, 0.389429, 0.000000},{
      0.399296, 0.391370, 0.000000},{0.399233, 0.391283, -0.001373}}],
    Polygon[{{0.401238, 0.389429, 0.000000},{0.401151, 0.389365, 0.001373},{
      0.399233, 0.391283, 0.001373},{0.399296, 0.391370, 0.000000}}],
    Polygon[{{0.401151, 0.389365, 0.001373},{0.400891, 0.389176, 0.002712},{
      0.399044, 0.391023, 0.002712},{0.399233, 0.391283, 0.001373}}],
    Polygon[{{0.400891, 0.389176, 0.002712},{0.400464, 0.388866, 0.003984},{
      0.398734, 0.390596, 0.003984},{0.399044, 0.391023, 0.002712}}],
    Polygon[{{0.400464, 0.388866, 0.003984},{0.399882, 0.388443, 0.005159},{
      0.398311, 0.390014, 0.005159},{0.398734, 0.390596, 0.003984}}],
    Polygon[{{0.399882, 0.388443, 0.005159},{0.399158, 0.387918, 0.006206},{
      0.397786, 0.389291, 0.006206},{0.398311, 0.390014, 0.005159}}],
    Polygon[{{0.399158, 0.387918, 0.006206},{0.398311, 0.387302, 0.007100},{
      0.397170, 0.388443, 0.007100},{0.397786, 0.389291, 0.006206}}],
    Polygon[{{0.398311, 0.387302, 0.007100},{0.397361, 0.386612, 0.007820},{
      0.396480, 0.387493, 0.007820},{0.397170, 0.388443, 0.007100}}],
    Polygon[{{0.397361, 0.386612, 0.007820},{0.396332, 0.385864, 0.008347},{
      0.395732, 0.386464, 0.008347},{0.396480, 0.387493, 0.007820}}],
    Polygon[{{0.396332, 0.385864, 0.008347},{0.395249, 0.385077, 0.008668},{
      0.394945, 0.385381, 0.008668},{0.395732, 0.386464, 0.008347}}],
    Polygon[{{0.394945, 0.385381, -0.008668},{0.395732, 0.386464, -0.008347},{
      0.394976, 0.386849, -0.008347},{0.394562, 0.385576, -0.008668}}],
    Polygon[{{0.395732, 0.386464, -0.008347},{0.396480, 0.387493, -0.007820},{
      0.395369, 0.388059, -0.007820},{0.394976, 0.386849, -0.008347}}],
    Polygon[{{0.396480, 0.387493, -0.007820},{0.397170, 0.388443, -0.007100},{
      0.395732, 0.389176, -0.007100},{0.395369, 0.388059, -0.007820}}],
    Polygon[{{0.397170, 0.388443, -0.007100},{0.397786, 0.389291, -0.006206},{
      0.396056, 0.390172, -0.006206},{0.395732, 0.389176, -0.007100}}],
    Polygon[{{0.397786, 0.389291, -0.006206},{0.398311, 0.390014, -0.005159},{
      0.396332, 0.391023, -0.005159},{0.396056, 0.390172, -0.006206}}],
    Polygon[{{0.398311, 0.390014, -0.005159},{0.398734, 0.390596, -0.003984},{
      0.396554, 0.391707, -0.003984},{0.396332, 0.391023, -0.005159}}],
    Polygon[{{0.398734, 0.390596, -0.003984},{0.399044, 0.391023, -0.002712},{
      0.396717, 0.392208, -0.002712},{0.396554, 0.391707, -0.003984}}],
    Polygon[{{0.399044, 0.391023, -0.002712},{0.399233, 0.391283, -0.001373},{
      0.396816, 0.392514, -0.001373},{0.396717, 0.392208, -0.002712}}],
    Polygon[{{0.399233, 0.391283, -0.001373},{0.399296, 0.391370, 0.000000},{
      0.396850, 0.392617, 0.000000},{0.396816, 0.392514, -0.001373}}],
    Polygon[{{0.399296, 0.391370, 0.000000},{0.399233, 0.391283, 0.001373},{
      0.396816, 0.392514, 0.001373},{0.396850, 0.392617, 0.000000}}],
    Polygon[{{0.399233, 0.391283, 0.001373},{0.399044, 0.391023, 0.002712},{
      0.396717, 0.392208, 0.002712},{0.396816, 0.392514, 0.001373}}],
    Polygon[{{0.399044, 0.391023, 0.002712},{0.398734, 0.390596, 0.003984},{
      0.396554, 0.391707, 0.003984},{0.396717, 0.392208, 0.002712}}],
    Polygon[{{0.398734, 0.390596, 0.003984},{0.398311, 0.390014, 0.005159},{
      0.396332, 0.391023, 0.005159},{0.396554, 0.391707, 0.003984}}],
    Polygon[{{0.398311, 0.390014, 0.005159},{0.397786, 0.389291, 0.006206},{
      0.396056, 0.390172, 0.006206},{0.396332, 0.391023, 0.005159}}],
    Polygon[{{0.397786, 0.389291, 0.006206},{0.397170, 0.388443, 0.007100},{
      0.395732, 0.389176, 0.007100},{0.396056, 0.390172, 0.006206}}],
    Polygon[{{0.397170, 0.388443, 0.007100},{0.396480, 0.387493, 0.007820},{
      0.395369, 0.388059, 0.007820},{0.395732, 0.389176, 0.007100}}],
    Polygon[{{0.396480, 0.387493, 0.007820},{0.395732, 0.386464, 0.008347},{
      0.394976, 0.386849, 0.008347},{0.395369, 0.388059, 0.007820}}],
    Polygon[{{0.395732, 0.386464, 0.008347},{0.394945, 0.385381, 0.008668},{
      0.394562, 0.385576, 0.008668},{0.394976, 0.386849, 0.008347}}],
    Polygon[{{0.394562, 0.385576, -0.008668},{0.394976, 0.386849, -0.008347},{
      0.394138, 0.386982, -0.008347},{0.394138, 0.385643, -0.008668}}],
    Polygon[{{0.394976, 0.386849, -0.008347},{0.395369, 0.388059, -0.007820},{
      0.394138, 0.388254, -0.007820},{0.394138, 0.386982, -0.008347}}],
    Polygon[{{0.395369, 0.388059, -0.007820},{0.395732, 0.389176, -0.007100},{
      0.394138, 0.389429, -0.007100},{0.394138, 0.388254, -0.007820}}],
    Polygon[{{0.395732, 0.389176, -0.007100},{0.396056, 0.390172, -0.006206},{
      0.394138, 0.390476, -0.006206},{0.394138, 0.389429, -0.007100}}],
    Polygon[{{0.396056, 0.390172, -0.006206},{0.396332, 0.391023, -0.005159},{
      0.394138, 0.391370, -0.005159},{0.394138, 0.390476, -0.006206}}],
    Polygon[{{0.396332, 0.391023, -0.005159},{0.396554, 0.391707, -0.003984},{
      0.394138, 0.392090, -0.003984},{0.394138, 0.391370, -0.005159}}],
    Polygon[{{0.396554, 0.391707, -0.003984},{0.396717, 0.392208, -0.002712},{
      0.394138, 0.392617, -0.002712},{0.394138, 0.392090, -0.003984}}],
    Polygon[{{0.396717, 0.392208, -0.002712},{0.396816, 0.392514, -0.001373},{
      0.394138, 0.392938, -0.001373},{0.394138, 0.392617, -0.002712}}],
    Polygon[{{0.396816, 0.392514, -0.001373},{0.396850, 0.392617, 0.000000},{
      0.394138, 0.393046, 0.000000},{0.394138, 0.392938, -0.001373}}],
    Polygon[{{0.396850, 0.392617, 0.000000},{0.396816, 0.392514, 0.001373},{
      0.394138, 0.392938, 0.001373},{0.394138, 0.393046, 0.000000}}],
    Polygon[{{0.396816, 0.392514, 0.001373},{0.396717, 0.392208, 0.002712},{
      0.394138, 0.392617, 0.002712},{0.394138, 0.392938, 0.001373}}],
    Polygon[{{0.396717, 0.392208, 0.002712},{0.396554, 0.391707, 0.003984},{
      0.394138, 0.392090, 0.003984},{0.394138, 0.392617, 0.002712}}],
    Polygon[{{0.396554, 0.391707, 0.003984},{0.396332, 0.391023, 0.005159},{
      0.394138, 0.391370, 0.005159},{0.394138, 0.392090, 0.003984}}],
    Polygon[{{0.396332, 0.391023, 0.005159},{0.396056, 0.390172, 0.006206},{
      0.394138, 0.390476, 0.006206},{0.394138, 0.391370, 0.005159}}],
    Polygon[{{0.396056, 0.390172, 0.006206},{0.395732, 0.389176, 0.007100},{
      0.394138, 0.389429, 0.007100},{0.394138, 0.390476, 0.006206}}],
    Polygon[{{0.395732, 0.389176, 0.007100},{0.395369, 0.388059, 0.007820},{
      0.394138, 0.388254, 0.007820},{0.394138, 0.389429, 0.007100}}],
    Polygon[{{0.395369, 0.388059, 0.007820},{0.394976, 0.386849, 0.008347},{
      0.394138, 0.386982, 0.008347},{0.394138, 0.388254, 0.007820}}],
    Polygon[{{0.394976, 0.386849, 0.008347},{0.394562, 0.385576, 0.008668},{
      0.394138, 0.385643, 0.008668},{0.394138, 0.386982, 0.008347}}],
    Polygon[{{0.394138, 0.385643, -0.008668},{0.394138, 0.386982, -0.008347},{
      0.393300, 0.386849, -0.008347},{0.393714, 0.385576, -0.008668}}],
    Polygon[{{0.394138, 0.386982, -0.008347},{0.394138, 0.388254, -0.007820},{
      0.392907, 0.388059, -0.007820},{0.393300, 0.386849, -0.008347}}],
    Polygon[{{0.394138, 0.388254, -0.007820},{0.394138, 0.389429, -0.007100},{
      0.392544, 0.389176, -0.007100},{0.392907, 0.388059, -0.007820}}],
    Polygon[{{0.394138, 0.389429, -0.007100},{0.394138, 0.390476, -0.006206},{
      0.392220, 0.390172, -0.006206},{0.392544, 0.389176, -0.007100}}],
    Polygon[{{0.394138, 0.390476, -0.006206},{0.394138, 0.391370, -0.005159},{
      0.391944, 0.391023, -0.005159},{0.392220, 0.390172, -0.006206}}],
    Polygon[{{0.394138, 0.391370, -0.005159},{0.394138, 0.392090, -0.003984},{
      0.391721, 0.391707, -0.003984},{0.391944, 0.391023, -0.005159}}],
    Polygon[{{0.394138, 0.392090, -0.003984},{0.394138, 0.392617, -0.002712},{
      0.391559, 0.392208, -0.002712},{0.391721, 0.391707, -0.003984}}],
    Polygon[{{0.394138, 0.392617, -0.002712},{0.394138, 0.392938, -0.001373},{
      0.391459, 0.392514, -0.001373},{0.391559, 0.392208, -0.002712}}],
    Polygon[{{0.394138, 0.392938, -0.001373},{0.394138, 0.393046, 0.000000},{
      0.391426, 0.392617, 0.000000},{0.391459, 0.392514, -0.001373}}],
    Polygon[{{0.394138, 0.393046, 0.000000},{0.394138, 0.392938, 0.001373},{
      0.391459, 0.392514, 0.001373},{0.391426, 0.392617, 0.000000}}],
    Polygon[{{0.394138, 0.392938, 0.001373},{0.394138, 0.392617, 0.002712},{
      0.391559, 0.392208, 0.002712},{0.391459, 0.392514, 0.001373}}],
    Polygon[{{0.394138, 0.392617, 0.002712},{0.394138, 0.392090, 0.003984},{
      0.391721, 0.391707, 0.003984},{0.391559, 0.392208, 0.002712}}],
    Polygon[{{0.394138, 0.392090, 0.003984},{0.394138, 0.391370, 0.005159},{
      0.391944, 0.391023, 0.005159},{0.391721, 0.391707, 0.003984}}],
    Polygon[{{0.394138, 0.391370, 0.005159},{0.394138, 0.390476, 0.006206},{
      0.392220, 0.390172, 0.006206},{0.391944, 0.391023, 0.005159}}],
    Polygon[{{0.394138, 0.390476, 0.006206},{0.394138, 0.389429, 0.007100},{
      0.392544, 0.389176, 0.007100},{0.392220, 0.390172, 0.006206}}],
    Polygon[{{0.394138, 0.389429, 0.007100},{0.394138, 0.388254, 0.007820},{
      0.392907, 0.388059, 0.007820},{0.392544, 0.389176, 0.007100}}],
    Polygon[{{0.394138, 0.388254, 0.007820},{0.394138, 0.386982, 0.008347},{
      0.393300, 0.386849, 0.008347},{0.392907, 0.388059, 0.007820}}],
    Polygon[{{0.394138, 0.386982, 0.008347},{0.394138, 0.385643, 0.008668},{
      0.393714, 0.385576, 0.008668},{0.393300, 0.386849, 0.008347}}],
    Polygon[{{0.393714, 0.385576, -0.008668},{0.393300, 0.386849, -0.008347},{
      0.392544, 0.386464, -0.008347},{0.393331, 0.385381, -0.008668}}],
    Polygon[{{0.393300, 0.386849, -0.008347},{0.392907, 0.388059, -0.007820},{
      0.391796, 0.387493, -0.007820},{0.392544, 0.386464, -0.008347}}],
    Polygon[{{0.392907, 0.388059, -0.007820},{0.392544, 0.389176, -0.007100},{
      0.391106, 0.388443, -0.007100},{0.391796, 0.387493, -0.007820}}],
    Polygon[{{0.392544, 0.389176, -0.007100},{0.392220, 0.390172, -0.006206},{
      0.390490, 0.389291, -0.006206},{0.391106, 0.388443, -0.007100}}],
    Polygon[{{0.392220, 0.390172, -0.006206},{0.391944, 0.391023, -0.005159},{
      0.389964, 0.390014, -0.005159},{0.390490, 0.389291, -0.006206}}],
    Polygon[{{0.391944, 0.391023, -0.005159},{0.391721, 0.391707, -0.003984},{
      0.389541, 0.390596, -0.003984},{0.389964, 0.390014, -0.005159}}],
    Polygon[{{0.391721, 0.391707, -0.003984},{0.391559, 0.392208, -0.002712},{
      0.389232, 0.391023, -0.002712},{0.389541, 0.390596, -0.003984}}],
    Polygon[{{0.391559, 0.392208, -0.002712},{0.391459, 0.392514, -0.001373},{
      0.389043, 0.391283, -0.001373},{0.389232, 0.391023, -0.002712}}],
    Polygon[{{0.391459, 0.392514, -0.001373},{0.391426, 0.392617, 0.000000},{
      0.388979, 0.391370, 0.000000},{0.389043, 0.391283, -0.001373}}],
    Polygon[{{0.391426, 0.392617, 0.000000},{0.391459, 0.392514, 0.001373},{
      0.389043, 0.391283, 0.001373},{0.388979, 0.391370, 0.000000}}],
    Polygon[{{0.391459, 0.392514, 0.001373},{0.391559, 0.392208, 0.002712},{
      0.389232, 0.391023, 0.002712},{0.389043, 0.391283, 0.001373}}],
    Polygon[{{0.391559, 0.392208, 0.002712},{0.391721, 0.391707, 0.003984},{
      0.389541, 0.390596, 0.003984},{0.389232, 0.391023, 0.002712}}],
    Polygon[{{0.391721, 0.391707, 0.003984},{0.391944, 0.391023, 0.005159},{
      0.389964, 0.390014, 0.005159},{0.389541, 0.390596, 0.003984}}],
    Polygon[{{0.391944, 0.391023, 0.005159},{0.392220, 0.390172, 0.006206},{
      0.390490, 0.389291, 0.006206},{0.389964, 0.390014, 0.005159}}],
    Polygon[{{0.392220, 0.390172, 0.006206},{0.392544, 0.389176, 0.007100},{
      0.391106, 0.388443, 0.007100},{0.390490, 0.389291, 0.006206}}],
    Polygon[{{0.392544, 0.389176, 0.007100},{0.392907, 0.388059, 0.007820},{
      0.391796, 0.387493, 0.007820},{0.391106, 0.388443, 0.007100}}],
    Polygon[{{0.392907, 0.388059, 0.007820},{0.393300, 0.386849, 0.008347},{
      0.392544, 0.386464, 0.008347},{0.391796, 0.387493, 0.007820}}],
    Polygon[{{0.393300, 0.386849, 0.008347},{0.393714, 0.385576, 0.008668},{
      0.393331, 0.385381, 0.008668},{0.392544, 0.386464, 0.008347}}],
    Polygon[{{0.393331, 0.385381, -0.008668},{0.392544, 0.386464, -0.008347},{
      0.391944, 0.385864, -0.008347},{0.393027, 0.385077, -0.008668}}],
    Polygon[{{0.392544, 0.386464, -0.008347},{0.391796, 0.387493, -0.007820},{
      0.390914, 0.386612, -0.007820},{0.391944, 0.385864, -0.008347}}],
    Polygon[{{0.391796, 0.387493, -0.007820},{0.391106, 0.388443, -0.007100},{
      0.389964, 0.387302, -0.007100},{0.390914, 0.386612, -0.007820}}],
    Polygon[{{0.391106, 0.388443, -0.007100},{0.390490, 0.389291, -0.006206},{
      0.389117, 0.387918, -0.006206},{0.389964, 0.387302, -0.007100}}],
    Polygon[{{0.390490, 0.389291, -0.006206},{0.389964, 0.390014, -0.005159},{
      0.388394, 0.388443, -0.005159},{0.389117, 0.387918, -0.006206}}],
    Polygon[{{0.389964, 0.390014, -0.005159},{0.389541, 0.390596, -0.003984},{
      0.387811, 0.388866, -0.003984},{0.388394, 0.388443, -0.005159}}],
    Polygon[{{0.389541, 0.390596, -0.003984},{0.389232, 0.391023, -0.002712},{
      0.387385, 0.389176, -0.002712},{0.387811, 0.388866, -0.003984}}],
    Polygon[{{0.389232, 0.391023, -0.002712},{0.389043, 0.391283, -0.001373},{
      0.387125, 0.389365, -0.001373},{0.387385, 0.389176, -0.002712}}],
    Polygon[{{0.389043, 0.391283, -0.001373},{0.388979, 0.391370, 0.000000},{
      0.387038, 0.389429, 0.000000},{0.387125, 0.389365, -0.001373}}],
    Polygon[{{0.388979, 0.391370, 0.000000},{0.389043, 0.391283, 0.001373},{
      0.387125, 0.389365, 0.001373},{0.387038, 0.389429, 0.000000}}],
    Polygon[{{0.389043, 0.391283, 0.001373},{0.389232, 0.391023, 0.002712},{
      0.387385, 0.389176, 0.002712},{0.387125, 0.389365, 0.001373}}],
    Polygon[{{0.389232, 0.391023, 0.002712},{0.389541, 0.390596, 0.003984},{
      0.387811, 0.388866, 0.003984},{0.387385, 0.389176, 0.002712}}],
    Polygon[{{0.389541, 0.390596, 0.003984},{0.389964, 0.390014, 0.005159},{
      0.388394, 0.388443, 0.005159},{0.387811, 0.388866, 0.003984}}],
    Polygon[{{0.389964, 0.390014, 0.005159},{0.390490, 0.389291, 0.006206},{
      0.389117, 0.387918, 0.006206},{0.388394, 0.388443, 0.005159}}],
    Polygon[{{0.390490, 0.389291, 0.006206},{0.391106, 0.388443, 0.007100},{
      0.389964, 0.387302, 0.007100},{0.389117, 0.387918, 0.006206}}],
    Polygon[{{0.391106, 0.388443, 0.007100},{0.391796, 0.387493, 0.007820},{
      0.390914, 0.386612, 0.007820},{0.389964, 0.387302, 0.007100}}],
    Polygon[{{0.391796, 0.387493, 0.007820},{0.392544, 0.386464, 0.008347},{
      0.391944, 0.385864, 0.008347},{0.390914, 0.386612, 0.007820}}],
    Polygon[{{0.392544, 0.386464, 0.008347},{0.393331, 0.385381, 0.008668},{
      0.393027, 0.385077, 0.008668},{0.391944, 0.385864, 0.008347}}],
    Polygon[{{0.393027, 0.385077, -0.008668},{0.391944, 0.385864, -0.008347},{
      0.391559, 0.385108, -0.008347},{0.392832, 0.384694, -0.008668}}],
    Polygon[{{0.391944, 0.385864, -0.008347},{0.390914, 0.386612, -0.007820},{
      0.390348, 0.385501, -0.007820},{0.391559, 0.385108, -0.008347}}],
    Polygon[{{0.390914, 0.386612, -0.007820},{0.389964, 0.387302, -0.007100},{
      0.389232, 0.385864, -0.007100},{0.390348, 0.385501, -0.007820}}],
    Polygon[{{0.389964, 0.387302, -0.007100},{0.389117, 0.387918, -0.006206},{
      0.388236, 0.386188, -0.006206},{0.389232, 0.385864, -0.007100}}],
    Polygon[{{0.389117, 0.387918, -0.006206},{0.388394, 0.388443, -0.005159},{
      0.387385, 0.386464, -0.005159},{0.388236, 0.386188, -0.006206}}],
    Polygon[{{0.388394, 0.388443, -0.005159},{0.387811, 0.388866, -0.003984},{
      0.386701, 0.386687, -0.003984},{0.387385, 0.386464, -0.005159}}],
    Polygon[{{0.387811, 0.388866, -0.003984},{0.387385, 0.389176, -0.002712},{
      0.386200, 0.386849, -0.002712},{0.386701, 0.386687, -0.003984}}],
    Polygon[{{0.387385, 0.389176, -0.002712},{0.387125, 0.389365, -0.001373},{
      0.385894, 0.386949, -0.001373},{0.386200, 0.386849, -0.002712}}],
    Polygon[{{0.387125, 0.389365, -0.001373},{0.387038, 0.389429, 0.000000},{
      0.385791, 0.386982, 0.000000},{0.385894, 0.386949, -0.001373}}],
    Polygon[{{0.387038, 0.389429, 0.000000},{0.387125, 0.389365, 0.001373},{
      0.385894, 0.386949, 0.001373},{0.385791, 0.386982, 0.000000}}],
    Polygon[{{0.387125, 0.389365, 0.001373},{0.387385, 0.389176, 0.002712},{
      0.386200, 0.386849, 0.002712},{0.385894, 0.386949, 0.001373}}],
    Polygon[{{0.387385, 0.389176, 0.002712},{0.387811, 0.388866, 0.003984},{
      0.386701, 0.386687, 0.003984},{0.386200, 0.386849, 0.002712}}],
    Polygon[{{0.387811, 0.388866, 0.003984},{0.388394, 0.388443, 0.005159},{
      0.387385, 0.386464, 0.005159},{0.386701, 0.386687, 0.003984}}],
    Polygon[{{0.388394, 0.388443, 0.005159},{0.389117, 0.387918, 0.006206},{
      0.388236, 0.386188, 0.006206},{0.387385, 0.386464, 0.005159}}],
    Polygon[{{0.389117, 0.387918, 0.006206},{0.389964, 0.387302, 0.007100},{
      0.389232, 0.385864, 0.007100},{0.388236, 0.386188, 0.006206}}],
    Polygon[{{0.389964, 0.387302, 0.007100},{0.390914, 0.386612, 0.007820},{
      0.390348, 0.385501, 0.007820},{0.389232, 0.385864, 0.007100}}],
    Polygon[{{0.390914, 0.386612, 0.007820},{0.391944, 0.385864, 0.008347},{
      0.391559, 0.385108, 0.008347},{0.390348, 0.385501, 0.007820}}],
    Polygon[{{0.391944, 0.385864, 0.008347},{0.393027, 0.385077, 0.008668},{
      0.392832, 0.384694, 0.008668},{0.391559, 0.385108, 0.008347}}],
    Polygon[{{0.392832, 0.384694, -0.008668},{0.391559, 0.385108, -0.008347},{
      0.391426, 0.384270, -0.008347},{0.392765, 0.384270, -0.008668}}],
    Polygon[{{0.391559, 0.385108, -0.008347},{0.390348, 0.385501, -0.007820},{
      0.390153, 0.384270, -0.007820},{0.391426, 0.384270, -0.008347}}],
    Polygon[{{0.390348, 0.385501, -0.007820},{0.389232, 0.385864, -0.007100},{
      0.388979, 0.384270, -0.007100},{0.390153, 0.384270, -0.007820}}],
    Polygon[{{0.389232, 0.385864, -0.007100},{0.388236, 0.386188, -0.006206},{
      0.387932, 0.384270, -0.006206},{0.388979, 0.384270, -0.007100}}],
    Polygon[{{0.388236, 0.386188, -0.006206},{0.387385, 0.386464, -0.005159},{
      0.387038, 0.384270, -0.005159},{0.387932, 0.384270, -0.006206}}],
    Polygon[{{0.387385, 0.386464, -0.005159},{0.386701, 0.386687, -0.003984},{
      0.386318, 0.384270, -0.003984},{0.387038, 0.384270, -0.005159}}],
    Polygon[{{0.386701, 0.386687, -0.003984},{0.386200, 0.386849, -0.002712},{
      0.385791, 0.384270, -0.002712},{0.386318, 0.384270, -0.003984}}],
    Polygon[{{0.386200, 0.386849, -0.002712},{0.385894, 0.386949, -0.001373},{
      0.385469, 0.384270, -0.001373},{0.385791, 0.384270, -0.002712}}],
    Polygon[{{0.385894, 0.386949, -0.001373},{0.385791, 0.386982, 0.000000},{
      0.385361, 0.384270, 0.000000},{0.385469, 0.384270, -0.001373}}],
    Polygon[{{0.385791, 0.386982, 0.000000},{0.385894, 0.386949, 0.001373},{
      0.385469, 0.384270, 0.001373},{0.385361, 0.384270, 0.000000}}],
    Polygon[{{0.385894, 0.386949, 0.001373},{0.386200, 0.386849, 0.002712},{
      0.385791, 0.384270, 0.002712},{0.385469, 0.384270, 0.001373}}],
    Polygon[{{0.386200, 0.386849, 0.002712},{0.386701, 0.386687, 0.003984},{
      0.386318, 0.384270, 0.003984},{0.385791, 0.384270, 0.002712}}],
    Polygon[{{0.386701, 0.386687, 0.003984},{0.387385, 0.386464, 0.005159},{
      0.387038, 0.384270, 0.005159},{0.386318, 0.384270, 0.003984}}],
    Polygon[{{0.387385, 0.386464, 0.005159},{0.388236, 0.386188, 0.006206},{
      0.387932, 0.384270, 0.006206},{0.387038, 0.384270, 0.005159}}],
    Polygon[{{0.388236, 0.386188, 0.006206},{0.389232, 0.385864, 0.007100},{
      0.388979, 0.384270, 0.007100},{0.387932, 0.384270, 0.006206}}],
    Polygon[{{0.389232, 0.385864, 0.007100},{0.390348, 0.385501, 0.007820},{
      0.390153, 0.384270, 0.007820},{0.388979, 0.384270, 0.007100}}],
    Polygon[{{0.390348, 0.385501, 0.007820},{0.391559, 0.385108, 0.008347},{
      0.391426, 0.384270, 0.008347},{0.390153, 0.384270, 0.007820}}],
    Polygon[{{0.391559, 0.385108, 0.008347},{0.392832, 0.384694, 0.008668},{
      0.392765, 0.384270, 0.008668},{0.391426, 0.384270, 0.008347}}],
    Polygon[{{0.392765, 0.384270, -0.008668},{0.391426, 0.384270, -0.008347},{
      0.391559, 0.383432, -0.008347},{0.392832, 0.383846, -0.008668}}],
    Polygon[{{0.391426, 0.384270, -0.008347},{0.390153, 0.384270, -0.007820},{
      0.390348, 0.383039, -0.007820},{0.391559, 0.383432, -0.008347}}],
    Polygon[{{0.390153, 0.384270, -0.007820},{0.388979, 0.384270, -0.007100},{
      0.389232, 0.382676, -0.007100},{0.390348, 0.383039, -0.007820}}],
    Polygon[{{0.388979, 0.384270, -0.007100},{0.387932, 0.384270, -0.006206},{
      0.388236, 0.382352, -0.006206},{0.389232, 0.382676, -0.007100}}],
    Polygon[{{0.387932, 0.384270, -0.006206},{0.387038, 0.384270, -0.005159},{
      0.387385, 0.382076, -0.005159},{0.388236, 0.382352, -0.006206}}],
    Polygon[{{0.387038, 0.384270, -0.005159},{0.386318, 0.384270, -0.003984},{
      0.386701, 0.381854, -0.003984},{0.387385, 0.382076, -0.005159}}],
    Polygon[{{0.386318, 0.384270, -0.003984},{0.385791, 0.384270, -0.002712},{
      0.386200, 0.381691, -0.002712},{0.386701, 0.381854, -0.003984}}],
    Polygon[{{0.385791, 0.384270, -0.002712},{0.385469, 0.384270, -0.001373},{
      0.385894, 0.381591, -0.001373},{0.386200, 0.381691, -0.002712}}],
    Polygon[{{0.385469, 0.384270, -0.001373},{0.385361, 0.384270, 0.000000},{
      0.385791, 0.381558, 0.000000},{0.385894, 0.381591, -0.001373}}],
    Polygon[{{0.385361, 0.384270, 0.000000},{0.385469, 0.384270, 0.001373},{
      0.385894, 0.381591, 0.001373},{0.385791, 0.381558, 0.000000}}],
    Polygon[{{0.385469, 0.384270, 0.001373},{0.385791, 0.384270, 0.002712},{
      0.386200, 0.381691, 0.002712},{0.385894, 0.381591, 0.001373}}],
    Polygon[{{0.385791, 0.384270, 0.002712},{0.386318, 0.384270, 0.003984},{
      0.386701, 0.381854, 0.003984},{0.386200, 0.381691, 0.002712}}],
    Polygon[{{0.386318, 0.384270, 0.003984},{0.387038, 0.384270, 0.005159},{
      0.387385, 0.382076, 0.005159},{0.386701, 0.381854, 0.003984}}],
    Polygon[{{0.387038, 0.384270, 0.005159},{0.387932, 0.384270, 0.006206},{
      0.388236, 0.382352, 0.006206},{0.387385, 0.382076, 0.005159}}],
    Polygon[{{0.387932, 0.384270, 0.006206},{0.388979, 0.384270, 0.007100},{
      0.389232, 0.382676, 0.007100},{0.388236, 0.382352, 0.006206}}],
    Polygon[{{0.388979, 0.384270, 0.007100},{0.390153, 0.384270, 0.007820},{
      0.390348, 0.383039, 0.007820},{0.389232, 0.382676, 0.007100}}],
    Polygon[{{0.390153, 0.384270, 0.007820},{0.391426, 0.384270, 0.008347},{
      0.391559, 0.383432, 0.008347},{0.390348, 0.383039, 0.007820}}],
    Polygon[{{0.391426, 0.384270, 0.008347},{0.392765, 0.384270, 0.008668},{
      0.392832, 0.383846, 0.008668},{0.391559, 0.383432, 0.008347}}],
    Polygon[{{0.392832, 0.383846, -0.008668},{0.391559, 0.383432, -0.008347},{
      0.391944, 0.382676, -0.008347},{0.393027, 0.383463, -0.008668}}],
    Polygon[{{0.391559, 0.383432, -0.008347},{0.390348, 0.383039, -0.007820},{
      0.390914, 0.381928, -0.007820},{0.391944, 0.382676, -0.008347}}],
    Polygon[{{0.390348, 0.383039, -0.007820},{0.389232, 0.382676, -0.007100},{
      0.389964, 0.381238, -0.007100},{0.390914, 0.381928, -0.007820}}],
    Polygon[{{0.389232, 0.382676, -0.007100},{0.388236, 0.382352, -0.006206},{
      0.389117, 0.380622, -0.006206},{0.389964, 0.381238, -0.007100}}],
    Polygon[{{0.388236, 0.382352, -0.006206},{0.387385, 0.382076, -0.005159},{
      0.388394, 0.380097, -0.005159},{0.389117, 0.380622, -0.006206}}],
    Polygon[{{0.387385, 0.382076, -0.005159},{0.386701, 0.381854, -0.003984},{
      0.387811, 0.379674, -0.003984},{0.388394, 0.380097, -0.005159}}],
    Polygon[{{0.386701, 0.381854, -0.003984},{0.386200, 0.381691, -0.002712},{
      0.387385, 0.379364, -0.002712},{0.387811, 0.379674, -0.003984}}],
    Polygon[{{0.386200, 0.381691, -0.002712},{0.385894, 0.381591, -0.001373},{
      0.387125, 0.379175, -0.001373},{0.387385, 0.379364, -0.002712}}],
    Polygon[{{0.385894, 0.381591, -0.001373},{0.385791, 0.381558, 0.000000},{
      0.387038, 0.379111, 0.000000},{0.387125, 0.379175, -0.001373}}],
    Polygon[{{0.385791, 0.381558, 0.000000},{0.385894, 0.381591, 0.001373},{
      0.387125, 0.379175, 0.001373},{0.387038, 0.379111, 0.000000}}],
    Polygon[{{0.385894, 0.381591, 0.001373},{0.386200, 0.381691, 0.002712},{
      0.387385, 0.379364, 0.002712},{0.387125, 0.379175, 0.001373}}],
    Polygon[{{0.386200, 0.381691, 0.002712},{0.386701, 0.381854, 0.003984},{
      0.387811, 0.379674, 0.003984},{0.387385, 0.379364, 0.002712}}],
    Polygon[{{0.386701, 0.381854, 0.003984},{0.387385, 0.382076, 0.005159},{
      0.388394, 0.380097, 0.005159},{0.387811, 0.379674, 0.003984}}],
    Polygon[{{0.387385, 0.382076, 0.005159},{0.388236, 0.382352, 0.006206},{
      0.389117, 0.380622, 0.006206},{0.388394, 0.380097, 0.005159}}],
    Polygon[{{0.388236, 0.382352, 0.006206},{0.389232, 0.382676, 0.007100},{
      0.389964, 0.381238, 0.007100},{0.389117, 0.380622, 0.006206}}],
    Polygon[{{0.389232, 0.382676, 0.007100},{0.390348, 0.383039, 0.007820},{
      0.390914, 0.381928, 0.007820},{0.389964, 0.381238, 0.007100}}],
    Polygon[{{0.390348, 0.383039, 0.007820},{0.391559, 0.383432, 0.008347},{
      0.391944, 0.382676, 0.008347},{0.390914, 0.381928, 0.007820}}],
    Polygon[{{0.391559, 0.383432, 0.008347},{0.392832, 0.383846, 0.008668},{
      0.393027, 0.383463, 0.008668},{0.391944, 0.382676, 0.008347}}],
    Polygon[{{0.393027, 0.383463, -0.008668},{0.391944, 0.382676, -0.008347},{
      0.392544, 0.382076, -0.008347},{0.393331, 0.383159, -0.008668}}],
    Polygon[{{0.391944, 0.382676, -0.008347},{0.390914, 0.381928, -0.007820},{
      0.391796, 0.381047, -0.007820},{0.392544, 0.382076, -0.008347}}],
    Polygon[{{0.390914, 0.381928, -0.007820},{0.389964, 0.381238, -0.007100},{
      0.391106, 0.380097, -0.007100},{0.391796, 0.381047, -0.007820}}],
    Polygon[{{0.389964, 0.381238, -0.007100},{0.389117, 0.380622, -0.006206},{
      0.390490, 0.379249, -0.006206},{0.391106, 0.380097, -0.007100}}],
    Polygon[{{0.389117, 0.380622, -0.006206},{0.388394, 0.380097, -0.005159},{
      0.389964, 0.378526, -0.005159},{0.390490, 0.379249, -0.006206}}],
    Polygon[{{0.388394, 0.380097, -0.005159},{0.387811, 0.379674, -0.003984},{
      0.389541, 0.377944, -0.003984},{0.389964, 0.378526, -0.005159}}],
    Polygon[{{0.387811, 0.379674, -0.003984},{0.387385, 0.379364, -0.002712},{
      0.389232, 0.377517, -0.002712},{0.389541, 0.377944, -0.003984}}],
    Polygon[{{0.387385, 0.379364, -0.002712},{0.387125, 0.379175, -0.001373},{
      0.389043, 0.377257, -0.001373},{0.389232, 0.377517, -0.002712}}],
    Polygon[{{0.387125, 0.379175, -0.001373},{0.387038, 0.379111, 0.000000},{
      0.388979, 0.377170, 0.000000},{0.389043, 0.377257, -0.001373}}],
    Polygon[{{0.387038, 0.379111, 0.000000},{0.387125, 0.379175, 0.001373},{
      0.389043, 0.377257, 0.001373},{0.388979, 0.377170, 0.000000}}],
    Polygon[{{0.387125, 0.379175, 0.001373},{0.387385, 0.379364, 0.002712},{
      0.389232, 0.377517, 0.002712},{0.389043, 0.377257, 0.001373}}],
    Polygon[{{0.387385, 0.379364, 0.002712},{0.387811, 0.379674, 0.003984},{
      0.389541, 0.377944, 0.003984},{0.389232, 0.377517, 0.002712}}],
    Polygon[{{0.387811, 0.379674, 0.003984},{0.388394, 0.380097, 0.005159},{
      0.389964, 0.378526, 0.005159},{0.389541, 0.377944, 0.003984}}],
    Polygon[{{0.388394, 0.380097, 0.005159},{0.389117, 0.380622, 0.006206},{
      0.390490, 0.379249, 0.006206},{0.389964, 0.378526, 0.005159}}],
    Polygon[{{0.389117, 0.380622, 0.006206},{0.389964, 0.381238, 0.007100},{
      0.391106, 0.380097, 0.007100},{0.390490, 0.379249, 0.006206}}],
    Polygon[{{0.389964, 0.381238, 0.007100},{0.390914, 0.381928, 0.007820},{
      0.391796, 0.381047, 0.007820},{0.391106, 0.380097, 0.007100}}],
    Polygon[{{0.390914, 0.381928, 0.007820},{0.391944, 0.382676, 0.008347},{
      0.392544, 0.382076, 0.008347},{0.391796, 0.381047, 0.007820}}],
    Polygon[{{0.391944, 0.382676, 0.008347},{0.393027, 0.383463, 0.008668},{
      0.393331, 0.383159, 0.008668},{0.392544, 0.382076, 0.008347}}],
    Polygon[{{0.393331, 0.383159, -0.008668},{0.392544, 0.382076, -0.008347},{
      0.393300, 0.381691, -0.008347},{0.393714, 0.382964, -0.008668}}],
    Polygon[{{0.392544, 0.382076, -0.008347},{0.391796, 0.381047, -0.007820},{
      0.392907, 0.380481, -0.007820},{0.393300, 0.381691, -0.008347}}],
    Polygon[{{0.391796, 0.381047, -0.007820},{0.391106, 0.380097, -0.007100},{
      0.392544, 0.379364, -0.007100},{0.392907, 0.380481, -0.007820}}],
    Polygon[{{0.391106, 0.380097, -0.007100},{0.390490, 0.379249, -0.006206},{
      0.392220, 0.378368, -0.006206},{0.392544, 0.379364, -0.007100}}],
    Polygon[{{0.390490, 0.379249, -0.006206},{0.389964, 0.378526, -0.005159},{
      0.391944, 0.377517, -0.005159},{0.392220, 0.378368, -0.006206}}],
    Polygon[{{0.389964, 0.378526, -0.005159},{0.389541, 0.377944, -0.003984},{
      0.391721, 0.376833, -0.003984},{0.391944, 0.377517, -0.005159}}],
    Polygon[{{0.389541, 0.377944, -0.003984},{0.389232, 0.377517, -0.002712},{
      0.391559, 0.376332, -0.002712},{0.391721, 0.376833, -0.003984}}],
    Polygon[{{0.389232, 0.377517, -0.002712},{0.389043, 0.377257, -0.001373},{
      0.391459, 0.376026, -0.001373},{0.391559, 0.376332, -0.002712}}],
    Polygon[{{0.389043, 0.377257, -0.001373},{0.388979, 0.377170, 0.000000},{
      0.391426, 0.375923, 0.000000},{0.391459, 0.376026, -0.001373}}],
    Polygon[{{0.388979, 0.377170, 0.000000},{0.389043, 0.377257, 0.001373},{
      0.391459, 0.376026, 0.001373},{0.391426, 0.375923, 0.000000}}],
    Polygon[{{0.389043, 0.377257, 0.001373},{0.389232, 0.377517, 0.002712},{
      0.391559, 0.376332, 0.002712},{0.391459, 0.376026, 0.001373}}],
    Polygon[{{0.389232, 0.377517, 0.002712},{0.389541, 0.377944, 0.003984},{
      0.391721, 0.376833, 0.003984},{0.391559, 0.376332, 0.002712}}],
    Polygon[{{0.389541, 0.377944, 0.003984},{0.389964, 0.378526, 0.005159},{
      0.391944, 0.377517, 0.005159},{0.391721, 0.376833, 0.003984}}],
    Polygon[{{0.389964, 0.378526, 0.005159},{0.390490, 0.379249, 0.006206},{
      0.392220, 0.378368, 0.006206},{0.391944, 0.377517, 0.005159}}],
    Polygon[{{0.390490, 0.379249, 0.006206},{0.391106, 0.380097, 0.007100},{
      0.392544, 0.379364, 0.007100},{0.392220, 0.378368, 0.006206}}],
    Polygon[{{0.391106, 0.380097, 0.007100},{0.391796, 0.381047, 0.007820},{
      0.392907, 0.380481, 0.007820},{0.392544, 0.379364, 0.007100}}],
    Polygon[{{0.391796, 0.381047, 0.007820},{0.392544, 0.382076, 0.008347},{
      0.393300, 0.381691, 0.008347},{0.392907, 0.380481, 0.007820}}],
    Polygon[{{0.392544, 0.382076, 0.008347},{0.393331, 0.383159, 0.008668},{
      0.393714, 0.382964, 0.008668},{0.393300, 0.381691, 0.008347}}],
    Polygon[{{0.393714, 0.382964, -0.008668},{0.393300, 0.381691, -0.008347},{
      0.394138, 0.381558, -0.008347},{0.394138, 0.382897, -0.008668}}],
    Polygon[{{0.393300, 0.381691, -0.008347},{0.392907, 0.380481, -0.007820},{
      0.394138, 0.380286, -0.007820},{0.394138, 0.381558, -0.008347}}],
    Polygon[{{0.392907, 0.380481, -0.007820},{0.392544, 0.379364, -0.007100},{
      0.394138, 0.379111, -0.007100},{0.394138, 0.380286, -0.007820}}],
    Polygon[{{0.392544, 0.379364, -0.007100},{0.392220, 0.378368, -0.006206},{
      0.394138, 0.378064, -0.006206},{0.394138, 0.379111, -0.007100}}],
    Polygon[{{0.392220, 0.378368, -0.006206},{0.391944, 0.377517, -0.005159},{
      0.394138, 0.377170, -0.005159},{0.394138, 0.378064, -0.006206}}],
    Polygon[{{0.391944, 0.377517, -0.005159},{0.391721, 0.376833, -0.003984},{
      0.394138, 0.376450, -0.003984},{0.394138, 0.377170, -0.005159}}],
    Polygon[{{0.391721, 0.376833, -0.003984},{0.391559, 0.376332, -0.002712},{
      0.394138, 0.375923, -0.002712},{0.394138, 0.376450, -0.003984}}],
    Polygon[{{0.391559, 0.376332, -0.002712},{0.391459, 0.376026, -0.001373},{
      0.394138, 0.375602, -0.001373},{0.394138, 0.375923, -0.002712}}],
    Polygon[{{0.391459, 0.376026, -0.001373},{0.391426, 0.375923, 0.000000},{
      0.394138, 0.375494, 0.000000},{0.394138, 0.375602, -0.001373}}],
    Polygon[{{0.391426, 0.375923, 0.000000},{0.391459, 0.376026, 0.001373},{
      0.394138, 0.375602, 0.001373},{0.394138, 0.375494, 0.000000}}],
    Polygon[{{0.391459, 0.376026, 0.001373},{0.391559, 0.376332, 0.002712},{
      0.394138, 0.375923, 0.002712},{0.394138, 0.375602, 0.001373}}],
    Polygon[{{0.391559, 0.376332, 0.002712},{0.391721, 0.376833, 0.003984},{
      0.394138, 0.376450, 0.003984},{0.394138, 0.375923, 0.002712}}],
    Polygon[{{0.391721, 0.376833, 0.003984},{0.391944, 0.377517, 0.005159},{
      0.394138, 0.377170, 0.005159},{0.394138, 0.376450, 0.003984}}],
    Polygon[{{0.391944, 0.377517, 0.005159},{0.392220, 0.378368, 0.006206},{
      0.394138, 0.378064, 0.006206},{0.394138, 0.377170, 0.005159}}],
    Polygon[{{0.392220, 0.378368, 0.006206},{0.392544, 0.379364, 0.007100},{
      0.394138, 0.379111, 0.007100},{0.394138, 0.378064, 0.006206}}],
    Polygon[{{0.392544, 0.379364, 0.007100},{0.392907, 0.380481, 0.007820},{
      0.394138, 0.380286, 0.007820},{0.394138, 0.379111, 0.007100}}],
    Polygon[{{0.392907, 0.380481, 0.007820},{0.393300, 0.381691, 0.008347},{
      0.394138, 0.381558, 0.008347},{0.394138, 0.380286, 0.007820}}],
    Polygon[{{0.393300, 0.381691, 0.008347},{0.393714, 0.382964, 0.008668},{
      0.394138, 0.382897, 0.008668},{0.394138, 0.381558, 0.008347}}],
    Polygon[{{0.394138, 0.382897, -0.008668},{0.394138, 0.381558, -0.008347},{
      0.394976, 0.381691, -0.008347},{0.394562, 0.382964, -0.008668}}],
    Polygon[{{0.394138, 0.381558, -0.008347},{0.394138, 0.380286, -0.007820},{
      0.395369, 0.380481, -0.007820},{0.394976, 0.381691, -0.008347}}],
    Polygon[{{0.394138, 0.380286, -0.007820},{0.394138, 0.379111, -0.007100},{
      0.395732, 0.379364, -0.007100},{0.395369, 0.380481, -0.007820}}],
    Polygon[{{0.394138, 0.379111, -0.007100},{0.394138, 0.378064, -0.006206},{
      0.396056, 0.378368, -0.006206},{0.395732, 0.379364, -0.007100}}],
    Polygon[{{0.394138, 0.378064, -0.006206},{0.394138, 0.377170, -0.005159},{
      0.396332, 0.377517, -0.005159},{0.396056, 0.378368, -0.006206}}],
    Polygon[{{0.394138, 0.377170, -0.005159},{0.394138, 0.376450, -0.003984},{
      0.396554, 0.376833, -0.003984},{0.396332, 0.377517, -0.005159}}],
    Polygon[{{0.394138, 0.376450, -0.003984},{0.394138, 0.375923, -0.002712},{
      0.396717, 0.376332, -0.002712},{0.396554, 0.376833, -0.003984}}],
    Polygon[{{0.394138, 0.375923, -0.002712},{0.394138, 0.375602, -0.001373},{
      0.396816, 0.376026, -0.001373},{0.396717, 0.376332, -0.002712}}],
    Polygon[{{0.394138, 0.375602, -0.001373},{0.394138, 0.375494, 0.000000},{
      0.396850, 0.375923, 0.000000},{0.396816, 0.376026, -0.001373}}],
    Polygon[{{0.394138, 0.375494, 0.000000},{0.394138, 0.375602, 0.001373},{
      0.396816, 0.376026, 0.001373},{0.396850, 0.375923, 0.000000}}],
    Polygon[{{0.394138, 0.375602, 0.001373},{0.394138, 0.375923, 0.002712},{
      0.396717, 0.376332, 0.002712},{0.396816, 0.376026, 0.001373}}],
    Polygon[{{0.394138, 0.375923, 0.002712},{0.394138, 0.376450, 0.003984},{
      0.396554, 0.376833, 0.003984},{0.396717, 0.376332, 0.002712}}],
    Polygon[{{0.394138, 0.376450, 0.003984},{0.394138, 0.377170, 0.005159},{
      0.396332, 0.377517, 0.005159},{0.396554, 0.376833, 0.003984}}],
    Polygon[{{0.394138, 0.377170, 0.005159},{0.394138, 0.378064, 0.006206},{
      0.396056, 0.378368, 0.006206},{0.396332, 0.377517, 0.005159}}],
    Polygon[{{0.394138, 0.378064, 0.006206},{0.394138, 0.379111, 0.007100},{
      0.395732, 0.379364, 0.007100},{0.396056, 0.378368, 0.006206}}],
    Polygon[{{0.394138, 0.379111, 0.007100},{0.394138, 0.380286, 0.007820},{
      0.395369, 0.380481, 0.007820},{0.395732, 0.379364, 0.007100}}],
    Polygon[{{0.394138, 0.380286, 0.007820},{0.394138, 0.381558, 0.008347},{
      0.394976, 0.381691, 0.008347},{0.395369, 0.380481, 0.007820}}],
    Polygon[{{0.394138, 0.381558, 0.008347},{0.394138, 0.382897, 0.008668},{
      0.394562, 0.382964, 0.008668},{0.394976, 0.381691, 0.008347}}],
    Polygon[{{0.394562, 0.382964, -0.008668},{0.394976, 0.381691, -0.008347},{
      0.395732, 0.382076, -0.008347},{0.394945, 0.383159, -0.008668}}],
    Polygon[{{0.394976, 0.381691, -0.008347},{0.395369, 0.380481, -0.007820},{
      0.396480, 0.381047, -0.007820},{0.395732, 0.382076, -0.008347}}],
    Polygon[{{0.395369, 0.380481, -0.007820},{0.395732, 0.379364, -0.007100},{
      0.397170, 0.380097, -0.007100},{0.396480, 0.381047, -0.007820}}],
    Polygon[{{0.395732, 0.379364, -0.007100},{0.396056, 0.378368, -0.006206},{
      0.397786, 0.379249, -0.006206},{0.397170, 0.380097, -0.007100}}],
    Polygon[{{0.396056, 0.378368, -0.006206},{0.396332, 0.377517, -0.005159},{
      0.398311, 0.378526, -0.005159},{0.397786, 0.379249, -0.006206}}],
    Polygon[{{0.396332, 0.377517, -0.005159},{0.396554, 0.376833, -0.003984},{
      0.398734, 0.377944, -0.003984},{0.398311, 0.378526, -0.005159}}],
    Polygon[{{0.396554, 0.376833, -0.003984},{0.396717, 0.376332, -0.002712},{
      0.399044, 0.377517, -0.002712},{0.398734, 0.377944, -0.003984}}],
    Polygon[{{0.396717, 0.376332, -0.002712},{0.396816, 0.376026, -0.001373},{
      0.399233, 0.377257, -0.001373},{0.399044, 0.377517, -0.002712}}],
    Polygon[{{0.396816, 0.376026, -0.001373},{0.396850, 0.375923, 0.000000},{
      0.399296, 0.377170, 0.000000},{0.399233, 0.377257, -0.001373}}],
    Polygon[{{0.396850, 0.375923, 0.000000},{0.396816, 0.376026, 0.001373},{
      0.399233, 0.377257, 0.001373},{0.399296, 0.377170, 0.000000}}],
    Polygon[{{0.396816, 0.376026, 0.001373},{0.396717, 0.376332, 0.002712},{
      0.399044, 0.377517, 0.002712},{0.399233, 0.377257, 0.001373}}],
    Polygon[{{0.396717, 0.376332, 0.002712},{0.396554, 0.376833, 0.003984},{
      0.398734, 0.377944, 0.003984},{0.399044, 0.377517, 0.002712}}],
    Polygon[{{0.396554, 0.376833, 0.003984},{0.396332, 0.377517, 0.005159},{
      0.398311, 0.378526, 0.005159},{0.398734, 0.377944, 0.003984}}],
    Polygon[{{0.396332, 0.377517, 0.005159},{0.396056, 0.378368, 0.006206},{
      0.397786, 0.379249, 0.006206},{0.398311, 0.378526, 0.005159}}],
    Polygon[{{0.396056, 0.378368, 0.006206},{0.395732, 0.379364, 0.007100},{
      0.397170, 0.380097, 0.007100},{0.397786, 0.379249, 0.006206}}],
    Polygon[{{0.395732, 0.379364, 0.007100},{0.395369, 0.380481, 0.007820},{
      0.396480, 0.381047, 0.007820},{0.397170, 0.380097, 0.007100}}],
    Polygon[{{0.395369, 0.380481, 0.007820},{0.394976, 0.381691, 0.008347},{
      0.395732, 0.382076, 0.008347},{0.396480, 0.381047, 0.007820}}],
    Polygon[{{0.394976, 0.381691, 0.008347},{0.394562, 0.382964, 0.008668},{
      0.394945, 0.383159, 0.008668},{0.395732, 0.382076, 0.008347}}],
    Polygon[{{0.394945, 0.383159, -0.008668},{0.395732, 0.382076, -0.008347},{
      0.396332, 0.382676, -0.008347},{0.395249, 0.383463, -0.008668}}],
    Polygon[{{0.395732, 0.382076, -0.008347},{0.396480, 0.381047, -0.007820},{
      0.397361, 0.381928, -0.007820},{0.396332, 0.382676, -0.008347}}],
    Polygon[{{0.396480, 0.381047, -0.007820},{0.397170, 0.380097, -0.007100},{
      0.398311, 0.381238, -0.007100},{0.397361, 0.381928, -0.007820}}],
    Polygon[{{0.397170, 0.380097, -0.007100},{0.397786, 0.379249, -0.006206},{
      0.399158, 0.380622, -0.006206},{0.398311, 0.381238, -0.007100}}],
    Polygon[{{0.397786, 0.379249, -0.006206},{0.398311, 0.378526, -0.005159},{
      0.399882, 0.380097, -0.005159},{0.399158, 0.380622, -0.006206}}],
    Polygon[{{0.398311, 0.378526, -0.005159},{0.398734, 0.377944, -0.003984},{
      0.400464, 0.379674, -0.003984},{0.399882, 0.380097, -0.005159}}],
    Polygon[{{0.398734, 0.377944, -0.003984},{0.399044, 0.377517, -0.002712},{
      0.400891, 0.379364, -0.002712},{0.400464, 0.379674, -0.003984}}],
    Polygon[{{0.399044, 0.377517, -0.002712},{0.399233, 0.377257, -0.001373},{
      0.401151, 0.379175, -0.001373},{0.400891, 0.379364, -0.002712}}],
    Polygon[{{0.399233, 0.377257, -0.001373},{0.399296, 0.377170, 0.000000},{
      0.401238, 0.379111, 0.000000},{0.401151, 0.379175, -0.001373}}],
    Polygon[{{0.399296, 0.377170, 0.000000},{0.399233, 0.377257, 0.001373},{
      0.401151, 0.379175, 0.001373},{0.401238, 0.379111, 0.000000}}],
    Polygon[{{0.399233, 0.377257, 0.001373},{0.399044, 0.377517, 0.002712},{
      0.400891, 0.379364, 0.002712},{0.401151, 0.379175, 0.001373}}],
    Polygon[{{0.399044, 0.377517, 0.002712},{0.398734, 0.377944, 0.003984},{
      0.400464, 0.379674, 0.003984},{0.400891, 0.379364, 0.002712}}],
    Polygon[{{0.398734, 0.377944, 0.003984},{0.398311, 0.378526, 0.005159},{
      0.399882, 0.380097, 0.005159},{0.400464, 0.379674, 0.003984}}],
    Polygon[{{0.398311, 0.378526, 0.005159},{0.397786, 0.379249, 0.006206},{
      0.399158, 0.380622, 0.006206},{0.399882, 0.380097, 0.005159}}],
    Polygon[{{0.397786, 0.379249, 0.006206},{0.397170, 0.380097, 0.007100},{
      0.398311, 0.381238, 0.007100},{0.399158, 0.380622, 0.006206}}],
    Polygon[{{0.397170, 0.380097, 0.007100},{0.396480, 0.381047, 0.007820},{
      0.397361, 0.381928, 0.007820},{0.398311, 0.381238, 0.007100}}],
    Polygon[{{0.396480, 0.381047, 0.007820},{0.395732, 0.382076, 0.008347},{
      0.396332, 0.382676, 0.008347},{0.397361, 0.381928, 0.007820}}],
    Polygon[{{0.395732, 0.382076, 0.008347},{0.394945, 0.383159, 0.008668},{
      0.395249, 0.383463, 0.008668},{0.396332, 0.382676, 0.008347}}],
    Polygon[{{0.395249, 0.383463, -0.008668},{0.396332, 0.382676, -0.008347},{
      0.396717, 0.383432, -0.008347},{0.395444, 0.383846, -0.008668}}],
    Polygon[{{0.396332, 0.382676, -0.008347},{0.397361, 0.381928, -0.007820},{
      0.397927, 0.383039, -0.007820},{0.396717, 0.383432, -0.008347}}],
    Polygon[{{0.397361, 0.381928, -0.007820},{0.398311, 0.381238, -0.007100},{
      0.399044, 0.382676, -0.007100},{0.397927, 0.383039, -0.007820}}],
    Polygon[{{0.398311, 0.381238, -0.007100},{0.399158, 0.380622, -0.006206},{
      0.400040, 0.382352, -0.006206},{0.399044, 0.382676, -0.007100}}],
    Polygon[{{0.399158, 0.380622, -0.006206},{0.399882, 0.380097, -0.005159},{
      0.400891, 0.382076, -0.005159},{0.400040, 0.382352, -0.006206}}],
    Polygon[{{0.399882, 0.380097, -0.005159},{0.400464, 0.379674, -0.003984},{
      0.401575, 0.381854, -0.003984},{0.400891, 0.382076, -0.005159}}],
    Polygon[{{0.400464, 0.379674, -0.003984},{0.400891, 0.379364, -0.002712},{
      0.402076, 0.381691, -0.002712},{0.401575, 0.381854, -0.003984}}],
    Polygon[{{0.400891, 0.379364, -0.002712},{0.401151, 0.379175, -0.001373},{
      0.402382, 0.381591, -0.001373},{0.402076, 0.381691, -0.002712}}],
    Polygon[{{0.401151, 0.379175, -0.001373},{0.401238, 0.379111, 0.000000},{
      0.402485, 0.381558, 0.000000},{0.402382, 0.381591, -0.001373}}],
    Polygon[{{0.401238, 0.379111, 0.000000},{0.401151, 0.379175, 0.001373},{
      0.402382, 0.381591, 0.001373},{0.402485, 0.381558, 0.000000}}],
    Polygon[{{0.401151, 0.379175, 0.001373},{0.400891, 0.379364, 0.002712},{
      0.402076, 0.381691, 0.002712},{0.402382, 0.381591, 0.001373}}],
    Polygon[{{0.400891, 0.379364, 0.002712},{0.400464, 0.379674, 0.003984},{
      0.401575, 0.381854, 0.003984},{0.402076, 0.381691, 0.002712}}],
    Polygon[{{0.400464, 0.379674, 0.003984},{0.399882, 0.380097, 0.005159},{
      0.400891, 0.382076, 0.005159},{0.401575, 0.381854, 0.003984}}],
    Polygon[{{0.399882, 0.380097, 0.005159},{0.399158, 0.380622, 0.006206},{
      0.400040, 0.382352, 0.006206},{0.400891, 0.382076, 0.005159}}],
    Polygon[{{0.399158, 0.380622, 0.006206},{0.398311, 0.381238, 0.007100},{
      0.399044, 0.382676, 0.007100},{0.400040, 0.382352, 0.006206}}],
    Polygon[{{0.398311, 0.381238, 0.007100},{0.397361, 0.381928, 0.007820},{
      0.397927, 0.383039, 0.007820},{0.399044, 0.382676, 0.007100}}],
    Polygon[{{0.397361, 0.381928, 0.007820},{0.396332, 0.382676, 0.008347},{
      0.396717, 0.383432, 0.008347},{0.397927, 0.383039, 0.007820}}],
    Polygon[{{0.396332, 0.382676, 0.008347},{0.395249, 0.383463, 0.008668},{
      0.395444, 0.383846, 0.008668},{0.396717, 0.383432, 0.008347}}],
    Polygon[{{0.395444, 0.383846, -0.008668},{0.396717, 0.383432, -0.008347},{
      0.396850, 0.384270, -0.008347},{0.395511, 0.384270, -0.008668}}],
    Polygon[{{0.396717, 0.383432, -0.008347},{0.397927, 0.383039, -0.007820},{
      0.398122, 0.384270, -0.007820},{0.396850, 0.384270, -0.008347}}],
    Polygon[{{0.397927, 0.383039, -0.007820},{0.399044, 0.382676, -0.007100},{
      0.399296, 0.384270, -0.007100},{0.398122, 0.384270, -0.007820}}],
    Polygon[{{0.399044, 0.382676, -0.007100},{0.400040, 0.382352, -0.006206},{
      0.400344, 0.384270, -0.006206},{0.399296, 0.384270, -0.007100}}],
    Polygon[{{0.400040, 0.382352, -0.006206},{0.400891, 0.382076, -0.005159},{
      0.401238, 0.384270, -0.005159},{0.400344, 0.384270, -0.006206}}],
    Polygon[{{0.400891, 0.382076, -0.005159},{0.401575, 0.381854, -0.003984},{
      0.401958, 0.384270, -0.003984},{0.401238, 0.384270, -0.005159}}],
    Polygon[{{0.401575, 0.381854, -0.003984},{0.402076, 0.381691, -0.002712},{
      0.402485, 0.384270, -0.002712},{0.401958, 0.384270, -0.003984}}],
    Polygon[{{0.402076, 0.381691, -0.002712},{0.402382, 0.381591, -0.001373},{
      0.402806, 0.384270, -0.001373},{0.402485, 0.384270, -0.002712}}],
    Polygon[{{0.402382, 0.381591, -0.001373},{0.402485, 0.381558, 0.000000},{
      0.402914, 0.384270, 0.000000},{0.402806, 0.384270, -0.001373}}],
    Polygon[{{0.402485, 0.381558, 0.000000},{0.402382, 0.381591, 0.001373},{
      0.402806, 0.384270, 0.001373},{0.402914, 0.384270, 0.000000}}],
    Polygon[{{0.402382, 0.381591, 0.001373},{0.402076, 0.381691, 0.002712},{
      0.402485, 0.384270, 0.002712},{0.402806, 0.384270, 0.001373}}],
    Polygon[{{0.402076, 0.381691, 0.002712},{0.401575, 0.381854, 0.003984},{
      0.401958, 0.384270, 0.003984},{0.402485, 0.384270, 0.002712}}],
    Polygon[{{0.401575, 0.381854, 0.003984},{0.400891, 0.382076, 0.005159},{
      0.401238, 0.384270, 0.005159},{0.401958, 0.384270, 0.003984}}],
    Polygon[{{0.400891, 0.382076, 0.005159},{0.400040, 0.382352, 0.006206},{
      0.400344, 0.384270, 0.006206},{0.401238, 0.384270, 0.005159}}],
    Polygon[{{0.400040, 0.382352, 0.006206},{0.399044, 0.382676, 0.007100},{
      0.399296, 0.384270, 0.007100},{0.400344, 0.384270, 0.006206}}],
    Polygon[{{0.399044, 0.382676, 0.007100},{0.397927, 0.383039, 0.007820},{
      0.398122, 0.384270, 0.007820},{0.399296, 0.384270, 0.007100}}],
    Polygon[{{0.397927, 0.383039, 0.007820},{0.396717, 0.383432, 0.008347},{
      0.396850, 0.384270, 0.008347},{0.398122, 0.384270, 0.007820}}],
    Polygon[{{0.396717, 0.383432, 0.008347},{0.395444, 0.383846, 0.008668},{
      0.395511, 0.384270, 0.008668},{0.396850, 0.384270, 0.008347}}],
    Polygon[{{1.696772, 0.192450, -0.190081},{1.726137, 0.192450, -0.183031},{
      1.723226, 0.210827, -0.183031},{1.695299, 0.201753, -0.190081}}],
    Polygon[{{1.726137, 0.192450, -0.183031},{1.754037, 0.192450, -0.171474},{
      1.749761, 0.219449, -0.171474},{1.723226, 0.210827, -0.183031}}],
    Polygon[{{1.754037, 0.192450, -0.171474},{1.779786, 0.192450, -0.155695},{
      1.774250, 0.227406, -0.155695},{1.749761, 0.219449, -0.171474}}],
    Polygon[{{1.779786, 0.192450, -0.155695},{1.802749, 0.192450, -0.136083},{
      1.796089, 0.234502, -0.136083},{1.774250, 0.227406, -0.155695}}],
    Polygon[{{1.802749, 0.192450, -0.136083},{1.822362, 0.192450, -0.113119},{
      1.814742, 0.240563, -0.113119},{1.796089, 0.234502, -0.136083}}],
    Polygon[{{1.822362, 0.192450, -0.113119},{1.838141, 0.192450, -0.087371},{
      1.829748, 0.245439, -0.087371},{1.814742, 0.240563, -0.113119}}],
    Polygon[{{1.838141, 0.192450, -0.087371},{1.849698, 0.192450, -0.059470},{
      1.840739, 0.249010, -0.059470},{1.829748, 0.245439, -0.087371}}],
    Polygon[{{1.849698, 0.192450, -0.059470},{1.856747, 0.192450, -0.030106},{
      1.847444, 0.251188, -0.030106},{1.840739, 0.249010, -0.059470}}],
    Polygon[{{1.856747, 0.192450, -0.030106},{1.859117, 0.192450, 0.000000},{
      1.849698, 0.251920, 0.000000},{1.847444, 0.251188, -0.030106}}],
    Polygon[{{1.859117, 0.192450, 0.000000},{1.856747, 0.192450, 0.030106},{
      1.847444, 0.251188, 0.030106},{1.849698, 0.251920, 0.000000}}],
    Polygon[{{1.856747, 0.192450, 0.030106},{1.849698, 0.192450, 0.059470},{
      1.840739, 0.249010, 0.059470},{1.847444, 0.251188, 0.030106}}],
    Polygon[{{1.849698, 0.192450, 0.059470},{1.838141, 0.192450, 0.087371},{
      1.829748, 0.245439, 0.087371},{1.840739, 0.249010, 0.059470}}],
    Polygon[{{1.838141, 0.192450, 0.087371},{1.822362, 0.192450, 0.113119},{
      1.814742, 0.240563, 0.113119},{1.829748, 0.245439, 0.087371}}],
    Polygon[{{1.822362, 0.192450, 0.113119},{1.802749, 0.192450, 0.136083},{
      1.796089, 0.234502, 0.136083},{1.814742, 0.240563, 0.113119}}],
    Polygon[{{1.802749, 0.192450, 0.136083},{1.779786, 0.192450, 0.155695},{
      1.774250, 0.227406, 0.155695},{1.796089, 0.234502, 0.136083}}],
    Polygon[{{1.779786, 0.192450, 0.155695},{1.754037, 0.192450, 0.171474},{
      1.749761, 0.219449, 0.171474},{1.774250, 0.227406, 0.155695}}],
    Polygon[{{1.754037, 0.192450, 0.171474},{1.726137, 0.192450, 0.183031},{
      1.723226, 0.210827, 0.183031},{1.749761, 0.219449, 0.171474}}],
    Polygon[{{1.726137, 0.192450, 0.183031},{1.696772, 0.192450, 0.190081},{
      1.695299, 0.201753, 0.190081},{1.723226, 0.210827, 0.183031}}],
    Polygon[{{1.695299, 0.201753, -0.190081},{1.723226, 0.210827, -0.183031},{
      1.714779, 0.227406, -0.183031},{1.691023, 0.210146, -0.190081}}],
    Polygon[{{1.723226, 0.210827, -0.183031},{1.749761, 0.219449, -0.171474},{
      1.737351, 0.243805, -0.171474},{1.714779, 0.227406, -0.183031}}],
    Polygon[{{1.749761, 0.219449, -0.171474},{1.774250, 0.227406, -0.155695},{
      1.758182, 0.258940, -0.155695},{1.737351, 0.243805, -0.171474}}],
    Polygon[{{1.774250, 0.227406, -0.155695},{1.796089, 0.234502, -0.136083},{
      1.776760, 0.272438, -0.136083},{1.758182, 0.258940, -0.155695}}],
    Polygon[{{1.796089, 0.234502, -0.136083},{1.814742, 0.240563, -0.113119},{
      1.792627, 0.283966, -0.113119},{1.776760, 0.272438, -0.136083}}],
    Polygon[{{1.814742, 0.240563, -0.113119},{1.829748, 0.245439, -0.087371},{
      1.805392, 0.293240, -0.087371},{1.792627, 0.283966, -0.113119}}],
    Polygon[{{1.829748, 0.245439, -0.087371},{1.840739, 0.249010, -0.059470},{
      1.814742, 0.300033, -0.059470},{1.805392, 0.293240, -0.087371}}],
    Polygon[{{1.840739, 0.249010, -0.059470},{1.847444, 0.251188, -0.030106},{
      1.820445, 0.304177, -0.030106},{1.814742, 0.300033, -0.059470}}],
    Polygon[{{1.847444, 0.251188, -0.030106},{1.849698, 0.251920, 0.000000},{
      1.822362, 0.305569, 0.000000},{1.820445, 0.304177, -0.030106}}],
    Polygon[{{1.849698, 0.251920, 0.000000},{1.847444, 0.251188, 0.030106},{
      1.820445, 0.304177, 0.030106},{1.822362, 0.305569, 0.000000}}],
    Polygon[{{1.847444, 0.251188, 0.030106},{1.840739, 0.249010, 0.059470},{
      1.814742, 0.300033, 0.059470},{1.820445, 0.304177, 0.030106}}],
    Polygon[{{1.840739, 0.249010, 0.059470},{1.829748, 0.245439, 0.087371},{
      1.805392, 0.293240, 0.087371},{1.814742, 0.300033, 0.059470}}],
    Polygon[{{1.829748, 0.245439, 0.087371},{1.814742, 0.240563, 0.113119},{
      1.792627, 0.283966, 0.113119},{1.805392, 0.293240, 0.087371}}],
    Polygon[{{1.814742, 0.240563, 0.113119},{1.796089, 0.234502, 0.136083},{
      1.776760, 0.272438, 0.136083},{1.792627, 0.283966, 0.113119}}],
    Polygon[{{1.796089, 0.234502, 0.136083},{1.774250, 0.227406, 0.155695},{
      1.758182, 0.258940, 0.155695},{1.776760, 0.272438, 0.136083}}],
    Polygon[{{1.774250, 0.227406, 0.155695},{1.749761, 0.219449, 0.171474},{
      1.737351, 0.243805, 0.171474},{1.758182, 0.258940, 0.155695}}],
    Polygon[{{1.749761, 0.219449, 0.171474},{1.723226, 0.210827, 0.183031},{
      1.714779, 0.227406, 0.183031},{1.737351, 0.243805, 0.171474}}],
    Polygon[{{1.723226, 0.210827, 0.183031},{1.695299, 0.201753, 0.190081},{
      1.691023, 0.210146, 0.190081},{1.714779, 0.227406, 0.183031}}],
    Polygon[{{1.691023, 0.210146, -0.190081},{1.714779, 0.227406, -0.183031},{
      1.701622, 0.240563, -0.183031},{1.684362, 0.216806, -0.190081}}],
    Polygon[{{1.714779, 0.227406, -0.183031},{1.737351, 0.243805, -0.171474},{
      1.718022, 0.263134, -0.171474},{1.701622, 0.240563, -0.183031}}],
    Polygon[{{1.737351, 0.243805, -0.171474},{1.758182, 0.258940, -0.155695},{
      1.733157, 0.283966, -0.155695},{1.718022, 0.263134, -0.171474}}],
    Polygon[{{1.758182, 0.258940, -0.155695},{1.776760, 0.272438, -0.136083},{
      1.746654, 0.302543, -0.136083},{1.733157, 0.283966, -0.155695}}],
    Polygon[{{1.776760, 0.272438, -0.136083},{1.792627, 0.283966, -0.113119},{
      1.758182, 0.318410, -0.113119},{1.746654, 0.302543, -0.136083}}],
    Polygon[{{1.792627, 0.283966, -0.113119},{1.805392, 0.293240, -0.087371},{
      1.767457, 0.331176, -0.087371},{1.758182, 0.318410, -0.113119}}],
    Polygon[{{1.805392, 0.293240, -0.087371},{1.814742, 0.300033, -0.059470},{
      1.774250, 0.340525, -0.059470},{1.767457, 0.331176, -0.087371}}],
    Polygon[{{1.814742, 0.300033, -0.059470},{1.820445, 0.304177, -0.030106},{
      1.778393, 0.346229, -0.030106},{1.774250, 0.340525, -0.059470}}],
    Polygon[{{1.820445, 0.304177, -0.030106},{1.822362, 0.305569, 0.000000},{
      1.779786, 0.348145, 0.000000},{1.778393, 0.346229, -0.030106}}],
    Polygon[{{1.822362, 0.305569, 0.000000},{1.820445, 0.304177, 0.030106},{
      1.778393, 0.346229, 0.030106},{1.779786, 0.348145, 0.000000}}],
    Polygon[{{1.820445, 0.304177, 0.030106},{1.814742, 0.300033, 0.059470},{
      1.774250, 0.340525, 0.059470},{1.778393, 0.346229, 0.030106}}],
    Polygon[{{1.814742, 0.300033, 0.059470},{1.805392, 0.293240, 0.087371},{
      1.767457, 0.331176, 0.087371},{1.774250, 0.340525, 0.059470}}],
    Polygon[{{1.805392, 0.293240, 0.087371},{1.792627, 0.283966, 0.113119},{
      1.758182, 0.318410, 0.113119},{1.767457, 0.331176, 0.087371}}],
    Polygon[{{1.792627, 0.283966, 0.113119},{1.776760, 0.272438, 0.136083},{
      1.746654, 0.302543, 0.136083},{1.758182, 0.318410, 0.113119}}],
    Polygon[{{1.776760, 0.272438, 0.136083},{1.758182, 0.258940, 0.155695},{
      1.733157, 0.283966, 0.155695},{1.746654, 0.302543, 0.136083}}],
    Polygon[{{1.758182, 0.258940, 0.155695},{1.737351, 0.243805, 0.171474},{
      1.718022, 0.263134, 0.171474},{1.733157, 0.283966, 0.155695}}],
    Polygon[{{1.737351, 0.243805, 0.171474},{1.714779, 0.227406, 0.183031},{
      1.701622, 0.240563, 0.183031},{1.718022, 0.263134, 0.171474}}],
    Polygon[{{1.714779, 0.227406, 0.183031},{1.691023, 0.210146, 0.190081},{
      1.684362, 0.216806, 0.190081},{1.701622, 0.240563, 0.183031}}],
    Polygon[{{1.684362, 0.216806, -0.190081},{1.701622, 0.240563, -0.183031},{
      1.685044, 0.249010, -0.183031},{1.675970, 0.221082, -0.190081}}],
    Polygon[{{1.701622, 0.240563, -0.183031},{1.718022, 0.263134, -0.171474},{
      1.693666, 0.275544, -0.171474},{1.685044, 0.249010, -0.183031}}],
    Polygon[{{1.718022, 0.263134, -0.171474},{1.733157, 0.283966, -0.155695},{
      1.701622, 0.300033, -0.155695},{1.693666, 0.275544, -0.171474}}],
    Polygon[{{1.733157, 0.283966, -0.155695},{1.746654, 0.302543, -0.136083},{
      1.708719, 0.321873, -0.136083},{1.701622, 0.300033, -0.155695}}],
    Polygon[{{1.746654, 0.302543, -0.136083},{1.758182, 0.318410, -0.113119},{
      1.714779, 0.340525, -0.113119},{1.708719, 0.321873, -0.136083}}],
    Polygon[{{1.758182, 0.318410, -0.113119},{1.767457, 0.331176, -0.087371},{
      1.719655, 0.355532, -0.087371},{1.714779, 0.340525, -0.113119}}],
    Polygon[{{1.767457, 0.331176, -0.087371},{1.774250, 0.340525, -0.059470},{
      1.723226, 0.366523, -0.059470},{1.719655, 0.355532, -0.087371}}],
    Polygon[{{1.774250, 0.340525, -0.059470},{1.778393, 0.346229, -0.030106},{
      1.725405, 0.373228, -0.030106},{1.723226, 0.366523, -0.059470}}],
    Polygon[{{1.778393, 0.346229, -0.030106},{1.779786, 0.348145, 0.000000},{
      1.726137, 0.375481, 0.000000},{1.725405, 0.373228, -0.030106}}],
    Polygon[{{1.779786, 0.348145, 0.000000},{1.778393, 0.346229, 0.030106},{
      1.725405, 0.373228, 0.030106},{1.726137, 0.375481, 0.000000}}],
    Polygon[{{1.778393, 0.346229, 0.030106},{1.774250, 0.340525, 0.059470},{
      1.723226, 0.366523, 0.059470},{1.725405, 0.373228, 0.030106}}],
    Polygon[{{1.774250, 0.340525, 0.059470},{1.767457, 0.331176, 0.087371},{
      1.719655, 0.355532, 0.087371},{1.723226, 0.366523, 0.059470}}],
    Polygon[{{1.767457, 0.331176, 0.087371},{1.758182, 0.318410, 0.113119},{
      1.714779, 0.340525, 0.113119},{1.719655, 0.355532, 0.087371}}],
    Polygon[{{1.758182, 0.318410, 0.113119},{1.746654, 0.302543, 0.136083},{
      1.708719, 0.321873, 0.136083},{1.714779, 0.340525, 0.113119}}],
    Polygon[{{1.746654, 0.302543, 0.136083},{1.733157, 0.283966, 0.155695},{
      1.701622, 0.300033, 0.155695},{1.708719, 0.321873, 0.136083}}],
    Polygon[{{1.733157, 0.283966, 0.155695},{1.718022, 0.263134, 0.171474},{
      1.693666, 0.275544, 0.171474},{1.701622, 0.300033, 0.155695}}],
    Polygon[{{1.718022, 0.263134, 0.171474},{1.701622, 0.240563, 0.183031},{
      1.685044, 0.249010, 0.183031},{1.693666, 0.275544, 0.171474}}],
    Polygon[{{1.701622, 0.240563, 0.183031},{1.684362, 0.216806, 0.190081},{
      1.675970, 0.221082, 0.190081},{1.685044, 0.249010, 0.183031}}],
    Polygon[{{1.675970, 0.221082, -0.190081},{1.685044, 0.249010, -0.183031},{
      1.666667, 0.251920, -0.183031},{1.666667, 0.222556, -0.190081}}],
    Polygon[{{1.685044, 0.249010, -0.183031},{1.693666, 0.275544, -0.171474},{
      1.666667, 0.279821, -0.171474},{1.666667, 0.251920, -0.183031}}],
    Polygon[{{1.693666, 0.275544, -0.171474},{1.701622, 0.300033, -0.155695},{
      1.666667, 0.305569, -0.155695},{1.666667, 0.279821, -0.171474}}],
    Polygon[{{1.701622, 0.300033, -0.155695},{1.708719, 0.321873, -0.136083},{
      1.666667, 0.328533, -0.136083},{1.666667, 0.305569, -0.155695}}],
    Polygon[{{1.708719, 0.321873, -0.136083},{1.714779, 0.340525, -0.113119},{
      1.666667, 0.348145, -0.113119},{1.666667, 0.328533, -0.136083}}],
    Polygon[{{1.714779, 0.340525, -0.113119},{1.719655, 0.355532, -0.087371},{
      1.666667, 0.363924, -0.087371},{1.666667, 0.348145, -0.113119}}],
    Polygon[{{1.719655, 0.355532, -0.087371},{1.723226, 0.366523, -0.059470},{
      1.666667, 0.375481, -0.059470},{1.666667, 0.363924, -0.087371}}],
    Polygon[{{1.723226, 0.366523, -0.059470},{1.725405, 0.373228, -0.030106},{
      1.666667, 0.382531, -0.030106},{1.666667, 0.375481, -0.059470}}],
    Polygon[{{1.725405, 0.373228, -0.030106},{1.726137, 0.375481, 0.000000},{
      1.666667, 0.384900, 0.000000},{1.666667, 0.382531, -0.030106}}],
    Polygon[{{1.726137, 0.375481, 0.000000},{1.725405, 0.373228, 0.030106},{
      1.666667, 0.382531, 0.030106},{1.666667, 0.384900, 0.000000}}],
    Polygon[{{1.725405, 0.373228, 0.030106},{1.723226, 0.366523, 0.059470},{
      1.666667, 0.375481, 0.059470},{1.666667, 0.382531, 0.030106}}],
    Polygon[{{1.723226, 0.366523, 0.059470},{1.719655, 0.355532, 0.087371},{
      1.666667, 0.363924, 0.087371},{1.666667, 0.375481, 0.059470}}],
    Polygon[{{1.719655, 0.355532, 0.087371},{1.714779, 0.340525, 0.113119},{
      1.666667, 0.348145, 0.113119},{1.666667, 0.363924, 0.087371}}],
    Polygon[{{1.714779, 0.340525, 0.113119},{1.708719, 0.321873, 0.136083},{
      1.666667, 0.328533, 0.136083},{1.666667, 0.348145, 0.113119}}],
    Polygon[{{1.708719, 0.321873, 0.136083},{1.701622, 0.300033, 0.155695},{
      1.666667, 0.305569, 0.155695},{1.666667, 0.328533, 0.136083}}],
    Polygon[{{1.701622, 0.300033, 0.155695},{1.693666, 0.275544, 0.171474},{
      1.666667, 0.279821, 0.171474},{1.666667, 0.305569, 0.155695}}],
    Polygon[{{1.693666, 0.275544, 0.171474},{1.685044, 0.249010, 0.183031},{
      1.666667, 0.251920, 0.183031},{1.666667, 0.279821, 0.171474}}],
    Polygon[{{1.685044, 0.249010, 0.183031},{1.675970, 0.221082, 0.190081},{
      1.666667, 0.222556, 0.190081},{1.666667, 0.251920, 0.183031}}],
    Polygon[{{1.666667, 0.222556, -0.190081},{1.666667, 0.251920, -0.183031},{
      1.648289, 0.249010, -0.183031},{1.657363, 0.221082, -0.190081}}],
    Polygon[{{1.666667, 0.251920, -0.183031},{1.666667, 0.279821, -0.171474},{
      1.639668, 0.275544, -0.171474},{1.648289, 0.249010, -0.183031}}],
    Polygon[{{1.666667, 0.279821, -0.171474},{1.666667, 0.305569, -0.155695},{
      1.631711, 0.300033, -0.155695},{1.639668, 0.275544, -0.171474}}],
    Polygon[{{1.666667, 0.305569, -0.155695},{1.666667, 0.328533, -0.136083},{
      1.624615, 0.321873, -0.136083},{1.631711, 0.300033, -0.155695}}],
    Polygon[{{1.666667, 0.328533, -0.136083},{1.666667, 0.348145, -0.113119},{
      1.618554, 0.340525, -0.113119},{1.624615, 0.321873, -0.136083}}],
    Polygon[{{1.666667, 0.348145, -0.113119},{1.666667, 0.363924, -0.087371},{
      1.613678, 0.355532, -0.087371},{1.618554, 0.340525, -0.113119}}],
    Polygon[{{1.666667, 0.363924, -0.087371},{1.666667, 0.375481, -0.059470},{
      1.610107, 0.366523, -0.059470},{1.613678, 0.355532, -0.087371}}],
    Polygon[{{1.666667, 0.375481, -0.059470},{1.666667, 0.382531, -0.030106},{
      1.607929, 0.373228, -0.030106},{1.610107, 0.366523, -0.059470}}],
    Polygon[{{1.666667, 0.382531, -0.030106},{1.666667, 0.384900, 0.000000},{
      1.607196, 0.375481, 0.000000},{1.607929, 0.373228, -0.030106}}],
    Polygon[{{1.666667, 0.384900, 0.000000},{1.666667, 0.382531, 0.030106},{
      1.607929, 0.373228, 0.030106},{1.607196, 0.375481, 0.000000}}],
    Polygon[{{1.666667, 0.382531, 0.030106},{1.666667, 0.375481, 0.059470},{
      1.610107, 0.366523, 0.059470},{1.607929, 0.373228, 0.030106}}],
    Polygon[{{1.666667, 0.375481, 0.059470},{1.666667, 0.363924, 0.087371},{
      1.613678, 0.355532, 0.087371},{1.610107, 0.366523, 0.059470}}],
    Polygon[{{1.666667, 0.363924, 0.087371},{1.666667, 0.348145, 0.113119},{
      1.618554, 0.340525, 0.113119},{1.613678, 0.355532, 0.087371}}],
    Polygon[{{1.666667, 0.348145, 0.113119},{1.666667, 0.328533, 0.136083},{
      1.624615, 0.321873, 0.136083},{1.618554, 0.340525, 0.113119}}],
    Polygon[{{1.666667, 0.328533, 0.136083},{1.666667, 0.305569, 0.155695},{
      1.631711, 0.300033, 0.155695},{1.624615, 0.321873, 0.136083}}],
    Polygon[{{1.666667, 0.305569, 0.155695},{1.666667, 0.279821, 0.171474},{
      1.639668, 0.275544, 0.171474},{1.631711, 0.300033, 0.155695}}],
    Polygon[{{1.666667, 0.279821, 0.171474},{1.666667, 0.251920, 0.183031},{
      1.648289, 0.249010, 0.183031},{1.639668, 0.275544, 0.171474}}],
    Polygon[{{1.666667, 0.251920, 0.183031},{1.666667, 0.222556, 0.190081},{
      1.657363, 0.221082, 0.190081},{1.648289, 0.249010, 0.183031}}],
    Polygon[{{1.657363, 0.221082, -0.190081},{1.648289, 0.249010, -0.183031},{
      1.631711, 0.240563, -0.183031},{1.648971, 0.216806, -0.190081}}],
    Polygon[{{1.648289, 0.249010, -0.183031},{1.639668, 0.275544, -0.171474},{
      1.615312, 0.263134, -0.171474},{1.631711, 0.240563, -0.183031}}],
    Polygon[{{1.639668, 0.275544, -0.171474},{1.631711, 0.300033, -0.155695},{
      1.600177, 0.283966, -0.155695},{1.615312, 0.263134, -0.171474}}],
    Polygon[{{1.631711, 0.300033, -0.155695},{1.624615, 0.321873, -0.136083},{
      1.586679, 0.302543, -0.136083},{1.600177, 0.283966, -0.155695}}],
    Polygon[{{1.624615, 0.321873, -0.136083},{1.618554, 0.340525, -0.113119},{
      1.575151, 0.318410, -0.113119},{1.586679, 0.302543, -0.136083}}],
    Polygon[{{1.618554, 0.340525, -0.113119},{1.613678, 0.355532, -0.087371},{
      1.565877, 0.331176, -0.087371},{1.575151, 0.318410, -0.113119}}],
    Polygon[{{1.613678, 0.355532, -0.087371},{1.610107, 0.366523, -0.059470},{
      1.559084, 0.340525, -0.059470},{1.565877, 0.331176, -0.087371}}],
    Polygon[{{1.610107, 0.366523, -0.059470},{1.607929, 0.373228, -0.030106},{
      1.554940, 0.346229, -0.030106},{1.559084, 0.340525, -0.059470}}],
    Polygon[{{1.607929, 0.373228, -0.030106},{1.607196, 0.375481, 0.000000},{
      1.553547, 0.348145, 0.000000},{1.554940, 0.346229, -0.030106}}],
    Polygon[{{1.607196, 0.375481, 0.000000},{1.607929, 0.373228, 0.030106},{
      1.554940, 0.346229, 0.030106},{1.553547, 0.348145, 0.000000}}],
    Polygon[{{1.607929, 0.373228, 0.030106},{1.610107, 0.366523, 0.059470},{
      1.559084, 0.340525, 0.059470},{1.554940, 0.346229, 0.030106}}],
    Polygon[{{1.610107, 0.366523, 0.059470},{1.613678, 0.355532, 0.087371},{
      1.565877, 0.331176, 0.087371},{1.559084, 0.340525, 0.059470}}],
    Polygon[{{1.613678, 0.355532, 0.087371},{1.618554, 0.340525, 0.113119},{
      1.575151, 0.318410, 0.113119},{1.565877, 0.331176, 0.087371}}],
    Polygon[{{1.618554, 0.340525, 0.113119},{1.624615, 0.321873, 0.136083},{
      1.586679, 0.302543, 0.136083},{1.575151, 0.318410, 0.113119}}],
    Polygon[{{1.624615, 0.321873, 0.136083},{1.631711, 0.300033, 0.155695},{
      1.600177, 0.283966, 0.155695},{1.586679, 0.302543, 0.136083}}],
    Polygon[{{1.631711, 0.300033, 0.155695},{1.639668, 0.275544, 0.171474},{
      1.615312, 0.263134, 0.171474},{1.600177, 0.283966, 0.155695}}],
    Polygon[{{1.639668, 0.275544, 0.171474},{1.648289, 0.249010, 0.183031},{
      1.631711, 0.240563, 0.183031},{1.615312, 0.263134, 0.171474}}],
    Polygon[{{1.648289, 0.249010, 0.183031},{1.657363, 0.221082, 0.190081},{
      1.648971, 0.216806, 0.190081},{1.631711, 0.240563, 0.183031}}],
    Polygon[{{1.648971, 0.216806, -0.190081},{1.631711, 0.240563, -0.183031},{
      1.618554, 0.227406, -0.183031},{1.642311, 0.210146, -0.190081}}],
    Polygon[{{1.631711, 0.240563, -0.183031},{1.615312, 0.263134, -0.171474},{
      1.595982, 0.243805, -0.171474},{1.618554, 0.227406, -0.183031}}],
    Polygon[{{1.615312, 0.263134, -0.171474},{1.600177, 0.283966, -0.155695},{
      1.575151, 0.258940, -0.155695},{1.595982, 0.243805, -0.171474}}],
    Polygon[{{1.600177, 0.283966, -0.155695},{1.586679, 0.302543, -0.136083},{
      1.556573, 0.272438, -0.136083},{1.575151, 0.258940, -0.155695}}],
    Polygon[{{1.586679, 0.302543, -0.136083},{1.575151, 0.318410, -0.113119},{
      1.540706, 0.283966, -0.113119},{1.556573, 0.272438, -0.136083}}],
    Polygon[{{1.575151, 0.318410, -0.113119},{1.565877, 0.331176, -0.087371},{
      1.527941, 0.293240, -0.087371},{1.540706, 0.283966, -0.113119}}],
    Polygon[{{1.565877, 0.331176, -0.087371},{1.559084, 0.340525, -0.059470},{
      1.518592, 0.300033, -0.059470},{1.527941, 0.293240, -0.087371}}],
    Polygon[{{1.559084, 0.340525, -0.059470},{1.554940, 0.346229, -0.030106},{
      1.512888, 0.304177, -0.030106},{1.518592, 0.300033, -0.059470}}],
    Polygon[{{1.554940, 0.346229, -0.030106},{1.553547, 0.348145, 0.000000},{
      1.510971, 0.305569, 0.000000},{1.512888, 0.304177, -0.030106}}],
    Polygon[{{1.553547, 0.348145, 0.000000},{1.554940, 0.346229, 0.030106},{
      1.512888, 0.304177, 0.030106},{1.510971, 0.305569, 0.000000}}],
    Polygon[{{1.554940, 0.346229, 0.030106},{1.559084, 0.340525, 0.059470},{
      1.518592, 0.300033, 0.059470},{1.512888, 0.304177, 0.030106}}],
    Polygon[{{1.559084, 0.340525, 0.059470},{1.565877, 0.331176, 0.087371},{
      1.527941, 0.293240, 0.087371},{1.518592, 0.300033, 0.059470}}],
    Polygon[{{1.565877, 0.331176, 0.087371},{1.575151, 0.318410, 0.113119},{
      1.540706, 0.283966, 0.113119},{1.527941, 0.293240, 0.087371}}],
    Polygon[{{1.575151, 0.318410, 0.113119},{1.586679, 0.302543, 0.136083},{
      1.556573, 0.272438, 0.136083},{1.540706, 0.283966, 0.113119}}],
    Polygon[{{1.586679, 0.302543, 0.136083},{1.600177, 0.283966, 0.155695},{
      1.575151, 0.258940, 0.155695},{1.556573, 0.272438, 0.136083}}],
    Polygon[{{1.600177, 0.283966, 0.155695},{1.615312, 0.263134, 0.171474},{
      1.595982, 0.243805, 0.171474},{1.575151, 0.258940, 0.155695}}],
    Polygon[{{1.615312, 0.263134, 0.171474},{1.631711, 0.240563, 0.183031},{
      1.618554, 0.227406, 0.183031},{1.595982, 0.243805, 0.171474}}],
    Polygon[{{1.631711, 0.240563, 0.183031},{1.648971, 0.216806, 0.190081},{
      1.642311, 0.210146, 0.190081},{1.618554, 0.227406, 0.183031}}],
    Polygon[{{1.642311, 0.210146, -0.190081},{1.618554, 0.227406, -0.183031},{
      1.610107, 0.210827, -0.183031},{1.638034, 0.201753, -0.190081}}],
    Polygon[{{1.618554, 0.227406, -0.183031},{1.595982, 0.243805, -0.171474},{
      1.583572, 0.219449, -0.171474},{1.610107, 0.210827, -0.183031}}],
    Polygon[{{1.595982, 0.243805, -0.171474},{1.575151, 0.258940, -0.155695},{
      1.559084, 0.227406, -0.155695},{1.583572, 0.219449, -0.171474}}],
    Polygon[{{1.575151, 0.258940, -0.155695},{1.556573, 0.272438, -0.136083},{
      1.537244, 0.234502, -0.136083},{1.559084, 0.227406, -0.155695}}],
    Polygon[{{1.556573, 0.272438, -0.136083},{1.540706, 0.283966, -0.113119},{
      1.518592, 0.240563, -0.113119},{1.537244, 0.234502, -0.136083}}],
    Polygon[{{1.540706, 0.283966, -0.113119},{1.527941, 0.293240, -0.087371},{
      1.503585, 0.245439, -0.087371},{1.518592, 0.240563, -0.113119}}],
    Polygon[{{1.527941, 0.293240, -0.087371},{1.518592, 0.300033, -0.059470},{
      1.492594, 0.249010, -0.059470},{1.503585, 0.245439, -0.087371}}],
    Polygon[{{1.518592, 0.300033, -0.059470},{1.512888, 0.304177, -0.030106},{
      1.485889, 0.251188, -0.030106},{1.492594, 0.249010, -0.059470}}],
    Polygon[{{1.512888, 0.304177, -0.030106},{1.510971, 0.305569, 0.000000},{
      1.483636, 0.251920, 0.000000},{1.485889, 0.251188, -0.030106}}],
    Polygon[{{1.510971, 0.305569, 0.000000},{1.512888, 0.304177, 0.030106},{
      1.485889, 0.251188, 0.030106},{1.483636, 0.251920, 0.000000}}],
    Polygon[{{1.512888, 0.304177, 0.030106},{1.518592, 0.300033, 0.059470},{
      1.492594, 0.249010, 0.059470},{1.485889, 0.251188, 0.030106}}],
    Polygon[{{1.518592, 0.300033, 0.059470},{1.527941, 0.293240, 0.087371},{
      1.503585, 0.245439, 0.087371},{1.492594, 0.249010, 0.059470}}],
    Polygon[{{1.527941, 0.293240, 0.087371},{1.540706, 0.283966, 0.113119},{
      1.518592, 0.240563, 0.113119},{1.503585, 0.245439, 0.087371}}],
    Polygon[{{1.540706, 0.283966, 0.113119},{1.556573, 0.272438, 0.136083},{
      1.537244, 0.234502, 0.136083},{1.518592, 0.240563, 0.113119}}],
    Polygon[{{1.556573, 0.272438, 0.136083},{1.575151, 0.258940, 0.155695},{
      1.559084, 0.227406, 0.155695},{1.537244, 0.234502, 0.136083}}],
    Polygon[{{1.575151, 0.258940, 0.155695},{1.595982, 0.243805, 0.171474},{
      1.583572, 0.219449, 0.171474},{1.559084, 0.227406, 0.155695}}],
    Polygon[{{1.595982, 0.243805, 0.171474},{1.618554, 0.227406, 0.183031},{
      1.610107, 0.210827, 0.183031},{1.583572, 0.219449, 0.171474}}],
    Polygon[{{1.618554, 0.227406, 0.183031},{1.642311, 0.210146, 0.190081},{
      1.638034, 0.201753, 0.190081},{1.610107, 0.210827, 0.183031}}],
    Polygon[{{1.638034, 0.201753, -0.190081},{1.610107, 0.210827, -0.183031},{
      1.607196, 0.192450, -0.183031},{1.636561, 0.192450, -0.190081}}],
    Polygon[{{1.610107, 0.210827, -0.183031},{1.583572, 0.219449, -0.171474},{
      1.579296, 0.192450, -0.171474},{1.607196, 0.192450, -0.183031}}],
    Polygon[{{1.583572, 0.219449, -0.171474},{1.559084, 0.227406, -0.155695},{
      1.553547, 0.192450, -0.155695},{1.579296, 0.192450, -0.171474}}],
    Polygon[{{1.559084, 0.227406, -0.155695},{1.537244, 0.234502, -0.136083},{
      1.530584, 0.192450, -0.136083},{1.553547, 0.192450, -0.155695}}],
    Polygon[{{1.537244, 0.234502, -0.136083},{1.518592, 0.240563, -0.113119},{
      1.510971, 0.192450, -0.113119},{1.530584, 0.192450, -0.136083}}],
    Polygon[{{1.518592, 0.240563, -0.113119},{1.503585, 0.245439, -0.087371},{
      1.495192, 0.192450, -0.087371},{1.510971, 0.192450, -0.113119}}],
    Polygon[{{1.503585, 0.245439, -0.087371},{1.492594, 0.249010, -0.059470},{
      1.483636, 0.192450, -0.059470},{1.495192, 0.192450, -0.087371}}],
    Polygon[{{1.492594, 0.249010, -0.059470},{1.485889, 0.251188, -0.030106},{
      1.476586, 0.192450, -0.030106},{1.483636, 0.192450, -0.059470}}],
    Polygon[{{1.485889, 0.251188, -0.030106},{1.483636, 0.251920, 0.000000},{
      1.474217, 0.192450, 0.000000},{1.476586, 0.192450, -0.030106}}],
    Polygon[{{1.483636, 0.251920, 0.000000},{1.485889, 0.251188, 0.030106},{
      1.476586, 0.192450, 0.030106},{1.474217, 0.192450, 0.000000}}],
    Polygon[{{1.485889, 0.251188, 0.030106},{1.492594, 0.249010, 0.059470},{
      1.483636, 0.192450, 0.059470},{1.476586, 0.192450, 0.030106}}],
    Polygon[{{1.492594, 0.249010, 0.059470},{1.503585, 0.245439, 0.087371},{
      1.495192, 0.192450, 0.087371},{1.483636, 0.192450, 0.059470}}],
    Polygon[{{1.503585, 0.245439, 0.087371},{1.518592, 0.240563, 0.113119},{
      1.510971, 0.192450, 0.113119},{1.495192, 0.192450, 0.087371}}],
    Polygon[{{1.518592, 0.240563, 0.113119},{1.537244, 0.234502, 0.136083},{
      1.530584, 0.192450, 0.136083},{1.510971, 0.192450, 0.113119}}],
    Polygon[{{1.537244, 0.234502, 0.136083},{1.559084, 0.227406, 0.155695},{
      1.553547, 0.192450, 0.155695},{1.530584, 0.192450, 0.136083}}],
    Polygon[{{1.559084, 0.227406, 0.155695},{1.583572, 0.219449, 0.171474},{
      1.579296, 0.192450, 0.171474},{1.553547, 0.192450, 0.155695}}],
    Polygon[{{1.583572, 0.219449, 0.171474},{1.610107, 0.210827, 0.183031},{
      1.607196, 0.192450, 0.183031},{1.579296, 0.192450, 0.171474}}],
    Polygon[{{1.610107, 0.210827, 0.183031},{1.638034, 0.201753, 0.190081},{
      1.636561, 0.192450, 0.190081},{1.607196, 0.192450, 0.183031}}],
    Polygon[{{1.636561, 0.192450, -0.190081},{1.607196, 0.192450, -0.183031},{
      1.610107, 0.174073, -0.183031},{1.638034, 0.183147, -0.190081}}],
    Polygon[{{1.607196, 0.192450, -0.183031},{1.579296, 0.192450, -0.171474},{
      1.583572, 0.165451, -0.171474},{1.610107, 0.174073, -0.183031}}],
    Polygon[{{1.579296, 0.192450, -0.171474},{1.553547, 0.192450, -0.155695},{
      1.559084, 0.157494, -0.155695},{1.583572, 0.165451, -0.171474}}],
    Polygon[{{1.553547, 0.192450, -0.155695},{1.530584, 0.192450, -0.136083},{
      1.537244, 0.150398, -0.136083},{1.559084, 0.157494, -0.155695}}],
    Polygon[{{1.530584, 0.192450, -0.136083},{1.510971, 0.192450, -0.113119},{
      1.518592, 0.144338, -0.113119},{1.537244, 0.150398, -0.136083}}],
    Polygon[{{1.510971, 0.192450, -0.113119},{1.495192, 0.192450, -0.087371},{
      1.503585, 0.139462, -0.087371},{1.518592, 0.144338, -0.113119}}],
    Polygon[{{1.495192, 0.192450, -0.087371},{1.483636, 0.192450, -0.059470},{
      1.492594, 0.135890, -0.059470},{1.503585, 0.139462, -0.087371}}],
    Polygon[{{1.483636, 0.192450, -0.059470},{1.476586, 0.192450, -0.030106},{
      1.485889, 0.133712, -0.030106},{1.492594, 0.135890, -0.059470}}],
    Polygon[{{1.476586, 0.192450, -0.030106},{1.474217, 0.192450, 0.000000},{
      1.483636, 0.132980, 0.000000},{1.485889, 0.133712, -0.030106}}],
    Polygon[{{1.474217, 0.192450, 0.000000},{1.476586, 0.192450, 0.030106},{
      1.485889, 0.133712, 0.030106},{1.483636, 0.132980, 0.000000}}],
    Polygon[{{1.476586, 0.192450, 0.030106},{1.483636, 0.192450, 0.059470},{
      1.492594, 0.135890, 0.059470},{1.485889, 0.133712, 0.030106}}],
    Polygon[{{1.483636, 0.192450, 0.059470},{1.495192, 0.192450, 0.087371},{
      1.503585, 0.139462, 0.087371},{1.492594, 0.135890, 0.059470}}],
    Polygon[{{1.495192, 0.192450, 0.087371},{1.510971, 0.192450, 0.113119},{
      1.518592, 0.144338, 0.113119},{1.503585, 0.139462, 0.087371}}],
    Polygon[{{1.510971, 0.192450, 0.113119},{1.530584, 0.192450, 0.136083},{
      1.537244, 0.150398, 0.136083},{1.518592, 0.144338, 0.113119}}],
    Polygon[{{1.530584, 0.192450, 0.136083},{1.553547, 0.192450, 0.155695},{
      1.559084, 0.157494, 0.155695},{1.537244, 0.150398, 0.136083}}],
    Polygon[{{1.553547, 0.192450, 0.155695},{1.579296, 0.192450, 0.171474},{
      1.583572, 0.165451, 0.171474},{1.559084, 0.157494, 0.155695}}],
    Polygon[{{1.579296, 0.192450, 0.171474},{1.607196, 0.192450, 0.183031},{
      1.610107, 0.174073, 0.183031},{1.583572, 0.165451, 0.171474}}],
    Polygon[{{1.607196, 0.192450, 0.183031},{1.636561, 0.192450, 0.190081},{
      1.638034, 0.183147, 0.190081},{1.610107, 0.174073, 0.183031}}],
    Polygon[{{1.638034, 0.183147, -0.190081},{1.610107, 0.174073, -0.183031},{
      1.618554, 0.157494, -0.183031},{1.642311, 0.174754, -0.190081}}],
    Polygon[{{1.610107, 0.174073, -0.183031},{1.583572, 0.165451, -0.171474},{
      1.595982, 0.141095, -0.171474},{1.618554, 0.157494, -0.183031}}],
    Polygon[{{1.583572, 0.165451, -0.171474},{1.559084, 0.157494, -0.155695},{
      1.575151, 0.125960, -0.155695},{1.595982, 0.141095, -0.171474}}],
    Polygon[{{1.559084, 0.157494, -0.155695},{1.537244, 0.150398, -0.136083},{
      1.556573, 0.112463, -0.136083},{1.575151, 0.125960, -0.155695}}],
    Polygon[{{1.537244, 0.150398, -0.136083},{1.518592, 0.144338, -0.113119},{
      1.540706, 0.100935, -0.113119},{1.556573, 0.112463, -0.136083}}],
    Polygon[{{1.518592, 0.144338, -0.113119},{1.503585, 0.139462, -0.087371},{
      1.527941, 0.091660, -0.087371},{1.540706, 0.100935, -0.113119}}],
    Polygon[{{1.503585, 0.139462, -0.087371},{1.492594, 0.135890, -0.059470},{
      1.518592, 0.084867, -0.059470},{1.527941, 0.091660, -0.087371}}],
    Polygon[{{1.492594, 0.135890, -0.059470},{1.485889, 0.133712, -0.030106},{
      1.512888, 0.080723, -0.030106},{1.518592, 0.084867, -0.059470}}],
    Polygon[{{1.485889, 0.133712, -0.030106},{1.483636, 0.132980, 0.000000},{
      1.510971, 0.079331, 0.000000},{1.512888, 0.080723, -0.030106}}],
    Polygon[{{1.483636, 0.132980, 0.000000},{1.485889, 0.133712, 0.030106},{
      1.512888, 0.080723, 0.030106},{1.510971, 0.079331, 0.000000}}],
    Polygon[{{1.485889, 0.133712, 0.030106},{1.492594, 0.135890, 0.059470},{
      1.518592, 0.084867, 0.059470},{1.512888, 0.080723, 0.030106}}],
    Polygon[{{1.492594, 0.135890, 0.059470},{1.503585, 0.139462, 0.087371},{
      1.527941, 0.091660, 0.087371},{1.518592, 0.084867, 0.059470}}],
    Polygon[{{1.503585, 0.139462, 0.087371},{1.518592, 0.144338, 0.113119},{
      1.540706, 0.100935, 0.113119},{1.527941, 0.091660, 0.087371}}],
    Polygon[{{1.518592, 0.144338, 0.113119},{1.537244, 0.150398, 0.136083},{
      1.556573, 0.112463, 0.136083},{1.540706, 0.100935, 0.113119}}],
    Polygon[{{1.537244, 0.150398, 0.136083},{1.559084, 0.157494, 0.155695},{
      1.575151, 0.125960, 0.155695},{1.556573, 0.112463, 0.136083}}],
    Polygon[{{1.559084, 0.157494, 0.155695},{1.583572, 0.165451, 0.171474},{
      1.595982, 0.141095, 0.171474},{1.575151, 0.125960, 0.155695}}],
    Polygon[{{1.583572, 0.165451, 0.171474},{1.610107, 0.174073, 0.183031},{
      1.618554, 0.157494, 0.183031},{1.595982, 0.141095, 0.171474}}],
    Polygon[{{1.610107, 0.174073, 0.183031},{1.638034, 0.183147, 0.190081},{
      1.642311, 0.174754, 0.190081},{1.618554, 0.157494, 0.183031}}],
    Polygon[{{1.642311, 0.174754, -0.190081},{1.618554, 0.157494, -0.183031},{
      1.631711, 0.144338, -0.183031},{1.648971, 0.168094, -0.190081}}],
    Polygon[{{1.618554, 0.157494, -0.183031},{1.595982, 0.141095, -0.171474},{
      1.615312, 0.121766, -0.171474},{1.631711, 0.144338, -0.183031}}],
    Polygon[{{1.595982, 0.141095, -0.171474},{1.575151, 0.125960, -0.155695},{
      1.600177, 0.100935, -0.155695},{1.615312, 0.121766, -0.171474}}],
    Polygon[{{1.575151, 0.125960, -0.155695},{1.556573, 0.112463, -0.136083},{
      1.586679, 0.082357, -0.136083},{1.600177, 0.100935, -0.155695}}],
    Polygon[{{1.556573, 0.112463, -0.136083},{1.540706, 0.100935, -0.113119},{
      1.575151, 0.066490, -0.113119},{1.586679, 0.082357, -0.136083}}],
    Polygon[{{1.540706, 0.100935, -0.113119},{1.527941, 0.091660, -0.087371},{
      1.565877, 0.053724, -0.087371},{1.575151, 0.066490, -0.113119}}],
    Polygon[{{1.527941, 0.091660, -0.087371},{1.518592, 0.084867, -0.059470},{
      1.559084, 0.044375, -0.059470},{1.565877, 0.053724, -0.087371}}],
    Polygon[{{1.518592, 0.084867, -0.059470},{1.512888, 0.080723, -0.030106},{
      1.554940, 0.038672, -0.030106},{1.559084, 0.044375, -0.059470}}],
    Polygon[{{1.512888, 0.080723, -0.030106},{1.510971, 0.079331, 0.000000},{
      1.553547, 0.036755, 0.000000},{1.554940, 0.038672, -0.030106}}],
    Polygon[{{1.510971, 0.079331, 0.000000},{1.512888, 0.080723, 0.030106},{
      1.554940, 0.038672, 0.030106},{1.553547, 0.036755, 0.000000}}],
    Polygon[{{1.512888, 0.080723, 0.030106},{1.518592, 0.084867, 0.059470},{
      1.559084, 0.044375, 0.059470},{1.554940, 0.038672, 0.030106}}],
    Polygon[{{1.518592, 0.084867, 0.059470},{1.527941, 0.091660, 0.087371},{
      1.565877, 0.053724, 0.087371},{1.559084, 0.044375, 0.059470}}],
    Polygon[{{1.527941, 0.091660, 0.087371},{1.540706, 0.100935, 0.113119},{
      1.575151, 0.066490, 0.113119},{1.565877, 0.053724, 0.087371}}],
    Polygon[{{1.540706, 0.100935, 0.113119},{1.556573, 0.112463, 0.136083},{
      1.586679, 0.082357, 0.136083},{1.575151, 0.066490, 0.113119}}],
    Polygon[{{1.556573, 0.112463, 0.136083},{1.575151, 0.125960, 0.155695},{
      1.600177, 0.100935, 0.155695},{1.586679, 0.082357, 0.136083}}],
    Polygon[{{1.575151, 0.125960, 0.155695},{1.595982, 0.141095, 0.171474},{
      1.615312, 0.121766, 0.171474},{1.600177, 0.100935, 0.155695}}],
    Polygon[{{1.595982, 0.141095, 0.171474},{1.618554, 0.157494, 0.183031},{
      1.631711, 0.144338, 0.183031},{1.615312, 0.121766, 0.171474}}],
    Polygon[{{1.618554, 0.157494, 0.183031},{1.642311, 0.174754, 0.190081},{
      1.648971, 0.168094, 0.190081},{1.631711, 0.144338, 0.183031}}],
    Polygon[{{1.648971, 0.168094, -0.190081},{1.631711, 0.144338, -0.183031},{
      1.648289, 0.135890, -0.183031},{1.657363, 0.163818, -0.190081}}],
    Polygon[{{1.631711, 0.144338, -0.183031},{1.615312, 0.121766, -0.171474},{
      1.639668, 0.109356, -0.171474},{1.648289, 0.135890, -0.183031}}],
    Polygon[{{1.615312, 0.121766, -0.171474},{1.600177, 0.100935, -0.155695},{
      1.631711, 0.084867, -0.155695},{1.639668, 0.109356, -0.171474}}],
    Polygon[{{1.600177, 0.100935, -0.155695},{1.586679, 0.082357, -0.136083},{
      1.624615, 0.063028, -0.136083},{1.631711, 0.084867, -0.155695}}],
    Polygon[{{1.586679, 0.082357, -0.136083},{1.575151, 0.066490, -0.113119},{
      1.618554, 0.044375, -0.113119},{1.624615, 0.063028, -0.136083}}],
    Polygon[{{1.575151, 0.066490, -0.113119},{1.565877, 0.053724, -0.087371},{
      1.613678, 0.029368, -0.087371},{1.618554, 0.044375, -0.113119}}],
    Polygon[{{1.565877, 0.053724, -0.087371},{1.559084, 0.044375, -0.059470},{
      1.610107, 0.018377, -0.059470},{1.613678, 0.029368, -0.087371}}],
    Polygon[{{1.559084, 0.044375, -0.059470},{1.554940, 0.038672, -0.030106},{
      1.607929, 0.011673, -0.030106},{1.610107, 0.018377, -0.059470}}],
    Polygon[{{1.554940, 0.038672, -0.030106},{1.553547, 0.036755, 0.000000},{
      1.607196, 0.009419, 0.000000},{1.607929, 0.011673, -0.030106}}],
    Polygon[{{1.553547, 0.036755, 0.000000},{1.554940, 0.038672, 0.030106},{
      1.607929, 0.011673, 0.030106},{1.607196, 0.009419, 0.000000}}],
    Polygon[{{1.554940, 0.038672, 0.030106},{1.559084, 0.044375, 0.059470},{
      1.610107, 0.018377, 0.059470},{1.607929, 0.011673, 0.030106}}],
    Polygon[{{1.559084, 0.044375, 0.059470},{1.565877, 0.053724, 0.087371},{
      1.613678, 0.029368, 0.087371},{1.610107, 0.018377, 0.059470}}],
    Polygon[{{1.565877, 0.053724, 0.087371},{1.575151, 0.066490, 0.113119},{
      1.618554, 0.044375, 0.113119},{1.613678, 0.029368, 0.087371}}],
    Polygon[{{1.575151, 0.066490, 0.113119},{1.586679, 0.082357, 0.136083},{
      1.624615, 0.063028, 0.136083},{1.618554, 0.044375, 0.113119}}],
    Polygon[{{1.586679, 0.082357, 0.136083},{1.600177, 0.100935, 0.155695},{
      1.631711, 0.084867, 0.155695},{1.624615, 0.063028, 0.136083}}],
    Polygon[{{1.600177, 0.100935, 0.155695},{1.615312, 0.121766, 0.171474},{
      1.639668, 0.109356, 0.171474},{1.631711, 0.084867, 0.155695}}],
    Polygon[{{1.615312, 0.121766, 0.171474},{1.631711, 0.144338, 0.183031},{
      1.648289, 0.135890, 0.183031},{1.639668, 0.109356, 0.171474}}],
    Polygon[{{1.631711, 0.144338, 0.183031},{1.648971, 0.168094, 0.190081},{
      1.657363, 0.163818, 0.190081},{1.648289, 0.135890, 0.183031}}],
    Polygon[{{1.657363, 0.163818, -0.190081},{1.648289, 0.135890, -0.183031},{
      1.666667, 0.132980, -0.183031},{1.666667, 0.162344, -0.190081}}],
    Polygon[{{1.648289, 0.135890, -0.183031},{1.639668, 0.109356, -0.171474},{
      1.666667, 0.105080, -0.171474},{1.666667, 0.132980, -0.183031}}],
    Polygon[{{1.639668, 0.109356, -0.171474},{1.631711, 0.084867, -0.155695},{
      1.666667, 0.079331, -0.155695},{1.666667, 0.105080, -0.171474}}],
    Polygon[{{1.631711, 0.084867, -0.155695},{1.624615, 0.063028, -0.136083},{
      1.666667, 0.056367, -0.136083},{1.666667, 0.079331, -0.155695}}],
    Polygon[{{1.624615, 0.063028, -0.136083},{1.618554, 0.044375, -0.113119},{
      1.666667, 0.036755, -0.113119},{1.666667, 0.056367, -0.136083}}],
    Polygon[{{1.618554, 0.044375, -0.113119},{1.613678, 0.029368, -0.087371},{
      1.666667, 0.020976, -0.087371},{1.666667, 0.036755, -0.113119}}],
    Polygon[{{1.613678, 0.029368, -0.087371},{1.610107, 0.018377, -0.059470},{
      1.666667, 0.009419, -0.059470},{1.666667, 0.020976, -0.087371}}],
    Polygon[{{1.610107, 0.018377, -0.059470},{1.607929, 0.011673, -0.030106},{
      1.666667, 0.002369, -0.030106},{1.666667, 0.009419, -0.059470}}],
    Polygon[{{1.607929, 0.011673, -0.030106},{1.607196, 0.009419, 0.000000},{
      1.666667, 0.000000, 0.000000},{1.666667, 0.002369, -0.030106}}],
    Polygon[{{1.607196, 0.009419, 0.000000},{1.607929, 0.011673, 0.030106},{
      1.666667, 0.002369, 0.030106},{1.666667, 0.000000, 0.000000}}],
    Polygon[{{1.607929, 0.011673, 0.030106},{1.610107, 0.018377, 0.059470},{
      1.666667, 0.009419, 0.059470},{1.666667, 0.002369, 0.030106}}],
    Polygon[{{1.610107, 0.018377, 0.059470},{1.613678, 0.029368, 0.087371},{
      1.666667, 0.020976, 0.087371},{1.666667, 0.009419, 0.059470}}],
    Polygon[{{1.613678, 0.029368, 0.087371},{1.618554, 0.044375, 0.113119},{
      1.666667, 0.036755, 0.113119},{1.666667, 0.020976, 0.087371}}],
    Polygon[{{1.618554, 0.044375, 0.113119},{1.624615, 0.063028, 0.136083},{
      1.666667, 0.056367, 0.136083},{1.666667, 0.036755, 0.113119}}],
    Polygon[{{1.624615, 0.063028, 0.136083},{1.631711, 0.084867, 0.155695},{
      1.666667, 0.079331, 0.155695},{1.666667, 0.056367, 0.136083}}],
    Polygon[{{1.631711, 0.084867, 0.155695},{1.639668, 0.109356, 0.171474},{
      1.666667, 0.105080, 0.171474},{1.666667, 0.079331, 0.155695}}],
    Polygon[{{1.639668, 0.109356, 0.171474},{1.648289, 0.135890, 0.183031},{
      1.666667, 0.132980, 0.183031},{1.666667, 0.105080, 0.171474}}],
    Polygon[{{1.648289, 0.135890, 0.183031},{1.657363, 0.163818, 0.190081},{
      1.666667, 0.162344, 0.190081},{1.666667, 0.132980, 0.183031}}],
    Polygon[{{1.666667, 0.162344, -0.190081},{1.666667, 0.132980, -0.183031},{
      1.685044, 0.135890, -0.183031},{1.675970, 0.163818, -0.190081}}],
    Polygon[{{1.666667, 0.132980, -0.183031},{1.666667, 0.105080, -0.171474},{
      1.693666, 0.109356, -0.171474},{1.685044, 0.135890, -0.183031}}],
    Polygon[{{1.666667, 0.105080, -0.171474},{1.666667, 0.079331, -0.155695},{
      1.701622, 0.084867, -0.155695},{1.693666, 0.109356, -0.171474}}],
    Polygon[{{1.666667, 0.079331, -0.155695},{1.666667, 0.056367, -0.136083},{
      1.708719, 0.063028, -0.136083},{1.701622, 0.084867, -0.155695}}],
    Polygon[{{1.666667, 0.056367, -0.136083},{1.666667, 0.036755, -0.113119},{
      1.714779, 0.044375, -0.113119},{1.708719, 0.063028, -0.136083}}],
    Polygon[{{1.666667, 0.036755, -0.113119},{1.666667, 0.020976, -0.087371},{
      1.719655, 0.029368, -0.087371},{1.714779, 0.044375, -0.113119}}],
    Polygon[{{1.666667, 0.020976, -0.087371},{1.666667, 0.009419, -0.059470},{
      1.723226, 0.018377, -0.059470},{1.719655, 0.029368, -0.087371}}],
    Polygon[{{1.666667, 0.009419, -0.059470},{1.666667, 0.002369, -0.030106},{
      1.725405, 0.011673, -0.030106},{1.723226, 0.018377, -0.059470}}],
    Polygon[{{1.666667, 0.002369, -0.030106},{1.666667, 0.000000, 0.000000},{
      1.726137, 0.009419, 0.000000},{1.725405, 0.011673, -0.030106}}],
    Polygon[{{1.666667, 0.000000, 0.000000},{1.666667, 0.002369, 0.030106},{
      1.725405, 0.011673, 0.030106},{1.726137, 0.009419, 0.000000}}],
    Polygon[{{1.666667, 0.002369, 0.030106},{1.666667, 0.009419, 0.059470},{
      1.723226, 0.018377, 0.059470},{1.725405, 0.011673, 0.030106}}],
    Polygon[{{1.666667, 0.009419, 0.059470},{1.666667, 0.020976, 0.087371},{
      1.719655, 0.029368, 0.087371},{1.723226, 0.018377, 0.059470}}],
    Polygon[{{1.666667, 0.020976, 0.087371},{1.666667, 0.036755, 0.113119},{
      1.714779, 0.044375, 0.113119},{1.719655, 0.029368, 0.087371}}],
    Polygon[{{1.666667, 0.036755, 0.113119},{1.666667, 0.056367, 0.136083},{
      1.708719, 0.063028, 0.136083},{1.714779, 0.044375, 0.113119}}],
    Polygon[{{1.666667, 0.056367, 0.136083},{1.666667, 0.079331, 0.155695},{
      1.701622, 0.084867, 0.155695},{1.708719, 0.063028, 0.136083}}],
    Polygon[{{1.666667, 0.079331, 0.155695},{1.666667, 0.105080, 0.171474},{
      1.693666, 0.109356, 0.171474},{1.701622, 0.084867, 0.155695}}],
    Polygon[{{1.666667, 0.105080, 0.171474},{1.666667, 0.132980, 0.183031},{
      1.685044, 0.135890, 0.183031},{1.693666, 0.109356, 0.171474}}],
    Polygon[{{1.666667, 0.132980, 0.183031},{1.666667, 0.162344, 0.190081},{
      1.675970, 0.163818, 0.190081},{1.685044, 0.135890, 0.183031}}],
    Polygon[{{1.675970, 0.163818, -0.190081},{1.685044, 0.135890, -0.183031},{
      1.701622, 0.144338, -0.183031},{1.684362, 0.168094, -0.190081}}],
    Polygon[{{1.685044, 0.135890, -0.183031},{1.693666, 0.109356, -0.171474},{
      1.718022, 0.121766, -0.171474},{1.701622, 0.144338, -0.183031}}],
    Polygon[{{1.693666, 0.109356, -0.171474},{1.701622, 0.084867, -0.155695},{
      1.733157, 0.100935, -0.155695},{1.718022, 0.121766, -0.171474}}],
    Polygon[{{1.701622, 0.084867, -0.155695},{1.708719, 0.063028, -0.136083},{
      1.746654, 0.082357, -0.136083},{1.733157, 0.100935, -0.155695}}],
    Polygon[{{1.708719, 0.063028, -0.136083},{1.714779, 0.044375, -0.113119},{
      1.758182, 0.066490, -0.113119},{1.746654, 0.082357, -0.136083}}],
    Polygon[{{1.714779, 0.044375, -0.113119},{1.719655, 0.029368, -0.087371},{
      1.767457, 0.053724, -0.087371},{1.758182, 0.066490, -0.113119}}],
    Polygon[{{1.719655, 0.029368, -0.087371},{1.723226, 0.018377, -0.059470},{
      1.774250, 0.044375, -0.059470},{1.767457, 0.053724, -0.087371}}],
    Polygon[{{1.723226, 0.018377, -0.059470},{1.725405, 0.011673, -0.030106},{
      1.778393, 0.038672, -0.030106},{1.774250, 0.044375, -0.059470}}],
    Polygon[{{1.725405, 0.011673, -0.030106},{1.726137, 0.009419, 0.000000},{
      1.779786, 0.036755, 0.000000},{1.778393, 0.038672, -0.030106}}],
    Polygon[{{1.726137, 0.009419, 0.000000},{1.725405, 0.011673, 0.030106},{
      1.778393, 0.038672, 0.030106},{1.779786, 0.036755, 0.000000}}],
    Polygon[{{1.725405, 0.011673, 0.030106},{1.723226, 0.018377, 0.059470},{
      1.774250, 0.044375, 0.059470},{1.778393, 0.038672, 0.030106}}],
    Polygon[{{1.723226, 0.018377, 0.059470},{1.719655, 0.029368, 0.087371},{
      1.767457, 0.053724, 0.087371},{1.774250, 0.044375, 0.059470}}],
    Polygon[{{1.719655, 0.029368, 0.087371},{1.714779, 0.044375, 0.113119},{
      1.758182, 0.066490, 0.113119},{1.767457, 0.053724, 0.087371}}],
    Polygon[{{1.714779, 0.044375, 0.113119},{1.708719, 0.063028, 0.136083},{
      1.746654, 0.082357, 0.136083},{1.758182, 0.066490, 0.113119}}],
    Polygon[{{1.708719, 0.063028, 0.136083},{1.701622, 0.084867, 0.155695},{
      1.733157, 0.100935, 0.155695},{1.746654, 0.082357, 0.136083}}],
    Polygon[{{1.701622, 0.084867, 0.155695},{1.693666, 0.109356, 0.171474},{
      1.718022, 0.121766, 0.171474},{1.733157, 0.100935, 0.155695}}],
    Polygon[{{1.693666, 0.109356, 0.171474},{1.685044, 0.135890, 0.183031},{
      1.701622, 0.144338, 0.183031},{1.718022, 0.121766, 0.171474}}],
    Polygon[{{1.685044, 0.135890, 0.183031},{1.675970, 0.163818, 0.190081},{
      1.684362, 0.168094, 0.190081},{1.701622, 0.144338, 0.183031}}],
    Polygon[{{1.684362, 0.168094, -0.190081},{1.701622, 0.144338, -0.183031},{
      1.714779, 0.157494, -0.183031},{1.691023, 0.174754, -0.190081}}],
    Polygon[{{1.701622, 0.144338, -0.183031},{1.718022, 0.121766, -0.171474},{
      1.737351, 0.141095, -0.171474},{1.714779, 0.157494, -0.183031}}],
    Polygon[{{1.718022, 0.121766, -0.171474},{1.733157, 0.100935, -0.155695},{
      1.758182, 0.125960, -0.155695},{1.737351, 0.141095, -0.171474}}],
    Polygon[{{1.733157, 0.100935, -0.155695},{1.746654, 0.082357, -0.136083},{
      1.776760, 0.112463, -0.136083},{1.758182, 0.125960, -0.155695}}],
    Polygon[{{1.746654, 0.082357, -0.136083},{1.758182, 0.066490, -0.113119},{
      1.792627, 0.100935, -0.113119},{1.776760, 0.112463, -0.136083}}],
    Polygon[{{1.758182, 0.066490, -0.113119},{1.767457, 0.053724, -0.087371},{
      1.805392, 0.091660, -0.087371},{1.792627, 0.100935, -0.113119}}],
    Polygon[{{1.767457, 0.053724, -0.087371},{1.774250, 0.044375, -0.059470},{
      1.814742, 0.084867, -0.059470},{1.805392, 0.091660, -0.087371}}],
    Polygon[{{1.774250, 0.044375, -0.059470},{1.778393, 0.038672, -0.030106},{
      1.820445, 0.080723, -0.030106},{1.814742, 0.084867, -0.059470}}],
    Polygon[{{1.778393, 0.038672, -0.030106},{1.779786, 0.036755, 0.000000},{
      1.822362, 0.079331, 0.000000},{1.820445, 0.080723, -0.030106}}],
    Polygon[{{1.779786, 0.036755, 0.000000},{1.778393, 0.038672, 0.030106},{
      1.820445, 0.080723, 0.030106},{1.822362, 0.079331, 0.000000}}],
    Polygon[{{1.778393, 0.038672, 0.030106},{1.774250, 0.044375, 0.059470},{
      1.814742, 0.084867, 0.059470},{1.820445, 0.080723, 0.030106}}],
    Polygon[{{1.774250, 0.044375, 0.059470},{1.767457, 0.053724, 0.087371},{
      1.805392, 0.091660, 0.087371},{1.814742, 0.084867, 0.059470}}],
    Polygon[{{1.767457, 0.053724, 0.087371},{1.758182, 0.066490, 0.113119},{
      1.792627, 0.100935, 0.113119},{1.805392, 0.091660, 0.087371}}],
    Polygon[{{1.758182, 0.066490, 0.113119},{1.746654, 0.082357, 0.136083},{
      1.776760, 0.112463, 0.136083},{1.792627, 0.100935, 0.113119}}],
    Polygon[{{1.746654, 0.082357, 0.136083},{1.733157, 0.100935, 0.155695},{
      1.758182, 0.125960, 0.155695},{1.776760, 0.112463, 0.136083}}],
    Polygon[{{1.733157, 0.100935, 0.155695},{1.718022, 0.121766, 0.171474},{
      1.737351, 0.141095, 0.171474},{1.758182, 0.125960, 0.155695}}],
    Polygon[{{1.718022, 0.121766, 0.171474},{1.701622, 0.144338, 0.183031},{
      1.714779, 0.157494, 0.183031},{1.737351, 0.141095, 0.171474}}],
    Polygon[{{1.701622, 0.144338, 0.183031},{1.684362, 0.168094, 0.190081},{
      1.691023, 0.174754, 0.190081},{1.714779, 0.157494, 0.183031}}],
    Polygon[{{1.691023, 0.174754, -0.190081},{1.714779, 0.157494, -0.183031},{
      1.723226, 0.174073, -0.183031},{1.695299, 0.183147, -0.190081}}],
    Polygon[{{1.714779, 0.157494, -0.183031},{1.737351, 0.141095, -0.171474},{
      1.749761, 0.165451, -0.171474},{1.723226, 0.174073, -0.183031}}],
    Polygon[{{1.737351, 0.141095, -0.171474},{1.758182, 0.125960, -0.155695},{
      1.774250, 0.157494, -0.155695},{1.749761, 0.165451, -0.171474}}],
    Polygon[{{1.758182, 0.125960, -0.155695},{1.776760, 0.112463, -0.136083},{
      1.796089, 0.150398, -0.136083},{1.774250, 0.157494, -0.155695}}],
    Polygon[{{1.776760, 0.112463, -0.136083},{1.792627, 0.100935, -0.113119},{
      1.814742, 0.144338, -0.113119},{1.796089, 0.150398, -0.136083}}],
    Polygon[{{1.792627, 0.100935, -0.113119},{1.805392, 0.091660, -0.087371},{
      1.829748, 0.139462, -0.087371},{1.814742, 0.144338, -0.113119}}],
    Polygon[{{1.805392, 0.091660, -0.087371},{1.814742, 0.084867, -0.059470},{
      1.840739, 0.135890, -0.059470},{1.829748, 0.139462, -0.087371}}],
    Polygon[{{1.814742, 0.084867, -0.059470},{1.820445, 0.080723, -0.030106},{
      1.847444, 0.133712, -0.030106},{1.840739, 0.135890, -0.059470}}],
    Polygon[{{1.820445, 0.080723, -0.030106},{1.822362, 0.079331, 0.000000},{
      1.849698, 0.132980, 0.000000},{1.847444, 0.133712, -0.030106}}],
    Polygon[{{1.822362, 0.079331, 0.000000},{1.820445, 0.080723, 0.030106},{
      1.847444, 0.133712, 0.030106},{1.849698, 0.132980, 0.000000}}],
    Polygon[{{1.820445, 0.080723, 0.030106},{1.814742, 0.084867, 0.059470},{
      1.840739, 0.135890, 0.059470},{1.847444, 0.133712, 0.030106}}],
    Polygon[{{1.814742, 0.084867, 0.059470},{1.805392, 0.091660, 0.087371},{
      1.829748, 0.139462, 0.087371},{1.840739, 0.135890, 0.059470}}],
    Polygon[{{1.805392, 0.091660, 0.087371},{1.792627, 0.100935, 0.113119},{
      1.814742, 0.144338, 0.113119},{1.829748, 0.139462, 0.087371}}],
    Polygon[{{1.792627, 0.100935, 0.113119},{1.776760, 0.112463, 0.136083},{
      1.796089, 0.150398, 0.136083},{1.814742, 0.144338, 0.113119}}],
    Polygon[{{1.776760, 0.112463, 0.136083},{1.758182, 0.125960, 0.155695},{
      1.774250, 0.157494, 0.155695},{1.796089, 0.150398, 0.136083}}],
    Polygon[{{1.758182, 0.125960, 0.155695},{1.737351, 0.141095, 0.171474},{
      1.749761, 0.165451, 0.171474},{1.774250, 0.157494, 0.155695}}],
    Polygon[{{1.737351, 0.141095, 0.171474},{1.714779, 0.157494, 0.183031},{
      1.723226, 0.174073, 0.183031},{1.749761, 0.165451, 0.171474}}],
    Polygon[{{1.714779, 0.157494, 0.183031},{1.691023, 0.174754, 0.190081},{
      1.695299, 0.183147, 0.190081},{1.723226, 0.174073, 0.183031}}],
    Polygon[{{1.695299, 0.183147, -0.190081},{1.723226, 0.174073, -0.183031},{
      1.726137, 0.192450, -0.183031},{1.696772, 0.192450, -0.190081}}],
    Polygon[{{1.723226, 0.174073, -0.183031},{1.749761, 0.165451, -0.171474},{
      1.754037, 0.192450, -0.171474},{1.726137, 0.192450, -0.183031}}],
    Polygon[{{1.749761, 0.165451, -0.171474},{1.774250, 0.157494, -0.155695},{
      1.779786, 0.192450, -0.155695},{1.754037, 0.192450, -0.171474}}],
    Polygon[{{1.774250, 0.157494, -0.155695},{1.796089, 0.150398, -0.136083},{
      1.802749, 0.192450, -0.136083},{1.779786, 0.192450, -0.155695}}],
    Polygon[{{1.796089, 0.150398, -0.136083},{1.814742, 0.144338, -0.113119},{
      1.822362, 0.192450, -0.113119},{1.802749, 0.192450, -0.136083}}],
    Polygon[{{1.814742, 0.144338, -0.113119},{1.829748, 0.139462, -0.087371},{
      1.838141, 0.192450, -0.087371},{1.822362, 0.192450, -0.113119}}],
    Polygon[{{1.829748, 0.139462, -0.087371},{1.840739, 0.135890, -0.059470},{
      1.849698, 0.192450, -0.059470},{1.838141, 0.192450, -0.087371}}],
    Polygon[{{1.840739, 0.135890, -0.059470},{1.847444, 0.133712, -0.030106},{
      1.856747, 0.192450, -0.030106},{1.849698, 0.192450, -0.059470}}],
    Polygon[{{1.847444, 0.133712, -0.030106},{1.849698, 0.132980, 0.000000},{
      1.859117, 0.192450, 0.000000},{1.856747, 0.192450, -0.030106}}],
    Polygon[{{1.849698, 0.132980, 0.000000},{1.847444, 0.133712, 0.030106},{
      1.856747, 0.192450, 0.030106},{1.859117, 0.192450, 0.000000}}],
    Polygon[{{1.847444, 0.133712, 0.030106},{1.840739, 0.135890, 0.059470},{
      1.849698, 0.192450, 0.059470},{1.856747, 0.192450, 0.030106}}],
    Polygon[{{1.840739, 0.135890, 0.059470},{1.829748, 0.139462, 0.087371},{
      1.838141, 0.192450, 0.087371},{1.849698, 0.192450, 0.059470}}],
    Polygon[{{1.829748, 0.139462, 0.087371},{1.814742, 0.144338, 0.113119},{
      1.822362, 0.192450, 0.113119},{1.838141, 0.192450, 0.087371}}],
    Polygon[{{1.814742, 0.144338, 0.113119},{1.796089, 0.150398, 0.136083},{
      1.802749, 0.192450, 0.136083},{1.822362, 0.192450, 0.113119}}],
    Polygon[{{1.796089, 0.150398, 0.136083},{1.774250, 0.157494, 0.155695},{
      1.779786, 0.192450, 0.155695},{1.802749, 0.192450, 0.136083}}],
    Polygon[{{1.774250, 0.157494, 0.155695},{1.749761, 0.165451, 0.171474},{
      1.754037, 0.192450, 0.171474},{1.779786, 0.192450, 0.155695}}],
    Polygon[{{1.749761, 0.165451, 0.171474},{1.723226, 0.174073, 0.183031},{
      1.726137, 0.192450, 0.183031},{1.754037, 0.192450, 0.171474}}],
    Polygon[{{1.723226, 0.174073, 0.183031},{1.695299, 0.183147, 0.190081},{
      1.696772, 0.192450, 0.190081},{1.726137, 0.192450, 0.183031}}],
    Polygon[{{1.898924, 0.064150, -0.063360},{1.908712, 0.064150, -0.061010},{
      1.907742, 0.070276, -0.061010},{1.898433, 0.067251, -0.063360}}],
    Polygon[{{1.908712, 0.064150, -0.061010},{1.918012, 0.064150, -0.057158},{
      1.916587, 0.073150, -0.057158},{1.907742, 0.070276, -0.061010}}],
    Polygon[{{1.918012, 0.064150, -0.057158},{1.926595, 0.064150, -0.051898},{
      1.924750, 0.075802, -0.051898},{1.916587, 0.073150, -0.057158}}],
    Polygon[{{1.926595, 0.064150, -0.051898},{1.934250, 0.064150, -0.045361},{
      1.932030, 0.078167, -0.045361},{1.924750, 0.075802, -0.051898}}],
    Polygon[{{1.934250, 0.064150, -0.045361},{1.940787, 0.064150, -0.037706},{
      1.938247, 0.080188, -0.037706},{1.932030, 0.078167, -0.045361}}],
    Polygon[{{1.940787, 0.064150, -0.037706},{1.946047, 0.064150, -0.029124},{
      1.943249, 0.081813, -0.029124},{1.938247, 0.080188, -0.037706}}],
    Polygon[{{1.946047, 0.064150, -0.029124},{1.949899, 0.064150, -0.019823},{
      1.946913, 0.083003, -0.019823},{1.943249, 0.081813, -0.029124}}],
    Polygon[{{1.949899, 0.064150, -0.019823},{1.952249, 0.064150, -0.010035},{
      1.949148, 0.083729, -0.010035},{1.946913, 0.083003, -0.019823}}],
    Polygon[{{1.952249, 0.064150, -0.010035},{1.953039, 0.064150, 0.000000},{
      1.949899, 0.083973, 0.000000},{1.949148, 0.083729, -0.010035}}],
    Polygon[{{1.953039, 0.064150, 0.000000},{1.952249, 0.064150, 0.010035},{
      1.949148, 0.083729, 0.010035},{1.949899, 0.083973, 0.000000}}],
    Polygon[{{1.952249, 0.064150, 0.010035},{1.949899, 0.064150, 0.019823},{
      1.946913, 0.083003, 0.019823},{1.949148, 0.083729, 0.010035}}],
    Polygon[{{1.949899, 0.064150, 0.019823},{1.946047, 0.064150, 0.029124},{
      1.943249, 0.081813, 0.029124},{1.946913, 0.083003, 0.019823}}],
    Polygon[{{1.946047, 0.064150, 0.029124},{1.940787, 0.064150, 0.037706},{
      1.938247, 0.080188, 0.037706},{1.943249, 0.081813, 0.029124}}],
    Polygon[{{1.940787, 0.064150, 0.037706},{1.934250, 0.064150, 0.045361},{
      1.932030, 0.078167, 0.045361},{1.938247, 0.080188, 0.037706}}],
    Polygon[{{1.934250, 0.064150, 0.045361},{1.926595, 0.064150, 0.051898},{
      1.924750, 0.075802, 0.051898},{1.932030, 0.078167, 0.045361}}],
    Polygon[{{1.926595, 0.064150, 0.051898},{1.918012, 0.064150, 0.057158},{
      1.916587, 0.073150, 0.057158},{1.924750, 0.075802, 0.051898}}],
    Polygon[{{1.918012, 0.064150, 0.057158},{1.908712, 0.064150, 0.061010},{
      1.907742, 0.070276, 0.061010},{1.916587, 0.073150, 0.057158}}],
    Polygon[{{1.908712, 0.064150, 0.061010},{1.898924, 0.064150, 0.063360},{
      1.898433, 0.067251, 0.063360},{1.907742, 0.070276, 0.061010}}],
    Polygon[{{1.898433, 0.067251, -0.063360},{1.907742, 0.070276, -0.061010},{
      1.904926, 0.075802, -0.061010},{1.897008, 0.070049, -0.063360}}],
    Polygon[{{1.907742, 0.070276, -0.061010},{1.916587, 0.073150, -0.057158},{
      1.912450, 0.081268, -0.057158},{1.904926, 0.075802, -0.061010}}],
    Polygon[{{1.916587, 0.073150, -0.057158},{1.924750, 0.075802, -0.051898},{
      1.919394, 0.086313, -0.051898},{1.912450, 0.081268, -0.057158}}],
    Polygon[{{1.924750, 0.075802, -0.051898},{1.932030, 0.078167, -0.045361},{
      1.925587, 0.090813, -0.045361},{1.919394, 0.086313, -0.051898}}],
    Polygon[{{1.932030, 0.078167, -0.045361},{1.938247, 0.080188, -0.037706},{
      1.930876, 0.094655, -0.037706},{1.925587, 0.090813, -0.045361}}],
    Polygon[{{1.938247, 0.080188, -0.037706},{1.943249, 0.081813, -0.029124},{
      1.935131, 0.097747, -0.029124},{1.930876, 0.094655, -0.037706}}],
    Polygon[{{1.943249, 0.081813, -0.029124},{1.946913, 0.083003, -0.019823},{
      1.938247, 0.100011, -0.019823},{1.935131, 0.097747, -0.029124}}],
    Polygon[{{1.946913, 0.083003, -0.019823},{1.949148, 0.083729, -0.010035},{
      1.940148, 0.101392, -0.010035},{1.938247, 0.100011, -0.019823}}],
    Polygon[{{1.949148, 0.083729, -0.010035},{1.949899, 0.083973, 0.000000},{
      1.940787, 0.101856, 0.000000},{1.940148, 0.101392, -0.010035}}],
    Polygon[{{1.949899, 0.083973, 0.000000},{1.949148, 0.083729, 0.010035},{
      1.940148, 0.101392, 0.010035},{1.940787, 0.101856, 0.000000}}],
    Polygon[{{1.949148, 0.083729, 0.010035},{1.946913, 0.083003, 0.019823},{
      1.938247, 0.100011, 0.019823},{1.940148, 0.101392, 0.010035}}],
    Polygon[{{1.946913, 0.083003, 0.019823},{1.943249, 0.081813, 0.029124},{
      1.935131, 0.097747, 0.029124},{1.938247, 0.100011, 0.019823}}],
    Polygon[{{1.943249, 0.081813, 0.029124},{1.938247, 0.080188, 0.037706},{
      1.930876, 0.094655, 0.037706},{1.935131, 0.097747, 0.029124}}],
    Polygon[{{1.938247, 0.080188, 0.037706},{1.932030, 0.078167, 0.045361},{
      1.925587, 0.090813, 0.045361},{1.930876, 0.094655, 0.037706}}],
    Polygon[{{1.932030, 0.078167, 0.045361},{1.924750, 0.075802, 0.051898},{
      1.919394, 0.086313, 0.051898},{1.925587, 0.090813, 0.045361}}],
    Polygon[{{1.924750, 0.075802, 0.051898},{1.916587, 0.073150, 0.057158},{
      1.912450, 0.081268, 0.057158},{1.919394, 0.086313, 0.051898}}],
    Polygon[{{1.916587, 0.073150, 0.057158},{1.907742, 0.070276, 0.061010},{
      1.904926, 0.075802, 0.061010},{1.912450, 0.081268, 0.057158}}],
    Polygon[{{1.907742, 0.070276, 0.061010},{1.898433, 0.067251, 0.063360},{
      1.897008, 0.070049, 0.063360},{1.904926, 0.075802, 0.061010}}],
    Polygon[{{1.897008, 0.070049, -0.063360},{1.904926, 0.075802, -0.061010},{
      1.900541, 0.080188, -0.061010},{1.894787, 0.072269, -0.063360}}],
    Polygon[{{1.904926, 0.075802, -0.061010},{1.912450, 0.081268, -0.057158},{
      1.906007, 0.087711, -0.057158},{1.900541, 0.080188, -0.061010}}],
    Polygon[{{1.912450, 0.081268, -0.057158},{1.919394, 0.086313, -0.051898},{
      1.911052, 0.094655, -0.051898},{1.906007, 0.087711, -0.057158}}],
    Polygon[{{1.919394, 0.086313, -0.051898},{1.925587, 0.090813, -0.045361},{
      1.915551, 0.100848, -0.045361},{1.911052, 0.094655, -0.051898}}],
    Polygon[{{1.925587, 0.090813, -0.045361},{1.930876, 0.094655, -0.037706},{
      1.919394, 0.106137, -0.037706},{1.915551, 0.100848, -0.045361}}],
    Polygon[{{1.930876, 0.094655, -0.037706},{1.935131, 0.097747, -0.029124},{
      1.922486, 0.110392, -0.029124},{1.919394, 0.106137, -0.037706}}],
    Polygon[{{1.935131, 0.097747, -0.029124},{1.938247, 0.100011, -0.019823},{
      1.924750, 0.113508, -0.019823},{1.922486, 0.110392, -0.029124}}],
    Polygon[{{1.938247, 0.100011, -0.019823},{1.940148, 0.101392, -0.010035},{
      1.926131, 0.115410, -0.010035},{1.924750, 0.113508, -0.019823}}],
    Polygon[{{1.940148, 0.101392, -0.010035},{1.940787, 0.101856, 0.000000},{
      1.926595, 0.116048, 0.000000},{1.926131, 0.115410, -0.010035}}],
    Polygon[{{1.940787, 0.101856, 0.000000},{1.940148, 0.101392, 0.010035},{
      1.926131, 0.115410, 0.010035},{1.926595, 0.116048, 0.000000}}],
    Polygon[{{1.940148, 0.101392, 0.010035},{1.938247, 0.100011, 0.019823},{
      1.924750, 0.113508, 0.019823},{1.926131, 0.115410, 0.010035}}],
    Polygon[{{1.938247, 0.100011, 0.019823},{1.935131, 0.097747, 0.029124},{
      1.922486, 0.110392, 0.029124},{1.924750, 0.113508, 0.019823}}],
    Polygon[{{1.935131, 0.097747, 0.029124},{1.930876, 0.094655, 0.037706},{
      1.919394, 0.106137, 0.037706},{1.922486, 0.110392, 0.029124}}],
    Polygon[{{1.930876, 0.094655, 0.037706},{1.925587, 0.090813, 0.045361},{
      1.915551, 0.100848, 0.045361},{1.919394, 0.106137, 0.037706}}],
    Polygon[{{1.925587, 0.090813, 0.045361},{1.919394, 0.086313, 0.051898},{
      1.911052, 0.094655, 0.051898},{1.915551, 0.100848, 0.045361}}],
    Polygon[{{1.919394, 0.086313, 0.051898},{1.912450, 0.081268, 0.057158},{
      1.906007, 0.087711, 0.057158},{1.911052, 0.094655, 0.051898}}],
    Polygon[{{1.912450, 0.081268, 0.057158},{1.904926, 0.075802, 0.061010},{
      1.900541, 0.080188, 0.061010},{1.906007, 0.087711, 0.057158}}],
    Polygon[{{1.904926, 0.075802, 0.061010},{1.897008, 0.070049, 0.063360},{
      1.894787, 0.072269, 0.063360},{1.900541, 0.080188, 0.061010}}],
    Polygon[{{1.894787, 0.072269, -0.063360},{1.900541, 0.080188, -0.061010},{
      1.895015, 0.083003, -0.061010},{1.891990, 0.073694, -0.063360}}],
    Polygon[{{1.900541, 0.080188, -0.061010},{1.906007, 0.087711, -0.057158},{
      1.897889, 0.091848, -0.057158},{1.895015, 0.083003, -0.061010}}],
    Polygon[{{1.906007, 0.087711, -0.057158},{1.911052, 0.094655, -0.051898},{
      1.900541, 0.100011, -0.051898},{1.897889, 0.091848, -0.057158}}],
    Polygon[{{1.911052, 0.094655, -0.051898},{1.915551, 0.100848, -0.045361},{
      1.902906, 0.107291, -0.045361},{1.900541, 0.100011, -0.051898}}],
    Polygon[{{1.915551, 0.100848, -0.045361},{1.919394, 0.106137, -0.037706},{
      1.904926, 0.113508, -0.037706},{1.902906, 0.107291, -0.045361}}],
    Polygon[{{1.919394, 0.106137, -0.037706},{1.922486, 0.110392, -0.029124},{
      1.906552, 0.118511, -0.029124},{1.904926, 0.113508, -0.037706}}],
    Polygon[{{1.922486, 0.110392, -0.029124},{1.924750, 0.113508, -0.019823},{
      1.907742, 0.122174, -0.019823},{1.906552, 0.118511, -0.029124}}],
    Polygon[{{1.924750, 0.113508, -0.019823},{1.926131, 0.115410, -0.010035},{
      1.908468, 0.124409, -0.010035},{1.907742, 0.122174, -0.019823}}],
    Polygon[{{1.926131, 0.115410, -0.010035},{1.926595, 0.116048, 0.000000},{
      1.908712, 0.125160, 0.000000},{1.908468, 0.124409, -0.010035}}],
    Polygon[{{1.926595, 0.116048, 0.000000},{1.926131, 0.115410, 0.010035},{
      1.908468, 0.124409, 0.010035},{1.908712, 0.125160, 0.000000}}],
    Polygon[{{1.926131, 0.115410, 0.010035},{1.924750, 0.113508, 0.019823},{
      1.907742, 0.122174, 0.019823},{1.908468, 0.124409, 0.010035}}],
    Polygon[{{1.924750, 0.113508, 0.019823},{1.922486, 0.110392, 0.029124},{
      1.906552, 0.118511, 0.029124},{1.907742, 0.122174, 0.019823}}],
    Polygon[{{1.922486, 0.110392, 0.029124},{1.919394, 0.106137, 0.037706},{
      1.904926, 0.113508, 0.037706},{1.906552, 0.118511, 0.029124}}],
    Polygon[{{1.919394, 0.106137, 0.037706},{1.915551, 0.100848, 0.045361},{
      1.902906, 0.107291, 0.045361},{1.904926, 0.113508, 0.037706}}],
    Polygon[{{1.915551, 0.100848, 0.045361},{1.911052, 0.094655, 0.051898},{
      1.900541, 0.100011, 0.051898},{1.902906, 0.107291, 0.045361}}],
    Polygon[{{1.911052, 0.094655, 0.051898},{1.906007, 0.087711, 0.057158},{
      1.897889, 0.091848, 0.057158},{1.900541, 0.100011, 0.051898}}],
    Polygon[{{1.906007, 0.087711, 0.057158},{1.900541, 0.080188, 0.061010},{
      1.895015, 0.083003, 0.061010},{1.897889, 0.091848, 0.057158}}],
    Polygon[{{1.900541, 0.080188, 0.061010},{1.894787, 0.072269, 0.063360},{
      1.891990, 0.073694, 0.063360},{1.895015, 0.083003, 0.061010}}],
    Polygon[{{1.891990, 0.073694, -0.063360},{1.895015, 0.083003, -0.061010},{
      1.888889, 0.083973, -0.061010},{1.888889, 0.074185, -0.063360}}],
    Polygon[{{1.895015, 0.083003, -0.061010},{1.897889, 0.091848, -0.057158},{
      1.888889, 0.093274, -0.057158},{1.888889, 0.083973, -0.061010}}],
    Polygon[{{1.897889, 0.091848, -0.057158},{1.900541, 0.100011, -0.051898},{
      1.888889, 0.101856, -0.051898},{1.888889, 0.093274, -0.057158}}],
    Polygon[{{1.900541, 0.100011, -0.051898},{1.902906, 0.107291, -0.045361},{
      1.888889, 0.109511, -0.045361},{1.888889, 0.101856, -0.051898}}],
    Polygon[{{1.902906, 0.107291, -0.045361},{1.904926, 0.113508, -0.037706},{
      1.888889, 0.116048, -0.037706},{1.888889, 0.109511, -0.045361}}],
    Polygon[{{1.904926, 0.113508, -0.037706},{1.906552, 0.118511, -0.029124},{
      1.888889, 0.121308, -0.029124},{1.888889, 0.116048, -0.037706}}],
    Polygon[{{1.906552, 0.118511, -0.029124},{1.907742, 0.122174, -0.019823},{
      1.888889, 0.125160, -0.019823},{1.888889, 0.121308, -0.029124}}],
    Polygon[{{1.907742, 0.122174, -0.019823},{1.908468, 0.124409, -0.010035},{
      1.888889, 0.127510, -0.010035},{1.888889, 0.125160, -0.019823}}],
    Polygon[{{1.908468, 0.124409, -0.010035},{1.908712, 0.125160, 0.000000},{
      1.888889, 0.128300, 0.000000},{1.888889, 0.127510, -0.010035}}],
    Polygon[{{1.908712, 0.125160, 0.000000},{1.908468, 0.124409, 0.010035},{
      1.888889, 0.127510, 0.010035},{1.888889, 0.128300, 0.000000}}],
    Polygon[{{1.908468, 0.124409, 0.010035},{1.907742, 0.122174, 0.019823},{
      1.888889, 0.125160, 0.019823},{1.888889, 0.127510, 0.010035}}],
    Polygon[{{1.907742, 0.122174, 0.019823},{1.906552, 0.118511, 0.029124},{
      1.888889, 0.121308, 0.029124},{1.888889, 0.125160, 0.019823}}],
    Polygon[{{1.906552, 0.118511, 0.029124},{1.904926, 0.113508, 0.037706},{
      1.888889, 0.116048, 0.037706},{1.888889, 0.121308, 0.029124}}],
    Polygon[{{1.904926, 0.113508, 0.037706},{1.902906, 0.107291, 0.045361},{
      1.888889, 0.109511, 0.045361},{1.888889, 0.116048, 0.037706}}],
    Polygon[{{1.902906, 0.107291, 0.045361},{1.900541, 0.100011, 0.051898},{
      1.888889, 0.101856, 0.051898},{1.888889, 0.109511, 0.045361}}],
    Polygon[{{1.900541, 0.100011, 0.051898},{1.897889, 0.091848, 0.057158},{
      1.888889, 0.093274, 0.057158},{1.888889, 0.101856, 0.051898}}],
    Polygon[{{1.897889, 0.091848, 0.057158},{1.895015, 0.083003, 0.061010},{
      1.888889, 0.083973, 0.061010},{1.888889, 0.093274, 0.057158}}],
    Polygon[{{1.895015, 0.083003, 0.061010},{1.891990, 0.073694, 0.063360},{
      1.888889, 0.074185, 0.063360},{1.888889, 0.083973, 0.061010}}],
    Polygon[{{1.888889, 0.074185, -0.063360},{1.888889, 0.083973, -0.061010},{
      1.882763, 0.083003, -0.061010},{1.885788, 0.073694, -0.063360}}],
    Polygon[{{1.888889, 0.083973, -0.061010},{1.888889, 0.093274, -0.057158},{
      1.879889, 0.091848, -0.057158},{1.882763, 0.083003, -0.061010}}],
    Polygon[{{1.888889, 0.093274, -0.057158},{1.888889, 0.101856, -0.051898},{
      1.877237, 0.100011, -0.051898},{1.879889, 0.091848, -0.057158}}],
    Polygon[{{1.888889, 0.101856, -0.051898},{1.888889, 0.109511, -0.045361},{
      1.874872, 0.107291, -0.045361},{1.877237, 0.100011, -0.051898}}],
    Polygon[{{1.888889, 0.109511, -0.045361},{1.888889, 0.116048, -0.037706},{
      1.872851, 0.113508, -0.037706},{1.874872, 0.107291, -0.045361}}],
    Polygon[{{1.888889, 0.116048, -0.037706},{1.888889, 0.121308, -0.029124},{
      1.871226, 0.118511, -0.029124},{1.872851, 0.113508, -0.037706}}],
    Polygon[{{1.888889, 0.121308, -0.029124},{1.888889, 0.125160, -0.019823},{
      1.870036, 0.122174, -0.019823},{1.871226, 0.118511, -0.029124}}],
    Polygon[{{1.888889, 0.125160, -0.019823},{1.888889, 0.127510, -0.010035},{
      1.869310, 0.124409, -0.010035},{1.870036, 0.122174, -0.019823}}],
    Polygon[{{1.888889, 0.127510, -0.010035},{1.888889, 0.128300, 0.000000},{
      1.869065, 0.125160, 0.000000},{1.869310, 0.124409, -0.010035}}],
    Polygon[{{1.888889, 0.128300, 0.000000},{1.888889, 0.127510, 0.010035},{
      1.869310, 0.124409, 0.010035},{1.869065, 0.125160, 0.000000}}],
    Polygon[{{1.888889, 0.127510, 0.010035},{1.888889, 0.125160, 0.019823},{
      1.870036, 0.122174, 0.019823},{1.869310, 0.124409, 0.010035}}],
    Polygon[{{1.888889, 0.125160, 0.019823},{1.888889, 0.121308, 0.029124},{
      1.871226, 0.118511, 0.029124},{1.870036, 0.122174, 0.019823}}],
    Polygon[{{1.888889, 0.121308, 0.029124},{1.888889, 0.116048, 0.037706},{
      1.872851, 0.113508, 0.037706},{1.871226, 0.118511, 0.029124}}],
    Polygon[{{1.888889, 0.116048, 0.037706},{1.888889, 0.109511, 0.045361},{
      1.874872, 0.107291, 0.045361},{1.872851, 0.113508, 0.037706}}],
    Polygon[{{1.888889, 0.109511, 0.045361},{1.888889, 0.101856, 0.051898},{
      1.877237, 0.100011, 0.051898},{1.874872, 0.107291, 0.045361}}],
    Polygon[{{1.888889, 0.101856, 0.051898},{1.888889, 0.093274, 0.057158},{
      1.879889, 0.091848, 0.057158},{1.877237, 0.100011, 0.051898}}],
    Polygon[{{1.888889, 0.093274, 0.057158},{1.888889, 0.083973, 0.061010},{
      1.882763, 0.083003, 0.061010},{1.879889, 0.091848, 0.057158}}],
    Polygon[{{1.888889, 0.083973, 0.061010},{1.888889, 0.074185, 0.063360},{
      1.885788, 0.073694, 0.063360},{1.882763, 0.083003, 0.061010}}],
    Polygon[{{1.885788, 0.073694, -0.063360},{1.882763, 0.083003, -0.061010},{
      1.877237, 0.080188, -0.061010},{1.882990, 0.072269, -0.063360}}],
    Polygon[{{1.882763, 0.083003, -0.061010},{1.879889, 0.091848, -0.057158},{
      1.871771, 0.087711, -0.057158},{1.877237, 0.080188, -0.061010}}],
    Polygon[{{1.879889, 0.091848, -0.057158},{1.877237, 0.100011, -0.051898},{
      1.866726, 0.094655, -0.051898},{1.871771, 0.087711, -0.057158}}],
    Polygon[{{1.877237, 0.100011, -0.051898},{1.874872, 0.107291, -0.045361},{
      1.862226, 0.100848, -0.045361},{1.866726, 0.094655, -0.051898}}],
    Polygon[{{1.874872, 0.107291, -0.045361},{1.872851, 0.113508, -0.037706},{
      1.858384, 0.106137, -0.037706},{1.862226, 0.100848, -0.045361}}],
    Polygon[{{1.872851, 0.113508, -0.037706},{1.871226, 0.118511, -0.029124},{
      1.855292, 0.110392, -0.029124},{1.858384, 0.106137, -0.037706}}],
    Polygon[{{1.871226, 0.118511, -0.029124},{1.870036, 0.122174, -0.019823},{
      1.853028, 0.113508, -0.019823},{1.855292, 0.110392, -0.029124}}],
    Polygon[{{1.870036, 0.122174, -0.019823},{1.869310, 0.124409, -0.010035},{
      1.851647, 0.115410, -0.010035},{1.853028, 0.113508, -0.019823}}],
    Polygon[{{1.869310, 0.124409, -0.010035},{1.869065, 0.125160, 0.000000},{
      1.851182, 0.116048, 0.000000},{1.851647, 0.115410, -0.010035}}],
    Polygon[{{1.869065, 0.125160, 0.000000},{1.869310, 0.124409, 0.010035},{
      1.851647, 0.115410, 0.010035},{1.851182, 0.116048, 0.000000}}],
    Polygon[{{1.869310, 0.124409, 0.010035},{1.870036, 0.122174, 0.019823},{
      1.853028, 0.113508, 0.019823},{1.851647, 0.115410, 0.010035}}],
    Polygon[{{1.870036, 0.122174, 0.019823},{1.871226, 0.118511, 0.029124},{
      1.855292, 0.110392, 0.029124},{1.853028, 0.113508, 0.019823}}],
    Polygon[{{1.871226, 0.118511, 0.029124},{1.872851, 0.113508, 0.037706},{
      1.858384, 0.106137, 0.037706},{1.855292, 0.110392, 0.029124}}],
    Polygon[{{1.872851, 0.113508, 0.037706},{1.874872, 0.107291, 0.045361},{
      1.862226, 0.100848, 0.045361},{1.858384, 0.106137, 0.037706}}],
    Polygon[{{1.874872, 0.107291, 0.045361},{1.877237, 0.100011, 0.051898},{
      1.866726, 0.094655, 0.051898},{1.862226, 0.100848, 0.045361}}],
    Polygon[{{1.877237, 0.100011, 0.051898},{1.879889, 0.091848, 0.057158},{
      1.871771, 0.087711, 0.057158},{1.866726, 0.094655, 0.051898}}],
    Polygon[{{1.879889, 0.091848, 0.057158},{1.882763, 0.083003, 0.061010},{
      1.877237, 0.080188, 0.061010},{1.871771, 0.087711, 0.057158}}],
    Polygon[{{1.882763, 0.083003, 0.061010},{1.885788, 0.073694, 0.063360},{
      1.882990, 0.072269, 0.063360},{1.877237, 0.080188, 0.061010}}],
    Polygon[{{1.882990, 0.072269, -0.063360},{1.877237, 0.080188, -0.061010},{
      1.872851, 0.075802, -0.061010},{1.880770, 0.070049, -0.063360}}],
    Polygon[{{1.877237, 0.080188, -0.061010},{1.871771, 0.087711, -0.057158},{
      1.865327, 0.081268, -0.057158},{1.872851, 0.075802, -0.061010}}],
    Polygon[{{1.871771, 0.087711, -0.057158},{1.866726, 0.094655, -0.051898},{
      1.858384, 0.086313, -0.051898},{1.865327, 0.081268, -0.057158}}],
    Polygon[{{1.866726, 0.094655, -0.051898},{1.862226, 0.100848, -0.045361},{
      1.852191, 0.090813, -0.045361},{1.858384, 0.086313, -0.051898}}],
    Polygon[{{1.862226, 0.100848, -0.045361},{1.858384, 0.106137, -0.037706},{
      1.846902, 0.094655, -0.037706},{1.852191, 0.090813, -0.045361}}],
    Polygon[{{1.858384, 0.106137, -0.037706},{1.855292, 0.110392, -0.029124},{
      1.842647, 0.097747, -0.029124},{1.846902, 0.094655, -0.037706}}],
    Polygon[{{1.855292, 0.110392, -0.029124},{1.853028, 0.113508, -0.019823},{
      1.839530, 0.100011, -0.019823},{1.842647, 0.097747, -0.029124}}],
    Polygon[{{1.853028, 0.113508, -0.019823},{1.851647, 0.115410, -0.010035},{
      1.837629, 0.101392, -0.010035},{1.839530, 0.100011, -0.019823}}],
    Polygon[{{1.851647, 0.115410, -0.010035},{1.851182, 0.116048, 0.000000},{
      1.836990, 0.101856, 0.000000},{1.837629, 0.101392, -0.010035}}],
    Polygon[{{1.851182, 0.116048, 0.000000},{1.851647, 0.115410, 0.010035},{
      1.837629, 0.101392, 0.010035},{1.836990, 0.101856, 0.000000}}],
    Polygon[{{1.851647, 0.115410, 0.010035},{1.853028, 0.113508, 0.019823},{
      1.839530, 0.100011, 0.019823},{1.837629, 0.101392, 0.010035}}],
    Polygon[{{1.853028, 0.113508, 0.019823},{1.855292, 0.110392, 0.029124},{
      1.842647, 0.097747, 0.029124},{1.839530, 0.100011, 0.019823}}],
    Polygon[{{1.855292, 0.110392, 0.029124},{1.858384, 0.106137, 0.037706},{
      1.846902, 0.094655, 0.037706},{1.842647, 0.097747, 0.029124}}],
    Polygon[{{1.858384, 0.106137, 0.037706},{1.862226, 0.100848, 0.045361},{
      1.852191, 0.090813, 0.045361},{1.846902, 0.094655, 0.037706}}],
    Polygon[{{1.862226, 0.100848, 0.045361},{1.866726, 0.094655, 0.051898},{
      1.858384, 0.086313, 0.051898},{1.852191, 0.090813, 0.045361}}],
    Polygon[{{1.866726, 0.094655, 0.051898},{1.871771, 0.087711, 0.057158},{
      1.865327, 0.081268, 0.057158},{1.858384, 0.086313, 0.051898}}],
    Polygon[{{1.871771, 0.087711, 0.057158},{1.877237, 0.080188, 0.061010},{
      1.872851, 0.075802, 0.061010},{1.865327, 0.081268, 0.057158}}],
    Polygon[{{1.877237, 0.080188, 0.061010},{1.882990, 0.072269, 0.063360},{
      1.880770, 0.070049, 0.063360},{1.872851, 0.075802, 0.061010}}],
    Polygon[{{1.880770, 0.070049, -0.063360},{1.872851, 0.075802, -0.061010},{
      1.870036, 0.070276, -0.061010},{1.879345, 0.067251, -0.063360}}],
    Polygon[{{1.872851, 0.075802, -0.061010},{1.865327, 0.081268, -0.057158},{
      1.861191, 0.073150, -0.057158},{1.870036, 0.070276, -0.061010}}],
    Polygon[{{1.865327, 0.081268, -0.057158},{1.858384, 0.086313, -0.051898},{
      1.853028, 0.075802, -0.051898},{1.861191, 0.073150, -0.057158}}],
    Polygon[{{1.858384, 0.086313, -0.051898},{1.852191, 0.090813, -0.045361},{
      1.845748, 0.078167, -0.045361},{1.853028, 0.075802, -0.051898}}],
    Polygon[{{1.852191, 0.090813, -0.045361},{1.846902, 0.094655, -0.037706},{
      1.839530, 0.080188, -0.037706},{1.845748, 0.078167, -0.045361}}],
    Polygon[{{1.846902, 0.094655, -0.037706},{1.842647, 0.097747, -0.029124},{
      1.834528, 0.081813, -0.029124},{1.839530, 0.080188, -0.037706}}],
    Polygon[{{1.842647, 0.097747, -0.029124},{1.839530, 0.100011, -0.019823},{
      1.830865, 0.083003, -0.019823},{1.834528, 0.081813, -0.029124}}],
    Polygon[{{1.839530, 0.100011, -0.019823},{1.837629, 0.101392, -0.010035},{
      1.828630, 0.083729, -0.010035},{1.830865, 0.083003, -0.019823}}],
    Polygon[{{1.837629, 0.101392, -0.010035},{1.836990, 0.101856, 0.000000},{
      1.827879, 0.083973, 0.000000},{1.828630, 0.083729, -0.010035}}],
    Polygon[{{1.836990, 0.101856, 0.000000},{1.837629, 0.101392, 0.010035},{
      1.828630, 0.083729, 0.010035},{1.827879, 0.083973, 0.000000}}],
    Polygon[{{1.837629, 0.101392, 0.010035},{1.839530, 0.100011, 0.019823},{
      1.830865, 0.083003, 0.019823},{1.828630, 0.083729, 0.010035}}],
    Polygon[{{1.839530, 0.100011, 0.019823},{1.842647, 0.097747, 0.029124},{
      1.834528, 0.081813, 0.029124},{1.830865, 0.083003, 0.019823}}],
    Polygon[{{1.842647, 0.097747, 0.029124},{1.846902, 0.094655, 0.037706},{
      1.839530, 0.080188, 0.037706},{1.834528, 0.081813, 0.029124}}],
    Polygon[{{1.846902, 0.094655, 0.037706},{1.852191, 0.090813, 0.045361},{
      1.845748, 0.078167, 0.045361},{1.839530, 0.080188, 0.037706}}],
    Polygon[{{1.852191, 0.090813, 0.045361},{1.858384, 0.086313, 0.051898},{
      1.853028, 0.075802, 0.051898},{1.845748, 0.078167, 0.045361}}],
    Polygon[{{1.858384, 0.086313, 0.051898},{1.865327, 0.081268, 0.057158},{
      1.861191, 0.073150, 0.057158},{1.853028, 0.075802, 0.051898}}],
    Polygon[{{1.865327, 0.081268, 0.057158},{1.872851, 0.075802, 0.061010},{
      1.870036, 0.070276, 0.061010},{1.861191, 0.073150, 0.057158}}],
    Polygon[{{1.872851, 0.075802, 0.061010},{1.880770, 0.070049, 0.063360},{
      1.879345, 0.067251, 0.063360},{1.870036, 0.070276, 0.061010}}],
    Polygon[{{1.879345, 0.067251, -0.063360},{1.870036, 0.070276, -0.061010},{
      1.869065, 0.064150, -0.061010},{1.878854, 0.064150, -0.063360}}],
    Polygon[{{1.870036, 0.070276, -0.061010},{1.861191, 0.073150, -0.057158},{
      1.859765, 0.064150, -0.057158},{1.869065, 0.064150, -0.061010}}],
    Polygon[{{1.861191, 0.073150, -0.057158},{1.853028, 0.075802, -0.051898},{
      1.851182, 0.064150, -0.051898},{1.859765, 0.064150, -0.057158}}],
    Polygon[{{1.853028, 0.075802, -0.051898},{1.845748, 0.078167, -0.045361},{
      1.843528, 0.064150, -0.045361},{1.851182, 0.064150, -0.051898}}],
    Polygon[{{1.845748, 0.078167, -0.045361},{1.839530, 0.080188, -0.037706},{
      1.836990, 0.064150, -0.037706},{1.843528, 0.064150, -0.045361}}],
    Polygon[{{1.839530, 0.080188, -0.037706},{1.834528, 0.081813, -0.029124},{
      1.831731, 0.064150, -0.029124},{1.836990, 0.064150, -0.037706}}],
    Polygon[{{1.834528, 0.081813, -0.029124},{1.830865, 0.083003, -0.019823},{
      1.827879, 0.064150, -0.019823},{1.831731, 0.064150, -0.029124}}],
    Polygon[{{1.830865, 0.083003, -0.019823},{1.828630, 0.083729, -0.010035},{
      1.825529, 0.064150, -0.010035},{1.827879, 0.064150, -0.019823}}],
    Polygon[{{1.828630, 0.083729, -0.010035},{1.827879, 0.083973, 0.000000},{
      1.824739, 0.064150, 0.000000},{1.825529, 0.064150, -0.010035}}],
    Polygon[{{1.827879, 0.083973, 0.000000},{1.828630, 0.083729, 0.010035},{
      1.825529, 0.064150, 0.010035},{1.824739, 0.064150, 0.000000}}],
    Polygon[{{1.828630, 0.083729, 0.010035},{1.830865, 0.083003, 0.019823},{
      1.827879, 0.064150, 0.019823},{1.825529, 0.064150, 0.010035}}],
    Polygon[{{1.830865, 0.083003, 0.019823},{1.834528, 0.081813, 0.029124},{
      1.831731, 0.064150, 0.029124},{1.827879, 0.064150, 0.019823}}],
    Polygon[{{1.834528, 0.081813, 0.029124},{1.839530, 0.080188, 0.037706},{
      1.836990, 0.064150, 0.037706},{1.831731, 0.064150, 0.029124}}],
    Polygon[{{1.839530, 0.080188, 0.037706},{1.845748, 0.078167, 0.045361},{
      1.843528, 0.064150, 0.045361},{1.836990, 0.064150, 0.037706}}],
    Polygon[{{1.845748, 0.078167, 0.045361},{1.853028, 0.075802, 0.051898},{
      1.851182, 0.064150, 0.051898},{1.843528, 0.064150, 0.045361}}],
    Polygon[{{1.853028, 0.075802, 0.051898},{1.861191, 0.073150, 0.057158},{
      1.859765, 0.064150, 0.057158},{1.851182, 0.064150, 0.051898}}],
    Polygon[{{1.861191, 0.073150, 0.057158},{1.870036, 0.070276, 0.061010},{
      1.869065, 0.064150, 0.061010},{1.859765, 0.064150, 0.057158}}],
    Polygon[{{1.870036, 0.070276, 0.061010},{1.879345, 0.067251, 0.063360},{
      1.878854, 0.064150, 0.063360},{1.869065, 0.064150, 0.061010}}],
    Polygon[{{1.878854, 0.064150, -0.063360},{1.869065, 0.064150, -0.061010},{
      1.870036, 0.058024, -0.061010},{1.879345, 0.061049, -0.063360}}],
    Polygon[{{1.869065, 0.064150, -0.061010},{1.859765, 0.064150, -0.057158},{
      1.861191, 0.055150, -0.057158},{1.870036, 0.058024, -0.061010}}],
    Polygon[{{1.859765, 0.064150, -0.057158},{1.851182, 0.064150, -0.051898},{
      1.853028, 0.052498, -0.051898},{1.861191, 0.055150, -0.057158}}],
    Polygon[{{1.851182, 0.064150, -0.051898},{1.843528, 0.064150, -0.045361},{
      1.845748, 0.050133, -0.045361},{1.853028, 0.052498, -0.051898}}],
    Polygon[{{1.843528, 0.064150, -0.045361},{1.836990, 0.064150, -0.037706},{
      1.839530, 0.048113, -0.037706},{1.845748, 0.050133, -0.045361}}],
    Polygon[{{1.836990, 0.064150, -0.037706},{1.831731, 0.064150, -0.029124},{
      1.834528, 0.046487, -0.029124},{1.839530, 0.048113, -0.037706}}],
    Polygon[{{1.831731, 0.064150, -0.029124},{1.827879, 0.064150, -0.019823},{
      1.830865, 0.045297, -0.019823},{1.834528, 0.046487, -0.029124}}],
    Polygon[{{1.827879, 0.064150, -0.019823},{1.825529, 0.064150, -0.010035},{
      1.828630, 0.044571, -0.010035},{1.830865, 0.045297, -0.019823}}],
    Polygon[{{1.825529, 0.064150, -0.010035},{1.824739, 0.064150, 0.000000},{
      1.827879, 0.044327, 0.000000},{1.828630, 0.044571, -0.010035}}],
    Polygon[{{1.824739, 0.064150, 0.000000},{1.825529, 0.064150, 0.010035},{
      1.828630, 0.044571, 0.010035},{1.827879, 0.044327, 0.000000}}],
    Polygon[{{1.825529, 0.064150, 0.010035},{1.827879, 0.064150, 0.019823},{
      1.830865, 0.045297, 0.019823},{1.828630, 0.044571, 0.010035}}],
    Polygon[{{1.827879, 0.064150, 0.019823},{1.831731, 0.064150, 0.029124},{
      1.834528, 0.046487, 0.029124},{1.830865, 0.045297, 0.019823}}],
    Polygon[{{1.831731, 0.064150, 0.029124},{1.836990, 0.064150, 0.037706},{
      1.839530, 0.048113, 0.037706},{1.834528, 0.046487, 0.029124}}],
    Polygon[{{1.836990, 0.064150, 0.037706},{1.843528, 0.064150, 0.045361},{
      1.845748, 0.050133, 0.045361},{1.839530, 0.048113, 0.037706}}],
    Polygon[{{1.843528, 0.064150, 0.045361},{1.851182, 0.064150, 0.051898},{
      1.853028, 0.052498, 0.051898},{1.845748, 0.050133, 0.045361}}],
    Polygon[{{1.851182, 0.064150, 0.051898},{1.859765, 0.064150, 0.057158},{
      1.861191, 0.055150, 0.057158},{1.853028, 0.052498, 0.051898}}],
    Polygon[{{1.859765, 0.064150, 0.057158},{1.869065, 0.064150, 0.061010},{
      1.870036, 0.058024, 0.061010},{1.861191, 0.055150, 0.057158}}],
    Polygon[{{1.869065, 0.064150, 0.061010},{1.878854, 0.064150, 0.063360},{
      1.879345, 0.061049, 0.063360},{1.870036, 0.058024, 0.061010}}],
    Polygon[{{1.879345, 0.061049, -0.063360},{1.870036, 0.058024, -0.061010},{
      1.872851, 0.052498, -0.061010},{1.880770, 0.058251, -0.063360}}],
    Polygon[{{1.870036, 0.058024, -0.061010},{1.861191, 0.055150, -0.057158},{
      1.865327, 0.047032, -0.057158},{1.872851, 0.052498, -0.061010}}],
    Polygon[{{1.861191, 0.055150, -0.057158},{1.853028, 0.052498, -0.051898},{
      1.858384, 0.041987, -0.051898},{1.865327, 0.047032, -0.057158}}],
    Polygon[{{1.853028, 0.052498, -0.051898},{1.845748, 0.050133, -0.045361},{
      1.852191, 0.037488, -0.045361},{1.858384, 0.041987, -0.051898}}],
    Polygon[{{1.845748, 0.050133, -0.045361},{1.839530, 0.048113, -0.037706},{
      1.846902, 0.033645, -0.037706},{1.852191, 0.037488, -0.045361}}],
    Polygon[{{1.839530, 0.048113, -0.037706},{1.834528, 0.046487, -0.029124},{
      1.842647, 0.030553, -0.029124},{1.846902, 0.033645, -0.037706}}],
    Polygon[{{1.834528, 0.046487, -0.029124},{1.830865, 0.045297, -0.019823},{
      1.839530, 0.028289, -0.019823},{1.842647, 0.030553, -0.029124}}],
    Polygon[{{1.830865, 0.045297, -0.019823},{1.828630, 0.044571, -0.010035},{
      1.837629, 0.026908, -0.010035},{1.839530, 0.028289, -0.019823}}],
    Polygon[{{1.828630, 0.044571, -0.010035},{1.827879, 0.044327, 0.000000},{
      1.836990, 0.026444, 0.000000},{1.837629, 0.026908, -0.010035}}],
    Polygon[{{1.827879, 0.044327, 0.000000},{1.828630, 0.044571, 0.010035},{
      1.837629, 0.026908, 0.010035},{1.836990, 0.026444, 0.000000}}],
    Polygon[{{1.828630, 0.044571, 0.010035},{1.830865, 0.045297, 0.019823},{
      1.839530, 0.028289, 0.019823},{1.837629, 0.026908, 0.010035}}],
    Polygon[{{1.830865, 0.045297, 0.019823},{1.834528, 0.046487, 0.029124},{
      1.842647, 0.030553, 0.029124},{1.839530, 0.028289, 0.019823}}],
    Polygon[{{1.834528, 0.046487, 0.029124},{1.839530, 0.048113, 0.037706},{
      1.846902, 0.033645, 0.037706},{1.842647, 0.030553, 0.029124}}],
    Polygon[{{1.839530, 0.048113, 0.037706},{1.845748, 0.050133, 0.045361},{
      1.852191, 0.037488, 0.045361},{1.846902, 0.033645, 0.037706}}],
    Polygon[{{1.845748, 0.050133, 0.045361},{1.853028, 0.052498, 0.051898},{
      1.858384, 0.041987, 0.051898},{1.852191, 0.037488, 0.045361}}],
    Polygon[{{1.853028, 0.052498, 0.051898},{1.861191, 0.055150, 0.057158},{
      1.865327, 0.047032, 0.057158},{1.858384, 0.041987, 0.051898}}],
    Polygon[{{1.861191, 0.055150, 0.057158},{1.870036, 0.058024, 0.061010},{
      1.872851, 0.052498, 0.061010},{1.865327, 0.047032, 0.057158}}],
    Polygon[{{1.870036, 0.058024, 0.061010},{1.879345, 0.061049, 0.063360},{
      1.880770, 0.058251, 0.063360},{1.872851, 0.052498, 0.061010}}],
    Polygon[{{1.880770, 0.058251, -0.063360},{1.872851, 0.052498, -0.061010},{
      1.877237, 0.048113, -0.061010},{1.882990, 0.056031, -0.063360}}],
    Polygon[{{1.872851, 0.052498, -0.061010},{1.865327, 0.047032, -0.057158},{
      1.871771, 0.040589, -0.057158},{1.877237, 0.048113, -0.061010}}],
    Polygon[{{1.865327, 0.047032, -0.057158},{1.858384, 0.041987, -0.051898},{
      1.866726, 0.033645, -0.051898},{1.871771, 0.040589, -0.057158}}],
    Polygon[{{1.858384, 0.041987, -0.051898},{1.852191, 0.037488, -0.045361},{
      1.862226, 0.027452, -0.045361},{1.866726, 0.033645, -0.051898}}],
    Polygon[{{1.852191, 0.037488, -0.045361},{1.846902, 0.033645, -0.037706},{
      1.858384, 0.022163, -0.037706},{1.862226, 0.027452, -0.045361}}],
    Polygon[{{1.846902, 0.033645, -0.037706},{1.842647, 0.030553, -0.029124},{
      1.855292, 0.017908, -0.029124},{1.858384, 0.022163, -0.037706}}],
    Polygon[{{1.842647, 0.030553, -0.029124},{1.839530, 0.028289, -0.019823},{
      1.853028, 0.014792, -0.019823},{1.855292, 0.017908, -0.029124}}],
    Polygon[{{1.839530, 0.028289, -0.019823},{1.837629, 0.026908, -0.010035},{
      1.851647, 0.012891, -0.010035},{1.853028, 0.014792, -0.019823}}],
    Polygon[{{1.837629, 0.026908, -0.010035},{1.836990, 0.026444, 0.000000},{
      1.851182, 0.012252, 0.000000},{1.851647, 0.012891, -0.010035}}],
    Polygon[{{1.836990, 0.026444, 0.000000},{1.837629, 0.026908, 0.010035},{
      1.851647, 0.012891, 0.010035},{1.851182, 0.012252, 0.000000}}],
    Polygon[{{1.837629, 0.026908, 0.010035},{1.839530, 0.028289, 0.019823},{
      1.853028, 0.014792, 0.019823},{1.851647, 0.012891, 0.010035}}],
    Polygon[{{1.839530, 0.028289, 0.019823},{1.842647, 0.030553, 0.029124},{
      1.855292, 0.017908, 0.029124},{1.853028, 0.014792, 0.019823}}],
    Polygon[{{1.842647, 0.030553, 0.029124},{1.846902, 0.033645, 0.037706},{
      1.858384, 0.022163, 0.037706},{1.855292, 0.017908, 0.029124}}],
    Polygon[{{1.846902, 0.033645, 0.037706},{1.852191, 0.037488, 0.045361},{
      1.862226, 0.027452, 0.045361},{1.858384, 0.022163, 0.037706}}],
    Polygon[{{1.852191, 0.037488, 0.045361},{1.858384, 0.041987, 0.051898},{
      1.866726, 0.033645, 0.051898},{1.862226, 0.027452, 0.045361}}],
    Polygon[{{1.858384, 0.041987, 0.051898},{1.865327, 0.047032, 0.057158},{
      1.871771, 0.040589, 0.057158},{1.866726, 0.033645, 0.051898}}],
    Polygon[{{1.865327, 0.047032, 0.057158},{1.872851, 0.052498, 0.061010},{
      1.877237, 0.048113, 0.061010},{1.871771, 0.040589, 0.057158}}],
    Polygon[{{1.872851, 0.052498, 0.061010},{1.880770, 0.058251, 0.063360},{
      1.882990, 0.056031, 0.063360},{1.877237, 0.048113, 0.061010}}],
    Polygon[{{1.882990, 0.056031, -0.063360},{1.877237, 0.048113, -0.061010},{
      1.882763, 0.045297, -0.061010},{1.885788, 0.054606, -0.063360}}],
    Polygon[{{1.877237, 0.048113, -0.061010},{1.871771, 0.040589, -0.057158},{
      1.879889, 0.036452, -0.057158},{1.882763, 0.045297, -0.061010}}],
    Polygon[{{1.871771, 0.040589, -0.057158},{1.866726, 0.033645, -0.051898},{
      1.877237, 0.028289, -0.051898},{1.879889, 0.036452, -0.057158}}],
    Polygon[{{1.866726, 0.033645, -0.051898},{1.862226, 0.027452, -0.045361},{
      1.874872, 0.021009, -0.045361},{1.877237, 0.028289, -0.051898}}],
    Polygon[{{1.862226, 0.027452, -0.045361},{1.858384, 0.022163, -0.037706},{
      1.872851, 0.014792, -0.037706},{1.874872, 0.021009, -0.045361}}],
    Polygon[{{1.858384, 0.022163, -0.037706},{1.855292, 0.017908, -0.029124},{
      1.871226, 0.009789, -0.029124},{1.872851, 0.014792, -0.037706}}],
    Polygon[{{1.855292, 0.017908, -0.029124},{1.853028, 0.014792, -0.019823},{
      1.870036, 0.006126, -0.019823},{1.871226, 0.009789, -0.029124}}],
    Polygon[{{1.853028, 0.014792, -0.019823},{1.851647, 0.012891, -0.010035},{
      1.869310, 0.003891, -0.010035},{1.870036, 0.006126, -0.019823}}],
    Polygon[{{1.851647, 0.012891, -0.010035},{1.851182, 0.012252, 0.000000},{
      1.869065, 0.003140, 0.000000},{1.869310, 0.003891, -0.010035}}],
    Polygon[{{1.851182, 0.012252, 0.000000},{1.851647, 0.012891, 0.010035},{
      1.869310, 0.003891, 0.010035},{1.869065, 0.003140, 0.000000}}],
    Polygon[{{1.851647, 0.012891, 0.010035},{1.853028, 0.014792, 0.019823},{
      1.870036, 0.006126, 0.019823},{1.869310, 0.003891, 0.010035}}],
    Polygon[{{1.853028, 0.014792, 0.019823},{1.855292, 0.017908, 0.029124},{
      1.871226, 0.009789, 0.029124},{1.870036, 0.006126, 0.019823}}],
    Polygon[{{1.855292, 0.017908, 0.029124},{1.858384, 0.022163, 0.037706},{
      1.872851, 0.014792, 0.037706},{1.871226, 0.009789, 0.029124}}],
    Polygon[{{1.858384, 0.022163, 0.037706},{1.862226, 0.027452, 0.045361},{
      1.874872, 0.021009, 0.045361},{1.872851, 0.014792, 0.037706}}],
    Polygon[{{1.862226, 0.027452, 0.045361},{1.866726, 0.033645, 0.051898},{
      1.877237, 0.028289, 0.051898},{1.874872, 0.021009, 0.045361}}],
    Polygon[{{1.866726, 0.033645, 0.051898},{1.871771, 0.040589, 0.057158},{
      1.879889, 0.036452, 0.057158},{1.877237, 0.028289, 0.051898}}],
    Polygon[{{1.871771, 0.040589, 0.057158},{1.877237, 0.048113, 0.061010},{
      1.882763, 0.045297, 0.061010},{1.879889, 0.036452, 0.057158}}],
    Polygon[{{1.877237, 0.048113, 0.061010},{1.882990, 0.056031, 0.063360},{
      1.885788, 0.054606, 0.063360},{1.882763, 0.045297, 0.061010}}],
    Polygon[{{1.885788, 0.054606, -0.063360},{1.882763, 0.045297, -0.061010},{
      1.888889, 0.044327, -0.061010},{1.888889, 0.054115, -0.063360}}],
    Polygon[{{1.882763, 0.045297, -0.061010},{1.879889, 0.036452, -0.057158},{
      1.888889, 0.035027, -0.057158},{1.888889, 0.044327, -0.061010}}],
    Polygon[{{1.879889, 0.036452, -0.057158},{1.877237, 0.028289, -0.051898},{
      1.888889, 0.026444, -0.051898},{1.888889, 0.035027, -0.057158}}],
    Polygon[{{1.877237, 0.028289, -0.051898},{1.874872, 0.021009, -0.045361},{
      1.888889, 0.018789, -0.045361},{1.888889, 0.026444, -0.051898}}],
    Polygon[{{1.874872, 0.021009, -0.045361},{1.872851, 0.014792, -0.037706},{
      1.888889, 0.012252, -0.037706},{1.888889, 0.018789, -0.045361}}],
    Polygon[{{1.872851, 0.014792, -0.037706},{1.871226, 0.009789, -0.029124},{
      1.888889, 0.006992, -0.029124},{1.888889, 0.012252, -0.037706}}],
    Polygon[{{1.871226, 0.009789, -0.029124},{1.870036, 0.006126, -0.019823},{
      1.888889, 0.003140, -0.019823},{1.888889, 0.006992, -0.029124}}],
    Polygon[{{1.870036, 0.006126, -0.019823},{1.869310, 0.003891, -0.010035},{
      1.888889, 0.000790, -0.010035},{1.888889, 0.003140, -0.019823}}],
    Polygon[{{1.869310, 0.003891, -0.010035},{1.869065, 0.003140, 0.000000},{
      1.888889, 0.000000, 0.000000},{1.888889, 0.000790, -0.010035}}],
    Polygon[{{1.869065, 0.003140, 0.000000},{1.869310, 0.003891, 0.010035},{
      1.888889, 0.000790, 0.010035},{1.888889, 0.000000, 0.000000}}],
    Polygon[{{1.869310, 0.003891, 0.010035},{1.870036, 0.006126, 0.019823},{
      1.888889, 0.003140, 0.019823},{1.888889, 0.000790, 0.010035}}],
    Polygon[{{1.870036, 0.006126, 0.019823},{1.871226, 0.009789, 0.029124},{
      1.888889, 0.006992, 0.029124},{1.888889, 0.003140, 0.019823}}],
    Polygon[{{1.871226, 0.009789, 0.029124},{1.872851, 0.014792, 0.037706},{
      1.888889, 0.012252, 0.037706},{1.888889, 0.006992, 0.029124}}],
    Polygon[{{1.872851, 0.014792, 0.037706},{1.874872, 0.021009, 0.045361},{
      1.888889, 0.018789, 0.045361},{1.888889, 0.012252, 0.037706}}],
    Polygon[{{1.874872, 0.021009, 0.045361},{1.877237, 0.028289, 0.051898},{
      1.888889, 0.026444, 0.051898},{1.888889, 0.018789, 0.045361}}],
    Polygon[{{1.877237, 0.028289, 0.051898},{1.879889, 0.036452, 0.057158},{
      1.888889, 0.035027, 0.057158},{1.888889, 0.026444, 0.051898}}],
    Polygon[{{1.879889, 0.036452, 0.057158},{1.882763, 0.045297, 0.061010},{
      1.888889, 0.044327, 0.061010},{1.888889, 0.035027, 0.057158}}],
    Polygon[{{1.882763, 0.045297, 0.061010},{1.885788, 0.054606, 0.063360},{
      1.888889, 0.054115, 0.063360},{1.888889, 0.044327, 0.061010}}],
    Polygon[{{1.888889, 0.054115, -0.063360},{1.888889, 0.044327, -0.061010},{
      1.895015, 0.045297, -0.061010},{1.891990, 0.054606, -0.063360}}],
    Polygon[{{1.888889, 0.044327, -0.061010},{1.888889, 0.035027, -0.057158},{
      1.897889, 0.036452, -0.057158},{1.895015, 0.045297, -0.061010}}],
    Polygon[{{1.888889, 0.035027, -0.057158},{1.888889, 0.026444, -0.051898},{
      1.900541, 0.028289, -0.051898},{1.897889, 0.036452, -0.057158}}],
    Polygon[{{1.888889, 0.026444, -0.051898},{1.888889, 0.018789, -0.045361},{
      1.902906, 0.021009, -0.045361},{1.900541, 0.028289, -0.051898}}],
    Polygon[{{1.888889, 0.018789, -0.045361},{1.888889, 0.012252, -0.037706},{
      1.904926, 0.014792, -0.037706},{1.902906, 0.021009, -0.045361}}],
    Polygon[{{1.888889, 0.012252, -0.037706},{1.888889, 0.006992, -0.029124},{
      1.906552, 0.009789, -0.029124},{1.904926, 0.014792, -0.037706}}],
    Polygon[{{1.888889, 0.006992, -0.029124},{1.888889, 0.003140, -0.019823},{
      1.907742, 0.006126, -0.019823},{1.906552, 0.009789, -0.029124}}],
    Polygon[{{1.888889, 0.003140, -0.019823},{1.888889, 0.000790, -0.010035},{
      1.908468, 0.003891, -0.010035},{1.907742, 0.006126, -0.019823}}],
    Polygon[{{1.888889, 0.000790, -0.010035},{1.888889, 0.000000, 0.000000},{
      1.908712, 0.003140, 0.000000},{1.908468, 0.003891, -0.010035}}],
    Polygon[{{1.888889, 0.000000, 0.000000},{1.888889, 0.000790, 0.010035},{
      1.908468, 0.003891, 0.010035},{1.908712, 0.003140, 0.000000}}],
    Polygon[{{1.888889, 0.000790, 0.010035},{1.888889, 0.003140, 0.019823},{
      1.907742, 0.006126, 0.019823},{1.908468, 0.003891, 0.010035}}],
    Polygon[{{1.888889, 0.003140, 0.019823},{1.888889, 0.006992, 0.029124},{
      1.906552, 0.009789, 0.029124},{1.907742, 0.006126, 0.019823}}],
    Polygon[{{1.888889, 0.006992, 0.029124},{1.888889, 0.012252, 0.037706},{
      1.904926, 0.014792, 0.037706},{1.906552, 0.009789, 0.029124}}],
    Polygon[{{1.888889, 0.012252, 0.037706},{1.888889, 0.018789, 0.045361},{
      1.902906, 0.021009, 0.045361},{1.904926, 0.014792, 0.037706}}],
    Polygon[{{1.888889, 0.018789, 0.045361},{1.888889, 0.026444, 0.051898},{
      1.900541, 0.028289, 0.051898},{1.902906, 0.021009, 0.045361}}],
    Polygon[{{1.888889, 0.026444, 0.051898},{1.888889, 0.035027, 0.057158},{
      1.897889, 0.036452, 0.057158},{1.900541, 0.028289, 0.051898}}],
    Polygon[{{1.888889, 0.035027, 0.057158},{1.888889, 0.044327, 0.061010},{
      1.895015, 0.045297, 0.061010},{1.897889, 0.036452, 0.057158}}],
    Polygon[{{1.888889, 0.044327, 0.061010},{1.888889, 0.054115, 0.063360},{
      1.891990, 0.054606, 0.063360},{1.895015, 0.045297, 0.061010}}],
    Polygon[{{1.891990, 0.054606, -0.063360},{1.895015, 0.045297, -0.061010},{
      1.900541, 0.048113, -0.061010},{1.894787, 0.056031, -0.063360}}],
    Polygon[{{1.895015, 0.045297, -0.061010},{1.897889, 0.036452, -0.057158},{
      1.906007, 0.040589, -0.057158},{1.900541, 0.048113, -0.061010}}],
    Polygon[{{1.897889, 0.036452, -0.057158},{1.900541, 0.028289, -0.051898},{
      1.911052, 0.033645, -0.051898},{1.906007, 0.040589, -0.057158}}],
    Polygon[{{1.900541, 0.028289, -0.051898},{1.902906, 0.021009, -0.045361},{
      1.915551, 0.027452, -0.045361},{1.911052, 0.033645, -0.051898}}],
    Polygon[{{1.902906, 0.021009, -0.045361},{1.904926, 0.014792, -0.037706},{
      1.919394, 0.022163, -0.037706},{1.915551, 0.027452, -0.045361}}],
    Polygon[{{1.904926, 0.014792, -0.037706},{1.906552, 0.009789, -0.029124},{
      1.922486, 0.017908, -0.029124},{1.919394, 0.022163, -0.037706}}],
    Polygon[{{1.906552, 0.009789, -0.029124},{1.907742, 0.006126, -0.019823},{
      1.924750, 0.014792, -0.019823},{1.922486, 0.017908, -0.029124}}],
    Polygon[{{1.907742, 0.006126, -0.019823},{1.908468, 0.003891, -0.010035},{
      1.926131, 0.012891, -0.010035},{1.924750, 0.014792, -0.019823}}],
    Polygon[{{1.908468, 0.003891, -0.010035},{1.908712, 0.003140, 0.000000},{
      1.926595, 0.012252, 0.000000},{1.926131, 0.012891, -0.010035}}],
    Polygon[{{1.908712, 0.003140, 0.000000},{1.908468, 0.003891, 0.010035},{
      1.926131, 0.012891, 0.010035},{1.926595, 0.012252, 0.000000}}],
    Polygon[{{1.908468, 0.003891, 0.010035},{1.907742, 0.006126, 0.019823},{
      1.924750, 0.014792, 0.019823},{1.926131, 0.012891, 0.010035}}],
    Polygon[{{1.907742, 0.006126, 0.019823},{1.906552, 0.009789, 0.029124},{
      1.922486, 0.017908, 0.029124},{1.924750, 0.014792, 0.019823}}],
    Polygon[{{1.906552, 0.009789, 0.029124},{1.904926, 0.014792, 0.037706},{
      1.919394, 0.022163, 0.037706},{1.922486, 0.017908, 0.029124}}],
    Polygon[{{1.904926, 0.014792, 0.037706},{1.902906, 0.021009, 0.045361},{
      1.915551, 0.027452, 0.045361},{1.919394, 0.022163, 0.037706}}],
    Polygon[{{1.902906, 0.021009, 0.045361},{1.900541, 0.028289, 0.051898},{
      1.911052, 0.033645, 0.051898},{1.915551, 0.027452, 0.045361}}],
    Polygon[{{1.900541, 0.028289, 0.051898},{1.897889, 0.036452, 0.057158},{
      1.906007, 0.040589, 0.057158},{1.911052, 0.033645, 0.051898}}],
    Polygon[{{1.897889, 0.036452, 0.057158},{1.895015, 0.045297, 0.061010},{
      1.900541, 0.048113, 0.061010},{1.906007, 0.040589, 0.057158}}],
    Polygon[{{1.895015, 0.045297, 0.061010},{1.891990, 0.054606, 0.063360},{
      1.894787, 0.056031, 0.063360},{1.900541, 0.048113, 0.061010}}],
    Polygon[{{1.894787, 0.056031, -0.063360},{1.900541, 0.048113, -0.061010},{
      1.904926, 0.052498, -0.061010},{1.897008, 0.058251, -0.063360}}],
    Polygon[{{1.900541, 0.048113, -0.061010},{1.906007, 0.040589, -0.057158},{
      1.912450, 0.047032, -0.057158},{1.904926, 0.052498, -0.061010}}],
    Polygon[{{1.906007, 0.040589, -0.057158},{1.911052, 0.033645, -0.051898},{
      1.919394, 0.041987, -0.051898},{1.912450, 0.047032, -0.057158}}],
    Polygon[{{1.911052, 0.033645, -0.051898},{1.915551, 0.027452, -0.045361},{
      1.925587, 0.037488, -0.045361},{1.919394, 0.041987, -0.051898}}],
    Polygon[{{1.915551, 0.027452, -0.045361},{1.919394, 0.022163, -0.037706},{
      1.930876, 0.033645, -0.037706},{1.925587, 0.037488, -0.045361}}],
    Polygon[{{1.919394, 0.022163, -0.037706},{1.922486, 0.017908, -0.029124},{
      1.935131, 0.030553, -0.029124},{1.930876, 0.033645, -0.037706}}],
    Polygon[{{1.922486, 0.017908, -0.029124},{1.924750, 0.014792, -0.019823},{
      1.938247, 0.028289, -0.019823},{1.935131, 0.030553, -0.029124}}],
    Polygon[{{1.924750, 0.014792, -0.019823},{1.926131, 0.012891, -0.010035},{
      1.940148, 0.026908, -0.010035},{1.938247, 0.028289, -0.019823}}],
    Polygon[{{1.926131, 0.012891, -0.010035},{1.926595, 0.012252, 0.000000},{
      1.940787, 0.026444, 0.000000},{1.940148, 0.026908, -0.010035}}],
    Polygon[{{1.926595, 0.012252, 0.000000},{1.926131, 0.012891, 0.010035},{
      1.940148, 0.026908, 0.010035},{1.940787, 0.026444, 0.000000}}],
    Polygon[{{1.926131, 0.012891, 0.010035},{1.924750, 0.014792, 0.019823},{
      1.938247, 0.028289, 0.019823},{1.940148, 0.026908, 0.010035}}],
    Polygon[{{1.924750, 0.014792, 0.019823},{1.922486, 0.017908, 0.029124},{
      1.935131, 0.030553, 0.029124},{1.938247, 0.028289, 0.019823}}],
    Polygon[{{1.922486, 0.017908, 0.029124},{1.919394, 0.022163, 0.037706},{
      1.930876, 0.033645, 0.037706},{1.935131, 0.030553, 0.029124}}],
    Polygon[{{1.919394, 0.022163, 0.037706},{1.915551, 0.027452, 0.045361},{
      1.925587, 0.037488, 0.045361},{1.930876, 0.033645, 0.037706}}],
    Polygon[{{1.915551, 0.027452, 0.045361},{1.911052, 0.033645, 0.051898},{
      1.919394, 0.041987, 0.051898},{1.925587, 0.037488, 0.045361}}],
    Polygon[{{1.911052, 0.033645, 0.051898},{1.906007, 0.040589, 0.057158},{
      1.912450, 0.047032, 0.057158},{1.919394, 0.041987, 0.051898}}],
    Polygon[{{1.906007, 0.040589, 0.057158},{1.900541, 0.048113, 0.061010},{
      1.904926, 0.052498, 0.061010},{1.912450, 0.047032, 0.057158}}],
    Polygon[{{1.900541, 0.048113, 0.061010},{1.894787, 0.056031, 0.063360},{
      1.897008, 0.058251, 0.063360},{1.904926, 0.052498, 0.061010}}],
    Polygon[{{1.897008, 0.058251, -0.063360},{1.904926, 0.052498, -0.061010},{
      1.907742, 0.058024, -0.061010},{1.898433, 0.061049, -0.063360}}],
    Polygon[{{1.904926, 0.052498, -0.061010},{1.912450, 0.047032, -0.057158},{
      1.916587, 0.055150, -0.057158},{1.907742, 0.058024, -0.061010}}],
    Polygon[{{1.912450, 0.047032, -0.057158},{1.919394, 0.041987, -0.051898},{
      1.924750, 0.052498, -0.051898},{1.916587, 0.055150, -0.057158}}],
    Polygon[{{1.919394, 0.041987, -0.051898},{1.925587, 0.037488, -0.045361},{
      1.932030, 0.050133, -0.045361},{1.924750, 0.052498, -0.051898}}],
    Polygon[{{1.925587, 0.037488, -0.045361},{1.930876, 0.033645, -0.037706},{
      1.938247, 0.048113, -0.037706},{1.932030, 0.050133, -0.045361}}],
    Polygon[{{1.930876, 0.033645, -0.037706},{1.935131, 0.030553, -0.029124},{
      1.943249, 0.046487, -0.029124},{1.938247, 0.048113, -0.037706}}],
    Polygon[{{1.935131, 0.030553, -0.029124},{1.938247, 0.028289, -0.019823},{
      1.946913, 0.045297, -0.019823},{1.943249, 0.046487, -0.029124}}],
    Polygon[{{1.938247, 0.028289, -0.019823},{1.940148, 0.026908, -0.010035},{
      1.949148, 0.044571, -0.010035},{1.946913, 0.045297, -0.019823}}],
    Polygon[{{1.940148, 0.026908, -0.010035},{1.940787, 0.026444, 0.000000},{
      1.949899, 0.044327, 0.000000},{1.949148, 0.044571, -0.010035}}],
    Polygon[{{1.940787, 0.026444, 0.000000},{1.940148, 0.026908, 0.010035},{
      1.949148, 0.044571, 0.010035},{1.949899, 0.044327, 0.000000}}],
    Polygon[{{1.940148, 0.026908, 0.010035},{1.938247, 0.028289, 0.019823},{
      1.946913, 0.045297, 0.019823},{1.949148, 0.044571, 0.010035}}],
    Polygon[{{1.938247, 0.028289, 0.019823},{1.935131, 0.030553, 0.029124},{
      1.943249, 0.046487, 0.029124},{1.946913, 0.045297, 0.019823}}],
    Polygon[{{1.935131, 0.030553, 0.029124},{1.930876, 0.033645, 0.037706},{
      1.938247, 0.048113, 0.037706},{1.943249, 0.046487, 0.029124}}],
    Polygon[{{1.930876, 0.033645, 0.037706},{1.925587, 0.037488, 0.045361},{
      1.932030, 0.050133, 0.045361},{1.938247, 0.048113, 0.037706}}],
    Polygon[{{1.925587, 0.037488, 0.045361},{1.919394, 0.041987, 0.051898},{
      1.924750, 0.052498, 0.051898},{1.932030, 0.050133, 0.045361}}],
    Polygon[{{1.919394, 0.041987, 0.051898},{1.912450, 0.047032, 0.057158},{
      1.916587, 0.055150, 0.057158},{1.924750, 0.052498, 0.051898}}],
    Polygon[{{1.912450, 0.047032, 0.057158},{1.904926, 0.052498, 0.061010},{
      1.907742, 0.058024, 0.061010},{1.916587, 0.055150, 0.057158}}],
    Polygon[{{1.904926, 0.052498, 0.061010},{1.897008, 0.058251, 0.063360},{
      1.898433, 0.061049, 0.063360},{1.907742, 0.058024, 0.061010}}],
    Polygon[{{1.898433, 0.061049, -0.063360},{1.907742, 0.058024, -0.061010},{
      1.908712, 0.064150, -0.061010},{1.898924, 0.064150, -0.063360}}],
    Polygon[{{1.907742, 0.058024, -0.061010},{1.916587, 0.055150, -0.057158},{
      1.918012, 0.064150, -0.057158},{1.908712, 0.064150, -0.061010}}],
    Polygon[{{1.916587, 0.055150, -0.057158},{1.924750, 0.052498, -0.051898},{
      1.926595, 0.064150, -0.051898},{1.918012, 0.064150, -0.057158}}],
    Polygon[{{1.924750, 0.052498, -0.051898},{1.932030, 0.050133, -0.045361},{
      1.934250, 0.064150, -0.045361},{1.926595, 0.064150, -0.051898}}],
    Polygon[{{1.932030, 0.050133, -0.045361},{1.938247, 0.048113, -0.037706},{
      1.940787, 0.064150, -0.037706},{1.934250, 0.064150, -0.045361}}],
    Polygon[{{1.938247, 0.048113, -0.037706},{1.943249, 0.046487, -0.029124},{
      1.946047, 0.064150, -0.029124},{1.940787, 0.064150, -0.037706}}],
    Polygon[{{1.943249, 0.046487, -0.029124},{1.946913, 0.045297, -0.019823},{
      1.949899, 0.064150, -0.019823},{1.946047, 0.064150, -0.029124}}],
    Polygon[{{1.946913, 0.045297, -0.019823},{1.949148, 0.044571, -0.010035},{
      1.952249, 0.064150, -0.010035},{1.949899, 0.064150, -0.019823}}],
    Polygon[{{1.949148, 0.044571, -0.010035},{1.949899, 0.044327, 0.000000},{
      1.953039, 0.064150, 0.000000},{1.952249, 0.064150, -0.010035}}],
    Polygon[{{1.949899, 0.044327, 0.000000},{1.949148, 0.044571, 0.010035},{
      1.952249, 0.064150, 0.010035},{1.953039, 0.064150, 0.000000}}],
    Polygon[{{1.949148, 0.044571, 0.010035},{1.946913, 0.045297, 0.019823},{
      1.949899, 0.064150, 0.019823},{1.952249, 0.064150, 0.010035}}],
    Polygon[{{1.946913, 0.045297, 0.019823},{1.943249, 0.046487, 0.029124},{
      1.946047, 0.064150, 0.029124},{1.949899, 0.064150, 0.019823}}],
    Polygon[{{1.943249, 0.046487, 0.029124},{1.938247, 0.048113, 0.037706},{
      1.940787, 0.064150, 0.037706},{1.946047, 0.064150, 0.029124}}],
    Polygon[{{1.938247, 0.048113, 0.037706},{1.932030, 0.050133, 0.045361},{
      1.934250, 0.064150, 0.045361},{1.940787, 0.064150, 0.037706}}],
    Polygon[{{1.932030, 0.050133, 0.045361},{1.924750, 0.052498, 0.051898},{
      1.926595, 0.064150, 0.051898},{1.934250, 0.064150, 0.045361}}],
    Polygon[{{1.924750, 0.052498, 0.051898},{1.916587, 0.055150, 0.057158},{
      1.918012, 0.064150, 0.057158},{1.926595, 0.064150, 0.051898}}],
    Polygon[{{1.916587, 0.055150, 0.057158},{1.907742, 0.058024, 0.061010},{
      1.908712, 0.064150, 0.061010},{1.918012, 0.064150, 0.057158}}],
    Polygon[{{1.907742, 0.058024, 0.061010},{1.898433, 0.061049, 0.063360},{
      1.898924, 0.064150, 0.063360},{1.908712, 0.064150, 0.061010}}],
    Polygon[{{1.966308, 0.021383, -0.021120},{1.969571, 0.021383, -0.020337},{
      1.969247, 0.023425, -0.020337},{1.966144, 0.022417, -0.021120}}],
    Polygon[{{1.969571, 0.021383, -0.020337},{1.972671, 0.021383, -0.019053},{
      1.972196, 0.024383, -0.019053},{1.969247, 0.023425, -0.020337}}],
    Polygon[{{1.972671, 0.021383, -0.019053},{1.975532, 0.021383, -0.017299},{
      1.974917, 0.025267, -0.017299},{1.972196, 0.024383, -0.019053}}],
    Polygon[{{1.975532, 0.021383, -0.017299},{1.978083, 0.021383, -0.015120},{
      1.977343, 0.026056, -0.015120},{1.974917, 0.025267, -0.017299}}],
    Polygon[{{1.978083, 0.021383, -0.015120},{1.980262, 0.021383, -0.012569},{
      1.979416, 0.026729, -0.012569},{1.977343, 0.026056, -0.015120}}],
    Polygon[{{1.980262, 0.021383, -0.012569},{1.982016, 0.021383, -0.009708},{
      1.981083, 0.027271, -0.009708},{1.979416, 0.026729, -0.012569}}],
    Polygon[{{1.982016, 0.021383, -0.009708},{1.983300, 0.021383, -0.006608},{
      1.982304, 0.027668, -0.006608},{1.981083, 0.027271, -0.009708}}],
    Polygon[{{1.983300, 0.021383, -0.006608},{1.984083, 0.021383, -0.003345},{
      1.983049, 0.027910, -0.003345},{1.982304, 0.027668, -0.006608}}],
    Polygon[{{1.984083, 0.021383, -0.003345},{1.984346, 0.021383, 0.000000},{
      1.983300, 0.027991, 0.000000},{1.983049, 0.027910, -0.003345}}],
    Polygon[{{1.984346, 0.021383, 0.000000},{1.984083, 0.021383, 0.003345},{
      1.983049, 0.027910, 0.003345},{1.983300, 0.027991, 0.000000}}],
    Polygon[{{1.984083, 0.021383, 0.003345},{1.983300, 0.021383, 0.006608},{
      1.982304, 0.027668, 0.006608},{1.983049, 0.027910, 0.003345}}],
    Polygon[{{1.983300, 0.021383, 0.006608},{1.982016, 0.021383, 0.009708},{
      1.981083, 0.027271, 0.009708},{1.982304, 0.027668, 0.006608}}],
    Polygon[{{1.982016, 0.021383, 0.009708},{1.980262, 0.021383, 0.012569},{
      1.979416, 0.026729, 0.012569},{1.981083, 0.027271, 0.009708}}],
    Polygon[{{1.980262, 0.021383, 0.012569},{1.978083, 0.021383, 0.015120},{
      1.977343, 0.026056, 0.015120},{1.979416, 0.026729, 0.012569}}],
    Polygon[{{1.978083, 0.021383, 0.015120},{1.975532, 0.021383, 0.017299},{
      1.974917, 0.025267, 0.017299},{1.977343, 0.026056, 0.015120}}],
    Polygon[{{1.975532, 0.021383, 0.017299},{1.972671, 0.021383, 0.019053},{
      1.972196, 0.024383, 0.019053},{1.974917, 0.025267, 0.017299}}],
    Polygon[{{1.972671, 0.021383, 0.019053},{1.969571, 0.021383, 0.020337},{
      1.969247, 0.023425, 0.020337},{1.972196, 0.024383, 0.019053}}],
    Polygon[{{1.969571, 0.021383, 0.020337},{1.966308, 0.021383, 0.021120},{
      1.966144, 0.022417, 0.021120},{1.969247, 0.023425, 0.020337}}],
    Polygon[{{1.966144, 0.022417, -0.021120},{1.969247, 0.023425, -0.020337},{
      1.968309, 0.025267, -0.020337},{1.965669, 0.023350, -0.021120}}],
    Polygon[{{1.969247, 0.023425, -0.020337},{1.972196, 0.024383, -0.019053},{
      1.970817, 0.027089, -0.019053},{1.968309, 0.025267, -0.020337}}],
    Polygon[{{1.972196, 0.024383, -0.019053},{1.974917, 0.025267, -0.017299},{
      1.973131, 0.028771, -0.017299},{1.970817, 0.027089, -0.019053}}],
    Polygon[{{1.974917, 0.025267, -0.017299},{1.977343, 0.026056, -0.015120},{
      1.975196, 0.030271, -0.015120},{1.973131, 0.028771, -0.017299}}],
    Polygon[{{1.977343, 0.026056, -0.015120},{1.979416, 0.026729, -0.012569},{
      1.976959, 0.031552, -0.012569},{1.975196, 0.030271, -0.015120}}],
    Polygon[{{1.979416, 0.026729, -0.012569},{1.981083, 0.027271, -0.009708},{
      1.978377, 0.032582, -0.009708},{1.976959, 0.031552, -0.012569}}],
    Polygon[{{1.981083, 0.027271, -0.009708},{1.982304, 0.027668, -0.006608},{
      1.979416, 0.033337, -0.006608},{1.978377, 0.032582, -0.009708}}],
    Polygon[{{1.982304, 0.027668, -0.006608},{1.983049, 0.027910, -0.003345},{
      1.980049, 0.033797, -0.003345},{1.979416, 0.033337, -0.006608}}],
    Polygon[{{1.983049, 0.027910, -0.003345},{1.983300, 0.027991, 0.000000},{
      1.980262, 0.033952, 0.000000},{1.980049, 0.033797, -0.003345}}],
    Polygon[{{1.983300, 0.027991, 0.000000},{1.983049, 0.027910, 0.003345},{
      1.980049, 0.033797, 0.003345},{1.980262, 0.033952, 0.000000}}],
    Polygon[{{1.983049, 0.027910, 0.003345},{1.982304, 0.027668, 0.006608},{
      1.979416, 0.033337, 0.006608},{1.980049, 0.033797, 0.003345}}],
    Polygon[{{1.982304, 0.027668, 0.006608},{1.981083, 0.027271, 0.009708},{
      1.978377, 0.032582, 0.009708},{1.979416, 0.033337, 0.006608}}],
    Polygon[{{1.981083, 0.027271, 0.009708},{1.979416, 0.026729, 0.012569},{
      1.976959, 0.031552, 0.012569},{1.978377, 0.032582, 0.009708}}],
    Polygon[{{1.979416, 0.026729, 0.012569},{1.977343, 0.026056, 0.015120},{
      1.975196, 0.030271, 0.015120},{1.976959, 0.031552, 0.012569}}],
    Polygon[{{1.977343, 0.026056, 0.015120},{1.974917, 0.025267, 0.017299},{
      1.973131, 0.028771, 0.017299},{1.975196, 0.030271, 0.015120}}],
    Polygon[{{1.974917, 0.025267, 0.017299},{1.972196, 0.024383, 0.019053},{
      1.970817, 0.027089, 0.019053},{1.973131, 0.028771, 0.017299}}],
    Polygon[{{1.972196, 0.024383, 0.019053},{1.969247, 0.023425, 0.020337},{
      1.968309, 0.025267, 0.020337},{1.970817, 0.027089, 0.019053}}],
    Polygon[{{1.969247, 0.023425, 0.020337},{1.966144, 0.022417, 0.021120},{
      1.965669, 0.023350, 0.021120},{1.968309, 0.025267, 0.020337}}],
    Polygon[{{1.965669, 0.023350, -0.021120},{1.968309, 0.025267, -0.020337},{
      1.966847, 0.026729, -0.020337},{1.964929, 0.024090, -0.021120}}],
    Polygon[{{1.968309, 0.025267, -0.020337},{1.970817, 0.027089, -0.019053},{
      1.968669, 0.029237, -0.019053},{1.966847, 0.026729, -0.020337}}],
    Polygon[{{1.970817, 0.027089, -0.019053},{1.973131, 0.028771, -0.017299},{
      1.970351, 0.031552, -0.017299},{1.968669, 0.029237, -0.019053}}],
    Polygon[{{1.973131, 0.028771, -0.017299},{1.975196, 0.030271, -0.015120},{
      1.971851, 0.033616, -0.015120},{1.970351, 0.031552, -0.017299}}],
    Polygon[{{1.975196, 0.030271, -0.015120},{1.976959, 0.031552, -0.012569},{
      1.973131, 0.035379, -0.012569},{1.971851, 0.033616, -0.015120}}],
    Polygon[{{1.976959, 0.031552, -0.012569},{1.978377, 0.032582, -0.009708},{
      1.974162, 0.036797, -0.009708},{1.973131, 0.035379, -0.012569}}],
    Polygon[{{1.978377, 0.032582, -0.009708},{1.979416, 0.033337, -0.006608},{
      1.974917, 0.037836, -0.006608},{1.974162, 0.036797, -0.009708}}],
    Polygon[{{1.979416, 0.033337, -0.006608},{1.980049, 0.033797, -0.003345},{
      1.975377, 0.038470, -0.003345},{1.974917, 0.037836, -0.006608}}],
    Polygon[{{1.980049, 0.033797, -0.003345},{1.980262, 0.033952, 0.000000},{
      1.975532, 0.038683, 0.000000},{1.975377, 0.038470, -0.003345}}],
    Polygon[{{1.980262, 0.033952, 0.000000},{1.980049, 0.033797, 0.003345},{
      1.975377, 0.038470, 0.003345},{1.975532, 0.038683, 0.000000}}],
    Polygon[{{1.980049, 0.033797, 0.003345},{1.979416, 0.033337, 0.006608},{
      1.974917, 0.037836, 0.006608},{1.975377, 0.038470, 0.003345}}],
    Polygon[{{1.979416, 0.033337, 0.006608},{1.978377, 0.032582, 0.009708},{
      1.974162, 0.036797, 0.009708},{1.974917, 0.037836, 0.006608}}],
    Polygon[{{1.978377, 0.032582, 0.009708},{1.976959, 0.031552, 0.012569},{
      1.973131, 0.035379, 0.012569},{1.974162, 0.036797, 0.009708}}],
    Polygon[{{1.976959, 0.031552, 0.012569},{1.975196, 0.030271, 0.015120},{
      1.971851, 0.033616, 0.015120},{1.973131, 0.035379, 0.012569}}],
    Polygon[{{1.975196, 0.030271, 0.015120},{1.973131, 0.028771, 0.017299},{
      1.970351, 0.031552, 0.017299},{1.971851, 0.033616, 0.015120}}],
    Polygon[{{1.973131, 0.028771, 0.017299},{1.970817, 0.027089, 0.019053},{
      1.968669, 0.029237, 0.019053},{1.970351, 0.031552, 0.017299}}],
    Polygon[{{1.970817, 0.027089, 0.019053},{1.968309, 0.025267, 0.020337},{
      1.966847, 0.026729, 0.020337},{1.968669, 0.029237, 0.019053}}],
    Polygon[{{1.968309, 0.025267, 0.020337},{1.965669, 0.023350, 0.021120},{
      1.964929, 0.024090, 0.021120},{1.966847, 0.026729, 0.020337}}],
    Polygon[{{1.964929, 0.024090, -0.021120},{1.966847, 0.026729, -0.020337},{
      1.965005, 0.027668, -0.020337},{1.963997, 0.024565, -0.021120}}],
    Polygon[{{1.966847, 0.026729, -0.020337},{1.968669, 0.029237, -0.019053},{
      1.965963, 0.030616, -0.019053},{1.965005, 0.027668, -0.020337}}],
    Polygon[{{1.968669, 0.029237, -0.019053},{1.970351, 0.031552, -0.017299},{
      1.966847, 0.033337, -0.017299},{1.965963, 0.030616, -0.019053}}],
    Polygon[{{1.970351, 0.031552, -0.017299},{1.971851, 0.033616, -0.015120},{
      1.967635, 0.035764, -0.015120},{1.966847, 0.033337, -0.017299}}],
    Polygon[{{1.971851, 0.033616, -0.015120},{1.973131, 0.035379, -0.012569},{
      1.968309, 0.037836, -0.012569},{1.967635, 0.035764, -0.015120}}],
    Polygon[{{1.973131, 0.035379, -0.012569},{1.974162, 0.036797, -0.009708},{
      1.968851, 0.039504, -0.009708},{1.968309, 0.037836, -0.012569}}],
    Polygon[{{1.974162, 0.036797, -0.009708},{1.974917, 0.037836, -0.006608},{
      1.969247, 0.040725, -0.006608},{1.968851, 0.039504, -0.009708}}],
    Polygon[{{1.974917, 0.037836, -0.006608},{1.975377, 0.038470, -0.003345},{
      1.969489, 0.041470, -0.003345},{1.969247, 0.040725, -0.006608}}],
    Polygon[{{1.975377, 0.038470, -0.003345},{1.975532, 0.038683, 0.000000},{
      1.969571, 0.041720, 0.000000},{1.969489, 0.041470, -0.003345}}],
    Polygon[{{1.975532, 0.038683, 0.000000},{1.975377, 0.038470, 0.003345},{
      1.969489, 0.041470, 0.003345},{1.969571, 0.041720, 0.000000}}],
    Polygon[{{1.975377, 0.038470, 0.003345},{1.974917, 0.037836, 0.006608},{
      1.969247, 0.040725, 0.006608},{1.969489, 0.041470, 0.003345}}],
    Polygon[{{1.974917, 0.037836, 0.006608},{1.974162, 0.036797, 0.009708},{
      1.968851, 0.039504, 0.009708},{1.969247, 0.040725, 0.006608}}],
    Polygon[{{1.974162, 0.036797, 0.009708},{1.973131, 0.035379, 0.012569},{
      1.968309, 0.037836, 0.012569},{1.968851, 0.039504, 0.009708}}],
    Polygon[{{1.973131, 0.035379, 0.012569},{1.971851, 0.033616, 0.015120},{
      1.967635, 0.035764, 0.015120},{1.968309, 0.037836, 0.012569}}],
    Polygon[{{1.971851, 0.033616, 0.015120},{1.970351, 0.031552, 0.017299},{
      1.966847, 0.033337, 0.017299},{1.967635, 0.035764, 0.015120}}],
    Polygon[{{1.970351, 0.031552, 0.017299},{1.968669, 0.029237, 0.019053},{
      1.965963, 0.030616, 0.019053},{1.966847, 0.033337, 0.017299}}],
    Polygon[{{1.968669, 0.029237, 0.019053},{1.966847, 0.026729, 0.020337},{
      1.965005, 0.027668, 0.020337},{1.965963, 0.030616, 0.019053}}],
    Polygon[{{1.966847, 0.026729, 0.020337},{1.964929, 0.024090, 0.021120},{
      1.963997, 0.024565, 0.021120},{1.965005, 0.027668, 0.020337}}],
    Polygon[{{1.963997, 0.024565, -0.021120},{1.965005, 0.027668, -0.020337},{
      1.962963, 0.027991, -0.020337},{1.962963, 0.024728, -0.021120}}],
    Polygon[{{1.965005, 0.027668, -0.020337},{1.965963, 0.030616, -0.019053},{
      1.962963, 0.031091, -0.019053},{1.962963, 0.027991, -0.020337}}],
    Polygon[{{1.965963, 0.030616, -0.019053},{1.966847, 0.033337, -0.017299},{
      1.962963, 0.033952, -0.017299},{1.962963, 0.031091, -0.019053}}],
    Polygon[{{1.966847, 0.033337, -0.017299},{1.967635, 0.035764, -0.015120},{
      1.962963, 0.036504, -0.015120},{1.962963, 0.033952, -0.017299}}],
    Polygon[{{1.967635, 0.035764, -0.015120},{1.968309, 0.037836, -0.012569},{
      1.962963, 0.038683, -0.012569},{1.962963, 0.036504, -0.015120}}],
    Polygon[{{1.968309, 0.037836, -0.012569},{1.968851, 0.039504, -0.009708},{
      1.962963, 0.040436, -0.009708},{1.962963, 0.038683, -0.012569}}],
    Polygon[{{1.968851, 0.039504, -0.009708},{1.969247, 0.040725, -0.006608},{
      1.962963, 0.041720, -0.006608},{1.962963, 0.040436, -0.009708}}],
    Polygon[{{1.969247, 0.040725, -0.006608},{1.969489, 0.041470, -0.003345},{
      1.962963, 0.042503, -0.003345},{1.962963, 0.041720, -0.006608}}],
    Polygon[{{1.969489, 0.041470, -0.003345},{1.969571, 0.041720, 0.000000},{
      1.962963, 0.042767, 0.000000},{1.962963, 0.042503, -0.003345}}],
    Polygon[{{1.969571, 0.041720, 0.000000},{1.969489, 0.041470, 0.003345},{
      1.962963, 0.042503, 0.003345},{1.962963, 0.042767, 0.000000}}],
    Polygon[{{1.969489, 0.041470, 0.003345},{1.969247, 0.040725, 0.006608},{
      1.962963, 0.041720, 0.006608},{1.962963, 0.042503, 0.003345}}],
    Polygon[{{1.969247, 0.040725, 0.006608},{1.968851, 0.039504, 0.009708},{
      1.962963, 0.040436, 0.009708},{1.962963, 0.041720, 0.006608}}],
    Polygon[{{1.968851, 0.039504, 0.009708},{1.968309, 0.037836, 0.012569},{
      1.962963, 0.038683, 0.012569},{1.962963, 0.040436, 0.009708}}],
    Polygon[{{1.968309, 0.037836, 0.012569},{1.967635, 0.035764, 0.015120},{
      1.962963, 0.036504, 0.015120},{1.962963, 0.038683, 0.012569}}],
    Polygon[{{1.967635, 0.035764, 0.015120},{1.966847, 0.033337, 0.017299},{
      1.962963, 0.033952, 0.017299},{1.962963, 0.036504, 0.015120}}],
    Polygon[{{1.966847, 0.033337, 0.017299},{1.965963, 0.030616, 0.019053},{
      1.962963, 0.031091, 0.019053},{1.962963, 0.033952, 0.017299}}],
    Polygon[{{1.965963, 0.030616, 0.019053},{1.965005, 0.027668, 0.020337},{
      1.962963, 0.027991, 0.020337},{1.962963, 0.031091, 0.019053}}],
    Polygon[{{1.965005, 0.027668, 0.020337},{1.963997, 0.024565, 0.021120},{
      1.962963, 0.024728, 0.021120},{1.962963, 0.027991, 0.020337}}],
    Polygon[{{1.962963, 0.024728, -0.021120},{1.962963, 0.027991, -0.020337},{
      1.960921, 0.027668, -0.020337},{1.961929, 0.024565, -0.021120}}],
    Polygon[{{1.962963, 0.027991, -0.020337},{1.962963, 0.031091, -0.019053},{
      1.959963, 0.030616, -0.019053},{1.960921, 0.027668, -0.020337}}],
    Polygon[{{1.962963, 0.031091, -0.019053},{1.962963, 0.033952, -0.017299},{
      1.959079, 0.033337, -0.017299},{1.959963, 0.030616, -0.019053}}],
    Polygon[{{1.962963, 0.033952, -0.017299},{1.962963, 0.036504, -0.015120},{
      1.958291, 0.035764, -0.015120},{1.959079, 0.033337, -0.017299}}],
    Polygon[{{1.962963, 0.036504, -0.015120},{1.962963, 0.038683, -0.012569},{
      1.957617, 0.037836, -0.012569},{1.958291, 0.035764, -0.015120}}],
    Polygon[{{1.962963, 0.038683, -0.012569},{1.962963, 0.040436, -0.009708},{
      1.957075, 0.039504, -0.009708},{1.957617, 0.037836, -0.012569}}],
    Polygon[{{1.962963, 0.040436, -0.009708},{1.962963, 0.041720, -0.006608},{
      1.956679, 0.040725, -0.006608},{1.957075, 0.039504, -0.009708}}],
    Polygon[{{1.962963, 0.041720, -0.006608},{1.962963, 0.042503, -0.003345},{
      1.956437, 0.041470, -0.003345},{1.956679, 0.040725, -0.006608}}],
    Polygon[{{1.962963, 0.042503, -0.003345},{1.962963, 0.042767, 0.000000},{
      1.956355, 0.041720, 0.000000},{1.956437, 0.041470, -0.003345}}],
    Polygon[{{1.962963, 0.042767, 0.000000},{1.962963, 0.042503, 0.003345},{
      1.956437, 0.041470, 0.003345},{1.956355, 0.041720, 0.000000}}],
    Polygon[{{1.962963, 0.042503, 0.003345},{1.962963, 0.041720, 0.006608},{
      1.956679, 0.040725, 0.006608},{1.956437, 0.041470, 0.003345}}],
    Polygon[{{1.962963, 0.041720, 0.006608},{1.962963, 0.040436, 0.009708},{
      1.957075, 0.039504, 0.009708},{1.956679, 0.040725, 0.006608}}],
    Polygon[{{1.962963, 0.040436, 0.009708},{1.962963, 0.038683, 0.012569},{
      1.957617, 0.037836, 0.012569},{1.957075, 0.039504, 0.009708}}],
    Polygon[{{1.962963, 0.038683, 0.012569},{1.962963, 0.036504, 0.015120},{
      1.958291, 0.035764, 0.015120},{1.957617, 0.037836, 0.012569}}],
    Polygon[{{1.962963, 0.036504, 0.015120},{1.962963, 0.033952, 0.017299},{
      1.959079, 0.033337, 0.017299},{1.958291, 0.035764, 0.015120}}],
    Polygon[{{1.962963, 0.033952, 0.017299},{1.962963, 0.031091, 0.019053},{
      1.959963, 0.030616, 0.019053},{1.959079, 0.033337, 0.017299}}],
    Polygon[{{1.962963, 0.031091, 0.019053},{1.962963, 0.027991, 0.020337},{
      1.960921, 0.027668, 0.020337},{1.959963, 0.030616, 0.019053}}],
    Polygon[{{1.962963, 0.027991, 0.020337},{1.962963, 0.024728, 0.021120},{
      1.961929, 0.024565, 0.021120},{1.960921, 0.027668, 0.020337}}],
    Polygon[{{1.961929, 0.024565, -0.021120},{1.960921, 0.027668, -0.020337},{
      1.959079, 0.026729, -0.020337},{1.960997, 0.024090, -0.021120}}],
    Polygon[{{1.960921, 0.027668, -0.020337},{1.959963, 0.030616, -0.019053},{
      1.957257, 0.029237, -0.019053},{1.959079, 0.026729, -0.020337}}],
    Polygon[{{1.959963, 0.030616, -0.019053},{1.959079, 0.033337, -0.017299},{
      1.955575, 0.031552, -0.017299},{1.957257, 0.029237, -0.019053}}],
    Polygon[{{1.959079, 0.033337, -0.017299},{1.958291, 0.035764, -0.015120},{
      1.954075, 0.033616, -0.015120},{1.955575, 0.031552, -0.017299}}],
    Polygon[{{1.958291, 0.035764, -0.015120},{1.957617, 0.037836, -0.012569},{
      1.952795, 0.035379, -0.012569},{1.954075, 0.033616, -0.015120}}],
    Polygon[{{1.957617, 0.037836, -0.012569},{1.957075, 0.039504, -0.009708},{
      1.951764, 0.036797, -0.009708},{1.952795, 0.035379, -0.012569}}],
    Polygon[{{1.957075, 0.039504, -0.009708},{1.956679, 0.040725, -0.006608},{
      1.951009, 0.037836, -0.006608},{1.951764, 0.036797, -0.009708}}],
    Polygon[{{1.956679, 0.040725, -0.006608},{1.956437, 0.041470, -0.003345},{
      1.950549, 0.038470, -0.003345},{1.951009, 0.037836, -0.006608}}],
    Polygon[{{1.956437, 0.041470, -0.003345},{1.956355, 0.041720, 0.000000},{
      1.950394, 0.038683, 0.000000},{1.950549, 0.038470, -0.003345}}],
    Polygon[{{1.956355, 0.041720, 0.000000},{1.956437, 0.041470, 0.003345},{
      1.950549, 0.038470, 0.003345},{1.950394, 0.038683, 0.000000}}],
    Polygon[{{1.956437, 0.041470, 0.003345},{1.956679, 0.040725, 0.006608},{
      1.951009, 0.037836, 0.006608},{1.950549, 0.038470, 0.003345}}],
    Polygon[{{1.956679, 0.040725, 0.006608},{1.957075, 0.039504, 0.009708},{
      1.951764, 0.036797, 0.009708},{1.951009, 0.037836, 0.006608}}],
    Polygon[{{1.957075, 0.039504, 0.009708},{1.957617, 0.037836, 0.012569},{
      1.952795, 0.035379, 0.012569},{1.951764, 0.036797, 0.009708}}],
    Polygon[{{1.957617, 0.037836, 0.012569},{1.958291, 0.035764, 0.015120},{
      1.954075, 0.033616, 0.015120},{1.952795, 0.035379, 0.012569}}],
    Polygon[{{1.958291, 0.035764, 0.015120},{1.959079, 0.033337, 0.017299},{
      1.955575, 0.031552, 0.017299},{1.954075, 0.033616, 0.015120}}],
    Polygon[{{1.959079, 0.033337, 0.017299},{1.959963, 0.030616, 0.019053},{
      1.957257, 0.029237, 0.019053},{1.955575, 0.031552, 0.017299}}],
    Polygon[{{1.959963, 0.030616, 0.019053},{1.960921, 0.027668, 0.020337},{
      1.959079, 0.026729, 0.020337},{1.957257, 0.029237, 0.019053}}],
    Polygon[{{1.960921, 0.027668, 0.020337},{1.961929, 0.024565, 0.021120},{
      1.960997, 0.024090, 0.021120},{1.959079, 0.026729, 0.020337}}],
    Polygon[{{1.960997, 0.024090, -0.021120},{1.959079, 0.026729, -0.020337},{
      1.957617, 0.025267, -0.020337},{1.960257, 0.023350, -0.021120}}],
    Polygon[{{1.959079, 0.026729, -0.020337},{1.957257, 0.029237, -0.019053},{
      1.955109, 0.027089, -0.019053},{1.957617, 0.025267, -0.020337}}],
    Polygon[{{1.957257, 0.029237, -0.019053},{1.955575, 0.031552, -0.017299},{
      1.952795, 0.028771, -0.017299},{1.955109, 0.027089, -0.019053}}],
    Polygon[{{1.955575, 0.031552, -0.017299},{1.954075, 0.033616, -0.015120},{
      1.950730, 0.030271, -0.015120},{1.952795, 0.028771, -0.017299}}],
    Polygon[{{1.954075, 0.033616, -0.015120},{1.952795, 0.035379, -0.012569},{
      1.948967, 0.031552, -0.012569},{1.950730, 0.030271, -0.015120}}],
    Polygon[{{1.952795, 0.035379, -0.012569},{1.951764, 0.036797, -0.009708},{
      1.947549, 0.032582, -0.009708},{1.948967, 0.031552, -0.012569}}],
    Polygon[{{1.951764, 0.036797, -0.009708},{1.951009, 0.037836, -0.006608},{
      1.946510, 0.033337, -0.006608},{1.947549, 0.032582, -0.009708}}],
    Polygon[{{1.951009, 0.037836, -0.006608},{1.950549, 0.038470, -0.003345},{
      1.945876, 0.033797, -0.003345},{1.946510, 0.033337, -0.006608}}],
    Polygon[{{1.950549, 0.038470, -0.003345},{1.950394, 0.038683, 0.000000},{
      1.945663, 0.033952, 0.000000},{1.945876, 0.033797, -0.003345}}],
    Polygon[{{1.950394, 0.038683, 0.000000},{1.950549, 0.038470, 0.003345},{
      1.945876, 0.033797, 0.003345},{1.945663, 0.033952, 0.000000}}],
    Polygon[{{1.950549, 0.038470, 0.003345},{1.951009, 0.037836, 0.006608},{
      1.946510, 0.033337, 0.006608},{1.945876, 0.033797, 0.003345}}],
    Polygon[{{1.951009, 0.037836, 0.006608},{1.951764, 0.036797, 0.009708},{
      1.947549, 0.032582, 0.009708},{1.946510, 0.033337, 0.006608}}],
    Polygon[{{1.951764, 0.036797, 0.009708},{1.952795, 0.035379, 0.012569},{
      1.948967, 0.031552, 0.012569},{1.947549, 0.032582, 0.009708}}],
    Polygon[{{1.952795, 0.035379, 0.012569},{1.954075, 0.033616, 0.015120},{
      1.950730, 0.030271, 0.015120},{1.948967, 0.031552, 0.012569}}],
    Polygon[{{1.954075, 0.033616, 0.015120},{1.955575, 0.031552, 0.017299},{
      1.952795, 0.028771, 0.017299},{1.950730, 0.030271, 0.015120}}],
    Polygon[{{1.955575, 0.031552, 0.017299},{1.957257, 0.029237, 0.019053},{
      1.955109, 0.027089, 0.019053},{1.952795, 0.028771, 0.017299}}],
    Polygon[{{1.957257, 0.029237, 0.019053},{1.959079, 0.026729, 0.020337},{
      1.957617, 0.025267, 0.020337},{1.955109, 0.027089, 0.019053}}],
    Polygon[{{1.959079, 0.026729, 0.020337},{1.960997, 0.024090, 0.021120},{
      1.960257, 0.023350, 0.021120},{1.957617, 0.025267, 0.020337}}],
    Polygon[{{1.960257, 0.023350, -0.021120},{1.957617, 0.025267, -0.020337},{
      1.956679, 0.023425, -0.020337},{1.959782, 0.022417, -0.021120}}],
    Polygon[{{1.957617, 0.025267, -0.020337},{1.955109, 0.027089, -0.019053},{
      1.953730, 0.024383, -0.019053},{1.956679, 0.023425, -0.020337}}],
    Polygon[{{1.955109, 0.027089, -0.019053},{1.952795, 0.028771, -0.017299},{
      1.951009, 0.025267, -0.017299},{1.953730, 0.024383, -0.019053}}],
    Polygon[{{1.952795, 0.028771, -0.017299},{1.950730, 0.030271, -0.015120},{
      1.948583, 0.026056, -0.015120},{1.951009, 0.025267, -0.017299}}],
    Polygon[{{1.950730, 0.030271, -0.015120},{1.948967, 0.031552, -0.012569},{
      1.946510, 0.026729, -0.012569},{1.948583, 0.026056, -0.015120}}],
    Polygon[{{1.948967, 0.031552, -0.012569},{1.947549, 0.032582, -0.009708},{
      1.944843, 0.027271, -0.009708},{1.946510, 0.026729, -0.012569}}],
    Polygon[{{1.947549, 0.032582, -0.009708},{1.946510, 0.033337, -0.006608},{
      1.943622, 0.027668, -0.006608},{1.944843, 0.027271, -0.009708}}],
    Polygon[{{1.946510, 0.033337, -0.006608},{1.945876, 0.033797, -0.003345},{
      1.942877, 0.027910, -0.003345},{1.943622, 0.027668, -0.006608}}],
    Polygon[{{1.945876, 0.033797, -0.003345},{1.945663, 0.033952, 0.000000},{
      1.942626, 0.027991, 0.000000},{1.942877, 0.027910, -0.003345}}],
    Polygon[{{1.945663, 0.033952, 0.000000},{1.945876, 0.033797, 0.003345},{
      1.942877, 0.027910, 0.003345},{1.942626, 0.027991, 0.000000}}],
    Polygon[{{1.945876, 0.033797, 0.003345},{1.946510, 0.033337, 0.006608},{
      1.943622, 0.027668, 0.006608},{1.942877, 0.027910, 0.003345}}],
    Polygon[{{1.946510, 0.033337, 0.006608},{1.947549, 0.032582, 0.009708},{
      1.944843, 0.027271, 0.009708},{1.943622, 0.027668, 0.006608}}],
    Polygon[{{1.947549, 0.032582, 0.009708},{1.948967, 0.031552, 0.012569},{
      1.946510, 0.026729, 0.012569},{1.944843, 0.027271, 0.009708}}],
    Polygon[{{1.948967, 0.031552, 0.012569},{1.950730, 0.030271, 0.015120},{
      1.948583, 0.026056, 0.015120},{1.946510, 0.026729, 0.012569}}],
    Polygon[{{1.950730, 0.030271, 0.015120},{1.952795, 0.028771, 0.017299},{
      1.951009, 0.025267, 0.017299},{1.948583, 0.026056, 0.015120}}],
    Polygon[{{1.952795, 0.028771, 0.017299},{1.955109, 0.027089, 0.019053},{
      1.953730, 0.024383, 0.019053},{1.951009, 0.025267, 0.017299}}],
    Polygon[{{1.955109, 0.027089, 0.019053},{1.957617, 0.025267, 0.020337},{
      1.956679, 0.023425, 0.020337},{1.953730, 0.024383, 0.019053}}],
    Polygon[{{1.957617, 0.025267, 0.020337},{1.960257, 0.023350, 0.021120},{
      1.959782, 0.022417, 0.021120},{1.956679, 0.023425, 0.020337}}],
    Polygon[{{1.959782, 0.022417, -0.021120},{1.956679, 0.023425, -0.020337},{
      1.956355, 0.021383, -0.020337},{1.959618, 0.021383, -0.021120}}],
    Polygon[{{1.956679, 0.023425, -0.020337},{1.953730, 0.024383, -0.019053},{
      1.953255, 0.021383, -0.019053},{1.956355, 0.021383, -0.020337}}],
    Polygon[{{1.953730, 0.024383, -0.019053},{1.951009, 0.025267, -0.017299},{
      1.950394, 0.021383, -0.017299},{1.953255, 0.021383, -0.019053}}],
    Polygon[{{1.951009, 0.025267, -0.017299},{1.948583, 0.026056, -0.015120},{
      1.947843, 0.021383, -0.015120},{1.950394, 0.021383, -0.017299}}],
    Polygon[{{1.948583, 0.026056, -0.015120},{1.946510, 0.026729, -0.012569},{
      1.945663, 0.021383, -0.012569},{1.947843, 0.021383, -0.015120}}],
    Polygon[{{1.946510, 0.026729, -0.012569},{1.944843, 0.027271, -0.009708},{
      1.943910, 0.021383, -0.009708},{1.945663, 0.021383, -0.012569}}],
    Polygon[{{1.944843, 0.027271, -0.009708},{1.943622, 0.027668, -0.006608},{
      1.942626, 0.021383, -0.006608},{1.943910, 0.021383, -0.009708}}],
    Polygon[{{1.943622, 0.027668, -0.006608},{1.942877, 0.027910, -0.003345},{
      1.941843, 0.021383, -0.003345},{1.942626, 0.021383, -0.006608}}],
    Polygon[{{1.942877, 0.027910, -0.003345},{1.942626, 0.027991, 0.000000},{
      1.941580, 0.021383, 0.000000},{1.941843, 0.021383, -0.003345}}],
    Polygon[{{1.942626, 0.027991, 0.000000},{1.942877, 0.027910, 0.003345},{
      1.941843, 0.021383, 0.003345},{1.941580, 0.021383, 0.000000}}],
    Polygon[{{1.942877, 0.027910, 0.003345},{1.943622, 0.027668, 0.006608},{
      1.942626, 0.021383, 0.006608},{1.941843, 0.021383, 0.003345}}],
    Polygon[{{1.943622, 0.027668, 0.006608},{1.944843, 0.027271, 0.009708},{
      1.943910, 0.021383, 0.009708},{1.942626, 0.021383, 0.006608}}],
    Polygon[{{1.944843, 0.027271, 0.009708},{1.946510, 0.026729, 0.012569},{
      1.945663, 0.021383, 0.012569},{1.943910, 0.021383, 0.009708}}],
    Polygon[{{1.946510, 0.026729, 0.012569},{1.948583, 0.026056, 0.015120},{
      1.947843, 0.021383, 0.015120},{1.945663, 0.021383, 0.012569}}],
    Polygon[{{1.948583, 0.026056, 0.015120},{1.951009, 0.025267, 0.017299},{
      1.950394, 0.021383, 0.017299},{1.947843, 0.021383, 0.015120}}],
    Polygon[{{1.951009, 0.025267, 0.017299},{1.953730, 0.024383, 0.019053},{
      1.953255, 0.021383, 0.019053},{1.950394, 0.021383, 0.017299}}],
    Polygon[{{1.953730, 0.024383, 0.019053},{1.956679, 0.023425, 0.020337},{
      1.956355, 0.021383, 0.020337},{1.953255, 0.021383, 0.019053}}],
    Polygon[{{1.956679, 0.023425, 0.020337},{1.959782, 0.022417, 0.021120},{
      1.959618, 0.021383, 0.021120},{1.956355, 0.021383, 0.020337}}],
    Polygon[{{1.959618, 0.021383, -0.021120},{1.956355, 0.021383, -0.020337},{
      1.956679, 0.019341, -0.020337},{1.959782, 0.020350, -0.021120}}],
    Polygon[{{1.956355, 0.021383, -0.020337},{1.953255, 0.021383, -0.019053},{
      1.953730, 0.018383, -0.019053},{1.956679, 0.019341, -0.020337}}],
    Polygon[{{1.953255, 0.021383, -0.019053},{1.950394, 0.021383, -0.017299},{
      1.951009, 0.017499, -0.017299},{1.953730, 0.018383, -0.019053}}],
    Polygon[{{1.950394, 0.021383, -0.017299},{1.947843, 0.021383, -0.015120},{
      1.948583, 0.016711, -0.015120},{1.951009, 0.017499, -0.017299}}],
    Polygon[{{1.947843, 0.021383, -0.015120},{1.945663, 0.021383, -0.012569},{
      1.946510, 0.016038, -0.012569},{1.948583, 0.016711, -0.015120}}],
    Polygon[{{1.945663, 0.021383, -0.012569},{1.943910, 0.021383, -0.009708},{
      1.944843, 0.015496, -0.009708},{1.946510, 0.016038, -0.012569}}],
    Polygon[{{1.943910, 0.021383, -0.009708},{1.942626, 0.021383, -0.006608},{
      1.943622, 0.015099, -0.006608},{1.944843, 0.015496, -0.009708}}],
    Polygon[{{1.942626, 0.021383, -0.006608},{1.941843, 0.021383, -0.003345},{
      1.942877, 0.014857, -0.003345},{1.943622, 0.015099, -0.006608}}],
    Polygon[{{1.941843, 0.021383, -0.003345},{1.941580, 0.021383, 0.000000},{
      1.942626, 0.014776, 0.000000},{1.942877, 0.014857, -0.003345}}],
    Polygon[{{1.941580, 0.021383, 0.000000},{1.941843, 0.021383, 0.003345},{
      1.942877, 0.014857, 0.003345},{1.942626, 0.014776, 0.000000}}],
    Polygon[{{1.941843, 0.021383, 0.003345},{1.942626, 0.021383, 0.006608},{
      1.943622, 0.015099, 0.006608},{1.942877, 0.014857, 0.003345}}],
    Polygon[{{1.942626, 0.021383, 0.006608},{1.943910, 0.021383, 0.009708},{
      1.944843, 0.015496, 0.009708},{1.943622, 0.015099, 0.006608}}],
    Polygon[{{1.943910, 0.021383, 0.009708},{1.945663, 0.021383, 0.012569},{
      1.946510, 0.016038, 0.012569},{1.944843, 0.015496, 0.009708}}],
    Polygon[{{1.945663, 0.021383, 0.012569},{1.947843, 0.021383, 0.015120},{
      1.948583, 0.016711, 0.015120},{1.946510, 0.016038, 0.012569}}],
    Polygon[{{1.947843, 0.021383, 0.015120},{1.950394, 0.021383, 0.017299},{
      1.951009, 0.017499, 0.017299},{1.948583, 0.016711, 0.015120}}],
    Polygon[{{1.950394, 0.021383, 0.017299},{1.953255, 0.021383, 0.019053},{
      1.953730, 0.018383, 0.019053},{1.951009, 0.017499, 0.017299}}],
    Polygon[{{1.953255, 0.021383, 0.019053},{1.956355, 0.021383, 0.020337},{
      1.956679, 0.019341, 0.020337},{1.953730, 0.018383, 0.019053}}],
    Polygon[{{1.956355, 0.021383, 0.020337},{1.959618, 0.021383, 0.021120},{
      1.959782, 0.020350, 0.021120},{1.956679, 0.019341, 0.020337}}],
    Polygon[{{1.959782, 0.020350, -0.021120},{1.956679, 0.019341, -0.020337},{
      1.957617, 0.017499, -0.020337},{1.960257, 0.019417, -0.021120}}],
    Polygon[{{1.956679, 0.019341, -0.020337},{1.953730, 0.018383, -0.019053},{
      1.955109, 0.015677, -0.019053},{1.957617, 0.017499, -0.020337}}],
    Polygon[{{1.953730, 0.018383, -0.019053},{1.951009, 0.017499, -0.017299},{
      1.952795, 0.013996, -0.017299},{1.955109, 0.015677, -0.019053}}],
    Polygon[{{1.951009, 0.017499, -0.017299},{1.948583, 0.016711, -0.015120},{
      1.950730, 0.012496, -0.015120},{1.952795, 0.013996, -0.017299}}],
    Polygon[{{1.948583, 0.016711, -0.015120},{1.946510, 0.016038, -0.012569},{
      1.948967, 0.011215, -0.012569},{1.950730, 0.012496, -0.015120}}],
    Polygon[{{1.946510, 0.016038, -0.012569},{1.944843, 0.015496, -0.009708},{
      1.947549, 0.010184, -0.009708},{1.948967, 0.011215, -0.012569}}],
    Polygon[{{1.944843, 0.015496, -0.009708},{1.943622, 0.015099, -0.006608},{
      1.946510, 0.009430, -0.006608},{1.947549, 0.010184, -0.009708}}],
    Polygon[{{1.943622, 0.015099, -0.006608},{1.942877, 0.014857, -0.003345},{
      1.945876, 0.008969, -0.003345},{1.946510, 0.009430, -0.006608}}],
    Polygon[{{1.942877, 0.014857, -0.003345},{1.942626, 0.014776, 0.000000},{
      1.945663, 0.008815, 0.000000},{1.945876, 0.008969, -0.003345}}],
    Polygon[{{1.942626, 0.014776, 0.000000},{1.942877, 0.014857, 0.003345},{
      1.945876, 0.008969, 0.003345},{1.945663, 0.008815, 0.000000}}],
    Polygon[{{1.942877, 0.014857, 0.003345},{1.943622, 0.015099, 0.006608},{
      1.946510, 0.009430, 0.006608},{1.945876, 0.008969, 0.003345}}],
    Polygon[{{1.943622, 0.015099, 0.006608},{1.944843, 0.015496, 0.009708},{
      1.947549, 0.010184, 0.009708},{1.946510, 0.009430, 0.006608}}],
    Polygon[{{1.944843, 0.015496, 0.009708},{1.946510, 0.016038, 0.012569},{
      1.948967, 0.011215, 0.012569},{1.947549, 0.010184, 0.009708}}],
    Polygon[{{1.946510, 0.016038, 0.012569},{1.948583, 0.016711, 0.015120},{
      1.950730, 0.012496, 0.015120},{1.948967, 0.011215, 0.012569}}],
    Polygon[{{1.948583, 0.016711, 0.015120},{1.951009, 0.017499, 0.017299},{
      1.952795, 0.013996, 0.017299},{1.950730, 0.012496, 0.015120}}],
    Polygon[{{1.951009, 0.017499, 0.017299},{1.953730, 0.018383, 0.019053},{
      1.955109, 0.015677, 0.019053},{1.952795, 0.013996, 0.017299}}],
    Polygon[{{1.953730, 0.018383, 0.019053},{1.956679, 0.019341, 0.020337},{
      1.957617, 0.017499, 0.020337},{1.955109, 0.015677, 0.019053}}],
    Polygon[{{1.956679, 0.019341, 0.020337},{1.959782, 0.020350, 0.021120},{
      1.960257, 0.019417, 0.021120},{1.957617, 0.017499, 0.020337}}],
    Polygon[{{1.960257, 0.019417, -0.021120},{1.957617, 0.017499, -0.020337},{
      1.959079, 0.016038, -0.020337},{1.960997, 0.018677, -0.021120}}],
    Polygon[{{1.957617, 0.017499, -0.020337},{1.955109, 0.015677, -0.019053},{
      1.957257, 0.013530, -0.019053},{1.959079, 0.016038, -0.020337}}],
    Polygon[{{1.955109, 0.015677, -0.019053},{1.952795, 0.013996, -0.017299},{
      1.955575, 0.011215, -0.017299},{1.957257, 0.013530, -0.019053}}],
    Polygon[{{1.952795, 0.013996, -0.017299},{1.950730, 0.012496, -0.015120},{
      1.954075, 0.009151, -0.015120},{1.955575, 0.011215, -0.017299}}],
    Polygon[{{1.950730, 0.012496, -0.015120},{1.948967, 0.011215, -0.012569},{
      1.952795, 0.007388, -0.012569},{1.954075, 0.009151, -0.015120}}],
    Polygon[{{1.948967, 0.011215, -0.012569},{1.947549, 0.010184, -0.009708},{
      1.951764, 0.005969, -0.009708},{1.952795, 0.007388, -0.012569}}],
    Polygon[{{1.947549, 0.010184, -0.009708},{1.946510, 0.009430, -0.006608},{
      1.951009, 0.004931, -0.006608},{1.951764, 0.005969, -0.009708}}],
    Polygon[{{1.946510, 0.009430, -0.006608},{1.945876, 0.008969, -0.003345},{
      1.950549, 0.004297, -0.003345},{1.951009, 0.004931, -0.006608}}],
    Polygon[{{1.945876, 0.008969, -0.003345},{1.945663, 0.008815, 0.000000},{
      1.950394, 0.004084, 0.000000},{1.950549, 0.004297, -0.003345}}],
    Polygon[{{1.945663, 0.008815, 0.000000},{1.945876, 0.008969, 0.003345},{
      1.950549, 0.004297, 0.003345},{1.950394, 0.004084, 0.000000}}],
    Polygon[{{1.945876, 0.008969, 0.003345},{1.946510, 0.009430, 0.006608},{
      1.951009, 0.004931, 0.006608},{1.950549, 0.004297, 0.003345}}],
    Polygon[{{1.946510, 0.009430, 0.006608},{1.947549, 0.010184, 0.009708},{
      1.951764, 0.005969, 0.009708},{1.951009, 0.004931, 0.006608}}],
    Polygon[{{1.947549, 0.010184, 0.009708},{1.948967, 0.011215, 0.012569},{
      1.952795, 0.007388, 0.012569},{1.951764, 0.005969, 0.009708}}],
    Polygon[{{1.948967, 0.011215, 0.012569},{1.950730, 0.012496, 0.015120},{
      1.954075, 0.009151, 0.015120},{1.952795, 0.007388, 0.012569}}],
    Polygon[{{1.950730, 0.012496, 0.015120},{1.952795, 0.013996, 0.017299},{
      1.955575, 0.011215, 0.017299},{1.954075, 0.009151, 0.015120}}],
    Polygon[{{1.952795, 0.013996, 0.017299},{1.955109, 0.015677, 0.019053},{
      1.957257, 0.013530, 0.019053},{1.955575, 0.011215, 0.017299}}],
    Polygon[{{1.955109, 0.015677, 0.019053},{1.957617, 0.017499, 0.020337},{
      1.959079, 0.016038, 0.020337},{1.957257, 0.013530, 0.019053}}],
    Polygon[{{1.957617, 0.017499, 0.020337},{1.960257, 0.019417, 0.021120},{
      1.960997, 0.018677, 0.021120},{1.959079, 0.016038, 0.020337}}],
    Polygon[{{1.960997, 0.018677, -0.021120},{1.959079, 0.016038, -0.020337},{
      1.960921, 0.015099, -0.020337},{1.961929, 0.018202, -0.021120}}],
    Polygon[{{1.959079, 0.016038, -0.020337},{1.957257, 0.013530, -0.019053},{
      1.959963, 0.012151, -0.019053},{1.960921, 0.015099, -0.020337}}],
    Polygon[{{1.957257, 0.013530, -0.019053},{1.955575, 0.011215, -0.017299},{
      1.959079, 0.009430, -0.017299},{1.959963, 0.012151, -0.019053}}],
    Polygon[{{1.955575, 0.011215, -0.017299},{1.954075, 0.009151, -0.015120},{
      1.958291, 0.007003, -0.015120},{1.959079, 0.009430, -0.017299}}],
    Polygon[{{1.954075, 0.009151, -0.015120},{1.952795, 0.007388, -0.012569},{
      1.957617, 0.004931, -0.012569},{1.958291, 0.007003, -0.015120}}],
    Polygon[{{1.952795, 0.007388, -0.012569},{1.951764, 0.005969, -0.009708},{
      1.957075, 0.003263, -0.009708},{1.957617, 0.004931, -0.012569}}],
    Polygon[{{1.951764, 0.005969, -0.009708},{1.951009, 0.004931, -0.006608},{
      1.956679, 0.002042, -0.006608},{1.957075, 0.003263, -0.009708}}],
    Polygon[{{1.951009, 0.004931, -0.006608},{1.950549, 0.004297, -0.003345},{
      1.956437, 0.001297, -0.003345},{1.956679, 0.002042, -0.006608}}],
    Polygon[{{1.950549, 0.004297, -0.003345},{1.950394, 0.004084, 0.000000},{
      1.956355, 0.001047, 0.000000},{1.956437, 0.001297, -0.003345}}],
    Polygon[{{1.950394, 0.004084, 0.000000},{1.950549, 0.004297, 0.003345},{
      1.956437, 0.001297, 0.003345},{1.956355, 0.001047, 0.000000}}],
    Polygon[{{1.950549, 0.004297, 0.003345},{1.951009, 0.004931, 0.006608},{
      1.956679, 0.002042, 0.006608},{1.956437, 0.001297, 0.003345}}],
    Polygon[{{1.951009, 0.004931, 0.006608},{1.951764, 0.005969, 0.009708},{
      1.957075, 0.003263, 0.009708},{1.956679, 0.002042, 0.006608}}],
    Polygon[{{1.951764, 0.005969, 0.009708},{1.952795, 0.007388, 0.012569},{
      1.957617, 0.004931, 0.012569},{1.957075, 0.003263, 0.009708}}],
    Polygon[{{1.952795, 0.007388, 0.012569},{1.954075, 0.009151, 0.015120},{
      1.958291, 0.007003, 0.015120},{1.957617, 0.004931, 0.012569}}],
    Polygon[{{1.954075, 0.009151, 0.015120},{1.955575, 0.011215, 0.017299},{
      1.959079, 0.009430, 0.017299},{1.958291, 0.007003, 0.015120}}],
    Polygon[{{1.955575, 0.011215, 0.017299},{1.957257, 0.013530, 0.019053},{
      1.959963, 0.012151, 0.019053},{1.959079, 0.009430, 0.017299}}],
    Polygon[{{1.957257, 0.013530, 0.019053},{1.959079, 0.016038, 0.020337},{
      1.960921, 0.015099, 0.020337},{1.959963, 0.012151, 0.019053}}],
    Polygon[{{1.959079, 0.016038, 0.020337},{1.960997, 0.018677, 0.021120},{
      1.961929, 0.018202, 0.021120},{1.960921, 0.015099, 0.020337}}],
    Polygon[{{1.961929, 0.018202, -0.021120},{1.960921, 0.015099, -0.020337},{
      1.962963, 0.014776, -0.020337},{1.962963, 0.018038, -0.021120}}],
    Polygon[{{1.960921, 0.015099, -0.020337},{1.959963, 0.012151, -0.019053},{
      1.962963, 0.011676, -0.019053},{1.962963, 0.014776, -0.020337}}],
    Polygon[{{1.959963, 0.012151, -0.019053},{1.959079, 0.009430, -0.017299},{
      1.962963, 0.008815, -0.017299},{1.962963, 0.011676, -0.019053}}],
    Polygon[{{1.959079, 0.009430, -0.017299},{1.958291, 0.007003, -0.015120},{
      1.962963, 0.006263, -0.015120},{1.962963, 0.008815, -0.017299}}],
    Polygon[{{1.958291, 0.007003, -0.015120},{1.957617, 0.004931, -0.012569},{
      1.962963, 0.004084, -0.012569},{1.962963, 0.006263, -0.015120}}],
    Polygon[{{1.957617, 0.004931, -0.012569},{1.957075, 0.003263, -0.009708},{
      1.962963, 0.002331, -0.009708},{1.962963, 0.004084, -0.012569}}],
    Polygon[{{1.957075, 0.003263, -0.009708},{1.956679, 0.002042, -0.006608},{
      1.962963, 0.001047, -0.006608},{1.962963, 0.002331, -0.009708}}],
    Polygon[{{1.956679, 0.002042, -0.006608},{1.956437, 0.001297, -0.003345},{
      1.962963, 0.000263, -0.003345},{1.962963, 0.001047, -0.006608}}],
    Polygon[{{1.956437, 0.001297, -0.003345},{1.956355, 0.001047, 0.000000},{
      1.962963, 0.000000, 0.000000},{1.962963, 0.000263, -0.003345}}],
    Polygon[{{1.956355, 0.001047, 0.000000},{1.956437, 0.001297, 0.003345},{
      1.962963, 0.000263, 0.003345},{1.962963, 0.000000, 0.000000}}],
    Polygon[{{1.956437, 0.001297, 0.003345},{1.956679, 0.002042, 0.006608},{
      1.962963, 0.001047, 0.006608},{1.962963, 0.000263, 0.003345}}],
    Polygon[{{1.956679, 0.002042, 0.006608},{1.957075, 0.003263, 0.009708},{
      1.962963, 0.002331, 0.009708},{1.962963, 0.001047, 0.006608}}],
    Polygon[{{1.957075, 0.003263, 0.009708},{1.957617, 0.004931, 0.012569},{
      1.962963, 0.004084, 0.012569},{1.962963, 0.002331, 0.009708}}],
    Polygon[{{1.957617, 0.004931, 0.012569},{1.958291, 0.007003, 0.015120},{
      1.962963, 0.006263, 0.015120},{1.962963, 0.004084, 0.012569}}],
    Polygon[{{1.958291, 0.007003, 0.015120},{1.959079, 0.009430, 0.017299},{
      1.962963, 0.008815, 0.017299},{1.962963, 0.006263, 0.015120}}],
    Polygon[{{1.959079, 0.009430, 0.017299},{1.959963, 0.012151, 0.019053},{
      1.962963, 0.011676, 0.019053},{1.962963, 0.008815, 0.017299}}],
    Polygon[{{1.959963, 0.012151, 0.019053},{1.960921, 0.015099, 0.020337},{
      1.962963, 0.014776, 0.020337},{1.962963, 0.011676, 0.019053}}],
    Polygon[{{1.960921, 0.015099, 0.020337},{1.961929, 0.018202, 0.021120},{
      1.962963, 0.018038, 0.021120},{1.962963, 0.014776, 0.020337}}],
    Polygon[{{1.962963, 0.018038, -0.021120},{1.962963, 0.014776, -0.020337},{
      1.965005, 0.015099, -0.020337},{1.963997, 0.018202, -0.021120}}],
    Polygon[{{1.962963, 0.014776, -0.020337},{1.962963, 0.011676, -0.019053},{
      1.965963, 0.012151, -0.019053},{1.965005, 0.015099, -0.020337}}],
    Polygon[{{1.962963, 0.011676, -0.019053},{1.962963, 0.008815, -0.017299},{
      1.966847, 0.009430, -0.017299},{1.965963, 0.012151, -0.019053}}],
    Polygon[{{1.962963, 0.008815, -0.017299},{1.962963, 0.006263, -0.015120},{
      1.967635, 0.007003, -0.015120},{1.966847, 0.009430, -0.017299}}],
    Polygon[{{1.962963, 0.006263, -0.015120},{1.962963, 0.004084, -0.012569},{
      1.968309, 0.004931, -0.012569},{1.967635, 0.007003, -0.015120}}],
    Polygon[{{1.962963, 0.004084, -0.012569},{1.962963, 0.002331, -0.009708},{
      1.968851, 0.003263, -0.009708},{1.968309, 0.004931, -0.012569}}],
    Polygon[{{1.962963, 0.002331, -0.009708},{1.962963, 0.001047, -0.006608},{
      1.969247, 0.002042, -0.006608},{1.968851, 0.003263, -0.009708}}],
    Polygon[{{1.962963, 0.001047, -0.006608},{1.962963, 0.000263, -0.003345},{
      1.969489, 0.001297, -0.003345},{1.969247, 0.002042, -0.006608}}],
    Polygon[{{1.962963, 0.000263, -0.003345},{1.962963, 0.000000, 0.000000},{
      1.969571, 0.001047, 0.000000},{1.969489, 0.001297, -0.003345}}],
    Polygon[{{1.962963, 0.000000, 0.000000},{1.962963, 0.000263, 0.003345},{
      1.969489, 0.001297, 0.003345},{1.969571, 0.001047, 0.000000}}],
    Polygon[{{1.962963, 0.000263, 0.003345},{1.962963, 0.001047, 0.006608},{
      1.969247, 0.002042, 0.006608},{1.969489, 0.001297, 0.003345}}],
    Polygon[{{1.962963, 0.001047, 0.006608},{1.962963, 0.002331, 0.009708},{
      1.968851, 0.003263, 0.009708},{1.969247, 0.002042, 0.006608}}],
    Polygon[{{1.962963, 0.002331, 0.009708},{1.962963, 0.004084, 0.012569},{
      1.968309, 0.004931, 0.012569},{1.968851, 0.003263, 0.009708}}],
    Polygon[{{1.962963, 0.004084, 0.012569},{1.962963, 0.006263, 0.015120},{
      1.967635, 0.007003, 0.015120},{1.968309, 0.004931, 0.012569}}],
    Polygon[{{1.962963, 0.006263, 0.015120},{1.962963, 0.008815, 0.017299},{
      1.966847, 0.009430, 0.017299},{1.967635, 0.007003, 0.015120}}],
    Polygon[{{1.962963, 0.008815, 0.017299},{1.962963, 0.011676, 0.019053},{
      1.965963, 0.012151, 0.019053},{1.966847, 0.009430, 0.017299}}],
    Polygon[{{1.962963, 0.011676, 0.019053},{1.962963, 0.014776, 0.020337},{
      1.965005, 0.015099, 0.020337},{1.965963, 0.012151, 0.019053}}],
    Polygon[{{1.962963, 0.014776, 0.020337},{1.962963, 0.018038, 0.021120},{
      1.963997, 0.018202, 0.021120},{1.965005, 0.015099, 0.020337}}],
    Polygon[{{1.963997, 0.018202, -0.021120},{1.965005, 0.015099, -0.020337},{
      1.966847, 0.016038, -0.020337},{1.964929, 0.018677, -0.021120}}],
    Polygon[{{1.965005, 0.015099, -0.020337},{1.965963, 0.012151, -0.019053},{
      1.968669, 0.013530, -0.019053},{1.966847, 0.016038, -0.020337}}],
    Polygon[{{1.965963, 0.012151, -0.019053},{1.966847, 0.009430, -0.017299},{
      1.970351, 0.011215, -0.017299},{1.968669, 0.013530, -0.019053}}],
    Polygon[{{1.966847, 0.009430, -0.017299},{1.967635, 0.007003, -0.015120},{
      1.971851, 0.009151, -0.015120},{1.970351, 0.011215, -0.017299}}],
    Polygon[{{1.967635, 0.007003, -0.015120},{1.968309, 0.004931, -0.012569},{
      1.973131, 0.007388, -0.012569},{1.971851, 0.009151, -0.015120}}],
    Polygon[{{1.968309, 0.004931, -0.012569},{1.968851, 0.003263, -0.009708},{
      1.974162, 0.005969, -0.009708},{1.973131, 0.007388, -0.012569}}],
    Polygon[{{1.968851, 0.003263, -0.009708},{1.969247, 0.002042, -0.006608},{
      1.974917, 0.004931, -0.006608},{1.974162, 0.005969, -0.009708}}],
    Polygon[{{1.969247, 0.002042, -0.006608},{1.969489, 0.001297, -0.003345},{
      1.975377, 0.004297, -0.003345},{1.974917, 0.004931, -0.006608}}],
    Polygon[{{1.969489, 0.001297, -0.003345},{1.969571, 0.001047, 0.000000},{
      1.975532, 0.004084, 0.000000},{1.975377, 0.004297, -0.003345}}],
    Polygon[{{1.969571, 0.001047, 0.000000},{1.969489, 0.001297, 0.003345},{
      1.975377, 0.004297, 0.003345},{1.975532, 0.004084, 0.000000}}],
    Polygon[{{1.969489, 0.001297, 0.003345},{1.969247, 0.002042, 0.006608},{
      1.974917, 0.004931, 0.006608},{1.975377, 0.004297, 0.003345}}],
    Polygon[{{1.969247, 0.002042, 0.006608},{1.968851, 0.003263, 0.009708},{
      1.974162, 0.005969, 0.009708},{1.974917, 0.004931, 0.006608}}],
    Polygon[{{1.968851, 0.003263, 0.009708},{1.968309, 0.004931, 0.012569},{
      1.973131, 0.007388, 0.012569},{1.974162, 0.005969, 0.009708}}],
    Polygon[{{1.968309, 0.004931, 0.012569},{1.967635, 0.007003, 0.015120},{
      1.971851, 0.009151, 0.015120},{1.973131, 0.007388, 0.012569}}],
    Polygon[{{1.967635, 0.007003, 0.015120},{1.966847, 0.009430, 0.017299},{
      1.970351, 0.011215, 0.017299},{1.971851, 0.009151, 0.015120}}],
    Polygon[{{1.966847, 0.009430, 0.017299},{1.965963, 0.012151, 0.019053},{
      1.968669, 0.013530, 0.019053},{1.970351, 0.011215, 0.017299}}],
    Polygon[{{1.965963, 0.012151, 0.019053},{1.965005, 0.015099, 0.020337},{
      1.966847, 0.016038, 0.020337},{1.968669, 0.013530, 0.019053}}],
    Polygon[{{1.965005, 0.015099, 0.020337},{1.963997, 0.018202, 0.021120},{
      1.964929, 0.018677, 0.021120},{1.966847, 0.016038, 0.020337}}],
    Polygon[{{1.964929, 0.018677, -0.021120},{1.966847, 0.016038, -0.020337},{
      1.968309, 0.017499, -0.020337},{1.965669, 0.019417, -0.021120}}],
    Polygon[{{1.966847, 0.016038, -0.020337},{1.968669, 0.013530, -0.019053},{
      1.970817, 0.015677, -0.019053},{1.968309, 0.017499, -0.020337}}],
    Polygon[{{1.968669, 0.013530, -0.019053},{1.970351, 0.011215, -0.017299},{
      1.973131, 0.013996, -0.017299},{1.970817, 0.015677, -0.019053}}],
    Polygon[{{1.970351, 0.011215, -0.017299},{1.971851, 0.009151, -0.015120},{
      1.975196, 0.012496, -0.015120},{1.973131, 0.013996, -0.017299}}],
    Polygon[{{1.971851, 0.009151, -0.015120},{1.973131, 0.007388, -0.012569},{
      1.976959, 0.011215, -0.012569},{1.975196, 0.012496, -0.015120}}],
    Polygon[{{1.973131, 0.007388, -0.012569},{1.974162, 0.005969, -0.009708},{
      1.978377, 0.010184, -0.009708},{1.976959, 0.011215, -0.012569}}],
    Polygon[{{1.974162, 0.005969, -0.009708},{1.974917, 0.004931, -0.006608},{
      1.979416, 0.009430, -0.006608},{1.978377, 0.010184, -0.009708}}],
    Polygon[{{1.974917, 0.004931, -0.006608},{1.975377, 0.004297, -0.003345},{
      1.980049, 0.008969, -0.003345},{1.979416, 0.009430, -0.006608}}],
    Polygon[{{1.975377, 0.004297, -0.003345},{1.975532, 0.004084, 0.000000},{
      1.980262, 0.008815, 0.000000},{1.980049, 0.008969, -0.003345}}],
    Polygon[{{1.975532, 0.004084, 0.000000},{1.975377, 0.004297, 0.003345},{
      1.980049, 0.008969, 0.003345},{1.980262, 0.008815, 0.000000}}],
    Polygon[{{1.975377, 0.004297, 0.003345},{1.974917, 0.004931, 0.006608},{
      1.979416, 0.009430, 0.006608},{1.980049, 0.008969, 0.003345}}],
    Polygon[{{1.974917, 0.004931, 0.006608},{1.974162, 0.005969, 0.009708},{
      1.978377, 0.010184, 0.009708},{1.979416, 0.009430, 0.006608}}],
    Polygon[{{1.974162, 0.005969, 0.009708},{1.973131, 0.007388, 0.012569},{
      1.976959, 0.011215, 0.012569},{1.978377, 0.010184, 0.009708}}],
    Polygon[{{1.973131, 0.007388, 0.012569},{1.971851, 0.009151, 0.015120},{
      1.975196, 0.012496, 0.015120},{1.976959, 0.011215, 0.012569}}],
    Polygon[{{1.971851, 0.009151, 0.015120},{1.970351, 0.011215, 0.017299},{
      1.973131, 0.013996, 0.017299},{1.975196, 0.012496, 0.015120}}],
    Polygon[{{1.970351, 0.011215, 0.017299},{1.968669, 0.013530, 0.019053},{
      1.970817, 0.015677, 0.019053},{1.973131, 0.013996, 0.017299}}],
    Polygon[{{1.968669, 0.013530, 0.019053},{1.966847, 0.016038, 0.020337},{
      1.968309, 0.017499, 0.020337},{1.970817, 0.015677, 0.019053}}],
    Polygon[{{1.966847, 0.016038, 0.020337},{1.964929, 0.018677, 0.021120},{
      1.965669, 0.019417, 0.021120},{1.968309, 0.017499, 0.020337}}],
    Polygon[{{1.965669, 0.019417, -0.021120},{1.968309, 0.017499, -0.020337},{
      1.969247, 0.019341, -0.020337},{1.966144, 0.020350, -0.021120}}],
    Polygon[{{1.968309, 0.017499, -0.020337},{1.970817, 0.015677, -0.019053},{
      1.972196, 0.018383, -0.019053},{1.969247, 0.019341, -0.020337}}],
    Polygon[{{1.970817, 0.015677, -0.019053},{1.973131, 0.013996, -0.017299},{
      1.974917, 0.017499, -0.017299},{1.972196, 0.018383, -0.019053}}],
    Polygon[{{1.973131, 0.013996, -0.017299},{1.975196, 0.012496, -0.015120},{
      1.977343, 0.016711, -0.015120},{1.974917, 0.017499, -0.017299}}],
    Polygon[{{1.975196, 0.012496, -0.015120},{1.976959, 0.011215, -0.012569},{
      1.979416, 0.016038, -0.012569},{1.977343, 0.016711, -0.015120}}],
    Polygon[{{1.976959, 0.011215, -0.012569},{1.978377, 0.010184, -0.009708},{
      1.981083, 0.015496, -0.009708},{1.979416, 0.016038, -0.012569}}],
    Polygon[{{1.978377, 0.010184, -0.009708},{1.979416, 0.009430, -0.006608},{
      1.982304, 0.015099, -0.006608},{1.981083, 0.015496, -0.009708}}],
    Polygon[{{1.979416, 0.009430, -0.006608},{1.980049, 0.008969, -0.003345},{
      1.983049, 0.014857, -0.003345},{1.982304, 0.015099, -0.006608}}],
    Polygon[{{1.980049, 0.008969, -0.003345},{1.980262, 0.008815, 0.000000},{
      1.983300, 0.014776, 0.000000},{1.983049, 0.014857, -0.003345}}],
    Polygon[{{1.980262, 0.008815, 0.000000},{1.980049, 0.008969, 0.003345},{
      1.983049, 0.014857, 0.003345},{1.983300, 0.014776, 0.000000}}],
    Polygon[{{1.980049, 0.008969, 0.003345},{1.979416, 0.009430, 0.006608},{
      1.982304, 0.015099, 0.006608},{1.983049, 0.014857, 0.003345}}],
    Polygon[{{1.979416, 0.009430, 0.006608},{1.978377, 0.010184, 0.009708},{
      1.981083, 0.015496, 0.009708},{1.982304, 0.015099, 0.006608}}],
    Polygon[{{1.978377, 0.010184, 0.009708},{1.976959, 0.011215, 0.012569},{
      1.979416, 0.016038, 0.012569},{1.981083, 0.015496, 0.009708}}],
    Polygon[{{1.976959, 0.011215, 0.012569},{1.975196, 0.012496, 0.015120},{
      1.977343, 0.016711, 0.015120},{1.979416, 0.016038, 0.012569}}],
    Polygon[{{1.975196, 0.012496, 0.015120},{1.973131, 0.013996, 0.017299},{
      1.974917, 0.017499, 0.017299},{1.977343, 0.016711, 0.015120}}],
    Polygon[{{1.973131, 0.013996, 0.017299},{1.970817, 0.015677, 0.019053},{
      1.972196, 0.018383, 0.019053},{1.974917, 0.017499, 0.017299}}],
    Polygon[{{1.970817, 0.015677, 0.019053},{1.968309, 0.017499, 0.020337},{
      1.969247, 0.019341, 0.020337},{1.972196, 0.018383, 0.019053}}],
    Polygon[{{1.968309, 0.017499, 0.020337},{1.965669, 0.019417, 0.021120},{
      1.966144, 0.020350, 0.021120},{1.969247, 0.019341, 0.020337}}],
    Polygon[{{1.966144, 0.020350, -0.021120},{1.969247, 0.019341, -0.020337},{
      1.969571, 0.021383, -0.020337},{1.966308, 0.021383, -0.021120}}],
    Polygon[{{1.969247, 0.019341, -0.020337},{1.972196, 0.018383, -0.019053},{
      1.972671, 0.021383, -0.019053},{1.969571, 0.021383, -0.020337}}],
    Polygon[{{1.972196, 0.018383, -0.019053},{1.974917, 0.017499, -0.017299},{
      1.975532, 0.021383, -0.017299},{1.972671, 0.021383, -0.019053}}],
    Polygon[{{1.974917, 0.017499, -0.017299},{1.977343, 0.016711, -0.015120},{
      1.978083, 0.021383, -0.015120},{1.975532, 0.021383, -0.017299}}],
    Polygon[{{1.977343, 0.016711, -0.015120},{1.979416, 0.016038, -0.012569},{
      1.980262, 0.021383, -0.012569},{1.978083, 0.021383, -0.015120}}],
    Polygon[{{1.979416, 0.016038, -0.012569},{1.981083, 0.015496, -0.009708},{
      1.982016, 0.021383, -0.009708},{1.980262, 0.021383, -0.012569}}],
    Polygon[{{1.981083, 0.015496, -0.009708},{1.982304, 0.015099, -0.006608},{
      1.983300, 0.021383, -0.006608},{1.982016, 0.021383, -0.009708}}],
    Polygon[{{1.982304, 0.015099, -0.006608},{1.983049, 0.014857, -0.003345},{
      1.984083, 0.021383, -0.003345},{1.983300, 0.021383, -0.006608}}],
    Polygon[{{1.983049, 0.014857, -0.003345},{1.983300, 0.014776, 0.000000},{
      1.984346, 0.021383, 0.000000},{1.984083, 0.021383, -0.003345}}],
    Polygon[{{1.983300, 0.014776, 0.000000},{1.983049, 0.014857, 0.003345},{
      1.984083, 0.021383, 0.003345},{1.984346, 0.021383, 0.000000}}],
    Polygon[{{1.983049, 0.014857, 0.003345},{1.982304, 0.015099, 0.006608},{
      1.983300, 0.021383, 0.006608},{1.984083, 0.021383, 0.003345}}],
    Polygon[{{1.982304, 0.015099, 0.006608},{1.981083, 0.015496, 0.009708},{
      1.982016, 0.021383, 0.009708},{1.983300, 0.021383, 0.006608}}],
    Polygon[{{1.981083, 0.015496, 0.009708},{1.979416, 0.016038, 0.012569},{
      1.980262, 0.021383, 0.012569},{1.982016, 0.021383, 0.009708}}],
    Polygon[{{1.979416, 0.016038, 0.012569},{1.977343, 0.016711, 0.015120},{
      1.978083, 0.021383, 0.015120},{1.980262, 0.021383, 0.012569}}],
    Polygon[{{1.977343, 0.016711, 0.015120},{1.974917, 0.017499, 0.017299},{
      1.975532, 0.021383, 0.017299},{1.978083, 0.021383, 0.015120}}],
    Polygon[{{1.974917, 0.017499, 0.017299},{1.972196, 0.018383, 0.019053},{
      1.972671, 0.021383, 0.019053},{1.975532, 0.021383, 0.017299}}],
    Polygon[{{1.972196, 0.018383, 0.019053},{1.969247, 0.019341, 0.020337},{
      1.969571, 0.021383, 0.020337},{1.972671, 0.021383, 0.019053}}],
    Polygon[{{1.969247, 0.019341, 0.020337},{1.966144, 0.020350, 0.021120},{
      1.966308, 0.021383, 0.021120},{1.969571, 0.021383, 0.020337}}],
    Polygon[{{1.988769, 0.007128, -0.007040},{1.989857, 0.007128, -0.006779},{
      1.989749, 0.007808, -0.006779},{1.988715, 0.007472, -0.007040}}],
    Polygon[{{1.989857, 0.007128, -0.006779},{1.990890, 0.007128, -0.006351},{
      1.990732, 0.008128, -0.006351},{1.989749, 0.007808, -0.006779}}],
    Polygon[{{1.990890, 0.007128, -0.006351},{1.991844, 0.007128, -0.005766},{
      1.991639, 0.008422, -0.005766},{1.990732, 0.008128, -0.006351}}],
    Polygon[{{1.991844, 0.007128, -0.005766},{1.992694, 0.007128, -0.005040},{
      1.992448, 0.008685, -0.005040},{1.991639, 0.008422, -0.005766}}],
    Polygon[{{1.992694, 0.007128, -0.005040},{1.993421, 0.007128, -0.004190},{
      1.993139, 0.008910, -0.004190},{1.992448, 0.008685, -0.005040}}],
    Polygon[{{1.993421, 0.007128, -0.004190},{1.994005, 0.007128, -0.003236},{
      1.993694, 0.009090, -0.003236},{1.993139, 0.008910, -0.004190}}],
    Polygon[{{1.994005, 0.007128, -0.003236},{1.994433, 0.007128, -0.002203},{
      1.994101, 0.009223, -0.002203},{1.993694, 0.009090, -0.003236}}],
    Polygon[{{1.994433, 0.007128, -0.002203},{1.994694, 0.007128, -0.001115},{
      1.994350, 0.009303, -0.001115},{1.994101, 0.009223, -0.002203}}],
    Polygon[{{1.994694, 0.007128, -0.001115},{1.994782, 0.007128, 0.000000},{
      1.994433, 0.009330, 0.000000},{1.994350, 0.009303, -0.001115}}],
    Polygon[{{1.994782, 0.007128, 0.000000},{1.994694, 0.007128, 0.001115},{
      1.994350, 0.009303, 0.001115},{1.994433, 0.009330, 0.000000}}],
    Polygon[{{1.994694, 0.007128, 0.001115},{1.994433, 0.007128, 0.002203},{
      1.994101, 0.009223, 0.002203},{1.994350, 0.009303, 0.001115}}],
    Polygon[{{1.994433, 0.007128, 0.002203},{1.994005, 0.007128, 0.003236},{
      1.993694, 0.009090, 0.003236},{1.994101, 0.009223, 0.002203}}],
    Polygon[{{1.994005, 0.007128, 0.003236},{1.993421, 0.007128, 0.004190},{
      1.993139, 0.008910, 0.004190},{1.993694, 0.009090, 0.003236}}],
    Polygon[{{1.993421, 0.007128, 0.004190},{1.992694, 0.007128, 0.005040},{
      1.992448, 0.008685, 0.005040},{1.993139, 0.008910, 0.004190}}],
    Polygon[{{1.992694, 0.007128, 0.005040},{1.991844, 0.007128, 0.005766},{
      1.991639, 0.008422, 0.005766},{1.992448, 0.008685, 0.005040}}],
    Polygon[{{1.991844, 0.007128, 0.005766},{1.990890, 0.007128, 0.006351},{
      1.990732, 0.008128, 0.006351},{1.991639, 0.008422, 0.005766}}],
    Polygon[{{1.990890, 0.007128, 0.006351},{1.989857, 0.007128, 0.006779},{
      1.989749, 0.007808, 0.006779},{1.990732, 0.008128, 0.006351}}],
    Polygon[{{1.989857, 0.007128, 0.006779},{1.988769, 0.007128, 0.007040},{
      1.988715, 0.007472, 0.007040},{1.989749, 0.007808, 0.006779}}],
    Polygon[{{1.988715, 0.007472, -0.007040},{1.989749, 0.007808, -0.006779},{
      1.989436, 0.008422, -0.006779},{1.988556, 0.007783, -0.007040}}],
    Polygon[{{1.989749, 0.007808, -0.006779},{1.990732, 0.008128, -0.006351},{
      1.990272, 0.009030, -0.006351},{1.989436, 0.008422, -0.006779}}],
    Polygon[{{1.990732, 0.008128, -0.006351},{1.991639, 0.008422, -0.005766},{
      1.991044, 0.009590, -0.005766},{1.990272, 0.009030, -0.006351}}],
    Polygon[{{1.991639, 0.008422, -0.005766},{1.992448, 0.008685, -0.005040},{
      1.991732, 0.010090, -0.005040},{1.991044, 0.009590, -0.005766}}],
    Polygon[{{1.992448, 0.008685, -0.005040},{1.993139, 0.008910, -0.004190},{
      1.992319, 0.010517, -0.004190},{1.991732, 0.010090, -0.005040}}],
    Polygon[{{1.993139, 0.008910, -0.004190},{1.993694, 0.009090, -0.003236},{
      1.992792, 0.010861, -0.003236},{1.992319, 0.010517, -0.004190}}],
    Polygon[{{1.993694, 0.009090, -0.003236},{1.994101, 0.009223, -0.002203},{
      1.993139, 0.011112, -0.002203},{1.992792, 0.010861, -0.003236}}],
    Polygon[{{1.994101, 0.009223, -0.002203},{1.994350, 0.009303, -0.001115},{
      1.993350, 0.011266, -0.001115},{1.993139, 0.011112, -0.002203}}],
    Polygon[{{1.994350, 0.009303, -0.001115},{1.994433, 0.009330, 0.000000},{
      1.993421, 0.011317, 0.000000},{1.993350, 0.011266, -0.001115}}],
    Polygon[{{1.994433, 0.009330, 0.000000},{1.994350, 0.009303, 0.001115},{
      1.993350, 0.011266, 0.001115},{1.993421, 0.011317, 0.000000}}],
    Polygon[{{1.994350, 0.009303, 0.001115},{1.994101, 0.009223, 0.002203},{
      1.993139, 0.011112, 0.002203},{1.993350, 0.011266, 0.001115}}],
    Polygon[{{1.994101, 0.009223, 0.002203},{1.993694, 0.009090, 0.003236},{
      1.992792, 0.010861, 0.003236},{1.993139, 0.011112, 0.002203}}],
    Polygon[{{1.993694, 0.009090, 0.003236},{1.993139, 0.008910, 0.004190},{
      1.992319, 0.010517, 0.004190},{1.992792, 0.010861, 0.003236}}],
    Polygon[{{1.993139, 0.008910, 0.004190},{1.992448, 0.008685, 0.005040},{
      1.991732, 0.010090, 0.005040},{1.992319, 0.010517, 0.004190}}],
    Polygon[{{1.992448, 0.008685, 0.005040},{1.991639, 0.008422, 0.005766},{
      1.991044, 0.009590, 0.005766},{1.991732, 0.010090, 0.005040}}],
    Polygon[{{1.991639, 0.008422, 0.005766},{1.990732, 0.008128, 0.006351},{
      1.990272, 0.009030, 0.006351},{1.991044, 0.009590, 0.005766}}],
    Polygon[{{1.990732, 0.008128, 0.006351},{1.989749, 0.007808, 0.006779},{
      1.989436, 0.008422, 0.006779},{1.990272, 0.009030, 0.006351}}],
    Polygon[{{1.989749, 0.007808, 0.006779},{1.988715, 0.007472, 0.007040},{
      1.988556, 0.007783, 0.007040},{1.989436, 0.008422, 0.006779}}],
    Polygon[{{1.988556, 0.007783, -0.007040},{1.989436, 0.008422, -0.006779},{
      1.988949, 0.008910, -0.006779},{1.988310, 0.008030, -0.007040}}],
    Polygon[{{1.989436, 0.008422, -0.006779},{1.990272, 0.009030, -0.006351},{
      1.989556, 0.009746, -0.006351},{1.988949, 0.008910, -0.006779}}],
    Polygon[{{1.990272, 0.009030, -0.006351},{1.991044, 0.009590, -0.005766},{
      1.990117, 0.010517, -0.005766},{1.989556, 0.009746, -0.006351}}],
    Polygon[{{1.991044, 0.009590, -0.005766},{1.991732, 0.010090, -0.005040},{
      1.990617, 0.011205, -0.005040},{1.990117, 0.010517, -0.005766}}],
    Polygon[{{1.991732, 0.010090, -0.005040},{1.992319, 0.010517, -0.004190},{
      1.991044, 0.011793, -0.004190},{1.990617, 0.011205, -0.005040}}],
    Polygon[{{1.992319, 0.010517, -0.004190},{1.992792, 0.010861, -0.003236},{
      1.991387, 0.012266, -0.003236},{1.991044, 0.011793, -0.004190}}],
    Polygon[{{1.992792, 0.010861, -0.003236},{1.993139, 0.011112, -0.002203},{
      1.991639, 0.012612, -0.002203},{1.991387, 0.012266, -0.003236}}],
    Polygon[{{1.993139, 0.011112, -0.002203},{1.993350, 0.011266, -0.001115},{
      1.991792, 0.012823, -0.001115},{1.991639, 0.012612, -0.002203}}],
    Polygon[{{1.993350, 0.011266, -0.001115},{1.993421, 0.011317, 0.000000},{
      1.991844, 0.012894, 0.000000},{1.991792, 0.012823, -0.001115}}],
    Polygon[{{1.993421, 0.011317, 0.000000},{1.993350, 0.011266, 0.001115},{
      1.991792, 0.012823, 0.001115},{1.991844, 0.012894, 0.000000}}],
    Polygon[{{1.993350, 0.011266, 0.001115},{1.993139, 0.011112, 0.002203},{
      1.991639, 0.012612, 0.002203},{1.991792, 0.012823, 0.001115}}],
    Polygon[{{1.993139, 0.011112, 0.002203},{1.992792, 0.010861, 0.003236},{
      1.991387, 0.012266, 0.003236},{1.991639, 0.012612, 0.002203}}],
    Polygon[{{1.992792, 0.010861, 0.003236},{1.992319, 0.010517, 0.004190},{
      1.991044, 0.011793, 0.004190},{1.991387, 0.012266, 0.003236}}],
    Polygon[{{1.992319, 0.010517, 0.004190},{1.991732, 0.010090, 0.005040},{
      1.990617, 0.011205, 0.005040},{1.991044, 0.011793, 0.004190}}],
    Polygon[{{1.991732, 0.010090, 0.005040},{1.991044, 0.009590, 0.005766},{
      1.990117, 0.010517, 0.005766},{1.990617, 0.011205, 0.005040}}],
    Polygon[{{1.991044, 0.009590, 0.005766},{1.990272, 0.009030, 0.006351},{
      1.989556, 0.009746, 0.006351},{1.990117, 0.010517, 0.005766}}],
    Polygon[{{1.990272, 0.009030, 0.006351},{1.989436, 0.008422, 0.006779},{
      1.988949, 0.008910, 0.006779},{1.989556, 0.009746, 0.006351}}],
    Polygon[{{1.989436, 0.008422, 0.006779},{1.988556, 0.007783, 0.007040},{
      1.988310, 0.008030, 0.007040},{1.988949, 0.008910, 0.006779}}],
    Polygon[{{1.988310, 0.008030, -0.007040},{1.988949, 0.008910, -0.006779},{
      1.988335, 0.009223, -0.006779},{1.987999, 0.008188, -0.007040}}],
    Polygon[{{1.988949, 0.008910, -0.006779},{1.989556, 0.009746, -0.006351},{
      1.988654, 0.010205, -0.006351},{1.988335, 0.009223, -0.006779}}],
    Polygon[{{1.989556, 0.009746, -0.006351},{1.990117, 0.010517, -0.005766},{
      1.988949, 0.011112, -0.005766},{1.988654, 0.010205, -0.006351}}],
    Polygon[{{1.990117, 0.010517, -0.005766},{1.990617, 0.011205, -0.005040},{
      1.989212, 0.011921, -0.005040},{1.988949, 0.011112, -0.005766}}],
    Polygon[{{1.990617, 0.011205, -0.005040},{1.991044, 0.011793, -0.004190},{
      1.989436, 0.012612, -0.004190},{1.989212, 0.011921, -0.005040}}],
    Polygon[{{1.991044, 0.011793, -0.004190},{1.991387, 0.012266, -0.003236},{
      1.989617, 0.013168, -0.003236},{1.989436, 0.012612, -0.004190}}],
    Polygon[{{1.991387, 0.012266, -0.003236},{1.991639, 0.012612, -0.002203},{
      1.989749, 0.013575, -0.002203},{1.989617, 0.013168, -0.003236}}],
    Polygon[{{1.991639, 0.012612, -0.002203},{1.991792, 0.012823, -0.001115},{
      1.989830, 0.013823, -0.001115},{1.989749, 0.013575, -0.002203}}],
    Polygon[{{1.991792, 0.012823, -0.001115},{1.991844, 0.012894, 0.000000},{
      1.989857, 0.013907, 0.000000},{1.989830, 0.013823, -0.001115}}],
    Polygon[{{1.991844, 0.012894, 0.000000},{1.991792, 0.012823, 0.001115},{
      1.989830, 0.013823, 0.001115},{1.989857, 0.013907, 0.000000}}],
    Polygon[{{1.991792, 0.012823, 0.001115},{1.991639, 0.012612, 0.002203},{
      1.989749, 0.013575, 0.002203},{1.989830, 0.013823, 0.001115}}],
    Polygon[{{1.991639, 0.012612, 0.002203},{1.991387, 0.012266, 0.003236},{
      1.989617, 0.013168, 0.003236},{1.989749, 0.013575, 0.002203}}],
    Polygon[{{1.991387, 0.012266, 0.003236},{1.991044, 0.011793, 0.004190},{
      1.989436, 0.012612, 0.004190},{1.989617, 0.013168, 0.003236}}],
    Polygon[{{1.991044, 0.011793, 0.004190},{1.990617, 0.011205, 0.005040},{
      1.989212, 0.011921, 0.005040},{1.989436, 0.012612, 0.004190}}],
    Polygon[{{1.990617, 0.011205, 0.005040},{1.990117, 0.010517, 0.005766},{
      1.988949, 0.011112, 0.005766},{1.989212, 0.011921, 0.005040}}],
    Polygon[{{1.990117, 0.010517, 0.005766},{1.989556, 0.009746, 0.006351},{
      1.988654, 0.010205, 0.006351},{1.988949, 0.011112, 0.005766}}],
    Polygon[{{1.989556, 0.009746, 0.006351},{1.988949, 0.008910, 0.006779},{
      1.988335, 0.009223, 0.006779},{1.988654, 0.010205, 0.006351}}],
    Polygon[{{1.988949, 0.008910, 0.006779},{1.988310, 0.008030, 0.007040},{
      1.987999, 0.008188, 0.007040},{1.988335, 0.009223, 0.006779}}],
    Polygon[{{1.987999, 0.008188, -0.007040},{1.988335, 0.009223, -0.006779},{
      1.987654, 0.009330, -0.006779},{1.987654, 0.008243, -0.007040}}],
    Polygon[{{1.988335, 0.009223, -0.006779},{1.988654, 0.010205, -0.006351},{
      1.987654, 0.010364, -0.006351},{1.987654, 0.009330, -0.006779}}],
    Polygon[{{1.988654, 0.010205, -0.006351},{1.988949, 0.011112, -0.005766},{
      1.987654, 0.011317, -0.005766},{1.987654, 0.010364, -0.006351}}],
    Polygon[{{1.988949, 0.011112, -0.005766},{1.989212, 0.011921, -0.005040},{
      1.987654, 0.012168, -0.005040},{1.987654, 0.011317, -0.005766}}],
    Polygon[{{1.989212, 0.011921, -0.005040},{1.989436, 0.012612, -0.004190},{
      1.987654, 0.012894, -0.004190},{1.987654, 0.012168, -0.005040}}],
    Polygon[{{1.989436, 0.012612, -0.004190},{1.989617, 0.013168, -0.003236},{
      1.987654, 0.013479, -0.003236},{1.987654, 0.012894, -0.004190}}],
    Polygon[{{1.989617, 0.013168, -0.003236},{1.989749, 0.013575, -0.002203},{
      1.987654, 0.013907, -0.002203},{1.987654, 0.013479, -0.003236}}],
    Polygon[{{1.989749, 0.013575, -0.002203},{1.989830, 0.013823, -0.001115},{
      1.987654, 0.014168, -0.001115},{1.987654, 0.013907, -0.002203}}],
    Polygon[{{1.989830, 0.013823, -0.001115},{1.989857, 0.013907, 0.000000},{
      1.987654, 0.014256, 0.000000},{1.987654, 0.014168, -0.001115}}],
    Polygon[{{1.989857, 0.013907, 0.000000},{1.989830, 0.013823, 0.001115},{
      1.987654, 0.014168, 0.001115},{1.987654, 0.014256, 0.000000}}],
    Polygon[{{1.989830, 0.013823, 0.001115},{1.989749, 0.013575, 0.002203},{
      1.987654, 0.013907, 0.002203},{1.987654, 0.014168, 0.001115}}],
    Polygon[{{1.989749, 0.013575, 0.002203},{1.989617, 0.013168, 0.003236},{
      1.987654, 0.013479, 0.003236},{1.987654, 0.013907, 0.002203}}],
    Polygon[{{1.989617, 0.013168, 0.003236},{1.989436, 0.012612, 0.004190},{
      1.987654, 0.012894, 0.004190},{1.987654, 0.013479, 0.003236}}],
    Polygon[{{1.989436, 0.012612, 0.004190},{1.989212, 0.011921, 0.005040},{
      1.987654, 0.012168, 0.005040},{1.987654, 0.012894, 0.004190}}],
    Polygon[{{1.989212, 0.011921, 0.005040},{1.988949, 0.011112, 0.005766},{
      1.987654, 0.011317, 0.005766},{1.987654, 0.012168, 0.005040}}],
    Polygon[{{1.988949, 0.011112, 0.005766},{1.988654, 0.010205, 0.006351},{
      1.987654, 0.010364, 0.006351},{1.987654, 0.011317, 0.005766}}],
    Polygon[{{1.988654, 0.010205, 0.006351},{1.988335, 0.009223, 0.006779},{
      1.987654, 0.009330, 0.006779},{1.987654, 0.010364, 0.006351}}],
    Polygon[{{1.988335, 0.009223, 0.006779},{1.987999, 0.008188, 0.007040},{
      1.987654, 0.008243, 0.007040},{1.987654, 0.009330, 0.006779}}],
    Polygon[{{1.987654, 0.008243, -0.007040},{1.987654, 0.009330, -0.006779},{
      1.986974, 0.009223, -0.006779},{1.987310, 0.008188, -0.007040}}],
    Polygon[{{1.987654, 0.009330, -0.006779},{1.987654, 0.010364, -0.006351},{
      1.986654, 0.010205, -0.006351},{1.986974, 0.009223, -0.006779}}],
    Polygon[{{1.987654, 0.010364, -0.006351},{1.987654, 0.011317, -0.005766},{
      1.986360, 0.011112, -0.005766},{1.986654, 0.010205, -0.006351}}],
    Polygon[{{1.987654, 0.011317, -0.005766},{1.987654, 0.012168, -0.005040},{
      1.986097, 0.011921, -0.005040},{1.986360, 0.011112, -0.005766}}],
    Polygon[{{1.987654, 0.012168, -0.005040},{1.987654, 0.012894, -0.004190},{
      1.985872, 0.012612, -0.004190},{1.986097, 0.011921, -0.005040}}],
    Polygon[{{1.987654, 0.012894, -0.004190},{1.987654, 0.013479, -0.003236},{
      1.985692, 0.013168, -0.003236},{1.985872, 0.012612, -0.004190}}],
    Polygon[{{1.987654, 0.013479, -0.003236},{1.987654, 0.013907, -0.002203},{
      1.985559, 0.013575, -0.002203},{1.985692, 0.013168, -0.003236}}],
    Polygon[{{1.987654, 0.013907, -0.002203},{1.987654, 0.014168, -0.001115},{
      1.985479, 0.013823, -0.001115},{1.985559, 0.013575, -0.002203}}],
    Polygon[{{1.987654, 0.014168, -0.001115},{1.987654, 0.014256, 0.000000},{
      1.985452, 0.013907, 0.000000},{1.985479, 0.013823, -0.001115}}],
    Polygon[{{1.987654, 0.014256, 0.000000},{1.987654, 0.014168, 0.001115},{
      1.985479, 0.013823, 0.001115},{1.985452, 0.013907, 0.000000}}],
    Polygon[{{1.987654, 0.014168, 0.001115},{1.987654, 0.013907, 0.002203},{
      1.985559, 0.013575, 0.002203},{1.985479, 0.013823, 0.001115}}],
    Polygon[{{1.987654, 0.013907, 0.002203},{1.987654, 0.013479, 0.003236},{
      1.985692, 0.013168, 0.003236},{1.985559, 0.013575, 0.002203}}],
    Polygon[{{1.987654, 0.013479, 0.003236},{1.987654, 0.012894, 0.004190},{
      1.985872, 0.012612, 0.004190},{1.985692, 0.013168, 0.003236}}],
    Polygon[{{1.987654, 0.012894, 0.004190},{1.987654, 0.012168, 0.005040},{
      1.986097, 0.011921, 0.005040},{1.985872, 0.012612, 0.004190}}],
    Polygon[{{1.987654, 0.012168, 0.005040},{1.987654, 0.011317, 0.005766},{
      1.986360, 0.011112, 0.005766},{1.986097, 0.011921, 0.005040}}],
    Polygon[{{1.987654, 0.011317, 0.005766},{1.987654, 0.010364, 0.006351},{
      1.986654, 0.010205, 0.006351},{1.986360, 0.011112, 0.005766}}],
    Polygon[{{1.987654, 0.010364, 0.006351},{1.987654, 0.009330, 0.006779},{
      1.986974, 0.009223, 0.006779},{1.986654, 0.010205, 0.006351}}],
    Polygon[{{1.987654, 0.009330, 0.006779},{1.987654, 0.008243, 0.007040},{
      1.987310, 0.008188, 0.007040},{1.986974, 0.009223, 0.006779}}],
    Polygon[{{1.987310, 0.008188, -0.007040},{1.986974, 0.009223, -0.006779},{
      1.986360, 0.008910, -0.006779},{1.986999, 0.008030, -0.007040}}],
    Polygon[{{1.986974, 0.009223, -0.006779},{1.986654, 0.010205, -0.006351},{
      1.985752, 0.009746, -0.006351},{1.986360, 0.008910, -0.006779}}],
    Polygon[{{1.986654, 0.010205, -0.006351},{1.986360, 0.011112, -0.005766},{
      1.985192, 0.010517, -0.005766},{1.985752, 0.009746, -0.006351}}],
    Polygon[{{1.986360, 0.011112, -0.005766},{1.986097, 0.011921, -0.005040},{
      1.984692, 0.011205, -0.005040},{1.985192, 0.010517, -0.005766}}],
    Polygon[{{1.986097, 0.011921, -0.005040},{1.985872, 0.012612, -0.004190},{
      1.984265, 0.011793, -0.004190},{1.984692, 0.011205, -0.005040}}],
    Polygon[{{1.985872, 0.012612, -0.004190},{1.985692, 0.013168, -0.003236},{
      1.983921, 0.012266, -0.003236},{1.984265, 0.011793, -0.004190}}],
    Polygon[{{1.985692, 0.013168, -0.003236},{1.985559, 0.013575, -0.002203},{
      1.983670, 0.012612, -0.002203},{1.983921, 0.012266, -0.003236}}],
    Polygon[{{1.985559, 0.013575, -0.002203},{1.985479, 0.013823, -0.001115},{
      1.983516, 0.012823, -0.001115},{1.983670, 0.012612, -0.002203}}],
    Polygon[{{1.985479, 0.013823, -0.001115},{1.985452, 0.013907, 0.000000},{
      1.983465, 0.012894, 0.000000},{1.983516, 0.012823, -0.001115}}],
    Polygon[{{1.985452, 0.013907, 0.000000},{1.985479, 0.013823, 0.001115},{
      1.983516, 0.012823, 0.001115},{1.983465, 0.012894, 0.000000}}],
    Polygon[{{1.985479, 0.013823, 0.001115},{1.985559, 0.013575, 0.002203},{
      1.983670, 0.012612, 0.002203},{1.983516, 0.012823, 0.001115}}],
    Polygon[{{1.985559, 0.013575, 0.002203},{1.985692, 0.013168, 0.003236},{
      1.983921, 0.012266, 0.003236},{1.983670, 0.012612, 0.002203}}],
    Polygon[{{1.985692, 0.013168, 0.003236},{1.985872, 0.012612, 0.004190},{
      1.984265, 0.011793, 0.004190},{1.983921, 0.012266, 0.003236}}],
    Polygon[{{1.985872, 0.012612, 0.004190},{1.986097, 0.011921, 0.005040},{
      1.984692, 0.011205, 0.005040},{1.984265, 0.011793, 0.004190}}],
    Polygon[{{1.986097, 0.011921, 0.005040},{1.986360, 0.011112, 0.005766},{
      1.985192, 0.010517, 0.005766},{1.984692, 0.011205, 0.005040}}],
    Polygon[{{1.986360, 0.011112, 0.005766},{1.986654, 0.010205, 0.006351},{
      1.985752, 0.009746, 0.006351},{1.985192, 0.010517, 0.005766}}],
    Polygon[{{1.986654, 0.010205, 0.006351},{1.986974, 0.009223, 0.006779},{
      1.986360, 0.008910, 0.006779},{1.985752, 0.009746, 0.006351}}],
    Polygon[{{1.986974, 0.009223, 0.006779},{1.987310, 0.008188, 0.007040},{
      1.986999, 0.008030, 0.007040},{1.986360, 0.008910, 0.006779}}],
    Polygon[{{1.986999, 0.008030, -0.007040},{1.986360, 0.008910, -0.006779},{
      1.985872, 0.008422, -0.006779},{1.986752, 0.007783, -0.007040}}],
    Polygon[{{1.986360, 0.008910, -0.006779},{1.985752, 0.009746, -0.006351},{
      1.985036, 0.009030, -0.006351},{1.985872, 0.008422, -0.006779}}],
    Polygon[{{1.985752, 0.009746, -0.006351},{1.985192, 0.010517, -0.005766},{
      1.984265, 0.009590, -0.005766},{1.985036, 0.009030, -0.006351}}],
    Polygon[{{1.985192, 0.010517, -0.005766},{1.984692, 0.011205, -0.005040},{
      1.983577, 0.010090, -0.005040},{1.984265, 0.009590, -0.005766}}],
    Polygon[{{1.984692, 0.011205, -0.005040},{1.984265, 0.011793, -0.004190},{
      1.982989, 0.010517, -0.004190},{1.983577, 0.010090, -0.005040}}],
    Polygon[{{1.984265, 0.011793, -0.004190},{1.983921, 0.012266, -0.003236},{
      1.982516, 0.010861, -0.003236},{1.982989, 0.010517, -0.004190}}],
    Polygon[{{1.983921, 0.012266, -0.003236},{1.983670, 0.012612, -0.002203},{
      1.982170, 0.011112, -0.002203},{1.982516, 0.010861, -0.003236}}],
    Polygon[{{1.983670, 0.012612, -0.002203},{1.983516, 0.012823, -0.001115},{
      1.981959, 0.011266, -0.001115},{1.982170, 0.011112, -0.002203}}],
    Polygon[{{1.983516, 0.012823, -0.001115},{1.983465, 0.012894, 0.000000},{
      1.981888, 0.011317, 0.000000},{1.981959, 0.011266, -0.001115}}],
    Polygon[{{1.983465, 0.012894, 0.000000},{1.983516, 0.012823, 0.001115},{
      1.981959, 0.011266, 0.001115},{1.981888, 0.011317, 0.000000}}],
    Polygon[{{1.983516, 0.012823, 0.001115},{1.983670, 0.012612, 0.002203},{
      1.982170, 0.011112, 0.002203},{1.981959, 0.011266, 0.001115}}],
    Polygon[{{1.983670, 0.012612, 0.002203},{1.983921, 0.012266, 0.003236},{
      1.982516, 0.010861, 0.003236},{1.982170, 0.011112, 0.002203}}],
    Polygon[{{1.983921, 0.012266, 0.003236},{1.984265, 0.011793, 0.004190},{
      1.982989, 0.010517, 0.004190},{1.982516, 0.010861, 0.003236}}],
    Polygon[{{1.984265, 0.011793, 0.004190},{1.984692, 0.011205, 0.005040},{
      1.983577, 0.010090, 0.005040},{1.982989, 0.010517, 0.004190}}],
    Polygon[{{1.984692, 0.011205, 0.005040},{1.985192, 0.010517, 0.005766},{
      1.984265, 0.009590, 0.005766},{1.983577, 0.010090, 0.005040}}],
    Polygon[{{1.985192, 0.010517, 0.005766},{1.985752, 0.009746, 0.006351},{
      1.985036, 0.009030, 0.006351},{1.984265, 0.009590, 0.005766}}],
    Polygon[{{1.985752, 0.009746, 0.006351},{1.986360, 0.008910, 0.006779},{
      1.985872, 0.008422, 0.006779},{1.985036, 0.009030, 0.006351}}],
    Polygon[{{1.986360, 0.008910, 0.006779},{1.986999, 0.008030, 0.007040},{
      1.986752, 0.007783, 0.007040},{1.985872, 0.008422, 0.006779}}],
    Polygon[{{1.986752, 0.007783, -0.007040},{1.985872, 0.008422, -0.006779},{
      1.985559, 0.007808, -0.006779},{1.986594, 0.007472, -0.007040}}],
    Polygon[{{1.985872, 0.008422, -0.006779},{1.985036, 0.009030, -0.006351},{
      1.984577, 0.008128, -0.006351},{1.985559, 0.007808, -0.006779}}],
    Polygon[{{1.985036, 0.009030, -0.006351},{1.984265, 0.009590, -0.005766},{
      1.983670, 0.008422, -0.005766},{1.984577, 0.008128, -0.006351}}],
    Polygon[{{1.984265, 0.009590, -0.005766},{1.983577, 0.010090, -0.005040},{
      1.982861, 0.008685, -0.005040},{1.983670, 0.008422, -0.005766}}],
    Polygon[{{1.983577, 0.010090, -0.005040},{1.982989, 0.010517, -0.004190},{
      1.982170, 0.008910, -0.004190},{1.982861, 0.008685, -0.005040}}],
    Polygon[{{1.982989, 0.010517, -0.004190},{1.982516, 0.010861, -0.003236},{
      1.981614, 0.009090, -0.003236},{1.982170, 0.008910, -0.004190}}],
    Polygon[{{1.982516, 0.010861, -0.003236},{1.982170, 0.011112, -0.002203},{
      1.981207, 0.009223, -0.002203},{1.981614, 0.009090, -0.003236}}],
    Polygon[{{1.982170, 0.011112, -0.002203},{1.981959, 0.011266, -0.001115},{
      1.980959, 0.009303, -0.001115},{1.981207, 0.009223, -0.002203}}],
    Polygon[{{1.981959, 0.011266, -0.001115},{1.981888, 0.011317, 0.000000},{
      1.980875, 0.009330, 0.000000},{1.980959, 0.009303, -0.001115}}],
    Polygon[{{1.981888, 0.011317, 0.000000},{1.981959, 0.011266, 0.001115},{
      1.980959, 0.009303, 0.001115},{1.980875, 0.009330, 0.000000}}],
    Polygon[{{1.981959, 0.011266, 0.001115},{1.982170, 0.011112, 0.002203},{
      1.981207, 0.009223, 0.002203},{1.980959, 0.009303, 0.001115}}],
    Polygon[{{1.982170, 0.011112, 0.002203},{1.982516, 0.010861, 0.003236},{
      1.981614, 0.009090, 0.003236},{1.981207, 0.009223, 0.002203}}],
    Polygon[{{1.982516, 0.010861, 0.003236},{1.982989, 0.010517, 0.004190},{
      1.982170, 0.008910, 0.004190},{1.981614, 0.009090, 0.003236}}],
    Polygon[{{1.982989, 0.010517, 0.004190},{1.983577, 0.010090, 0.005040},{
      1.982861, 0.008685, 0.005040},{1.982170, 0.008910, 0.004190}}],
    Polygon[{{1.983577, 0.010090, 0.005040},{1.984265, 0.009590, 0.005766},{
      1.983670, 0.008422, 0.005766},{1.982861, 0.008685, 0.005040}}],
    Polygon[{{1.984265, 0.009590, 0.005766},{1.985036, 0.009030, 0.006351},{
      1.984577, 0.008128, 0.006351},{1.983670, 0.008422, 0.005766}}],
    Polygon[{{1.985036, 0.009030, 0.006351},{1.985872, 0.008422, 0.006779},{
      1.985559, 0.007808, 0.006779},{1.984577, 0.008128, 0.006351}}],
    Polygon[{{1.985872, 0.008422, 0.006779},{1.986752, 0.007783, 0.007040},{
      1.986594, 0.007472, 0.007040},{1.985559, 0.007808, 0.006779}}],
    Polygon[{{1.986594, 0.007472, -0.007040},{1.985559, 0.007808, -0.006779},{
      1.985452, 0.007128, -0.006779},{1.986539, 0.007128, -0.007040}}],
    Polygon[{{1.985559, 0.007808, -0.006779},{1.984577, 0.008128, -0.006351},{
      1.984418, 0.007128, -0.006351},{1.985452, 0.007128, -0.006779}}],
    Polygon[{{1.984577, 0.008128, -0.006351},{1.983670, 0.008422, -0.005766},{
      1.983465, 0.007128, -0.005766},{1.984418, 0.007128, -0.006351}}],
    Polygon[{{1.983670, 0.008422, -0.005766},{1.982861, 0.008685, -0.005040},{
      1.982614, 0.007128, -0.005040},{1.983465, 0.007128, -0.005766}}],
    Polygon[{{1.982861, 0.008685, -0.005040},{1.982170, 0.008910, -0.004190},{
      1.981888, 0.007128, -0.004190},{1.982614, 0.007128, -0.005040}}],
    Polygon[{{1.982170, 0.008910, -0.004190},{1.981614, 0.009090, -0.003236},{
      1.981303, 0.007128, -0.003236},{1.981888, 0.007128, -0.004190}}],
    Polygon[{{1.981614, 0.009090, -0.003236},{1.981207, 0.009223, -0.002203},{
      1.980875, 0.007128, -0.002203},{1.981303, 0.007128, -0.003236}}],
    Polygon[{{1.981207, 0.009223, -0.002203},{1.980959, 0.009303, -0.001115},{
      1.980614, 0.007128, -0.001115},{1.980875, 0.007128, -0.002203}}],
    Polygon[{{1.980959, 0.009303, -0.001115},{1.980875, 0.009330, 0.000000},{
      1.980527, 0.007128, 0.000000},{1.980614, 0.007128, -0.001115}}],
    Polygon[{{1.980875, 0.009330, 0.000000},{1.980959, 0.009303, 0.001115},{
      1.980614, 0.007128, 0.001115},{1.980527, 0.007128, 0.000000}}],
    Polygon[{{1.980959, 0.009303, 0.001115},{1.981207, 0.009223, 0.002203},{
      1.980875, 0.007128, 0.002203},{1.980614, 0.007128, 0.001115}}],
    Polygon[{{1.981207, 0.009223, 0.002203},{1.981614, 0.009090, 0.003236},{
      1.981303, 0.007128, 0.003236},{1.980875, 0.007128, 0.002203}}],
    Polygon[{{1.981614, 0.009090, 0.003236},{1.982170, 0.008910, 0.004190},{
      1.981888, 0.007128, 0.004190},{1.981303, 0.007128, 0.003236}}],
    Polygon[{{1.982170, 0.008910, 0.004190},{1.982861, 0.008685, 0.005040},{
      1.982614, 0.007128, 0.005040},{1.981888, 0.007128, 0.004190}}],
    Polygon[{{1.982861, 0.008685, 0.005040},{1.983670, 0.008422, 0.005766},{
      1.983465, 0.007128, 0.005766},{1.982614, 0.007128, 0.005040}}],
    Polygon[{{1.983670, 0.008422, 0.005766},{1.984577, 0.008128, 0.006351},{
      1.984418, 0.007128, 0.006351},{1.983465, 0.007128, 0.005766}}],
    Polygon[{{1.984577, 0.008128, 0.006351},{1.985559, 0.007808, 0.006779},{
      1.985452, 0.007128, 0.006779},{1.984418, 0.007128, 0.006351}}],
    Polygon[{{1.985559, 0.007808, 0.006779},{1.986594, 0.007472, 0.007040},{
      1.986539, 0.007128, 0.007040},{1.985452, 0.007128, 0.006779}}],
    Polygon[{{1.986539, 0.007128, -0.007040},{1.985452, 0.007128, -0.006779},{
      1.985559, 0.006447, -0.006779},{1.986594, 0.006783, -0.007040}}],
    Polygon[{{1.985452, 0.007128, -0.006779},{1.984418, 0.007128, -0.006351},{
      1.984577, 0.006128, -0.006351},{1.985559, 0.006447, -0.006779}}],
    Polygon[{{1.984418, 0.007128, -0.006351},{1.983465, 0.007128, -0.005766},{
      1.983670, 0.005833, -0.005766},{1.984577, 0.006128, -0.006351}}],
    Polygon[{{1.983465, 0.007128, -0.005766},{1.982614, 0.007128, -0.005040},{
      1.982861, 0.005570, -0.005040},{1.983670, 0.005833, -0.005766}}],
    Polygon[{{1.982614, 0.007128, -0.005040},{1.981888, 0.007128, -0.004190},{
      1.982170, 0.005346, -0.004190},{1.982861, 0.005570, -0.005040}}],
    Polygon[{{1.981888, 0.007128, -0.004190},{1.981303, 0.007128, -0.003236},{
      1.981614, 0.005165, -0.003236},{1.982170, 0.005346, -0.004190}}],
    Polygon[{{1.981303, 0.007128, -0.003236},{1.980875, 0.007128, -0.002203},{
      1.981207, 0.005033, -0.002203},{1.981614, 0.005165, -0.003236}}],
    Polygon[{{1.980875, 0.007128, -0.002203},{1.980614, 0.007128, -0.001115},{
      1.980959, 0.004952, -0.001115},{1.981207, 0.005033, -0.002203}}],
    Polygon[{{1.980614, 0.007128, -0.001115},{1.980527, 0.007128, 0.000000},{
      1.980875, 0.004925, 0.000000},{1.980959, 0.004952, -0.001115}}],
    Polygon[{{1.980527, 0.007128, 0.000000},{1.980614, 0.007128, 0.001115},{
      1.980959, 0.004952, 0.001115},{1.980875, 0.004925, 0.000000}}],
    Polygon[{{1.980614, 0.007128, 0.001115},{1.980875, 0.007128, 0.002203},{
      1.981207, 0.005033, 0.002203},{1.980959, 0.004952, 0.001115}}],
    Polygon[{{1.980875, 0.007128, 0.002203},{1.981303, 0.007128, 0.003236},{
      1.981614, 0.005165, 0.003236},{1.981207, 0.005033, 0.002203}}],
    Polygon[{{1.981303, 0.007128, 0.003236},{1.981888, 0.007128, 0.004190},{
      1.982170, 0.005346, 0.004190},{1.981614, 0.005165, 0.003236}}],
    Polygon[{{1.981888, 0.007128, 0.004190},{1.982614, 0.007128, 0.005040},{
      1.982861, 0.005570, 0.005040},{1.982170, 0.005346, 0.004190}}],
    Polygon[{{1.982614, 0.007128, 0.005040},{1.983465, 0.007128, 0.005766},{
      1.983670, 0.005833, 0.005766},{1.982861, 0.005570, 0.005040}}],
    Polygon[{{1.983465, 0.007128, 0.005766},{1.984418, 0.007128, 0.006351},{
      1.984577, 0.006128, 0.006351},{1.983670, 0.005833, 0.005766}}],
    Polygon[{{1.984418, 0.007128, 0.006351},{1.985452, 0.007128, 0.006779},{
      1.985559, 0.006447, 0.006779},{1.984577, 0.006128, 0.006351}}],
    Polygon[{{1.985452, 0.007128, 0.006779},{1.986539, 0.007128, 0.007040},{
      1.986594, 0.006783, 0.007040},{1.985559, 0.006447, 0.006779}}],
    Polygon[{{1.986594, 0.006783, -0.007040},{1.985559, 0.006447, -0.006779},{
      1.985872, 0.005833, -0.006779},{1.986752, 0.006472, -0.007040}}],
    Polygon[{{1.985559, 0.006447, -0.006779},{1.984577, 0.006128, -0.006351},{
      1.985036, 0.005226, -0.006351},{1.985872, 0.005833, -0.006779}}],
    Polygon[{{1.984577, 0.006128, -0.006351},{1.983670, 0.005833, -0.005766},{
      1.984265, 0.004665, -0.005766},{1.985036, 0.005226, -0.006351}}],
    Polygon[{{1.983670, 0.005833, -0.005766},{1.982861, 0.005570, -0.005040},{
      1.983577, 0.004165, -0.005040},{1.984265, 0.004665, -0.005766}}],
    Polygon[{{1.982861, 0.005570, -0.005040},{1.982170, 0.005346, -0.004190},{
      1.982989, 0.003738, -0.004190},{1.983577, 0.004165, -0.005040}}],
    Polygon[{{1.982170, 0.005346, -0.004190},{1.981614, 0.005165, -0.003236},{
      1.982516, 0.003395, -0.003236},{1.982989, 0.003738, -0.004190}}],
    Polygon[{{1.981614, 0.005165, -0.003236},{1.981207, 0.005033, -0.002203},{
      1.982170, 0.003143, -0.002203},{1.982516, 0.003395, -0.003236}}],
    Polygon[{{1.981207, 0.005033, -0.002203},{1.980959, 0.004952, -0.001115},{
      1.981959, 0.002990, -0.001115},{1.982170, 0.003143, -0.002203}}],
    Polygon[{{1.980959, 0.004952, -0.001115},{1.980875, 0.004925, 0.000000},{
      1.981888, 0.002938, 0.000000},{1.981959, 0.002990, -0.001115}}],
    Polygon[{{1.980875, 0.004925, 0.000000},{1.980959, 0.004952, 0.001115},{
      1.981959, 0.002990, 0.001115},{1.981888, 0.002938, 0.000000}}],
    Polygon[{{1.980959, 0.004952, 0.001115},{1.981207, 0.005033, 0.002203},{
      1.982170, 0.003143, 0.002203},{1.981959, 0.002990, 0.001115}}],
    Polygon[{{1.981207, 0.005033, 0.002203},{1.981614, 0.005165, 0.003236},{
      1.982516, 0.003395, 0.003236},{1.982170, 0.003143, 0.002203}}],
    Polygon[{{1.981614, 0.005165, 0.003236},{1.982170, 0.005346, 0.004190},{
      1.982989, 0.003738, 0.004190},{1.982516, 0.003395, 0.003236}}],
    Polygon[{{1.982170, 0.005346, 0.004190},{1.982861, 0.005570, 0.005040},{
      1.983577, 0.004165, 0.005040},{1.982989, 0.003738, 0.004190}}],
    Polygon[{{1.982861, 0.005570, 0.005040},{1.983670, 0.005833, 0.005766},{
      1.984265, 0.004665, 0.005766},{1.983577, 0.004165, 0.005040}}],
    Polygon[{{1.983670, 0.005833, 0.005766},{1.984577, 0.006128, 0.006351},{
      1.985036, 0.005226, 0.006351},{1.984265, 0.004665, 0.005766}}],
    Polygon[{{1.984577, 0.006128, 0.006351},{1.985559, 0.006447, 0.006779},{
      1.985872, 0.005833, 0.006779},{1.985036, 0.005226, 0.006351}}],
    Polygon[{{1.985559, 0.006447, 0.006779},{1.986594, 0.006783, 0.007040},{
      1.986752, 0.006472, 0.007040},{1.985872, 0.005833, 0.006779}}],
    Polygon[{{1.986752, 0.006472, -0.007040},{1.985872, 0.005833, -0.006779},{
      1.986360, 0.005346, -0.006779},{1.986999, 0.006226, -0.007040}}],
    Polygon[{{1.985872, 0.005833, -0.006779},{1.985036, 0.005226, -0.006351},{
      1.985752, 0.004510, -0.006351},{1.986360, 0.005346, -0.006779}}],
    Polygon[{{1.985036, 0.005226, -0.006351},{1.984265, 0.004665, -0.005766},{
      1.985192, 0.003738, -0.005766},{1.985752, 0.004510, -0.006351}}],
    Polygon[{{1.984265, 0.004665, -0.005766},{1.983577, 0.004165, -0.005040},{
      1.984692, 0.003050, -0.005040},{1.985192, 0.003738, -0.005766}}],
    Polygon[{{1.983577, 0.004165, -0.005040},{1.982989, 0.003738, -0.004190},{
      1.984265, 0.002463, -0.004190},{1.984692, 0.003050, -0.005040}}],
    Polygon[{{1.982989, 0.003738, -0.004190},{1.982516, 0.003395, -0.003236},{
      1.983921, 0.001990, -0.003236},{1.984265, 0.002463, -0.004190}}],
    Polygon[{{1.982516, 0.003395, -0.003236},{1.982170, 0.003143, -0.002203},{
      1.983670, 0.001644, -0.002203},{1.983921, 0.001990, -0.003236}}],
    Polygon[{{1.982170, 0.003143, -0.002203},{1.981959, 0.002990, -0.001115},{
      1.983516, 0.001432, -0.001115},{1.983670, 0.001644, -0.002203}}],
    Polygon[{{1.981959, 0.002990, -0.001115},{1.981888, 0.002938, 0.000000},{
      1.983465, 0.001361, 0.000000},{1.983516, 0.001432, -0.001115}}],
    Polygon[{{1.981888, 0.002938, 0.000000},{1.981959, 0.002990, 0.001115},{
      1.983516, 0.001432, 0.001115},{1.983465, 0.001361, 0.000000}}],
    Polygon[{{1.981959, 0.002990, 0.001115},{1.982170, 0.003143, 0.002203},{
      1.983670, 0.001644, 0.002203},{1.983516, 0.001432, 0.001115}}],
    Polygon[{{1.982170, 0.003143, 0.002203},{1.982516, 0.003395, 0.003236},{
      1.983921, 0.001990, 0.003236},{1.983670, 0.001644, 0.002203}}],
    Polygon[{{1.982516, 0.003395, 0.003236},{1.982989, 0.003738, 0.004190},{
      1.984265, 0.002463, 0.004190},{1.983921, 0.001990, 0.003236}}],
    Polygon[{{1.982989, 0.003738, 0.004190},{1.983577, 0.004165, 0.005040},{
      1.984692, 0.003050, 0.005040},{1.984265, 0.002463, 0.004190}}],
    Polygon[{{1.983577, 0.004165, 0.005040},{1.984265, 0.004665, 0.005766},{
      1.985192, 0.003738, 0.005766},{1.984692, 0.003050, 0.005040}}],
    Polygon[{{1.984265, 0.004665, 0.005766},{1.985036, 0.005226, 0.006351},{
      1.985752, 0.004510, 0.006351},{1.985192, 0.003738, 0.005766}}],
    Polygon[{{1.985036, 0.005226, 0.006351},{1.985872, 0.005833, 0.006779},{
      1.986360, 0.005346, 0.006779},{1.985752, 0.004510, 0.006351}}],
    Polygon[{{1.985872, 0.005833, 0.006779},{1.986752, 0.006472, 0.007040},{
      1.986999, 0.006226, 0.007040},{1.986360, 0.005346, 0.006779}}],
    Polygon[{{1.986999, 0.006226, -0.007040},{1.986360, 0.005346, -0.006779},{
      1.986974, 0.005033, -0.006779},{1.987310, 0.006067, -0.007040}}],
    Polygon[{{1.986360, 0.005346, -0.006779},{1.985752, 0.004510, -0.006351},{
      1.986654, 0.004050, -0.006351},{1.986974, 0.005033, -0.006779}}],
    Polygon[{{1.985752, 0.004510, -0.006351},{1.985192, 0.003738, -0.005766},{
      1.986360, 0.003143, -0.005766},{1.986654, 0.004050, -0.006351}}],
    Polygon[{{1.985192, 0.003738, -0.005766},{1.984692, 0.003050, -0.005040},{
      1.986097, 0.002334, -0.005040},{1.986360, 0.003143, -0.005766}}],
    Polygon[{{1.984692, 0.003050, -0.005040},{1.984265, 0.002463, -0.004190},{
      1.985872, 0.001644, -0.004190},{1.986097, 0.002334, -0.005040}}],
    Polygon[{{1.984265, 0.002463, -0.004190},{1.983921, 0.001990, -0.003236},{
      1.985692, 0.001088, -0.003236},{1.985872, 0.001644, -0.004190}}],
    Polygon[{{1.983921, 0.001990, -0.003236},{1.983670, 0.001644, -0.002203},{
      1.985559, 0.000681, -0.002203},{1.985692, 0.001088, -0.003236}}],
    Polygon[{{1.983670, 0.001644, -0.002203},{1.983516, 0.001432, -0.001115},{
      1.985479, 0.000432, -0.001115},{1.985559, 0.000681, -0.002203}}],
    Polygon[{{1.983516, 0.001432, -0.001115},{1.983465, 0.001361, 0.000000},{
      1.985452, 0.000349, 0.000000},{1.985479, 0.000432, -0.001115}}],
    Polygon[{{1.983465, 0.001361, 0.000000},{1.983516, 0.001432, 0.001115},{
      1.985479, 0.000432, 0.001115},{1.985452, 0.000349, 0.000000}}],
    Polygon[{{1.983516, 0.001432, 0.001115},{1.983670, 0.001644, 0.002203},{
      1.985559, 0.000681, 0.002203},{1.985479, 0.000432, 0.001115}}],
    Polygon[{{1.983670, 0.001644, 0.002203},{1.983921, 0.001990, 0.003236},{
      1.985692, 0.001088, 0.003236},{1.985559, 0.000681, 0.002203}}],
    Polygon[{{1.983921, 0.001990, 0.003236},{1.984265, 0.002463, 0.004190},{
      1.985872, 0.001644, 0.004190},{1.985692, 0.001088, 0.003236}}],
    Polygon[{{1.984265, 0.002463, 0.004190},{1.984692, 0.003050, 0.005040},{
      1.986097, 0.002334, 0.005040},{1.985872, 0.001644, 0.004190}}],
    Polygon[{{1.984692, 0.003050, 0.005040},{1.985192, 0.003738, 0.005766},{
      1.986360, 0.003143, 0.005766},{1.986097, 0.002334, 0.005040}}],
    Polygon[{{1.985192, 0.003738, 0.005766},{1.985752, 0.004510, 0.006351},{
      1.986654, 0.004050, 0.006351},{1.986360, 0.003143, 0.005766}}],
    Polygon[{{1.985752, 0.004510, 0.006351},{1.986360, 0.005346, 0.006779},{
      1.986974, 0.005033, 0.006779},{1.986654, 0.004050, 0.006351}}],
    Polygon[{{1.986360, 0.005346, 0.006779},{1.986999, 0.006226, 0.007040},{
      1.987310, 0.006067, 0.007040},{1.986974, 0.005033, 0.006779}}],
    Polygon[{{1.987310, 0.006067, -0.007040},{1.986974, 0.005033, -0.006779},{
      1.987654, 0.004925, -0.006779},{1.987654, 0.006013, -0.007040}}],
    Polygon[{{1.986974, 0.005033, -0.006779},{1.986654, 0.004050, -0.006351},{
      1.987654, 0.003892, -0.006351},{1.987654, 0.004925, -0.006779}}],
    Polygon[{{1.986654, 0.004050, -0.006351},{1.986360, 0.003143, -0.005766},{
      1.987654, 0.002938, -0.005766},{1.987654, 0.003892, -0.006351}}],
    Polygon[{{1.986360, 0.003143, -0.005766},{1.986097, 0.002334, -0.005040},{
      1.987654, 0.002088, -0.005040},{1.987654, 0.002938, -0.005766}}],
    Polygon[{{1.986097, 0.002334, -0.005040},{1.985872, 0.001644, -0.004190},{
      1.987654, 0.001361, -0.004190},{1.987654, 0.002088, -0.005040}}],
    Polygon[{{1.985872, 0.001644, -0.004190},{1.985692, 0.001088, -0.003236},{
      1.987654, 0.000777, -0.003236},{1.987654, 0.001361, -0.004190}}],
    Polygon[{{1.985692, 0.001088, -0.003236},{1.985559, 0.000681, -0.002203},{
      1.987654, 0.000349, -0.002203},{1.987654, 0.000777, -0.003236}}],
    Polygon[{{1.985559, 0.000681, -0.002203},{1.985479, 0.000432, -0.001115},{
      1.987654, 0.000088, -0.001115},{1.987654, 0.000349, -0.002203}}],
    Polygon[{{1.985479, 0.000432, -0.001115},{1.985452, 0.000349, 0.000000},{
      1.987654, 0.000000, 0.000000},{1.987654, 0.000088, -0.001115}}],
    Polygon[{{1.985452, 0.000349, 0.000000},{1.985479, 0.000432, 0.001115},{
      1.987654, 0.000088, 0.001115},{1.987654, 0.000000, 0.000000}}],
    Polygon[{{1.985479, 0.000432, 0.001115},{1.985559, 0.000681, 0.002203},{
      1.987654, 0.000349, 0.002203},{1.987654, 0.000088, 0.001115}}],
    Polygon[{{1.985559, 0.000681, 0.002203},{1.985692, 0.001088, 0.003236},{
      1.987654, 0.000777, 0.003236},{1.987654, 0.000349, 0.002203}}],
    Polygon[{{1.985692, 0.001088, 0.003236},{1.985872, 0.001644, 0.004190},{
      1.987654, 0.001361, 0.004190},{1.987654, 0.000777, 0.003236}}],
    Polygon[{{1.985872, 0.001644, 0.004190},{1.986097, 0.002334, 0.005040},{
      1.987654, 0.002088, 0.005040},{1.987654, 0.001361, 0.004190}}],
    Polygon[{{1.986097, 0.002334, 0.005040},{1.986360, 0.003143, 0.005766},{
      1.987654, 0.002938, 0.005766},{1.987654, 0.002088, 0.005040}}],
    Polygon[{{1.986360, 0.003143, 0.005766},{1.986654, 0.004050, 0.006351},{
      1.987654, 0.003892, 0.006351},{1.987654, 0.002938, 0.005766}}],
    Polygon[{{1.986654, 0.004050, 0.006351},{1.986974, 0.005033, 0.006779},{
      1.987654, 0.004925, 0.006779},{1.987654, 0.003892, 0.006351}}],
    Polygon[{{1.986974, 0.005033, 0.006779},{1.987310, 0.006067, 0.007040},{
      1.987654, 0.006013, 0.007040},{1.987654, 0.004925, 0.006779}}],
    Polygon[{{1.987654, 0.006013, -0.007040},{1.987654, 0.004925, -0.006779},{
      1.988335, 0.005033, -0.006779},{1.987999, 0.006067, -0.007040}}],
    Polygon[{{1.987654, 0.004925, -0.006779},{1.987654, 0.003892, -0.006351},{
      1.988654, 0.004050, -0.006351},{1.988335, 0.005033, -0.006779}}],
    Polygon[{{1.987654, 0.003892, -0.006351},{1.987654, 0.002938, -0.005766},{
      1.988949, 0.003143, -0.005766},{1.988654, 0.004050, -0.006351}}],
    Polygon[{{1.987654, 0.002938, -0.005766},{1.987654, 0.002088, -0.005040},{
      1.989212, 0.002334, -0.005040},{1.988949, 0.003143, -0.005766}}],
    Polygon[{{1.987654, 0.002088, -0.005040},{1.987654, 0.001361, -0.004190},{
      1.989436, 0.001644, -0.004190},{1.989212, 0.002334, -0.005040}}],
    Polygon[{{1.987654, 0.001361, -0.004190},{1.987654, 0.000777, -0.003236},{
      1.989617, 0.001088, -0.003236},{1.989436, 0.001644, -0.004190}}],
    Polygon[{{1.987654, 0.000777, -0.003236},{1.987654, 0.000349, -0.002203},{
      1.989749, 0.000681, -0.002203},{1.989617, 0.001088, -0.003236}}],
    Polygon[{{1.987654, 0.000349, -0.002203},{1.987654, 0.000088, -0.001115},{
      1.989830, 0.000432, -0.001115},{1.989749, 0.000681, -0.002203}}],
    Polygon[{{1.987654, 0.000088, -0.001115},{1.987654, 0.000000, 0.000000},{
      1.989857, 0.000349, 0.000000},{1.989830, 0.000432, -0.001115}}],
    Polygon[{{1.987654, 0.000000, 0.000000},{1.987654, 0.000088, 0.001115},{
      1.989830, 0.000432, 0.001115},{1.989857, 0.000349, 0.000000}}],
    Polygon[{{1.987654, 0.000088, 0.001115},{1.987654, 0.000349, 0.002203},{
      1.989749, 0.000681, 0.002203},{1.989830, 0.000432, 0.001115}}],
    Polygon[{{1.987654, 0.000349, 0.002203},{1.987654, 0.000777, 0.003236},{
      1.989617, 0.001088, 0.003236},{1.989749, 0.000681, 0.002203}}],
    Polygon[{{1.987654, 0.000777, 0.003236},{1.987654, 0.001361, 0.004190},{
      1.989436, 0.001644, 0.004190},{1.989617, 0.001088, 0.003236}}],
    Polygon[{{1.987654, 0.001361, 0.004190},{1.987654, 0.002088, 0.005040},{
      1.989212, 0.002334, 0.005040},{1.989436, 0.001644, 0.004190}}],
    Polygon[{{1.987654, 0.002088, 0.005040},{1.987654, 0.002938, 0.005766},{
      1.988949, 0.003143, 0.005766},{1.989212, 0.002334, 0.005040}}],
    Polygon[{{1.987654, 0.002938, 0.005766},{1.987654, 0.003892, 0.006351},{
      1.988654, 0.004050, 0.006351},{1.988949, 0.003143, 0.005766}}],
    Polygon[{{1.987654, 0.003892, 0.006351},{1.987654, 0.004925, 0.006779},{
      1.988335, 0.005033, 0.006779},{1.988654, 0.004050, 0.006351}}],
    Polygon[{{1.987654, 0.004925, 0.006779},{1.987654, 0.006013, 0.007040},{
      1.987999, 0.006067, 0.007040},{1.988335, 0.005033, 0.006779}}],
    Polygon[{{1.987999, 0.006067, -0.007040},{1.988335, 0.005033, -0.006779},{
      1.988949, 0.005346, -0.006779},{1.988310, 0.006226, -0.007040}}],
    Polygon[{{1.988335, 0.005033, -0.006779},{1.988654, 0.004050, -0.006351},{
      1.989556, 0.004510, -0.006351},{1.988949, 0.005346, -0.006779}}],
    Polygon[{{1.988654, 0.004050, -0.006351},{1.988949, 0.003143, -0.005766},{
      1.990117, 0.003738, -0.005766},{1.989556, 0.004510, -0.006351}}],
    Polygon[{{1.988949, 0.003143, -0.005766},{1.989212, 0.002334, -0.005040},{
      1.990617, 0.003050, -0.005040},{1.990117, 0.003738, -0.005766}}],
    Polygon[{{1.989212, 0.002334, -0.005040},{1.989436, 0.001644, -0.004190},{
      1.991044, 0.002463, -0.004190},{1.990617, 0.003050, -0.005040}}],
    Polygon[{{1.989436, 0.001644, -0.004190},{1.989617, 0.001088, -0.003236},{
      1.991387, 0.001990, -0.003236},{1.991044, 0.002463, -0.004190}}],
    Polygon[{{1.989617, 0.001088, -0.003236},{1.989749, 0.000681, -0.002203},{
      1.991639, 0.001644, -0.002203},{1.991387, 0.001990, -0.003236}}],
    Polygon[{{1.989749, 0.000681, -0.002203},{1.989830, 0.000432, -0.001115},{
      1.991792, 0.001432, -0.001115},{1.991639, 0.001644, -0.002203}}],
    Polygon[{{1.989830, 0.000432, -0.001115},{1.989857, 0.000349, 0.000000},{
      1.991844, 0.001361, 0.000000},{1.991792, 0.001432, -0.001115}}],
    Polygon[{{1.989857, 0.000349, 0.000000},{1.989830, 0.000432, 0.001115},{
      1.991792, 0.001432, 0.001115},{1.991844, 0.001361, 0.000000}}],
    Polygon[{{1.989830, 0.000432, 0.001115},{1.989749, 0.000681, 0.002203},{
      1.991639, 0.001644, 0.002203},{1.991792, 0.001432, 0.001115}}],
    Polygon[{{1.989749, 0.000681, 0.002203},{1.989617, 0.001088, 0.003236},{
      1.991387, 0.001990, 0.003236},{1.991639, 0.001644, 0.002203}}],
    Polygon[{{1.989617, 0.001088, 0.003236},{1.989436, 0.001644, 0.004190},{
      1.991044, 0.002463, 0.004190},{1.991387, 0.001990, 0.003236}}],
    Polygon[{{1.989436, 0.001644, 0.004190},{1.989212, 0.002334, 0.005040},{
      1.990617, 0.003050, 0.005040},{1.991044, 0.002463, 0.004190}}],
    Polygon[{{1.989212, 0.002334, 0.005040},{1.988949, 0.003143, 0.005766},{
      1.990117, 0.003738, 0.005766},{1.990617, 0.003050, 0.005040}}],
    Polygon[{{1.988949, 0.003143, 0.005766},{1.988654, 0.004050, 0.006351},{
      1.989556, 0.004510, 0.006351},{1.990117, 0.003738, 0.005766}}],
    Polygon[{{1.988654, 0.004050, 0.006351},{1.988335, 0.005033, 0.006779},{
      1.988949, 0.005346, 0.006779},{1.989556, 0.004510, 0.006351}}],
    Polygon[{{1.988335, 0.005033, 0.006779},{1.987999, 0.006067, 0.007040},{
      1.988310, 0.006226, 0.007040},{1.988949, 0.005346, 0.006779}}],
    Polygon[{{1.988310, 0.006226, -0.007040},{1.988949, 0.005346, -0.006779},{
      1.989436, 0.005833, -0.006779},{1.988556, 0.006472, -0.007040}}],
    Polygon[{{1.988949, 0.005346, -0.006779},{1.989556, 0.004510, -0.006351},{
      1.990272, 0.005226, -0.006351},{1.989436, 0.005833, -0.006779}}],
    Polygon[{{1.989556, 0.004510, -0.006351},{1.990117, 0.003738, -0.005766},{
      1.991044, 0.004665, -0.005766},{1.990272, 0.005226, -0.006351}}],
    Polygon[{{1.990117, 0.003738, -0.005766},{1.990617, 0.003050, -0.005040},{
      1.991732, 0.004165, -0.005040},{1.991044, 0.004665, -0.005766}}],
    Polygon[{{1.990617, 0.003050, -0.005040},{1.991044, 0.002463, -0.004190},{
      1.992319, 0.003738, -0.004190},{1.991732, 0.004165, -0.005040}}],
    Polygon[{{1.991044, 0.002463, -0.004190},{1.991387, 0.001990, -0.003236},{
      1.992792, 0.003395, -0.003236},{1.992319, 0.003738, -0.004190}}],
    Polygon[{{1.991387, 0.001990, -0.003236},{1.991639, 0.001644, -0.002203},{
      1.993139, 0.003143, -0.002203},{1.992792, 0.003395, -0.003236}}],
    Polygon[{{1.991639, 0.001644, -0.002203},{1.991792, 0.001432, -0.001115},{
      1.993350, 0.002990, -0.001115},{1.993139, 0.003143, -0.002203}}],
    Polygon[{{1.991792, 0.001432, -0.001115},{1.991844, 0.001361, 0.000000},{
      1.993421, 0.002938, 0.000000},{1.993350, 0.002990, -0.001115}}],
    Polygon[{{1.991844, 0.001361, 0.000000},{1.991792, 0.001432, 0.001115},{
      1.993350, 0.002990, 0.001115},{1.993421, 0.002938, 0.000000}}],
    Polygon[{{1.991792, 0.001432, 0.001115},{1.991639, 0.001644, 0.002203},{
      1.993139, 0.003143, 0.002203},{1.993350, 0.002990, 0.001115}}],
    Polygon[{{1.991639, 0.001644, 0.002203},{1.991387, 0.001990, 0.003236},{
      1.992792, 0.003395, 0.003236},{1.993139, 0.003143, 0.002203}}],
    Polygon[{{1.991387, 0.001990, 0.003236},{1.991044, 0.002463, 0.004190},{
      1.992319, 0.003738, 0.004190},{1.992792, 0.003395, 0.003236}}],
    Polygon[{{1.991044, 0.002463, 0.004190},{1.990617, 0.003050, 0.005040},{
      1.991732, 0.004165, 0.005040},{1.992319, 0.003738, 0.004190}}],
    Polygon[{{1.990617, 0.003050, 0.005040},{1.990117, 0.003738, 0.005766},{
      1.991044, 0.004665, 0.005766},{1.991732, 0.004165, 0.005040}}],
    Polygon[{{1.990117, 0.003738, 0.005766},{1.989556, 0.004510, 0.006351},{
      1.990272, 0.005226, 0.006351},{1.991044, 0.004665, 0.005766}}],
    Polygon[{{1.989556, 0.004510, 0.006351},{1.988949, 0.005346, 0.006779},{
      1.989436, 0.005833, 0.006779},{1.990272, 0.005226, 0.006351}}],
    Polygon[{{1.988949, 0.005346, 0.006779},{1.988310, 0.006226, 0.007040},{
      1.988556, 0.006472, 0.007040},{1.989436, 0.005833, 0.006779}}],
    Polygon[{{1.988556, 0.006472, -0.007040},{1.989436, 0.005833, -0.006779},{
      1.989749, 0.006447, -0.006779},{1.988715, 0.006783, -0.007040}}],
    Polygon[{{1.989436, 0.005833, -0.006779},{1.990272, 0.005226, -0.006351},{
      1.990732, 0.006128, -0.006351},{1.989749, 0.006447, -0.006779}}],
    Polygon[{{1.990272, 0.005226, -0.006351},{1.991044, 0.004665, -0.005766},{
      1.991639, 0.005833, -0.005766},{1.990732, 0.006128, -0.006351}}],
    Polygon[{{1.991044, 0.004665, -0.005766},{1.991732, 0.004165, -0.005040},{
      1.992448, 0.005570, -0.005040},{1.991639, 0.005833, -0.005766}}],
    Polygon[{{1.991732, 0.004165, -0.005040},{1.992319, 0.003738, -0.004190},{
      1.993139, 0.005346, -0.004190},{1.992448, 0.005570, -0.005040}}],
    Polygon[{{1.992319, 0.003738, -0.004190},{1.992792, 0.003395, -0.003236},{
      1.993694, 0.005165, -0.003236},{1.993139, 0.005346, -0.004190}}],
    Polygon[{{1.992792, 0.003395, -0.003236},{1.993139, 0.003143, -0.002203},{
      1.994101, 0.005033, -0.002203},{1.993694, 0.005165, -0.003236}}],
    Polygon[{{1.993139, 0.003143, -0.002203},{1.993350, 0.002990, -0.001115},{
      1.994350, 0.004952, -0.001115},{1.994101, 0.005033, -0.002203}}],
    Polygon[{{1.993350, 0.002990, -0.001115},{1.993421, 0.002938, 0.000000},{
      1.994433, 0.004925, 0.000000},{1.994350, 0.004952, -0.001115}}],
    Polygon[{{1.993421, 0.002938, 0.000000},{1.993350, 0.002990, 0.001115},{
      1.994350, 0.004952, 0.001115},{1.994433, 0.004925, 0.000000}}],
    Polygon[{{1.993350, 0.002990, 0.001115},{1.993139, 0.003143, 0.002203},{
      1.994101, 0.005033, 0.002203},{1.994350, 0.004952, 0.001115}}],
    Polygon[{{1.993139, 0.003143, 0.002203},{1.992792, 0.003395, 0.003236},{
      1.993694, 0.005165, 0.003236},{1.994101, 0.005033, 0.002203}}],
    Polygon[{{1.992792, 0.003395, 0.003236},{1.992319, 0.003738, 0.004190},{
      1.993139, 0.005346, 0.004190},{1.993694, 0.005165, 0.003236}}],
    Polygon[{{1.992319, 0.003738, 0.004190},{1.991732, 0.004165, 0.005040},{
      1.992448, 0.005570, 0.005040},{1.993139, 0.005346, 0.004190}}],
    Polygon[{{1.991732, 0.004165, 0.005040},{1.991044, 0.004665, 0.005766},{
      1.991639, 0.005833, 0.005766},{1.992448, 0.005570, 0.005040}}],
    Polygon[{{1.991044, 0.004665, 0.005766},{1.990272, 0.005226, 0.006351},{
      1.990732, 0.006128, 0.006351},{1.991639, 0.005833, 0.005766}}],
    Polygon[{{1.990272, 0.005226, 0.006351},{1.989436, 0.005833, 0.006779},{
      1.989749, 0.006447, 0.006779},{1.990732, 0.006128, 0.006351}}],
    Polygon[{{1.989436, 0.005833, 0.006779},{1.988556, 0.006472, 0.007040},{
      1.988715, 0.006783, 0.007040},{1.989749, 0.006447, 0.006779}}],
    Polygon[{{1.988715, 0.006783, -0.007040},{1.989749, 0.006447, -0.006779},{
      1.989857, 0.007128, -0.006779},{1.988769, 0.007128, -0.007040}}],
    Polygon[{{1.989749, 0.006447, -0.006779},{1.990732, 0.006128, -0.006351},{
      1.990890, 0.007128, -0.006351},{1.989857, 0.007128, -0.006779}}],
    Polygon[{{1.990732, 0.006128, -0.006351},{1.991639, 0.005833, -0.005766},{
      1.991844, 0.007128, -0.005766},{1.990890, 0.007128, -0.006351}}],
    Polygon[{{1.991639, 0.005833, -0.005766},{1.992448, 0.005570, -0.005040},{
      1.992694, 0.007128, -0.005040},{1.991844, 0.007128, -0.005766}}],
    Polygon[{{1.992448, 0.005570, -0.005040},{1.993139, 0.005346, -0.004190},{
      1.993421, 0.007128, -0.004190},{1.992694, 0.007128, -0.005040}}],
    Polygon[{{1.993139, 0.005346, -0.004190},{1.993694, 0.005165, -0.003236},{
      1.994005, 0.007128, -0.003236},{1.993421, 0.007128, -0.004190}}],
    Polygon[{{1.993694, 0.005165, -0.003236},{1.994101, 0.005033, -0.002203},{
      1.994433, 0.007128, -0.002203},{1.994005, 0.007128, -0.003236}}],
    Polygon[{{1.994101, 0.005033, -0.002203},{1.994350, 0.004952, -0.001115},{
      1.994694, 0.007128, -0.001115},{1.994433, 0.007128, -0.002203}}],
    Polygon[{{1.994350, 0.004952, -0.001115},{1.994433, 0.004925, 0.000000},{
      1.994782, 0.007128, 0.000000},{1.994694, 0.007128, -0.001115}}],
    Polygon[{{1.994433, 0.004925, 0.000000},{1.994350, 0.004952, 0.001115},{
      1.994694, 0.007128, 0.001115},{1.994782, 0.007128, 0.000000}}],
    Polygon[{{1.994350, 0.004952, 0.001115},{1.994101, 0.005033, 0.002203},{
      1.994433, 0.007128, 0.002203},{1.994694, 0.007128, 0.001115}}],
    Polygon[{{1.994101, 0.005033, 0.002203},{1.993694, 0.005165, 0.003236},{
      1.994005, 0.007128, 0.003236},{1.994433, 0.007128, 0.002203}}],
    Polygon[{{1.993694, 0.005165, 0.003236},{1.993139, 0.005346, 0.004190},{
      1.993421, 0.007128, 0.004190},{1.994005, 0.007128, 0.003236}}],
    Polygon[{{1.993139, 0.005346, 0.004190},{1.992448, 0.005570, 0.005040},{
      1.992694, 0.007128, 0.005040},{1.993421, 0.007128, 0.004190}}],
    Polygon[{{1.992448, 0.005570, 0.005040},{1.991639, 0.005833, 0.005766},{
      1.991844, 0.007128, 0.005766},{1.992694, 0.007128, 0.005040}}],
    Polygon[{{1.991639, 0.005833, 0.005766},{1.990732, 0.006128, 0.006351},{
      1.990890, 0.007128, 0.006351},{1.991844, 0.007128, 0.005766}}],
    Polygon[{{1.990732, 0.006128, 0.006351},{1.989749, 0.006447, 0.006779},{
      1.989857, 0.007128, 0.006779},{1.990890, 0.007128, 0.006351}}],
    Polygon[{{1.989749, 0.006447, 0.006779},{1.988715, 0.006783, 0.007040},{
      1.988769, 0.007128, 0.007040},{1.989857, 0.007128, 0.006779}}],
    Polygon[{{1.937194, 0.008594, -0.008489},{1.938506, 0.008594, -0.008174},{
      1.938376, 0.009415, -0.008174},{1.937129, 0.009010, -0.008489}}],
    Polygon[{{1.938506, 0.008594, -0.008174},{1.939752, 0.008594, -0.007658},{
      1.939561, 0.009800, -0.007658},{1.938376, 0.009415, -0.008174}}],
    Polygon[{{1.939752, 0.008594, -0.007658},{1.940902, 0.008594, -0.006953},{
      1.940654, 0.010156, -0.006953},{1.939561, 0.009800, -0.007658}}],
    Polygon[{{1.940902, 0.008594, -0.006953},{1.941927, 0.008594, -0.006077},{
      1.941630, 0.010472, -0.006077},{1.940654, 0.010156, -0.006953}}],
    Polygon[{{1.941927, 0.008594, -0.006077},{1.942803, 0.008594, -0.005052},{
      1.942463, 0.010743, -0.005052},{1.941630, 0.010472, -0.006077}}],
    Polygon[{{1.942803, 0.008594, -0.005052},{1.943508, 0.008594, -0.003902},{
      1.943133, 0.010961, -0.003902},{1.942463, 0.010743, -0.005052}}],
    Polygon[{{1.943508, 0.008594, -0.003902},{1.944024, 0.008594, -0.002656},{
      1.943624, 0.011120, -0.002656},{1.943133, 0.010961, -0.003902}}],
    Polygon[{{1.944024, 0.008594, -0.002656},{1.944339, 0.008594, -0.001344},{
      1.943923, 0.011218, -0.001344},{1.943624, 0.011120, -0.002656}}],
    Polygon[{{1.944339, 0.008594, -0.001344},{1.944444, 0.008594, 0.000000},{
      1.944024, 0.011250, 0.000000},{1.943923, 0.011218, -0.001344}}],
    Polygon[{{1.944444, 0.008594, 0.000000},{1.944339, 0.008594, 0.001344},{
      1.943923, 0.011218, 0.001344},{1.944024, 0.011250, 0.000000}}],
    Polygon[{{1.944339, 0.008594, 0.001344},{1.944024, 0.008594, 0.002656},{
      1.943624, 0.011120, 0.002656},{1.943923, 0.011218, 0.001344}}],
    Polygon[{{1.944024, 0.008594, 0.002656},{1.943508, 0.008594, 0.003902},{
      1.943133, 0.010961, 0.003902},{1.943624, 0.011120, 0.002656}}],
    Polygon[{{1.943508, 0.008594, 0.003902},{1.942803, 0.008594, 0.005052},{
      1.942463, 0.010743, 0.005052},{1.943133, 0.010961, 0.003902}}],
    Polygon[{{1.942803, 0.008594, 0.005052},{1.941927, 0.008594, 0.006077},{
      1.941630, 0.010472, 0.006077},{1.942463, 0.010743, 0.005052}}],
    Polygon[{{1.941927, 0.008594, 0.006077},{1.940902, 0.008594, 0.006953},{
      1.940654, 0.010156, 0.006953},{1.941630, 0.010472, 0.006077}}],
    Polygon[{{1.940902, 0.008594, 0.006953},{1.939752, 0.008594, 0.007658},{
      1.939561, 0.009800, 0.007658},{1.940654, 0.010156, 0.006953}}],
    Polygon[{{1.939752, 0.008594, 0.007658},{1.938506, 0.008594, 0.008174},{
      1.938376, 0.009415, 0.008174},{1.939561, 0.009800, 0.007658}}],
    Polygon[{{1.938506, 0.008594, 0.008174},{1.937194, 0.008594, 0.008489},{
      1.937129, 0.009010, 0.008489},{1.938376, 0.009415, 0.008174}}],
    Polygon[{{1.937129, 0.009010, -0.008489},{1.938376, 0.009415, -0.008174},{
      1.937999, 0.010156, -0.008174},{1.936938, 0.009385, -0.008489}}],
    Polygon[{{1.938376, 0.009415, -0.008174},{1.939561, 0.009800, -0.007658},{
      1.939007, 0.010888, -0.007658},{1.937999, 0.010156, -0.008174}}],
    Polygon[{{1.939561, 0.009800, -0.007658},{1.940654, 0.010156, -0.006953},{
      1.939937, 0.011564, -0.006953},{1.939007, 0.010888, -0.007658}}],
    Polygon[{{1.940654, 0.010156, -0.006953},{1.941630, 0.010472, -0.006077},{
      1.940767, 0.012167, -0.006077},{1.939937, 0.011564, -0.006953}}],
    Polygon[{{1.941630, 0.010472, -0.006077},{1.942463, 0.010743, -0.005052},{
      1.941475, 0.012681, -0.005052},{1.940767, 0.012167, -0.006077}}],
    Polygon[{{1.942463, 0.010743, -0.005052},{1.943133, 0.010961, -0.003902},{
      1.942045, 0.013096, -0.003902},{1.941475, 0.012681, -0.005052}}],
    Polygon[{{1.943133, 0.010961, -0.003902},{1.943624, 0.011120, -0.002656},{
      1.942463, 0.013399, -0.002656},{1.942045, 0.013096, -0.003902}}],
    Polygon[{{1.943624, 0.011120, -0.002656},{1.943923, 0.011218, -0.001344},{
      1.942717, 0.013584, -0.001344},{1.942463, 0.013399, -0.002656}}],
    Polygon[{{1.943923, 0.011218, -0.001344},{1.944024, 0.011250, 0.000000},{
      1.942803, 0.013646, 0.000000},{1.942717, 0.013584, -0.001344}}],
    Polygon[{{1.944024, 0.011250, 0.000000},{1.943923, 0.011218, 0.001344},{
      1.942717, 0.013584, 0.001344},{1.942803, 0.013646, 0.000000}}],
    Polygon[{{1.943923, 0.011218, 0.001344},{1.943624, 0.011120, 0.002656},{
      1.942463, 0.013399, 0.002656},{1.942717, 0.013584, 0.001344}}],
    Polygon[{{1.943624, 0.011120, 0.002656},{1.943133, 0.010961, 0.003902},{
      1.942045, 0.013096, 0.003902},{1.942463, 0.013399, 0.002656}}],
    Polygon[{{1.943133, 0.010961, 0.003902},{1.942463, 0.010743, 0.005052},{
      1.941475, 0.012681, 0.005052},{1.942045, 0.013096, 0.003902}}],
    Polygon[{{1.942463, 0.010743, 0.005052},{1.941630, 0.010472, 0.006077},{
      1.940767, 0.012167, 0.006077},{1.941475, 0.012681, 0.005052}}],
    Polygon[{{1.941630, 0.010472, 0.006077},{1.940654, 0.010156, 0.006953},{
      1.939937, 0.011564, 0.006953},{1.940767, 0.012167, 0.006077}}],
    Polygon[{{1.940654, 0.010156, 0.006953},{1.939561, 0.009800, 0.007658},{
      1.939007, 0.010888, 0.007658},{1.939937, 0.011564, 0.006953}}],
    Polygon[{{1.939561, 0.009800, 0.007658},{1.938376, 0.009415, 0.008174},{
      1.937999, 0.010156, 0.008174},{1.939007, 0.010888, 0.007658}}],
    Polygon[{{1.938376, 0.009415, 0.008174},{1.937129, 0.009010, 0.008489},{
      1.936938, 0.009385, 0.008489},{1.937999, 0.010156, 0.008174}}],
    Polygon[{{1.936938, 0.009385, -0.008489},{1.937999, 0.010156, -0.008174},{
      1.937411, 0.010743, -0.008174},{1.936640, 0.009682, -0.008489}}],
    Polygon[{{1.937999, 0.010156, -0.008174},{1.939007, 0.010888, -0.007658},{
      1.938143, 0.011751, -0.007658},{1.937411, 0.010743, -0.008174}}],
    Polygon[{{1.939007, 0.010888, -0.007658},{1.939937, 0.011564, -0.006953},{
      1.938819, 0.012681, -0.006953},{1.938143, 0.011751, -0.007658}}],
    Polygon[{{1.939937, 0.011564, -0.006953},{1.940767, 0.012167, -0.006077},{
      1.939422, 0.013511, -0.006077},{1.938819, 0.012681, -0.006953}}],
    Polygon[{{1.940767, 0.012167, -0.006077},{1.941475, 0.012681, -0.005052},{
      1.939937, 0.014220, -0.005052},{1.939422, 0.013511, -0.006077}}],
    Polygon[{{1.941475, 0.012681, -0.005052},{1.942045, 0.013096, -0.003902},{
      1.940351, 0.014790, -0.003902},{1.939937, 0.014220, -0.005052}}],
    Polygon[{{1.942045, 0.013096, -0.003902},{1.942463, 0.013399, -0.002656},{
      1.940654, 0.015207, -0.002656},{1.940351, 0.014790, -0.003902}}],
    Polygon[{{1.942463, 0.013399, -0.002656},{1.942717, 0.013584, -0.001344},{
      1.940840, 0.015462, -0.001344},{1.940654, 0.015207, -0.002656}}],
    Polygon[{{1.942717, 0.013584, -0.001344},{1.942803, 0.013646, 0.000000},{
      1.940902, 0.015548, 0.000000},{1.940840, 0.015462, -0.001344}}],
    Polygon[{{1.942803, 0.013646, 0.000000},{1.942717, 0.013584, 0.001344},{
      1.940840, 0.015462, 0.001344},{1.940902, 0.015548, 0.000000}}],
    Polygon[{{1.942717, 0.013584, 0.001344},{1.942463, 0.013399, 0.002656},{
      1.940654, 0.015207, 0.002656},{1.940840, 0.015462, 0.001344}}],
    Polygon[{{1.942463, 0.013399, 0.002656},{1.942045, 0.013096, 0.003902},{
      1.940351, 0.014790, 0.003902},{1.940654, 0.015207, 0.002656}}],
    Polygon[{{1.942045, 0.013096, 0.003902},{1.941475, 0.012681, 0.005052},{
      1.939937, 0.014220, 0.005052},{1.940351, 0.014790, 0.003902}}],
    Polygon[{{1.941475, 0.012681, 0.005052},{1.940767, 0.012167, 0.006077},{
      1.939422, 0.013511, 0.006077},{1.939937, 0.014220, 0.005052}}],
    Polygon[{{1.940767, 0.012167, 0.006077},{1.939937, 0.011564, 0.006953},{
      1.938819, 0.012681, 0.006953},{1.939422, 0.013511, 0.006077}}],
    Polygon[{{1.939937, 0.011564, 0.006953},{1.939007, 0.010888, 0.007658},{
      1.938143, 0.011751, 0.007658},{1.938819, 0.012681, 0.006953}}],
    Polygon[{{1.939007, 0.010888, 0.007658},{1.937999, 0.010156, 0.008174},{
      1.937411, 0.010743, 0.008174},{1.938143, 0.011751, 0.007658}}],
    Polygon[{{1.937999, 0.010156, 0.008174},{1.936938, 0.009385, 0.008489},{
      1.936640, 0.009682, 0.008489},{1.937411, 0.010743, 0.008174}}],
    Polygon[{{1.936640, 0.009682, -0.008489},{1.937411, 0.010743, -0.008174},{
      1.936671, 0.011120, -0.008174},{1.936265, 0.009873, -0.008489}}],
    Polygon[{{1.937411, 0.010743, -0.008174},{1.938143, 0.011751, -0.007658},{
      1.937056, 0.012305, -0.007658},{1.936671, 0.011120, -0.008174}}],
    Polygon[{{1.938143, 0.011751, -0.007658},{1.938819, 0.012681, -0.006953},{
      1.937411, 0.013399, -0.006953},{1.937056, 0.012305, -0.007658}}],
    Polygon[{{1.938819, 0.012681, -0.006953},{1.939422, 0.013511, -0.006077},{
      1.937728, 0.014374, -0.006077},{1.937411, 0.013399, -0.006953}}],
    Polygon[{{1.939422, 0.013511, -0.006077},{1.939937, 0.014220, -0.005052},{
      1.937999, 0.015207, -0.005052},{1.937728, 0.014374, -0.006077}}],
    Polygon[{{1.939937, 0.014220, -0.005052},{1.940351, 0.014790, -0.003902},{
      1.938216, 0.015877, -0.003902},{1.937999, 0.015207, -0.005052}}],
    Polygon[{{1.940351, 0.014790, -0.003902},{1.940654, 0.015207, -0.002656},{
      1.938376, 0.016368, -0.002656},{1.938216, 0.015877, -0.003902}}],
    Polygon[{{1.940654, 0.015207, -0.002656},{1.940840, 0.015462, -0.001344},{
      1.938473, 0.016668, -0.001344},{1.938376, 0.016368, -0.002656}}],
    Polygon[{{1.940840, 0.015462, -0.001344},{1.940902, 0.015548, 0.000000},{
      1.938506, 0.016768, 0.000000},{1.938473, 0.016668, -0.001344}}],
    Polygon[{{1.940902, 0.015548, 0.000000},{1.940840, 0.015462, 0.001344},{
      1.938473, 0.016668, 0.001344},{1.938506, 0.016768, 0.000000}}],
    Polygon[{{1.940840, 0.015462, 0.001344},{1.940654, 0.015207, 0.002656},{
      1.938376, 0.016368, 0.002656},{1.938473, 0.016668, 0.001344}}],
    Polygon[{{1.940654, 0.015207, 0.002656},{1.940351, 0.014790, 0.003902},{
      1.938216, 0.015877, 0.003902},{1.938376, 0.016368, 0.002656}}],
    Polygon[{{1.940351, 0.014790, 0.003902},{1.939937, 0.014220, 0.005052},{
      1.937999, 0.015207, 0.005052},{1.938216, 0.015877, 0.003902}}],
    Polygon[{{1.939937, 0.014220, 0.005052},{1.939422, 0.013511, 0.006077},{
      1.937728, 0.014374, 0.006077},{1.937999, 0.015207, 0.005052}}],
    Polygon[{{1.939422, 0.013511, 0.006077},{1.938819, 0.012681, 0.006953},{
      1.937411, 0.013399, 0.006953},{1.937728, 0.014374, 0.006077}}],
    Polygon[{{1.938819, 0.012681, 0.006953},{1.938143, 0.011751, 0.007658},{
      1.937056, 0.012305, 0.007658},{1.937411, 0.013399, 0.006953}}],
    Polygon[{{1.938143, 0.011751, 0.007658},{1.937411, 0.010743, 0.008174},{
      1.936671, 0.011120, 0.008174},{1.937056, 0.012305, 0.007658}}],
    Polygon[{{1.937411, 0.010743, 0.008174},{1.936640, 0.009682, 0.008489},{
      1.936265, 0.009873, 0.008489},{1.936671, 0.011120, 0.008174}}],
    Polygon[{{1.936265, 0.009873, -0.008489},{1.936671, 0.011120, -0.008174},{
      1.935850, 0.011250, -0.008174},{1.935850, 0.009939, -0.008489}}],
    Polygon[{{1.936671, 0.011120, -0.008174},{1.937056, 0.012305, -0.007658},{
      1.935850, 0.012496, -0.007658},{1.935850, 0.011250, -0.008174}}],
    Polygon[{{1.937056, 0.012305, -0.007658},{1.937411, 0.013399, -0.006953},{
      1.935850, 0.013646, -0.006953},{1.935850, 0.012496, -0.007658}}],
    Polygon[{{1.937411, 0.013399, -0.006953},{1.937728, 0.014374, -0.006077},{
      1.935850, 0.014672, -0.006077},{1.935850, 0.013646, -0.006953}}],
    Polygon[{{1.937728, 0.014374, -0.006077},{1.937999, 0.015207, -0.005052},{
      1.935850, 0.015548, -0.005052},{1.935850, 0.014672, -0.006077}}],
    Polygon[{{1.937999, 0.015207, -0.005052},{1.938216, 0.015877, -0.003902},{
      1.935850, 0.016252, -0.003902},{1.935850, 0.015548, -0.005052}}],
    Polygon[{{1.938216, 0.015877, -0.003902},{1.938376, 0.016368, -0.002656},{
      1.935850, 0.016768, -0.002656},{1.935850, 0.016252, -0.003902}}],
    Polygon[{{1.938376, 0.016368, -0.002656},{1.938473, 0.016668, -0.001344},{
      1.935850, 0.017083, -0.001344},{1.935850, 0.016768, -0.002656}}],
    Polygon[{{1.938473, 0.016668, -0.001344},{1.938506, 0.016768, 0.000000},{
      1.935850, 0.017189, 0.000000},{1.935850, 0.017083, -0.001344}}],
    Polygon[{{1.938506, 0.016768, 0.000000},{1.938473, 0.016668, 0.001344},{
      1.935850, 0.017083, 0.001344},{1.935850, 0.017189, 0.000000}}],
    Polygon[{{1.938473, 0.016668, 0.001344},{1.938376, 0.016368, 0.002656},{
      1.935850, 0.016768, 0.002656},{1.935850, 0.017083, 0.001344}}],
    Polygon[{{1.938376, 0.016368, 0.002656},{1.938216, 0.015877, 0.003902},{
      1.935850, 0.016252, 0.003902},{1.935850, 0.016768, 0.002656}}],
    Polygon[{{1.938216, 0.015877, 0.003902},{1.937999, 0.015207, 0.005052},{
      1.935850, 0.015548, 0.005052},{1.935850, 0.016252, 0.003902}}],
    Polygon[{{1.937999, 0.015207, 0.005052},{1.937728, 0.014374, 0.006077},{
      1.935850, 0.014672, 0.006077},{1.935850, 0.015548, 0.005052}}],
    Polygon[{{1.937728, 0.014374, 0.006077},{1.937411, 0.013399, 0.006953},{
      1.935850, 0.013646, 0.006953},{1.935850, 0.014672, 0.006077}}],
    Polygon[{{1.937411, 0.013399, 0.006953},{1.937056, 0.012305, 0.007658},{
      1.935850, 0.012496, 0.007658},{1.935850, 0.013646, 0.006953}}],
    Polygon[{{1.937056, 0.012305, 0.007658},{1.936671, 0.011120, 0.008174},{
      1.935850, 0.011250, 0.008174},{1.935850, 0.012496, 0.007658}}],
    Polygon[{{1.936671, 0.011120, 0.008174},{1.936265, 0.009873, 0.008489},{
      1.935850, 0.009939, 0.008489},{1.935850, 0.011250, 0.008174}}],
    Polygon[{{1.935850, 0.009939, -0.008489},{1.935850, 0.011250, -0.008174},{
      1.935029, 0.011120, -0.008174},{1.935434, 0.009873, -0.008489}}],
    Polygon[{{1.935850, 0.011250, -0.008174},{1.935850, 0.012496, -0.007658},{
      1.934644, 0.012305, -0.007658},{1.935029, 0.011120, -0.008174}}],
    Polygon[{{1.935850, 0.012496, -0.007658},{1.935850, 0.013646, -0.006953},{
      1.934289, 0.013399, -0.006953},{1.934644, 0.012305, -0.007658}}],
    Polygon[{{1.935850, 0.013646, -0.006953},{1.935850, 0.014672, -0.006077},{
      1.933972, 0.014374, -0.006077},{1.934289, 0.013399, -0.006953}}],
    Polygon[{{1.935850, 0.014672, -0.006077},{1.935850, 0.015548, -0.005052},{
      1.933701, 0.015207, -0.005052},{1.933972, 0.014374, -0.006077}}],
    Polygon[{{1.935850, 0.015548, -0.005052},{1.935850, 0.016252, -0.003902},{
      1.933484, 0.015877, -0.003902},{1.933701, 0.015207, -0.005052}}],
    Polygon[{{1.935850, 0.016252, -0.003902},{1.935850, 0.016768, -0.002656},{
      1.933324, 0.016368, -0.002656},{1.933484, 0.015877, -0.003902}}],
    Polygon[{{1.935850, 0.016768, -0.002656},{1.935850, 0.017083, -0.001344},{
      1.933227, 0.016668, -0.001344},{1.933324, 0.016368, -0.002656}}],
    Polygon[{{1.935850, 0.017083, -0.001344},{1.935850, 0.017189, 0.000000},{
      1.933194, 0.016768, 0.000000},{1.933227, 0.016668, -0.001344}}],
    Polygon[{{1.935850, 0.017189, 0.000000},{1.935850, 0.017083, 0.001344},{
      1.933227, 0.016668, 0.001344},{1.933194, 0.016768, 0.000000}}],
    Polygon[{{1.935850, 0.017083, 0.001344},{1.935850, 0.016768, 0.002656},{
      1.933324, 0.016368, 0.002656},{1.933227, 0.016668, 0.001344}}],
    Polygon[{{1.935850, 0.016768, 0.002656},{1.935850, 0.016252, 0.003902},{
      1.933484, 0.015877, 0.003902},{1.933324, 0.016368, 0.002656}}],
    Polygon[{{1.935850, 0.016252, 0.003902},{1.935850, 0.015548, 0.005052},{
      1.933701, 0.015207, 0.005052},{1.933484, 0.015877, 0.003902}}],
    Polygon[{{1.935850, 0.015548, 0.005052},{1.935850, 0.014672, 0.006077},{
      1.933972, 0.014374, 0.006077},{1.933701, 0.015207, 0.005052}}],
    Polygon[{{1.935850, 0.014672, 0.006077},{1.935850, 0.013646, 0.006953},{
      1.934289, 0.013399, 0.006953},{1.933972, 0.014374, 0.006077}}],
    Polygon[{{1.935850, 0.013646, 0.006953},{1.935850, 0.012496, 0.007658},{
      1.934644, 0.012305, 0.007658},{1.934289, 0.013399, 0.006953}}],
    Polygon[{{1.935850, 0.012496, 0.007658},{1.935850, 0.011250, 0.008174},{
      1.935029, 0.011120, 0.008174},{1.934644, 0.012305, 0.007658}}],
    Polygon[{{1.935850, 0.011250, 0.008174},{1.935850, 0.009939, 0.008489},{
      1.935434, 0.009873, 0.008489},{1.935029, 0.011120, 0.008174}}],
    Polygon[{{1.935434, 0.009873, -0.008489},{1.935029, 0.011120, -0.008174},{
      1.934289, 0.010743, -0.008174},{1.935060, 0.009682, -0.008489}}],
    Polygon[{{1.935029, 0.011120, -0.008174},{1.934644, 0.012305, -0.007658},{
      1.933557, 0.011751, -0.007658},{1.934289, 0.010743, -0.008174}}],
    Polygon[{{1.934644, 0.012305, -0.007658},{1.934289, 0.013399, -0.006953},{
      1.932881, 0.012681, -0.006953},{1.933557, 0.011751, -0.007658}}],
    Polygon[{{1.934289, 0.013399, -0.006953},{1.933972, 0.014374, -0.006077},{
      1.932278, 0.013511, -0.006077},{1.932881, 0.012681, -0.006953}}],
    Polygon[{{1.933972, 0.014374, -0.006077},{1.933701, 0.015207, -0.005052},{
      1.931763, 0.014220, -0.005052},{1.932278, 0.013511, -0.006077}}],
    Polygon[{{1.933701, 0.015207, -0.005052},{1.933484, 0.015877, -0.003902},{
      1.931349, 0.014790, -0.003902},{1.931763, 0.014220, -0.005052}}],
    Polygon[{{1.933484, 0.015877, -0.003902},{1.933324, 0.016368, -0.002656},{
      1.931046, 0.015207, -0.002656},{1.931349, 0.014790, -0.003902}}],
    Polygon[{{1.933324, 0.016368, -0.002656},{1.933227, 0.016668, -0.001344},{
      1.930860, 0.015462, -0.001344},{1.931046, 0.015207, -0.002656}}],
    Polygon[{{1.933227, 0.016668, -0.001344},{1.933194, 0.016768, 0.000000},{
      1.930798, 0.015548, 0.000000},{1.930860, 0.015462, -0.001344}}],
    Polygon[{{1.933194, 0.016768, 0.000000},{1.933227, 0.016668, 0.001344},{
      1.930860, 0.015462, 0.001344},{1.930798, 0.015548, 0.000000}}],
    Polygon[{{1.933227, 0.016668, 0.001344},{1.933324, 0.016368, 0.002656},{
      1.931046, 0.015207, 0.002656},{1.930860, 0.015462, 0.001344}}],
    Polygon[{{1.933324, 0.016368, 0.002656},{1.933484, 0.015877, 0.003902},{
      1.931349, 0.014790, 0.003902},{1.931046, 0.015207, 0.002656}}],
    Polygon[{{1.933484, 0.015877, 0.003902},{1.933701, 0.015207, 0.005052},{
      1.931763, 0.014220, 0.005052},{1.931349, 0.014790, 0.003902}}],
    Polygon[{{1.933701, 0.015207, 0.005052},{1.933972, 0.014374, 0.006077},{
      1.932278, 0.013511, 0.006077},{1.931763, 0.014220, 0.005052}}],
    Polygon[{{1.933972, 0.014374, 0.006077},{1.934289, 0.013399, 0.006953},{
      1.932881, 0.012681, 0.006953},{1.932278, 0.013511, 0.006077}}],
    Polygon[{{1.934289, 0.013399, 0.006953},{1.934644, 0.012305, 0.007658},{
      1.933557, 0.011751, 0.007658},{1.932881, 0.012681, 0.006953}}],
    Polygon[{{1.934644, 0.012305, 0.007658},{1.935029, 0.011120, 0.008174},{
      1.934289, 0.010743, 0.008174},{1.933557, 0.011751, 0.007658}}],
    Polygon[{{1.935029, 0.011120, 0.008174},{1.935434, 0.009873, 0.008489},{
      1.935060, 0.009682, 0.008489},{1.934289, 0.010743, 0.008174}}],
    Polygon[{{1.935060, 0.009682, -0.008489},{1.934289, 0.010743, -0.008174},{
      1.933701, 0.010156, -0.008174},{1.934762, 0.009385, -0.008489}}],
    Polygon[{{1.934289, 0.010743, -0.008174},{1.933557, 0.011751, -0.007658},{
      1.932693, 0.010888, -0.007658},{1.933701, 0.010156, -0.008174}}],
    Polygon[{{1.933557, 0.011751, -0.007658},{1.932881, 0.012681, -0.006953},{
      1.931763, 0.011564, -0.006953},{1.932693, 0.010888, -0.007658}}],
    Polygon[{{1.932881, 0.012681, -0.006953},{1.932278, 0.013511, -0.006077},{
      1.930933, 0.012167, -0.006077},{1.931763, 0.011564, -0.006953}}],
    Polygon[{{1.932278, 0.013511, -0.006077},{1.931763, 0.014220, -0.005052},{
      1.930225, 0.012681, -0.005052},{1.930933, 0.012167, -0.006077}}],
    Polygon[{{1.931763, 0.014220, -0.005052},{1.931349, 0.014790, -0.003902},{
      1.929655, 0.013096, -0.003902},{1.930225, 0.012681, -0.005052}}],
    Polygon[{{1.931349, 0.014790, -0.003902},{1.931046, 0.015207, -0.002656},{
      1.929237, 0.013399, -0.002656},{1.929655, 0.013096, -0.003902}}],
    Polygon[{{1.931046, 0.015207, -0.002656},{1.930860, 0.015462, -0.001344},{
      1.928982, 0.013584, -0.001344},{1.929237, 0.013399, -0.002656}}],
    Polygon[{{1.930860, 0.015462, -0.001344},{1.930798, 0.015548, 0.000000},{
      1.928897, 0.013646, 0.000000},{1.928982, 0.013584, -0.001344}}],
    Polygon[{{1.930798, 0.015548, 0.000000},{1.930860, 0.015462, 0.001344},{
      1.928982, 0.013584, 0.001344},{1.928897, 0.013646, 0.000000}}],
    Polygon[{{1.930860, 0.015462, 0.001344},{1.931046, 0.015207, 0.002656},{
      1.929237, 0.013399, 0.002656},{1.928982, 0.013584, 0.001344}}],
    Polygon[{{1.931046, 0.015207, 0.002656},{1.931349, 0.014790, 0.003902},{
      1.929655, 0.013096, 0.003902},{1.929237, 0.013399, 0.002656}}],
    Polygon[{{1.931349, 0.014790, 0.003902},{1.931763, 0.014220, 0.005052},{
      1.930225, 0.012681, 0.005052},{1.929655, 0.013096, 0.003902}}],
    Polygon[{{1.931763, 0.014220, 0.005052},{1.932278, 0.013511, 0.006077},{
      1.930933, 0.012167, 0.006077},{1.930225, 0.012681, 0.005052}}],
    Polygon[{{1.932278, 0.013511, 0.006077},{1.932881, 0.012681, 0.006953},{
      1.931763, 0.011564, 0.006953},{1.930933, 0.012167, 0.006077}}],
    Polygon[{{1.932881, 0.012681, 0.006953},{1.933557, 0.011751, 0.007658},{
      1.932693, 0.010888, 0.007658},{1.931763, 0.011564, 0.006953}}],
    Polygon[{{1.933557, 0.011751, 0.007658},{1.934289, 0.010743, 0.008174},{
      1.933701, 0.010156, 0.008174},{1.932693, 0.010888, 0.007658}}],
    Polygon[{{1.934289, 0.010743, 0.008174},{1.935060, 0.009682, 0.008489},{
      1.934762, 0.009385, 0.008489},{1.933701, 0.010156, 0.008174}}],
    Polygon[{{1.934762, 0.009385, -0.008489},{1.933701, 0.010156, -0.008174},{
      1.933324, 0.009415, -0.008174},{1.934571, 0.009010, -0.008489}}],
    Polygon[{{1.933701, 0.010156, -0.008174},{1.932693, 0.010888, -0.007658},{
      1.932139, 0.009800, -0.007658},{1.933324, 0.009415, -0.008174}}],
    Polygon[{{1.932693, 0.010888, -0.007658},{1.931763, 0.011564, -0.006953},{
      1.931046, 0.010156, -0.006953},{1.932139, 0.009800, -0.007658}}],
    Polygon[{{1.931763, 0.011564, -0.006953},{1.930933, 0.012167, -0.006077},{
      1.930070, 0.010472, -0.006077},{1.931046, 0.010156, -0.006953}}],
    Polygon[{{1.930933, 0.012167, -0.006077},{1.930225, 0.012681, -0.005052},{
      1.929237, 0.010743, -0.005052},{1.930070, 0.010472, -0.006077}}],
    Polygon[{{1.930225, 0.012681, -0.005052},{1.929655, 0.013096, -0.003902},{
      1.928567, 0.010961, -0.003902},{1.929237, 0.010743, -0.005052}}],
    Polygon[{{1.929655, 0.013096, -0.003902},{1.929237, 0.013399, -0.002656},{
      1.928076, 0.011120, -0.002656},{1.928567, 0.010961, -0.003902}}],
    Polygon[{{1.929237, 0.013399, -0.002656},{1.928982, 0.013584, -0.001344},{
      1.927777, 0.011218, -0.001344},{1.928076, 0.011120, -0.002656}}],
    Polygon[{{1.928982, 0.013584, -0.001344},{1.928897, 0.013646, 0.000000},{
      1.927676, 0.011250, 0.000000},{1.927777, 0.011218, -0.001344}}],
    Polygon[{{1.928897, 0.013646, 0.000000},{1.928982, 0.013584, 0.001344},{
      1.927777, 0.011218, 0.001344},{1.927676, 0.011250, 0.000000}}],
    Polygon[{{1.928982, 0.013584, 0.001344},{1.929237, 0.013399, 0.002656},{
      1.928076, 0.011120, 0.002656},{1.927777, 0.011218, 0.001344}}],
    Polygon[{{1.929237, 0.013399, 0.002656},{1.929655, 0.013096, 0.003902},{
      1.928567, 0.010961, 0.003902},{1.928076, 0.011120, 0.002656}}],
    Polygon[{{1.929655, 0.013096, 0.003902},{1.930225, 0.012681, 0.005052},{
      1.929237, 0.010743, 0.005052},{1.928567, 0.010961, 0.003902}}],
    Polygon[{{1.930225, 0.012681, 0.005052},{1.930933, 0.012167, 0.006077},{
      1.930070, 0.010472, 0.006077},{1.929237, 0.010743, 0.005052}}],
    Polygon[{{1.930933, 0.012167, 0.006077},{1.931763, 0.011564, 0.006953},{
      1.931046, 0.010156, 0.006953},{1.930070, 0.010472, 0.006077}}],
    Polygon[{{1.931763, 0.011564, 0.006953},{1.932693, 0.010888, 0.007658},{
      1.932139, 0.009800, 0.007658},{1.931046, 0.010156, 0.006953}}],
    Polygon[{{1.932693, 0.010888, 0.007658},{1.933701, 0.010156, 0.008174},{
      1.933324, 0.009415, 0.008174},{1.932139, 0.009800, 0.007658}}],
    Polygon[{{1.933701, 0.010156, 0.008174},{1.934762, 0.009385, 0.008489},{
      1.934571, 0.009010, 0.008489},{1.933324, 0.009415, 0.008174}}],
    Polygon[{{1.934571, 0.009010, -0.008489},{1.933324, 0.009415, -0.008174},{
      1.933194, 0.008594, -0.008174},{1.934505, 0.008594, -0.008489}}],
    Polygon[{{1.933324, 0.009415, -0.008174},{1.932139, 0.009800, -0.007658},{
      1.931948, 0.008594, -0.007658},{1.933194, 0.008594, -0.008174}}],
    Polygon[{{1.932139, 0.009800, -0.007658},{1.931046, 0.010156, -0.006953},{
      1.930798, 0.008594, -0.006953},{1.931948, 0.008594, -0.007658}}],
    Polygon[{{1.931046, 0.010156, -0.006953},{1.930070, 0.010472, -0.006077},{
      1.929773, 0.008594, -0.006077},{1.930798, 0.008594, -0.006953}}],
    Polygon[{{1.930070, 0.010472, -0.006077},{1.929237, 0.010743, -0.005052},{
      1.928897, 0.008594, -0.005052},{1.929773, 0.008594, -0.006077}}],
    Polygon[{{1.929237, 0.010743, -0.005052},{1.928567, 0.010961, -0.003902},{
      1.928192, 0.008594, -0.003902},{1.928897, 0.008594, -0.005052}}],
    Polygon[{{1.928567, 0.010961, -0.003902},{1.928076, 0.011120, -0.002656},{
      1.927676, 0.008594, -0.002656},{1.928192, 0.008594, -0.003902}}],
    Polygon[{{1.928076, 0.011120, -0.002656},{1.927777, 0.011218, -0.001344},{
      1.927361, 0.008594, -0.001344},{1.927676, 0.008594, -0.002656}}],
    Polygon[{{1.927777, 0.011218, -0.001344},{1.927676, 0.011250, 0.000000},{
      1.927256, 0.008594, 0.000000},{1.927361, 0.008594, -0.001344}}],
    Polygon[{{1.927676, 0.011250, 0.000000},{1.927777, 0.011218, 0.001344},{
      1.927361, 0.008594, 0.001344},{1.927256, 0.008594, 0.000000}}],
    Polygon[{{1.927777, 0.011218, 0.001344},{1.928076, 0.011120, 0.002656},{
      1.927676, 0.008594, 0.002656},{1.927361, 0.008594, 0.001344}}],
    Polygon[{{1.928076, 0.011120, 0.002656},{1.928567, 0.010961, 0.003902},{
      1.928192, 0.008594, 0.003902},{1.927676, 0.008594, 0.002656}}],
    Polygon[{{1.928567, 0.010961, 0.003902},{1.929237, 0.010743, 0.005052},{
      1.928897, 0.008594, 0.005052},{1.928192, 0.008594, 0.003902}}],
    Polygon[{{1.929237, 0.010743, 0.005052},{1.930070, 0.010472, 0.006077},{
      1.929773, 0.008594, 0.006077},{1.928897, 0.008594, 0.005052}}],
    Polygon[{{1.930070, 0.010472, 0.006077},{1.931046, 0.010156, 0.006953},{
      1.930798, 0.008594, 0.006953},{1.929773, 0.008594, 0.006077}}],
    Polygon[{{1.931046, 0.010156, 0.006953},{1.932139, 0.009800, 0.007658},{
      1.931948, 0.008594, 0.007658},{1.930798, 0.008594, 0.006953}}],
    Polygon[{{1.932139, 0.009800, 0.007658},{1.933324, 0.009415, 0.008174},{
      1.933194, 0.008594, 0.008174},{1.931948, 0.008594, 0.007658}}],
    Polygon[{{1.933324, 0.009415, 0.008174},{1.934571, 0.009010, 0.008489},{
      1.934505, 0.008594, 0.008489},{1.933194, 0.008594, 0.008174}}],
    Polygon[{{1.934505, 0.008594, -0.008489},{1.933194, 0.008594, -0.008174},{
      1.933324, 0.007774, -0.008174},{1.934571, 0.008179, -0.008489}}],
    Polygon[{{1.933194, 0.008594, -0.008174},{1.931948, 0.008594, -0.007658},{
      1.932139, 0.007389, -0.007658},{1.933324, 0.007774, -0.008174}}],
    Polygon[{{1.931948, 0.008594, -0.007658},{1.930798, 0.008594, -0.006953},{
      1.931046, 0.007033, -0.006953},{1.932139, 0.007389, -0.007658}}],
    Polygon[{{1.930798, 0.008594, -0.006953},{1.929773, 0.008594, -0.006077},{
      1.930070, 0.006717, -0.006077},{1.931046, 0.007033, -0.006953}}],
    Polygon[{{1.929773, 0.008594, -0.006077},{1.928897, 0.008594, -0.005052},{
      1.929237, 0.006446, -0.005052},{1.930070, 0.006717, -0.006077}}],
    Polygon[{{1.928897, 0.008594, -0.005052},{1.928192, 0.008594, -0.003902},{
      1.928567, 0.006228, -0.003902},{1.929237, 0.006446, -0.005052}}],
    Polygon[{{1.928192, 0.008594, -0.003902},{1.927676, 0.008594, -0.002656},{
      1.928076, 0.006069, -0.002656},{1.928567, 0.006228, -0.003902}}],
    Polygon[{{1.927676, 0.008594, -0.002656},{1.927361, 0.008594, -0.001344},{
      1.927777, 0.005971, -0.001344},{1.928076, 0.006069, -0.002656}}],
    Polygon[{{1.927361, 0.008594, -0.001344},{1.927256, 0.008594, 0.000000},{
      1.927676, 0.005939, 0.000000},{1.927777, 0.005971, -0.001344}}],
    Polygon[{{1.927256, 0.008594, 0.000000},{1.927361, 0.008594, 0.001344},{
      1.927777, 0.005971, 0.001344},{1.927676, 0.005939, 0.000000}}],
    Polygon[{{1.927361, 0.008594, 0.001344},{1.927676, 0.008594, 0.002656},{
      1.928076, 0.006069, 0.002656},{1.927777, 0.005971, 0.001344}}],
    Polygon[{{1.927676, 0.008594, 0.002656},{1.928192, 0.008594, 0.003902},{
      1.928567, 0.006228, 0.003902},{1.928076, 0.006069, 0.002656}}],
    Polygon[{{1.928192, 0.008594, 0.003902},{1.928897, 0.008594, 0.005052},{
      1.929237, 0.006446, 0.005052},{1.928567, 0.006228, 0.003902}}],
    Polygon[{{1.928897, 0.008594, 0.005052},{1.929773, 0.008594, 0.006077},{
      1.930070, 0.006717, 0.006077},{1.929237, 0.006446, 0.005052}}],
    Polygon[{{1.929773, 0.008594, 0.006077},{1.930798, 0.008594, 0.006953},{
      1.931046, 0.007033, 0.006953},{1.930070, 0.006717, 0.006077}}],
    Polygon[{{1.930798, 0.008594, 0.006953},{1.931948, 0.008594, 0.007658},{
      1.932139, 0.007389, 0.007658},{1.931046, 0.007033, 0.006953}}],
    Polygon[{{1.931948, 0.008594, 0.007658},{1.933194, 0.008594, 0.008174},{
      1.933324, 0.007774, 0.008174},{1.932139, 0.007389, 0.007658}}],
    Polygon[{{1.933194, 0.008594, 0.008174},{1.934505, 0.008594, 0.008489},{
      1.934571, 0.008179, 0.008489},{1.933324, 0.007774, 0.008174}}],
    Polygon[{{1.934571, 0.008179, -0.008489},{1.933324, 0.007774, -0.008174},{
      1.933701, 0.007033, -0.008174},{1.934762, 0.007804, -0.008489}}],
    Polygon[{{1.933324, 0.007774, -0.008174},{1.932139, 0.007389, -0.007658},{
      1.932693, 0.006301, -0.007658},{1.933701, 0.007033, -0.008174}}],
    Polygon[{{1.932139, 0.007389, -0.007658},{1.931046, 0.007033, -0.006953},{
      1.931763, 0.005625, -0.006953},{1.932693, 0.006301, -0.007658}}],
    Polygon[{{1.931046, 0.007033, -0.006953},{1.930070, 0.006717, -0.006077},{
      1.930933, 0.005022, -0.006077},{1.931763, 0.005625, -0.006953}}],
    Polygon[{{1.930070, 0.006717, -0.006077},{1.929237, 0.006446, -0.005052},{
      1.930225, 0.004508, -0.005052},{1.930933, 0.005022, -0.006077}}],
    Polygon[{{1.929237, 0.006446, -0.005052},{1.928567, 0.006228, -0.003902},{
      1.929655, 0.004093, -0.003902},{1.930225, 0.004508, -0.005052}}],
    Polygon[{{1.928567, 0.006228, -0.003902},{1.928076, 0.006069, -0.002656},{
      1.929237, 0.003790, -0.002656},{1.929655, 0.004093, -0.003902}}],
    Polygon[{{1.928076, 0.006069, -0.002656},{1.927777, 0.005971, -0.001344},{
      1.928982, 0.003605, -0.001344},{1.929237, 0.003790, -0.002656}}],
    Polygon[{{1.927777, 0.005971, -0.001344},{1.927676, 0.005939, 0.000000},{
      1.928897, 0.003543, 0.000000},{1.928982, 0.003605, -0.001344}}],
    Polygon[{{1.927676, 0.005939, 0.000000},{1.927777, 0.005971, 0.001344},{
      1.928982, 0.003605, 0.001344},{1.928897, 0.003543, 0.000000}}],
    Polygon[{{1.927777, 0.005971, 0.001344},{1.928076, 0.006069, 0.002656},{
      1.929237, 0.003790, 0.002656},{1.928982, 0.003605, 0.001344}}],
    Polygon[{{1.928076, 0.006069, 0.002656},{1.928567, 0.006228, 0.003902},{
      1.929655, 0.004093, 0.003902},{1.929237, 0.003790, 0.002656}}],
    Polygon[{{1.928567, 0.006228, 0.003902},{1.929237, 0.006446, 0.005052},{
      1.930225, 0.004508, 0.005052},{1.929655, 0.004093, 0.003902}}],
    Polygon[{{1.929237, 0.006446, 0.005052},{1.930070, 0.006717, 0.006077},{
      1.930933, 0.005022, 0.006077},{1.930225, 0.004508, 0.005052}}],
    Polygon[{{1.930070, 0.006717, 0.006077},{1.931046, 0.007033, 0.006953},{
      1.931763, 0.005625, 0.006953},{1.930933, 0.005022, 0.006077}}],
    Polygon[{{1.931046, 0.007033, 0.006953},{1.932139, 0.007389, 0.007658},{
      1.932693, 0.006301, 0.007658},{1.931763, 0.005625, 0.006953}}],
    Polygon[{{1.932139, 0.007389, 0.007658},{1.933324, 0.007774, 0.008174},{
      1.933701, 0.007033, 0.008174},{1.932693, 0.006301, 0.007658}}],
    Polygon[{{1.933324, 0.007774, 0.008174},{1.934571, 0.008179, 0.008489},{
      1.934762, 0.007804, 0.008489},{1.933701, 0.007033, 0.008174}}],
    Polygon[{{1.934762, 0.007804, -0.008489},{1.933701, 0.007033, -0.008174},{
      1.934289, 0.006446, -0.008174},{1.935060, 0.007507, -0.008489}}],
    Polygon[{{1.933701, 0.007033, -0.008174},{1.932693, 0.006301, -0.007658},{
      1.933557, 0.005438, -0.007658},{1.934289, 0.006446, -0.008174}}],
    Polygon[{{1.932693, 0.006301, -0.007658},{1.931763, 0.005625, -0.006953},{
      1.932881, 0.004508, -0.006953},{1.933557, 0.005438, -0.007658}}],
    Polygon[{{1.931763, 0.005625, -0.006953},{1.930933, 0.005022, -0.006077},{
      1.932278, 0.003678, -0.006077},{1.932881, 0.004508, -0.006953}}],
    Polygon[{{1.930933, 0.005022, -0.006077},{1.930225, 0.004508, -0.005052},{
      1.931763, 0.002969, -0.005052},{1.932278, 0.003678, -0.006077}}],
    Polygon[{{1.930225, 0.004508, -0.005052},{1.929655, 0.004093, -0.003902},{
      1.931349, 0.002399, -0.003902},{1.931763, 0.002969, -0.005052}}],
    Polygon[{{1.929655, 0.004093, -0.003902},{1.929237, 0.003790, -0.002656},{
      1.931046, 0.001982, -0.002656},{1.931349, 0.002399, -0.003902}}],
    Polygon[{{1.929237, 0.003790, -0.002656},{1.928982, 0.003605, -0.001344},{
      1.930860, 0.001727, -0.001344},{1.931046, 0.001982, -0.002656}}],
    Polygon[{{1.928982, 0.003605, -0.001344},{1.928897, 0.003543, 0.000000},{
      1.930798, 0.001641, 0.000000},{1.930860, 0.001727, -0.001344}}],
    Polygon[{{1.928897, 0.003543, 0.000000},{1.928982, 0.003605, 0.001344},{
      1.930860, 0.001727, 0.001344},{1.930798, 0.001641, 0.000000}}],
    Polygon[{{1.928982, 0.003605, 0.001344},{1.929237, 0.003790, 0.002656},{
      1.931046, 0.001982, 0.002656},{1.930860, 0.001727, 0.001344}}],
    Polygon[{{1.929237, 0.003790, 0.002656},{1.929655, 0.004093, 0.003902},{
      1.931349, 0.002399, 0.003902},{1.931046, 0.001982, 0.002656}}],
    Polygon[{{1.929655, 0.004093, 0.003902},{1.930225, 0.004508, 0.005052},{
      1.931763, 0.002969, 0.005052},{1.931349, 0.002399, 0.003902}}],
    Polygon[{{1.930225, 0.004508, 0.005052},{1.930933, 0.005022, 0.006077},{
      1.932278, 0.003678, 0.006077},{1.931763, 0.002969, 0.005052}}],
    Polygon[{{1.930933, 0.005022, 0.006077},{1.931763, 0.005625, 0.006953},{
      1.932881, 0.004508, 0.006953},{1.932278, 0.003678, 0.006077}}],
    Polygon[{{1.931763, 0.005625, 0.006953},{1.932693, 0.006301, 0.007658},{
      1.933557, 0.005438, 0.007658},{1.932881, 0.004508, 0.006953}}],
    Polygon[{{1.932693, 0.006301, 0.007658},{1.933701, 0.007033, 0.008174},{
      1.934289, 0.006446, 0.008174},{1.933557, 0.005438, 0.007658}}],
    Polygon[{{1.933701, 0.007033, 0.008174},{1.934762, 0.007804, 0.008489},{
      1.935060, 0.007507, 0.008489},{1.934289, 0.006446, 0.008174}}],
    Polygon[{{1.935060, 0.007507, -0.008489},{1.934289, 0.006446, -0.008174},{
      1.935029, 0.006069, -0.008174},{1.935434, 0.007316, -0.008489}}],
    Polygon[{{1.934289, 0.006446, -0.008174},{1.933557, 0.005438, -0.007658},{
      1.934644, 0.004884, -0.007658},{1.935029, 0.006069, -0.008174}}],
    Polygon[{{1.933557, 0.005438, -0.007658},{1.932881, 0.004508, -0.006953},{
      1.934289, 0.003790, -0.006953},{1.934644, 0.004884, -0.007658}}],
    Polygon[{{1.932881, 0.004508, -0.006953},{1.932278, 0.003678, -0.006077},{
      1.933972, 0.002815, -0.006077},{1.934289, 0.003790, -0.006953}}],
    Polygon[{{1.932278, 0.003678, -0.006077},{1.931763, 0.002969, -0.005052},{
      1.933701, 0.001982, -0.005052},{1.933972, 0.002815, -0.006077}}],
    Polygon[{{1.931763, 0.002969, -0.005052},{1.931349, 0.002399, -0.003902},{
      1.933484, 0.001312, -0.003902},{1.933701, 0.001982, -0.005052}}],
    Polygon[{{1.931349, 0.002399, -0.003902},{1.931046, 0.001982, -0.002656},{
      1.933324, 0.000821, -0.002656},{1.933484, 0.001312, -0.003902}}],
    Polygon[{{1.931046, 0.001982, -0.002656},{1.930860, 0.001727, -0.001344},{
      1.933227, 0.000521, -0.001344},{1.933324, 0.000821, -0.002656}}],
    Polygon[{{1.930860, 0.001727, -0.001344},{1.930798, 0.001641, 0.000000},{
      1.933194, 0.000421, 0.000000},{1.933227, 0.000521, -0.001344}}],
    Polygon[{{1.930798, 0.001641, 0.000000},{1.930860, 0.001727, 0.001344},{
      1.933227, 0.000521, 0.001344},{1.933194, 0.000421, 0.000000}}],
    Polygon[{{1.930860, 0.001727, 0.001344},{1.931046, 0.001982, 0.002656},{
      1.933324, 0.000821, 0.002656},{1.933227, 0.000521, 0.001344}}],
    Polygon[{{1.931046, 0.001982, 0.002656},{1.931349, 0.002399, 0.003902},{
      1.933484, 0.001312, 0.003902},{1.933324, 0.000821, 0.002656}}],
    Polygon[{{1.931349, 0.002399, 0.003902},{1.931763, 0.002969, 0.005052},{
      1.933701, 0.001982, 0.005052},{1.933484, 0.001312, 0.003902}}],
    Polygon[{{1.931763, 0.002969, 0.005052},{1.932278, 0.003678, 0.006077},{
      1.933972, 0.002815, 0.006077},{1.933701, 0.001982, 0.005052}}],
    Polygon[{{1.932278, 0.003678, 0.006077},{1.932881, 0.004508, 0.006953},{
      1.934289, 0.003790, 0.006953},{1.933972, 0.002815, 0.006077}}],
    Polygon[{{1.932881, 0.004508, 0.006953},{1.933557, 0.005438, 0.007658},{
      1.934644, 0.004884, 0.007658},{1.934289, 0.003790, 0.006953}}],
    Polygon[{{1.933557, 0.005438, 0.007658},{1.934289, 0.006446, 0.008174},{
      1.935029, 0.006069, 0.008174},{1.934644, 0.004884, 0.007658}}],
    Polygon[{{1.934289, 0.006446, 0.008174},{1.935060, 0.007507, 0.008489},{
      1.935434, 0.007316, 0.008489},{1.935029, 0.006069, 0.008174}}],
    Polygon[{{1.935434, 0.007316, -0.008489},{1.935029, 0.006069, -0.008174},{
      1.935850, 0.005939, -0.008174},{1.935850, 0.007250, -0.008489}}],
    Polygon[{{1.935029, 0.006069, -0.008174},{1.934644, 0.004884, -0.007658},{
      1.935850, 0.004693, -0.007658},{1.935850, 0.005939, -0.008174}}],
    Polygon[{{1.934644, 0.004884, -0.007658},{1.934289, 0.003790, -0.006953},{
      1.935850, 0.003543, -0.006953},{1.935850, 0.004693, -0.007658}}],
    Polygon[{{1.934289, 0.003790, -0.006953},{1.933972, 0.002815, -0.006077},{
      1.935850, 0.002517, -0.006077},{1.935850, 0.003543, -0.006953}}],
    Polygon[{{1.933972, 0.002815, -0.006077},{1.933701, 0.001982, -0.005052},{
      1.935850, 0.001641, -0.005052},{1.935850, 0.002517, -0.006077}}],
    Polygon[{{1.933701, 0.001982, -0.005052},{1.933484, 0.001312, -0.003902},{
      1.935850, 0.000937, -0.003902},{1.935850, 0.001641, -0.005052}}],
    Polygon[{{1.933484, 0.001312, -0.003902},{1.933324, 0.000821, -0.002656},{
      1.935850, 0.000421, -0.002656},{1.935850, 0.000937, -0.003902}}],
    Polygon[{{1.933324, 0.000821, -0.002656},{1.933227, 0.000521, -0.001344},{
      1.935850, 0.000106, -0.001344},{1.935850, 0.000421, -0.002656}}],
    Polygon[{{1.933227, 0.000521, -0.001344},{1.933194, 0.000421, 0.000000},{
      1.935850, 0.000000, 0.000000},{1.935850, 0.000106, -0.001344}}],
    Polygon[{{1.933194, 0.000421, 0.000000},{1.933227, 0.000521, 0.001344},{
      1.935850, 0.000106, 0.001344},{1.935850, 0.000000, 0.000000}}],
    Polygon[{{1.933227, 0.000521, 0.001344},{1.933324, 0.000821, 0.002656},{
      1.935850, 0.000421, 0.002656},{1.935850, 0.000106, 0.001344}}],
    Polygon[{{1.933324, 0.000821, 0.002656},{1.933484, 0.001312, 0.003902},{
      1.935850, 0.000937, 0.003902},{1.935850, 0.000421, 0.002656}}],
    Polygon[{{1.933484, 0.001312, 0.003902},{1.933701, 0.001982, 0.005052},{
      1.935850, 0.001641, 0.005052},{1.935850, 0.000937, 0.003902}}],
    Polygon[{{1.933701, 0.001982, 0.005052},{1.933972, 0.002815, 0.006077},{
      1.935850, 0.002517, 0.006077},{1.935850, 0.001641, 0.005052}}],
    Polygon[{{1.933972, 0.002815, 0.006077},{1.934289, 0.003790, 0.006953},{
      1.935850, 0.003543, 0.006953},{1.935850, 0.002517, 0.006077}}],
    Polygon[{{1.934289, 0.003790, 0.006953},{1.934644, 0.004884, 0.007658},{
      1.935850, 0.004693, 0.007658},{1.935850, 0.003543, 0.006953}}],
    Polygon[{{1.934644, 0.004884, 0.007658},{1.935029, 0.006069, 0.008174},{
      1.935850, 0.005939, 0.008174},{1.935850, 0.004693, 0.007658}}],
    Polygon[{{1.935029, 0.006069, 0.008174},{1.935434, 0.007316, 0.008489},{
      1.935850, 0.007250, 0.008489},{1.935850, 0.005939, 0.008174}}],
    Polygon[{{1.935850, 0.007250, -0.008489},{1.935850, 0.005939, -0.008174},{
      1.936671, 0.006069, -0.008174},{1.936265, 0.007316, -0.008489}}],
    Polygon[{{1.935850, 0.005939, -0.008174},{1.935850, 0.004693, -0.007658},{
      1.937056, 0.004884, -0.007658},{1.936671, 0.006069, -0.008174}}],
    Polygon[{{1.935850, 0.004693, -0.007658},{1.935850, 0.003543, -0.006953},{
      1.937411, 0.003790, -0.006953},{1.937056, 0.004884, -0.007658}}],
    Polygon[{{1.935850, 0.003543, -0.006953},{1.935850, 0.002517, -0.006077},{
      1.937728, 0.002815, -0.006077},{1.937411, 0.003790, -0.006953}}],
    Polygon[{{1.935850, 0.002517, -0.006077},{1.935850, 0.001641, -0.005052},{
      1.937999, 0.001982, -0.005052},{1.937728, 0.002815, -0.006077}}],
    Polygon[{{1.935850, 0.001641, -0.005052},{1.935850, 0.000937, -0.003902},{
      1.938216, 0.001312, -0.003902},{1.937999, 0.001982, -0.005052}}],
    Polygon[{{1.935850, 0.000937, -0.003902},{1.935850, 0.000421, -0.002656},{
      1.938376, 0.000821, -0.002656},{1.938216, 0.001312, -0.003902}}],
    Polygon[{{1.935850, 0.000421, -0.002656},{1.935850, 0.000106, -0.001344},{
      1.938473, 0.000521, -0.001344},{1.938376, 0.000821, -0.002656}}],
    Polygon[{{1.935850, 0.000106, -0.001344},{1.935850, 0.000000, 0.000000},{
      1.938506, 0.000421, 0.000000},{1.938473, 0.000521, -0.001344}}],
    Polygon[{{1.935850, 0.000000, 0.000000},{1.935850, 0.000106, 0.001344},{
      1.938473, 0.000521, 0.001344},{1.938506, 0.000421, 0.000000}}],
    Polygon[{{1.935850, 0.000106, 0.001344},{1.935850, 0.000421, 0.002656},{
      1.938376, 0.000821, 0.002656},{1.938473, 0.000521, 0.001344}}],
    Polygon[{{1.935850, 0.000421, 0.002656},{1.935850, 0.000937, 0.003902},{
      1.938216, 0.001312, 0.003902},{1.938376, 0.000821, 0.002656}}],
    Polygon[{{1.935850, 0.000937, 0.003902},{1.935850, 0.001641, 0.005052},{
      1.937999, 0.001982, 0.005052},{1.938216, 0.001312, 0.003902}}],
    Polygon[{{1.935850, 0.001641, 0.005052},{1.935850, 0.002517, 0.006077},{
      1.937728, 0.002815, 0.006077},{1.937999, 0.001982, 0.005052}}],
    Polygon[{{1.935850, 0.002517, 0.006077},{1.935850, 0.003543, 0.006953},{
      1.937411, 0.003790, 0.006953},{1.937728, 0.002815, 0.006077}}],
    Polygon[{{1.935850, 0.003543, 0.006953},{1.935850, 0.004693, 0.007658},{
      1.937056, 0.004884, 0.007658},{1.937411, 0.003790, 0.006953}}],
    Polygon[{{1.935850, 0.004693, 0.007658},{1.935850, 0.005939, 0.008174},{
      1.936671, 0.006069, 0.008174},{1.937056, 0.004884, 0.007658}}],
    Polygon[{{1.935850, 0.005939, 0.008174},{1.935850, 0.007250, 0.008489},{
      1.936265, 0.007316, 0.008489},{1.936671, 0.006069, 0.008174}}],
    Polygon[{{1.936265, 0.007316, -0.008489},{1.936671, 0.006069, -0.008174},{
      1.937411, 0.006446, -0.008174},{1.936640, 0.007507, -0.008489}}],
    Polygon[{{1.936671, 0.006069, -0.008174},{1.937056, 0.004884, -0.007658},{
      1.938143, 0.005438, -0.007658},{1.937411, 0.006446, -0.008174}}],
    Polygon[{{1.937056, 0.004884, -0.007658},{1.937411, 0.003790, -0.006953},{
      1.938819, 0.004508, -0.006953},{1.938143, 0.005438, -0.007658}}],
    Polygon[{{1.937411, 0.003790, -0.006953},{1.937728, 0.002815, -0.006077},{
      1.939422, 0.003678, -0.006077},{1.938819, 0.004508, -0.006953}}],
    Polygon[{{1.937728, 0.002815, -0.006077},{1.937999, 0.001982, -0.005052},{
      1.939937, 0.002969, -0.005052},{1.939422, 0.003678, -0.006077}}],
    Polygon[{{1.937999, 0.001982, -0.005052},{1.938216, 0.001312, -0.003902},{
      1.940351, 0.002399, -0.003902},{1.939937, 0.002969, -0.005052}}],
    Polygon[{{1.938216, 0.001312, -0.003902},{1.938376, 0.000821, -0.002656},{
      1.940654, 0.001982, -0.002656},{1.940351, 0.002399, -0.003902}}],
    Polygon[{{1.938376, 0.000821, -0.002656},{1.938473, 0.000521, -0.001344},{
      1.940840, 0.001727, -0.001344},{1.940654, 0.001982, -0.002656}}],
    Polygon[{{1.938473, 0.000521, -0.001344},{1.938506, 0.000421, 0.000000},{
      1.940902, 0.001641, 0.000000},{1.940840, 0.001727, -0.001344}}],
    Polygon[{{1.938506, 0.000421, 0.000000},{1.938473, 0.000521, 0.001344},{
      1.940840, 0.001727, 0.001344},{1.940902, 0.001641, 0.000000}}],
    Polygon[{{1.938473, 0.000521, 0.001344},{1.938376, 0.000821, 0.002656},{
      1.940654, 0.001982, 0.002656},{1.940840, 0.001727, 0.001344}}],
    Polygon[{{1.938376, 0.000821, 0.002656},{1.938216, 0.001312, 0.003902},{
      1.940351, 0.002399, 0.003902},{1.940654, 0.001982, 0.002656}}],
    Polygon[{{1.938216, 0.001312, 0.003902},{1.937999, 0.001982, 0.005052},{
      1.939937, 0.002969, 0.005052},{1.940351, 0.002399, 0.003902}}],
    Polygon[{{1.937999, 0.001982, 0.005052},{1.937728, 0.002815, 0.006077},{
      1.939422, 0.003678, 0.006077},{1.939937, 0.002969, 0.005052}}],
    Polygon[{{1.937728, 0.002815, 0.006077},{1.937411, 0.003790, 0.006953},{
      1.938819, 0.004508, 0.006953},{1.939422, 0.003678, 0.006077}}],
    Polygon[{{1.937411, 0.003790, 0.006953},{1.937056, 0.004884, 0.007658},{
      1.938143, 0.005438, 0.007658},{1.938819, 0.004508, 0.006953}}],
    Polygon[{{1.937056, 0.004884, 0.007658},{1.936671, 0.006069, 0.008174},{
      1.937411, 0.006446, 0.008174},{1.938143, 0.005438, 0.007658}}],
    Polygon[{{1.936671, 0.006069, 0.008174},{1.936265, 0.007316, 0.008489},{
      1.936640, 0.007507, 0.008489},{1.937411, 0.006446, 0.008174}}],
    Polygon[{{1.936640, 0.007507, -0.008489},{1.937411, 0.006446, -0.008174},{
      1.937999, 0.007033, -0.008174},{1.936938, 0.007804, -0.008489}}],
    Polygon[{{1.937411, 0.006446, -0.008174},{1.938143, 0.005438, -0.007658},{
      1.939007, 0.006301, -0.007658},{1.937999, 0.007033, -0.008174}}],
    Polygon[{{1.938143, 0.005438, -0.007658},{1.938819, 0.004508, -0.006953},{
      1.939937, 0.005625, -0.006953},{1.939007, 0.006301, -0.007658}}],
    Polygon[{{1.938819, 0.004508, -0.006953},{1.939422, 0.003678, -0.006077},{
      1.940767, 0.005022, -0.006077},{1.939937, 0.005625, -0.006953}}],
    Polygon[{{1.939422, 0.003678, -0.006077},{1.939937, 0.002969, -0.005052},{
      1.941475, 0.004508, -0.005052},{1.940767, 0.005022, -0.006077}}],
    Polygon[{{1.939937, 0.002969, -0.005052},{1.940351, 0.002399, -0.003902},{
      1.942045, 0.004093, -0.003902},{1.941475, 0.004508, -0.005052}}],
    Polygon[{{1.940351, 0.002399, -0.003902},{1.940654, 0.001982, -0.002656},{
      1.942463, 0.003790, -0.002656},{1.942045, 0.004093, -0.003902}}],
    Polygon[{{1.940654, 0.001982, -0.002656},{1.940840, 0.001727, -0.001344},{
      1.942717, 0.003605, -0.001344},{1.942463, 0.003790, -0.002656}}],
    Polygon[{{1.940840, 0.001727, -0.001344},{1.940902, 0.001641, 0.000000},{
      1.942803, 0.003543, 0.000000},{1.942717, 0.003605, -0.001344}}],
    Polygon[{{1.940902, 0.001641, 0.000000},{1.940840, 0.001727, 0.001344},{
      1.942717, 0.003605, 0.001344},{1.942803, 0.003543, 0.000000}}],
    Polygon[{{1.940840, 0.001727, 0.001344},{1.940654, 0.001982, 0.002656},{
      1.942463, 0.003790, 0.002656},{1.942717, 0.003605, 0.001344}}],
    Polygon[{{1.940654, 0.001982, 0.002656},{1.940351, 0.002399, 0.003902},{
      1.942045, 0.004093, 0.003902},{1.942463, 0.003790, 0.002656}}],
    Polygon[{{1.940351, 0.002399, 0.003902},{1.939937, 0.002969, 0.005052},{
      1.941475, 0.004508, 0.005052},{1.942045, 0.004093, 0.003902}}],
    Polygon[{{1.939937, 0.002969, 0.005052},{1.939422, 0.003678, 0.006077},{
      1.940767, 0.005022, 0.006077},{1.941475, 0.004508, 0.005052}}],
    Polygon[{{1.939422, 0.003678, 0.006077},{1.938819, 0.004508, 0.006953},{
      1.939937, 0.005625, 0.006953},{1.940767, 0.005022, 0.006077}}],
    Polygon[{{1.938819, 0.004508, 0.006953},{1.938143, 0.005438, 0.007658},{
      1.939007, 0.006301, 0.007658},{1.939937, 0.005625, 0.006953}}],
    Polygon[{{1.938143, 0.005438, 0.007658},{1.937411, 0.006446, 0.008174},{
      1.937999, 0.007033, 0.008174},{1.939007, 0.006301, 0.007658}}],
    Polygon[{{1.937411, 0.006446, 0.008174},{1.936640, 0.007507, 0.008489},{
      1.936938, 0.007804, 0.008489},{1.937999, 0.007033, 0.008174}}],
    Polygon[{{1.936938, 0.007804, -0.008489},{1.937999, 0.007033, -0.008174},{
      1.938376, 0.007774, -0.008174},{1.937129, 0.008179, -0.008489}}],
    Polygon[{{1.937999, 0.007033, -0.008174},{1.939007, 0.006301, -0.007658},{
      1.939561, 0.007389, -0.007658},{1.938376, 0.007774, -0.008174}}],
    Polygon[{{1.939007, 0.006301, -0.007658},{1.939937, 0.005625, -0.006953},{
      1.940654, 0.007033, -0.006953},{1.939561, 0.007389, -0.007658}}],
    Polygon[{{1.939937, 0.005625, -0.006953},{1.940767, 0.005022, -0.006077},{
      1.941630, 0.006717, -0.006077},{1.940654, 0.007033, -0.006953}}],
    Polygon[{{1.940767, 0.005022, -0.006077},{1.941475, 0.004508, -0.005052},{
      1.942463, 0.006446, -0.005052},{1.941630, 0.006717, -0.006077}}],
    Polygon[{{1.941475, 0.004508, -0.005052},{1.942045, 0.004093, -0.003902},{
      1.943133, 0.006228, -0.003902},{1.942463, 0.006446, -0.005052}}],
    Polygon[{{1.942045, 0.004093, -0.003902},{1.942463, 0.003790, -0.002656},{
      1.943624, 0.006069, -0.002656},{1.943133, 0.006228, -0.003902}}],
    Polygon[{{1.942463, 0.003790, -0.002656},{1.942717, 0.003605, -0.001344},{
      1.943923, 0.005971, -0.001344},{1.943624, 0.006069, -0.002656}}],
    Polygon[{{1.942717, 0.003605, -0.001344},{1.942803, 0.003543, 0.000000},{
      1.944024, 0.005939, 0.000000},{1.943923, 0.005971, -0.001344}}],
    Polygon[{{1.942803, 0.003543, 0.000000},{1.942717, 0.003605, 0.001344},{
      1.943923, 0.005971, 0.001344},{1.944024, 0.005939, 0.000000}}],
    Polygon[{{1.942717, 0.003605, 0.001344},{1.942463, 0.003790, 0.002656},{
      1.943624, 0.006069, 0.002656},{1.943923, 0.005971, 0.001344}}],
    Polygon[{{1.942463, 0.003790, 0.002656},{1.942045, 0.004093, 0.003902},{
      1.943133, 0.006228, 0.003902},{1.943624, 0.006069, 0.002656}}],
    Polygon[{{1.942045, 0.004093, 0.003902},{1.941475, 0.004508, 0.005052},{
      1.942463, 0.006446, 0.005052},{1.943133, 0.006228, 0.003902}}],
    Polygon[{{1.941475, 0.004508, 0.005052},{1.940767, 0.005022, 0.006077},{
      1.941630, 0.006717, 0.006077},{1.942463, 0.006446, 0.005052}}],
    Polygon[{{1.940767, 0.005022, 0.006077},{1.939937, 0.005625, 0.006953},{
      1.940654, 0.007033, 0.006953},{1.941630, 0.006717, 0.006077}}],
    Polygon[{{1.939937, 0.005625, 0.006953},{1.939007, 0.006301, 0.007658},{
      1.939561, 0.007389, 0.007658},{1.940654, 0.007033, 0.006953}}],
    Polygon[{{1.939007, 0.006301, 0.007658},{1.937999, 0.007033, 0.008174},{
      1.938376, 0.007774, 0.008174},{1.939561, 0.007389, 0.007658}}],
    Polygon[{{1.937999, 0.007033, 0.008174},{1.936938, 0.007804, 0.008489},{
      1.937129, 0.008179, 0.008489},{1.938376, 0.007774, 0.008174}}],
    Polygon[{{1.937129, 0.008179, -0.008489},{1.938376, 0.007774, -0.008174},{
      1.938506, 0.008594, -0.008174},{1.937194, 0.008594, -0.008489}}],
    Polygon[{{1.938376, 0.007774, -0.008174},{1.939561, 0.007389, -0.007658},{
      1.939752, 0.008594, -0.007658},{1.938506, 0.008594, -0.008174}}],
    Polygon[{{1.939561, 0.007389, -0.007658},{1.940654, 0.007033, -0.006953},{
      1.940902, 0.008594, -0.006953},{1.939752, 0.008594, -0.007658}}],
    Polygon[{{1.940654, 0.007033, -0.006953},{1.941630, 0.006717, -0.006077},{
      1.941927, 0.008594, -0.006077},{1.940902, 0.008594, -0.006953}}],
    Polygon[{{1.941630, 0.006717, -0.006077},{1.942463, 0.006446, -0.005052},{
      1.942803, 0.008594, -0.005052},{1.941927, 0.008594, -0.006077}}],
    Polygon[{{1.942463, 0.006446, -0.005052},{1.943133, 0.006228, -0.003902},{
      1.943508, 0.008594, -0.003902},{1.942803, 0.008594, -0.005052}}],
    Polygon[{{1.943133, 0.006228, -0.003902},{1.943624, 0.006069, -0.002656},{
      1.944024, 0.008594, -0.002656},{1.943508, 0.008594, -0.003902}}],
    Polygon[{{1.943624, 0.006069, -0.002656},{1.943923, 0.005971, -0.001344},{
      1.944339, 0.008594, -0.001344},{1.944024, 0.008594, -0.002656}}],
    Polygon[{{1.943923, 0.005971, -0.001344},{1.944024, 0.005939, 0.000000},{
      1.944444, 0.008594, 0.000000},{1.944339, 0.008594, -0.001344}}],
    Polygon[{{1.944024, 0.005939, 0.000000},{1.943923, 0.005971, 0.001344},{
      1.944339, 0.008594, 0.001344},{1.944444, 0.008594, 0.000000}}],
    Polygon[{{1.943923, 0.005971, 0.001344},{1.943624, 0.006069, 0.002656},{
      1.944024, 0.008594, 0.002656},{1.944339, 0.008594, 0.001344}}],
    Polygon[{{1.943624, 0.006069, 0.002656},{1.943133, 0.006228, 0.003902},{
      1.943508, 0.008594, 0.003902},{1.944024, 0.008594, 0.002656}}],
    Polygon[{{1.943133, 0.006228, 0.003902},{1.942463, 0.006446, 0.005052},{
      1.942803, 0.008594, 0.005052},{1.943508, 0.008594, 0.003902}}],
    Polygon[{{1.942463, 0.006446, 0.005052},{1.941630, 0.006717, 0.006077},{
      1.941927, 0.008594, 0.006077},{1.942803, 0.008594, 0.005052}}],
    Polygon[{{1.941630, 0.006717, 0.006077},{1.940654, 0.007033, 0.006953},{
      1.940902, 0.008594, 0.006953},{1.941927, 0.008594, 0.006077}}],
    Polygon[{{1.940654, 0.007033, 0.006953},{1.939561, 0.007389, 0.007658},{
      1.939752, 0.008594, 0.007658},{1.940902, 0.008594, 0.006953}}],
    Polygon[{{1.939561, 0.007389, 0.007658},{1.938376, 0.007774, 0.008174},{
      1.938506, 0.008594, 0.008174},{1.939752, 0.008594, 0.007658}}],
    Polygon[{{1.938376, 0.007774, 0.008174},{1.937129, 0.008179, 0.008489},{
      1.937194, 0.008594, 0.008489},{1.938506, 0.008594, 0.008174}}],
    Polygon[{{1.961826, 0.051258, -0.008489},{1.963138, 0.051258, -0.008174},{
      1.963008, 0.052079, -0.008174},{1.961761, 0.051674, -0.008489}}],
    Polygon[{{1.963138, 0.051258, -0.008174},{1.964384, 0.051258, -0.007658},{
      1.964193, 0.052464, -0.007658},{1.963008, 0.052079, -0.008174}}],
    Polygon[{{1.964384, 0.051258, -0.007658},{1.965534, 0.051258, -0.006953},{
      1.965286, 0.052819, -0.006953},{1.964193, 0.052464, -0.007658}}],
    Polygon[{{1.965534, 0.051258, -0.006953},{1.966559, 0.051258, -0.006077},{
      1.966262, 0.053136, -0.006077},{1.965286, 0.052819, -0.006953}}],
    Polygon[{{1.966559, 0.051258, -0.006077},{1.967435, 0.051258, -0.005052},{
      1.967095, 0.053407, -0.005052},{1.966262, 0.053136, -0.006077}}],
    Polygon[{{1.967435, 0.051258, -0.005052},{1.968140, 0.051258, -0.003902},{
      1.967765, 0.053625, -0.003902},{1.967095, 0.053407, -0.005052}}],
    Polygon[{{1.968140, 0.051258, -0.003902},{1.968656, 0.051258, -0.002656},{
      1.968256, 0.053784, -0.002656},{1.967765, 0.053625, -0.003902}}],
    Polygon[{{1.968656, 0.051258, -0.002656},{1.968971, 0.051258, -0.001344},{
      1.968555, 0.053881, -0.001344},{1.968256, 0.053784, -0.002656}}],
    Polygon[{{1.968971, 0.051258, -0.001344},{1.969076, 0.051258, 0.000000},{
      1.968656, 0.053914, 0.000000},{1.968555, 0.053881, -0.001344}}],
    Polygon[{{1.969076, 0.051258, 0.000000},{1.968971, 0.051258, 0.001344},{
      1.968555, 0.053881, 0.001344},{1.968656, 0.053914, 0.000000}}],
    Polygon[{{1.968971, 0.051258, 0.001344},{1.968656, 0.051258, 0.002656},{
      1.968256, 0.053784, 0.002656},{1.968555, 0.053881, 0.001344}}],
    Polygon[{{1.968656, 0.051258, 0.002656},{1.968140, 0.051258, 0.003902},{
      1.967765, 0.053625, 0.003902},{1.968256, 0.053784, 0.002656}}],
    Polygon[{{1.968140, 0.051258, 0.003902},{1.967435, 0.051258, 0.005052},{
      1.967095, 0.053407, 0.005052},{1.967765, 0.053625, 0.003902}}],
    Polygon[{{1.967435, 0.051258, 0.005052},{1.966559, 0.051258, 0.006077},{
      1.966262, 0.053136, 0.006077},{1.967095, 0.053407, 0.005052}}],
    Polygon[{{1.966559, 0.051258, 0.006077},{1.965534, 0.051258, 0.006953},{
      1.965286, 0.052819, 0.006953},{1.966262, 0.053136, 0.006077}}],
    Polygon[{{1.965534, 0.051258, 0.006953},{1.964384, 0.051258, 0.007658},{
      1.964193, 0.052464, 0.007658},{1.965286, 0.052819, 0.006953}}],
    Polygon[{{1.964384, 0.051258, 0.007658},{1.963138, 0.051258, 0.008174},{
      1.963008, 0.052079, 0.008174},{1.964193, 0.052464, 0.007658}}],
    Polygon[{{1.963138, 0.051258, 0.008174},{1.961826, 0.051258, 0.008489},{
      1.961761, 0.051674, 0.008489},{1.963008, 0.052079, 0.008174}}],
    Polygon[{{1.961761, 0.051674, -0.008489},{1.963008, 0.052079, -0.008174},{
      1.962631, 0.052819, -0.008174},{1.961570, 0.052049, -0.008489}}],
    Polygon[{{1.963008, 0.052079, -0.008174},{1.964193, 0.052464, -0.007658},{
      1.963639, 0.053552, -0.007658},{1.962631, 0.052819, -0.008174}}],
    Polygon[{{1.964193, 0.052464, -0.007658},{1.965286, 0.052819, -0.006953},{
      1.964569, 0.054228, -0.006953},{1.963639, 0.053552, -0.007658}}],
    Polygon[{{1.965286, 0.052819, -0.006953},{1.966262, 0.053136, -0.006077},{
      1.965399, 0.054830, -0.006077},{1.964569, 0.054228, -0.006953}}],
    Polygon[{{1.966262, 0.053136, -0.006077},{1.967095, 0.053407, -0.005052},{
      1.966107, 0.055345, -0.005052},{1.965399, 0.054830, -0.006077}}],
    Polygon[{{1.967095, 0.053407, -0.005052},{1.967765, 0.053625, -0.003902},{
      1.966677, 0.055759, -0.003902},{1.966107, 0.055345, -0.005052}}],
    Polygon[{{1.967765, 0.053625, -0.003902},{1.968256, 0.053784, -0.002656},{
      1.967095, 0.056063, -0.002656},{1.966677, 0.055759, -0.003902}}],
    Polygon[{{1.968256, 0.053784, -0.002656},{1.968555, 0.053881, -0.001344},{
      1.967349, 0.056248, -0.001344},{1.967095, 0.056063, -0.002656}}],
    Polygon[{{1.968555, 0.053881, -0.001344},{1.968656, 0.053914, 0.000000},{
      1.967435, 0.056310, 0.000000},{1.967349, 0.056248, -0.001344}}],
    Polygon[{{1.968656, 0.053914, 0.000000},{1.968555, 0.053881, 0.001344},{
      1.967349, 0.056248, 0.001344},{1.967435, 0.056310, 0.000000}}],
    Polygon[{{1.968555, 0.053881, 0.001344},{1.968256, 0.053784, 0.002656},{
      1.967095, 0.056063, 0.002656},{1.967349, 0.056248, 0.001344}}],
    Polygon[{{1.968256, 0.053784, 0.002656},{1.967765, 0.053625, 0.003902},{
      1.966677, 0.055759, 0.003902},{1.967095, 0.056063, 0.002656}}],
    Polygon[{{1.967765, 0.053625, 0.003902},{1.967095, 0.053407, 0.005052},{
      1.966107, 0.055345, 0.005052},{1.966677, 0.055759, 0.003902}}],
    Polygon[{{1.967095, 0.053407, 0.005052},{1.966262, 0.053136, 0.006077},{
      1.965399, 0.054830, 0.006077},{1.966107, 0.055345, 0.005052}}],
    Polygon[{{1.966262, 0.053136, 0.006077},{1.965286, 0.052819, 0.006953},{
      1.964569, 0.054228, 0.006953},{1.965399, 0.054830, 0.006077}}],
    Polygon[{{1.965286, 0.052819, 0.006953},{1.964193, 0.052464, 0.007658},{
      1.963639, 0.053552, 0.007658},{1.964569, 0.054228, 0.006953}}],
    Polygon[{{1.964193, 0.052464, 0.007658},{1.963008, 0.052079, 0.008174},{
      1.962631, 0.052819, 0.008174},{1.963639, 0.053552, 0.007658}}],
    Polygon[{{1.963008, 0.052079, 0.008174},{1.961761, 0.051674, 0.008489},{
      1.961570, 0.052049, 0.008489},{1.962631, 0.052819, 0.008174}}],
    Polygon[{{1.961570, 0.052049, -0.008489},{1.962631, 0.052819, -0.008174},{
      1.962043, 0.053407, -0.008174},{1.961272, 0.052346, -0.008489}}],
    Polygon[{{1.962631, 0.052819, -0.008174},{1.963639, 0.053552, -0.007658},{
      1.962775, 0.054415, -0.007658},{1.962043, 0.053407, -0.008174}}],
    Polygon[{{1.963639, 0.053552, -0.007658},{1.964569, 0.054228, -0.006953},{
      1.963451, 0.055345, -0.006953},{1.962775, 0.054415, -0.007658}}],
    Polygon[{{1.964569, 0.054228, -0.006953},{1.965399, 0.054830, -0.006077},{
      1.964054, 0.056175, -0.006077},{1.963451, 0.055345, -0.006953}}],
    Polygon[{{1.965399, 0.054830, -0.006077},{1.966107, 0.055345, -0.005052},{
      1.964569, 0.056883, -0.005052},{1.964054, 0.056175, -0.006077}}],
    Polygon[{{1.966107, 0.055345, -0.005052},{1.966677, 0.055759, -0.003902},{
      1.964983, 0.057454, -0.003902},{1.964569, 0.056883, -0.005052}}],
    Polygon[{{1.966677, 0.055759, -0.003902},{1.967095, 0.056063, -0.002656},{
      1.965286, 0.057871, -0.002656},{1.964983, 0.057454, -0.003902}}],
    Polygon[{{1.967095, 0.056063, -0.002656},{1.967349, 0.056248, -0.001344},{
      1.965472, 0.058126, -0.001344},{1.965286, 0.057871, -0.002656}}],
    Polygon[{{1.967349, 0.056248, -0.001344},{1.967435, 0.056310, 0.000000},{
      1.965534, 0.058211, 0.000000},{1.965472, 0.058126, -0.001344}}],
    Polygon[{{1.967435, 0.056310, 0.000000},{1.967349, 0.056248, 0.001344},{
      1.965472, 0.058126, 0.001344},{1.965534, 0.058211, 0.000000}}],
    Polygon[{{1.967349, 0.056248, 0.001344},{1.967095, 0.056063, 0.002656},{
      1.965286, 0.057871, 0.002656},{1.965472, 0.058126, 0.001344}}],
    Polygon[{{1.967095, 0.056063, 0.002656},{1.966677, 0.055759, 0.003902},{
      1.964983, 0.057454, 0.003902},{1.965286, 0.057871, 0.002656}}],
    Polygon[{{1.966677, 0.055759, 0.003902},{1.966107, 0.055345, 0.005052},{
      1.964569, 0.056883, 0.005052},{1.964983, 0.057454, 0.003902}}],
    Polygon[{{1.966107, 0.055345, 0.005052},{1.965399, 0.054830, 0.006077},{
      1.964054, 0.056175, 0.006077},{1.964569, 0.056883, 0.005052}}],
    Polygon[{{1.965399, 0.054830, 0.006077},{1.964569, 0.054228, 0.006953},{
      1.963451, 0.055345, 0.006953},{1.964054, 0.056175, 0.006077}}],
    Polygon[{{1.964569, 0.054228, 0.006953},{1.963639, 0.053552, 0.007658},{
      1.962775, 0.054415, 0.007658},{1.963451, 0.055345, 0.006953}}],
    Polygon[{{1.963639, 0.053552, 0.007658},{1.962631, 0.052819, 0.008174},{
      1.962043, 0.053407, 0.008174},{1.962775, 0.054415, 0.007658}}],
    Polygon[{{1.962631, 0.052819, 0.008174},{1.961570, 0.052049, 0.008489},{
      1.961272, 0.052346, 0.008489},{1.962043, 0.053407, 0.008174}}],
    Polygon[{{1.961272, 0.052346, -0.008489},{1.962043, 0.053407, -0.008174},{
      1.961303, 0.053784, -0.008174},{1.960897, 0.052537, -0.008489}}],
    Polygon[{{1.962043, 0.053407, -0.008174},{1.962775, 0.054415, -0.007658},{
      1.961688, 0.054969, -0.007658},{1.961303, 0.053784, -0.008174}}],
    Polygon[{{1.962775, 0.054415, -0.007658},{1.963451, 0.055345, -0.006953},{
      1.962043, 0.056063, -0.006953},{1.961688, 0.054969, -0.007658}}],
    Polygon[{{1.963451, 0.055345, -0.006953},{1.964054, 0.056175, -0.006077},{
      1.962360, 0.057038, -0.006077},{1.962043, 0.056063, -0.006953}}],
    Polygon[{{1.964054, 0.056175, -0.006077},{1.964569, 0.056883, -0.005052},{
      1.962631, 0.057871, -0.005052},{1.962360, 0.057038, -0.006077}}],
    Polygon[{{1.964569, 0.056883, -0.005052},{1.964983, 0.057454, -0.003902},{
      1.962848, 0.058541, -0.003902},{1.962631, 0.057871, -0.005052}}],
    Polygon[{{1.964983, 0.057454, -0.003902},{1.965286, 0.057871, -0.002656},{
      1.963008, 0.059032, -0.002656},{1.962848, 0.058541, -0.003902}}],
    Polygon[{{1.965286, 0.057871, -0.002656},{1.965472, 0.058126, -0.001344},{
      1.963105, 0.059332, -0.001344},{1.963008, 0.059032, -0.002656}}],
    Polygon[{{1.965472, 0.058126, -0.001344},{1.965534, 0.058211, 0.000000},{
      1.963138, 0.059432, 0.000000},{1.963105, 0.059332, -0.001344}}],
    Polygon[{{1.965534, 0.058211, 0.000000},{1.965472, 0.058126, 0.001344},{
      1.963105, 0.059332, 0.001344},{1.963138, 0.059432, 0.000000}}],
    Polygon[{{1.965472, 0.058126, 0.001344},{1.965286, 0.057871, 0.002656},{
      1.963008, 0.059032, 0.002656},{1.963105, 0.059332, 0.001344}}],
    Polygon[{{1.965286, 0.057871, 0.002656},{1.964983, 0.057454, 0.003902},{
      1.962848, 0.058541, 0.003902},{1.963008, 0.059032, 0.002656}}],
    Polygon[{{1.964983, 0.057454, 0.003902},{1.964569, 0.056883, 0.005052},{
      1.962631, 0.057871, 0.005052},{1.962848, 0.058541, 0.003902}}],
    Polygon[{{1.964569, 0.056883, 0.005052},{1.964054, 0.056175, 0.006077},{
      1.962360, 0.057038, 0.006077},{1.962631, 0.057871, 0.005052}}],
    Polygon[{{1.964054, 0.056175, 0.006077},{1.963451, 0.055345, 0.006953},{
      1.962043, 0.056063, 0.006953},{1.962360, 0.057038, 0.006077}}],
    Polygon[{{1.963451, 0.055345, 0.006953},{1.962775, 0.054415, 0.007658},{
      1.961688, 0.054969, 0.007658},{1.962043, 0.056063, 0.006953}}],
    Polygon[{{1.962775, 0.054415, 0.007658},{1.962043, 0.053407, 0.008174},{
      1.961303, 0.053784, 0.008174},{1.961688, 0.054969, 0.007658}}],
    Polygon[{{1.962043, 0.053407, 0.008174},{1.961272, 0.052346, 0.008489},{
      1.960897, 0.052537, 0.008489},{1.961303, 0.053784, 0.008174}}],
    Polygon[{{1.960897, 0.052537, -0.008489},{1.961303, 0.053784, -0.008174},{
      1.960482, 0.053914, -0.008174},{1.960482, 0.052603, -0.008489}}],
    Polygon[{{1.961303, 0.053784, -0.008174},{1.961688, 0.054969, -0.007658},{
      1.960482, 0.055160, -0.007658},{1.960482, 0.053914, -0.008174}}],
    Polygon[{{1.961688, 0.054969, -0.007658},{1.962043, 0.056063, -0.006953},{
      1.960482, 0.056310, -0.006953},{1.960482, 0.055160, -0.007658}}],
    Polygon[{{1.962043, 0.056063, -0.006953},{1.962360, 0.057038, -0.006077},{
      1.960482, 0.057336, -0.006077},{1.960482, 0.056310, -0.006953}}],
    Polygon[{{1.962360, 0.057038, -0.006077},{1.962631, 0.057871, -0.005052},{
      1.960482, 0.058211, -0.005052},{1.960482, 0.057336, -0.006077}}],
    Polygon[{{1.962631, 0.057871, -0.005052},{1.962848, 0.058541, -0.003902},{
      1.960482, 0.058916, -0.003902},{1.960482, 0.058211, -0.005052}}],
    Polygon[{{1.962848, 0.058541, -0.003902},{1.963008, 0.059032, -0.002656},{
      1.960482, 0.059432, -0.002656},{1.960482, 0.058916, -0.003902}}],
    Polygon[{{1.963008, 0.059032, -0.002656},{1.963105, 0.059332, -0.001344},{
      1.960482, 0.059747, -0.001344},{1.960482, 0.059432, -0.002656}}],
    Polygon[{{1.963105, 0.059332, -0.001344},{1.963138, 0.059432, 0.000000},{
      1.960482, 0.059853, 0.000000},{1.960482, 0.059747, -0.001344}}],
    Polygon[{{1.963138, 0.059432, 0.000000},{1.963105, 0.059332, 0.001344},{
      1.960482, 0.059747, 0.001344},{1.960482, 0.059853, 0.000000}}],
    Polygon[{{1.963105, 0.059332, 0.001344},{1.963008, 0.059032, 0.002656},{
      1.960482, 0.059432, 0.002656},{1.960482, 0.059747, 0.001344}}],
    Polygon[{{1.963008, 0.059032, 0.002656},{1.962848, 0.058541, 0.003902},{
      1.960482, 0.058916, 0.003902},{1.960482, 0.059432, 0.002656}}],
    Polygon[{{1.962848, 0.058541, 0.003902},{1.962631, 0.057871, 0.005052},{
      1.960482, 0.058211, 0.005052},{1.960482, 0.058916, 0.003902}}],
    Polygon[{{1.962631, 0.057871, 0.005052},{1.962360, 0.057038, 0.006077},{
      1.960482, 0.057336, 0.006077},{1.960482, 0.058211, 0.005052}}],
    Polygon[{{1.962360, 0.057038, 0.006077},{1.962043, 0.056063, 0.006953},{
      1.960482, 0.056310, 0.006953},{1.960482, 0.057336, 0.006077}}],
    Polygon[{{1.962043, 0.056063, 0.006953},{1.961688, 0.054969, 0.007658},{
      1.960482, 0.055160, 0.007658},{1.960482, 0.056310, 0.006953}}],
    Polygon[{{1.961688, 0.054969, 0.007658},{1.961303, 0.053784, 0.008174},{
      1.960482, 0.053914, 0.008174},{1.960482, 0.055160, 0.007658}}],
    Polygon[{{1.961303, 0.053784, 0.008174},{1.960897, 0.052537, 0.008489},{
      1.960482, 0.052603, 0.008489},{1.960482, 0.053914, 0.008174}}],
    Polygon[{{1.960482, 0.052603, -0.008489},{1.960482, 0.053914, -0.008174},{
      1.959661, 0.053784, -0.008174},{1.960066, 0.052537, -0.008489}}],
    Polygon[{{1.960482, 0.053914, -0.008174},{1.960482, 0.055160, -0.007658},{
      1.959276, 0.054969, -0.007658},{1.959661, 0.053784, -0.008174}}],
    Polygon[{{1.960482, 0.055160, -0.007658},{1.960482, 0.056310, -0.006953},{
      1.958921, 0.056063, -0.006953},{1.959276, 0.054969, -0.007658}}],
    Polygon[{{1.960482, 0.056310, -0.006953},{1.960482, 0.057336, -0.006077},{
      1.958604, 0.057038, -0.006077},{1.958921, 0.056063, -0.006953}}],
    Polygon[{{1.960482, 0.057336, -0.006077},{1.960482, 0.058211, -0.005052},{
      1.958333, 0.057871, -0.005052},{1.958604, 0.057038, -0.006077}}],
    Polygon[{{1.960482, 0.058211, -0.005052},{1.960482, 0.058916, -0.003902},{
      1.958116, 0.058541, -0.003902},{1.958333, 0.057871, -0.005052}}],
    Polygon[{{1.960482, 0.058916, -0.003902},{1.960482, 0.059432, -0.002656},{
      1.957956, 0.059032, -0.002656},{1.958116, 0.058541, -0.003902}}],
    Polygon[{{1.960482, 0.059432, -0.002656},{1.960482, 0.059747, -0.001344},{
      1.957859, 0.059332, -0.001344},{1.957956, 0.059032, -0.002656}}],
    Polygon[{{1.960482, 0.059747, -0.001344},{1.960482, 0.059853, 0.000000},{
      1.957826, 0.059432, 0.000000},{1.957859, 0.059332, -0.001344}}],
    Polygon[{{1.960482, 0.059853, 0.000000},{1.960482, 0.059747, 0.001344},{
      1.957859, 0.059332, 0.001344},{1.957826, 0.059432, 0.000000}}],
    Polygon[{{1.960482, 0.059747, 0.001344},{1.960482, 0.059432, 0.002656},{
      1.957956, 0.059032, 0.002656},{1.957859, 0.059332, 0.001344}}],
    Polygon[{{1.960482, 0.059432, 0.002656},{1.960482, 0.058916, 0.003902},{
      1.958116, 0.058541, 0.003902},{1.957956, 0.059032, 0.002656}}],
    Polygon[{{1.960482, 0.058916, 0.003902},{1.960482, 0.058211, 0.005052},{
      1.958333, 0.057871, 0.005052},{1.958116, 0.058541, 0.003902}}],
    Polygon[{{1.960482, 0.058211, 0.005052},{1.960482, 0.057336, 0.006077},{
      1.958604, 0.057038, 0.006077},{1.958333, 0.057871, 0.005052}}],
    Polygon[{{1.960482, 0.057336, 0.006077},{1.960482, 0.056310, 0.006953},{
      1.958921, 0.056063, 0.006953},{1.958604, 0.057038, 0.006077}}],
    Polygon[{{1.960482, 0.056310, 0.006953},{1.960482, 0.055160, 0.007658},{
      1.959276, 0.054969, 0.007658},{1.958921, 0.056063, 0.006953}}],
    Polygon[{{1.960482, 0.055160, 0.007658},{1.960482, 0.053914, 0.008174},{
      1.959661, 0.053784, 0.008174},{1.959276, 0.054969, 0.007658}}],
    Polygon[{{1.960482, 0.053914, 0.008174},{1.960482, 0.052603, 0.008489},{
      1.960066, 0.052537, 0.008489},{1.959661, 0.053784, 0.008174}}],
    Polygon[{{1.960066, 0.052537, -0.008489},{1.959661, 0.053784, -0.008174},{
      1.958921, 0.053407, -0.008174},{1.959692, 0.052346, -0.008489}}],
    Polygon[{{1.959661, 0.053784, -0.008174},{1.959276, 0.054969, -0.007658},{
      1.958189, 0.054415, -0.007658},{1.958921, 0.053407, -0.008174}}],
    Polygon[{{1.959276, 0.054969, -0.007658},{1.958921, 0.056063, -0.006953},{
      1.957513, 0.055345, -0.006953},{1.958189, 0.054415, -0.007658}}],
    Polygon[{{1.958921, 0.056063, -0.006953},{1.958604, 0.057038, -0.006077},{
      1.956910, 0.056175, -0.006077},{1.957513, 0.055345, -0.006953}}],
    Polygon[{{1.958604, 0.057038, -0.006077},{1.958333, 0.057871, -0.005052},{
      1.956395, 0.056883, -0.005052},{1.956910, 0.056175, -0.006077}}],
    Polygon[{{1.958333, 0.057871, -0.005052},{1.958116, 0.058541, -0.003902},{
      1.955981, 0.057454, -0.003902},{1.956395, 0.056883, -0.005052}}],
    Polygon[{{1.958116, 0.058541, -0.003902},{1.957956, 0.059032, -0.002656},{
      1.955678, 0.057871, -0.002656},{1.955981, 0.057454, -0.003902}}],
    Polygon[{{1.957956, 0.059032, -0.002656},{1.957859, 0.059332, -0.001344},{
      1.955492, 0.058126, -0.001344},{1.955678, 0.057871, -0.002656}}],
    Polygon[{{1.957859, 0.059332, -0.001344},{1.957826, 0.059432, 0.000000},{
      1.955430, 0.058211, 0.000000},{1.955492, 0.058126, -0.001344}}],
    Polygon[{{1.957826, 0.059432, 0.000000},{1.957859, 0.059332, 0.001344},{
      1.955492, 0.058126, 0.001344},{1.955430, 0.058211, 0.000000}}],
    Polygon[{{1.957859, 0.059332, 0.001344},{1.957956, 0.059032, 0.002656},{
      1.955678, 0.057871, 0.002656},{1.955492, 0.058126, 0.001344}}],
    Polygon[{{1.957956, 0.059032, 0.002656},{1.958116, 0.058541, 0.003902},{
      1.955981, 0.057454, 0.003902},{1.955678, 0.057871, 0.002656}}],
    Polygon[{{1.958116, 0.058541, 0.003902},{1.958333, 0.057871, 0.005052},{
      1.956395, 0.056883, 0.005052},{1.955981, 0.057454, 0.003902}}],
    Polygon[{{1.958333, 0.057871, 0.005052},{1.958604, 0.057038, 0.006077},{
      1.956910, 0.056175, 0.006077},{1.956395, 0.056883, 0.005052}}],
    Polygon[{{1.958604, 0.057038, 0.006077},{1.958921, 0.056063, 0.006953},{
      1.957513, 0.055345, 0.006953},{1.956910, 0.056175, 0.006077}}],
    Polygon[{{1.958921, 0.056063, 0.006953},{1.959276, 0.054969, 0.007658},{
      1.958189, 0.054415, 0.007658},{1.957513, 0.055345, 0.006953}}],
    Polygon[{{1.959276, 0.054969, 0.007658},{1.959661, 0.053784, 0.008174},{
      1.958921, 0.053407, 0.008174},{1.958189, 0.054415, 0.007658}}],
    Polygon[{{1.959661, 0.053784, 0.008174},{1.960066, 0.052537, 0.008489},{
      1.959692, 0.052346, 0.008489},{1.958921, 0.053407, 0.008174}}],
    Polygon[{{1.959692, 0.052346, -0.008489},{1.958921, 0.053407, -0.008174},{
      1.958333, 0.052819, -0.008174},{1.959394, 0.052049, -0.008489}}],
    Polygon[{{1.958921, 0.053407, -0.008174},{1.958189, 0.054415, -0.007658},{
      1.957325, 0.053552, -0.007658},{1.958333, 0.052819, -0.008174}}],
    Polygon[{{1.958189, 0.054415, -0.007658},{1.957513, 0.055345, -0.006953},{
      1.956395, 0.054228, -0.006953},{1.957325, 0.053552, -0.007658}}],
    Polygon[{{1.957513, 0.055345, -0.006953},{1.956910, 0.056175, -0.006077},{
      1.955565, 0.054830, -0.006077},{1.956395, 0.054228, -0.006953}}],
    Polygon[{{1.956910, 0.056175, -0.006077},{1.956395, 0.056883, -0.005052},{
      1.954857, 0.055345, -0.005052},{1.955565, 0.054830, -0.006077}}],
    Polygon[{{1.956395, 0.056883, -0.005052},{1.955981, 0.057454, -0.003902},{
      1.954287, 0.055759, -0.003902},{1.954857, 0.055345, -0.005052}}],
    Polygon[{{1.955981, 0.057454, -0.003902},{1.955678, 0.057871, -0.002656},{
      1.953869, 0.056063, -0.002656},{1.954287, 0.055759, -0.003902}}],
    Polygon[{{1.955678, 0.057871, -0.002656},{1.955492, 0.058126, -0.001344},{
      1.953614, 0.056248, -0.001344},{1.953869, 0.056063, -0.002656}}],
    Polygon[{{1.955492, 0.058126, -0.001344},{1.955430, 0.058211, 0.000000},{
      1.953529, 0.056310, 0.000000},{1.953614, 0.056248, -0.001344}}],
    Polygon[{{1.955430, 0.058211, 0.000000},{1.955492, 0.058126, 0.001344},{
      1.953614, 0.056248, 0.001344},{1.953529, 0.056310, 0.000000}}],
    Polygon[{{1.955492, 0.058126, 0.001344},{1.955678, 0.057871, 0.002656},{
      1.953869, 0.056063, 0.002656},{1.953614, 0.056248, 0.001344}}],
    Polygon[{{1.955678, 0.057871, 0.002656},{1.955981, 0.057454, 0.003902},{
      1.954287, 0.055759, 0.003902},{1.953869, 0.056063, 0.002656}}],
    Polygon[{{1.955981, 0.057454, 0.003902},{1.956395, 0.056883, 0.005052},{
      1.954857, 0.055345, 0.005052},{1.954287, 0.055759, 0.003902}}],
    Polygon[{{1.956395, 0.056883, 0.005052},{1.956910, 0.056175, 0.006077},{
      1.955565, 0.054830, 0.006077},{1.954857, 0.055345, 0.005052}}],
    Polygon[{{1.956910, 0.056175, 0.006077},{1.957513, 0.055345, 0.006953},{
      1.956395, 0.054228, 0.006953},{1.955565, 0.054830, 0.006077}}],
    Polygon[{{1.957513, 0.055345, 0.006953},{1.958189, 0.054415, 0.007658},{
      1.957325, 0.053552, 0.007658},{1.956395, 0.054228, 0.006953}}],
    Polygon[{{1.958189, 0.054415, 0.007658},{1.958921, 0.053407, 0.008174},{
      1.958333, 0.052819, 0.008174},{1.957325, 0.053552, 0.007658}}],
    Polygon[{{1.958921, 0.053407, 0.008174},{1.959692, 0.052346, 0.008489},{
      1.959394, 0.052049, 0.008489},{1.958333, 0.052819, 0.008174}}],
    Polygon[{{1.959394, 0.052049, -0.008489},{1.958333, 0.052819, -0.008174},{
      1.957956, 0.052079, -0.008174},{1.959203, 0.051674, -0.008489}}],
    Polygon[{{1.958333, 0.052819, -0.008174},{1.957325, 0.053552, -0.007658},{
      1.956771, 0.052464, -0.007658},{1.957956, 0.052079, -0.008174}}],
    Polygon[{{1.957325, 0.053552, -0.007658},{1.956395, 0.054228, -0.006953},{
      1.955678, 0.052819, -0.006953},{1.956771, 0.052464, -0.007658}}],
    Polygon[{{1.956395, 0.054228, -0.006953},{1.955565, 0.054830, -0.006077},{
      1.954702, 0.053136, -0.006077},{1.955678, 0.052819, -0.006953}}],
    Polygon[{{1.955565, 0.054830, -0.006077},{1.954857, 0.055345, -0.005052},{
      1.953869, 0.053407, -0.005052},{1.954702, 0.053136, -0.006077}}],
    Polygon[{{1.954857, 0.055345, -0.005052},{1.954287, 0.055759, -0.003902},{
      1.953199, 0.053625, -0.003902},{1.953869, 0.053407, -0.005052}}],
    Polygon[{{1.954287, 0.055759, -0.003902},{1.953869, 0.056063, -0.002656},{
      1.952708, 0.053784, -0.002656},{1.953199, 0.053625, -0.003902}}],
    Polygon[{{1.953869, 0.056063, -0.002656},{1.953614, 0.056248, -0.001344},{
      1.952409, 0.053881, -0.001344},{1.952708, 0.053784, -0.002656}}],
    Polygon[{{1.953614, 0.056248, -0.001344},{1.953529, 0.056310, 0.000000},{
      1.952308, 0.053914, 0.000000},{1.952409, 0.053881, -0.001344}}],
    Polygon[{{1.953529, 0.056310, 0.000000},{1.953614, 0.056248, 0.001344},{
      1.952409, 0.053881, 0.001344},{1.952308, 0.053914, 0.000000}}],
    Polygon[{{1.953614, 0.056248, 0.001344},{1.953869, 0.056063, 0.002656},{
      1.952708, 0.053784, 0.002656},{1.952409, 0.053881, 0.001344}}],
    Polygon[{{1.953869, 0.056063, 0.002656},{1.954287, 0.055759, 0.003902},{
      1.953199, 0.053625, 0.003902},{1.952708, 0.053784, 0.002656}}],
    Polygon[{{1.954287, 0.055759, 0.003902},{1.954857, 0.055345, 0.005052},{
      1.953869, 0.053407, 0.005052},{1.953199, 0.053625, 0.003902}}],
    Polygon[{{1.954857, 0.055345, 0.005052},{1.955565, 0.054830, 0.006077},{
      1.954702, 0.053136, 0.006077},{1.953869, 0.053407, 0.005052}}],
    Polygon[{{1.955565, 0.054830, 0.006077},{1.956395, 0.054228, 0.006953},{
      1.955678, 0.052819, 0.006953},{1.954702, 0.053136, 0.006077}}],
    Polygon[{{1.956395, 0.054228, 0.006953},{1.957325, 0.053552, 0.007658},{
      1.956771, 0.052464, 0.007658},{1.955678, 0.052819, 0.006953}}],
    Polygon[{{1.957325, 0.053552, 0.007658},{1.958333, 0.052819, 0.008174},{
      1.957956, 0.052079, 0.008174},{1.956771, 0.052464, 0.007658}}],
    Polygon[{{1.958333, 0.052819, 0.008174},{1.959394, 0.052049, 0.008489},{
      1.959203, 0.051674, 0.008489},{1.957956, 0.052079, 0.008174}}],
    Polygon[{{1.959203, 0.051674, -0.008489},{1.957956, 0.052079, -0.008174},{
      1.957826, 0.051258, -0.008174},{1.959137, 0.051258, -0.008489}}],
    Polygon[{{1.957956, 0.052079, -0.008174},{1.956771, 0.052464, -0.007658},{
      1.956580, 0.051258, -0.007658},{1.957826, 0.051258, -0.008174}}],
    Polygon[{{1.956771, 0.052464, -0.007658},{1.955678, 0.052819, -0.006953},{
      1.955430, 0.051258, -0.006953},{1.956580, 0.051258, -0.007658}}],
    Polygon[{{1.955678, 0.052819, -0.006953},{1.954702, 0.053136, -0.006077},{
      1.954405, 0.051258, -0.006077},{1.955430, 0.051258, -0.006953}}],
    Polygon[{{1.954702, 0.053136, -0.006077},{1.953869, 0.053407, -0.005052},{
      1.953529, 0.051258, -0.005052},{1.954405, 0.051258, -0.006077}}],
    Polygon[{{1.953869, 0.053407, -0.005052},{1.953199, 0.053625, -0.003902},{
      1.952824, 0.051258, -0.003902},{1.953529, 0.051258, -0.005052}}],
    Polygon[{{1.953199, 0.053625, -0.003902},{1.952708, 0.053784, -0.002656},{
      1.952308, 0.051258, -0.002656},{1.952824, 0.051258, -0.003902}}],
    Polygon[{{1.952708, 0.053784, -0.002656},{1.952409, 0.053881, -0.001344},{
      1.951993, 0.051258, -0.001344},{1.952308, 0.051258, -0.002656}}],
    Polygon[{{1.952409, 0.053881, -0.001344},{1.952308, 0.053914, 0.000000},{
      1.951887, 0.051258, 0.000000},{1.951993, 0.051258, -0.001344}}],
    Polygon[{{1.952308, 0.053914, 0.000000},{1.952409, 0.053881, 0.001344},{
      1.951993, 0.051258, 0.001344},{1.951887, 0.051258, 0.000000}}],
    Polygon[{{1.952409, 0.053881, 0.001344},{1.952708, 0.053784, 0.002656},{
      1.952308, 0.051258, 0.002656},{1.951993, 0.051258, 0.001344}}],
    Polygon[{{1.952708, 0.053784, 0.002656},{1.953199, 0.053625, 0.003902},{
      1.952824, 0.051258, 0.003902},{1.952308, 0.051258, 0.002656}}],
    Polygon[{{1.953199, 0.053625, 0.003902},{1.953869, 0.053407, 0.005052},{
      1.953529, 0.051258, 0.005052},{1.952824, 0.051258, 0.003902}}],
    Polygon[{{1.953869, 0.053407, 0.005052},{1.954702, 0.053136, 0.006077},{
      1.954405, 0.051258, 0.006077},{1.953529, 0.051258, 0.005052}}],
    Polygon[{{1.954702, 0.053136, 0.006077},{1.955678, 0.052819, 0.006953},{
      1.955430, 0.051258, 0.006953},{1.954405, 0.051258, 0.006077}}],
    Polygon[{{1.955678, 0.052819, 0.006953},{1.956771, 0.052464, 0.007658},{
      1.956580, 0.051258, 0.007658},{1.955430, 0.051258, 0.006953}}],
    Polygon[{{1.956771, 0.052464, 0.007658},{1.957956, 0.052079, 0.008174},{
      1.957826, 0.051258, 0.008174},{1.956580, 0.051258, 0.007658}}],
    Polygon[{{1.957956, 0.052079, 0.008174},{1.959203, 0.051674, 0.008489},{
      1.959137, 0.051258, 0.008489},{1.957826, 0.051258, 0.008174}}],
    Polygon[{{1.959137, 0.051258, -0.008489},{1.957826, 0.051258, -0.008174},{
      1.957956, 0.050438, -0.008174},{1.959203, 0.050843, -0.008489}}],
    Polygon[{{1.957826, 0.051258, -0.008174},{1.956580, 0.051258, -0.007658},{
      1.956771, 0.050053, -0.007658},{1.957956, 0.050438, -0.008174}}],
    Polygon[{{1.956580, 0.051258, -0.007658},{1.955430, 0.051258, -0.006953},{
      1.955678, 0.049697, -0.006953},{1.956771, 0.050053, -0.007658}}],
    Polygon[{{1.955430, 0.051258, -0.006953},{1.954405, 0.051258, -0.006077},{
      1.954702, 0.049380, -0.006077},{1.955678, 0.049697, -0.006953}}],
    Polygon[{{1.954405, 0.051258, -0.006077},{1.953529, 0.051258, -0.005052},{
      1.953869, 0.049110, -0.005052},{1.954702, 0.049380, -0.006077}}],
    Polygon[{{1.953529, 0.051258, -0.005052},{1.952824, 0.051258, -0.003902},{
      1.953199, 0.048892, -0.003902},{1.953869, 0.049110, -0.005052}}],
    Polygon[{{1.952824, 0.051258, -0.003902},{1.952308, 0.051258, -0.002656},{
      1.952708, 0.048732, -0.002656},{1.953199, 0.048892, -0.003902}}],
    Polygon[{{1.952308, 0.051258, -0.002656},{1.951993, 0.051258, -0.001344},{
      1.952409, 0.048635, -0.001344},{1.952708, 0.048732, -0.002656}}],
    Polygon[{{1.951993, 0.051258, -0.001344},{1.951887, 0.051258, 0.000000},{
      1.952308, 0.048602, 0.000000},{1.952409, 0.048635, -0.001344}}],
    Polygon[{{1.951887, 0.051258, 0.000000},{1.951993, 0.051258, 0.001344},{
      1.952409, 0.048635, 0.001344},{1.952308, 0.048602, 0.000000}}],
    Polygon[{{1.951993, 0.051258, 0.001344},{1.952308, 0.051258, 0.002656},{
      1.952708, 0.048732, 0.002656},{1.952409, 0.048635, 0.001344}}],
    Polygon[{{1.952308, 0.051258, 0.002656},{1.952824, 0.051258, 0.003902},{
      1.953199, 0.048892, 0.003902},{1.952708, 0.048732, 0.002656}}],
    Polygon[{{1.952824, 0.051258, 0.003902},{1.953529, 0.051258, 0.005052},{
      1.953869, 0.049110, 0.005052},{1.953199, 0.048892, 0.003902}}],
    Polygon[{{1.953529, 0.051258, 0.005052},{1.954405, 0.051258, 0.006077},{
      1.954702, 0.049380, 0.006077},{1.953869, 0.049110, 0.005052}}],
    Polygon[{{1.954405, 0.051258, 0.006077},{1.955430, 0.051258, 0.006953},{
      1.955678, 0.049697, 0.006953},{1.954702, 0.049380, 0.006077}}],
    Polygon[{{1.955430, 0.051258, 0.006953},{1.956580, 0.051258, 0.007658},{
      1.956771, 0.050053, 0.007658},{1.955678, 0.049697, 0.006953}}],
    Polygon[{{1.956580, 0.051258, 0.007658},{1.957826, 0.051258, 0.008174},{
      1.957956, 0.050438, 0.008174},{1.956771, 0.050053, 0.007658}}],
    Polygon[{{1.957826, 0.051258, 0.008174},{1.959137, 0.051258, 0.008489},{
      1.959203, 0.050843, 0.008489},{1.957956, 0.050438, 0.008174}}],
    Polygon[{{1.959203, 0.050843, -0.008489},{1.957956, 0.050438, -0.008174},{
      1.958333, 0.049697, -0.008174},{1.959394, 0.050468, -0.008489}}],
    Polygon[{{1.957956, 0.050438, -0.008174},{1.956771, 0.050053, -0.007658},{
      1.957325, 0.048965, -0.007658},{1.958333, 0.049697, -0.008174}}],
    Polygon[{{1.956771, 0.050053, -0.007658},{1.955678, 0.049697, -0.006953},{
      1.956395, 0.048289, -0.006953},{1.957325, 0.048965, -0.007658}}],
    Polygon[{{1.955678, 0.049697, -0.006953},{1.954702, 0.049380, -0.006077},{
      1.955565, 0.047686, -0.006077},{1.956395, 0.048289, -0.006953}}],
    Polygon[{{1.954702, 0.049380, -0.006077},{1.953869, 0.049110, -0.005052},{
      1.954857, 0.047171, -0.005052},{1.955565, 0.047686, -0.006077}}],
    Polygon[{{1.953869, 0.049110, -0.005052},{1.953199, 0.048892, -0.003902},{
      1.954287, 0.046757, -0.003902},{1.954857, 0.047171, -0.005052}}],
    Polygon[{{1.953199, 0.048892, -0.003902},{1.952708, 0.048732, -0.002656},{
      1.953869, 0.046454, -0.002656},{1.954287, 0.046757, -0.003902}}],
    Polygon[{{1.952708, 0.048732, -0.002656},{1.952409, 0.048635, -0.001344},{
      1.953614, 0.046269, -0.001344},{1.953869, 0.046454, -0.002656}}],
    Polygon[{{1.952409, 0.048635, -0.001344},{1.952308, 0.048602, 0.000000},{
      1.953529, 0.046207, 0.000000},{1.953614, 0.046269, -0.001344}}],
    Polygon[{{1.952308, 0.048602, 0.000000},{1.952409, 0.048635, 0.001344},{
      1.953614, 0.046269, 0.001344},{1.953529, 0.046207, 0.000000}}],
    Polygon[{{1.952409, 0.048635, 0.001344},{1.952708, 0.048732, 0.002656},{
      1.953869, 0.046454, 0.002656},{1.953614, 0.046269, 0.001344}}],
    Polygon[{{1.952708, 0.048732, 0.002656},{1.953199, 0.048892, 0.003902},{
      1.954287, 0.046757, 0.003902},{1.953869, 0.046454, 0.002656}}],
    Polygon[{{1.953199, 0.048892, 0.003902},{1.953869, 0.049110, 0.005052},{
      1.954857, 0.047171, 0.005052},{1.954287, 0.046757, 0.003902}}],
    Polygon[{{1.953869, 0.049110, 0.005052},{1.954702, 0.049380, 0.006077},{
      1.955565, 0.047686, 0.006077},{1.954857, 0.047171, 0.005052}}],
    Polygon[{{1.954702, 0.049380, 0.006077},{1.955678, 0.049697, 0.006953},{
      1.956395, 0.048289, 0.006953},{1.955565, 0.047686, 0.006077}}],
    Polygon[{{1.955678, 0.049697, 0.006953},{1.956771, 0.050053, 0.007658},{
      1.957325, 0.048965, 0.007658},{1.956395, 0.048289, 0.006953}}],
    Polygon[{{1.956771, 0.050053, 0.007658},{1.957956, 0.050438, 0.008174},{
      1.958333, 0.049697, 0.008174},{1.957325, 0.048965, 0.007658}}],
    Polygon[{{1.957956, 0.050438, 0.008174},{1.959203, 0.050843, 0.008489},{
      1.959394, 0.050468, 0.008489},{1.958333, 0.049697, 0.008174}}],
    Polygon[{{1.959394, 0.050468, -0.008489},{1.958333, 0.049697, -0.008174},{
      1.958921, 0.049110, -0.008174},{1.959692, 0.050171, -0.008489}}],
    Polygon[{{1.958333, 0.049697, -0.008174},{1.957325, 0.048965, -0.007658},{
      1.958189, 0.048102, -0.007658},{1.958921, 0.049110, -0.008174}}],
    Polygon[{{1.957325, 0.048965, -0.007658},{1.956395, 0.048289, -0.006953},{
      1.957513, 0.047171, -0.006953},{1.958189, 0.048102, -0.007658}}],
    Polygon[{{1.956395, 0.048289, -0.006953},{1.955565, 0.047686, -0.006077},{
      1.956910, 0.046342, -0.006077},{1.957513, 0.047171, -0.006953}}],
    Polygon[{{1.955565, 0.047686, -0.006077},{1.954857, 0.047171, -0.005052},{
      1.956395, 0.045633, -0.005052},{1.956910, 0.046342, -0.006077}}],
    Polygon[{{1.954857, 0.047171, -0.005052},{1.954287, 0.046757, -0.003902},{
      1.955981, 0.045063, -0.003902},{1.956395, 0.045633, -0.005052}}],
    Polygon[{{1.954287, 0.046757, -0.003902},{1.953869, 0.046454, -0.002656},{
      1.955678, 0.044646, -0.002656},{1.955981, 0.045063, -0.003902}}],
    Polygon[{{1.953869, 0.046454, -0.002656},{1.953614, 0.046269, -0.001344},{
      1.955492, 0.044391, -0.001344},{1.955678, 0.044646, -0.002656}}],
    Polygon[{{1.953614, 0.046269, -0.001344},{1.953529, 0.046207, 0.000000},{
      1.955430, 0.044305, 0.000000},{1.955492, 0.044391, -0.001344}}],
    Polygon[{{1.953529, 0.046207, 0.000000},{1.953614, 0.046269, 0.001344},{
      1.955492, 0.044391, 0.001344},{1.955430, 0.044305, 0.000000}}],
    Polygon[{{1.953614, 0.046269, 0.001344},{1.953869, 0.046454, 0.002656},{
      1.955678, 0.044646, 0.002656},{1.955492, 0.044391, 0.001344}}],
    Polygon[{{1.953869, 0.046454, 0.002656},{1.954287, 0.046757, 0.003902},{
      1.955981, 0.045063, 0.003902},{1.955678, 0.044646, 0.002656}}],
    Polygon[{{1.954287, 0.046757, 0.003902},{1.954857, 0.047171, 0.005052},{
      1.956395, 0.045633, 0.005052},{1.955981, 0.045063, 0.003902}}],
    Polygon[{{1.954857, 0.047171, 0.005052},{1.955565, 0.047686, 0.006077},{
      1.956910, 0.046342, 0.006077},{1.956395, 0.045633, 0.005052}}],
    Polygon[{{1.955565, 0.047686, 0.006077},{1.956395, 0.048289, 0.006953},{
      1.957513, 0.047171, 0.006953},{1.956910, 0.046342, 0.006077}}],
    Polygon[{{1.956395, 0.048289, 0.006953},{1.957325, 0.048965, 0.007658},{
      1.958189, 0.048102, 0.007658},{1.957513, 0.047171, 0.006953}}],
    Polygon[{{1.957325, 0.048965, 0.007658},{1.958333, 0.049697, 0.008174},{
      1.958921, 0.049110, 0.008174},{1.958189, 0.048102, 0.007658}}],
    Polygon[{{1.958333, 0.049697, 0.008174},{1.959394, 0.050468, 0.008489},{
      1.959692, 0.050171, 0.008489},{1.958921, 0.049110, 0.008174}}],
    Polygon[{{1.959692, 0.050171, -0.008489},{1.958921, 0.049110, -0.008174},{
      1.959661, 0.048732, -0.008174},{1.960066, 0.049980, -0.008489}}],
    Polygon[{{1.958921, 0.049110, -0.008174},{1.958189, 0.048102, -0.007658},{
      1.959276, 0.047547, -0.007658},{1.959661, 0.048732, -0.008174}}],
    Polygon[{{1.958189, 0.048102, -0.007658},{1.957513, 0.047171, -0.006953},{
      1.958921, 0.046454, -0.006953},{1.959276, 0.047547, -0.007658}}],
    Polygon[{{1.957513, 0.047171, -0.006953},{1.956910, 0.046342, -0.006077},{
      1.958604, 0.045479, -0.006077},{1.958921, 0.046454, -0.006953}}],
    Polygon[{{1.956910, 0.046342, -0.006077},{1.956395, 0.045633, -0.005052},{
      1.958333, 0.044646, -0.005052},{1.958604, 0.045479, -0.006077}}],
    Polygon[{{1.956395, 0.045633, -0.005052},{1.955981, 0.045063, -0.003902},{
      1.958116, 0.043975, -0.003902},{1.958333, 0.044646, -0.005052}}],
    Polygon[{{1.955981, 0.045063, -0.003902},{1.955678, 0.044646, -0.002656},{
      1.957956, 0.043485, -0.002656},{1.958116, 0.043975, -0.003902}}],
    Polygon[{{1.955678, 0.044646, -0.002656},{1.955492, 0.044391, -0.001344},{
      1.957859, 0.043185, -0.001344},{1.957956, 0.043485, -0.002656}}],
    Polygon[{{1.955492, 0.044391, -0.001344},{1.955430, 0.044305, 0.000000},{
      1.957826, 0.043084, 0.000000},{1.957859, 0.043185, -0.001344}}],
    Polygon[{{1.955430, 0.044305, 0.000000},{1.955492, 0.044391, 0.001344},{
      1.957859, 0.043185, 0.001344},{1.957826, 0.043084, 0.000000}}],
    Polygon[{{1.955492, 0.044391, 0.001344},{1.955678, 0.044646, 0.002656},{
      1.957956, 0.043485, 0.002656},{1.957859, 0.043185, 0.001344}}],
    Polygon[{{1.955678, 0.044646, 0.002656},{1.955981, 0.045063, 0.003902},{
      1.958116, 0.043975, 0.003902},{1.957956, 0.043485, 0.002656}}],
    Polygon[{{1.955981, 0.045063, 0.003902},{1.956395, 0.045633, 0.005052},{
      1.958333, 0.044646, 0.005052},{1.958116, 0.043975, 0.003902}}],
    Polygon[{{1.956395, 0.045633, 0.005052},{1.956910, 0.046342, 0.006077},{
      1.958604, 0.045479, 0.006077},{1.958333, 0.044646, 0.005052}}],
    Polygon[{{1.956910, 0.046342, 0.006077},{1.957513, 0.047171, 0.006953},{
      1.958921, 0.046454, 0.006953},{1.958604, 0.045479, 0.006077}}],
    Polygon[{{1.957513, 0.047171, 0.006953},{1.958189, 0.048102, 0.007658},{
      1.959276, 0.047547, 0.007658},{1.958921, 0.046454, 0.006953}}],
    Polygon[{{1.958189, 0.048102, 0.007658},{1.958921, 0.049110, 0.008174},{
      1.959661, 0.048732, 0.008174},{1.959276, 0.047547, 0.007658}}],
    Polygon[{{1.958921, 0.049110, 0.008174},{1.959692, 0.050171, 0.008489},{
      1.960066, 0.049980, 0.008489},{1.959661, 0.048732, 0.008174}}],
    Polygon[{{1.960066, 0.049980, -0.008489},{1.959661, 0.048732, -0.008174},{
      1.960482, 0.048602, -0.008174},{1.960482, 0.049914, -0.008489}}],
    Polygon[{{1.959661, 0.048732, -0.008174},{1.959276, 0.047547, -0.007658},{
      1.960482, 0.047357, -0.007658},{1.960482, 0.048602, -0.008174}}],
    Polygon[{{1.959276, 0.047547, -0.007658},{1.958921, 0.046454, -0.006953},{
      1.960482, 0.046207, -0.006953},{1.960482, 0.047357, -0.007658}}],
    Polygon[{{1.958921, 0.046454, -0.006953},{1.958604, 0.045479, -0.006077},{
      1.960482, 0.045181, -0.006077},{1.960482, 0.046207, -0.006953}}],
    Polygon[{{1.958604, 0.045479, -0.006077},{1.958333, 0.044646, -0.005052},{
      1.960482, 0.044305, -0.005052},{1.960482, 0.045181, -0.006077}}],
    Polygon[{{1.958333, 0.044646, -0.005052},{1.958116, 0.043975, -0.003902},{
      1.960482, 0.043601, -0.003902},{1.960482, 0.044305, -0.005052}}],
    Polygon[{{1.958116, 0.043975, -0.003902},{1.957956, 0.043485, -0.002656},{
      1.960482, 0.043084, -0.002656},{1.960482, 0.043601, -0.003902}}],
    Polygon[{{1.957956, 0.043485, -0.002656},{1.957859, 0.043185, -0.001344},{
      1.960482, 0.042770, -0.001344},{1.960482, 0.043084, -0.002656}}],
    Polygon[{{1.957859, 0.043185, -0.001344},{1.957826, 0.043084, 0.000000},{
      1.960482, 0.042664, 0.000000},{1.960482, 0.042770, -0.001344}}],
    Polygon[{{1.957826, 0.043084, 0.000000},{1.957859, 0.043185, 0.001344},{
      1.960482, 0.042770, 0.001344},{1.960482, 0.042664, 0.000000}}],
    Polygon[{{1.957859, 0.043185, 0.001344},{1.957956, 0.043485, 0.002656},{
      1.960482, 0.043084, 0.002656},{1.960482, 0.042770, 0.001344}}],
    Polygon[{{1.957956, 0.043485, 0.002656},{1.958116, 0.043975, 0.003902},{
      1.960482, 0.043601, 0.003902},{1.960482, 0.043084, 0.002656}}],
    Polygon[{{1.958116, 0.043975, 0.003902},{1.958333, 0.044646, 0.005052},{
      1.960482, 0.044305, 0.005052},{1.960482, 0.043601, 0.003902}}],
    Polygon[{{1.958333, 0.044646, 0.005052},{1.958604, 0.045479, 0.006077},{
      1.960482, 0.045181, 0.006077},{1.960482, 0.044305, 0.005052}}],
    Polygon[{{1.958604, 0.045479, 0.006077},{1.958921, 0.046454, 0.006953},{
      1.960482, 0.046207, 0.006953},{1.960482, 0.045181, 0.006077}}],
    Polygon[{{1.958921, 0.046454, 0.006953},{1.959276, 0.047547, 0.007658},{
      1.960482, 0.047357, 0.007658},{1.960482, 0.046207, 0.006953}}],
    Polygon[{{1.959276, 0.047547, 0.007658},{1.959661, 0.048732, 0.008174},{
      1.960482, 0.048602, 0.008174},{1.960482, 0.047357, 0.007658}}],
    Polygon[{{1.959661, 0.048732, 0.008174},{1.960066, 0.049980, 0.008489},{
      1.960482, 0.049914, 0.008489},{1.960482, 0.048602, 0.008174}}],
    Polygon[{{1.960482, 0.049914, -0.008489},{1.960482, 0.048602, -0.008174},{
      1.961303, 0.048732, -0.008174},{1.960897, 0.049980, -0.008489}}],
    Polygon[{{1.960482, 0.048602, -0.008174},{1.960482, 0.047357, -0.007658},{
      1.961688, 0.047547, -0.007658},{1.961303, 0.048732, -0.008174}}],
    Polygon[{{1.960482, 0.047357, -0.007658},{1.960482, 0.046207, -0.006953},{
      1.962043, 0.046454, -0.006953},{1.961688, 0.047547, -0.007658}}],
    Polygon[{{1.960482, 0.046207, -0.006953},{1.960482, 0.045181, -0.006077},{
      1.962360, 0.045479, -0.006077},{1.962043, 0.046454, -0.006953}}],
    Polygon[{{1.960482, 0.045181, -0.006077},{1.960482, 0.044305, -0.005052},{
      1.962631, 0.044646, -0.005052},{1.962360, 0.045479, -0.006077}}],
    Polygon[{{1.960482, 0.044305, -0.005052},{1.960482, 0.043601, -0.003902},{
      1.962848, 0.043975, -0.003902},{1.962631, 0.044646, -0.005052}}],
    Polygon[{{1.960482, 0.043601, -0.003902},{1.960482, 0.043084, -0.002656},{
      1.963008, 0.043485, -0.002656},{1.962848, 0.043975, -0.003902}}],
    Polygon[{{1.960482, 0.043084, -0.002656},{1.960482, 0.042770, -0.001344},{
      1.963105, 0.043185, -0.001344},{1.963008, 0.043485, -0.002656}}],
    Polygon[{{1.960482, 0.042770, -0.001344},{1.960482, 0.042664, 0.000000},{
      1.963138, 0.043084, 0.000000},{1.963105, 0.043185, -0.001344}}],
    Polygon[{{1.960482, 0.042664, 0.000000},{1.960482, 0.042770, 0.001344},{
      1.963105, 0.043185, 0.001344},{1.963138, 0.043084, 0.000000}}],
    Polygon[{{1.960482, 0.042770, 0.001344},{1.960482, 0.043084, 0.002656},{
      1.963008, 0.043485, 0.002656},{1.963105, 0.043185, 0.001344}}],
    Polygon[{{1.960482, 0.043084, 0.002656},{1.960482, 0.043601, 0.003902},{
      1.962848, 0.043975, 0.003902},{1.963008, 0.043485, 0.002656}}],
    Polygon[{{1.960482, 0.043601, 0.003902},{1.960482, 0.044305, 0.005052},{
      1.962631, 0.044646, 0.005052},{1.962848, 0.043975, 0.003902}}],
    Polygon[{{1.960482, 0.044305, 0.005052},{1.960482, 0.045181, 0.006077},{
      1.962360, 0.045479, 0.006077},{1.962631, 0.044646, 0.005052}}],
    Polygon[{{1.960482, 0.045181, 0.006077},{1.960482, 0.046207, 0.006953},{
      1.962043, 0.046454, 0.006953},{1.962360, 0.045479, 0.006077}}],
    Polygon[{{1.960482, 0.046207, 0.006953},{1.960482, 0.047357, 0.007658},{
      1.961688, 0.047547, 0.007658},{1.962043, 0.046454, 0.006953}}],
    Polygon[{{1.960482, 0.047357, 0.007658},{1.960482, 0.048602, 0.008174},{
      1.961303, 0.048732, 0.008174},{1.961688, 0.047547, 0.007658}}],
    Polygon[{{1.960482, 0.048602, 0.008174},{1.960482, 0.049914, 0.008489},{
      1.960897, 0.049980, 0.008489},{1.961303, 0.048732, 0.008174}}],
    Polygon[{{1.960897, 0.049980, -0.008489},{1.961303, 0.048732, -0.008174},{
      1.962043, 0.049110, -0.008174},{1.961272, 0.050171, -0.008489}}],
    Polygon[{{1.961303, 0.048732, -0.008174},{1.961688, 0.047547, -0.007658},{
      1.962775, 0.048102, -0.007658},{1.962043, 0.049110, -0.008174}}],
    Polygon[{{1.961688, 0.047547, -0.007658},{1.962043, 0.046454, -0.006953},{
      1.963451, 0.047171, -0.006953},{1.962775, 0.048102, -0.007658}}],
    Polygon[{{1.962043, 0.046454, -0.006953},{1.962360, 0.045479, -0.006077},{
      1.964054, 0.046342, -0.006077},{1.963451, 0.047171, -0.006953}}],
    Polygon[{{1.962360, 0.045479, -0.006077},{1.962631, 0.044646, -0.005052},{
      1.964569, 0.045633, -0.005052},{1.964054, 0.046342, -0.006077}}],
    Polygon[{{1.962631, 0.044646, -0.005052},{1.962848, 0.043975, -0.003902},{
      1.964983, 0.045063, -0.003902},{1.964569, 0.045633, -0.005052}}],
    Polygon[{{1.962848, 0.043975, -0.003902},{1.963008, 0.043485, -0.002656},{
      1.965286, 0.044646, -0.002656},{1.964983, 0.045063, -0.003902}}],
    Polygon[{{1.963008, 0.043485, -0.002656},{1.963105, 0.043185, -0.001344},{
      1.965472, 0.044391, -0.001344},{1.965286, 0.044646, -0.002656}}],
    Polygon[{{1.963105, 0.043185, -0.001344},{1.963138, 0.043084, 0.000000},{
      1.965534, 0.044305, 0.000000},{1.965472, 0.044391, -0.001344}}],
    Polygon[{{1.963138, 0.043084, 0.000000},{1.963105, 0.043185, 0.001344},{
      1.965472, 0.044391, 0.001344},{1.965534, 0.044305, 0.000000}}],
    Polygon[{{1.963105, 0.043185, 0.001344},{1.963008, 0.043485, 0.002656},{
      1.965286, 0.044646, 0.002656},{1.965472, 0.044391, 0.001344}}],
    Polygon[{{1.963008, 0.043485, 0.002656},{1.962848, 0.043975, 0.003902},{
      1.964983, 0.045063, 0.003902},{1.965286, 0.044646, 0.002656}}],
    Polygon[{{1.962848, 0.043975, 0.003902},{1.962631, 0.044646, 0.005052},{
      1.964569, 0.045633, 0.005052},{1.964983, 0.045063, 0.003902}}],
    Polygon[{{1.962631, 0.044646, 0.005052},{1.962360, 0.045479, 0.006077},{
      1.964054, 0.046342, 0.006077},{1.964569, 0.045633, 0.005052}}],
    Polygon[{{1.962360, 0.045479, 0.006077},{1.962043, 0.046454, 0.006953},{
      1.963451, 0.047171, 0.006953},{1.964054, 0.046342, 0.006077}}],
    Polygon[{{1.962043, 0.046454, 0.006953},{1.961688, 0.047547, 0.007658},{
      1.962775, 0.048102, 0.007658},{1.963451, 0.047171, 0.006953}}],
    Polygon[{{1.961688, 0.047547, 0.007658},{1.961303, 0.048732, 0.008174},{
      1.962043, 0.049110, 0.008174},{1.962775, 0.048102, 0.007658}}],
    Polygon[{{1.961303, 0.048732, 0.008174},{1.960897, 0.049980, 0.008489},{
      1.961272, 0.050171, 0.008489},{1.962043, 0.049110, 0.008174}}],
    Polygon[{{1.961272, 0.050171, -0.008489},{1.962043, 0.049110, -0.008174},{
      1.962631, 0.049697, -0.008174},{1.961570, 0.050468, -0.008489}}],
    Polygon[{{1.962043, 0.049110, -0.008174},{1.962775, 0.048102, -0.007658},{
      1.963639, 0.048965, -0.007658},{1.962631, 0.049697, -0.008174}}],
    Polygon[{{1.962775, 0.048102, -0.007658},{1.963451, 0.047171, -0.006953},{
      1.964569, 0.048289, -0.006953},{1.963639, 0.048965, -0.007658}}],
    Polygon[{{1.963451, 0.047171, -0.006953},{1.964054, 0.046342, -0.006077},{
      1.965399, 0.047686, -0.006077},{1.964569, 0.048289, -0.006953}}],
    Polygon[{{1.964054, 0.046342, -0.006077},{1.964569, 0.045633, -0.005052},{
      1.966107, 0.047171, -0.005052},{1.965399, 0.047686, -0.006077}}],
    Polygon[{{1.964569, 0.045633, -0.005052},{1.964983, 0.045063, -0.003902},{
      1.966677, 0.046757, -0.003902},{1.966107, 0.047171, -0.005052}}],
    Polygon[{{1.964983, 0.045063, -0.003902},{1.965286, 0.044646, -0.002656},{
      1.967095, 0.046454, -0.002656},{1.966677, 0.046757, -0.003902}}],
    Polygon[{{1.965286, 0.044646, -0.002656},{1.965472, 0.044391, -0.001344},{
      1.967349, 0.046269, -0.001344},{1.967095, 0.046454, -0.002656}}],
    Polygon[{{1.965472, 0.044391, -0.001344},{1.965534, 0.044305, 0.000000},{
      1.967435, 0.046207, 0.000000},{1.967349, 0.046269, -0.001344}}],
    Polygon[{{1.965534, 0.044305, 0.000000},{1.965472, 0.044391, 0.001344},{
      1.967349, 0.046269, 0.001344},{1.967435, 0.046207, 0.000000}}],
    Polygon[{{1.965472, 0.044391, 0.001344},{1.965286, 0.044646, 0.002656},{
      1.967095, 0.046454, 0.002656},{1.967349, 0.046269, 0.001344}}],
    Polygon[{{1.965286, 0.044646, 0.002656},{1.964983, 0.045063, 0.003902},{
      1.966677, 0.046757, 0.003902},{1.967095, 0.046454, 0.002656}}],
    Polygon[{{1.964983, 0.045063, 0.003902},{1.964569, 0.045633, 0.005052},{
      1.966107, 0.047171, 0.005052},{1.966677, 0.046757, 0.003902}}],
    Polygon[{{1.964569, 0.045633, 0.005052},{1.964054, 0.046342, 0.006077},{
      1.965399, 0.047686, 0.006077},{1.966107, 0.047171, 0.005052}}],
    Polygon[{{1.964054, 0.046342, 0.006077},{1.963451, 0.047171, 0.006953},{
      1.964569, 0.048289, 0.006953},{1.965399, 0.047686, 0.006077}}],
    Polygon[{{1.963451, 0.047171, 0.006953},{1.962775, 0.048102, 0.007658},{
      1.963639, 0.048965, 0.007658},{1.964569, 0.048289, 0.006953}}],
    Polygon[{{1.962775, 0.048102, 0.007658},{1.962043, 0.049110, 0.008174},{
      1.962631, 0.049697, 0.008174},{1.963639, 0.048965, 0.007658}}],
    Polygon[{{1.962043, 0.049110, 0.008174},{1.961272, 0.050171, 0.008489},{
      1.961570, 0.050468, 0.008489},{1.962631, 0.049697, 0.008174}}],
    Polygon[{{1.961570, 0.050468, -0.008489},{1.962631, 0.049697, -0.008174},{
      1.963008, 0.050438, -0.008174},{1.961761, 0.050843, -0.008489}}],
    Polygon[{{1.962631, 0.049697, -0.008174},{1.963639, 0.048965, -0.007658},{
      1.964193, 0.050053, -0.007658},{1.963008, 0.050438, -0.008174}}],
    Polygon[{{1.963639, 0.048965, -0.007658},{1.964569, 0.048289, -0.006953},{
      1.965286, 0.049697, -0.006953},{1.964193, 0.050053, -0.007658}}],
    Polygon[{{1.964569, 0.048289, -0.006953},{1.965399, 0.047686, -0.006077},{
      1.966262, 0.049380, -0.006077},{1.965286, 0.049697, -0.006953}}],
    Polygon[{{1.965399, 0.047686, -0.006077},{1.966107, 0.047171, -0.005052},{
      1.967095, 0.049110, -0.005052},{1.966262, 0.049380, -0.006077}}],
    Polygon[{{1.966107, 0.047171, -0.005052},{1.966677, 0.046757, -0.003902},{
      1.967765, 0.048892, -0.003902},{1.967095, 0.049110, -0.005052}}],
    Polygon[{{1.966677, 0.046757, -0.003902},{1.967095, 0.046454, -0.002656},{
      1.968256, 0.048732, -0.002656},{1.967765, 0.048892, -0.003902}}],
    Polygon[{{1.967095, 0.046454, -0.002656},{1.967349, 0.046269, -0.001344},{
      1.968555, 0.048635, -0.001344},{1.968256, 0.048732, -0.002656}}],
    Polygon[{{1.967349, 0.046269, -0.001344},{1.967435, 0.046207, 0.000000},{
      1.968656, 0.048602, 0.000000},{1.968555, 0.048635, -0.001344}}],
    Polygon[{{1.967435, 0.046207, 0.000000},{1.967349, 0.046269, 0.001344},{
      1.968555, 0.048635, 0.001344},{1.968656, 0.048602, 0.000000}}],
    Polygon[{{1.967349, 0.046269, 0.001344},{1.967095, 0.046454, 0.002656},{
      1.968256, 0.048732, 0.002656},{1.968555, 0.048635, 0.001344}}],
    Polygon[{{1.967095, 0.046454, 0.002656},{1.966677, 0.046757, 0.003902},{
      1.967765, 0.048892, 0.003902},{1.968256, 0.048732, 0.002656}}],
    Polygon[{{1.966677, 0.046757, 0.003902},{1.966107, 0.047171, 0.005052},{
      1.967095, 0.049110, 0.005052},{1.967765, 0.048892, 0.003902}}],
    Polygon[{{1.966107, 0.047171, 0.005052},{1.965399, 0.047686, 0.006077},{
      1.966262, 0.049380, 0.006077},{1.967095, 0.049110, 0.005052}}],
    Polygon[{{1.965399, 0.047686, 0.006077},{1.964569, 0.048289, 0.006953},{
      1.965286, 0.049697, 0.006953},{1.966262, 0.049380, 0.006077}}],
    Polygon[{{1.964569, 0.048289, 0.006953},{1.963639, 0.048965, 0.007658},{
      1.964193, 0.050053, 0.007658},{1.965286, 0.049697, 0.006953}}],
    Polygon[{{1.963639, 0.048965, 0.007658},{1.962631, 0.049697, 0.008174},{
      1.963008, 0.050438, 0.008174},{1.964193, 0.050053, 0.007658}}],
    Polygon[{{1.962631, 0.049697, 0.008174},{1.961570, 0.050468, 0.008489},{
      1.961761, 0.050843, 0.008489},{1.963008, 0.050438, 0.008174}}],
    Polygon[{{1.961761, 0.050843, -0.008489},{1.963008, 0.050438, -0.008174},{
      1.963138, 0.051258, -0.008174},{1.961826, 0.051258, -0.008489}}],
    Polygon[{{1.963008, 0.050438, -0.008174},{1.964193, 0.050053, -0.007658},{
      1.964384, 0.051258, -0.007658},{1.963138, 0.051258, -0.008174}}],
    Polygon[{{1.964193, 0.050053, -0.007658},{1.965286, 0.049697, -0.006953},{
      1.965534, 0.051258, -0.006953},{1.964384, 0.051258, -0.007658}}],
    Polygon[{{1.965286, 0.049697, -0.006953},{1.966262, 0.049380, -0.006077},{
      1.966559, 0.051258, -0.006077},{1.965534, 0.051258, -0.006953}}],
    Polygon[{{1.966262, 0.049380, -0.006077},{1.967095, 0.049110, -0.005052},{
      1.967435, 0.051258, -0.005052},{1.966559, 0.051258, -0.006077}}],
    Polygon[{{1.967095, 0.049110, -0.005052},{1.967765, 0.048892, -0.003902},{
      1.968140, 0.051258, -0.003902},{1.967435, 0.051258, -0.005052}}],
    Polygon[{{1.967765, 0.048892, -0.003902},{1.968256, 0.048732, -0.002656},{
      1.968656, 0.051258, -0.002656},{1.968140, 0.051258, -0.003902}}],
    Polygon[{{1.968256, 0.048732, -0.002656},{1.968555, 0.048635, -0.001344},{
      1.968971, 0.051258, -0.001344},{1.968656, 0.051258, -0.002656}}],
    Polygon[{{1.968555, 0.048635, -0.001344},{1.968656, 0.048602, 0.000000},{
      1.969076, 0.051258, 0.000000},{1.968971, 0.051258, -0.001344}}],
    Polygon[{{1.968656, 0.048602, 0.000000},{1.968555, 0.048635, 0.001344},{
      1.968971, 0.051258, 0.001344},{1.969076, 0.051258, 0.000000}}],
    Polygon[{{1.968555, 0.048635, 0.001344},{1.968256, 0.048732, 0.002656},{
      1.968656, 0.051258, 0.002656},{1.968971, 0.051258, 0.001344}}],
    Polygon[{{1.968256, 0.048732, 0.002656},{1.967765, 0.048892, 0.003902},{
      1.968140, 0.051258, 0.003902},{1.968656, 0.051258, 0.002656}}],
    Polygon[{{1.967765, 0.048892, 0.003902},{1.967095, 0.049110, 0.005052},{
      1.967435, 0.051258, 0.005052},{1.968140, 0.051258, 0.003902}}],
    Polygon[{{1.967095, 0.049110, 0.005052},{1.966262, 0.049380, 0.006077},{
      1.966559, 0.051258, 0.006077},{1.967435, 0.051258, 0.005052}}],
    Polygon[{{1.966262, 0.049380, 0.006077},{1.965286, 0.049697, 0.006953},{
      1.965534, 0.051258, 0.006953},{1.966559, 0.051258, 0.006077}}],
    Polygon[{{1.965286, 0.049697, 0.006953},{1.964193, 0.050053, 0.007658},{
      1.964384, 0.051258, 0.007658},{1.965534, 0.051258, 0.006953}}],
    Polygon[{{1.964193, 0.050053, 0.007658},{1.963008, 0.050438, 0.008174},{
      1.963138, 0.051258, 0.008174},{1.964384, 0.051258, 0.007658}}],
    Polygon[{{1.963008, 0.050438, 0.008174},{1.961761, 0.050843, 0.008489},{
      1.961826, 0.051258, 0.008489},{1.963138, 0.051258, 0.008174}}],
    Polygon[{{1.811583, 0.025783, -0.025466},{1.815517, 0.025783, -0.024521},{
      1.815127, 0.028246, -0.024521},{1.811386, 0.027030, -0.025466}}],
    Polygon[{{1.815517, 0.025783, -0.024521},{1.819255, 0.025783, -0.022973},{
      1.818682, 0.029401, -0.022973},{1.815127, 0.028246, -0.024521}}],
    Polygon[{{1.819255, 0.025783, -0.022973},{1.822705, 0.025783, -0.020859},{
      1.821963, 0.030467, -0.020859},{1.818682, 0.029401, -0.022973}}],
    Polygon[{{1.822705, 0.025783, -0.020859},{1.825782, 0.025783, -0.018232},{
      1.824889, 0.031417, -0.018232},{1.821963, 0.030467, -0.020859}}],
    Polygon[{{1.825782, 0.025783, -0.018232},{1.828409, 0.025783, -0.015155},{
      1.827388, 0.032229, -0.015155},{1.824889, 0.031417, -0.018232}}],
    Polygon[{{1.828409, 0.025783, -0.015155},{1.830523, 0.025783, -0.011705},{
      1.829399, 0.032883, -0.011705},{1.827388, 0.032229, -0.015155}}],
    Polygon[{{1.830523, 0.025783, -0.011705},{1.832071, 0.025783, -0.007968},{
      1.830871, 0.033361, -0.007968},{1.829399, 0.032883, -0.011705}}],
    Polygon[{{1.832071, 0.025783, -0.007968},{1.833016, 0.025783, -0.004033},{
      1.831769, 0.033653, -0.004033},{1.830871, 0.033361, -0.007968}}],
    Polygon[{{1.833016, 0.025783, -0.004033},{1.833333, 0.025783, 0.000000},{
      1.832071, 0.033751, 0.000000},{1.831769, 0.033653, -0.004033}}],
    Polygon[{{1.833333, 0.025783, 0.000000},{1.833016, 0.025783, 0.004033},{
      1.831769, 0.033653, 0.004033},{1.832071, 0.033751, 0.000000}}],
    Polygon[{{1.833016, 0.025783, 0.004033},{1.832071, 0.025783, 0.007968},{
      1.830871, 0.033361, 0.007968},{1.831769, 0.033653, 0.004033}}],
    Polygon[{{1.832071, 0.025783, 0.007968},{1.830523, 0.025783, 0.011705},{
      1.829399, 0.032883, 0.011705},{1.830871, 0.033361, 0.007968}}],
    Polygon[{{1.830523, 0.025783, 0.011705},{1.828409, 0.025783, 0.015155},{
      1.827388, 0.032229, 0.015155},{1.829399, 0.032883, 0.011705}}],
    Polygon[{{1.828409, 0.025783, 0.015155},{1.825782, 0.025783, 0.018232},{
      1.824889, 0.031417, 0.018232},{1.827388, 0.032229, 0.015155}}],
    Polygon[{{1.825782, 0.025783, 0.018232},{1.822705, 0.025783, 0.020859},{
      1.821963, 0.030467, 0.020859},{1.824889, 0.031417, 0.018232}}],
    Polygon[{{1.822705, 0.025783, 0.020859},{1.819255, 0.025783, 0.022973},{
      1.818682, 0.029401, 0.022973},{1.821963, 0.030467, 0.020859}}],
    Polygon[{{1.819255, 0.025783, 0.022973},{1.815517, 0.025783, 0.024521},{
      1.815127, 0.028246, 0.024521},{1.818682, 0.029401, 0.022973}}],
    Polygon[{{1.815517, 0.025783, 0.024521},{1.811583, 0.025783, 0.025466},{
      1.811386, 0.027030, 0.025466},{1.815127, 0.028246, 0.024521}}],
    Polygon[{{1.811386, 0.027030, -0.025466},{1.815127, 0.028246, -0.024521},{
      1.813996, 0.030467, -0.024521},{1.810813, 0.028154, -0.025466}}],
    Polygon[{{1.815127, 0.028246, -0.024521},{1.818682, 0.029401, -0.022973},{
      1.817020, 0.032664, -0.022973},{1.813996, 0.030467, -0.024521}}],
    Polygon[{{1.818682, 0.029401, -0.022973},{1.821963, 0.030467, -0.020859},{
      1.819811, 0.034691, -0.020859},{1.817020, 0.032664, -0.022973}}],
    Polygon[{{1.821963, 0.030467, -0.020859},{1.824889, 0.031417, -0.018232},{
      1.822300, 0.036500, -0.018232},{1.819811, 0.034691, -0.020859}}],
    Polygon[{{1.824889, 0.031417, -0.018232},{1.827388, 0.032229, -0.015155},{
      1.824425, 0.038044, -0.015155},{1.822300, 0.036500, -0.018232}}],
    Polygon[{{1.827388, 0.032229, -0.015155},{1.829399, 0.032883, -0.011705},{
      1.826136, 0.039287, -0.011705},{1.824425, 0.038044, -0.015155}}],
    Polygon[{{1.829399, 0.032883, -0.011705},{1.830871, 0.033361, -0.007968},{
      1.827388, 0.040197, -0.007968},{1.826136, 0.039287, -0.011705}}],
    Polygon[{{1.830871, 0.033361, -0.007968},{1.831769, 0.033653, -0.004033},{
      1.828152, 0.040752, -0.004033},{1.827388, 0.040197, -0.007968}}],
    Polygon[{{1.831769, 0.033653, -0.004033},{1.832071, 0.033751, 0.000000},{
      1.828409, 0.040939, 0.000000},{1.828152, 0.040752, -0.004033}}],
    Polygon[{{1.832071, 0.033751, 0.000000},{1.831769, 0.033653, 0.004033},{
      1.828152, 0.040752, 0.004033},{1.828409, 0.040939, 0.000000}}],
    Polygon[{{1.831769, 0.033653, 0.004033},{1.830871, 0.033361, 0.007968},{
      1.827388, 0.040197, 0.007968},{1.828152, 0.040752, 0.004033}}],
    Polygon[{{1.830871, 0.033361, 0.007968},{1.829399, 0.032883, 0.011705},{
      1.826136, 0.039287, 0.011705},{1.827388, 0.040197, 0.007968}}],
    Polygon[{{1.829399, 0.032883, 0.011705},{1.827388, 0.032229, 0.015155},{
      1.824425, 0.038044, 0.015155},{1.826136, 0.039287, 0.011705}}],
    Polygon[{{1.827388, 0.032229, 0.015155},{1.824889, 0.031417, 0.018232},{
      1.822300, 0.036500, 0.018232},{1.824425, 0.038044, 0.015155}}],
    Polygon[{{1.824889, 0.031417, 0.018232},{1.821963, 0.030467, 0.020859},{
      1.819811, 0.034691, 0.020859},{1.822300, 0.036500, 0.018232}}],
    Polygon[{{1.821963, 0.030467, 0.020859},{1.818682, 0.029401, 0.022973},{
      1.817020, 0.032664, 0.022973},{1.819811, 0.034691, 0.020859}}],
    Polygon[{{1.818682, 0.029401, 0.022973},{1.815127, 0.028246, 0.024521},{
      1.813996, 0.030467, 0.024521},{1.817020, 0.032664, 0.022973}}],
    Polygon[{{1.815127, 0.028246, 0.024521},{1.811386, 0.027030, 0.025466},{
      1.810813, 0.028154, 0.025466},{1.813996, 0.030467, 0.024521}}],
    Polygon[{{1.810813, 0.028154, -0.025466},{1.813996, 0.030467, -0.024521},{
      1.812233, 0.032229, -0.024521},{1.809921, 0.029047, -0.025466}}],
    Polygon[{{1.813996, 0.030467, -0.024521},{1.817020, 0.032664, -0.022973},{
      1.814430, 0.035253, -0.022973},{1.812233, 0.032229, -0.024521}}],
    Polygon[{{1.817020, 0.032664, -0.022973},{1.819811, 0.034691, -0.020859},{
      1.816458, 0.038044, -0.020859},{1.814430, 0.035253, -0.022973}}],
    Polygon[{{1.819811, 0.034691, -0.020859},{1.822300, 0.036500, -0.018232},{
      1.818266, 0.040533, -0.018232},{1.816458, 0.038044, -0.020859}}],
    Polygon[{{1.822300, 0.036500, -0.018232},{1.824425, 0.038044, -0.015155},{
      1.819811, 0.042659, -0.015155},{1.818266, 0.040533, -0.018232}}],
    Polygon[{{1.824425, 0.038044, -0.015155},{1.826136, 0.039287, -0.011705},{
      1.821053, 0.044369, -0.011705},{1.819811, 0.042659, -0.015155}}],
    Polygon[{{1.826136, 0.039287, -0.011705},{1.827388, 0.040197, -0.007968},{
      1.821963, 0.045622, -0.007968},{1.821053, 0.044369, -0.011705}}],
    Polygon[{{1.827388, 0.040197, -0.007968},{1.828152, 0.040752, -0.004033},{
      1.822518, 0.046386, -0.004033},{1.821963, 0.045622, -0.007968}}],
    Polygon[{{1.828152, 0.040752, -0.004033},{1.828409, 0.040939, 0.000000},{
      1.822705, 0.046643, 0.000000},{1.822518, 0.046386, -0.004033}}],
    Polygon[{{1.828409, 0.040939, 0.000000},{1.828152, 0.040752, 0.004033},{
      1.822518, 0.046386, 0.004033},{1.822705, 0.046643, 0.000000}}],
    Polygon[{{1.828152, 0.040752, 0.004033},{1.827388, 0.040197, 0.007968},{
      1.821963, 0.045622, 0.007968},{1.822518, 0.046386, 0.004033}}],
    Polygon[{{1.827388, 0.040197, 0.007968},{1.826136, 0.039287, 0.011705},{
      1.821053, 0.044369, 0.011705},{1.821963, 0.045622, 0.007968}}],
    Polygon[{{1.826136, 0.039287, 0.011705},{1.824425, 0.038044, 0.015155},{
      1.819811, 0.042659, 0.015155},{1.821053, 0.044369, 0.011705}}],
    Polygon[{{1.824425, 0.038044, 0.015155},{1.822300, 0.036500, 0.018232},{
      1.818266, 0.040533, 0.018232},{1.819811, 0.042659, 0.015155}}],
    Polygon[{{1.822300, 0.036500, 0.018232},{1.819811, 0.034691, 0.020859},{
      1.816458, 0.038044, 0.020859},{1.818266, 0.040533, 0.018232}}],
    Polygon[{{1.819811, 0.034691, 0.020859},{1.817020, 0.032664, 0.022973},{
      1.814430, 0.035253, 0.022973},{1.816458, 0.038044, 0.020859}}],
    Polygon[{{1.817020, 0.032664, 0.022973},{1.813996, 0.030467, 0.024521},{
      1.812233, 0.032229, 0.024521},{1.814430, 0.035253, 0.022973}}],
    Polygon[{{1.813996, 0.030467, 0.024521},{1.810813, 0.028154, 0.025466},{
      1.809921, 0.029047, 0.025466},{1.812233, 0.032229, 0.024521}}],
    Polygon[{{1.809921, 0.029047, -0.025466},{1.812233, 0.032229, -0.024521},{
      1.810012, 0.033361, -0.024521},{1.808796, 0.029619, -0.025466}}],
    Polygon[{{1.812233, 0.032229, -0.024521},{1.814430, 0.035253, -0.022973},{
      1.811167, 0.036916, -0.022973},{1.810012, 0.033361, -0.024521}}],
    Polygon[{{1.814430, 0.035253, -0.022973},{1.816458, 0.038044, -0.020859},{
      1.812233, 0.040197, -0.020859},{1.811167, 0.036916, -0.022973}}],
    Polygon[{{1.816458, 0.038044, -0.020859},{1.818266, 0.040533, -0.018232},{
      1.813184, 0.043123, -0.018232},{1.812233, 0.040197, -0.020859}}],
    Polygon[{{1.818266, 0.040533, -0.018232},{1.819811, 0.042659, -0.015155},{
      1.813996, 0.045622, -0.015155},{1.813184, 0.043123, -0.018232}}],
    Polygon[{{1.819811, 0.042659, -0.015155},{1.821053, 0.044369, -0.011705},{
      1.814649, 0.047632, -0.011705},{1.813996, 0.045622, -0.015155}}],
    Polygon[{{1.821053, 0.044369, -0.011705},{1.821963, 0.045622, -0.007968},{
      1.815127, 0.049105, -0.007968},{1.814649, 0.047632, -0.011705}}],
    Polygon[{{1.821963, 0.045622, -0.007968},{1.822518, 0.046386, -0.004033},{
      1.815419, 0.050003, -0.004033},{1.815127, 0.049105, -0.007968}}],
    Polygon[{{1.822518, 0.046386, -0.004033},{1.822705, 0.046643, 0.000000},{
      1.815517, 0.050305, 0.000000},{1.815419, 0.050003, -0.004033}}],
    Polygon[{{1.822705, 0.046643, 0.000000},{1.822518, 0.046386, 0.004033},{
      1.815419, 0.050003, 0.004033},{1.815517, 0.050305, 0.000000}}],
    Polygon[{{1.822518, 0.046386, 0.004033},{1.821963, 0.045622, 0.007968},{
      1.815127, 0.049105, 0.007968},{1.815419, 0.050003, 0.004033}}],
    Polygon[{{1.821963, 0.045622, 0.007968},{1.821053, 0.044369, 0.011705},{
      1.814649, 0.047632, 0.011705},{1.815127, 0.049105, 0.007968}}],
    Polygon[{{1.821053, 0.044369, 0.011705},{1.819811, 0.042659, 0.015155},{
      1.813996, 0.045622, 0.015155},{1.814649, 0.047632, 0.011705}}],
    Polygon[{{1.819811, 0.042659, 0.015155},{1.818266, 0.040533, 0.018232},{
      1.813184, 0.043123, 0.018232},{1.813996, 0.045622, 0.015155}}],
    Polygon[{{1.818266, 0.040533, 0.018232},{1.816458, 0.038044, 0.020859},{
      1.812233, 0.040197, 0.020859},{1.813184, 0.043123, 0.018232}}],
    Polygon[{{1.816458, 0.038044, 0.020859},{1.814430, 0.035253, 0.022973},{
      1.811167, 0.036916, 0.022973},{1.812233, 0.040197, 0.020859}}],
    Polygon[{{1.814430, 0.035253, 0.022973},{1.812233, 0.032229, 0.024521},{
      1.810012, 0.033361, 0.024521},{1.811167, 0.036916, 0.022973}}],
    Polygon[{{1.812233, 0.032229, 0.024521},{1.809921, 0.029047, 0.025466},{
      1.808796, 0.029619, 0.025466},{1.810012, 0.033361, 0.024521}}],
    Polygon[{{1.808796, 0.029619, -0.025466},{1.810012, 0.033361, -0.024521},{
      1.807550, 0.033751, -0.024521},{1.807550, 0.029817, -0.025466}}],
    Polygon[{{1.810012, 0.033361, -0.024521},{1.811167, 0.036916, -0.022973},{
      1.807550, 0.037489, -0.022973},{1.807550, 0.033751, -0.024521}}],
    Polygon[{{1.811167, 0.036916, -0.022973},{1.812233, 0.040197, -0.020859},{
      1.807550, 0.040939, -0.020859},{1.807550, 0.037489, -0.022973}}],
    Polygon[{{1.812233, 0.040197, -0.020859},{1.813184, 0.043123, -0.018232},{
      1.807550, 0.044015, -0.018232},{1.807550, 0.040939, -0.020859}}],
    Polygon[{{1.813184, 0.043123, -0.018232},{1.813996, 0.045622, -0.015155},{
      1.807550, 0.046643, -0.015155},{1.807550, 0.044015, -0.018232}}],
    Polygon[{{1.813996, 0.045622, -0.015155},{1.814649, 0.047632, -0.011705},{
      1.807550, 0.048757, -0.011705},{1.807550, 0.046643, -0.015155}}],
    Polygon[{{1.814649, 0.047632, -0.011705},{1.815127, 0.049105, -0.007968},{
      1.807550, 0.050305, -0.007968},{1.807550, 0.048757, -0.011705}}],
    Polygon[{{1.815127, 0.049105, -0.007968},{1.815419, 0.050003, -0.004033},{
      1.807550, 0.051249, -0.004033},{1.807550, 0.050305, -0.007968}}],
    Polygon[{{1.815419, 0.050003, -0.004033},{1.815517, 0.050305, 0.000000},{
      1.807550, 0.051567, 0.000000},{1.807550, 0.051249, -0.004033}}],
    Polygon[{{1.815517, 0.050305, 0.000000},{1.815419, 0.050003, 0.004033},{
      1.807550, 0.051249, 0.004033},{1.807550, 0.051567, 0.000000}}],
    Polygon[{{1.815419, 0.050003, 0.004033},{1.815127, 0.049105, 0.007968},{
      1.807550, 0.050305, 0.007968},{1.807550, 0.051249, 0.004033}}],
    Polygon[{{1.815127, 0.049105, 0.007968},{1.814649, 0.047632, 0.011705},{
      1.807550, 0.048757, 0.011705},{1.807550, 0.050305, 0.007968}}],
    Polygon[{{1.814649, 0.047632, 0.011705},{1.813996, 0.045622, 0.015155},{
      1.807550, 0.046643, 0.015155},{1.807550, 0.048757, 0.011705}}],
    Polygon[{{1.813996, 0.045622, 0.015155},{1.813184, 0.043123, 0.018232},{
      1.807550, 0.044015, 0.018232},{1.807550, 0.046643, 0.015155}}],
    Polygon[{{1.813184, 0.043123, 0.018232},{1.812233, 0.040197, 0.020859},{
      1.807550, 0.040939, 0.020859},{1.807550, 0.044015, 0.018232}}],
    Polygon[{{1.812233, 0.040197, 0.020859},{1.811167, 0.036916, 0.022973},{
      1.807550, 0.037489, 0.022973},{1.807550, 0.040939, 0.020859}}],
    Polygon[{{1.811167, 0.036916, 0.022973},{1.810012, 0.033361, 0.024521},{
      1.807550, 0.033751, 0.024521},{1.807550, 0.037489, 0.022973}}],
    Polygon[{{1.810012, 0.033361, 0.024521},{1.808796, 0.029619, 0.025466},{
      1.807550, 0.029817, 0.025466},{1.807550, 0.033751, 0.024521}}],
    Polygon[{{1.807550, 0.029817, -0.025466},{1.807550, 0.033751, -0.024521},{
      1.805088, 0.033361, -0.024521},{1.806304, 0.029619, -0.025466}}],
    Polygon[{{1.807550, 0.033751, -0.024521},{1.807550, 0.037489, -0.022973},{
      1.803933, 0.036916, -0.022973},{1.805088, 0.033361, -0.024521}}],
    Polygon[{{1.807550, 0.037489, -0.022973},{1.807550, 0.040939, -0.020859},{
      1.802867, 0.040197, -0.020859},{1.803933, 0.036916, -0.022973}}],
    Polygon[{{1.807550, 0.040939, -0.020859},{1.807550, 0.044015, -0.018232},{
      1.801916, 0.043123, -0.018232},{1.802867, 0.040197, -0.020859}}],
    Polygon[{{1.807550, 0.044015, -0.018232},{1.807550, 0.046643, -0.015155},{
      1.801104, 0.045622, -0.015155},{1.801916, 0.043123, -0.018232}}],
    Polygon[{{1.807550, 0.046643, -0.015155},{1.807550, 0.048757, -0.011705},{
      1.800451, 0.047632, -0.011705},{1.801104, 0.045622, -0.015155}}],
    Polygon[{{1.807550, 0.048757, -0.011705},{1.807550, 0.050305, -0.007968},{
      1.799972, 0.049105, -0.007968},{1.800451, 0.047632, -0.011705}}],
    Polygon[{{1.807550, 0.050305, -0.007968},{1.807550, 0.051249, -0.004033},{
      1.799680, 0.050003, -0.004033},{1.799972, 0.049105, -0.007968}}],
    Polygon[{{1.807550, 0.051249, -0.004033},{1.807550, 0.051567, 0.000000},{
      1.799582, 0.050305, 0.000000},{1.799680, 0.050003, -0.004033}}],
    Polygon[{{1.807550, 0.051567, 0.000000},{1.807550, 0.051249, 0.004033},{
      1.799680, 0.050003, 0.004033},{1.799582, 0.050305, 0.000000}}],
    Polygon[{{1.807550, 0.051249, 0.004033},{1.807550, 0.050305, 0.007968},{
      1.799972, 0.049105, 0.007968},{1.799680, 0.050003, 0.004033}}],
    Polygon[{{1.807550, 0.050305, 0.007968},{1.807550, 0.048757, 0.011705},{
      1.800451, 0.047632, 0.011705},{1.799972, 0.049105, 0.007968}}],
    Polygon[{{1.807550, 0.048757, 0.011705},{1.807550, 0.046643, 0.015155},{
      1.801104, 0.045622, 0.015155},{1.800451, 0.047632, 0.011705}}],
    Polygon[{{1.807550, 0.046643, 0.015155},{1.807550, 0.044015, 0.018232},{
      1.801916, 0.043123, 0.018232},{1.801104, 0.045622, 0.015155}}],
    Polygon[{{1.807550, 0.044015, 0.018232},{1.807550, 0.040939, 0.020859},{
      1.802867, 0.040197, 0.020859},{1.801916, 0.043123, 0.018232}}],
    Polygon[{{1.807550, 0.040939, 0.020859},{1.807550, 0.037489, 0.022973},{
      1.803933, 0.036916, 0.022973},{1.802867, 0.040197, 0.020859}}],
    Polygon[{{1.807550, 0.037489, 0.022973},{1.807550, 0.033751, 0.024521},{
      1.805088, 0.033361, 0.024521},{1.803933, 0.036916, 0.022973}}],
    Polygon[{{1.807550, 0.033751, 0.024521},{1.807550, 0.029817, 0.025466},{
      1.806304, 0.029619, 0.025466},{1.805088, 0.033361, 0.024521}}],
    Polygon[{{1.806304, 0.029619, -0.025466},{1.805088, 0.033361, -0.024521},{
      1.802867, 0.032229, -0.024521},{1.805179, 0.029047, -0.025466}}],
    Polygon[{{1.805088, 0.033361, -0.024521},{1.803933, 0.036916, -0.022973},{
      1.800670, 0.035253, -0.022973},{1.802867, 0.032229, -0.024521}}],
    Polygon[{{1.803933, 0.036916, -0.022973},{1.802867, 0.040197, -0.020859},{
      1.798642, 0.038044, -0.020859},{1.800670, 0.035253, -0.022973}}],
    Polygon[{{1.802867, 0.040197, -0.020859},{1.801916, 0.043123, -0.018232},{
      1.796834, 0.040533, -0.018232},{1.798642, 0.038044, -0.020859}}],
    Polygon[{{1.801916, 0.043123, -0.018232},{1.801104, 0.045622, -0.015155},{
      1.795289, 0.042659, -0.015155},{1.796834, 0.040533, -0.018232}}],
    Polygon[{{1.801104, 0.045622, -0.015155},{1.800451, 0.047632, -0.011705},{
      1.794047, 0.044369, -0.011705},{1.795289, 0.042659, -0.015155}}],
    Polygon[{{1.800451, 0.047632, -0.011705},{1.799972, 0.049105, -0.007968},{
      1.793137, 0.045622, -0.007968},{1.794047, 0.044369, -0.011705}}],
    Polygon[{{1.799972, 0.049105, -0.007968},{1.799680, 0.050003, -0.004033},{
      1.792581, 0.046386, -0.004033},{1.793137, 0.045622, -0.007968}}],
    Polygon[{{1.799680, 0.050003, -0.004033},{1.799582, 0.050305, 0.000000},{
      1.792395, 0.046643, 0.000000},{1.792581, 0.046386, -0.004033}}],
    Polygon[{{1.799582, 0.050305, 0.000000},{1.799680, 0.050003, 0.004033},{
      1.792581, 0.046386, 0.004033},{1.792395, 0.046643, 0.000000}}],
    Polygon[{{1.799680, 0.050003, 0.004033},{1.799972, 0.049105, 0.007968},{
      1.793137, 0.045622, 0.007968},{1.792581, 0.046386, 0.004033}}],
    Polygon[{{1.799972, 0.049105, 0.007968},{1.800451, 0.047632, 0.011705},{
      1.794047, 0.044369, 0.011705},{1.793137, 0.045622, 0.007968}}],
    Polygon[{{1.800451, 0.047632, 0.011705},{1.801104, 0.045622, 0.015155},{
      1.795289, 0.042659, 0.015155},{1.794047, 0.044369, 0.011705}}],
    Polygon[{{1.801104, 0.045622, 0.015155},{1.801916, 0.043123, 0.018232},{
      1.796834, 0.040533, 0.018232},{1.795289, 0.042659, 0.015155}}],
    Polygon[{{1.801916, 0.043123, 0.018232},{1.802867, 0.040197, 0.020859},{
      1.798642, 0.038044, 0.020859},{1.796834, 0.040533, 0.018232}}],
    Polygon[{{1.802867, 0.040197, 0.020859},{1.803933, 0.036916, 0.022973},{
      1.800670, 0.035253, 0.022973},{1.798642, 0.038044, 0.020859}}],
    Polygon[{{1.803933, 0.036916, 0.022973},{1.805088, 0.033361, 0.024521},{
      1.802867, 0.032229, 0.024521},{1.800670, 0.035253, 0.022973}}],
    Polygon[{{1.805088, 0.033361, 0.024521},{1.806304, 0.029619, 0.025466},{
      1.805179, 0.029047, 0.025466},{1.802867, 0.032229, 0.024521}}],
    Polygon[{{1.805179, 0.029047, -0.025466},{1.802867, 0.032229, -0.024521},{
      1.801104, 0.030467, -0.024521},{1.804287, 0.028154, -0.025466}}],
    Polygon[{{1.802867, 0.032229, -0.024521},{1.800670, 0.035253, -0.022973},{
      1.798080, 0.032664, -0.022973},{1.801104, 0.030467, -0.024521}}],
    Polygon[{{1.800670, 0.035253, -0.022973},{1.798642, 0.038044, -0.020859},{
      1.795289, 0.034691, -0.020859},{1.798080, 0.032664, -0.022973}}],
    Polygon[{{1.798642, 0.038044, -0.020859},{1.796834, 0.040533, -0.018232},{
      1.792800, 0.036500, -0.018232},{1.795289, 0.034691, -0.020859}}],
    Polygon[{{1.796834, 0.040533, -0.018232},{1.795289, 0.042659, -0.015155},{
      1.790674, 0.038044, -0.015155},{1.792800, 0.036500, -0.018232}}],
    Polygon[{{1.795289, 0.042659, -0.015155},{1.794047, 0.044369, -0.011705},{
      1.788964, 0.039287, -0.011705},{1.790674, 0.038044, -0.015155}}],
    Polygon[{{1.794047, 0.044369, -0.011705},{1.793137, 0.045622, -0.007968},{
      1.787712, 0.040197, -0.007968},{1.788964, 0.039287, -0.011705}}],
    Polygon[{{1.793137, 0.045622, -0.007968},{1.792581, 0.046386, -0.004033},{
      1.786947, 0.040752, -0.004033},{1.787712, 0.040197, -0.007968}}],
    Polygon[{{1.792581, 0.046386, -0.004033},{1.792395, 0.046643, 0.000000},{
      1.786691, 0.040939, 0.000000},{1.786947, 0.040752, -0.004033}}],
    Polygon[{{1.792395, 0.046643, 0.000000},{1.792581, 0.046386, 0.004033},{
      1.786947, 0.040752, 0.004033},{1.786691, 0.040939, 0.000000}}],
    Polygon[{{1.792581, 0.046386, 0.004033},{1.793137, 0.045622, 0.007968},{
      1.787712, 0.040197, 0.007968},{1.786947, 0.040752, 0.004033}}],
    Polygon[{{1.793137, 0.045622, 0.007968},{1.794047, 0.044369, 0.011705},{
      1.788964, 0.039287, 0.011705},{1.787712, 0.040197, 0.007968}}],
    Polygon[{{1.794047, 0.044369, 0.011705},{1.795289, 0.042659, 0.015155},{
      1.790674, 0.038044, 0.015155},{1.788964, 0.039287, 0.011705}}],
    Polygon[{{1.795289, 0.042659, 0.015155},{1.796834, 0.040533, 0.018232},{
      1.792800, 0.036500, 0.018232},{1.790674, 0.038044, 0.015155}}],
    Polygon[{{1.796834, 0.040533, 0.018232},{1.798642, 0.038044, 0.020859},{
      1.795289, 0.034691, 0.020859},{1.792800, 0.036500, 0.018232}}],
    Polygon[{{1.798642, 0.038044, 0.020859},{1.800670, 0.035253, 0.022973},{
      1.798080, 0.032664, 0.022973},{1.795289, 0.034691, 0.020859}}],
    Polygon[{{1.800670, 0.035253, 0.022973},{1.802867, 0.032229, 0.024521},{
      1.801104, 0.030467, 0.024521},{1.798080, 0.032664, 0.022973}}],
    Polygon[{{1.802867, 0.032229, 0.024521},{1.805179, 0.029047, 0.025466},{
      1.804287, 0.028154, 0.025466},{1.801104, 0.030467, 0.024521}}],
    Polygon[{{1.804287, 0.028154, -0.025466},{1.801104, 0.030467, -0.024521},{
      1.799972, 0.028246, -0.024521},{1.803714, 0.027030, -0.025466}}],
    Polygon[{{1.801104, 0.030467, -0.024521},{1.798080, 0.032664, -0.022973},{
      1.796417, 0.029401, -0.022973},{1.799972, 0.028246, -0.024521}}],
    Polygon[{{1.798080, 0.032664, -0.022973},{1.795289, 0.034691, -0.020859},{
      1.793137, 0.030467, -0.020859},{1.796417, 0.029401, -0.022973}}],
    Polygon[{{1.795289, 0.034691, -0.020859},{1.792800, 0.036500, -0.018232},{
      1.790211, 0.031417, -0.018232},{1.793137, 0.030467, -0.020859}}],
    Polygon[{{1.792800, 0.036500, -0.018232},{1.790674, 0.038044, -0.015155},{
      1.787712, 0.032229, -0.015155},{1.790211, 0.031417, -0.018232}}],
    Polygon[{{1.790674, 0.038044, -0.015155},{1.788964, 0.039287, -0.011705},{
      1.785701, 0.032883, -0.011705},{1.787712, 0.032229, -0.015155}}],
    Polygon[{{1.788964, 0.039287, -0.011705},{1.787712, 0.040197, -0.007968},{
      1.784229, 0.033361, -0.007968},{1.785701, 0.032883, -0.011705}}],
    Polygon[{{1.787712, 0.040197, -0.007968},{1.786947, 0.040752, -0.004033},{
      1.783330, 0.033653, -0.004033},{1.784229, 0.033361, -0.007968}}],
    Polygon[{{1.786947, 0.040752, -0.004033},{1.786691, 0.040939, 0.000000},{
      1.783028, 0.033751, 0.000000},{1.783330, 0.033653, -0.004033}}],
    Polygon[{{1.786691, 0.040939, 0.000000},{1.786947, 0.040752, 0.004033},{
      1.783330, 0.033653, 0.004033},{1.783028, 0.033751, 0.000000}}],
    Polygon[{{1.786947, 0.040752, 0.004033},{1.787712, 0.040197, 0.007968},{
      1.784229, 0.033361, 0.007968},{1.783330, 0.033653, 0.004033}}],
    Polygon[{{1.787712, 0.040197, 0.007968},{1.788964, 0.039287, 0.011705},{
      1.785701, 0.032883, 0.011705},{1.784229, 0.033361, 0.007968}}],
    Polygon[{{1.788964, 0.039287, 0.011705},{1.790674, 0.038044, 0.015155},{
      1.787712, 0.032229, 0.015155},{1.785701, 0.032883, 0.011705}}],
    Polygon[{{1.790674, 0.038044, 0.015155},{1.792800, 0.036500, 0.018232},{
      1.790211, 0.031417, 0.018232},{1.787712, 0.032229, 0.015155}}],
    Polygon[{{1.792800, 0.036500, 0.018232},{1.795289, 0.034691, 0.020859},{
      1.793137, 0.030467, 0.020859},{1.790211, 0.031417, 0.018232}}],
    Polygon[{{1.795289, 0.034691, 0.020859},{1.798080, 0.032664, 0.022973},{
      1.796417, 0.029401, 0.022973},{1.793137, 0.030467, 0.020859}}],
    Polygon[{{1.798080, 0.032664, 0.022973},{1.801104, 0.030467, 0.024521},{
      1.799972, 0.028246, 0.024521},{1.796417, 0.029401, 0.022973}}],
    Polygon[{{1.801104, 0.030467, 0.024521},{1.804287, 0.028154, 0.025466},{
      1.803714, 0.027030, 0.025466},{1.799972, 0.028246, 0.024521}}],
    Polygon[{{1.803714, 0.027030, -0.025466},{1.799972, 0.028246, -0.024521},{
      1.799582, 0.025783, -0.024521},{1.803517, 0.025783, -0.025466}}],
    Polygon[{{1.799972, 0.028246, -0.024521},{1.796417, 0.029401, -0.022973},{
      1.795844, 0.025783, -0.022973},{1.799582, 0.025783, -0.024521}}],
    Polygon[{{1.796417, 0.029401, -0.022973},{1.793137, 0.030467, -0.020859},{
      1.792395, 0.025783, -0.020859},{1.795844, 0.025783, -0.022973}}],
    Polygon[{{1.793137, 0.030467, -0.020859},{1.790211, 0.031417, -0.018232},{
      1.789318, 0.025783, -0.018232},{1.792395, 0.025783, -0.020859}}],
    Polygon[{{1.790211, 0.031417, -0.018232},{1.787712, 0.032229, -0.015155},{
      1.786691, 0.025783, -0.015155},{1.789318, 0.025783, -0.018232}}],
    Polygon[{{1.787712, 0.032229, -0.015155},{1.785701, 0.032883, -0.011705},{
      1.784577, 0.025783, -0.011705},{1.786691, 0.025783, -0.015155}}],
    Polygon[{{1.785701, 0.032883, -0.011705},{1.784229, 0.033361, -0.007968},{
      1.783028, 0.025783, -0.007968},{1.784577, 0.025783, -0.011705}}],
    Polygon[{{1.784229, 0.033361, -0.007968},{1.783330, 0.033653, -0.004033},{
      1.782084, 0.025783, -0.004033},{1.783028, 0.025783, -0.007968}}],
    Polygon[{{1.783330, 0.033653, -0.004033},{1.783028, 0.033751, 0.000000},{
      1.781767, 0.025783, 0.000000},{1.782084, 0.025783, -0.004033}}],
    Polygon[{{1.783028, 0.033751, 0.000000},{1.783330, 0.033653, 0.004033},{
      1.782084, 0.025783, 0.004033},{1.781767, 0.025783, 0.000000}}],
    Polygon[{{1.783330, 0.033653, 0.004033},{1.784229, 0.033361, 0.007968},{
      1.783028, 0.025783, 0.007968},{1.782084, 0.025783, 0.004033}}],
    Polygon[{{1.784229, 0.033361, 0.007968},{1.785701, 0.032883, 0.011705},{
      1.784577, 0.025783, 0.011705},{1.783028, 0.025783, 0.007968}}],
    Polygon[{{1.785701, 0.032883, 0.011705},{1.787712, 0.032229, 0.015155},{
      1.786691, 0.025783, 0.015155},{1.784577, 0.025783, 0.011705}}],
    Polygon[{{1.787712, 0.032229, 0.015155},{1.790211, 0.031417, 0.018232},{
      1.789318, 0.025783, 0.018232},{1.786691, 0.025783, 0.015155}}],
    Polygon[{{1.790211, 0.031417, 0.018232},{1.793137, 0.030467, 0.020859},{
      1.792395, 0.025783, 0.020859},{1.789318, 0.025783, 0.018232}}],
    Polygon[{{1.793137, 0.030467, 0.020859},{1.796417, 0.029401, 0.022973},{
      1.795844, 0.025783, 0.022973},{1.792395, 0.025783, 0.020859}}],
    Polygon[{{1.796417, 0.029401, 0.022973},{1.799972, 0.028246, 0.024521},{
      1.799582, 0.025783, 0.024521},{1.795844, 0.025783, 0.022973}}],
    Polygon[{{1.799972, 0.028246, 0.024521},{1.803714, 0.027030, 0.025466},{
      1.803517, 0.025783, 0.025466},{1.799582, 0.025783, 0.024521}}],
    Polygon[{{1.803517, 0.025783, -0.025466},{1.799582, 0.025783, -0.024521},{
      1.799972, 0.023321, -0.024521},{1.803714, 0.024537, -0.025466}}],
    Polygon[{{1.799582, 0.025783, -0.024521},{1.795844, 0.025783, -0.022973},{
      1.796417, 0.022166, -0.022973},{1.799972, 0.023321, -0.024521}}],
    Polygon[{{1.795844, 0.025783, -0.022973},{1.792395, 0.025783, -0.020859},{
      1.793137, 0.021100, -0.020859},{1.796417, 0.022166, -0.022973}}],
    Polygon[{{1.792395, 0.025783, -0.020859},{1.789318, 0.025783, -0.018232},{
      1.790211, 0.020150, -0.018232},{1.793137, 0.021100, -0.020859}}],
    Polygon[{{1.789318, 0.025783, -0.018232},{1.786691, 0.025783, -0.015155},{
      1.787712, 0.019338, -0.015155},{1.790211, 0.020150, -0.018232}}],
    Polygon[{{1.786691, 0.025783, -0.015155},{1.784577, 0.025783, -0.011705},{
      1.785701, 0.018684, -0.011705},{1.787712, 0.019338, -0.015155}}],
    Polygon[{{1.784577, 0.025783, -0.011705},{1.783028, 0.025783, -0.007968},{
      1.784229, 0.018206, -0.007968},{1.785701, 0.018684, -0.011705}}],
    Polygon[{{1.783028, 0.025783, -0.007968},{1.782084, 0.025783, -0.004033},{
      1.783330, 0.017914, -0.004033},{1.784229, 0.018206, -0.007968}}],
    Polygon[{{1.782084, 0.025783, -0.004033},{1.781767, 0.025783, 0.000000},{
      1.783028, 0.017816, 0.000000},{1.783330, 0.017914, -0.004033}}],
    Polygon[{{1.781767, 0.025783, 0.000000},{1.782084, 0.025783, 0.004033},{
      1.783330, 0.017914, 0.004033},{1.783028, 0.017816, 0.000000}}],
    Polygon[{{1.782084, 0.025783, 0.004033},{1.783028, 0.025783, 0.007968},{
      1.784229, 0.018206, 0.007968},{1.783330, 0.017914, 0.004033}}],
    Polygon[{{1.783028, 0.025783, 0.007968},{1.784577, 0.025783, 0.011705},{
      1.785701, 0.018684, 0.011705},{1.784229, 0.018206, 0.007968}}],
    Polygon[{{1.784577, 0.025783, 0.011705},{1.786691, 0.025783, 0.015155},{
      1.787712, 0.019338, 0.015155},{1.785701, 0.018684, 0.011705}}],
    Polygon[{{1.786691, 0.025783, 0.015155},{1.789318, 0.025783, 0.018232},{
      1.790211, 0.020150, 0.018232},{1.787712, 0.019338, 0.015155}}],
    Polygon[{{1.789318, 0.025783, 0.018232},{1.792395, 0.025783, 0.020859},{
      1.793137, 0.021100, 0.020859},{1.790211, 0.020150, 0.018232}}],
    Polygon[{{1.792395, 0.025783, 0.020859},{1.795844, 0.025783, 0.022973},{
      1.796417, 0.022166, 0.022973},{1.793137, 0.021100, 0.020859}}],
    Polygon[{{1.795844, 0.025783, 0.022973},{1.799582, 0.025783, 0.024521},{
      1.799972, 0.023321, 0.024521},{1.796417, 0.022166, 0.022973}}],
    Polygon[{{1.799582, 0.025783, 0.024521},{1.803517, 0.025783, 0.025466},{
      1.803714, 0.024537, 0.025466},{1.799972, 0.023321, 0.024521}}],
    Polygon[{{1.803714, 0.024537, -0.025466},{1.799972, 0.023321, -0.024521},{
      1.801104, 0.021100, -0.024521},{1.804287, 0.023413, -0.025466}}],
    Polygon[{{1.799972, 0.023321, -0.024521},{1.796417, 0.022166, -0.022973},{
      1.798080, 0.018903, -0.022973},{1.801104, 0.021100, -0.024521}}],
    Polygon[{{1.796417, 0.022166, -0.022973},{1.793137, 0.021100, -0.020859},{
      1.795289, 0.016875, -0.020859},{1.798080, 0.018903, -0.022973}}],
    Polygon[{{1.793137, 0.021100, -0.020859},{1.790211, 0.020150, -0.018232},{
      1.792800, 0.015067, -0.018232},{1.795289, 0.016875, -0.020859}}],
    Polygon[{{1.790211, 0.020150, -0.018232},{1.787712, 0.019338, -0.015155},{
      1.790674, 0.013523, -0.015155},{1.792800, 0.015067, -0.018232}}],
    Polygon[{{1.787712, 0.019338, -0.015155},{1.785701, 0.018684, -0.011705},{
      1.788964, 0.012280, -0.011705},{1.790674, 0.013523, -0.015155}}],
    Polygon[{{1.785701, 0.018684, -0.011705},{1.784229, 0.018206, -0.007968},{
      1.787712, 0.011370, -0.007968},{1.788964, 0.012280, -0.011705}}],
    Polygon[{{1.784229, 0.018206, -0.007968},{1.783330, 0.017914, -0.004033},{
      1.786947, 0.010815, -0.004033},{1.787712, 0.011370, -0.007968}}],
    Polygon[{{1.783330, 0.017914, -0.004033},{1.783028, 0.017816, 0.000000},{
      1.786691, 0.010628, 0.000000},{1.786947, 0.010815, -0.004033}}],
    Polygon[{{1.783028, 0.017816, 0.000000},{1.783330, 0.017914, 0.004033},{
      1.786947, 0.010815, 0.004033},{1.786691, 0.010628, 0.000000}}],
    Polygon[{{1.783330, 0.017914, 0.004033},{1.784229, 0.018206, 0.007968},{
      1.787712, 0.011370, 0.007968},{1.786947, 0.010815, 0.004033}}],
    Polygon[{{1.784229, 0.018206, 0.007968},{1.785701, 0.018684, 0.011705},{
      1.788964, 0.012280, 0.011705},{1.787712, 0.011370, 0.007968}}],
    Polygon[{{1.785701, 0.018684, 0.011705},{1.787712, 0.019338, 0.015155},{
      1.790674, 0.013523, 0.015155},{1.788964, 0.012280, 0.011705}}],
    Polygon[{{1.787712, 0.019338, 0.015155},{1.790211, 0.020150, 0.018232},{
      1.792800, 0.015067, 0.018232},{1.790674, 0.013523, 0.015155}}],
    Polygon[{{1.790211, 0.020150, 0.018232},{1.793137, 0.021100, 0.020859},{
      1.795289, 0.016875, 0.020859},{1.792800, 0.015067, 0.018232}}],
    Polygon[{{1.793137, 0.021100, 0.020859},{1.796417, 0.022166, 0.022973},{
      1.798080, 0.018903, 0.022973},{1.795289, 0.016875, 0.020859}}],
    Polygon[{{1.796417, 0.022166, 0.022973},{1.799972, 0.023321, 0.024521},{
      1.801104, 0.021100, 0.024521},{1.798080, 0.018903, 0.022973}}],
    Polygon[{{1.799972, 0.023321, 0.024521},{1.803714, 0.024537, 0.025466},{
      1.804287, 0.023413, 0.025466},{1.801104, 0.021100, 0.024521}}],
    Polygon[{{1.804287, 0.023413, -0.025466},{1.801104, 0.021100, -0.024521},{
      1.802867, 0.019338, -0.024521},{1.805179, 0.022520, -0.025466}}],
    Polygon[{{1.801104, 0.021100, -0.024521},{1.798080, 0.018903, -0.022973},{
      1.800670, 0.016314, -0.022973},{1.802867, 0.019338, -0.024521}}],
    Polygon[{{1.798080, 0.018903, -0.022973},{1.795289, 0.016875, -0.020859},{
      1.798642, 0.013523, -0.020859},{1.800670, 0.016314, -0.022973}}],
    Polygon[{{1.795289, 0.016875, -0.020859},{1.792800, 0.015067, -0.018232},{
      1.796834, 0.011034, -0.018232},{1.798642, 0.013523, -0.020859}}],
    Polygon[{{1.792800, 0.015067, -0.018232},{1.790674, 0.013523, -0.015155},{
      1.795289, 0.008908, -0.015155},{1.796834, 0.011034, -0.018232}}],
    Polygon[{{1.790674, 0.013523, -0.015155},{1.788964, 0.012280, -0.011705},{
      1.794047, 0.007198, -0.011705},{1.795289, 0.008908, -0.015155}}],
    Polygon[{{1.788964, 0.012280, -0.011705},{1.787712, 0.011370, -0.007968},{
      1.793137, 0.005945, -0.007968},{1.794047, 0.007198, -0.011705}}],
    Polygon[{{1.787712, 0.011370, -0.007968},{1.786947, 0.010815, -0.004033},{
      1.792581, 0.005181, -0.004033},{1.793137, 0.005945, -0.007968}}],
    Polygon[{{1.786947, 0.010815, -0.004033},{1.786691, 0.010628, 0.000000},{
      1.792395, 0.004924, 0.000000},{1.792581, 0.005181, -0.004033}}],
    Polygon[{{1.786691, 0.010628, 0.000000},{1.786947, 0.010815, 0.004033},{
      1.792581, 0.005181, 0.004033},{1.792395, 0.004924, 0.000000}}],
    Polygon[{{1.786947, 0.010815, 0.004033},{1.787712, 0.011370, 0.007968},{
      1.793137, 0.005945, 0.007968},{1.792581, 0.005181, 0.004033}}],
    Polygon[{{1.787712, 0.011370, 0.007968},{1.788964, 0.012280, 0.011705},{
      1.794047, 0.007198, 0.011705},{1.793137, 0.005945, 0.007968}}],
    Polygon[{{1.788964, 0.012280, 0.011705},{1.790674, 0.013523, 0.015155},{
      1.795289, 0.008908, 0.015155},{1.794047, 0.007198, 0.011705}}],
    Polygon[{{1.790674, 0.013523, 0.015155},{1.792800, 0.015067, 0.018232},{
      1.796834, 0.011034, 0.018232},{1.795289, 0.008908, 0.015155}}],
    Polygon[{{1.792800, 0.015067, 0.018232},{1.795289, 0.016875, 0.020859},{
      1.798642, 0.013523, 0.020859},{1.796834, 0.011034, 0.018232}}],
    Polygon[{{1.795289, 0.016875, 0.020859},{1.798080, 0.018903, 0.022973},{
      1.800670, 0.016314, 0.022973},{1.798642, 0.013523, 0.020859}}],
    Polygon[{{1.798080, 0.018903, 0.022973},{1.801104, 0.021100, 0.024521},{
      1.802867, 0.019338, 0.024521},{1.800670, 0.016314, 0.022973}}],
    Polygon[{{1.801104, 0.021100, 0.024521},{1.804287, 0.023413, 0.025466},{
      1.805179, 0.022520, 0.025466},{1.802867, 0.019338, 0.024521}}],
    Polygon[{{1.805179, 0.022520, -0.025466},{1.802867, 0.019338, -0.024521},{
      1.805088, 0.018206, -0.024521},{1.806304, 0.021947, -0.025466}}],
    Polygon[{{1.802867, 0.019338, -0.024521},{1.800670, 0.016314, -0.022973},{
      1.803933, 0.014651, -0.022973},{1.805088, 0.018206, -0.024521}}],
    Polygon[{{1.800670, 0.016314, -0.022973},{1.798642, 0.013523, -0.020859},{
      1.802867, 0.011370, -0.020859},{1.803933, 0.014651, -0.022973}}],
    Polygon[{{1.798642, 0.013523, -0.020859},{1.796834, 0.011034, -0.018232},{
      1.801916, 0.008444, -0.018232},{1.802867, 0.011370, -0.020859}}],
    Polygon[{{1.796834, 0.011034, -0.018232},{1.795289, 0.008908, -0.015155},{
      1.801104, 0.005945, -0.015155},{1.801916, 0.008444, -0.018232}}],
    Polygon[{{1.795289, 0.008908, -0.015155},{1.794047, 0.007198, -0.011705},{
      1.800451, 0.003935, -0.011705},{1.801104, 0.005945, -0.015155}}],
    Polygon[{{1.794047, 0.007198, -0.011705},{1.793137, 0.005945, -0.007968},{
      1.799972, 0.002462, -0.007968},{1.800451, 0.003935, -0.011705}}],
    Polygon[{{1.793137, 0.005945, -0.007968},{1.792581, 0.005181, -0.004033},{
      1.799680, 0.001564, -0.004033},{1.799972, 0.002462, -0.007968}}],
    Polygon[{{1.792581, 0.005181, -0.004033},{1.792395, 0.004924, 0.000000},{
      1.799582, 0.001262, 0.000000},{1.799680, 0.001564, -0.004033}}],
    Polygon[{{1.792395, 0.004924, 0.000000},{1.792581, 0.005181, 0.004033},{
      1.799680, 0.001564, 0.004033},{1.799582, 0.001262, 0.000000}}],
    Polygon[{{1.792581, 0.005181, 0.004033},{1.793137, 0.005945, 0.007968},{
      1.799972, 0.002462, 0.007968},{1.799680, 0.001564, 0.004033}}],
    Polygon[{{1.793137, 0.005945, 0.007968},{1.794047, 0.007198, 0.011705},{
      1.800451, 0.003935, 0.011705},{1.799972, 0.002462, 0.007968}}],
    Polygon[{{1.794047, 0.007198, 0.011705},{1.795289, 0.008908, 0.015155},{
      1.801104, 0.005945, 0.015155},{1.800451, 0.003935, 0.011705}}],
    Polygon[{{1.795289, 0.008908, 0.015155},{1.796834, 0.011034, 0.018232},{
      1.801916, 0.008444, 0.018232},{1.801104, 0.005945, 0.015155}}],
    Polygon[{{1.796834, 0.011034, 0.018232},{1.798642, 0.013523, 0.020859},{
      1.802867, 0.011370, 0.020859},{1.801916, 0.008444, 0.018232}}],
    Polygon[{{1.798642, 0.013523, 0.020859},{1.800670, 0.016314, 0.022973},{
      1.803933, 0.014651, 0.022973},{1.802867, 0.011370, 0.020859}}],
    Polygon[{{1.800670, 0.016314, 0.022973},{1.802867, 0.019338, 0.024521},{
      1.805088, 0.018206, 0.024521},{1.803933, 0.014651, 0.022973}}],
    Polygon[{{1.802867, 0.019338, 0.024521},{1.805179, 0.022520, 0.025466},{
      1.806304, 0.021947, 0.025466},{1.805088, 0.018206, 0.024521}}],
    Polygon[{{1.806304, 0.021947, -0.025466},{1.805088, 0.018206, -0.024521},{
      1.807550, 0.017816, -0.024521},{1.807550, 0.021750, -0.025466}}],
    Polygon[{{1.805088, 0.018206, -0.024521},{1.803933, 0.014651, -0.022973},{
      1.807550, 0.014078, -0.022973},{1.807550, 0.017816, -0.024521}}],
    Polygon[{{1.803933, 0.014651, -0.022973},{1.802867, 0.011370, -0.020859},{
      1.807550, 0.010628, -0.020859},{1.807550, 0.014078, -0.022973}}],
    Polygon[{{1.802867, 0.011370, -0.020859},{1.801916, 0.008444, -0.018232},{
      1.807550, 0.007552, -0.018232},{1.807550, 0.010628, -0.020859}}],
    Polygon[{{1.801916, 0.008444, -0.018232},{1.801104, 0.005945, -0.015155},{
      1.807550, 0.004924, -0.015155},{1.807550, 0.007552, -0.018232}}],
    Polygon[{{1.801104, 0.005945, -0.015155},{1.800451, 0.003935, -0.011705},{
      1.807550, 0.002810, -0.011705},{1.807550, 0.004924, -0.015155}}],
    Polygon[{{1.800451, 0.003935, -0.011705},{1.799972, 0.002462, -0.007968},{
      1.807550, 0.001262, -0.007968},{1.807550, 0.002810, -0.011705}}],
    Polygon[{{1.799972, 0.002462, -0.007968},{1.799680, 0.001564, -0.004033},{
      1.807550, 0.000317, -0.004033},{1.807550, 0.001262, -0.007968}}],
    Polygon[{{1.799680, 0.001564, -0.004033},{1.799582, 0.001262, 0.000000},{
      1.807550, 0.000000, 0.000000},{1.807550, 0.000317, -0.004033}}],
    Polygon[{{1.799582, 0.001262, 0.000000},{1.799680, 0.001564, 0.004033},{
      1.807550, 0.000317, 0.004033},{1.807550, 0.000000, 0.000000}}],
    Polygon[{{1.799680, 0.001564, 0.004033},{1.799972, 0.002462, 0.007968},{
      1.807550, 0.001262, 0.007968},{1.807550, 0.000317, 0.004033}}],
    Polygon[{{1.799972, 0.002462, 0.007968},{1.800451, 0.003935, 0.011705},{
      1.807550, 0.002810, 0.011705},{1.807550, 0.001262, 0.007968}}],
    Polygon[{{1.800451, 0.003935, 0.011705},{1.801104, 0.005945, 0.015155},{
      1.807550, 0.004924, 0.015155},{1.807550, 0.002810, 0.011705}}],
    Polygon[{{1.801104, 0.005945, 0.015155},{1.801916, 0.008444, 0.018232},{
      1.807550, 0.007552, 0.018232},{1.807550, 0.004924, 0.015155}}],
    Polygon[{{1.801916, 0.008444, 0.018232},{1.802867, 0.011370, 0.020859},{
      1.807550, 0.010628, 0.020859},{1.807550, 0.007552, 0.018232}}],
    Polygon[{{1.802867, 0.011370, 0.020859},{1.803933, 0.014651, 0.022973},{
      1.807550, 0.014078, 0.022973},{1.807550, 0.010628, 0.020859}}],
    Polygon[{{1.803933, 0.014651, 0.022973},{1.805088, 0.018206, 0.024521},{
      1.807550, 0.017816, 0.024521},{1.807550, 0.014078, 0.022973}}],
    Polygon[{{1.805088, 0.018206, 0.024521},{1.806304, 0.021947, 0.025466},{
      1.807550, 0.021750, 0.025466},{1.807550, 0.017816, 0.024521}}],
    Polygon[{{1.807550, 0.021750, -0.025466},{1.807550, 0.017816, -0.024521},{
      1.810012, 0.018206, -0.024521},{1.808796, 0.021947, -0.025466}}],
    Polygon[{{1.807550, 0.017816, -0.024521},{1.807550, 0.014078, -0.022973},{
      1.811167, 0.014651, -0.022973},{1.810012, 0.018206, -0.024521}}],
    Polygon[{{1.807550, 0.014078, -0.022973},{1.807550, 0.010628, -0.020859},{
      1.812233, 0.011370, -0.020859},{1.811167, 0.014651, -0.022973}}],
    Polygon[{{1.807550, 0.010628, -0.020859},{1.807550, 0.007552, -0.018232},{
      1.813184, 0.008444, -0.018232},{1.812233, 0.011370, -0.020859}}],
    Polygon[{{1.807550, 0.007552, -0.018232},{1.807550, 0.004924, -0.015155},{
      1.813996, 0.005945, -0.015155},{1.813184, 0.008444, -0.018232}}],
    Polygon[{{1.807550, 0.004924, -0.015155},{1.807550, 0.002810, -0.011705},{
      1.814649, 0.003935, -0.011705},{1.813996, 0.005945, -0.015155}}],
    Polygon[{{1.807550, 0.002810, -0.011705},{1.807550, 0.001262, -0.007968},{
      1.815127, 0.002462, -0.007968},{1.814649, 0.003935, -0.011705}}],
    Polygon[{{1.807550, 0.001262, -0.007968},{1.807550, 0.000317, -0.004033},{
      1.815419, 0.001564, -0.004033},{1.815127, 0.002462, -0.007968}}],
    Polygon[{{1.807550, 0.000317, -0.004033},{1.807550, 0.000000, 0.000000},{
      1.815517, 0.001262, 0.000000},{1.815419, 0.001564, -0.004033}}],
    Polygon[{{1.807550, 0.000000, 0.000000},{1.807550, 0.000317, 0.004033},{
      1.815419, 0.001564, 0.004033},{1.815517, 0.001262, 0.000000}}],
    Polygon[{{1.807550, 0.000317, 0.004033},{1.807550, 0.001262, 0.007968},{
      1.815127, 0.002462, 0.007968},{1.815419, 0.001564, 0.004033}}],
    Polygon[{{1.807550, 0.001262, 0.007968},{1.807550, 0.002810, 0.011705},{
      1.814649, 0.003935, 0.011705},{1.815127, 0.002462, 0.007968}}],
    Polygon[{{1.807550, 0.002810, 0.011705},{1.807550, 0.004924, 0.015155},{
      1.813996, 0.005945, 0.015155},{1.814649, 0.003935, 0.011705}}],
    Polygon[{{1.807550, 0.004924, 0.015155},{1.807550, 0.007552, 0.018232},{
      1.813184, 0.008444, 0.018232},{1.813996, 0.005945, 0.015155}}],
    Polygon[{{1.807550, 0.007552, 0.018232},{1.807550, 0.010628, 0.020859},{
      1.812233, 0.011370, 0.020859},{1.813184, 0.008444, 0.018232}}],
    Polygon[{{1.807550, 0.010628, 0.020859},{1.807550, 0.014078, 0.022973},{
      1.811167, 0.014651, 0.022973},{1.812233, 0.011370, 0.020859}}],
    Polygon[{{1.807550, 0.014078, 0.022973},{1.807550, 0.017816, 0.024521},{
      1.810012, 0.018206, 0.024521},{1.811167, 0.014651, 0.022973}}],
    Polygon[{{1.807550, 0.017816, 0.024521},{1.807550, 0.021750, 0.025466},{
      1.808796, 0.021947, 0.025466},{1.810012, 0.018206, 0.024521}}],
    Polygon[{{1.808796, 0.021947, -0.025466},{1.810012, 0.018206, -0.024521},{
      1.812233, 0.019338, -0.024521},{1.809921, 0.022520, -0.025466}}],
    Polygon[{{1.810012, 0.018206, -0.024521},{1.811167, 0.014651, -0.022973},{
      1.814430, 0.016314, -0.022973},{1.812233, 0.019338, -0.024521}}],
    Polygon[{{1.811167, 0.014651, -0.022973},{1.812233, 0.011370, -0.020859},{
      1.816458, 0.013523, -0.020859},{1.814430, 0.016314, -0.022973}}],
    Polygon[{{1.812233, 0.011370, -0.020859},{1.813184, 0.008444, -0.018232},{
      1.818266, 0.011034, -0.018232},{1.816458, 0.013523, -0.020859}}],
    Polygon[{{1.813184, 0.008444, -0.018232},{1.813996, 0.005945, -0.015155},{
      1.819811, 0.008908, -0.015155},{1.818266, 0.011034, -0.018232}}],
    Polygon[{{1.813996, 0.005945, -0.015155},{1.814649, 0.003935, -0.011705},{
      1.821053, 0.007198, -0.011705},{1.819811, 0.008908, -0.015155}}],
    Polygon[{{1.814649, 0.003935, -0.011705},{1.815127, 0.002462, -0.007968},{
      1.821963, 0.005945, -0.007968},{1.821053, 0.007198, -0.011705}}],
    Polygon[{{1.815127, 0.002462, -0.007968},{1.815419, 0.001564, -0.004033},{
      1.822518, 0.005181, -0.004033},{1.821963, 0.005945, -0.007968}}],
    Polygon[{{1.815419, 0.001564, -0.004033},{1.815517, 0.001262, 0.000000},{
      1.822705, 0.004924, 0.000000},{1.822518, 0.005181, -0.004033}}],
    Polygon[{{1.815517, 0.001262, 0.000000},{1.815419, 0.001564, 0.004033},{
      1.822518, 0.005181, 0.004033},{1.822705, 0.004924, 0.000000}}],
    Polygon[{{1.815419, 0.001564, 0.004033},{1.815127, 0.002462, 0.007968},{
      1.821963, 0.005945, 0.007968},{1.822518, 0.005181, 0.004033}}],
    Polygon[{{1.815127, 0.002462, 0.007968},{1.814649, 0.003935, 0.011705},{
      1.821053, 0.007198, 0.011705},{1.821963, 0.005945, 0.007968}}],
    Polygon[{{1.814649, 0.003935, 0.011705},{1.813996, 0.005945, 0.015155},{
      1.819811, 0.008908, 0.015155},{1.821053, 0.007198, 0.011705}}],
    Polygon[{{1.813996, 0.005945, 0.015155},{1.813184, 0.008444, 0.018232},{
      1.818266, 0.011034, 0.018232},{1.819811, 0.008908, 0.015155}}],
    Polygon[{{1.813184, 0.008444, 0.018232},{1.812233, 0.011370, 0.020859},{
      1.816458, 0.013523, 0.020859},{1.818266, 0.011034, 0.018232}}],
    Polygon[{{1.812233, 0.011370, 0.020859},{1.811167, 0.014651, 0.022973},{
      1.814430, 0.016314, 0.022973},{1.816458, 0.013523, 0.020859}}],
    Polygon[{{1.811167, 0.014651, 0.022973},{1.810012, 0.018206, 0.024521},{
      1.812233, 0.019338, 0.024521},{1.814430, 0.016314, 0.022973}}],
    Polygon[{{1.810012, 0.018206, 0.024521},{1.808796, 0.021947, 0.025466},{
      1.809921, 0.022520, 0.025466},{1.812233, 0.019338, 0.024521}}],
    Polygon[{{1.809921, 0.022520, -0.025466},{1.812233, 0.019338, -0.024521},{
      1.813996, 0.021100, -0.024521},{1.810813, 0.023413, -0.025466}}],
    Polygon[{{1.812233, 0.019338, -0.024521},{1.814430, 0.016314, -0.022973},{
      1.817020, 0.018903, -0.022973},{1.813996, 0.021100, -0.024521}}],
    Polygon[{{1.814430, 0.016314, -0.022973},{1.816458, 0.013523, -0.020859},{
      1.819811, 0.016875, -0.020859},{1.817020, 0.018903, -0.022973}}],
    Polygon[{{1.816458, 0.013523, -0.020859},{1.818266, 0.011034, -0.018232},{
      1.822300, 0.015067, -0.018232},{1.819811, 0.016875, -0.020859}}],
    Polygon[{{1.818266, 0.011034, -0.018232},{1.819811, 0.008908, -0.015155},{
      1.824425, 0.013523, -0.015155},{1.822300, 0.015067, -0.018232}}],
    Polygon[{{1.819811, 0.008908, -0.015155},{1.821053, 0.007198, -0.011705},{
      1.826136, 0.012280, -0.011705},{1.824425, 0.013523, -0.015155}}],
    Polygon[{{1.821053, 0.007198, -0.011705},{1.821963, 0.005945, -0.007968},{
      1.827388, 0.011370, -0.007968},{1.826136, 0.012280, -0.011705}}],
    Polygon[{{1.821963, 0.005945, -0.007968},{1.822518, 0.005181, -0.004033},{
      1.828152, 0.010815, -0.004033},{1.827388, 0.011370, -0.007968}}],
    Polygon[{{1.822518, 0.005181, -0.004033},{1.822705, 0.004924, 0.000000},{
      1.828409, 0.010628, 0.000000},{1.828152, 0.010815, -0.004033}}],
    Polygon[{{1.822705, 0.004924, 0.000000},{1.822518, 0.005181, 0.004033},{
      1.828152, 0.010815, 0.004033},{1.828409, 0.010628, 0.000000}}],
    Polygon[{{1.822518, 0.005181, 0.004033},{1.821963, 0.005945, 0.007968},{
      1.827388, 0.011370, 0.007968},{1.828152, 0.010815, 0.004033}}],
    Polygon[{{1.821963, 0.005945, 0.007968},{1.821053, 0.007198, 0.011705},{
      1.826136, 0.012280, 0.011705},{1.827388, 0.011370, 0.007968}}],
    Polygon[{{1.821053, 0.007198, 0.011705},{1.819811, 0.008908, 0.015155},{
      1.824425, 0.013523, 0.015155},{1.826136, 0.012280, 0.011705}}],
    Polygon[{{1.819811, 0.008908, 0.015155},{1.818266, 0.011034, 0.018232},{
      1.822300, 0.015067, 0.018232},{1.824425, 0.013523, 0.015155}}],
    Polygon[{{1.818266, 0.011034, 0.018232},{1.816458, 0.013523, 0.020859},{
      1.819811, 0.016875, 0.020859},{1.822300, 0.015067, 0.018232}}],
    Polygon[{{1.816458, 0.013523, 0.020859},{1.814430, 0.016314, 0.022973},{
      1.817020, 0.018903, 0.022973},{1.819811, 0.016875, 0.020859}}],
    Polygon[{{1.814430, 0.016314, 0.022973},{1.812233, 0.019338, 0.024521},{
      1.813996, 0.021100, 0.024521},{1.817020, 0.018903, 0.022973}}],
    Polygon[{{1.812233, 0.019338, 0.024521},{1.809921, 0.022520, 0.025466},{
      1.810813, 0.023413, 0.025466},{1.813996, 0.021100, 0.024521}}],
    Polygon[{{1.810813, 0.023413, -0.025466},{1.813996, 0.021100, -0.024521},{
      1.815127, 0.023321, -0.024521},{1.811386, 0.024537, -0.025466}}],
    Polygon[{{1.813996, 0.021100, -0.024521},{1.817020, 0.018903, -0.022973},{
      1.818682, 0.022166, -0.022973},{1.815127, 0.023321, -0.024521}}],
    Polygon[{{1.817020, 0.018903, -0.022973},{1.819811, 0.016875, -0.020859},{
      1.821963, 0.021100, -0.020859},{1.818682, 0.022166, -0.022973}}],
    Polygon[{{1.819811, 0.016875, -0.020859},{1.822300, 0.015067, -0.018232},{
      1.824889, 0.020150, -0.018232},{1.821963, 0.021100, -0.020859}}],
    Polygon[{{1.822300, 0.015067, -0.018232},{1.824425, 0.013523, -0.015155},{
      1.827388, 0.019338, -0.015155},{1.824889, 0.020150, -0.018232}}],
    Polygon[{{1.824425, 0.013523, -0.015155},{1.826136, 0.012280, -0.011705},{
      1.829399, 0.018684, -0.011705},{1.827388, 0.019338, -0.015155}}],
    Polygon[{{1.826136, 0.012280, -0.011705},{1.827388, 0.011370, -0.007968},{
      1.830871, 0.018206, -0.007968},{1.829399, 0.018684, -0.011705}}],
    Polygon[{{1.827388, 0.011370, -0.007968},{1.828152, 0.010815, -0.004033},{
      1.831769, 0.017914, -0.004033},{1.830871, 0.018206, -0.007968}}],
    Polygon[{{1.828152, 0.010815, -0.004033},{1.828409, 0.010628, 0.000000},{
      1.832071, 0.017816, 0.000000},{1.831769, 0.017914, -0.004033}}],
    Polygon[{{1.828409, 0.010628, 0.000000},{1.828152, 0.010815, 0.004033},{
      1.831769, 0.017914, 0.004033},{1.832071, 0.017816, 0.000000}}],
    Polygon[{{1.828152, 0.010815, 0.004033},{1.827388, 0.011370, 0.007968},{
      1.830871, 0.018206, 0.007968},{1.831769, 0.017914, 0.004033}}],
    Polygon[{{1.827388, 0.011370, 0.007968},{1.826136, 0.012280, 0.011705},{
      1.829399, 0.018684, 0.011705},{1.830871, 0.018206, 0.007968}}],
    Polygon[{{1.826136, 0.012280, 0.011705},{1.824425, 0.013523, 0.015155},{
      1.827388, 0.019338, 0.015155},{1.829399, 0.018684, 0.011705}}],
    Polygon[{{1.824425, 0.013523, 0.015155},{1.822300, 0.015067, 0.018232},{
      1.824889, 0.020150, 0.018232},{1.827388, 0.019338, 0.015155}}],
    Polygon[{{1.822300, 0.015067, 0.018232},{1.819811, 0.016875, 0.020859},{
      1.821963, 0.021100, 0.020859},{1.824889, 0.020150, 0.018232}}],
    Polygon[{{1.819811, 0.016875, 0.020859},{1.817020, 0.018903, 0.022973},{
      1.818682, 0.022166, 0.022973},{1.821963, 0.021100, 0.020859}}],
    Polygon[{{1.817020, 0.018903, 0.022973},{1.813996, 0.021100, 0.024521},{
      1.815127, 0.023321, 0.024521},{1.818682, 0.022166, 0.022973}}],
    Polygon[{{1.813996, 0.021100, 0.024521},{1.810813, 0.023413, 0.025466},{
      1.811386, 0.024537, 0.025466},{1.815127, 0.023321, 0.024521}}],
    Polygon[{{1.811386, 0.024537, -0.025466},{1.815127, 0.023321, -0.024521},{
      1.815517, 0.025783, -0.024521},{1.811583, 0.025783, -0.025466}}],
    Polygon[{{1.815127, 0.023321, -0.024521},{1.818682, 0.022166, -0.022973},{
      1.819255, 0.025783, -0.022973},{1.815517, 0.025783, -0.024521}}],
    Polygon[{{1.818682, 0.022166, -0.022973},{1.821963, 0.021100, -0.020859},{
      1.822705, 0.025783, -0.020859},{1.819255, 0.025783, -0.022973}}],
    Polygon[{{1.821963, 0.021100, -0.020859},{1.824889, 0.020150, -0.018232},{
      1.825782, 0.025783, -0.018232},{1.822705, 0.025783, -0.020859}}],
    Polygon[{{1.824889, 0.020150, -0.018232},{1.827388, 0.019338, -0.015155},{
      1.828409, 0.025783, -0.015155},{1.825782, 0.025783, -0.018232}}],
    Polygon[{{1.827388, 0.019338, -0.015155},{1.829399, 0.018684, -0.011705},{
      1.830523, 0.025783, -0.011705},{1.828409, 0.025783, -0.015155}}],
    Polygon[{{1.829399, 0.018684, -0.011705},{1.830871, 0.018206, -0.007968},{
      1.832071, 0.025783, -0.007968},{1.830523, 0.025783, -0.011705}}],
    Polygon[{{1.830871, 0.018206, -0.007968},{1.831769, 0.017914, -0.004033},{
      1.833016, 0.025783, -0.004033},{1.832071, 0.025783, -0.007968}}],
    Polygon[{{1.831769, 0.017914, -0.004033},{1.832071, 0.017816, 0.000000},{
      1.833333, 0.025783, 0.000000},{1.833016, 0.025783, -0.004033}}],
    Polygon[{{1.832071, 0.017816, 0.000000},{1.831769, 0.017914, 0.004033},{
      1.833016, 0.025783, 0.004033},{1.833333, 0.025783, 0.000000}}],
    Polygon[{{1.831769, 0.017914, 0.004033},{1.830871, 0.018206, 0.007968},{
      1.832071, 0.025783, 0.007968},{1.833016, 0.025783, 0.004033}}],
    Polygon[{{1.830871, 0.018206, 0.007968},{1.829399, 0.018684, 0.011705},{
      1.830523, 0.025783, 0.011705},{1.832071, 0.025783, 0.007968}}],
    Polygon[{{1.829399, 0.018684, 0.011705},{1.827388, 0.019338, 0.015155},{
      1.828409, 0.025783, 0.015155},{1.830523, 0.025783, 0.011705}}],
    Polygon[{{1.827388, 0.019338, 0.015155},{1.824889, 0.020150, 0.018232},{
      1.825782, 0.025783, 0.018232},{1.828409, 0.025783, 0.015155}}],
    Polygon[{{1.824889, 0.020150, 0.018232},{1.821963, 0.021100, 0.020859},{
      1.822705, 0.025783, 0.020859},{1.825782, 0.025783, 0.018232}}],
    Polygon[{{1.821963, 0.021100, 0.020859},{1.818682, 0.022166, 0.022973},{
      1.819255, 0.025783, 0.022973},{1.822705, 0.025783, 0.020859}}],
    Polygon[{{1.818682, 0.022166, 0.022973},{1.815127, 0.023321, 0.024521},{
      1.815517, 0.025783, 0.024521},{1.819255, 0.025783, 0.022973}}],
    Polygon[{{1.815127, 0.023321, 0.024521},{1.811386, 0.024537, 0.025466},{
      1.811583, 0.025783, 0.025466},{1.815517, 0.025783, 0.024521}}],
    Polygon[{{1.771962, 0.013817, -0.013647},{1.774070, 0.013817, -0.013141},{
      1.773861, 0.015137, -0.013141},{1.771856, 0.014485, -0.013647}}],
    Polygon[{{1.774070, 0.013817, -0.013141},{1.776073, 0.013817, -0.012311},{
      1.775766, 0.015756, -0.012311},{1.773861, 0.015137, -0.013141}}],
    Polygon[{{1.776073, 0.013817, -0.012311},{1.777922, 0.013817, -0.011178},{
      1.777524, 0.016327, -0.011178},{1.775766, 0.015756, -0.012311}}],
    Polygon[{{1.777922, 0.013817, -0.011178},{1.779571, 0.013817, -0.009770},{
      1.779092, 0.016836, -0.009770},{1.777524, 0.016327, -0.011178}}],
    Polygon[{{1.779571, 0.013817, -0.009770},{1.780979, 0.013817, -0.008122},{
      1.780432, 0.017272, -0.008122},{1.779092, 0.016836, -0.009770}}],
    Polygon[{{1.780979, 0.013817, -0.008122},{1.782112, 0.013817, -0.006273},{
      1.781509, 0.017622, -0.006273},{1.780432, 0.017272, -0.008122}}],
    Polygon[{{1.782112, 0.013817, -0.006273},{1.782941, 0.013817, -0.004270},{
      1.782298, 0.017878, -0.004270},{1.781509, 0.017622, -0.006273}}],
    Polygon[{{1.782941, 0.013817, -0.004270},{1.783448, 0.013817, -0.002162},{
      1.782780, 0.018035, -0.002162},{1.782298, 0.017878, -0.004270}}],
    Polygon[{{1.783448, 0.013817, -0.002162},{1.783618, 0.013817, 0.000000},{
      1.782941, 0.018087, 0.000000},{1.782780, 0.018035, -0.002162}}],
    Polygon[{{1.783618, 0.013817, 0.000000},{1.783448, 0.013817, 0.002162},{
      1.782780, 0.018035, 0.002162},{1.782941, 0.018087, 0.000000}}],
    Polygon[{{1.783448, 0.013817, 0.002162},{1.782941, 0.013817, 0.004270},{
      1.782298, 0.017878, 0.004270},{1.782780, 0.018035, 0.002162}}],
    Polygon[{{1.782941, 0.013817, 0.004270},{1.782112, 0.013817, 0.006273},{
      1.781509, 0.017622, 0.006273},{1.782298, 0.017878, 0.004270}}],
    Polygon[{{1.782112, 0.013817, 0.006273},{1.780979, 0.013817, 0.008122},{
      1.780432, 0.017272, 0.008122},{1.781509, 0.017622, 0.006273}}],
    Polygon[{{1.780979, 0.013817, 0.008122},{1.779571, 0.013817, 0.009770},{
      1.779092, 0.016836, 0.009770},{1.780432, 0.017272, 0.008122}}],
    Polygon[{{1.779571, 0.013817, 0.009770},{1.777922, 0.013817, 0.011178},{
      1.777524, 0.016327, 0.011178},{1.779092, 0.016836, 0.009770}}],
    Polygon[{{1.777922, 0.013817, 0.011178},{1.776073, 0.013817, 0.012311},{
      1.775766, 0.015756, 0.012311},{1.777524, 0.016327, 0.011178}}],
    Polygon[{{1.776073, 0.013817, 0.012311},{1.774070, 0.013817, 0.013141},{
      1.773861, 0.015137, 0.013141},{1.775766, 0.015756, 0.012311}}],
    Polygon[{{1.774070, 0.013817, 0.013141},{1.771962, 0.013817, 0.013647},{
      1.771856, 0.014485, 0.013647},{1.773861, 0.015137, 0.013141}}],
    Polygon[{{1.771856, 0.014485, -0.013647},{1.773861, 0.015137, -0.013141},{
      1.773255, 0.016327, -0.013141},{1.771549, 0.015088, -0.013647}}],
    Polygon[{{1.773861, 0.015137, -0.013141},{1.775766, 0.015756, -0.012311},{
      1.774875, 0.017504, -0.012311},{1.773255, 0.016327, -0.013141}}],
    Polygon[{{1.775766, 0.015756, -0.012311},{1.777524, 0.016327, -0.011178},{
      1.776371, 0.018591, -0.011178},{1.774875, 0.017504, -0.012311}}],
    Polygon[{{1.777524, 0.016327, -0.011178},{1.779092, 0.016836, -0.009770},{
      1.777705, 0.019560, -0.009770},{1.776371, 0.018591, -0.011178}}],
    Polygon[{{1.779092, 0.016836, -0.009770},{1.780432, 0.017272, -0.008122},{
      1.778844, 0.020388, -0.008122},{1.777705, 0.019560, -0.009770}}],
    Polygon[{{1.780432, 0.017272, -0.008122},{1.781509, 0.017622, -0.006273},{
      1.779760, 0.021054, -0.006273},{1.778844, 0.020388, -0.008122}}],
    Polygon[{{1.781509, 0.017622, -0.006273},{1.782298, 0.017878, -0.004270},{
      1.780432, 0.021541, -0.004270},{1.779760, 0.021054, -0.006273}}],
    Polygon[{{1.782298, 0.017878, -0.004270},{1.782780, 0.018035, -0.002162},{
      1.780841, 0.021839, -0.002162},{1.780432, 0.021541, -0.004270}}],
    Polygon[{{1.782780, 0.018035, -0.002162},{1.782941, 0.018087, 0.000000},{
      1.780979, 0.021939, 0.000000},{1.780841, 0.021839, -0.002162}}],
    Polygon[{{1.782941, 0.018087, 0.000000},{1.782780, 0.018035, 0.002162},{
      1.780841, 0.021839, 0.002162},{1.780979, 0.021939, 0.000000}}],
    Polygon[{{1.782780, 0.018035, 0.002162},{1.782298, 0.017878, 0.004270},{
      1.780432, 0.021541, 0.004270},{1.780841, 0.021839, 0.002162}}],
    Polygon[{{1.782298, 0.017878, 0.004270},{1.781509, 0.017622, 0.006273},{
      1.779760, 0.021054, 0.006273},{1.780432, 0.021541, 0.004270}}],
    Polygon[{{1.781509, 0.017622, 0.006273},{1.780432, 0.017272, 0.008122},{
      1.778844, 0.020388, 0.008122},{1.779760, 0.021054, 0.006273}}],
    Polygon[{{1.780432, 0.017272, 0.008122},{1.779092, 0.016836, 0.009770},{
      1.777705, 0.019560, 0.009770},{1.778844, 0.020388, 0.008122}}],
    Polygon[{{1.779092, 0.016836, 0.009770},{1.777524, 0.016327, 0.011178},{
      1.776371, 0.018591, 0.011178},{1.777705, 0.019560, 0.009770}}],
    Polygon[{{1.777524, 0.016327, 0.011178},{1.775766, 0.015756, 0.012311},{
      1.774875, 0.017504, 0.012311},{1.776371, 0.018591, 0.011178}}],
    Polygon[{{1.775766, 0.015756, 0.012311},{1.773861, 0.015137, 0.013141},{
      1.773255, 0.016327, 0.013141},{1.774875, 0.017504, 0.012311}}],
    Polygon[{{1.773861, 0.015137, 0.013141},{1.771856, 0.014485, 0.013647},{
      1.771549, 0.015088, 0.013647},{1.773255, 0.016327, 0.013141}}],
    Polygon[{{1.771549, 0.015088, -0.013647},{1.773255, 0.016327, -0.013141},{
      1.772310, 0.017272, -0.013141},{1.771071, 0.015566, -0.013647}}],
    Polygon[{{1.773255, 0.016327, -0.013141},{1.774875, 0.017504, -0.012311},{
      1.773487, 0.018892, -0.012311},{1.772310, 0.017272, -0.013141}}],
    Polygon[{{1.774875, 0.017504, -0.012311},{1.776371, 0.018591, -0.011178},{
      1.774574, 0.020388, -0.011178},{1.773487, 0.018892, -0.012311}}],
    Polygon[{{1.776371, 0.018591, -0.011178},{1.777705, 0.019560, -0.009770},{
      1.775543, 0.021722, -0.009770},{1.774574, 0.020388, -0.011178}}],
    Polygon[{{1.777705, 0.019560, -0.009770},{1.778844, 0.020388, -0.008122},{
      1.776371, 0.022861, -0.008122},{1.775543, 0.021722, -0.009770}}],
    Polygon[{{1.778844, 0.020388, -0.008122},{1.779760, 0.021054, -0.006273},{
      1.777037, 0.023777, -0.006273},{1.776371, 0.022861, -0.008122}}],
    Polygon[{{1.779760, 0.021054, -0.006273},{1.780432, 0.021541, -0.004270},{
      1.777524, 0.024449, -0.004270},{1.777037, 0.023777, -0.006273}}],
    Polygon[{{1.780432, 0.021541, -0.004270},{1.780841, 0.021839, -0.002162},{
      1.777822, 0.024858, -0.002162},{1.777524, 0.024449, -0.004270}}],
    Polygon[{{1.780841, 0.021839, -0.002162},{1.780979, 0.021939, 0.000000},{
      1.777922, 0.024996, 0.000000},{1.777822, 0.024858, -0.002162}}],
    Polygon[{{1.780979, 0.021939, 0.000000},{1.780841, 0.021839, 0.002162},{
      1.777822, 0.024858, 0.002162},{1.777922, 0.024996, 0.000000}}],
    Polygon[{{1.780841, 0.021839, 0.002162},{1.780432, 0.021541, 0.004270},{
      1.777524, 0.024449, 0.004270},{1.777822, 0.024858, 0.002162}}],
    Polygon[{{1.780432, 0.021541, 0.004270},{1.779760, 0.021054, 0.006273},{
      1.777037, 0.023777, 0.006273},{1.777524, 0.024449, 0.004270}}],
    Polygon[{{1.779760, 0.021054, 0.006273},{1.778844, 0.020388, 0.008122},{
      1.776371, 0.022861, 0.008122},{1.777037, 0.023777, 0.006273}}],
    Polygon[{{1.778844, 0.020388, 0.008122},{1.777705, 0.019560, 0.009770},{
      1.775543, 0.021722, 0.009770},{1.776371, 0.022861, 0.008122}}],
    Polygon[{{1.777705, 0.019560, 0.009770},{1.776371, 0.018591, 0.011178},{
      1.774574, 0.020388, 0.011178},{1.775543, 0.021722, 0.009770}}],
    Polygon[{{1.776371, 0.018591, 0.011178},{1.774875, 0.017504, 0.012311},{
      1.773487, 0.018892, 0.012311},{1.774574, 0.020388, 0.011178}}],
    Polygon[{{1.774875, 0.017504, 0.012311},{1.773255, 0.016327, 0.013141},{
      1.772310, 0.017272, 0.013141},{1.773487, 0.018892, 0.012311}}],
    Polygon[{{1.773255, 0.016327, 0.013141},{1.771549, 0.015088, 0.013647},{
      1.771071, 0.015566, 0.013647},{1.772310, 0.017272, 0.013141}}],
    Polygon[{{1.771071, 0.015566, -0.013647},{1.772310, 0.017272, -0.013141},{
      1.771120, 0.017878, -0.013141},{1.770468, 0.015873, -0.013647}}],
    Polygon[{{1.772310, 0.017272, -0.013141},{1.773487, 0.018892, -0.012311},{
      1.771739, 0.019783, -0.012311},{1.771120, 0.017878, -0.013141}}],
    Polygon[{{1.773487, 0.018892, -0.012311},{1.774574, 0.020388, -0.011178},{
      1.772310, 0.021541, -0.011178},{1.771739, 0.019783, -0.012311}}],
    Polygon[{{1.774574, 0.020388, -0.011178},{1.775543, 0.021722, -0.009770},{
      1.772820, 0.023109, -0.009770},{1.772310, 0.021541, -0.011178}}],
    Polygon[{{1.775543, 0.021722, -0.009770},{1.776371, 0.022861, -0.008122},{
      1.773255, 0.024449, -0.008122},{1.772820, 0.023109, -0.009770}}],
    Polygon[{{1.776371, 0.022861, -0.008122},{1.777037, 0.023777, -0.006273},{
      1.773605, 0.025526, -0.006273},{1.773255, 0.024449, -0.008122}}],
    Polygon[{{1.777037, 0.023777, -0.006273},{1.777524, 0.024449, -0.004270},{
      1.773861, 0.026315, -0.004270},{1.773605, 0.025526, -0.006273}}],
    Polygon[{{1.777524, 0.024449, -0.004270},{1.777822, 0.024858, -0.002162},{
      1.774018, 0.026797, -0.002162},{1.773861, 0.026315, -0.004270}}],
    Polygon[{{1.777822, 0.024858, -0.002162},{1.777922, 0.024996, 0.000000},{
      1.774070, 0.026958, 0.000000},{1.774018, 0.026797, -0.002162}}],
    Polygon[{{1.777922, 0.024996, 0.000000},{1.777822, 0.024858, 0.002162},{
      1.774018, 0.026797, 0.002162},{1.774070, 0.026958, 0.000000}}],
    Polygon[{{1.777822, 0.024858, 0.002162},{1.777524, 0.024449, 0.004270},{
      1.773861, 0.026315, 0.004270},{1.774018, 0.026797, 0.002162}}],
    Polygon[{{1.777524, 0.024449, 0.004270},{1.777037, 0.023777, 0.006273},{
      1.773605, 0.025526, 0.006273},{1.773861, 0.026315, 0.004270}}],
    Polygon[{{1.777037, 0.023777, 0.006273},{1.776371, 0.022861, 0.008122},{
      1.773255, 0.024449, 0.008122},{1.773605, 0.025526, 0.006273}}],
    Polygon[{{1.776371, 0.022861, 0.008122},{1.775543, 0.021722, 0.009770},{
      1.772820, 0.023109, 0.009770},{1.773255, 0.024449, 0.008122}}],
    Polygon[{{1.775543, 0.021722, 0.009770},{1.774574, 0.020388, 0.011178},{
      1.772310, 0.021541, 0.011178},{1.772820, 0.023109, 0.009770}}],
    Polygon[{{1.774574, 0.020388, 0.011178},{1.773487, 0.018892, 0.012311},{
      1.771739, 0.019783, 0.012311},{1.772310, 0.021541, 0.011178}}],
    Polygon[{{1.773487, 0.018892, 0.012311},{1.772310, 0.017272, 0.013141},{
      1.771120, 0.017878, 0.013141},{1.771739, 0.019783, 0.012311}}],
    Polygon[{{1.772310, 0.017272, 0.013141},{1.771071, 0.015566, 0.013647},{
      1.770468, 0.015873, 0.013647},{1.771120, 0.017878, 0.013141}}],
    Polygon[{{1.770468, 0.015873, -0.013647},{1.771120, 0.017878, -0.013141},{
      1.769800, 0.018087, -0.013141},{1.769800, 0.015979, -0.013647}}],
    Polygon[{{1.771120, 0.017878, -0.013141},{1.771739, 0.019783, -0.012311},{
      1.769800, 0.020090, -0.012311},{1.769800, 0.018087, -0.013141}}],
    Polygon[{{1.771739, 0.019783, -0.012311},{1.772310, 0.021541, -0.011178},{
      1.769800, 0.021939, -0.011178},{1.769800, 0.020090, -0.012311}}],
    Polygon[{{1.772310, 0.021541, -0.011178},{1.772820, 0.023109, -0.009770},{
      1.769800, 0.023588, -0.009770},{1.769800, 0.021939, -0.011178}}],
    Polygon[{{1.772820, 0.023109, -0.009770},{1.773255, 0.024449, -0.008122},{
      1.769800, 0.024996, -0.008122},{1.769800, 0.023588, -0.009770}}],
    Polygon[{{1.773255, 0.024449, -0.008122},{1.773605, 0.025526, -0.006273},{
      1.769800, 0.026129, -0.006273},{1.769800, 0.024996, -0.008122}}],
    Polygon[{{1.773605, 0.025526, -0.006273},{1.773861, 0.026315, -0.004270},{
      1.769800, 0.026958, -0.004270},{1.769800, 0.026129, -0.006273}}],
    Polygon[{{1.773861, 0.026315, -0.004270},{1.774018, 0.026797, -0.002162},{
      1.769800, 0.027464, -0.002162},{1.769800, 0.026958, -0.004270}}],
    Polygon[{{1.774018, 0.026797, -0.002162},{1.774070, 0.026958, 0.000000},{
      1.769800, 0.027635, 0.000000},{1.769800, 0.027464, -0.002162}}],
    Polygon[{{1.774070, 0.026958, 0.000000},{1.774018, 0.026797, 0.002162},{
      1.769800, 0.027464, 0.002162},{1.769800, 0.027635, 0.000000}}],
    Polygon[{{1.774018, 0.026797, 0.002162},{1.773861, 0.026315, 0.004270},{
      1.769800, 0.026958, 0.004270},{1.769800, 0.027464, 0.002162}}],
    Polygon[{{1.773861, 0.026315, 0.004270},{1.773605, 0.025526, 0.006273},{
      1.769800, 0.026129, 0.006273},{1.769800, 0.026958, 0.004270}}],
    Polygon[{{1.773605, 0.025526, 0.006273},{1.773255, 0.024449, 0.008122},{
      1.769800, 0.024996, 0.008122},{1.769800, 0.026129, 0.006273}}],
    Polygon[{{1.773255, 0.024449, 0.008122},{1.772820, 0.023109, 0.009770},{
      1.769800, 0.023588, 0.009770},{1.769800, 0.024996, 0.008122}}],
    Polygon[{{1.772820, 0.023109, 0.009770},{1.772310, 0.021541, 0.011178},{
      1.769800, 0.021939, 0.011178},{1.769800, 0.023588, 0.009770}}],
    Polygon[{{1.772310, 0.021541, 0.011178},{1.771739, 0.019783, 0.012311},{
      1.769800, 0.020090, 0.012311},{1.769800, 0.021939, 0.011178}}],
    Polygon[{{1.771739, 0.019783, 0.012311},{1.771120, 0.017878, 0.013141},{
      1.769800, 0.018087, 0.013141},{1.769800, 0.020090, 0.012311}}],
    Polygon[{{1.771120, 0.017878, 0.013141},{1.770468, 0.015873, 0.013647},{
      1.769800, 0.015979, 0.013647},{1.769800, 0.018087, 0.013141}}],
    Polygon[{{1.769800, 0.015979, -0.013647},{1.769800, 0.018087, -0.013141},{
      1.768481, 0.017878, -0.013141},{1.769132, 0.015873, -0.013647}}],
    Polygon[{{1.769800, 0.018087, -0.013141},{1.769800, 0.020090, -0.012311},{
      1.767862, 0.019783, -0.012311},{1.768481, 0.017878, -0.013141}}],
    Polygon[{{1.769800, 0.020090, -0.012311},{1.769800, 0.021939, -0.011178},{
      1.767291, 0.021541, -0.011178},{1.767862, 0.019783, -0.012311}}],
    Polygon[{{1.769800, 0.021939, -0.011178},{1.769800, 0.023588, -0.009770},{
      1.766781, 0.023109, -0.009770},{1.767291, 0.021541, -0.011178}}],
    Polygon[{{1.769800, 0.023588, -0.009770},{1.769800, 0.024996, -0.008122},{
      1.766346, 0.024449, -0.008122},{1.766781, 0.023109, -0.009770}}],
    Polygon[{{1.769800, 0.024996, -0.008122},{1.769800, 0.026129, -0.006273},{
      1.765996, 0.025526, -0.006273},{1.766346, 0.024449, -0.008122}}],
    Polygon[{{1.769800, 0.026129, -0.006273},{1.769800, 0.026958, -0.004270},{
      1.765740, 0.026315, -0.004270},{1.765996, 0.025526, -0.006273}}],
    Polygon[{{1.769800, 0.026958, -0.004270},{1.769800, 0.027464, -0.002162},{
      1.765583, 0.026797, -0.002162},{1.765740, 0.026315, -0.004270}}],
    Polygon[{{1.769800, 0.027464, -0.002162},{1.769800, 0.027635, 0.000000},{
      1.765531, 0.026958, 0.000000},{1.765583, 0.026797, -0.002162}}],
    Polygon[{{1.769800, 0.027635, 0.000000},{1.769800, 0.027464, 0.002162},{
      1.765583, 0.026797, 0.002162},{1.765531, 0.026958, 0.000000}}],
    Polygon[{{1.769800, 0.027464, 0.002162},{1.769800, 0.026958, 0.004270},{
      1.765740, 0.026315, 0.004270},{1.765583, 0.026797, 0.002162}}],
    Polygon[{{1.769800, 0.026958, 0.004270},{1.769800, 0.026129, 0.006273},{
      1.765996, 0.025526, 0.006273},{1.765740, 0.026315, 0.004270}}],
    Polygon[{{1.769800, 0.026129, 0.006273},{1.769800, 0.024996, 0.008122},{
      1.766346, 0.024449, 0.008122},{1.765996, 0.025526, 0.006273}}],
    Polygon[{{1.769800, 0.024996, 0.008122},{1.769800, 0.023588, 0.009770},{
      1.766781, 0.023109, 0.009770},{1.766346, 0.024449, 0.008122}}],
    Polygon[{{1.769800, 0.023588, 0.009770},{1.769800, 0.021939, 0.011178},{
      1.767291, 0.021541, 0.011178},{1.766781, 0.023109, 0.009770}}],
    Polygon[{{1.769800, 0.021939, 0.011178},{1.769800, 0.020090, 0.012311},{
      1.767862, 0.019783, 0.012311},{1.767291, 0.021541, 0.011178}}],
    Polygon[{{1.769800, 0.020090, 0.012311},{1.769800, 0.018087, 0.013141},{
      1.768481, 0.017878, 0.013141},{1.767862, 0.019783, 0.012311}}],
    Polygon[{{1.769800, 0.018087, 0.013141},{1.769800, 0.015979, 0.013647},{
      1.769132, 0.015873, 0.013647},{1.768481, 0.017878, 0.013141}}],
    Polygon[{{1.769132, 0.015873, -0.013647},{1.768481, 0.017878, -0.013141},{
      1.767291, 0.017272, -0.013141},{1.768530, 0.015566, -0.013647}}],
    Polygon[{{1.768481, 0.017878, -0.013141},{1.767862, 0.019783, -0.012311},{
      1.766113, 0.018892, -0.012311},{1.767291, 0.017272, -0.013141}}],
    Polygon[{{1.767862, 0.019783, -0.012311},{1.767291, 0.021541, -0.011178},{
      1.765027, 0.020388, -0.011178},{1.766113, 0.018892, -0.012311}}],
    Polygon[{{1.767291, 0.021541, -0.011178},{1.766781, 0.023109, -0.009770},{
      1.764058, 0.021722, -0.009770},{1.765027, 0.020388, -0.011178}}],
    Polygon[{{1.766781, 0.023109, -0.009770},{1.766346, 0.024449, -0.008122},{
      1.763230, 0.022861, -0.008122},{1.764058, 0.021722, -0.009770}}],
    Polygon[{{1.766346, 0.024449, -0.008122},{1.765996, 0.025526, -0.006273},{
      1.762564, 0.023777, -0.006273},{1.763230, 0.022861, -0.008122}}],
    Polygon[{{1.765996, 0.025526, -0.006273},{1.765740, 0.026315, -0.004270},{
      1.762076, 0.024449, -0.004270},{1.762564, 0.023777, -0.006273}}],
    Polygon[{{1.765740, 0.026315, -0.004270},{1.765583, 0.026797, -0.002162},{
      1.761779, 0.024858, -0.002162},{1.762076, 0.024449, -0.004270}}],
    Polygon[{{1.765583, 0.026797, -0.002162},{1.765531, 0.026958, 0.000000},{
      1.761679, 0.024996, 0.000000},{1.761779, 0.024858, -0.002162}}],
    Polygon[{{1.765531, 0.026958, 0.000000},{1.765583, 0.026797, 0.002162},{
      1.761779, 0.024858, 0.002162},{1.761679, 0.024996, 0.000000}}],
    Polygon[{{1.765583, 0.026797, 0.002162},{1.765740, 0.026315, 0.004270},{
      1.762076, 0.024449, 0.004270},{1.761779, 0.024858, 0.002162}}],
    Polygon[{{1.765740, 0.026315, 0.004270},{1.765996, 0.025526, 0.006273},{
      1.762564, 0.023777, 0.006273},{1.762076, 0.024449, 0.004270}}],
    Polygon[{{1.765996, 0.025526, 0.006273},{1.766346, 0.024449, 0.008122},{
      1.763230, 0.022861, 0.008122},{1.762564, 0.023777, 0.006273}}],
    Polygon[{{1.766346, 0.024449, 0.008122},{1.766781, 0.023109, 0.009770},{
      1.764058, 0.021722, 0.009770},{1.763230, 0.022861, 0.008122}}],
    Polygon[{{1.766781, 0.023109, 0.009770},{1.767291, 0.021541, 0.011178},{
      1.765027, 0.020388, 0.011178},{1.764058, 0.021722, 0.009770}}],
    Polygon[{{1.767291, 0.021541, 0.011178},{1.767862, 0.019783, 0.012311},{
      1.766113, 0.018892, 0.012311},{1.765027, 0.020388, 0.011178}}],
    Polygon[{{1.767862, 0.019783, 0.012311},{1.768481, 0.017878, 0.013141},{
      1.767291, 0.017272, 0.013141},{1.766113, 0.018892, 0.012311}}],
    Polygon[{{1.768481, 0.017878, 0.013141},{1.769132, 0.015873, 0.013647},{
      1.768530, 0.015566, 0.013647},{1.767291, 0.017272, 0.013141}}],
    Polygon[{{1.768530, 0.015566, -0.013647},{1.767291, 0.017272, -0.013141},{
      1.766346, 0.016327, -0.013141},{1.768052, 0.015088, -0.013647}}],
    Polygon[{{1.767291, 0.017272, -0.013141},{1.766113, 0.018892, -0.012311},{
      1.764725, 0.017504, -0.012311},{1.766346, 0.016327, -0.013141}}],
    Polygon[{{1.766113, 0.018892, -0.012311},{1.765027, 0.020388, -0.011178},{
      1.763230, 0.018591, -0.011178},{1.764725, 0.017504, -0.012311}}],
    Polygon[{{1.765027, 0.020388, -0.011178},{1.764058, 0.021722, -0.009770},{
      1.761896, 0.019560, -0.009770},{1.763230, 0.018591, -0.011178}}],
    Polygon[{{1.764058, 0.021722, -0.009770},{1.763230, 0.022861, -0.008122},{
      1.760757, 0.020388, -0.008122},{1.761896, 0.019560, -0.009770}}],
    Polygon[{{1.763230, 0.022861, -0.008122},{1.762564, 0.023777, -0.006273},{
      1.759840, 0.021054, -0.006273},{1.760757, 0.020388, -0.008122}}],
    Polygon[{{1.762564, 0.023777, -0.006273},{1.762076, 0.024449, -0.004270},{
      1.759169, 0.021541, -0.004270},{1.759840, 0.021054, -0.006273}}],
    Polygon[{{1.762076, 0.024449, -0.004270},{1.761779, 0.024858, -0.002162},{
      1.758759, 0.021839, -0.002162},{1.759169, 0.021541, -0.004270}}],
    Polygon[{{1.761779, 0.024858, -0.002162},{1.761679, 0.024996, 0.000000},{
      1.758622, 0.021939, 0.000000},{1.758759, 0.021839, -0.002162}}],
    Polygon[{{1.761679, 0.024996, 0.000000},{1.761779, 0.024858, 0.002162},{
      1.758759, 0.021839, 0.002162},{1.758622, 0.021939, 0.000000}}],
    Polygon[{{1.761779, 0.024858, 0.002162},{1.762076, 0.024449, 0.004270},{
      1.759169, 0.021541, 0.004270},{1.758759, 0.021839, 0.002162}}],
    Polygon[{{1.762076, 0.024449, 0.004270},{1.762564, 0.023777, 0.006273},{
      1.759840, 0.021054, 0.006273},{1.759169, 0.021541, 0.004270}}],
    Polygon[{{1.762564, 0.023777, 0.006273},{1.763230, 0.022861, 0.008122},{
      1.760757, 0.020388, 0.008122},{1.759840, 0.021054, 0.006273}}],
    Polygon[{{1.763230, 0.022861, 0.008122},{1.764058, 0.021722, 0.009770},{
      1.761896, 0.019560, 0.009770},{1.760757, 0.020388, 0.008122}}],
    Polygon[{{1.764058, 0.021722, 0.009770},{1.765027, 0.020388, 0.011178},{
      1.763230, 0.018591, 0.011178},{1.761896, 0.019560, 0.009770}}],
    Polygon[{{1.765027, 0.020388, 0.011178},{1.766113, 0.018892, 0.012311},{
      1.764725, 0.017504, 0.012311},{1.763230, 0.018591, 0.011178}}],
    Polygon[{{1.766113, 0.018892, 0.012311},{1.767291, 0.017272, 0.013141},{
      1.766346, 0.016327, 0.013141},{1.764725, 0.017504, 0.012311}}],
    Polygon[{{1.767291, 0.017272, 0.013141},{1.768530, 0.015566, 0.013647},{
      1.768052, 0.015088, 0.013647},{1.766346, 0.016327, 0.013141}}],
    Polygon[{{1.768052, 0.015088, -0.013647},{1.766346, 0.016327, -0.013141},{
      1.765740, 0.015137, -0.013141},{1.767745, 0.014485, -0.013647}}],
    Polygon[{{1.766346, 0.016327, -0.013141},{1.764725, 0.017504, -0.012311},{
      1.763834, 0.015756, -0.012311},{1.765740, 0.015137, -0.013141}}],
    Polygon[{{1.764725, 0.017504, -0.012311},{1.763230, 0.018591, -0.011178},{
      1.762076, 0.016327, -0.011178},{1.763834, 0.015756, -0.012311}}],
    Polygon[{{1.763230, 0.018591, -0.011178},{1.761896, 0.019560, -0.009770},{
      1.760508, 0.016836, -0.009770},{1.762076, 0.016327, -0.011178}}],
    Polygon[{{1.761896, 0.019560, -0.009770},{1.760757, 0.020388, -0.008122},{
      1.759169, 0.017272, -0.008122},{1.760508, 0.016836, -0.009770}}],
    Polygon[{{1.760757, 0.020388, -0.008122},{1.759840, 0.021054, -0.006273},{
      1.758092, 0.017622, -0.006273},{1.759169, 0.017272, -0.008122}}],
    Polygon[{{1.759840, 0.021054, -0.006273},{1.759169, 0.021541, -0.004270},{
      1.757303, 0.017878, -0.004270},{1.758092, 0.017622, -0.006273}}],
    Polygon[{{1.759169, 0.021541, -0.004270},{1.758759, 0.021839, -0.002162},{
      1.756821, 0.018035, -0.002162},{1.757303, 0.017878, -0.004270}}],
    Polygon[{{1.758759, 0.021839, -0.002162},{1.758622, 0.021939, 0.000000},{
      1.756659, 0.018087, 0.000000},{1.756821, 0.018035, -0.002162}}],
    Polygon[{{1.758622, 0.021939, 0.000000},{1.758759, 0.021839, 0.002162},{
      1.756821, 0.018035, 0.002162},{1.756659, 0.018087, 0.000000}}],
    Polygon[{{1.758759, 0.021839, 0.002162},{1.759169, 0.021541, 0.004270},{
      1.757303, 0.017878, 0.004270},{1.756821, 0.018035, 0.002162}}],
    Polygon[{{1.759169, 0.021541, 0.004270},{1.759840, 0.021054, 0.006273},{
      1.758092, 0.017622, 0.006273},{1.757303, 0.017878, 0.004270}}],
    Polygon[{{1.759840, 0.021054, 0.006273},{1.760757, 0.020388, 0.008122},{
      1.759169, 0.017272, 0.008122},{1.758092, 0.017622, 0.006273}}],
    Polygon[{{1.760757, 0.020388, 0.008122},{1.761896, 0.019560, 0.009770},{
      1.760508, 0.016836, 0.009770},{1.759169, 0.017272, 0.008122}}],
    Polygon[{{1.761896, 0.019560, 0.009770},{1.763230, 0.018591, 0.011178},{
      1.762076, 0.016327, 0.011178},{1.760508, 0.016836, 0.009770}}],
    Polygon[{{1.763230, 0.018591, 0.011178},{1.764725, 0.017504, 0.012311},{
      1.763834, 0.015756, 0.012311},{1.762076, 0.016327, 0.011178}}],
    Polygon[{{1.764725, 0.017504, 0.012311},{1.766346, 0.016327, 0.013141},{
      1.765740, 0.015137, 0.013141},{1.763834, 0.015756, 0.012311}}],
    Polygon[{{1.766346, 0.016327, 0.013141},{1.768052, 0.015088, 0.013647},{
      1.767745, 0.014485, 0.013647},{1.765740, 0.015137, 0.013141}}],
    Polygon[{{1.767745, 0.014485, -0.013647},{1.765740, 0.015137, -0.013141},{
      1.765531, 0.013817, -0.013141},{1.767639, 0.013817, -0.013647}}],
    Polygon[{{1.765740, 0.015137, -0.013141},{1.763834, 0.015756, -0.012311},{
      1.763527, 0.013817, -0.012311},{1.765531, 0.013817, -0.013141}}],
    Polygon[{{1.763834, 0.015756, -0.012311},{1.762076, 0.016327, -0.011178},{
      1.761679, 0.013817, -0.011178},{1.763527, 0.013817, -0.012311}}],
    Polygon[{{1.762076, 0.016327, -0.011178},{1.760508, 0.016836, -0.009770},{
      1.760030, 0.013817, -0.009770},{1.761679, 0.013817, -0.011178}}],
    Polygon[{{1.760508, 0.016836, -0.009770},{1.759169, 0.017272, -0.008122},{
      1.758622, 0.013817, -0.008122},{1.760030, 0.013817, -0.009770}}],
    Polygon[{{1.759169, 0.017272, -0.008122},{1.758092, 0.017622, -0.006273},{
      1.757489, 0.013817, -0.006273},{1.758622, 0.013817, -0.008122}}],
    Polygon[{{1.758092, 0.017622, -0.006273},{1.757303, 0.017878, -0.004270},{
      1.756659, 0.013817, -0.004270},{1.757489, 0.013817, -0.006273}}],
    Polygon[{{1.757303, 0.017878, -0.004270},{1.756821, 0.018035, -0.002162},{
      1.756153, 0.013817, -0.002162},{1.756659, 0.013817, -0.004270}}],
    Polygon[{{1.756821, 0.018035, -0.002162},{1.756659, 0.018087, 0.000000},{
      1.755983, 0.013817, 0.000000},{1.756153, 0.013817, -0.002162}}],
    Polygon[{{1.756659, 0.018087, 0.000000},{1.756821, 0.018035, 0.002162},{
      1.756153, 0.013817, 0.002162},{1.755983, 0.013817, 0.000000}}],
    Polygon[{{1.756821, 0.018035, 0.002162},{1.757303, 0.017878, 0.004270},{
      1.756659, 0.013817, 0.004270},{1.756153, 0.013817, 0.002162}}],
    Polygon[{{1.757303, 0.017878, 0.004270},{1.758092, 0.017622, 0.006273},{
      1.757489, 0.013817, 0.006273},{1.756659, 0.013817, 0.004270}}],
    Polygon[{{1.758092, 0.017622, 0.006273},{1.759169, 0.017272, 0.008122},{
      1.758622, 0.013817, 0.008122},{1.757489, 0.013817, 0.006273}}],
    Polygon[{{1.759169, 0.017272, 0.008122},{1.760508, 0.016836, 0.009770},{
      1.760030, 0.013817, 0.009770},{1.758622, 0.013817, 0.008122}}],
    Polygon[{{1.760508, 0.016836, 0.009770},{1.762076, 0.016327, 0.011178},{
      1.761679, 0.013817, 0.011178},{1.760030, 0.013817, 0.009770}}],
    Polygon[{{1.762076, 0.016327, 0.011178},{1.763834, 0.015756, 0.012311},{
      1.763527, 0.013817, 0.012311},{1.761679, 0.013817, 0.011178}}],
    Polygon[{{1.763834, 0.015756, 0.012311},{1.765740, 0.015137, 0.013141},{
      1.765531, 0.013817, 0.013141},{1.763527, 0.013817, 0.012311}}],
    Polygon[{{1.765740, 0.015137, 0.013141},{1.767745, 0.014485, 0.013647},{
      1.767639, 0.013817, 0.013647},{1.765531, 0.013817, 0.013141}}],
    Polygon[{{1.767639, 0.013817, -0.013647},{1.765531, 0.013817, -0.013141},{
      1.765740, 0.012498, -0.013141},{1.767745, 0.013149, -0.013647}}],
    Polygon[{{1.765531, 0.013817, -0.013141},{1.763527, 0.013817, -0.012311},{
      1.763834, 0.011879, -0.012311},{1.765740, 0.012498, -0.013141}}],
    Polygon[{{1.763527, 0.013817, -0.012311},{1.761679, 0.013817, -0.011178},{
      1.762076, 0.011308, -0.011178},{1.763834, 0.011879, -0.012311}}],
    Polygon[{{1.761679, 0.013817, -0.011178},{1.760030, 0.013817, -0.009770},{
      1.760508, 0.010798, -0.009770},{1.762076, 0.011308, -0.011178}}],
    Polygon[{{1.760030, 0.013817, -0.009770},{1.758622, 0.013817, -0.008122},{
      1.759169, 0.010363, -0.008122},{1.760508, 0.010798, -0.009770}}],
    Polygon[{{1.758622, 0.013817, -0.008122},{1.757489, 0.013817, -0.006273},{
      1.758092, 0.010013, -0.006273},{1.759169, 0.010363, -0.008122}}],
    Polygon[{{1.757489, 0.013817, -0.006273},{1.756659, 0.013817, -0.004270},{
      1.757303, 0.009756, -0.004270},{1.758092, 0.010013, -0.006273}}],
    Polygon[{{1.756659, 0.013817, -0.004270},{1.756153, 0.013817, -0.002162},{
      1.756821, 0.009600, -0.002162},{1.757303, 0.009756, -0.004270}}],
    Polygon[{{1.756153, 0.013817, -0.002162},{1.755983, 0.013817, 0.000000},{
      1.756659, 0.009548, 0.000000},{1.756821, 0.009600, -0.002162}}],
    Polygon[{{1.755983, 0.013817, 0.000000},{1.756153, 0.013817, 0.002162},{
      1.756821, 0.009600, 0.002162},{1.756659, 0.009548, 0.000000}}],
    Polygon[{{1.756153, 0.013817, 0.002162},{1.756659, 0.013817, 0.004270},{
      1.757303, 0.009756, 0.004270},{1.756821, 0.009600, 0.002162}}],
    Polygon[{{1.756659, 0.013817, 0.004270},{1.757489, 0.013817, 0.006273},{
      1.758092, 0.010013, 0.006273},{1.757303, 0.009756, 0.004270}}],
    Polygon[{{1.757489, 0.013817, 0.006273},{1.758622, 0.013817, 0.008122},{
      1.759169, 0.010363, 0.008122},{1.758092, 0.010013, 0.006273}}],
    Polygon[{{1.758622, 0.013817, 0.008122},{1.760030, 0.013817, 0.009770},{
      1.760508, 0.010798, 0.009770},{1.759169, 0.010363, 0.008122}}],
    Polygon[{{1.760030, 0.013817, 0.009770},{1.761679, 0.013817, 0.011178},{
      1.762076, 0.011308, 0.011178},{1.760508, 0.010798, 0.009770}}],
    Polygon[{{1.761679, 0.013817, 0.011178},{1.763527, 0.013817, 0.012311},{
      1.763834, 0.011879, 0.012311},{1.762076, 0.011308, 0.011178}}],
    Polygon[{{1.763527, 0.013817, 0.012311},{1.765531, 0.013817, 0.013141},{
      1.765740, 0.012498, 0.013141},{1.763834, 0.011879, 0.012311}}],
    Polygon[{{1.765531, 0.013817, 0.013141},{1.767639, 0.013817, 0.013647},{
      1.767745, 0.013149, 0.013647},{1.765740, 0.012498, 0.013141}}],
    Polygon[{{1.767745, 0.013149, -0.013647},{1.765740, 0.012498, -0.013141},{
      1.766346, 0.011308, -0.013141},{1.768052, 0.012547, -0.013647}}],
    Polygon[{{1.765740, 0.012498, -0.013141},{1.763834, 0.011879, -0.012311},{
      1.764725, 0.010130, -0.012311},{1.766346, 0.011308, -0.013141}}],
    Polygon[{{1.763834, 0.011879, -0.012311},{1.762076, 0.011308, -0.011178},{
      1.763230, 0.009044, -0.011178},{1.764725, 0.010130, -0.012311}}],
    Polygon[{{1.762076, 0.011308, -0.011178},{1.760508, 0.010798, -0.009770},{
      1.761896, 0.008074, -0.009770},{1.763230, 0.009044, -0.011178}}],
    Polygon[{{1.760508, 0.010798, -0.009770},{1.759169, 0.010363, -0.008122},{
      1.760757, 0.007247, -0.008122},{1.761896, 0.008074, -0.009770}}],
    Polygon[{{1.759169, 0.010363, -0.008122},{1.758092, 0.010013, -0.006273},{
      1.759840, 0.006581, -0.006273},{1.760757, 0.007247, -0.008122}}],
    Polygon[{{1.758092, 0.010013, -0.006273},{1.757303, 0.009756, -0.004270},{
      1.759169, 0.006093, -0.004270},{1.759840, 0.006581, -0.006273}}],
    Polygon[{{1.757303, 0.009756, -0.004270},{1.756821, 0.009600, -0.002162},{
      1.758759, 0.005796, -0.002162},{1.759169, 0.006093, -0.004270}}],
    Polygon[{{1.756821, 0.009600, -0.002162},{1.756659, 0.009548, 0.000000},{
      1.758622, 0.005696, 0.000000},{1.758759, 0.005796, -0.002162}}],
    Polygon[{{1.756659, 0.009548, 0.000000},{1.756821, 0.009600, 0.002162},{
      1.758759, 0.005796, 0.002162},{1.758622, 0.005696, 0.000000}}],
    Polygon[{{1.756821, 0.009600, 0.002162},{1.757303, 0.009756, 0.004270},{
      1.759169, 0.006093, 0.004270},{1.758759, 0.005796, 0.002162}}],
    Polygon[{{1.757303, 0.009756, 0.004270},{1.758092, 0.010013, 0.006273},{
      1.759840, 0.006581, 0.006273},{1.759169, 0.006093, 0.004270}}],
    Polygon[{{1.758092, 0.010013, 0.006273},{1.759169, 0.010363, 0.008122},{
      1.760757, 0.007247, 0.008122},{1.759840, 0.006581, 0.006273}}],
    Polygon[{{1.759169, 0.010363, 0.008122},{1.760508, 0.010798, 0.009770},{
      1.761896, 0.008074, 0.009770},{1.760757, 0.007247, 0.008122}}],
    Polygon[{{1.760508, 0.010798, 0.009770},{1.762076, 0.011308, 0.011178},{
      1.763230, 0.009044, 0.011178},{1.761896, 0.008074, 0.009770}}],
    Polygon[{{1.762076, 0.011308, 0.011178},{1.763834, 0.011879, 0.012311},{
      1.764725, 0.010130, 0.012311},{1.763230, 0.009044, 0.011178}}],
    Polygon[{{1.763834, 0.011879, 0.012311},{1.765740, 0.012498, 0.013141},{
      1.766346, 0.011308, 0.013141},{1.764725, 0.010130, 0.012311}}],
    Polygon[{{1.765740, 0.012498, 0.013141},{1.767745, 0.013149, 0.013647},{
      1.768052, 0.012547, 0.013647},{1.766346, 0.011308, 0.013141}}],
    Polygon[{{1.768052, 0.012547, -0.013647},{1.766346, 0.011308, -0.013141},{
      1.767291, 0.010363, -0.013141},{1.768530, 0.012069, -0.013647}}],
    Polygon[{{1.766346, 0.011308, -0.013141},{1.764725, 0.010130, -0.012311},{
      1.766113, 0.008742, -0.012311},{1.767291, 0.010363, -0.013141}}],
    Polygon[{{1.764725, 0.010130, -0.012311},{1.763230, 0.009044, -0.011178},{
      1.765027, 0.007247, -0.011178},{1.766113, 0.008742, -0.012311}}],
    Polygon[{{1.763230, 0.009044, -0.011178},{1.761896, 0.008074, -0.009770},{
      1.764058, 0.005913, -0.009770},{1.765027, 0.007247, -0.011178}}],
    Polygon[{{1.761896, 0.008074, -0.009770},{1.760757, 0.007247, -0.008122},{
      1.763230, 0.004774, -0.008122},{1.764058, 0.005913, -0.009770}}],
    Polygon[{{1.760757, 0.007247, -0.008122},{1.759840, 0.006581, -0.006273},{
      1.762564, 0.003857, -0.006273},{1.763230, 0.004774, -0.008122}}],
    Polygon[{{1.759840, 0.006581, -0.006273},{1.759169, 0.006093, -0.004270},{
      1.762076, 0.003186, -0.004270},{1.762564, 0.003857, -0.006273}}],
    Polygon[{{1.759169, 0.006093, -0.004270},{1.758759, 0.005796, -0.002162},{
      1.761779, 0.002776, -0.002162},{1.762076, 0.003186, -0.004270}}],
    Polygon[{{1.758759, 0.005796, -0.002162},{1.758622, 0.005696, 0.000000},{
      1.761679, 0.002639, 0.000000},{1.761779, 0.002776, -0.002162}}],
    Polygon[{{1.758622, 0.005696, 0.000000},{1.758759, 0.005796, 0.002162},{
      1.761779, 0.002776, 0.002162},{1.761679, 0.002639, 0.000000}}],
    Polygon[{{1.758759, 0.005796, 0.002162},{1.759169, 0.006093, 0.004270},{
      1.762076, 0.003186, 0.004270},{1.761779, 0.002776, 0.002162}}],
    Polygon[{{1.759169, 0.006093, 0.004270},{1.759840, 0.006581, 0.006273},{
      1.762564, 0.003857, 0.006273},{1.762076, 0.003186, 0.004270}}],
    Polygon[{{1.759840, 0.006581, 0.006273},{1.760757, 0.007247, 0.008122},{
      1.763230, 0.004774, 0.008122},{1.762564, 0.003857, 0.006273}}],
    Polygon[{{1.760757, 0.007247, 0.008122},{1.761896, 0.008074, 0.009770},{
      1.764058, 0.005913, 0.009770},{1.763230, 0.004774, 0.008122}}],
    Polygon[{{1.761896, 0.008074, 0.009770},{1.763230, 0.009044, 0.011178},{
      1.765027, 0.007247, 0.011178},{1.764058, 0.005913, 0.009770}}],
    Polygon[{{1.763230, 0.009044, 0.011178},{1.764725, 0.010130, 0.012311},{
      1.766113, 0.008742, 0.012311},{1.765027, 0.007247, 0.011178}}],
    Polygon[{{1.764725, 0.010130, 0.012311},{1.766346, 0.011308, 0.013141},{
      1.767291, 0.010363, 0.013141},{1.766113, 0.008742, 0.012311}}],
    Polygon[{{1.766346, 0.011308, 0.013141},{1.768052, 0.012547, 0.013647},{
      1.768530, 0.012069, 0.013647},{1.767291, 0.010363, 0.013141}}],
    Polygon[{{1.768530, 0.012069, -0.013647},{1.767291, 0.010363, -0.013141},{
      1.768481, 0.009756, -0.013141},{1.769132, 0.011762, -0.013647}}],
    Polygon[{{1.767291, 0.010363, -0.013141},{1.766113, 0.008742, -0.012311},{
      1.767862, 0.007851, -0.012311},{1.768481, 0.009756, -0.013141}}],
    Polygon[{{1.766113, 0.008742, -0.012311},{1.765027, 0.007247, -0.011178},{
      1.767291, 0.006093, -0.011178},{1.767862, 0.007851, -0.012311}}],
    Polygon[{{1.765027, 0.007247, -0.011178},{1.764058, 0.005913, -0.009770},{
      1.766781, 0.004525, -0.009770},{1.767291, 0.006093, -0.011178}}],
    Polygon[{{1.764058, 0.005913, -0.009770},{1.763230, 0.004774, -0.008122},{
      1.766346, 0.003186, -0.008122},{1.766781, 0.004525, -0.009770}}],
    Polygon[{{1.763230, 0.004774, -0.008122},{1.762564, 0.003857, -0.006273},{
      1.765996, 0.002109, -0.006273},{1.766346, 0.003186, -0.008122}}],
    Polygon[{{1.762564, 0.003857, -0.006273},{1.762076, 0.003186, -0.004270},{
      1.765740, 0.001319, -0.004270},{1.765996, 0.002109, -0.006273}}],
    Polygon[{{1.762076, 0.003186, -0.004270},{1.761779, 0.002776, -0.002162},{
      1.765583, 0.000838, -0.002162},{1.765740, 0.001319, -0.004270}}],
    Polygon[{{1.761779, 0.002776, -0.002162},{1.761679, 0.002639, 0.000000},{
      1.765531, 0.000676, 0.000000},{1.765583, 0.000838, -0.002162}}],
    Polygon[{{1.761679, 0.002639, 0.000000},{1.761779, 0.002776, 0.002162},{
      1.765583, 0.000838, 0.002162},{1.765531, 0.000676, 0.000000}}],
    Polygon[{{1.761779, 0.002776, 0.002162},{1.762076, 0.003186, 0.004270},{
      1.765740, 0.001319, 0.004270},{1.765583, 0.000838, 0.002162}}],
    Polygon[{{1.762076, 0.003186, 0.004270},{1.762564, 0.003857, 0.006273},{
      1.765996, 0.002109, 0.006273},{1.765740, 0.001319, 0.004270}}],
    Polygon[{{1.762564, 0.003857, 0.006273},{1.763230, 0.004774, 0.008122},{
      1.766346, 0.003186, 0.008122},{1.765996, 0.002109, 0.006273}}],
    Polygon[{{1.763230, 0.004774, 0.008122},{1.764058, 0.005913, 0.009770},{
      1.766781, 0.004525, 0.009770},{1.766346, 0.003186, 0.008122}}],
    Polygon[{{1.764058, 0.005913, 0.009770},{1.765027, 0.007247, 0.011178},{
      1.767291, 0.006093, 0.011178},{1.766781, 0.004525, 0.009770}}],
    Polygon[{{1.765027, 0.007247, 0.011178},{1.766113, 0.008742, 0.012311},{
      1.767862, 0.007851, 0.012311},{1.767291, 0.006093, 0.011178}}],
    Polygon[{{1.766113, 0.008742, 0.012311},{1.767291, 0.010363, 0.013141},{
      1.768481, 0.009756, 0.013141},{1.767862, 0.007851, 0.012311}}],
    Polygon[{{1.767291, 0.010363, 0.013141},{1.768530, 0.012069, 0.013647},{
      1.769132, 0.011762, 0.013647},{1.768481, 0.009756, 0.013141}}],
    Polygon[{{1.769132, 0.011762, -0.013647},{1.768481, 0.009756, -0.013141},{
      1.769800, 0.009548, -0.013141},{1.769800, 0.011656, -0.013647}}],
    Polygon[{{1.768481, 0.009756, -0.013141},{1.767862, 0.007851, -0.012311},{
      1.769800, 0.007544, -0.012311},{1.769800, 0.009548, -0.013141}}],
    Polygon[{{1.767862, 0.007851, -0.012311},{1.767291, 0.006093, -0.011178},{
      1.769800, 0.005696, -0.011178},{1.769800, 0.007544, -0.012311}}],
    Polygon[{{1.767291, 0.006093, -0.011178},{1.766781, 0.004525, -0.009770},{
      1.769800, 0.004047, -0.009770},{1.769800, 0.005696, -0.011178}}],
    Polygon[{{1.766781, 0.004525, -0.009770},{1.766346, 0.003186, -0.008122},{
      1.769800, 0.002639, -0.008122},{1.769800, 0.004047, -0.009770}}],
    Polygon[{{1.766346, 0.003186, -0.008122},{1.765996, 0.002109, -0.006273},{
      1.769800, 0.001506, -0.006273},{1.769800, 0.002639, -0.008122}}],
    Polygon[{{1.765996, 0.002109, -0.006273},{1.765740, 0.001319, -0.004270},{
      1.769800, 0.000676, -0.004270},{1.769800, 0.001506, -0.006273}}],
    Polygon[{{1.765740, 0.001319, -0.004270},{1.765583, 0.000838, -0.002162},{
      1.769800, 0.000170, -0.002162},{1.769800, 0.000676, -0.004270}}],
    Polygon[{{1.765583, 0.000838, -0.002162},{1.765531, 0.000676, 0.000000},{
      1.769800, 0.000000, 0.000000},{1.769800, 0.000170, -0.002162}}],
    Polygon[{{1.765531, 0.000676, 0.000000},{1.765583, 0.000838, 0.002162},{
      1.769800, 0.000170, 0.002162},{1.769800, 0.000000, 0.000000}}],
    Polygon[{{1.765583, 0.000838, 0.002162},{1.765740, 0.001319, 0.004270},{
      1.769800, 0.000676, 0.004270},{1.769800, 0.000170, 0.002162}}],
    Polygon[{{1.765740, 0.001319, 0.004270},{1.765996, 0.002109, 0.006273},{
      1.769800, 0.001506, 0.006273},{1.769800, 0.000676, 0.004270}}],
    Polygon[{{1.765996, 0.002109, 0.006273},{1.766346, 0.003186, 0.008122},{
      1.769800, 0.002639, 0.008122},{1.769800, 0.001506, 0.006273}}],
    Polygon[{{1.766346, 0.003186, 0.008122},{1.766781, 0.004525, 0.009770},{
      1.769800, 0.004047, 0.009770},{1.769800, 0.002639, 0.008122}}],
    Polygon[{{1.766781, 0.004525, 0.009770},{1.767291, 0.006093, 0.011178},{
      1.769800, 0.005696, 0.011178},{1.769800, 0.004047, 0.009770}}],
    Polygon[{{1.767291, 0.006093, 0.011178},{1.767862, 0.007851, 0.012311},{
      1.769800, 0.007544, 0.012311},{1.769800, 0.005696, 0.011178}}],
    Polygon[{{1.767862, 0.007851, 0.012311},{1.768481, 0.009756, 0.013141},{
      1.769800, 0.009548, 0.013141},{1.769800, 0.007544, 0.012311}}],
    Polygon[{{1.768481, 0.009756, 0.013141},{1.769132, 0.011762, 0.013647},{
      1.769800, 0.011656, 0.013647},{1.769800, 0.009548, 0.013141}}],
    Polygon[{{1.769800, 0.011656, -0.013647},{1.769800, 0.009548, -0.013141},{
      1.771120, 0.009756, -0.013141},{1.770468, 0.011762, -0.013647}}],
    Polygon[{{1.769800, 0.009548, -0.013141},{1.769800, 0.007544, -0.012311},{
      1.771739, 0.007851, -0.012311},{1.771120, 0.009756, -0.013141}}],
    Polygon[{{1.769800, 0.007544, -0.012311},{1.769800, 0.005696, -0.011178},{
      1.772310, 0.006093, -0.011178},{1.771739, 0.007851, -0.012311}}],
    Polygon[{{1.769800, 0.005696, -0.011178},{1.769800, 0.004047, -0.009770},{
      1.772820, 0.004525, -0.009770},{1.772310, 0.006093, -0.011178}}],
    Polygon[{{1.769800, 0.004047, -0.009770},{1.769800, 0.002639, -0.008122},{
      1.773255, 0.003186, -0.008122},{1.772820, 0.004525, -0.009770}}],
    Polygon[{{1.769800, 0.002639, -0.008122},{1.769800, 0.001506, -0.006273},{
      1.773605, 0.002109, -0.006273},{1.773255, 0.003186, -0.008122}}],
    Polygon[{{1.769800, 0.001506, -0.006273},{1.769800, 0.000676, -0.004270},{
      1.773861, 0.001319, -0.004270},{1.773605, 0.002109, -0.006273}}],
    Polygon[{{1.769800, 0.000676, -0.004270},{1.769800, 0.000170, -0.002162},{
      1.774018, 0.000838, -0.002162},{1.773861, 0.001319, -0.004270}}],
    Polygon[{{1.769800, 0.000170, -0.002162},{1.769800, 0.000000, 0.000000},{
      1.774070, 0.000676, 0.000000},{1.774018, 0.000838, -0.002162}}],
    Polygon[{{1.769800, 0.000000, 0.000000},{1.769800, 0.000170, 0.002162},{
      1.774018, 0.000838, 0.002162},{1.774070, 0.000676, 0.000000}}],
    Polygon[{{1.769800, 0.000170, 0.002162},{1.769800, 0.000676, 0.004270},{
      1.773861, 0.001319, 0.004270},{1.774018, 0.000838, 0.002162}}],
    Polygon[{{1.769800, 0.000676, 0.004270},{1.769800, 0.001506, 0.006273},{
      1.773605, 0.002109, 0.006273},{1.773861, 0.001319, 0.004270}}],
    Polygon[{{1.769800, 0.001506, 0.006273},{1.769800, 0.002639, 0.008122},{
      1.773255, 0.003186, 0.008122},{1.773605, 0.002109, 0.006273}}],
    Polygon[{{1.769800, 0.002639, 0.008122},{1.769800, 0.004047, 0.009770},{
      1.772820, 0.004525, 0.009770},{1.773255, 0.003186, 0.008122}}],
    Polygon[{{1.769800, 0.004047, 0.009770},{1.769800, 0.005696, 0.011178},{
      1.772310, 0.006093, 0.011178},{1.772820, 0.004525, 0.009770}}],
    Polygon[{{1.769800, 0.005696, 0.011178},{1.769800, 0.007544, 0.012311},{
      1.771739, 0.007851, 0.012311},{1.772310, 0.006093, 0.011178}}],
    Polygon[{{1.769800, 0.007544, 0.012311},{1.769800, 0.009548, 0.013141},{
      1.771120, 0.009756, 0.013141},{1.771739, 0.007851, 0.012311}}],
    Polygon[{{1.769800, 0.009548, 0.013141},{1.769800, 0.011656, 0.013647},{
      1.770468, 0.011762, 0.013647},{1.771120, 0.009756, 0.013141}}],
    Polygon[{{1.770468, 0.011762, -0.013647},{1.771120, 0.009756, -0.013141},{
      1.772310, 0.010363, -0.013141},{1.771071, 0.012069, -0.013647}}],
    Polygon[{{1.771120, 0.009756, -0.013141},{1.771739, 0.007851, -0.012311},{
      1.773487, 0.008742, -0.012311},{1.772310, 0.010363, -0.013141}}],
    Polygon[{{1.771739, 0.007851, -0.012311},{1.772310, 0.006093, -0.011178},{
      1.774574, 0.007247, -0.011178},{1.773487, 0.008742, -0.012311}}],
    Polygon[{{1.772310, 0.006093, -0.011178},{1.772820, 0.004525, -0.009770},{
      1.775543, 0.005913, -0.009770},{1.774574, 0.007247, -0.011178}}],
    Polygon[{{1.772820, 0.004525, -0.009770},{1.773255, 0.003186, -0.008122},{
      1.776371, 0.004774, -0.008122},{1.775543, 0.005913, -0.009770}}],
    Polygon[{{1.773255, 0.003186, -0.008122},{1.773605, 0.002109, -0.006273},{
      1.777037, 0.003857, -0.006273},{1.776371, 0.004774, -0.008122}}],
    Polygon[{{1.773605, 0.002109, -0.006273},{1.773861, 0.001319, -0.004270},{
      1.777524, 0.003186, -0.004270},{1.777037, 0.003857, -0.006273}}],
    Polygon[{{1.773861, 0.001319, -0.004270},{1.774018, 0.000838, -0.002162},{
      1.777822, 0.002776, -0.002162},{1.777524, 0.003186, -0.004270}}],
    Polygon[{{1.774018, 0.000838, -0.002162},{1.774070, 0.000676, 0.000000},{
      1.777922, 0.002639, 0.000000},{1.777822, 0.002776, -0.002162}}],
    Polygon[{{1.774070, 0.000676, 0.000000},{1.774018, 0.000838, 0.002162},{
      1.777822, 0.002776, 0.002162},{1.777922, 0.002639, 0.000000}}],
    Polygon[{{1.774018, 0.000838, 0.002162},{1.773861, 0.001319, 0.004270},{
      1.777524, 0.003186, 0.004270},{1.777822, 0.002776, 0.002162}}],
    Polygon[{{1.773861, 0.001319, 0.004270},{1.773605, 0.002109, 0.006273},{
      1.777037, 0.003857, 0.006273},{1.777524, 0.003186, 0.004270}}],
    Polygon[{{1.773605, 0.002109, 0.006273},{1.773255, 0.003186, 0.008122},{
      1.776371, 0.004774, 0.008122},{1.777037, 0.003857, 0.006273}}],
    Polygon[{{1.773255, 0.003186, 0.008122},{1.772820, 0.004525, 0.009770},{
      1.775543, 0.005913, 0.009770},{1.776371, 0.004774, 0.008122}}],
    Polygon[{{1.772820, 0.004525, 0.009770},{1.772310, 0.006093, 0.011178},{
      1.774574, 0.007247, 0.011178},{1.775543, 0.005913, 0.009770}}],
    Polygon[{{1.772310, 0.006093, 0.011178},{1.771739, 0.007851, 0.012311},{
      1.773487, 0.008742, 0.012311},{1.774574, 0.007247, 0.011178}}],
    Polygon[{{1.771739, 0.007851, 0.012311},{1.771120, 0.009756, 0.013141},{
      1.772310, 0.010363, 0.013141},{1.773487, 0.008742, 0.012311}}],
    Polygon[{{1.771120, 0.009756, 0.013141},{1.770468, 0.011762, 0.013647},{
      1.771071, 0.012069, 0.013647},{1.772310, 0.010363, 0.013141}}],
    Polygon[{{1.771071, 0.012069, -0.013647},{1.772310, 0.010363, -0.013141},{
      1.773255, 0.011308, -0.013141},{1.771549, 0.012547, -0.013647}}],
    Polygon[{{1.772310, 0.010363, -0.013141},{1.773487, 0.008742, -0.012311},{
      1.774875, 0.010130, -0.012311},{1.773255, 0.011308, -0.013141}}],
    Polygon[{{1.773487, 0.008742, -0.012311},{1.774574, 0.007247, -0.011178},{
      1.776371, 0.009044, -0.011178},{1.774875, 0.010130, -0.012311}}],
    Polygon[{{1.774574, 0.007247, -0.011178},{1.775543, 0.005913, -0.009770},{
      1.777705, 0.008074, -0.009770},{1.776371, 0.009044, -0.011178}}],
    Polygon[{{1.775543, 0.005913, -0.009770},{1.776371, 0.004774, -0.008122},{
      1.778844, 0.007247, -0.008122},{1.777705, 0.008074, -0.009770}}],
    Polygon[{{1.776371, 0.004774, -0.008122},{1.777037, 0.003857, -0.006273},{
      1.779760, 0.006581, -0.006273},{1.778844, 0.007247, -0.008122}}],
    Polygon[{{1.777037, 0.003857, -0.006273},{1.777524, 0.003186, -0.004270},{
      1.780432, 0.006093, -0.004270},{1.779760, 0.006581, -0.006273}}],
    Polygon[{{1.777524, 0.003186, -0.004270},{1.777822, 0.002776, -0.002162},{
      1.780841, 0.005796, -0.002162},{1.780432, 0.006093, -0.004270}}],
    Polygon[{{1.777822, 0.002776, -0.002162},{1.777922, 0.002639, 0.000000},{
      1.780979, 0.005696, 0.000000},{1.780841, 0.005796, -0.002162}}],
    Polygon[{{1.777922, 0.002639, 0.000000},{1.777822, 0.002776, 0.002162},{
      1.780841, 0.005796, 0.002162},{1.780979, 0.005696, 0.000000}}],
    Polygon[{{1.777822, 0.002776, 0.002162},{1.777524, 0.003186, 0.004270},{
      1.780432, 0.006093, 0.004270},{1.780841, 0.005796, 0.002162}}],
    Polygon[{{1.777524, 0.003186, 0.004270},{1.777037, 0.003857, 0.006273},{
      1.779760, 0.006581, 0.006273},{1.780432, 0.006093, 0.004270}}],
    Polygon[{{1.777037, 0.003857, 0.006273},{1.776371, 0.004774, 0.008122},{
      1.778844, 0.007247, 0.008122},{1.779760, 0.006581, 0.006273}}],
    Polygon[{{1.776371, 0.004774, 0.008122},{1.775543, 0.005913, 0.009770},{
      1.777705, 0.008074, 0.009770},{1.778844, 0.007247, 0.008122}}],
    Polygon[{{1.775543, 0.005913, 0.009770},{1.774574, 0.007247, 0.011178},{
      1.776371, 0.009044, 0.011178},{1.777705, 0.008074, 0.009770}}],
    Polygon[{{1.774574, 0.007247, 0.011178},{1.773487, 0.008742, 0.012311},{
      1.774875, 0.010130, 0.012311},{1.776371, 0.009044, 0.011178}}],
    Polygon[{{1.773487, 0.008742, 0.012311},{1.772310, 0.010363, 0.013141},{
      1.773255, 0.011308, 0.013141},{1.774875, 0.010130, 0.012311}}],
    Polygon[{{1.772310, 0.010363, 0.013141},{1.771071, 0.012069, 0.013647},{
      1.771549, 0.012547, 0.013647},{1.773255, 0.011308, 0.013141}}],
    Polygon[{{1.771549, 0.012547, -0.013647},{1.773255, 0.011308, -0.013141},{
      1.773861, 0.012498, -0.013141},{1.771856, 0.013149, -0.013647}}],
    Polygon[{{1.773255, 0.011308, -0.013141},{1.774875, 0.010130, -0.012311},{
      1.775766, 0.011879, -0.012311},{1.773861, 0.012498, -0.013141}}],
    Polygon[{{1.774875, 0.010130, -0.012311},{1.776371, 0.009044, -0.011178},{
      1.777524, 0.011308, -0.011178},{1.775766, 0.011879, -0.012311}}],
    Polygon[{{1.776371, 0.009044, -0.011178},{1.777705, 0.008074, -0.009770},{
      1.779092, 0.010798, -0.009770},{1.777524, 0.011308, -0.011178}}],
    Polygon[{{1.777705, 0.008074, -0.009770},{1.778844, 0.007247, -0.008122},{
      1.780432, 0.010363, -0.008122},{1.779092, 0.010798, -0.009770}}],
    Polygon[{{1.778844, 0.007247, -0.008122},{1.779760, 0.006581, -0.006273},{
      1.781509, 0.010013, -0.006273},{1.780432, 0.010363, -0.008122}}],
    Polygon[{{1.779760, 0.006581, -0.006273},{1.780432, 0.006093, -0.004270},{
      1.782298, 0.009756, -0.004270},{1.781509, 0.010013, -0.006273}}],
    Polygon[{{1.780432, 0.006093, -0.004270},{1.780841, 0.005796, -0.002162},{
      1.782780, 0.009600, -0.002162},{1.782298, 0.009756, -0.004270}}],
    Polygon[{{1.780841, 0.005796, -0.002162},{1.780979, 0.005696, 0.000000},{
      1.782941, 0.009548, 0.000000},{1.782780, 0.009600, -0.002162}}],
    Polygon[{{1.780979, 0.005696, 0.000000},{1.780841, 0.005796, 0.002162},{
      1.782780, 0.009600, 0.002162},{1.782941, 0.009548, 0.000000}}],
    Polygon[{{1.780841, 0.005796, 0.002162},{1.780432, 0.006093, 0.004270},{
      1.782298, 0.009756, 0.004270},{1.782780, 0.009600, 0.002162}}],
    Polygon[{{1.780432, 0.006093, 0.004270},{1.779760, 0.006581, 0.006273},{
      1.781509, 0.010013, 0.006273},{1.782298, 0.009756, 0.004270}}],
    Polygon[{{1.779760, 0.006581, 0.006273},{1.778844, 0.007247, 0.008122},{
      1.780432, 0.010363, 0.008122},{1.781509, 0.010013, 0.006273}}],
    Polygon[{{1.778844, 0.007247, 0.008122},{1.777705, 0.008074, 0.009770},{
      1.779092, 0.010798, 0.009770},{1.780432, 0.010363, 0.008122}}],
    Polygon[{{1.777705, 0.008074, 0.009770},{1.776371, 0.009044, 0.011178},{
      1.777524, 0.011308, 0.011178},{1.779092, 0.010798, 0.009770}}],
    Polygon[{{1.776371, 0.009044, 0.011178},{1.774875, 0.010130, 0.012311},{
      1.775766, 0.011879, 0.012311},{1.777524, 0.011308, 0.011178}}],
    Polygon[{{1.774875, 0.010130, 0.012311},{1.773255, 0.011308, 0.013141},{
      1.773861, 0.012498, 0.013141},{1.775766, 0.011879, 0.012311}}],
    Polygon[{{1.773255, 0.011308, 0.013141},{1.771549, 0.012547, 0.013647},{
      1.771856, 0.013149, 0.013647},{1.773861, 0.012498, 0.013141}}],
    Polygon[{{1.771856, 0.013149, -0.013647},{1.773861, 0.012498, -0.013141},{
      1.774070, 0.013817, -0.013141},{1.771962, 0.013817, -0.013647}}],
    Polygon[{{1.773861, 0.012498, -0.013141},{1.775766, 0.011879, -0.012311},{
      1.776073, 0.013817, -0.012311},{1.774070, 0.013817, -0.013141}}],
    Polygon[{{1.775766, 0.011879, -0.012311},{1.777524, 0.011308, -0.011178},{
      1.777922, 0.013817, -0.011178},{1.776073, 0.013817, -0.012311}}],
    Polygon[{{1.777524, 0.011308, -0.011178},{1.779092, 0.010798, -0.009770},{
      1.779571, 0.013817, -0.009770},{1.777922, 0.013817, -0.011178}}],
    Polygon[{{1.779092, 0.010798, -0.009770},{1.780432, 0.010363, -0.008122},{
      1.780979, 0.013817, -0.008122},{1.779571, 0.013817, -0.009770}}],
    Polygon[{{1.780432, 0.010363, -0.008122},{1.781509, 0.010013, -0.006273},{
      1.782112, 0.013817, -0.006273},{1.780979, 0.013817, -0.008122}}],
    Polygon[{{1.781509, 0.010013, -0.006273},{1.782298, 0.009756, -0.004270},{
      1.782941, 0.013817, -0.004270},{1.782112, 0.013817, -0.006273}}],
    Polygon[{{1.782298, 0.009756, -0.004270},{1.782780, 0.009600, -0.002162},{
      1.783448, 0.013817, -0.002162},{1.782941, 0.013817, -0.004270}}],
    Polygon[{{1.782780, 0.009600, -0.002162},{1.782941, 0.009548, 0.000000},{
      1.783618, 0.013817, 0.000000},{1.783448, 0.013817, -0.002162}}],
    Polygon[{{1.782941, 0.009548, 0.000000},{1.782780, 0.009600, 0.002162},{
      1.783448, 0.013817, 0.002162},{1.783618, 0.013817, 0.000000}}],
    Polygon[{{1.782780, 0.009600, 0.002162},{1.782298, 0.009756, 0.004270},{
      1.782941, 0.013817, 0.004270},{1.783448, 0.013817, 0.002162}}],
    Polygon[{{1.782298, 0.009756, 0.004270},{1.781509, 0.010013, 0.006273},{
      1.782112, 0.013817, 0.006273},{1.782941, 0.013817, 0.004270}}],
    Polygon[{{1.781509, 0.010013, 0.006273},{1.780432, 0.010363, 0.008122},{
      1.780979, 0.013817, 0.008122},{1.782112, 0.013817, 0.006273}}],
    Polygon[{{1.780432, 0.010363, 0.008122},{1.779092, 0.010798, 0.009770},{
      1.779571, 0.013817, 0.009770},{1.780979, 0.013817, 0.008122}}],
    Polygon[{{1.779092, 0.010798, 0.009770},{1.777524, 0.011308, 0.011178},{
      1.777922, 0.013817, 0.011178},{1.779571, 0.013817, 0.009770}}],
    Polygon[{{1.777524, 0.011308, 0.011178},{1.775766, 0.011879, 0.012311},{
      1.776073, 0.013817, 0.012311},{1.777922, 0.013817, 0.011178}}],
    Polygon[{{1.775766, 0.011879, 0.012311},{1.773861, 0.012498, 0.013141},{
      1.774070, 0.013817, 0.013141},{1.776073, 0.013817, 0.012311}}],
    Polygon[{{1.773861, 0.012498, 0.013141},{1.771856, 0.013149, 0.013647},{
      1.771962, 0.013817, 0.013647},{1.774070, 0.013817, 0.013141}}],
    Polygon[{{1.840620, 0.009657, -0.009538},{1.842093, 0.009657, -0.009185},{
      1.841947, 0.010579, -0.009185},{1.840546, 0.010124, -0.009538}}],
    Polygon[{{1.842093, 0.009657, -0.009185},{1.843493, 0.009657, -0.008605},{
      1.843279, 0.011012, -0.008605},{1.841947, 0.010579, -0.009185}}],
    Polygon[{{1.843493, 0.009657, -0.008605},{1.844785, 0.009657, -0.007813},{
      1.844508, 0.011411, -0.007813},{1.843279, 0.011012, -0.008605}}],
    Polygon[{{1.844785, 0.009657, -0.007813},{1.845938, 0.009657, -0.006829},{
      1.845603, 0.011767, -0.006829},{1.844508, 0.011411, -0.007813}}],
    Polygon[{{1.845938, 0.009657, -0.006829},{1.846922, 0.009657, -0.005676},{
      1.846539, 0.012071, -0.005676},{1.845603, 0.011767, -0.006829}}],
    Polygon[{{1.846922, 0.009657, -0.005676},{1.847714, 0.009657, -0.004384},{
      1.847293, 0.012316, -0.004384},{1.846539, 0.012071, -0.005676}}],
    Polygon[{{1.847714, 0.009657, -0.004384},{1.848294, 0.009657, -0.002984},{
      1.847844, 0.012495, -0.002984},{1.847293, 0.012316, -0.004384}}],
    Polygon[{{1.848294, 0.009657, -0.002984},{1.848647, 0.009657, -0.001511},{
      1.848181, 0.012605, -0.001511},{1.847844, 0.012495, -0.002984}}],
    Polygon[{{1.848647, 0.009657, -0.001511},{1.848766, 0.009657, 0.000000},{
      1.848294, 0.012641, 0.000000},{1.848181, 0.012605, -0.001511}}],
    Polygon[{{1.848766, 0.009657, 0.000000},{1.848647, 0.009657, 0.001511},{
      1.848181, 0.012605, 0.001511},{1.848294, 0.012641, 0.000000}}],
    Polygon[{{1.848647, 0.009657, 0.001511},{1.848294, 0.009657, 0.002984},{
      1.847844, 0.012495, 0.002984},{1.848181, 0.012605, 0.001511}}],
    Polygon[{{1.848294, 0.009657, 0.002984},{1.847714, 0.009657, 0.004384},{
      1.847293, 0.012316, 0.004384},{1.847844, 0.012495, 0.002984}}],
    Polygon[{{1.847714, 0.009657, 0.004384},{1.846922, 0.009657, 0.005676},{
      1.846539, 0.012071, 0.005676},{1.847293, 0.012316, 0.004384}}],
    Polygon[{{1.846922, 0.009657, 0.005676},{1.845938, 0.009657, 0.006829},{
      1.845603, 0.011767, 0.006829},{1.846539, 0.012071, 0.005676}}],
    Polygon[{{1.845938, 0.009657, 0.006829},{1.844785, 0.009657, 0.007813},{
      1.844508, 0.011411, 0.007813},{1.845603, 0.011767, 0.006829}}],
    Polygon[{{1.844785, 0.009657, 0.007813},{1.843493, 0.009657, 0.008605},{
      1.843279, 0.011012, 0.008605},{1.844508, 0.011411, 0.007813}}],
    Polygon[{{1.843493, 0.009657, 0.008605},{1.842093, 0.009657, 0.009185},{
      1.841947, 0.010579, 0.009185},{1.843279, 0.011012, 0.008605}}],
    Polygon[{{1.842093, 0.009657, 0.009185},{1.840620, 0.009657, 0.009538},{
      1.840546, 0.010124, 0.009538},{1.841947, 0.010579, 0.009185}}],
    Polygon[{{1.840546, 0.010124, -0.009538},{1.841947, 0.010579, -0.009185},{
      1.841523, 0.011411, -0.009185},{1.840331, 0.010545, -0.009538}}],
    Polygon[{{1.841947, 0.010579, -0.009185},{1.843279, 0.011012, -0.008605},{
      1.842656, 0.012234, -0.008605},{1.841523, 0.011411, -0.009185}}],
    Polygon[{{1.843279, 0.011012, -0.008605},{1.844508, 0.011411, -0.007813},{
      1.843701, 0.012994, -0.007813},{1.842656, 0.012234, -0.008605}}],
    Polygon[{{1.844508, 0.011411, -0.007813},{1.845603, 0.011767, -0.006829},{
      1.844634, 0.013671, -0.006829},{1.843701, 0.012994, -0.007813}}],
    Polygon[{{1.845603, 0.011767, -0.006829},{1.846539, 0.012071, -0.005676},{
      1.845430, 0.014249, -0.005676},{1.844634, 0.013671, -0.006829}}],
    Polygon[{{1.846539, 0.012071, -0.005676},{1.847293, 0.012316, -0.004384},{
      1.846070, 0.014715, -0.004384},{1.845430, 0.014249, -0.005676}}],
    Polygon[{{1.847293, 0.012316, -0.004384},{1.847844, 0.012495, -0.002984},{
      1.846539, 0.015056, -0.002984},{1.846070, 0.014715, -0.004384}}],
    Polygon[{{1.847844, 0.012495, -0.002984},{1.848181, 0.012605, -0.001511},{
      1.846826, 0.015264, -0.001511},{1.846539, 0.015056, -0.002984}}],
    Polygon[{{1.848181, 0.012605, -0.001511},{1.848294, 0.012641, 0.000000},{
      1.846922, 0.015334, 0.000000},{1.846826, 0.015264, -0.001511}}],
    Polygon[{{1.848294, 0.012641, 0.000000},{1.848181, 0.012605, 0.001511},{
      1.846826, 0.015264, 0.001511},{1.846922, 0.015334, 0.000000}}],
    Polygon[{{1.848181, 0.012605, 0.001511},{1.847844, 0.012495, 0.002984},{
      1.846539, 0.015056, 0.002984},{1.846826, 0.015264, 0.001511}}],
    Polygon[{{1.847844, 0.012495, 0.002984},{1.847293, 0.012316, 0.004384},{
      1.846070, 0.014715, 0.004384},{1.846539, 0.015056, 0.002984}}],
    Polygon[{{1.847293, 0.012316, 0.004384},{1.846539, 0.012071, 0.005676},{
      1.845430, 0.014249, 0.005676},{1.846070, 0.014715, 0.004384}}],
    Polygon[{{1.846539, 0.012071, 0.005676},{1.845603, 0.011767, 0.006829},{
      1.844634, 0.013671, 0.006829},{1.845430, 0.014249, 0.005676}}],
    Polygon[{{1.845603, 0.011767, 0.006829},{1.844508, 0.011411, 0.007813},{
      1.843701, 0.012994, 0.007813},{1.844634, 0.013671, 0.006829}}],
    Polygon[{{1.844508, 0.011411, 0.007813},{1.843279, 0.011012, 0.008605},{
      1.842656, 0.012234, 0.008605},{1.843701, 0.012994, 0.007813}}],
    Polygon[{{1.843279, 0.011012, 0.008605},{1.841947, 0.010579, 0.009185},{
      1.841523, 0.011411, 0.009185},{1.842656, 0.012234, 0.008605}}],
    Polygon[{{1.841947, 0.010579, 0.009185},{1.840546, 0.010124, 0.009538},{
      1.840331, 0.010545, 0.009538},{1.841523, 0.011411, 0.009185}}],
    Polygon[{{1.840331, 0.010545, -0.009538},{1.841523, 0.011411, -0.009185},{
      1.840863, 0.012071, -0.009185},{1.839997, 0.010879, -0.009538}}],
    Polygon[{{1.841523, 0.011411, -0.009185},{1.842656, 0.012234, -0.008605},{
      1.841686, 0.013204, -0.008605},{1.840863, 0.012071, -0.009185}}],
    Polygon[{{1.842656, 0.012234, -0.008605},{1.843701, 0.012994, -0.007813},{
      1.842445, 0.014249, -0.007813},{1.841686, 0.013204, -0.008605}}],
    Polygon[{{1.843701, 0.012994, -0.007813},{1.844634, 0.013671, -0.006829},{
      1.843123, 0.015182, -0.006829},{1.842445, 0.014249, -0.007813}}],
    Polygon[{{1.844634, 0.013671, -0.006829},{1.845430, 0.014249, -0.005676},{
      1.843701, 0.015978, -0.005676},{1.843123, 0.015182, -0.006829}}],
    Polygon[{{1.845430, 0.014249, -0.005676},{1.846070, 0.014715, -0.004384},{
      1.844167, 0.016618, -0.004384},{1.843701, 0.015978, -0.005676}}],
    Polygon[{{1.846070, 0.014715, -0.004384},{1.846539, 0.015056, -0.002984},{
      1.844508, 0.017088, -0.002984},{1.844167, 0.016618, -0.004384}}],
    Polygon[{{1.846539, 0.015056, -0.002984},{1.846826, 0.015264, -0.001511},{
      1.844715, 0.017374, -0.001511},{1.844508, 0.017088, -0.002984}}],
    Polygon[{{1.846826, 0.015264, -0.001511},{1.846922, 0.015334, 0.000000},{
      1.844785, 0.017470, 0.000000},{1.844715, 0.017374, -0.001511}}],
    Polygon[{{1.846922, 0.015334, 0.000000},{1.846826, 0.015264, 0.001511},{
      1.844715, 0.017374, 0.001511},{1.844785, 0.017470, 0.000000}}],
    Polygon[{{1.846826, 0.015264, 0.001511},{1.846539, 0.015056, 0.002984},{
      1.844508, 0.017088, 0.002984},{1.844715, 0.017374, 0.001511}}],
    Polygon[{{1.846539, 0.015056, 0.002984},{1.846070, 0.014715, 0.004384},{
      1.844167, 0.016618, 0.004384},{1.844508, 0.017088, 0.002984}}],
    Polygon[{{1.846070, 0.014715, 0.004384},{1.845430, 0.014249, 0.005676},{
      1.843701, 0.015978, 0.005676},{1.844167, 0.016618, 0.004384}}],
    Polygon[{{1.845430, 0.014249, 0.005676},{1.844634, 0.013671, 0.006829},{
      1.843123, 0.015182, 0.006829},{1.843701, 0.015978, 0.005676}}],
    Polygon[{{1.844634, 0.013671, 0.006829},{1.843701, 0.012994, 0.007813},{
      1.842445, 0.014249, 0.007813},{1.843123, 0.015182, 0.006829}}],
    Polygon[{{1.843701, 0.012994, 0.007813},{1.842656, 0.012234, 0.008605},{
      1.841686, 0.013204, 0.008605},{1.842445, 0.014249, 0.007813}}],
    Polygon[{{1.842656, 0.012234, 0.008605},{1.841523, 0.011411, 0.009185},{
      1.840863, 0.012071, 0.009185},{1.841686, 0.013204, 0.008605}}],
    Polygon[{{1.841523, 0.011411, 0.009185},{1.840331, 0.010545, 0.009538},{
      1.839997, 0.010879, 0.009538},{1.840863, 0.012071, 0.009185}}],
    Polygon[{{1.839997, 0.010879, -0.009538},{1.840863, 0.012071, -0.009185},{
      1.840031, 0.012495, -0.009185},{1.839576, 0.011094, -0.009538}}],
    Polygon[{{1.840863, 0.012071, -0.009185},{1.841686, 0.013204, -0.008605},{
      1.840464, 0.013827, -0.008605},{1.840031, 0.012495, -0.009185}}],
    Polygon[{{1.841686, 0.013204, -0.008605},{1.842445, 0.014249, -0.007813},{
      1.840863, 0.015056, -0.007813},{1.840464, 0.013827, -0.008605}}],
    Polygon[{{1.842445, 0.014249, -0.007813},{1.843123, 0.015182, -0.006829},{
      1.841219, 0.016152, -0.006829},{1.840863, 0.015056, -0.007813}}],
    Polygon[{{1.843123, 0.015182, -0.006829},{1.843701, 0.015978, -0.005676},{
      1.841523, 0.017088, -0.005676},{1.841219, 0.016152, -0.006829}}],
    Polygon[{{1.843701, 0.015978, -0.005676},{1.844167, 0.016618, -0.004384},{
      1.841768, 0.017841, -0.004384},{1.841523, 0.017088, -0.005676}}],
    Polygon[{{1.844167, 0.016618, -0.004384},{1.844508, 0.017088, -0.002984},{
      1.841947, 0.018392, -0.002984},{1.841768, 0.017841, -0.004384}}],
    Polygon[{{1.844508, 0.017088, -0.002984},{1.844715, 0.017374, -0.001511},{
      1.842057, 0.018729, -0.001511},{1.841947, 0.018392, -0.002984}}],
    Polygon[{{1.844715, 0.017374, -0.001511},{1.844785, 0.017470, 0.000000},{
      1.842093, 0.018842, 0.000000},{1.842057, 0.018729, -0.001511}}],
    Polygon[{{1.844785, 0.017470, 0.000000},{1.844715, 0.017374, 0.001511},{
      1.842057, 0.018729, 0.001511},{1.842093, 0.018842, 0.000000}}],
    Polygon[{{1.844715, 0.017374, 0.001511},{1.844508, 0.017088, 0.002984},{
      1.841947, 0.018392, 0.002984},{1.842057, 0.018729, 0.001511}}],
    Polygon[{{1.844508, 0.017088, 0.002984},{1.844167, 0.016618, 0.004384},{
      1.841768, 0.017841, 0.004384},{1.841947, 0.018392, 0.002984}}],
    Polygon[{{1.844167, 0.016618, 0.004384},{1.843701, 0.015978, 0.005676},{
      1.841523, 0.017088, 0.005676},{1.841768, 0.017841, 0.004384}}],
    Polygon[{{1.843701, 0.015978, 0.005676},{1.843123, 0.015182, 0.006829},{
      1.841219, 0.016152, 0.006829},{1.841523, 0.017088, 0.005676}}],
    Polygon[{{1.843123, 0.015182, 0.006829},{1.842445, 0.014249, 0.007813},{
      1.840863, 0.015056, 0.007813},{1.841219, 0.016152, 0.006829}}],
    Polygon[{{1.842445, 0.014249, 0.007813},{1.841686, 0.013204, 0.008605},{
      1.840464, 0.013827, 0.008605},{1.840863, 0.015056, 0.007813}}],
    Polygon[{{1.841686, 0.013204, 0.008605},{1.840863, 0.012071, 0.009185},{
      1.840031, 0.012495, 0.009185},{1.840464, 0.013827, 0.008605}}],
    Polygon[{{1.840863, 0.012071, 0.009185},{1.839997, 0.010879, 0.009538},{
      1.839576, 0.011094, 0.009538},{1.840031, 0.012495, 0.009185}}],
    Polygon[{{1.839576, 0.011094, -0.009538},{1.840031, 0.012495, -0.009185},{
      1.839109, 0.012641, -0.009185},{1.839109, 0.011168, -0.009538}}],
    Polygon[{{1.840031, 0.012495, -0.009185},{1.840464, 0.013827, -0.008605},{
      1.839109, 0.014041, -0.008605},{1.839109, 0.012641, -0.009185}}],
    Polygon[{{1.840464, 0.013827, -0.008605},{1.840863, 0.015056, -0.007813},{
      1.839109, 0.015334, -0.007813},{1.839109, 0.014041, -0.008605}}],
    Polygon[{{1.840863, 0.015056, -0.007813},{1.841219, 0.016152, -0.006829},{
      1.839109, 0.016486, -0.006829},{1.839109, 0.015334, -0.007813}}],
    Polygon[{{1.841219, 0.016152, -0.006829},{1.841523, 0.017088, -0.005676},{
      1.839109, 0.017470, -0.005676},{1.839109, 0.016486, -0.006829}}],
    Polygon[{{1.841523, 0.017088, -0.005676},{1.841768, 0.017841, -0.004384},{
      1.839109, 0.018262, -0.004384},{1.839109, 0.017470, -0.005676}}],
    Polygon[{{1.841768, 0.017841, -0.004384},{1.841947, 0.018392, -0.002984},{
      1.839109, 0.018842, -0.002984},{1.839109, 0.018262, -0.004384}}],
    Polygon[{{1.841947, 0.018392, -0.002984},{1.842057, 0.018729, -0.001511},{
      1.839109, 0.019195, -0.001511},{1.839109, 0.018842, -0.002984}}],
    Polygon[{{1.842057, 0.018729, -0.001511},{1.842093, 0.018842, 0.000000},{
      1.839109, 0.019314, 0.000000},{1.839109, 0.019195, -0.001511}}],
    Polygon[{{1.842093, 0.018842, 0.000000},{1.842057, 0.018729, 0.001511},{
      1.839109, 0.019195, 0.001511},{1.839109, 0.019314, 0.000000}}],
    Polygon[{{1.842057, 0.018729, 0.001511},{1.841947, 0.018392, 0.002984},{
      1.839109, 0.018842, 0.002984},{1.839109, 0.019195, 0.001511}}],
    Polygon[{{1.841947, 0.018392, 0.002984},{1.841768, 0.017841, 0.004384},{
      1.839109, 0.018262, 0.004384},{1.839109, 0.018842, 0.002984}}],
    Polygon[{{1.841768, 0.017841, 0.004384},{1.841523, 0.017088, 0.005676},{
      1.839109, 0.017470, 0.005676},{1.839109, 0.018262, 0.004384}}],
    Polygon[{{1.841523, 0.017088, 0.005676},{1.841219, 0.016152, 0.006829},{
      1.839109, 0.016486, 0.006829},{1.839109, 0.017470, 0.005676}}],
    Polygon[{{1.841219, 0.016152, 0.006829},{1.840863, 0.015056, 0.007813},{
      1.839109, 0.015334, 0.007813},{1.839109, 0.016486, 0.006829}}],
    Polygon[{{1.840863, 0.015056, 0.007813},{1.840464, 0.013827, 0.008605},{
      1.839109, 0.014041, 0.008605},{1.839109, 0.015334, 0.007813}}],
    Polygon[{{1.840464, 0.013827, 0.008605},{1.840031, 0.012495, 0.009185},{
      1.839109, 0.012641, 0.009185},{1.839109, 0.014041, 0.008605}}],
    Polygon[{{1.840031, 0.012495, 0.009185},{1.839576, 0.011094, 0.009538},{
      1.839109, 0.011168, 0.009538},{1.839109, 0.012641, 0.009185}}],
    Polygon[{{1.839109, 0.011168, -0.009538},{1.839109, 0.012641, -0.009185},{
      1.838187, 0.012495, -0.009185},{1.838642, 0.011094, -0.009538}}],
    Polygon[{{1.839109, 0.012641, -0.009185},{1.839109, 0.014041, -0.008605},{
      1.837754, 0.013827, -0.008605},{1.838187, 0.012495, -0.009185}}],
    Polygon[{{1.839109, 0.014041, -0.008605},{1.839109, 0.015334, -0.007813},{
      1.837355, 0.015056, -0.007813},{1.837754, 0.013827, -0.008605}}],
    Polygon[{{1.839109, 0.015334, -0.007813},{1.839109, 0.016486, -0.006829},{
      1.836999, 0.016152, -0.006829},{1.837355, 0.015056, -0.007813}}],
    Polygon[{{1.839109, 0.016486, -0.006829},{1.839109, 0.017470, -0.005676},{
      1.836695, 0.017088, -0.005676},{1.836999, 0.016152, -0.006829}}],
    Polygon[{{1.839109, 0.017470, -0.005676},{1.839109, 0.018262, -0.004384},{
      1.836450, 0.017841, -0.004384},{1.836695, 0.017088, -0.005676}}],
    Polygon[{{1.839109, 0.018262, -0.004384},{1.839109, 0.018842, -0.002984},{
      1.836271, 0.018392, -0.002984},{1.836450, 0.017841, -0.004384}}],
    Polygon[{{1.839109, 0.018842, -0.002984},{1.839109, 0.019195, -0.001511},{
      1.836162, 0.018729, -0.001511},{1.836271, 0.018392, -0.002984}}],
    Polygon[{{1.839109, 0.019195, -0.001511},{1.839109, 0.019314, 0.000000},{
      1.836125, 0.018842, 0.000000},{1.836162, 0.018729, -0.001511}}],
    Polygon[{{1.839109, 0.019314, 0.000000},{1.839109, 0.019195, 0.001511},{
      1.836162, 0.018729, 0.001511},{1.836125, 0.018842, 0.000000}}],
    Polygon[{{1.839109, 0.019195, 0.001511},{1.839109, 0.018842, 0.002984},{
      1.836271, 0.018392, 0.002984},{1.836162, 0.018729, 0.001511}}],
    Polygon[{{1.839109, 0.018842, 0.002984},{1.839109, 0.018262, 0.004384},{
      1.836450, 0.017841, 0.004384},{1.836271, 0.018392, 0.002984}}],
    Polygon[{{1.839109, 0.018262, 0.004384},{1.839109, 0.017470, 0.005676},{
      1.836695, 0.017088, 0.005676},{1.836450, 0.017841, 0.004384}}],
    Polygon[{{1.839109, 0.017470, 0.005676},{1.839109, 0.016486, 0.006829},{
      1.836999, 0.016152, 0.006829},{1.836695, 0.017088, 0.005676}}],
    Polygon[{{1.839109, 0.016486, 0.006829},{1.839109, 0.015334, 0.007813},{
      1.837355, 0.015056, 0.007813},{1.836999, 0.016152, 0.006829}}],
    Polygon[{{1.839109, 0.015334, 0.007813},{1.839109, 0.014041, 0.008605},{
      1.837754, 0.013827, 0.008605},{1.837355, 0.015056, 0.007813}}],
    Polygon[{{1.839109, 0.014041, 0.008605},{1.839109, 0.012641, 0.009185},{
      1.838187, 0.012495, 0.009185},{1.837754, 0.013827, 0.008605}}],
    Polygon[{{1.839109, 0.012641, 0.009185},{1.839109, 0.011168, 0.009538},{
      1.838642, 0.011094, 0.009538},{1.838187, 0.012495, 0.009185}}],
    Polygon[{{1.838642, 0.011094, -0.009538},{1.838187, 0.012495, -0.009185},{
      1.837355, 0.012071, -0.009185},{1.838221, 0.010879, -0.009538}}],
    Polygon[{{1.838187, 0.012495, -0.009185},{1.837754, 0.013827, -0.008605},{
      1.836532, 0.013204, -0.008605},{1.837355, 0.012071, -0.009185}}],
    Polygon[{{1.837754, 0.013827, -0.008605},{1.837355, 0.015056, -0.007813},{
      1.835773, 0.014249, -0.007813},{1.836532, 0.013204, -0.008605}}],
    Polygon[{{1.837355, 0.015056, -0.007813},{1.836999, 0.016152, -0.006829},{
      1.835095, 0.015182, -0.006829},{1.835773, 0.014249, -0.007813}}],
    Polygon[{{1.836999, 0.016152, -0.006829},{1.836695, 0.017088, -0.005676},{
      1.834517, 0.015978, -0.005676},{1.835095, 0.015182, -0.006829}}],
    Polygon[{{1.836695, 0.017088, -0.005676},{1.836450, 0.017841, -0.004384},{
      1.834051, 0.016618, -0.004384},{1.834517, 0.015978, -0.005676}}],
    Polygon[{{1.836450, 0.017841, -0.004384},{1.836271, 0.018392, -0.002984},{
      1.833711, 0.017088, -0.002984},{1.834051, 0.016618, -0.004384}}],
    Polygon[{{1.836271, 0.018392, -0.002984},{1.836162, 0.018729, -0.001511},{
      1.833503, 0.017374, -0.001511},{1.833711, 0.017088, -0.002984}}],
    Polygon[{{1.836162, 0.018729, -0.001511},{1.836125, 0.018842, 0.000000},{
      1.833433, 0.017470, 0.000000},{1.833503, 0.017374, -0.001511}}],
    Polygon[{{1.836125, 0.018842, 0.000000},{1.836162, 0.018729, 0.001511},{
      1.833503, 0.017374, 0.001511},{1.833433, 0.017470, 0.000000}}],
    Polygon[{{1.836162, 0.018729, 0.001511},{1.836271, 0.018392, 0.002984},{
      1.833711, 0.017088, 0.002984},{1.833503, 0.017374, 0.001511}}],
    Polygon[{{1.836271, 0.018392, 0.002984},{1.836450, 0.017841, 0.004384},{
      1.834051, 0.016618, 0.004384},{1.833711, 0.017088, 0.002984}}],
    Polygon[{{1.836450, 0.017841, 0.004384},{1.836695, 0.017088, 0.005676},{
      1.834517, 0.015978, 0.005676},{1.834051, 0.016618, 0.004384}}],
    Polygon[{{1.836695, 0.017088, 0.005676},{1.836999, 0.016152, 0.006829},{
      1.835095, 0.015182, 0.006829},{1.834517, 0.015978, 0.005676}}],
    Polygon[{{1.836999, 0.016152, 0.006829},{1.837355, 0.015056, 0.007813},{
      1.835773, 0.014249, 0.007813},{1.835095, 0.015182, 0.006829}}],
    Polygon[{{1.837355, 0.015056, 0.007813},{1.837754, 0.013827, 0.008605},{
      1.836532, 0.013204, 0.008605},{1.835773, 0.014249, 0.007813}}],
    Polygon[{{1.837754, 0.013827, 0.008605},{1.838187, 0.012495, 0.009185},{
      1.837355, 0.012071, 0.009185},{1.836532, 0.013204, 0.008605}}],
    Polygon[{{1.838187, 0.012495, 0.009185},{1.838642, 0.011094, 0.009538},{
      1.838221, 0.010879, 0.009538},{1.837355, 0.012071, 0.009185}}],
    Polygon[{{1.838221, 0.010879, -0.009538},{1.837355, 0.012071, -0.009185},{
      1.836695, 0.011411, -0.009185},{1.837887, 0.010545, -0.009538}}],
    Polygon[{{1.837355, 0.012071, -0.009185},{1.836532, 0.013204, -0.008605},{
      1.835562, 0.012234, -0.008605},{1.836695, 0.011411, -0.009185}}],
    Polygon[{{1.836532, 0.013204, -0.008605},{1.835773, 0.014249, -0.007813},{
      1.834517, 0.012994, -0.007813},{1.835562, 0.012234, -0.008605}}],
    Polygon[{{1.835773, 0.014249, -0.007813},{1.835095, 0.015182, -0.006829},{
      1.833585, 0.013671, -0.006829},{1.834517, 0.012994, -0.007813}}],
    Polygon[{{1.835095, 0.015182, -0.006829},{1.834517, 0.015978, -0.005676},{
      1.832788, 0.014249, -0.005676},{1.833585, 0.013671, -0.006829}}],
    Polygon[{{1.834517, 0.015978, -0.005676},{1.834051, 0.016618, -0.004384},{
      1.832148, 0.014715, -0.004384},{1.832788, 0.014249, -0.005676}}],
    Polygon[{{1.834051, 0.016618, -0.004384},{1.833711, 0.017088, -0.002984},{
      1.831679, 0.015056, -0.002984},{1.832148, 0.014715, -0.004384}}],
    Polygon[{{1.833711, 0.017088, -0.002984},{1.833503, 0.017374, -0.001511},{
      1.831392, 0.015264, -0.001511},{1.831679, 0.015056, -0.002984}}],
    Polygon[{{1.833503, 0.017374, -0.001511},{1.833433, 0.017470, 0.000000},{
      1.831296, 0.015334, 0.000000},{1.831392, 0.015264, -0.001511}}],
    Polygon[{{1.833433, 0.017470, 0.000000},{1.833503, 0.017374, 0.001511},{
      1.831392, 0.015264, 0.001511},{1.831296, 0.015334, 0.000000}}],
    Polygon[{{1.833503, 0.017374, 0.001511},{1.833711, 0.017088, 0.002984},{
      1.831679, 0.015056, 0.002984},{1.831392, 0.015264, 0.001511}}],
    Polygon[{{1.833711, 0.017088, 0.002984},{1.834051, 0.016618, 0.004384},{
      1.832148, 0.014715, 0.004384},{1.831679, 0.015056, 0.002984}}],
    Polygon[{{1.834051, 0.016618, 0.004384},{1.834517, 0.015978, 0.005676},{
      1.832788, 0.014249, 0.005676},{1.832148, 0.014715, 0.004384}}],
    Polygon[{{1.834517, 0.015978, 0.005676},{1.835095, 0.015182, 0.006829},{
      1.833585, 0.013671, 0.006829},{1.832788, 0.014249, 0.005676}}],
    Polygon[{{1.835095, 0.015182, 0.006829},{1.835773, 0.014249, 0.007813},{
      1.834517, 0.012994, 0.007813},{1.833585, 0.013671, 0.006829}}],
    Polygon[{{1.835773, 0.014249, 0.007813},{1.836532, 0.013204, 0.008605},{
      1.835562, 0.012234, 0.008605},{1.834517, 0.012994, 0.007813}}],
    Polygon[{{1.836532, 0.013204, 0.008605},{1.837355, 0.012071, 0.009185},{
      1.836695, 0.011411, 0.009185},{1.835562, 0.012234, 0.008605}}],
    Polygon[{{1.837355, 0.012071, 0.009185},{1.838221, 0.010879, 0.009538},{
      1.837887, 0.010545, 0.009538},{1.836695, 0.011411, 0.009185}}],
    Polygon[{{1.837887, 0.010545, -0.009538},{1.836695, 0.011411, -0.009185},{
      1.836271, 0.010579, -0.009185},{1.837672, 0.010124, -0.009538}}],
    Polygon[{{1.836695, 0.011411, -0.009185},{1.835562, 0.012234, -0.008605},{
      1.834939, 0.011012, -0.008605},{1.836271, 0.010579, -0.009185}}],
    Polygon[{{1.835562, 0.012234, -0.008605},{1.834517, 0.012994, -0.007813},{
      1.833711, 0.011411, -0.007813},{1.834939, 0.011012, -0.008605}}],
    Polygon[{{1.834517, 0.012994, -0.007813},{1.833585, 0.013671, -0.006829},{
      1.832615, 0.011767, -0.006829},{1.833711, 0.011411, -0.007813}}],
    Polygon[{{1.833585, 0.013671, -0.006829},{1.832788, 0.014249, -0.005676},{
      1.831679, 0.012071, -0.005676},{1.832615, 0.011767, -0.006829}}],
    Polygon[{{1.832788, 0.014249, -0.005676},{1.832148, 0.014715, -0.004384},{
      1.830926, 0.012316, -0.004384},{1.831679, 0.012071, -0.005676}}],
    Polygon[{{1.832148, 0.014715, -0.004384},{1.831679, 0.015056, -0.002984},{
      1.830374, 0.012495, -0.002984},{1.830926, 0.012316, -0.004384}}],
    Polygon[{{1.831679, 0.015056, -0.002984},{1.831392, 0.015264, -0.001511},{
      1.830038, 0.012605, -0.001511},{1.830374, 0.012495, -0.002984}}],
    Polygon[{{1.831392, 0.015264, -0.001511},{1.831296, 0.015334, 0.000000},{
      1.829925, 0.012641, 0.000000},{1.830038, 0.012605, -0.001511}}],
    Polygon[{{1.831296, 0.015334, 0.000000},{1.831392, 0.015264, 0.001511},{
      1.830038, 0.012605, 0.001511},{1.829925, 0.012641, 0.000000}}],
    Polygon[{{1.831392, 0.015264, 0.001511},{1.831679, 0.015056, 0.002984},{
      1.830374, 0.012495, 0.002984},{1.830038, 0.012605, 0.001511}}],
    Polygon[{{1.831679, 0.015056, 0.002984},{1.832148, 0.014715, 0.004384},{
      1.830926, 0.012316, 0.004384},{1.830374, 0.012495, 0.002984}}],
    Polygon[{{1.832148, 0.014715, 0.004384},{1.832788, 0.014249, 0.005676},{
      1.831679, 0.012071, 0.005676},{1.830926, 0.012316, 0.004384}}],
    Polygon[{{1.832788, 0.014249, 0.005676},{1.833585, 0.013671, 0.006829},{
      1.832615, 0.011767, 0.006829},{1.831679, 0.012071, 0.005676}}],
    Polygon[{{1.833585, 0.013671, 0.006829},{1.834517, 0.012994, 0.007813},{
      1.833711, 0.011411, 0.007813},{1.832615, 0.011767, 0.006829}}],
    Polygon[{{1.834517, 0.012994, 0.007813},{1.835562, 0.012234, 0.008605},{
      1.834939, 0.011012, 0.008605},{1.833711, 0.011411, 0.007813}}],
    Polygon[{{1.835562, 0.012234, 0.008605},{1.836695, 0.011411, 0.009185},{
      1.836271, 0.010579, 0.009185},{1.834939, 0.011012, 0.008605}}],
    Polygon[{{1.836695, 0.011411, 0.009185},{1.837887, 0.010545, 0.009538},{
      1.837672, 0.010124, 0.009538},{1.836271, 0.010579, 0.009185}}],
    Polygon[{{1.837672, 0.010124, -0.009538},{1.836271, 0.010579, -0.009185},{
      1.836125, 0.009657, -0.009185},{1.837598, 0.009657, -0.009538}}],
    Polygon[{{1.836271, 0.010579, -0.009185},{1.834939, 0.011012, -0.008605},{
      1.834725, 0.009657, -0.008605},{1.836125, 0.009657, -0.009185}}],
    Polygon[{{1.834939, 0.011012, -0.008605},{1.833711, 0.011411, -0.007813},{
      1.833433, 0.009657, -0.007813},{1.834725, 0.009657, -0.008605}}],
    Polygon[{{1.833711, 0.011411, -0.007813},{1.832615, 0.011767, -0.006829},{
      1.832280, 0.009657, -0.006829},{1.833433, 0.009657, -0.007813}}],
    Polygon[{{1.832615, 0.011767, -0.006829},{1.831679, 0.012071, -0.005676},{
      1.831296, 0.009657, -0.005676},{1.832280, 0.009657, -0.006829}}],
    Polygon[{{1.831679, 0.012071, -0.005676},{1.830926, 0.012316, -0.004384},{
      1.830504, 0.009657, -0.004384},{1.831296, 0.009657, -0.005676}}],
    Polygon[{{1.830926, 0.012316, -0.004384},{1.830374, 0.012495, -0.002984},{
      1.829925, 0.009657, -0.002984},{1.830504, 0.009657, -0.004384}}],
    Polygon[{{1.830374, 0.012495, -0.002984},{1.830038, 0.012605, -0.001511},{
      1.829571, 0.009657, -0.001511},{1.829925, 0.009657, -0.002984}}],
    Polygon[{{1.830038, 0.012605, -0.001511},{1.829925, 0.012641, 0.000000},{
      1.829452, 0.009657, 0.000000},{1.829571, 0.009657, -0.001511}}],
    Polygon[{{1.829925, 0.012641, 0.000000},{1.830038, 0.012605, 0.001511},{
      1.829571, 0.009657, 0.001511},{1.829452, 0.009657, 0.000000}}],
    Polygon[{{1.830038, 0.012605, 0.001511},{1.830374, 0.012495, 0.002984},{
      1.829925, 0.009657, 0.002984},{1.829571, 0.009657, 0.001511}}],
    Polygon[{{1.830374, 0.012495, 0.002984},{1.830926, 0.012316, 0.004384},{
      1.830504, 0.009657, 0.004384},{1.829925, 0.009657, 0.002984}}],
    Polygon[{{1.830926, 0.012316, 0.004384},{1.831679, 0.012071, 0.005676},{
      1.831296, 0.009657, 0.005676},{1.830504, 0.009657, 0.004384}}],
    Polygon[{{1.831679, 0.012071, 0.005676},{1.832615, 0.011767, 0.006829},{
      1.832280, 0.009657, 0.006829},{1.831296, 0.009657, 0.005676}}],
    Polygon[{{1.832615, 0.011767, 0.006829},{1.833711, 0.011411, 0.007813},{
      1.833433, 0.009657, 0.007813},{1.832280, 0.009657, 0.006829}}],
    Polygon[{{1.833711, 0.011411, 0.007813},{1.834939, 0.011012, 0.008605},{
      1.834725, 0.009657, 0.008605},{1.833433, 0.009657, 0.007813}}],
    Polygon[{{1.834939, 0.011012, 0.008605},{1.836271, 0.010579, 0.009185},{
      1.836125, 0.009657, 0.009185},{1.834725, 0.009657, 0.008605}}],
    Polygon[{{1.836271, 0.010579, 0.009185},{1.837672, 0.010124, 0.009538},{
      1.837598, 0.009657, 0.009538},{1.836125, 0.009657, 0.009185}}],
    Polygon[{{1.837598, 0.009657, -0.009538},{1.836125, 0.009657, -0.009185},{
      1.836271, 0.008735, -0.009185},{1.837672, 0.009190, -0.009538}}],
    Polygon[{{1.836125, 0.009657, -0.009185},{1.834725, 0.009657, -0.008605},{
      1.834939, 0.008302, -0.008605},{1.836271, 0.008735, -0.009185}}],
    Polygon[{{1.834725, 0.009657, -0.008605},{1.833433, 0.009657, -0.007813},{
      1.833711, 0.007903, -0.007813},{1.834939, 0.008302, -0.008605}}],
    Polygon[{{1.833433, 0.009657, -0.007813},{1.832280, 0.009657, -0.006829},{
      1.832615, 0.007547, -0.006829},{1.833711, 0.007903, -0.007813}}],
    Polygon[{{1.832280, 0.009657, -0.006829},{1.831296, 0.009657, -0.005676},{
      1.831679, 0.007243, -0.005676},{1.832615, 0.007547, -0.006829}}],
    Polygon[{{1.831296, 0.009657, -0.005676},{1.830504, 0.009657, -0.004384},{
      1.830926, 0.006998, -0.004384},{1.831679, 0.007243, -0.005676}}],
    Polygon[{{1.830504, 0.009657, -0.004384},{1.829925, 0.009657, -0.002984},{
      1.830374, 0.006819, -0.002984},{1.830926, 0.006998, -0.004384}}],
    Polygon[{{1.829925, 0.009657, -0.002984},{1.829571, 0.009657, -0.001511},{
      1.830038, 0.006710, -0.001511},{1.830374, 0.006819, -0.002984}}],
    Polygon[{{1.829571, 0.009657, -0.001511},{1.829452, 0.009657, 0.000000},{
      1.829925, 0.006673, 0.000000},{1.830038, 0.006710, -0.001511}}],
    Polygon[{{1.829452, 0.009657, 0.000000},{1.829571, 0.009657, 0.001511},{
      1.830038, 0.006710, 0.001511},{1.829925, 0.006673, 0.000000}}],
    Polygon[{{1.829571, 0.009657, 0.001511},{1.829925, 0.009657, 0.002984},{
      1.830374, 0.006819, 0.002984},{1.830038, 0.006710, 0.001511}}],
    Polygon[{{1.829925, 0.009657, 0.002984},{1.830504, 0.009657, 0.004384},{
      1.830926, 0.006998, 0.004384},{1.830374, 0.006819, 0.002984}}],
    Polygon[{{1.830504, 0.009657, 0.004384},{1.831296, 0.009657, 0.005676},{
      1.831679, 0.007243, 0.005676},{1.830926, 0.006998, 0.004384}}],
    Polygon[{{1.831296, 0.009657, 0.005676},{1.832280, 0.009657, 0.006829},{
      1.832615, 0.007547, 0.006829},{1.831679, 0.007243, 0.005676}}],
    Polygon[{{1.832280, 0.009657, 0.006829},{1.833433, 0.009657, 0.007813},{
      1.833711, 0.007903, 0.007813},{1.832615, 0.007547, 0.006829}}],
    Polygon[{{1.833433, 0.009657, 0.007813},{1.834725, 0.009657, 0.008605},{
      1.834939, 0.008302, 0.008605},{1.833711, 0.007903, 0.007813}}],
    Polygon[{{1.834725, 0.009657, 0.008605},{1.836125, 0.009657, 0.009185},{
      1.836271, 0.008735, 0.009185},{1.834939, 0.008302, 0.008605}}],
    Polygon[{{1.836125, 0.009657, 0.009185},{1.837598, 0.009657, 0.009538},{
      1.837672, 0.009190, 0.009538},{1.836271, 0.008735, 0.009185}}],
    Polygon[{{1.837672, 0.009190, -0.009538},{1.836271, 0.008735, -0.009185},{
      1.836695, 0.007903, -0.009185},{1.837887, 0.008769, -0.009538}}],
    Polygon[{{1.836271, 0.008735, -0.009185},{1.834939, 0.008302, -0.008605},{
      1.835562, 0.007080, -0.008605},{1.836695, 0.007903, -0.009185}}],
    Polygon[{{1.834939, 0.008302, -0.008605},{1.833711, 0.007903, -0.007813},{
      1.834517, 0.006321, -0.007813},{1.835562, 0.007080, -0.008605}}],
    Polygon[{{1.833711, 0.007903, -0.007813},{1.832615, 0.007547, -0.006829},{
      1.833585, 0.005643, -0.006829},{1.834517, 0.006321, -0.007813}}],
    Polygon[{{1.832615, 0.007547, -0.006829},{1.831679, 0.007243, -0.005676},{
      1.832788, 0.005065, -0.005676},{1.833585, 0.005643, -0.006829}}],
    Polygon[{{1.831679, 0.007243, -0.005676},{1.830926, 0.006998, -0.004384},{
      1.832148, 0.004600, -0.004384},{1.832788, 0.005065, -0.005676}}],
    Polygon[{{1.830926, 0.006998, -0.004384},{1.830374, 0.006819, -0.002984},{
      1.831679, 0.004259, -0.002984},{1.832148, 0.004600, -0.004384}}],
    Polygon[{{1.830374, 0.006819, -0.002984},{1.830038, 0.006710, -0.001511},{
      1.831392, 0.004051, -0.001511},{1.831679, 0.004259, -0.002984}}],
    Polygon[{{1.830038, 0.006710, -0.001511},{1.829925, 0.006673, 0.000000},{
      1.831296, 0.003981, 0.000000},{1.831392, 0.004051, -0.001511}}],
    Polygon[{{1.829925, 0.006673, 0.000000},{1.830038, 0.006710, 0.001511},{
      1.831392, 0.004051, 0.001511},{1.831296, 0.003981, 0.000000}}],
    Polygon[{{1.830038, 0.006710, 0.001511},{1.830374, 0.006819, 0.002984},{
      1.831679, 0.004259, 0.002984},{1.831392, 0.004051, 0.001511}}],
    Polygon[{{1.830374, 0.006819, 0.002984},{1.830926, 0.006998, 0.004384},{
      1.832148, 0.004600, 0.004384},{1.831679, 0.004259, 0.002984}}],
    Polygon[{{1.830926, 0.006998, 0.004384},{1.831679, 0.007243, 0.005676},{
      1.832788, 0.005065, 0.005676},{1.832148, 0.004600, 0.004384}}],
    Polygon[{{1.831679, 0.007243, 0.005676},{1.832615, 0.007547, 0.006829},{
      1.833585, 0.005643, 0.006829},{1.832788, 0.005065, 0.005676}}],
    Polygon[{{1.832615, 0.007547, 0.006829},{1.833711, 0.007903, 0.007813},{
      1.834517, 0.006321, 0.007813},{1.833585, 0.005643, 0.006829}}],
    Polygon[{{1.833711, 0.007903, 0.007813},{1.834939, 0.008302, 0.008605},{
      1.835562, 0.007080, 0.008605},{1.834517, 0.006321, 0.007813}}],
    Polygon[{{1.834939, 0.008302, 0.008605},{1.836271, 0.008735, 0.009185},{
      1.836695, 0.007903, 0.009185},{1.835562, 0.007080, 0.008605}}],
    Polygon[{{1.836271, 0.008735, 0.009185},{1.837672, 0.009190, 0.009538},{
      1.837887, 0.008769, 0.009538},{1.836695, 0.007903, 0.009185}}],
    Polygon[{{1.837887, 0.008769, -0.009538},{1.836695, 0.007903, -0.009185},{
      1.837355, 0.007243, -0.009185},{1.838221, 0.008435, -0.009538}}],
    Polygon[{{1.836695, 0.007903, -0.009185},{1.835562, 0.007080, -0.008605},{
      1.836532, 0.006110, -0.008605},{1.837355, 0.007243, -0.009185}}],
    Polygon[{{1.835562, 0.007080, -0.008605},{1.834517, 0.006321, -0.007813},{
      1.835773, 0.005065, -0.007813},{1.836532, 0.006110, -0.008605}}],
    Polygon[{{1.834517, 0.006321, -0.007813},{1.833585, 0.005643, -0.006829},{
      1.835095, 0.004133, -0.006829},{1.835773, 0.005065, -0.007813}}],
    Polygon[{{1.833585, 0.005643, -0.006829},{1.832788, 0.005065, -0.005676},{
      1.834517, 0.003336, -0.005676},{1.835095, 0.004133, -0.006829}}],
    Polygon[{{1.832788, 0.005065, -0.005676},{1.832148, 0.004600, -0.004384},{
      1.834051, 0.002696, -0.004384},{1.834517, 0.003336, -0.005676}}],
    Polygon[{{1.832148, 0.004600, -0.004384},{1.831679, 0.004259, -0.002984},{
      1.833711, 0.002227, -0.002984},{1.834051, 0.002696, -0.004384}}],
    Polygon[{{1.831679, 0.004259, -0.002984},{1.831392, 0.004051, -0.001511},{
      1.833503, 0.001941, -0.001511},{1.833711, 0.002227, -0.002984}}],
    Polygon[{{1.831392, 0.004051, -0.001511},{1.831296, 0.003981, 0.000000},{
      1.833433, 0.001844, 0.000000},{1.833503, 0.001941, -0.001511}}],
    Polygon[{{1.831296, 0.003981, 0.000000},{1.831392, 0.004051, 0.001511},{
      1.833503, 0.001941, 0.001511},{1.833433, 0.001844, 0.000000}}],
    Polygon[{{1.831392, 0.004051, 0.001511},{1.831679, 0.004259, 0.002984},{
      1.833711, 0.002227, 0.002984},{1.833503, 0.001941, 0.001511}}],
    Polygon[{{1.831679, 0.004259, 0.002984},{1.832148, 0.004600, 0.004384},{
      1.834051, 0.002696, 0.004384},{1.833711, 0.002227, 0.002984}}],
    Polygon[{{1.832148, 0.004600, 0.004384},{1.832788, 0.005065, 0.005676},{
      1.834517, 0.003336, 0.005676},{1.834051, 0.002696, 0.004384}}],
    Polygon[{{1.832788, 0.005065, 0.005676},{1.833585, 0.005643, 0.006829},{
      1.835095, 0.004133, 0.006829},{1.834517, 0.003336, 0.005676}}],
    Polygon[{{1.833585, 0.005643, 0.006829},{1.834517, 0.006321, 0.007813},{
      1.835773, 0.005065, 0.007813},{1.835095, 0.004133, 0.006829}}],
    Polygon[{{1.834517, 0.006321, 0.007813},{1.835562, 0.007080, 0.008605},{
      1.836532, 0.006110, 0.008605},{1.835773, 0.005065, 0.007813}}],
    Polygon[{{1.835562, 0.007080, 0.008605},{1.836695, 0.007903, 0.009185},{
      1.837355, 0.007243, 0.009185},{1.836532, 0.006110, 0.008605}}],
    Polygon[{{1.836695, 0.007903, 0.009185},{1.837887, 0.008769, 0.009538},{
      1.838221, 0.008435, 0.009538},{1.837355, 0.007243, 0.009185}}],
    Polygon[{{1.838221, 0.008435, -0.009538},{1.837355, 0.007243, -0.009185},{
      1.838187, 0.006819, -0.009185},{1.838642, 0.008220, -0.009538}}],
    Polygon[{{1.837355, 0.007243, -0.009185},{1.836532, 0.006110, -0.008605},{
      1.837754, 0.005487, -0.008605},{1.838187, 0.006819, -0.009185}}],
    Polygon[{{1.836532, 0.006110, -0.008605},{1.835773, 0.005065, -0.007813},{
      1.837355, 0.004259, -0.007813},{1.837754, 0.005487, -0.008605}}],
    Polygon[{{1.835773, 0.005065, -0.007813},{1.835095, 0.004133, -0.006829},{
      1.836999, 0.003163, -0.006829},{1.837355, 0.004259, -0.007813}}],
    Polygon[{{1.835095, 0.004133, -0.006829},{1.834517, 0.003336, -0.005676},{
      1.836695, 0.002227, -0.005676},{1.836999, 0.003163, -0.006829}}],
    Polygon[{{1.834517, 0.003336, -0.005676},{1.834051, 0.002696, -0.004384},{
      1.836450, 0.001474, -0.004384},{1.836695, 0.002227, -0.005676}}],
    Polygon[{{1.834051, 0.002696, -0.004384},{1.833711, 0.002227, -0.002984},{
      1.836271, 0.000922, -0.002984},{1.836450, 0.001474, -0.004384}}],
    Polygon[{{1.833711, 0.002227, -0.002984},{1.833503, 0.001941, -0.001511},{
      1.836162, 0.000586, -0.001511},{1.836271, 0.000922, -0.002984}}],
    Polygon[{{1.833503, 0.001941, -0.001511},{1.833433, 0.001844, 0.000000},{
      1.836125, 0.000473, 0.000000},{1.836162, 0.000586, -0.001511}}],
    Polygon[{{1.833433, 0.001844, 0.000000},{1.833503, 0.001941, 0.001511},{
      1.836162, 0.000586, 0.001511},{1.836125, 0.000473, 0.000000}}],
    Polygon[{{1.833503, 0.001941, 0.001511},{1.833711, 0.002227, 0.002984},{
      1.836271, 0.000922, 0.002984},{1.836162, 0.000586, 0.001511}}],
    Polygon[{{1.833711, 0.002227, 0.002984},{1.834051, 0.002696, 0.004384},{
      1.836450, 0.001474, 0.004384},{1.836271, 0.000922, 0.002984}}],
    Polygon[{{1.834051, 0.002696, 0.004384},{1.834517, 0.003336, 0.005676},{
      1.836695, 0.002227, 0.005676},{1.836450, 0.001474, 0.004384}}],
    Polygon[{{1.834517, 0.003336, 0.005676},{1.835095, 0.004133, 0.006829},{
      1.836999, 0.003163, 0.006829},{1.836695, 0.002227, 0.005676}}],
    Polygon[{{1.835095, 0.004133, 0.006829},{1.835773, 0.005065, 0.007813},{
      1.837355, 0.004259, 0.007813},{1.836999, 0.003163, 0.006829}}],
    Polygon[{{1.835773, 0.005065, 0.007813},{1.836532, 0.006110, 0.008605},{
      1.837754, 0.005487, 0.008605},{1.837355, 0.004259, 0.007813}}],
    Polygon[{{1.836532, 0.006110, 0.008605},{1.837355, 0.007243, 0.009185},{
      1.838187, 0.006819, 0.009185},{1.837754, 0.005487, 0.008605}}],
    Polygon[{{1.837355, 0.007243, 0.009185},{1.838221, 0.008435, 0.009538},{
      1.838642, 0.008220, 0.009538},{1.838187, 0.006819, 0.009185}}],
    Polygon[{{1.838642, 0.008220, -0.009538},{1.838187, 0.006819, -0.009185},{
      1.839109, 0.006673, -0.009185},{1.839109, 0.008146, -0.009538}}],
    Polygon[{{1.838187, 0.006819, -0.009185},{1.837754, 0.005487, -0.008605},{
      1.839109, 0.005273, -0.008605},{1.839109, 0.006673, -0.009185}}],
    Polygon[{{1.837754, 0.005487, -0.008605},{1.837355, 0.004259, -0.007813},{
      1.839109, 0.003981, -0.007813},{1.839109, 0.005273, -0.008605}}],
    Polygon[{{1.837355, 0.004259, -0.007813},{1.836999, 0.003163, -0.006829},{
      1.839109, 0.002829, -0.006829},{1.839109, 0.003981, -0.007813}}],
    Polygon[{{1.836999, 0.003163, -0.006829},{1.836695, 0.002227, -0.005676},{
      1.839109, 0.001844, -0.005676},{1.839109, 0.002829, -0.006829}}],
    Polygon[{{1.836695, 0.002227, -0.005676},{1.836450, 0.001474, -0.004384},{
      1.839109, 0.001053, -0.004384},{1.839109, 0.001844, -0.005676}}],
    Polygon[{{1.836450, 0.001474, -0.004384},{1.836271, 0.000922, -0.002984},{
      1.839109, 0.000473, -0.002984},{1.839109, 0.001053, -0.004384}}],
    Polygon[{{1.836271, 0.000922, -0.002984},{1.836162, 0.000586, -0.001511},{
      1.839109, 0.000119, -0.001511},{1.839109, 0.000473, -0.002984}}],
    Polygon[{{1.836162, 0.000586, -0.001511},{1.836125, 0.000473, 0.000000},{
      1.839109, 0.000000, 0.000000},{1.839109, 0.000119, -0.001511}}],
    Polygon[{{1.836125, 0.000473, 0.000000},{1.836162, 0.000586, 0.001511},{
      1.839109, 0.000119, 0.001511},{1.839109, 0.000000, 0.000000}}],
    Polygon[{{1.836162, 0.000586, 0.001511},{1.836271, 0.000922, 0.002984},{
      1.839109, 0.000473, 0.002984},{1.839109, 0.000119, 0.001511}}],
    Polygon[{{1.836271, 0.000922, 0.002984},{1.836450, 0.001474, 0.004384},{
      1.839109, 0.001053, 0.004384},{1.839109, 0.000473, 0.002984}}],
    Polygon[{{1.836450, 0.001474, 0.004384},{1.836695, 0.002227, 0.005676},{
      1.839109, 0.001844, 0.005676},{1.839109, 0.001053, 0.004384}}],
    Polygon[{{1.836695, 0.002227, 0.005676},{1.836999, 0.003163, 0.006829},{
      1.839109, 0.002829, 0.006829},{1.839109, 0.001844, 0.005676}}],
    Polygon[{{1.836999, 0.003163, 0.006829},{1.837355, 0.004259, 0.007813},{
      1.839109, 0.003981, 0.007813},{1.839109, 0.002829, 0.006829}}],
    Polygon[{{1.837355, 0.004259, 0.007813},{1.837754, 0.005487, 0.008605},{
      1.839109, 0.005273, 0.008605},{1.839109, 0.003981, 0.007813}}],
    Polygon[{{1.837754, 0.005487, 0.008605},{1.838187, 0.006819, 0.009185},{
      1.839109, 0.006673, 0.009185},{1.839109, 0.005273, 0.008605}}],
    Polygon[{{1.838187, 0.006819, 0.009185},{1.838642, 0.008220, 0.009538},{
      1.839109, 0.008146, 0.009538},{1.839109, 0.006673, 0.009185}}],
    Polygon[{{1.839109, 0.008146, -0.009538},{1.839109, 0.006673, -0.009185},{
      1.840031, 0.006819, -0.009185},{1.839576, 0.008220, -0.009538}}],
    Polygon[{{1.839109, 0.006673, -0.009185},{1.839109, 0.005273, -0.008605},{
      1.840464, 0.005487, -0.008605},{1.840031, 0.006819, -0.009185}}],
    Polygon[{{1.839109, 0.005273, -0.008605},{1.839109, 0.003981, -0.007813},{
      1.840863, 0.004259, -0.007813},{1.840464, 0.005487, -0.008605}}],
    Polygon[{{1.839109, 0.003981, -0.007813},{1.839109, 0.002829, -0.006829},{
      1.841219, 0.003163, -0.006829},{1.840863, 0.004259, -0.007813}}],
    Polygon[{{1.839109, 0.002829, -0.006829},{1.839109, 0.001844, -0.005676},{
      1.841523, 0.002227, -0.005676},{1.841219, 0.003163, -0.006829}}],
    Polygon[{{1.839109, 0.001844, -0.005676},{1.839109, 0.001053, -0.004384},{
      1.841768, 0.001474, -0.004384},{1.841523, 0.002227, -0.005676}}],
    Polygon[{{1.839109, 0.001053, -0.004384},{1.839109, 0.000473, -0.002984},{
      1.841947, 0.000922, -0.002984},{1.841768, 0.001474, -0.004384}}],
    Polygon[{{1.839109, 0.000473, -0.002984},{1.839109, 0.000119, -0.001511},{
      1.842057, 0.000586, -0.001511},{1.841947, 0.000922, -0.002984}}],
    Polygon[{{1.839109, 0.000119, -0.001511},{1.839109, 0.000000, 0.000000},{
      1.842093, 0.000473, 0.000000},{1.842057, 0.000586, -0.001511}}],
    Polygon[{{1.839109, 0.000000, 0.000000},{1.839109, 0.000119, 0.001511},{
      1.842057, 0.000586, 0.001511},{1.842093, 0.000473, 0.000000}}],
    Polygon[{{1.839109, 0.000119, 0.001511},{1.839109, 0.000473, 0.002984},{
      1.841947, 0.000922, 0.002984},{1.842057, 0.000586, 0.001511}}],
    Polygon[{{1.839109, 0.000473, 0.002984},{1.839109, 0.001053, 0.004384},{
      1.841768, 0.001474, 0.004384},{1.841947, 0.000922, 0.002984}}],
    Polygon[{{1.839109, 0.001053, 0.004384},{1.839109, 0.001844, 0.005676},{
      1.841523, 0.002227, 0.005676},{1.841768, 0.001474, 0.004384}}],
    Polygon[{{1.839109, 0.001844, 0.005676},{1.839109, 0.002829, 0.006829},{
      1.841219, 0.003163, 0.006829},{1.841523, 0.002227, 0.005676}}],
    Polygon[{{1.839109, 0.002829, 0.006829},{1.839109, 0.003981, 0.007813},{
      1.840863, 0.004259, 0.007813},{1.841219, 0.003163, 0.006829}}],
    Polygon[{{1.839109, 0.003981, 0.007813},{1.839109, 0.005273, 0.008605},{
      1.840464, 0.005487, 0.008605},{1.840863, 0.004259, 0.007813}}],
    Polygon[{{1.839109, 0.005273, 0.008605},{1.839109, 0.006673, 0.009185},{
      1.840031, 0.006819, 0.009185},{1.840464, 0.005487, 0.008605}}],
    Polygon[{{1.839109, 0.006673, 0.009185},{1.839109, 0.008146, 0.009538},{
      1.839576, 0.008220, 0.009538},{1.840031, 0.006819, 0.009185}}],
    Polygon[{{1.839576, 0.008220, -0.009538},{1.840031, 0.006819, -0.009185},{
      1.840863, 0.007243, -0.009185},{1.839997, 0.008435, -0.009538}}],
    Polygon[{{1.840031, 0.006819, -0.009185},{1.840464, 0.005487, -0.008605},{
      1.841686, 0.006110, -0.008605},{1.840863, 0.007243, -0.009185}}],
    Polygon[{{1.840464, 0.005487, -0.008605},{1.840863, 0.004259, -0.007813},{
      1.842445, 0.005065, -0.007813},{1.841686, 0.006110, -0.008605}}],
    Polygon[{{1.840863, 0.004259, -0.007813},{1.841219, 0.003163, -0.006829},{
      1.843123, 0.004133, -0.006829},{1.842445, 0.005065, -0.007813}}],
    Polygon[{{1.841219, 0.003163, -0.006829},{1.841523, 0.002227, -0.005676},{
      1.843701, 0.003336, -0.005676},{1.843123, 0.004133, -0.006829}}],
    Polygon[{{1.841523, 0.002227, -0.005676},{1.841768, 0.001474, -0.004384},{
      1.844167, 0.002696, -0.004384},{1.843701, 0.003336, -0.005676}}],
    Polygon[{{1.841768, 0.001474, -0.004384},{1.841947, 0.000922, -0.002984},{
      1.844508, 0.002227, -0.002984},{1.844167, 0.002696, -0.004384}}],
    Polygon[{{1.841947, 0.000922, -0.002984},{1.842057, 0.000586, -0.001511},{
      1.844715, 0.001941, -0.001511},{1.844508, 0.002227, -0.002984}}],
    Polygon[{{1.842057, 0.000586, -0.001511},{1.842093, 0.000473, 0.000000},{
      1.844785, 0.001844, 0.000000},{1.844715, 0.001941, -0.001511}}],
    Polygon[{{1.842093, 0.000473, 0.000000},{1.842057, 0.000586, 0.001511},{
      1.844715, 0.001941, 0.001511},{1.844785, 0.001844, 0.000000}}],
    Polygon[{{1.842057, 0.000586, 0.001511},{1.841947, 0.000922, 0.002984},{
      1.844508, 0.002227, 0.002984},{1.844715, 0.001941, 0.001511}}],
    Polygon[{{1.841947, 0.000922, 0.002984},{1.841768, 0.001474, 0.004384},{
      1.844167, 0.002696, 0.004384},{1.844508, 0.002227, 0.002984}}],
    Polygon[{{1.841768, 0.001474, 0.004384},{1.841523, 0.002227, 0.005676},{
      1.843701, 0.003336, 0.005676},{1.844167, 0.002696, 0.004384}}],
    Polygon[{{1.841523, 0.002227, 0.005676},{1.841219, 0.003163, 0.006829},{
      1.843123, 0.004133, 0.006829},{1.843701, 0.003336, 0.005676}}],
    Polygon[{{1.841219, 0.003163, 0.006829},{1.840863, 0.004259, 0.007813},{
      1.842445, 0.005065, 0.007813},{1.843123, 0.004133, 0.006829}}],
    Polygon[{{1.840863, 0.004259, 0.007813},{1.840464, 0.005487, 0.008605},{
      1.841686, 0.006110, 0.008605},{1.842445, 0.005065, 0.007813}}],
    Polygon[{{1.840464, 0.005487, 0.008605},{1.840031, 0.006819, 0.009185},{
      1.840863, 0.007243, 0.009185},{1.841686, 0.006110, 0.008605}}],
    Polygon[{{1.840031, 0.006819, 0.009185},{1.839576, 0.008220, 0.009538},{
      1.839997, 0.008435, 0.009538},{1.840863, 0.007243, 0.009185}}],
    Polygon[{{1.839997, 0.008435, -0.009538},{1.840863, 0.007243, -0.009185},{
      1.841523, 0.007903, -0.009185},{1.840331, 0.008769, -0.009538}}],
    Polygon[{{1.840863, 0.007243, -0.009185},{1.841686, 0.006110, -0.008605},{
      1.842656, 0.007080, -0.008605},{1.841523, 0.007903, -0.009185}}],
    Polygon[{{1.841686, 0.006110, -0.008605},{1.842445, 0.005065, -0.007813},{
      1.843701, 0.006321, -0.007813},{1.842656, 0.007080, -0.008605}}],
    Polygon[{{1.842445, 0.005065, -0.007813},{1.843123, 0.004133, -0.006829},{
      1.844634, 0.005643, -0.006829},{1.843701, 0.006321, -0.007813}}],
    Polygon[{{1.843123, 0.004133, -0.006829},{1.843701, 0.003336, -0.005676},{
      1.845430, 0.005065, -0.005676},{1.844634, 0.005643, -0.006829}}],
    Polygon[{{1.843701, 0.003336, -0.005676},{1.844167, 0.002696, -0.004384},{
      1.846070, 0.004600, -0.004384},{1.845430, 0.005065, -0.005676}}],
    Polygon[{{1.844167, 0.002696, -0.004384},{1.844508, 0.002227, -0.002984},{
      1.846539, 0.004259, -0.002984},{1.846070, 0.004600, -0.004384}}],
    Polygon[{{1.844508, 0.002227, -0.002984},{1.844715, 0.001941, -0.001511},{
      1.846826, 0.004051, -0.001511},{1.846539, 0.004259, -0.002984}}],
    Polygon[{{1.844715, 0.001941, -0.001511},{1.844785, 0.001844, 0.000000},{
      1.846922, 0.003981, 0.000000},{1.846826, 0.004051, -0.001511}}],
    Polygon[{{1.844785, 0.001844, 0.000000},{1.844715, 0.001941, 0.001511},{
      1.846826, 0.004051, 0.001511},{1.846922, 0.003981, 0.000000}}],
    Polygon[{{1.844715, 0.001941, 0.001511},{1.844508, 0.002227, 0.002984},{
      1.846539, 0.004259, 0.002984},{1.846826, 0.004051, 0.001511}}],
    Polygon[{{1.844508, 0.002227, 0.002984},{1.844167, 0.002696, 0.004384},{
      1.846070, 0.004600, 0.004384},{1.846539, 0.004259, 0.002984}}],
    Polygon[{{1.844167, 0.002696, 0.004384},{1.843701, 0.003336, 0.005676},{
      1.845430, 0.005065, 0.005676},{1.846070, 0.004600, 0.004384}}],
    Polygon[{{1.843701, 0.003336, 0.005676},{1.843123, 0.004133, 0.006829},{
      1.844634, 0.005643, 0.006829},{1.845430, 0.005065, 0.005676}}],
    Polygon[{{1.843123, 0.004133, 0.006829},{1.842445, 0.005065, 0.007813},{
      1.843701, 0.006321, 0.007813},{1.844634, 0.005643, 0.006829}}],
    Polygon[{{1.842445, 0.005065, 0.007813},{1.841686, 0.006110, 0.008605},{
      1.842656, 0.007080, 0.008605},{1.843701, 0.006321, 0.007813}}],
    Polygon[{{1.841686, 0.006110, 0.008605},{1.840863, 0.007243, 0.009185},{
      1.841523, 0.007903, 0.009185},{1.842656, 0.007080, 0.008605}}],
    Polygon[{{1.840863, 0.007243, 0.009185},{1.839997, 0.008435, 0.009538},{
      1.840331, 0.008769, 0.009538},{1.841523, 0.007903, 0.009185}}],
    Polygon[{{1.840331, 0.008769, -0.009538},{1.841523, 0.007903, -0.009185},{
      1.841947, 0.008735, -0.009185},{1.840546, 0.009190, -0.009538}}],
    Polygon[{{1.841523, 0.007903, -0.009185},{1.842656, 0.007080, -0.008605},{
      1.843279, 0.008302, -0.008605},{1.841947, 0.008735, -0.009185}}],
    Polygon[{{1.842656, 0.007080, -0.008605},{1.843701, 0.006321, -0.007813},{
      1.844508, 0.007903, -0.007813},{1.843279, 0.008302, -0.008605}}],
    Polygon[{{1.843701, 0.006321, -0.007813},{1.844634, 0.005643, -0.006829},{
      1.845603, 0.007547, -0.006829},{1.844508, 0.007903, -0.007813}}],
    Polygon[{{1.844634, 0.005643, -0.006829},{1.845430, 0.005065, -0.005676},{
      1.846539, 0.007243, -0.005676},{1.845603, 0.007547, -0.006829}}],
    Polygon[{{1.845430, 0.005065, -0.005676},{1.846070, 0.004600, -0.004384},{
      1.847293, 0.006998, -0.004384},{1.846539, 0.007243, -0.005676}}],
    Polygon[{{1.846070, 0.004600, -0.004384},{1.846539, 0.004259, -0.002984},{
      1.847844, 0.006819, -0.002984},{1.847293, 0.006998, -0.004384}}],
    Polygon[{{1.846539, 0.004259, -0.002984},{1.846826, 0.004051, -0.001511},{
      1.848181, 0.006710, -0.001511},{1.847844, 0.006819, -0.002984}}],
    Polygon[{{1.846826, 0.004051, -0.001511},{1.846922, 0.003981, 0.000000},{
      1.848294, 0.006673, 0.000000},{1.848181, 0.006710, -0.001511}}],
    Polygon[{{1.846922, 0.003981, 0.000000},{1.846826, 0.004051, 0.001511},{
      1.848181, 0.006710, 0.001511},{1.848294, 0.006673, 0.000000}}],
    Polygon[{{1.846826, 0.004051, 0.001511},{1.846539, 0.004259, 0.002984},{
      1.847844, 0.006819, 0.002984},{1.848181, 0.006710, 0.001511}}],
    Polygon[{{1.846539, 0.004259, 0.002984},{1.846070, 0.004600, 0.004384},{
      1.847293, 0.006998, 0.004384},{1.847844, 0.006819, 0.002984}}],
    Polygon[{{1.846070, 0.004600, 0.004384},{1.845430, 0.005065, 0.005676},{
      1.846539, 0.007243, 0.005676},{1.847293, 0.006998, 0.004384}}],
    Polygon[{{1.845430, 0.005065, 0.005676},{1.844634, 0.005643, 0.006829},{
      1.845603, 0.007547, 0.006829},{1.846539, 0.007243, 0.005676}}],
    Polygon[{{1.844634, 0.005643, 0.006829},{1.843701, 0.006321, 0.007813},{
      1.844508, 0.007903, 0.007813},{1.845603, 0.007547, 0.006829}}],
    Polygon[{{1.843701, 0.006321, 0.007813},{1.842656, 0.007080, 0.008605},{
      1.843279, 0.008302, 0.008605},{1.844508, 0.007903, 0.007813}}],
    Polygon[{{1.842656, 0.007080, 0.008605},{1.841523, 0.007903, 0.009185},{
      1.841947, 0.008735, 0.009185},{1.843279, 0.008302, 0.008605}}],
    Polygon[{{1.841523, 0.007903, 0.009185},{1.840331, 0.008769, 0.009538},{
      1.840546, 0.009190, 0.009538},{1.841947, 0.008735, 0.009185}}],
    Polygon[{{1.840546, 0.009190, -0.009538},{1.841947, 0.008735, -0.009185},{
      1.842093, 0.009657, -0.009185},{1.840620, 0.009657, -0.009538}}],
    Polygon[{{1.841947, 0.008735, -0.009185},{1.843279, 0.008302, -0.008605},{
      1.843493, 0.009657, -0.008605},{1.842093, 0.009657, -0.009185}}],
    Polygon[{{1.843279, 0.008302, -0.008605},{1.844508, 0.007903, -0.007813},{
      1.844785, 0.009657, -0.007813},{1.843493, 0.009657, -0.008605}}],
    Polygon[{{1.844508, 0.007903, -0.007813},{1.845603, 0.007547, -0.006829},{
      1.845938, 0.009657, -0.006829},{1.844785, 0.009657, -0.007813}}],
    Polygon[{{1.845603, 0.007547, -0.006829},{1.846539, 0.007243, -0.005676},{
      1.846922, 0.009657, -0.005676},{1.845938, 0.009657, -0.006829}}],
    Polygon[{{1.846539, 0.007243, -0.005676},{1.847293, 0.006998, -0.004384},{
      1.847714, 0.009657, -0.004384},{1.846922, 0.009657, -0.005676}}],
    Polygon[{{1.847293, 0.006998, -0.004384},{1.847844, 0.006819, -0.002984},{
      1.848294, 0.009657, -0.002984},{1.847714, 0.009657, -0.004384}}],
    Polygon[{{1.847844, 0.006819, -0.002984},{1.848181, 0.006710, -0.001511},{
      1.848647, 0.009657, -0.001511},{1.848294, 0.009657, -0.002984}}],
    Polygon[{{1.848181, 0.006710, -0.001511},{1.848294, 0.006673, 0.000000},{
      1.848766, 0.009657, 0.000000},{1.848647, 0.009657, -0.001511}}],
    Polygon[{{1.848294, 0.006673, 0.000000},{1.848181, 0.006710, 0.001511},{
      1.848647, 0.009657, 0.001511},{1.848766, 0.009657, 0.000000}}],
    Polygon[{{1.848181, 0.006710, 0.001511},{1.847844, 0.006819, 0.002984},{
      1.848294, 0.009657, 0.002984},{1.848647, 0.009657, 0.001511}}],
    Polygon[{{1.847844, 0.006819, 0.002984},{1.847293, 0.006998, 0.004384},{
      1.847714, 0.009657, 0.004384},{1.848294, 0.009657, 0.002984}}],
    Polygon[{{1.847293, 0.006998, 0.004384},{1.846539, 0.007243, 0.005676},{
      1.846922, 0.009657, 0.005676},{1.847714, 0.009657, 0.004384}}],
    Polygon[{{1.846539, 0.007243, 0.005676},{1.845603, 0.007547, 0.006829},{
      1.845938, 0.009657, 0.006829},{1.846922, 0.009657, 0.005676}}],
    Polygon[{{1.845603, 0.007547, 0.006829},{1.844508, 0.007903, 0.007813},{
      1.844785, 0.009657, 0.007813},{1.845938, 0.009657, 0.006829}}],
    Polygon[{{1.844508, 0.007903, 0.007813},{1.843279, 0.008302, 0.008605},{
      1.843493, 0.009657, 0.008605},{1.844785, 0.009657, 0.007813}}],
    Polygon[{{1.843279, 0.008302, 0.008605},{1.841947, 0.008735, 0.009185},{
      1.842093, 0.009657, 0.009185},{1.843493, 0.009657, 0.008605}}],
    Polygon[{{1.841947, 0.008735, 0.009185},{1.840546, 0.009190, 0.009538},{
      1.840620, 0.009657, 0.009538},{1.842093, 0.009657, 0.009185}}],
    Polygon[{{1.817859, 0.058755, -0.008290},{1.819140, 0.058755, -0.007983},{
      1.819013, 0.059557, -0.007983},{1.817795, 0.059161, -0.008290}}],
    Polygon[{{1.819140, 0.058755, -0.007983},{1.820357, 0.058755, -0.007479},{
      1.820170, 0.059933, -0.007479},{1.819013, 0.059557, -0.007983}}],
    Polygon[{{1.820357, 0.058755, -0.007479},{1.821480, 0.058755, -0.006791},{
      1.821238, 0.060280, -0.006791},{1.820170, 0.059933, -0.007479}}],
    Polygon[{{1.821480, 0.058755, -0.006791},{1.822481, 0.058755, -0.005935},{
      1.822191, 0.060589, -0.005935},{1.821238, 0.060280, -0.006791}}],
    Polygon[{{1.822481, 0.058755, -0.005935},{1.823337, 0.058755, -0.004934},{
      1.823004, 0.060854, -0.004934},{1.822191, 0.060589, -0.005935}}],
    Polygon[{{1.823337, 0.058755, -0.004934},{1.824025, 0.058755, -0.003811},{
      1.823659, 0.061066, -0.003811},{1.823004, 0.060854, -0.004934}}],
    Polygon[{{1.824025, 0.058755, -0.003811},{1.824529, 0.058755, -0.002594},{
      1.824138, 0.061222, -0.002594},{1.823659, 0.061066, -0.003811}}],
    Polygon[{{1.824529, 0.058755, -0.002594},{1.824836, 0.058755, -0.001313},{
      1.824431, 0.061317, -0.001313},{1.824138, 0.061222, -0.002594}}],
    Polygon[{{1.824836, 0.058755, -0.001313},{1.824940, 0.058755, 0.000000},{
      1.824529, 0.061349, 0.000000},{1.824431, 0.061317, -0.001313}}],
    Polygon[{{1.824940, 0.058755, 0.000000},{1.824836, 0.058755, 0.001313},{
      1.824431, 0.061317, 0.001313},{1.824529, 0.061349, 0.000000}}],
    Polygon[{{1.824836, 0.058755, 0.001313},{1.824529, 0.058755, 0.002594},{
      1.824138, 0.061222, 0.002594},{1.824431, 0.061317, 0.001313}}],
    Polygon[{{1.824529, 0.058755, 0.002594},{1.824025, 0.058755, 0.003811},{
      1.823659, 0.061066, 0.003811},{1.824138, 0.061222, 0.002594}}],
    Polygon[{{1.824025, 0.058755, 0.003811},{1.823337, 0.058755, 0.004934},{
      1.823004, 0.060854, 0.004934},{1.823659, 0.061066, 0.003811}}],
    Polygon[{{1.823337, 0.058755, 0.004934},{1.822481, 0.058755, 0.005935},{
      1.822191, 0.060589, 0.005935},{1.823004, 0.060854, 0.004934}}],
    Polygon[{{1.822481, 0.058755, 0.005935},{1.821480, 0.058755, 0.006791},{
      1.821238, 0.060280, 0.006791},{1.822191, 0.060589, 0.005935}}],
    Polygon[{{1.821480, 0.058755, 0.006791},{1.820357, 0.058755, 0.007479},{
      1.820170, 0.059933, 0.007479},{1.821238, 0.060280, 0.006791}}],
    Polygon[{{1.820357, 0.058755, 0.007479},{1.819140, 0.058755, 0.007983},{
      1.819013, 0.059557, 0.007983},{1.820170, 0.059933, 0.007479}}],
    Polygon[{{1.819140, 0.058755, 0.007983},{1.817859, 0.058755, 0.008290},{
      1.817795, 0.059161, 0.008290},{1.819013, 0.059557, 0.007983}}],
    Polygon[{{1.817795, 0.059161, -0.008290},{1.819013, 0.059557, -0.007983},{
      1.818645, 0.060280, -0.007983},{1.817608, 0.059527, -0.008290}}],
    Polygon[{{1.819013, 0.059557, -0.007983},{1.820170, 0.059933, -0.007479},{
      1.819629, 0.060995, -0.007479},{1.818645, 0.060280, -0.007983}}],
    Polygon[{{1.820170, 0.059933, -0.007479},{1.821238, 0.060280, -0.006791},{
      1.820538, 0.061655, -0.006791},{1.819629, 0.060995, -0.007479}}],
    Polygon[{{1.821238, 0.060280, -0.006791},{1.822191, 0.060589, -0.005935},{
      1.821348, 0.062244, -0.005935},{1.820538, 0.061655, -0.006791}}],
    Polygon[{{1.822191, 0.060589, -0.005935},{1.823004, 0.060854, -0.004934},{
      1.822040, 0.062747, -0.004934},{1.821348, 0.062244, -0.005935}}],
    Polygon[{{1.823004, 0.060854, -0.004934},{1.823659, 0.061066, -0.003811},{
      1.822597, 0.063151, -0.003811},{1.822040, 0.062747, -0.004934}}],
    Polygon[{{1.823659, 0.061066, -0.003811},{1.824138, 0.061222, -0.002594},{
      1.823004, 0.063447, -0.002594},{1.822597, 0.063151, -0.003811}}],
    Polygon[{{1.824138, 0.061222, -0.002594},{1.824431, 0.061317, -0.001313},{
      1.823253, 0.063628, -0.001313},{1.823004, 0.063447, -0.002594}}],
    Polygon[{{1.824431, 0.061317, -0.001313},{1.824529, 0.061349, 0.000000},{
      1.823337, 0.063689, 0.000000},{1.823253, 0.063628, -0.001313}}],
    Polygon[{{1.824529, 0.061349, 0.000000},{1.824431, 0.061317, 0.001313},{
      1.823253, 0.063628, 0.001313},{1.823337, 0.063689, 0.000000}}],
    Polygon[{{1.824431, 0.061317, 0.001313},{1.824138, 0.061222, 0.002594},{
      1.823004, 0.063447, 0.002594},{1.823253, 0.063628, 0.001313}}],
    Polygon[{{1.824138, 0.061222, 0.002594},{1.823659, 0.061066, 0.003811},{
      1.822597, 0.063151, 0.003811},{1.823004, 0.063447, 0.002594}}],
    Polygon[{{1.823659, 0.061066, 0.003811},{1.823004, 0.060854, 0.004934},{
      1.822040, 0.062747, 0.004934},{1.822597, 0.063151, 0.003811}}],
    Polygon[{{1.823004, 0.060854, 0.004934},{1.822191, 0.060589, 0.005935},{
      1.821348, 0.062244, 0.005935},{1.822040, 0.062747, 0.004934}}],
    Polygon[{{1.822191, 0.060589, 0.005935},{1.821238, 0.060280, 0.006791},{
      1.820538, 0.061655, 0.006791},{1.821348, 0.062244, 0.005935}}],
    Polygon[{{1.821238, 0.060280, 0.006791},{1.820170, 0.059933, 0.007479},{
      1.819629, 0.060995, 0.007479},{1.820538, 0.061655, 0.006791}}],
    Polygon[{{1.820170, 0.059933, 0.007479},{1.819013, 0.059557, 0.007983},{
      1.818645, 0.060280, 0.007983},{1.819629, 0.060995, 0.007479}}],
    Polygon[{{1.819013, 0.059557, 0.007983},{1.817795, 0.059161, 0.008290},{
      1.817608, 0.059527, 0.008290},{1.818645, 0.060280, 0.007983}}],
    Polygon[{{1.817608, 0.059527, -0.008290},{1.818645, 0.060280, -0.007983},{
      1.818071, 0.060854, -0.007983},{1.817318, 0.059817, -0.008290}}],
    Polygon[{{1.818645, 0.060280, -0.007983},{1.819629, 0.060995, -0.007479},{
      1.818786, 0.061838, -0.007479},{1.818071, 0.060854, -0.007983}}],
    Polygon[{{1.819629, 0.060995, -0.007479},{1.820538, 0.061655, -0.006791},{
      1.819446, 0.062747, -0.006791},{1.818786, 0.061838, -0.007479}}],
    Polygon[{{1.820538, 0.061655, -0.006791},{1.821348, 0.062244, -0.005935},{
      1.820035, 0.063557, -0.005935},{1.819446, 0.062747, -0.006791}}],
    Polygon[{{1.821348, 0.062244, -0.005935},{1.822040, 0.062747, -0.004934},{
      1.820538, 0.064249, -0.004934},{1.820035, 0.063557, -0.005935}}],
    Polygon[{{1.822040, 0.062747, -0.004934},{1.822597, 0.063151, -0.003811},{
      1.820942, 0.064806, -0.003811},{1.820538, 0.064249, -0.004934}}],
    Polygon[{{1.822597, 0.063151, -0.003811},{1.823004, 0.063447, -0.002594},{
      1.821238, 0.065213, -0.002594},{1.820942, 0.064806, -0.003811}}],
    Polygon[{{1.823004, 0.063447, -0.002594},{1.823253, 0.063628, -0.001313},{
      1.821419, 0.065462, -0.001313},{1.821238, 0.065213, -0.002594}}],
    Polygon[{{1.823253, 0.063628, -0.001313},{1.823337, 0.063689, 0.000000},{
      1.821480, 0.065546, 0.000000},{1.821419, 0.065462, -0.001313}}],
    Polygon[{{1.823337, 0.063689, 0.000000},{1.823253, 0.063628, 0.001313},{
      1.821419, 0.065462, 0.001313},{1.821480, 0.065546, 0.000000}}],
    Polygon[{{1.823253, 0.063628, 0.001313},{1.823004, 0.063447, 0.002594},{
      1.821238, 0.065213, 0.002594},{1.821419, 0.065462, 0.001313}}],
    Polygon[{{1.823004, 0.063447, 0.002594},{1.822597, 0.063151, 0.003811},{
      1.820942, 0.064806, 0.003811},{1.821238, 0.065213, 0.002594}}],
    Polygon[{{1.822597, 0.063151, 0.003811},{1.822040, 0.062747, 0.004934},{
      1.820538, 0.064249, 0.004934},{1.820942, 0.064806, 0.003811}}],
    Polygon[{{1.822040, 0.062747, 0.004934},{1.821348, 0.062244, 0.005935},{
      1.820035, 0.063557, 0.005935},{1.820538, 0.064249, 0.004934}}],
    Polygon[{{1.821348, 0.062244, 0.005935},{1.820538, 0.061655, 0.006791},{
      1.819446, 0.062747, 0.006791},{1.820035, 0.063557, 0.005935}}],
    Polygon[{{1.820538, 0.061655, 0.006791},{1.819629, 0.060995, 0.007479},{
      1.818786, 0.061838, 0.007479},{1.819446, 0.062747, 0.006791}}],
    Polygon[{{1.819629, 0.060995, 0.007479},{1.818645, 0.060280, 0.007983},{
      1.818071, 0.060854, 0.007983},{1.818786, 0.061838, 0.007479}}],
    Polygon[{{1.818645, 0.060280, 0.007983},{1.817608, 0.059527, 0.008290},{
      1.817318, 0.059817, 0.008290},{1.818071, 0.060854, 0.007983}}],
    Polygon[{{1.817318, 0.059817, -0.008290},{1.818071, 0.060854, -0.007983},{
      1.817348, 0.061222, -0.007983},{1.816952, 0.060004, -0.008290}}],
    Polygon[{{1.818071, 0.060854, -0.007983},{1.818786, 0.061838, -0.007479},{
      1.817724, 0.062379, -0.007479},{1.817348, 0.061222, -0.007983}}],
    Polygon[{{1.818786, 0.061838, -0.007479},{1.819446, 0.062747, -0.006791},{
      1.818071, 0.063447, -0.006791},{1.817724, 0.062379, -0.007479}}],
    Polygon[{{1.819446, 0.062747, -0.006791},{1.820035, 0.063557, -0.005935},{
      1.818380, 0.064400, -0.005935},{1.818071, 0.063447, -0.006791}}],
    Polygon[{{1.820035, 0.063557, -0.005935},{1.820538, 0.064249, -0.004934},{
      1.818645, 0.065213, -0.004934},{1.818380, 0.064400, -0.005935}}],
    Polygon[{{1.820538, 0.064249, -0.004934},{1.820942, 0.064806, -0.003811},{
      1.818857, 0.065868, -0.003811},{1.818645, 0.065213, -0.004934}}],
    Polygon[{{1.820942, 0.064806, -0.003811},{1.821238, 0.065213, -0.002594},{
      1.819013, 0.066347, -0.002594},{1.818857, 0.065868, -0.003811}}],
    Polygon[{{1.821238, 0.065213, -0.002594},{1.821419, 0.065462, -0.001313},{
      1.819108, 0.066640, -0.001313},{1.819013, 0.066347, -0.002594}}],
    Polygon[{{1.821419, 0.065462, -0.001313},{1.821480, 0.065546, 0.000000},{
      1.819140, 0.066738, 0.000000},{1.819108, 0.066640, -0.001313}}],
    Polygon[{{1.821480, 0.065546, 0.000000},{1.821419, 0.065462, 0.001313},{
      1.819108, 0.066640, 0.001313},{1.819140, 0.066738, 0.000000}}],
    Polygon[{{1.821419, 0.065462, 0.001313},{1.821238, 0.065213, 0.002594},{
      1.819013, 0.066347, 0.002594},{1.819108, 0.066640, 0.001313}}],
    Polygon[{{1.821238, 0.065213, 0.002594},{1.820942, 0.064806, 0.003811},{
      1.818857, 0.065868, 0.003811},{1.819013, 0.066347, 0.002594}}],
    Polygon[{{1.820942, 0.064806, 0.003811},{1.820538, 0.064249, 0.004934},{
      1.818645, 0.065213, 0.004934},{1.818857, 0.065868, 0.003811}}],
    Polygon[{{1.820538, 0.064249, 0.004934},{1.820035, 0.063557, 0.005935},{
      1.818380, 0.064400, 0.005935},{1.818645, 0.065213, 0.004934}}],
    Polygon[{{1.820035, 0.063557, 0.005935},{1.819446, 0.062747, 0.006791},{
      1.818071, 0.063447, 0.006791},{1.818380, 0.064400, 0.005935}}],
    Polygon[{{1.819446, 0.062747, 0.006791},{1.818786, 0.061838, 0.007479},{
      1.817724, 0.062379, 0.007479},{1.818071, 0.063447, 0.006791}}],
    Polygon[{{1.818786, 0.061838, 0.007479},{1.818071, 0.060854, 0.007983},{
      1.817348, 0.061222, 0.007983},{1.817724, 0.062379, 0.007479}}],
    Polygon[{{1.818071, 0.060854, 0.007983},{1.817318, 0.059817, 0.008290},{
      1.816952, 0.060004, 0.008290},{1.817348, 0.061222, 0.007983}}],
    Polygon[{{1.816952, 0.060004, -0.008290},{1.817348, 0.061222, -0.007983},{
      1.816546, 0.061349, -0.007983},{1.816546, 0.060068, -0.008290}}],
    Polygon[{{1.817348, 0.061222, -0.007983},{1.817724, 0.062379, -0.007479},{
      1.816546, 0.062566, -0.007479},{1.816546, 0.061349, -0.007983}}],
    Polygon[{{1.817724, 0.062379, -0.007479},{1.818071, 0.063447, -0.006791},{
      1.816546, 0.063689, -0.006791},{1.816546, 0.062566, -0.007479}}],
    Polygon[{{1.818071, 0.063447, -0.006791},{1.818380, 0.064400, -0.005935},{
      1.816546, 0.064690, -0.005935},{1.816546, 0.063689, -0.006791}}],
    Polygon[{{1.818380, 0.064400, -0.005935},{1.818645, 0.065213, -0.004934},{
      1.816546, 0.065546, -0.004934},{1.816546, 0.064690, -0.005935}}],
    Polygon[{{1.818645, 0.065213, -0.004934},{1.818857, 0.065868, -0.003811},{
      1.816546, 0.066234, -0.003811},{1.816546, 0.065546, -0.004934}}],
    Polygon[{{1.818857, 0.065868, -0.003811},{1.819013, 0.066347, -0.002594},{
      1.816546, 0.066738, -0.002594},{1.816546, 0.066234, -0.003811}}],
    Polygon[{{1.819013, 0.066347, -0.002594},{1.819108, 0.066640, -0.001313},{
      1.816546, 0.067045, -0.001313},{1.816546, 0.066738, -0.002594}}],
    Polygon[{{1.819108, 0.066640, -0.001313},{1.819140, 0.066738, 0.000000},{
      1.816546, 0.067149, 0.000000},{1.816546, 0.067045, -0.001313}}],
    Polygon[{{1.819140, 0.066738, 0.000000},{1.819108, 0.066640, 0.001313},{
      1.816546, 0.067045, 0.001313},{1.816546, 0.067149, 0.000000}}],
    Polygon[{{1.819108, 0.066640, 0.001313},{1.819013, 0.066347, 0.002594},{
      1.816546, 0.066738, 0.002594},{1.816546, 0.067045, 0.001313}}],
    Polygon[{{1.819013, 0.066347, 0.002594},{1.818857, 0.065868, 0.003811},{
      1.816546, 0.066234, 0.003811},{1.816546, 0.066738, 0.002594}}],
    Polygon[{{1.818857, 0.065868, 0.003811},{1.818645, 0.065213, 0.004934},{
      1.816546, 0.065546, 0.004934},{1.816546, 0.066234, 0.003811}}],
    Polygon[{{1.818645, 0.065213, 0.004934},{1.818380, 0.064400, 0.005935},{
      1.816546, 0.064690, 0.005935},{1.816546, 0.065546, 0.004934}}],
    Polygon[{{1.818380, 0.064400, 0.005935},{1.818071, 0.063447, 0.006791},{
      1.816546, 0.063689, 0.006791},{1.816546, 0.064690, 0.005935}}],
    Polygon[{{1.818071, 0.063447, 0.006791},{1.817724, 0.062379, 0.007479},{
      1.816546, 0.062566, 0.007479},{1.816546, 0.063689, 0.006791}}],
    Polygon[{{1.817724, 0.062379, 0.007479},{1.817348, 0.061222, 0.007983},{
      1.816546, 0.061349, 0.007983},{1.816546, 0.062566, 0.007479}}],
    Polygon[{{1.817348, 0.061222, 0.007983},{1.816952, 0.060004, 0.008290},{
      1.816546, 0.060068, 0.008290},{1.816546, 0.061349, 0.007983}}],
    Polygon[{{1.816546, 0.060068, -0.008290},{1.816546, 0.061349, -0.007983},{
      1.815745, 0.061222, -0.007983},{1.816140, 0.060004, -0.008290}}],
    Polygon[{{1.816546, 0.061349, -0.007983},{1.816546, 0.062566, -0.007479},{
      1.815369, 0.062379, -0.007479},{1.815745, 0.061222, -0.007983}}],
    Polygon[{{1.816546, 0.062566, -0.007479},{1.816546, 0.063689, -0.006791},{
      1.815022, 0.063447, -0.006791},{1.815369, 0.062379, -0.007479}}],
    Polygon[{{1.816546, 0.063689, -0.006791},{1.816546, 0.064690, -0.005935},{
      1.814712, 0.064400, -0.005935},{1.815022, 0.063447, -0.006791}}],
    Polygon[{{1.816546, 0.064690, -0.005935},{1.816546, 0.065546, -0.004934},{
      1.814448, 0.065213, -0.004934},{1.814712, 0.064400, -0.005935}}],
    Polygon[{{1.816546, 0.065546, -0.004934},{1.816546, 0.066234, -0.003811},{
      1.814235, 0.065868, -0.003811},{1.814448, 0.065213, -0.004934}}],
    Polygon[{{1.816546, 0.066234, -0.003811},{1.816546, 0.066738, -0.002594},{
      1.814079, 0.066347, -0.002594},{1.814235, 0.065868, -0.003811}}],
    Polygon[{{1.816546, 0.066738, -0.002594},{1.816546, 0.067045, -0.001313},{
      1.813984, 0.066640, -0.001313},{1.814079, 0.066347, -0.002594}}],
    Polygon[{{1.816546, 0.067045, -0.001313},{1.816546, 0.067149, 0.000000},{
      1.813952, 0.066738, 0.000000},{1.813984, 0.066640, -0.001313}}],
    Polygon[{{1.816546, 0.067149, 0.000000},{1.816546, 0.067045, 0.001313},{
      1.813984, 0.066640, 0.001313},{1.813952, 0.066738, 0.000000}}],
    Polygon[{{1.816546, 0.067045, 0.001313},{1.816546, 0.066738, 0.002594},{
      1.814079, 0.066347, 0.002594},{1.813984, 0.066640, 0.001313}}],
    Polygon[{{1.816546, 0.066738, 0.002594},{1.816546, 0.066234, 0.003811},{
      1.814235, 0.065868, 0.003811},{1.814079, 0.066347, 0.002594}}],
    Polygon[{{1.816546, 0.066234, 0.003811},{1.816546, 0.065546, 0.004934},{
      1.814448, 0.065213, 0.004934},{1.814235, 0.065868, 0.003811}}],
    Polygon[{{1.816546, 0.065546, 0.004934},{1.816546, 0.064690, 0.005935},{
      1.814712, 0.064400, 0.005935},{1.814448, 0.065213, 0.004934}}],
    Polygon[{{1.816546, 0.064690, 0.005935},{1.816546, 0.063689, 0.006791},{
      1.815022, 0.063447, 0.006791},{1.814712, 0.064400, 0.005935}}],
    Polygon[{{1.816546, 0.063689, 0.006791},{1.816546, 0.062566, 0.007479},{
      1.815369, 0.062379, 0.007479},{1.815022, 0.063447, 0.006791}}],
    Polygon[{{1.816546, 0.062566, 0.007479},{1.816546, 0.061349, 0.007983},{
      1.815745, 0.061222, 0.007983},{1.815369, 0.062379, 0.007479}}],
    Polygon[{{1.816546, 0.061349, 0.007983},{1.816546, 0.060068, 0.008290},{
      1.816140, 0.060004, 0.008290},{1.815745, 0.061222, 0.007983}}],
    Polygon[{{1.816140, 0.060004, -0.008290},{1.815745, 0.061222, -0.007983},{
      1.815022, 0.060854, -0.007983},{1.815774, 0.059817, -0.008290}}],
    Polygon[{{1.815745, 0.061222, -0.007983},{1.815369, 0.062379, -0.007479},{
      1.814306, 0.061838, -0.007479},{1.815022, 0.060854, -0.007983}}],
    Polygon[{{1.815369, 0.062379, -0.007479},{1.815022, 0.063447, -0.006791},{
      1.813646, 0.062747, -0.006791},{1.814306, 0.061838, -0.007479}}],
    Polygon[{{1.815022, 0.063447, -0.006791},{1.814712, 0.064400, -0.005935},{
      1.813058, 0.063557, -0.005935},{1.813646, 0.062747, -0.006791}}],
    Polygon[{{1.814712, 0.064400, -0.005935},{1.814448, 0.065213, -0.004934},{
      1.812555, 0.064249, -0.004934},{1.813058, 0.063557, -0.005935}}],
    Polygon[{{1.814448, 0.065213, -0.004934},{1.814235, 0.065868, -0.003811},{
      1.812150, 0.064806, -0.003811},{1.812555, 0.064249, -0.004934}}],
    Polygon[{{1.814235, 0.065868, -0.003811},{1.814079, 0.066347, -0.002594},{
      1.811854, 0.065213, -0.002594},{1.812150, 0.064806, -0.003811}}],
    Polygon[{{1.814079, 0.066347, -0.002594},{1.813984, 0.066640, -0.001313},{
      1.811673, 0.065462, -0.001313},{1.811854, 0.065213, -0.002594}}],
    Polygon[{{1.813984, 0.066640, -0.001313},{1.813952, 0.066738, 0.000000},{
      1.811612, 0.065546, 0.000000},{1.811673, 0.065462, -0.001313}}],
    Polygon[{{1.813952, 0.066738, 0.000000},{1.813984, 0.066640, 0.001313},{
      1.811673, 0.065462, 0.001313},{1.811612, 0.065546, 0.000000}}],
    Polygon[{{1.813984, 0.066640, 0.001313},{1.814079, 0.066347, 0.002594},{
      1.811854, 0.065213, 0.002594},{1.811673, 0.065462, 0.001313}}],
    Polygon[{{1.814079, 0.066347, 0.002594},{1.814235, 0.065868, 0.003811},{
      1.812150, 0.064806, 0.003811},{1.811854, 0.065213, 0.002594}}],
    Polygon[{{1.814235, 0.065868, 0.003811},{1.814448, 0.065213, 0.004934},{
      1.812555, 0.064249, 0.004934},{1.812150, 0.064806, 0.003811}}],
    Polygon[{{1.814448, 0.065213, 0.004934},{1.814712, 0.064400, 0.005935},{
      1.813058, 0.063557, 0.005935},{1.812555, 0.064249, 0.004934}}],
    Polygon[{{1.814712, 0.064400, 0.005935},{1.815022, 0.063447, 0.006791},{
      1.813646, 0.062747, 0.006791},{1.813058, 0.063557, 0.005935}}],
    Polygon[{{1.815022, 0.063447, 0.006791},{1.815369, 0.062379, 0.007479},{
      1.814306, 0.061838, 0.007479},{1.813646, 0.062747, 0.006791}}],
    Polygon[{{1.815369, 0.062379, 0.007479},{1.815745, 0.061222, 0.007983},{
      1.815022, 0.060854, 0.007983},{1.814306, 0.061838, 0.007479}}],
    Polygon[{{1.815745, 0.061222, 0.007983},{1.816140, 0.060004, 0.008290},{
      1.815774, 0.059817, 0.008290},{1.815022, 0.060854, 0.007983}}],
    Polygon[{{1.815774, 0.059817, -0.008290},{1.815022, 0.060854, -0.007983},{
      1.814448, 0.060280, -0.007983},{1.815484, 0.059527, -0.008290}}],
    Polygon[{{1.815022, 0.060854, -0.007983},{1.814306, 0.061838, -0.007479},{
      1.813463, 0.060995, -0.007479},{1.814448, 0.060280, -0.007983}}],
    Polygon[{{1.814306, 0.061838, -0.007479},{1.813646, 0.062747, -0.006791},{
      1.812555, 0.061655, -0.006791},{1.813463, 0.060995, -0.007479}}],
    Polygon[{{1.813646, 0.062747, -0.006791},{1.813058, 0.063557, -0.005935},{
      1.811744, 0.062244, -0.005935},{1.812555, 0.061655, -0.006791}}],
    Polygon[{{1.813058, 0.063557, -0.005935},{1.812555, 0.064249, -0.004934},{
      1.811052, 0.062747, -0.004934},{1.811744, 0.062244, -0.005935}}],
    Polygon[{{1.812555, 0.064249, -0.004934},{1.812150, 0.064806, -0.003811},{
      1.810496, 0.063151, -0.003811},{1.811052, 0.062747, -0.004934}}],
    Polygon[{{1.812150, 0.064806, -0.003811},{1.811854, 0.065213, -0.002594},{
      1.810088, 0.063447, -0.002594},{1.810496, 0.063151, -0.003811}}],
    Polygon[{{1.811854, 0.065213, -0.002594},{1.811673, 0.065462, -0.001313},{
      1.809839, 0.063628, -0.001313},{1.810088, 0.063447, -0.002594}}],
    Polygon[{{1.811673, 0.065462, -0.001313},{1.811612, 0.065546, 0.000000},{
      1.809756, 0.063689, 0.000000},{1.809839, 0.063628, -0.001313}}],
    Polygon[{{1.811612, 0.065546, 0.000000},{1.811673, 0.065462, 0.001313},{
      1.809839, 0.063628, 0.001313},{1.809756, 0.063689, 0.000000}}],
    Polygon[{{1.811673, 0.065462, 0.001313},{1.811854, 0.065213, 0.002594},{
      1.810088, 0.063447, 0.002594},{1.809839, 0.063628, 0.001313}}],
    Polygon[{{1.811854, 0.065213, 0.002594},{1.812150, 0.064806, 0.003811},{
      1.810496, 0.063151, 0.003811},{1.810088, 0.063447, 0.002594}}],
    Polygon[{{1.812150, 0.064806, 0.003811},{1.812555, 0.064249, 0.004934},{
      1.811052, 0.062747, 0.004934},{1.810496, 0.063151, 0.003811}}],
    Polygon[{{1.812555, 0.064249, 0.004934},{1.813058, 0.063557, 0.005935},{
      1.811744, 0.062244, 0.005935},{1.811052, 0.062747, 0.004934}}],
    Polygon[{{1.813058, 0.063557, 0.005935},{1.813646, 0.062747, 0.006791},{
      1.812555, 0.061655, 0.006791},{1.811744, 0.062244, 0.005935}}],
    Polygon[{{1.813646, 0.062747, 0.006791},{1.814306, 0.061838, 0.007479},{
      1.813463, 0.060995, 0.007479},{1.812555, 0.061655, 0.006791}}],
    Polygon[{{1.814306, 0.061838, 0.007479},{1.815022, 0.060854, 0.007983},{
      1.814448, 0.060280, 0.007983},{1.813463, 0.060995, 0.007479}}],
    Polygon[{{1.815022, 0.060854, 0.007983},{1.815774, 0.059817, 0.008290},{
      1.815484, 0.059527, 0.008290},{1.814448, 0.060280, 0.007983}}],
    Polygon[{{1.815484, 0.059527, -0.008290},{1.814448, 0.060280, -0.007983},{
      1.814079, 0.059557, -0.007983},{1.815297, 0.059161, -0.008290}}],
    Polygon[{{1.814448, 0.060280, -0.007983},{1.813463, 0.060995, -0.007479},{
      1.812922, 0.059933, -0.007479},{1.814079, 0.059557, -0.007983}}],
    Polygon[{{1.813463, 0.060995, -0.007479},{1.812555, 0.061655, -0.006791},{
      1.811854, 0.060280, -0.006791},{1.812922, 0.059933, -0.007479}}],
    Polygon[{{1.812555, 0.061655, -0.006791},{1.811744, 0.062244, -0.005935},{
      1.810901, 0.060589, -0.005935},{1.811854, 0.060280, -0.006791}}],
    Polygon[{{1.811744, 0.062244, -0.005935},{1.811052, 0.062747, -0.004934},{
      1.810088, 0.060854, -0.004934},{1.810901, 0.060589, -0.005935}}],
    Polygon[{{1.811052, 0.062747, -0.004934},{1.810496, 0.063151, -0.003811},{
      1.809433, 0.061066, -0.003811},{1.810088, 0.060854, -0.004934}}],
    Polygon[{{1.810496, 0.063151, -0.003811},{1.810088, 0.063447, -0.002594},{
      1.808954, 0.061222, -0.002594},{1.809433, 0.061066, -0.003811}}],
    Polygon[{{1.810088, 0.063447, -0.002594},{1.809839, 0.063628, -0.001313},{
      1.808662, 0.061317, -0.001313},{1.808954, 0.061222, -0.002594}}],
    Polygon[{{1.809839, 0.063628, -0.001313},{1.809756, 0.063689, 0.000000},{
      1.808563, 0.061349, 0.000000},{1.808662, 0.061317, -0.001313}}],
    Polygon[{{1.809756, 0.063689, 0.000000},{1.809839, 0.063628, 0.001313},{
      1.808662, 0.061317, 0.001313},{1.808563, 0.061349, 0.000000}}],
    Polygon[{{1.809839, 0.063628, 0.001313},{1.810088, 0.063447, 0.002594},{
      1.808954, 0.061222, 0.002594},{1.808662, 0.061317, 0.001313}}],
    Polygon[{{1.810088, 0.063447, 0.002594},{1.810496, 0.063151, 0.003811},{
      1.809433, 0.061066, 0.003811},{1.808954, 0.061222, 0.002594}}],
    Polygon[{{1.810496, 0.063151, 0.003811},{1.811052, 0.062747, 0.004934},{
      1.810088, 0.060854, 0.004934},{1.809433, 0.061066, 0.003811}}],
    Polygon[{{1.811052, 0.062747, 0.004934},{1.811744, 0.062244, 0.005935},{
      1.810901, 0.060589, 0.005935},{1.810088, 0.060854, 0.004934}}],
    Polygon[{{1.811744, 0.062244, 0.005935},{1.812555, 0.061655, 0.006791},{
      1.811854, 0.060280, 0.006791},{1.810901, 0.060589, 0.005935}}],
    Polygon[{{1.812555, 0.061655, 0.006791},{1.813463, 0.060995, 0.007479},{
      1.812922, 0.059933, 0.007479},{1.811854, 0.060280, 0.006791}}],
    Polygon[{{1.813463, 0.060995, 0.007479},{1.814448, 0.060280, 0.007983},{
      1.814079, 0.059557, 0.007983},{1.812922, 0.059933, 0.007479}}],
    Polygon[{{1.814448, 0.060280, 0.007983},{1.815484, 0.059527, 0.008290},{
      1.815297, 0.059161, 0.008290},{1.814079, 0.059557, 0.007983}}],
    Polygon[{{1.815297, 0.059161, -0.008290},{1.814079, 0.059557, -0.007983},{
      1.813952, 0.058755, -0.007983},{1.815233, 0.058755, -0.008290}}],
    Polygon[{{1.814079, 0.059557, -0.007983},{1.812922, 0.059933, -0.007479},{
      1.812736, 0.058755, -0.007479},{1.813952, 0.058755, -0.007983}}],
    Polygon[{{1.812922, 0.059933, -0.007479},{1.811854, 0.060280, -0.006791},{
      1.811612, 0.058755, -0.006791},{1.812736, 0.058755, -0.007479}}],
    Polygon[{{1.811854, 0.060280, -0.006791},{1.810901, 0.060589, -0.005935},{
      1.810611, 0.058755, -0.005935},{1.811612, 0.058755, -0.006791}}],
    Polygon[{{1.810901, 0.060589, -0.005935},{1.810088, 0.060854, -0.004934},{
      1.809756, 0.058755, -0.004934},{1.810611, 0.058755, -0.005935}}],
    Polygon[{{1.810088, 0.060854, -0.004934},{1.809433, 0.061066, -0.003811},{
      1.809067, 0.058755, -0.003811},{1.809756, 0.058755, -0.004934}}],
    Polygon[{{1.809433, 0.061066, -0.003811},{1.808954, 0.061222, -0.002594},{
      1.808563, 0.058755, -0.002594},{1.809067, 0.058755, -0.003811}}],
    Polygon[{{1.808954, 0.061222, -0.002594},{1.808662, 0.061317, -0.001313},{
      1.808256, 0.058755, -0.001313},{1.808563, 0.058755, -0.002594}}],
    Polygon[{{1.808662, 0.061317, -0.001313},{1.808563, 0.061349, 0.000000},{
      1.808153, 0.058755, 0.000000},{1.808256, 0.058755, -0.001313}}],
    Polygon[{{1.808563, 0.061349, 0.000000},{1.808662, 0.061317, 0.001313},{
      1.808256, 0.058755, 0.001313},{1.808153, 0.058755, 0.000000}}],
    Polygon[{{1.808662, 0.061317, 0.001313},{1.808954, 0.061222, 0.002594},{
      1.808563, 0.058755, 0.002594},{1.808256, 0.058755, 0.001313}}],
    Polygon[{{1.808954, 0.061222, 0.002594},{1.809433, 0.061066, 0.003811},{
      1.809067, 0.058755, 0.003811},{1.808563, 0.058755, 0.002594}}],
    Polygon[{{1.809433, 0.061066, 0.003811},{1.810088, 0.060854, 0.004934},{
      1.809756, 0.058755, 0.004934},{1.809067, 0.058755, 0.003811}}],
    Polygon[{{1.810088, 0.060854, 0.004934},{1.810901, 0.060589, 0.005935},{
      1.810611, 0.058755, 0.005935},{1.809756, 0.058755, 0.004934}}],
    Polygon[{{1.810901, 0.060589, 0.005935},{1.811854, 0.060280, 0.006791},{
      1.811612, 0.058755, 0.006791},{1.810611, 0.058755, 0.005935}}],
    Polygon[{{1.811854, 0.060280, 0.006791},{1.812922, 0.059933, 0.007479},{
      1.812736, 0.058755, 0.007479},{1.811612, 0.058755, 0.006791}}],
    Polygon[{{1.812922, 0.059933, 0.007479},{1.814079, 0.059557, 0.007983},{
      1.813952, 0.058755, 0.007983},{1.812736, 0.058755, 0.007479}}],
    Polygon[{{1.814079, 0.059557, 0.007983},{1.815297, 0.059161, 0.008290},{
      1.815233, 0.058755, 0.008290},{1.813952, 0.058755, 0.007983}}],
    Polygon[{{1.815233, 0.058755, -0.008290},{1.813952, 0.058755, -0.007983},{
      1.814079, 0.057954, -0.007983},{1.815297, 0.058349, -0.008290}}],
    Polygon[{{1.813952, 0.058755, -0.007983},{1.812736, 0.058755, -0.007479},{
      1.812922, 0.057578, -0.007479},{1.814079, 0.057954, -0.007983}}],
    Polygon[{{1.812736, 0.058755, -0.007479},{1.811612, 0.058755, -0.006791},{
      1.811854, 0.057231, -0.006791},{1.812922, 0.057578, -0.007479}}],
    Polygon[{{1.811612, 0.058755, -0.006791},{1.810611, 0.058755, -0.005935},{
      1.810901, 0.056921, -0.005935},{1.811854, 0.057231, -0.006791}}],
    Polygon[{{1.810611, 0.058755, -0.005935},{1.809756, 0.058755, -0.004934},{
      1.810088, 0.056657, -0.004934},{1.810901, 0.056921, -0.005935}}],
    Polygon[{{1.809756, 0.058755, -0.004934},{1.809067, 0.058755, -0.003811},{
      1.809433, 0.056444, -0.003811},{1.810088, 0.056657, -0.004934}}],
    Polygon[{{1.809067, 0.058755, -0.003811},{1.808563, 0.058755, -0.002594},{
      1.808954, 0.056288, -0.002594},{1.809433, 0.056444, -0.003811}}],
    Polygon[{{1.808563, 0.058755, -0.002594},{1.808256, 0.058755, -0.001313},{
      1.808662, 0.056193, -0.001313},{1.808954, 0.056288, -0.002594}}],
    Polygon[{{1.808256, 0.058755, -0.001313},{1.808153, 0.058755, 0.000000},{
      1.808563, 0.056161, 0.000000},{1.808662, 0.056193, -0.001313}}],
    Polygon[{{1.808153, 0.058755, 0.000000},{1.808256, 0.058755, 0.001313},{
      1.808662, 0.056193, 0.001313},{1.808563, 0.056161, 0.000000}}],
    Polygon[{{1.808256, 0.058755, 0.001313},{1.808563, 0.058755, 0.002594},{
      1.808954, 0.056288, 0.002594},{1.808662, 0.056193, 0.001313}}],
    Polygon[{{1.808563, 0.058755, 0.002594},{1.809067, 0.058755, 0.003811},{
      1.809433, 0.056444, 0.003811},{1.808954, 0.056288, 0.002594}}],
    Polygon[{{1.809067, 0.058755, 0.003811},{1.809756, 0.058755, 0.004934},{
      1.810088, 0.056657, 0.004934},{1.809433, 0.056444, 0.003811}}],
    Polygon[{{1.809756, 0.058755, 0.004934},{1.810611, 0.058755, 0.005935},{
      1.810901, 0.056921, 0.005935},{1.810088, 0.056657, 0.004934}}],
    Polygon[{{1.810611, 0.058755, 0.005935},{1.811612, 0.058755, 0.006791},{
      1.811854, 0.057231, 0.006791},{1.810901, 0.056921, 0.005935}}],
    Polygon[{{1.811612, 0.058755, 0.006791},{1.812736, 0.058755, 0.007479},{
      1.812922, 0.057578, 0.007479},{1.811854, 0.057231, 0.006791}}],
    Polygon[{{1.812736, 0.058755, 0.007479},{1.813952, 0.058755, 0.007983},{
      1.814079, 0.057954, 0.007983},{1.812922, 0.057578, 0.007479}}],
    Polygon[{{1.813952, 0.058755, 0.007983},{1.815233, 0.058755, 0.008290},{
      1.815297, 0.058349, 0.008290},{1.814079, 0.057954, 0.007983}}],
    Polygon[{{1.815297, 0.058349, -0.008290},{1.814079, 0.057954, -0.007983},{
      1.814448, 0.057231, -0.007983},{1.815484, 0.057983, -0.008290}}],
    Polygon[{{1.814079, 0.057954, -0.007983},{1.812922, 0.057578, -0.007479},{
      1.813463, 0.056515, -0.007479},{1.814448, 0.057231, -0.007983}}],
    Polygon[{{1.812922, 0.057578, -0.007479},{1.811854, 0.057231, -0.006791},{
      1.812555, 0.055855, -0.006791},{1.813463, 0.056515, -0.007479}}],
    Polygon[{{1.811854, 0.057231, -0.006791},{1.810901, 0.056921, -0.005935},{
      1.811744, 0.055267, -0.005935},{1.812555, 0.055855, -0.006791}}],
    Polygon[{{1.810901, 0.056921, -0.005935},{1.810088, 0.056657, -0.004934},{
      1.811052, 0.054764, -0.004934},{1.811744, 0.055267, -0.005935}}],
    Polygon[{{1.810088, 0.056657, -0.004934},{1.809433, 0.056444, -0.003811},{
      1.810496, 0.054359, -0.003811},{1.811052, 0.054764, -0.004934}}],
    Polygon[{{1.809433, 0.056444, -0.003811},{1.808954, 0.056288, -0.002594},{
      1.810088, 0.054063, -0.002594},{1.810496, 0.054359, -0.003811}}],
    Polygon[{{1.808954, 0.056288, -0.002594},{1.808662, 0.056193, -0.001313},{
      1.809839, 0.053882, -0.001313},{1.810088, 0.054063, -0.002594}}],
    Polygon[{{1.808662, 0.056193, -0.001313},{1.808563, 0.056161, 0.000000},{
      1.809756, 0.053822, 0.000000},{1.809839, 0.053882, -0.001313}}],
    Polygon[{{1.808563, 0.056161, 0.000000},{1.808662, 0.056193, 0.001313},{
      1.809839, 0.053882, 0.001313},{1.809756, 0.053822, 0.000000}}],
    Polygon[{{1.808662, 0.056193, 0.001313},{1.808954, 0.056288, 0.002594},{
      1.810088, 0.054063, 0.002594},{1.809839, 0.053882, 0.001313}}],
    Polygon[{{1.808954, 0.056288, 0.002594},{1.809433, 0.056444, 0.003811},{
      1.810496, 0.054359, 0.003811},{1.810088, 0.054063, 0.002594}}],
    Polygon[{{1.809433, 0.056444, 0.003811},{1.810088, 0.056657, 0.004934},{
      1.811052, 0.054764, 0.004934},{1.810496, 0.054359, 0.003811}}],
    Polygon[{{1.810088, 0.056657, 0.004934},{1.810901, 0.056921, 0.005935},{
      1.811744, 0.055267, 0.005935},{1.811052, 0.054764, 0.004934}}],
    Polygon[{{1.810901, 0.056921, 0.005935},{1.811854, 0.057231, 0.006791},{
      1.812555, 0.055855, 0.006791},{1.811744, 0.055267, 0.005935}}],
    Polygon[{{1.811854, 0.057231, 0.006791},{1.812922, 0.057578, 0.007479},{
      1.813463, 0.056515, 0.007479},{1.812555, 0.055855, 0.006791}}],
    Polygon[{{1.812922, 0.057578, 0.007479},{1.814079, 0.057954, 0.007983},{
      1.814448, 0.057231, 0.007983},{1.813463, 0.056515, 0.007479}}],
    Polygon[{{1.814079, 0.057954, 0.007983},{1.815297, 0.058349, 0.008290},{
      1.815484, 0.057983, 0.008290},{1.814448, 0.057231, 0.007983}}],
    Polygon[{{1.815484, 0.057983, -0.008290},{1.814448, 0.057231, -0.007983},{
      1.815022, 0.056657, -0.007983},{1.815774, 0.057693, -0.008290}}],
    Polygon[{{1.814448, 0.057231, -0.007983},{1.813463, 0.056515, -0.007479},{
      1.814306, 0.055672, -0.007479},{1.815022, 0.056657, -0.007983}}],
    Polygon[{{1.813463, 0.056515, -0.007479},{1.812555, 0.055855, -0.006791},{
      1.813646, 0.054764, -0.006791},{1.814306, 0.055672, -0.007479}}],
    Polygon[{{1.812555, 0.055855, -0.006791},{1.811744, 0.055267, -0.005935},{
      1.813058, 0.053954, -0.005935},{1.813646, 0.054764, -0.006791}}],
    Polygon[{{1.811744, 0.055267, -0.005935},{1.811052, 0.054764, -0.004934},{
      1.812555, 0.053261, -0.004934},{1.813058, 0.053954, -0.005935}}],
    Polygon[{{1.811052, 0.054764, -0.004934},{1.810496, 0.054359, -0.003811},{
      1.812150, 0.052705, -0.003811},{1.812555, 0.053261, -0.004934}}],
    Polygon[{{1.810496, 0.054359, -0.003811},{1.810088, 0.054063, -0.002594},{
      1.811854, 0.052297, -0.002594},{1.812150, 0.052705, -0.003811}}],
    Polygon[{{1.810088, 0.054063, -0.002594},{1.809839, 0.053882, -0.001313},{
      1.811673, 0.052048, -0.001313},{1.811854, 0.052297, -0.002594}}],
    Polygon[{{1.809839, 0.053882, -0.001313},{1.809756, 0.053822, 0.000000},{
      1.811612, 0.051965, 0.000000},{1.811673, 0.052048, -0.001313}}],
    Polygon[{{1.809756, 0.053822, 0.000000},{1.809839, 0.053882, 0.001313},{
      1.811673, 0.052048, 0.001313},{1.811612, 0.051965, 0.000000}}],
    Polygon[{{1.809839, 0.053882, 0.001313},{1.810088, 0.054063, 0.002594},{
      1.811854, 0.052297, 0.002594},{1.811673, 0.052048, 0.001313}}],
    Polygon[{{1.810088, 0.054063, 0.002594},{1.810496, 0.054359, 0.003811},{
      1.812150, 0.052705, 0.003811},{1.811854, 0.052297, 0.002594}}],
    Polygon[{{1.810496, 0.054359, 0.003811},{1.811052, 0.054764, 0.004934},{
      1.812555, 0.053261, 0.004934},{1.812150, 0.052705, 0.003811}}],
    Polygon[{{1.811052, 0.054764, 0.004934},{1.811744, 0.055267, 0.005935},{
      1.813058, 0.053954, 0.005935},{1.812555, 0.053261, 0.004934}}],
    Polygon[{{1.811744, 0.055267, 0.005935},{1.812555, 0.055855, 0.006791},{
      1.813646, 0.054764, 0.006791},{1.813058, 0.053954, 0.005935}}],
    Polygon[{{1.812555, 0.055855, 0.006791},{1.813463, 0.056515, 0.007479},{
      1.814306, 0.055672, 0.007479},{1.813646, 0.054764, 0.006791}}],
    Polygon[{{1.813463, 0.056515, 0.007479},{1.814448, 0.057231, 0.007983},{
      1.815022, 0.056657, 0.007983},{1.814306, 0.055672, 0.007479}}],
    Polygon[{{1.814448, 0.057231, 0.007983},{1.815484, 0.057983, 0.008290},{
      1.815774, 0.057693, 0.008290},{1.815022, 0.056657, 0.007983}}],
    Polygon[{{1.815774, 0.057693, -0.008290},{1.815022, 0.056657, -0.007983},{
      1.815745, 0.056288, -0.007983},{1.816140, 0.057506, -0.008290}}],
    Polygon[{{1.815022, 0.056657, -0.007983},{1.814306, 0.055672, -0.007479},{
      1.815369, 0.055131, -0.007479},{1.815745, 0.056288, -0.007983}}],
    Polygon[{{1.814306, 0.055672, -0.007479},{1.813646, 0.054764, -0.006791},{
      1.815022, 0.054063, -0.006791},{1.815369, 0.055131, -0.007479}}],
    Polygon[{{1.813646, 0.054764, -0.006791},{1.813058, 0.053954, -0.005935},{
      1.814712, 0.053110, -0.005935},{1.815022, 0.054063, -0.006791}}],
    Polygon[{{1.813058, 0.053954, -0.005935},{1.812555, 0.053261, -0.004934},{
      1.814448, 0.052297, -0.004934},{1.814712, 0.053110, -0.005935}}],
    Polygon[{{1.812555, 0.053261, -0.004934},{1.812150, 0.052705, -0.003811},{
      1.814235, 0.051642, -0.003811},{1.814448, 0.052297, -0.004934}}],
    Polygon[{{1.812150, 0.052705, -0.003811},{1.811854, 0.052297, -0.002594},{
      1.814079, 0.051163, -0.002594},{1.814235, 0.051642, -0.003811}}],
    Polygon[{{1.811854, 0.052297, -0.002594},{1.811673, 0.052048, -0.001313},{
      1.813984, 0.050871, -0.001313},{1.814079, 0.051163, -0.002594}}],
    Polygon[{{1.811673, 0.052048, -0.001313},{1.811612, 0.051965, 0.000000},{
      1.813952, 0.050772, 0.000000},{1.813984, 0.050871, -0.001313}}],
    Polygon[{{1.811612, 0.051965, 0.000000},{1.811673, 0.052048, 0.001313},{
      1.813984, 0.050871, 0.001313},{1.813952, 0.050772, 0.000000}}],
    Polygon[{{1.811673, 0.052048, 0.001313},{1.811854, 0.052297, 0.002594},{
      1.814079, 0.051163, 0.002594},{1.813984, 0.050871, 0.001313}}],
    Polygon[{{1.811854, 0.052297, 0.002594},{1.812150, 0.052705, 0.003811},{
      1.814235, 0.051642, 0.003811},{1.814079, 0.051163, 0.002594}}],
    Polygon[{{1.812150, 0.052705, 0.003811},{1.812555, 0.053261, 0.004934},{
      1.814448, 0.052297, 0.004934},{1.814235, 0.051642, 0.003811}}],
    Polygon[{{1.812555, 0.053261, 0.004934},{1.813058, 0.053954, 0.005935},{
      1.814712, 0.053110, 0.005935},{1.814448, 0.052297, 0.004934}}],
    Polygon[{{1.813058, 0.053954, 0.005935},{1.813646, 0.054764, 0.006791},{
      1.815022, 0.054063, 0.006791},{1.814712, 0.053110, 0.005935}}],
    Polygon[{{1.813646, 0.054764, 0.006791},{1.814306, 0.055672, 0.007479},{
      1.815369, 0.055131, 0.007479},{1.815022, 0.054063, 0.006791}}],
    Polygon[{{1.814306, 0.055672, 0.007479},{1.815022, 0.056657, 0.007983},{
      1.815745, 0.056288, 0.007983},{1.815369, 0.055131, 0.007479}}],
    Polygon[{{1.815022, 0.056657, 0.007983},{1.815774, 0.057693, 0.008290},{
      1.816140, 0.057506, 0.008290},{1.815745, 0.056288, 0.007983}}],
    Polygon[{{1.816140, 0.057506, -0.008290},{1.815745, 0.056288, -0.007983},{
      1.816546, 0.056161, -0.007983},{1.816546, 0.057442, -0.008290}}],
    Polygon[{{1.815745, 0.056288, -0.007983},{1.815369, 0.055131, -0.007479},{
      1.816546, 0.054945, -0.007479},{1.816546, 0.056161, -0.007983}}],
    Polygon[{{1.815369, 0.055131, -0.007479},{1.815022, 0.054063, -0.006791},{
      1.816546, 0.053822, -0.006791},{1.816546, 0.054945, -0.007479}}],
    Polygon[{{1.815022, 0.054063, -0.006791},{1.814712, 0.053110, -0.005935},{
      1.816546, 0.052820, -0.005935},{1.816546, 0.053822, -0.006791}}],
    Polygon[{{1.814712, 0.053110, -0.005935},{1.814448, 0.052297, -0.004934},{
      1.816546, 0.051965, -0.004934},{1.816546, 0.052820, -0.005935}}],
    Polygon[{{1.814448, 0.052297, -0.004934},{1.814235, 0.051642, -0.003811},{
      1.816546, 0.051276, -0.003811},{1.816546, 0.051965, -0.004934}}],
    Polygon[{{1.814235, 0.051642, -0.003811},{1.814079, 0.051163, -0.002594},{
      1.816546, 0.050772, -0.002594},{1.816546, 0.051276, -0.003811}}],
    Polygon[{{1.814079, 0.051163, -0.002594},{1.813984, 0.050871, -0.001313},{
      1.816546, 0.050465, -0.001313},{1.816546, 0.050772, -0.002594}}],
    Polygon[{{1.813984, 0.050871, -0.001313},{1.813952, 0.050772, 0.000000},{
      1.816546, 0.050362, 0.000000},{1.816546, 0.050465, -0.001313}}],
    Polygon[{{1.813952, 0.050772, 0.000000},{1.813984, 0.050871, 0.001313},{
      1.816546, 0.050465, 0.001313},{1.816546, 0.050362, 0.000000}}],
    Polygon[{{1.813984, 0.050871, 0.001313},{1.814079, 0.051163, 0.002594},{
      1.816546, 0.050772, 0.002594},{1.816546, 0.050465, 0.001313}}],
    Polygon[{{1.814079, 0.051163, 0.002594},{1.814235, 0.051642, 0.003811},{
      1.816546, 0.051276, 0.003811},{1.816546, 0.050772, 0.002594}}],
    Polygon[{{1.814235, 0.051642, 0.003811},{1.814448, 0.052297, 0.004934},{
      1.816546, 0.051965, 0.004934},{1.816546, 0.051276, 0.003811}}],
    Polygon[{{1.814448, 0.052297, 0.004934},{1.814712, 0.053110, 0.005935},{
      1.816546, 0.052820, 0.005935},{1.816546, 0.051965, 0.004934}}],
    Polygon[{{1.814712, 0.053110, 0.005935},{1.815022, 0.054063, 0.006791},{
      1.816546, 0.053822, 0.006791},{1.816546, 0.052820, 0.005935}}],
    Polygon[{{1.815022, 0.054063, 0.006791},{1.815369, 0.055131, 0.007479},{
      1.816546, 0.054945, 0.007479},{1.816546, 0.053822, 0.006791}}],
    Polygon[{{1.815369, 0.055131, 0.007479},{1.815745, 0.056288, 0.007983},{
      1.816546, 0.056161, 0.007983},{1.816546, 0.054945, 0.007479}}],
    Polygon[{{1.815745, 0.056288, 0.007983},{1.816140, 0.057506, 0.008290},{
      1.816546, 0.057442, 0.008290},{1.816546, 0.056161, 0.007983}}],
    Polygon[{{1.816546, 0.057442, -0.008290},{1.816546, 0.056161, -0.007983},{
      1.817348, 0.056288, -0.007983},{1.816952, 0.057506, -0.008290}}],
    Polygon[{{1.816546, 0.056161, -0.007983},{1.816546, 0.054945, -0.007479},{
      1.817724, 0.055131, -0.007479},{1.817348, 0.056288, -0.007983}}],
    Polygon[{{1.816546, 0.054945, -0.007479},{1.816546, 0.053822, -0.006791},{
      1.818071, 0.054063, -0.006791},{1.817724, 0.055131, -0.007479}}],
    Polygon[{{1.816546, 0.053822, -0.006791},{1.816546, 0.052820, -0.005935},{
      1.818380, 0.053110, -0.005935},{1.818071, 0.054063, -0.006791}}],
    Polygon[{{1.816546, 0.052820, -0.005935},{1.816546, 0.051965, -0.004934},{
      1.818645, 0.052297, -0.004934},{1.818380, 0.053110, -0.005935}}],
    Polygon[{{1.816546, 0.051965, -0.004934},{1.816546, 0.051276, -0.003811},{
      1.818857, 0.051642, -0.003811},{1.818645, 0.052297, -0.004934}}],
    Polygon[{{1.816546, 0.051276, -0.003811},{1.816546, 0.050772, -0.002594},{
      1.819013, 0.051163, -0.002594},{1.818857, 0.051642, -0.003811}}],
    Polygon[{{1.816546, 0.050772, -0.002594},{1.816546, 0.050465, -0.001313},{
      1.819108, 0.050871, -0.001313},{1.819013, 0.051163, -0.002594}}],
    Polygon[{{1.816546, 0.050465, -0.001313},{1.816546, 0.050362, 0.000000},{
      1.819140, 0.050772, 0.000000},{1.819108, 0.050871, -0.001313}}],
    Polygon[{{1.816546, 0.050362, 0.000000},{1.816546, 0.050465, 0.001313},{
      1.819108, 0.050871, 0.001313},{1.819140, 0.050772, 0.000000}}],
    Polygon[{{1.816546, 0.050465, 0.001313},{1.816546, 0.050772, 0.002594},{
      1.819013, 0.051163, 0.002594},{1.819108, 0.050871, 0.001313}}],
    Polygon[{{1.816546, 0.050772, 0.002594},{1.816546, 0.051276, 0.003811},{
      1.818857, 0.051642, 0.003811},{1.819013, 0.051163, 0.002594}}],
    Polygon[{{1.816546, 0.051276, 0.003811},{1.816546, 0.051965, 0.004934},{
      1.818645, 0.052297, 0.004934},{1.818857, 0.051642, 0.003811}}],
    Polygon[{{1.816546, 0.051965, 0.004934},{1.816546, 0.052820, 0.005935},{
      1.818380, 0.053110, 0.005935},{1.818645, 0.052297, 0.004934}}],
    Polygon[{{1.816546, 0.052820, 0.005935},{1.816546, 0.053822, 0.006791},{
      1.818071, 0.054063, 0.006791},{1.818380, 0.053110, 0.005935}}],
    Polygon[{{1.816546, 0.053822, 0.006791},{1.816546, 0.054945, 0.007479},{
      1.817724, 0.055131, 0.007479},{1.818071, 0.054063, 0.006791}}],
    Polygon[{{1.816546, 0.054945, 0.007479},{1.816546, 0.056161, 0.007983},{
      1.817348, 0.056288, 0.007983},{1.817724, 0.055131, 0.007479}}],
    Polygon[{{1.816546, 0.056161, 0.007983},{1.816546, 0.057442, 0.008290},{
      1.816952, 0.057506, 0.008290},{1.817348, 0.056288, 0.007983}}],
    Polygon[{{1.816952, 0.057506, -0.008290},{1.817348, 0.056288, -0.007983},{
      1.818071, 0.056657, -0.007983},{1.817318, 0.057693, -0.008290}}],
    Polygon[{{1.817348, 0.056288, -0.007983},{1.817724, 0.055131, -0.007479},{
      1.818786, 0.055672, -0.007479},{1.818071, 0.056657, -0.007983}}],
    Polygon[{{1.817724, 0.055131, -0.007479},{1.818071, 0.054063, -0.006791},{
      1.819446, 0.054764, -0.006791},{1.818786, 0.055672, -0.007479}}],
    Polygon[{{1.818071, 0.054063, -0.006791},{1.818380, 0.053110, -0.005935},{
      1.820035, 0.053954, -0.005935},{1.819446, 0.054764, -0.006791}}],
    Polygon[{{1.818380, 0.053110, -0.005935},{1.818645, 0.052297, -0.004934},{
      1.820538, 0.053261, -0.004934},{1.820035, 0.053954, -0.005935}}],
    Polygon[{{1.818645, 0.052297, -0.004934},{1.818857, 0.051642, -0.003811},{
      1.820942, 0.052705, -0.003811},{1.820538, 0.053261, -0.004934}}],
    Polygon[{{1.818857, 0.051642, -0.003811},{1.819013, 0.051163, -0.002594},{
      1.821238, 0.052297, -0.002594},{1.820942, 0.052705, -0.003811}}],
    Polygon[{{1.819013, 0.051163, -0.002594},{1.819108, 0.050871, -0.001313},{
      1.821419, 0.052048, -0.001313},{1.821238, 0.052297, -0.002594}}],
    Polygon[{{1.819108, 0.050871, -0.001313},{1.819140, 0.050772, 0.000000},{
      1.821480, 0.051965, 0.000000},{1.821419, 0.052048, -0.001313}}],
    Polygon[{{1.819140, 0.050772, 0.000000},{1.819108, 0.050871, 0.001313},{
      1.821419, 0.052048, 0.001313},{1.821480, 0.051965, 0.000000}}],
    Polygon[{{1.819108, 0.050871, 0.001313},{1.819013, 0.051163, 0.002594},{
      1.821238, 0.052297, 0.002594},{1.821419, 0.052048, 0.001313}}],
    Polygon[{{1.819013, 0.051163, 0.002594},{1.818857, 0.051642, 0.003811},{
      1.820942, 0.052705, 0.003811},{1.821238, 0.052297, 0.002594}}],
    Polygon[{{1.818857, 0.051642, 0.003811},{1.818645, 0.052297, 0.004934},{
      1.820538, 0.053261, 0.004934},{1.820942, 0.052705, 0.003811}}],
    Polygon[{{1.818645, 0.052297, 0.004934},{1.818380, 0.053110, 0.005935},{
      1.820035, 0.053954, 0.005935},{1.820538, 0.053261, 0.004934}}],
    Polygon[{{1.818380, 0.053110, 0.005935},{1.818071, 0.054063, 0.006791},{
      1.819446, 0.054764, 0.006791},{1.820035, 0.053954, 0.005935}}],
    Polygon[{{1.818071, 0.054063, 0.006791},{1.817724, 0.055131, 0.007479},{
      1.818786, 0.055672, 0.007479},{1.819446, 0.054764, 0.006791}}],
    Polygon[{{1.817724, 0.055131, 0.007479},{1.817348, 0.056288, 0.007983},{
      1.818071, 0.056657, 0.007983},{1.818786, 0.055672, 0.007479}}],
    Polygon[{{1.817348, 0.056288, 0.007983},{1.816952, 0.057506, 0.008290},{
      1.817318, 0.057693, 0.008290},{1.818071, 0.056657, 0.007983}}],
    Polygon[{{1.817318, 0.057693, -0.008290},{1.818071, 0.056657, -0.007983},{
      1.818645, 0.057231, -0.007983},{1.817608, 0.057983, -0.008290}}],
    Polygon[{{1.818071, 0.056657, -0.007983},{1.818786, 0.055672, -0.007479},{
      1.819629, 0.056515, -0.007479},{1.818645, 0.057231, -0.007983}}],
    Polygon[{{1.818786, 0.055672, -0.007479},{1.819446, 0.054764, -0.006791},{
      1.820538, 0.055855, -0.006791},{1.819629, 0.056515, -0.007479}}],
    Polygon[{{1.819446, 0.054764, -0.006791},{1.820035, 0.053954, -0.005935},{
      1.821348, 0.055267, -0.005935},{1.820538, 0.055855, -0.006791}}],
    Polygon[{{1.820035, 0.053954, -0.005935},{1.820538, 0.053261, -0.004934},{
      1.822040, 0.054764, -0.004934},{1.821348, 0.055267, -0.005935}}],
    Polygon[{{1.820538, 0.053261, -0.004934},{1.820942, 0.052705, -0.003811},{
      1.822597, 0.054359, -0.003811},{1.822040, 0.054764, -0.004934}}],
    Polygon[{{1.820942, 0.052705, -0.003811},{1.821238, 0.052297, -0.002594},{
      1.823004, 0.054063, -0.002594},{1.822597, 0.054359, -0.003811}}],
    Polygon[{{1.821238, 0.052297, -0.002594},{1.821419, 0.052048, -0.001313},{
      1.823253, 0.053882, -0.001313},{1.823004, 0.054063, -0.002594}}],
    Polygon[{{1.821419, 0.052048, -0.001313},{1.821480, 0.051965, 0.000000},{
      1.823337, 0.053822, 0.000000},{1.823253, 0.053882, -0.001313}}],
    Polygon[{{1.821480, 0.051965, 0.000000},{1.821419, 0.052048, 0.001313},{
      1.823253, 0.053882, 0.001313},{1.823337, 0.053822, 0.000000}}],
    Polygon[{{1.821419, 0.052048, 0.001313},{1.821238, 0.052297, 0.002594},{
      1.823004, 0.054063, 0.002594},{1.823253, 0.053882, 0.001313}}],
    Polygon[{{1.821238, 0.052297, 0.002594},{1.820942, 0.052705, 0.003811},{
      1.822597, 0.054359, 0.003811},{1.823004, 0.054063, 0.002594}}],
    Polygon[{{1.820942, 0.052705, 0.003811},{1.820538, 0.053261, 0.004934},{
      1.822040, 0.054764, 0.004934},{1.822597, 0.054359, 0.003811}}],
    Polygon[{{1.820538, 0.053261, 0.004934},{1.820035, 0.053954, 0.005935},{
      1.821348, 0.055267, 0.005935},{1.822040, 0.054764, 0.004934}}],
    Polygon[{{1.820035, 0.053954, 0.005935},{1.819446, 0.054764, 0.006791},{
      1.820538, 0.055855, 0.006791},{1.821348, 0.055267, 0.005935}}],
    Polygon[{{1.819446, 0.054764, 0.006791},{1.818786, 0.055672, 0.007479},{
      1.819629, 0.056515, 0.007479},{1.820538, 0.055855, 0.006791}}],
    Polygon[{{1.818786, 0.055672, 0.007479},{1.818071, 0.056657, 0.007983},{
      1.818645, 0.057231, 0.007983},{1.819629, 0.056515, 0.007479}}],
    Polygon[{{1.818071, 0.056657, 0.007983},{1.817318, 0.057693, 0.008290},{
      1.817608, 0.057983, 0.008290},{1.818645, 0.057231, 0.007983}}],
    Polygon[{{1.817608, 0.057983, -0.008290},{1.818645, 0.057231, -0.007983},{
      1.819013, 0.057954, -0.007983},{1.817795, 0.058349, -0.008290}}],
    Polygon[{{1.818645, 0.057231, -0.007983},{1.819629, 0.056515, -0.007479},{
      1.820170, 0.057578, -0.007479},{1.819013, 0.057954, -0.007983}}],
    Polygon[{{1.819629, 0.056515, -0.007479},{1.820538, 0.055855, -0.006791},{
      1.821238, 0.057231, -0.006791},{1.820170, 0.057578, -0.007479}}],
    Polygon[{{1.820538, 0.055855, -0.006791},{1.821348, 0.055267, -0.005935},{
      1.822191, 0.056921, -0.005935},{1.821238, 0.057231, -0.006791}}],
    Polygon[{{1.821348, 0.055267, -0.005935},{1.822040, 0.054764, -0.004934},{
      1.823004, 0.056657, -0.004934},{1.822191, 0.056921, -0.005935}}],
    Polygon[{{1.822040, 0.054764, -0.004934},{1.822597, 0.054359, -0.003811},{
      1.823659, 0.056444, -0.003811},{1.823004, 0.056657, -0.004934}}],
    Polygon[{{1.822597, 0.054359, -0.003811},{1.823004, 0.054063, -0.002594},{
      1.824138, 0.056288, -0.002594},{1.823659, 0.056444, -0.003811}}],
    Polygon[{{1.823004, 0.054063, -0.002594},{1.823253, 0.053882, -0.001313},{
      1.824431, 0.056193, -0.001313},{1.824138, 0.056288, -0.002594}}],
    Polygon[{{1.823253, 0.053882, -0.001313},{1.823337, 0.053822, 0.000000},{
      1.824529, 0.056161, 0.000000},{1.824431, 0.056193, -0.001313}}],
    Polygon[{{1.823337, 0.053822, 0.000000},{1.823253, 0.053882, 0.001313},{
      1.824431, 0.056193, 0.001313},{1.824529, 0.056161, 0.000000}}],
    Polygon[{{1.823253, 0.053882, 0.001313},{1.823004, 0.054063, 0.002594},{
      1.824138, 0.056288, 0.002594},{1.824431, 0.056193, 0.001313}}],
    Polygon[{{1.823004, 0.054063, 0.002594},{1.822597, 0.054359, 0.003811},{
      1.823659, 0.056444, 0.003811},{1.824138, 0.056288, 0.002594}}],
    Polygon[{{1.822597, 0.054359, 0.003811},{1.822040, 0.054764, 0.004934},{
      1.823004, 0.056657, 0.004934},{1.823659, 0.056444, 0.003811}}],
    Polygon[{{1.822040, 0.054764, 0.004934},{1.821348, 0.055267, 0.005935},{
      1.822191, 0.056921, 0.005935},{1.823004, 0.056657, 0.004934}}],
    Polygon[{{1.821348, 0.055267, 0.005935},{1.820538, 0.055855, 0.006791},{
      1.821238, 0.057231, 0.006791},{1.822191, 0.056921, 0.005935}}],
    Polygon[{{1.820538, 0.055855, 0.006791},{1.819629, 0.056515, 0.007479},{
      1.820170, 0.057578, 0.007479},{1.821238, 0.057231, 0.006791}}],
    Polygon[{{1.819629, 0.056515, 0.007479},{1.818645, 0.057231, 0.007983},{
      1.819013, 0.057954, 0.007983},{1.820170, 0.057578, 0.007479}}],
    Polygon[{{1.818645, 0.057231, 0.007983},{1.817608, 0.057983, 0.008290},{
      1.817795, 0.058349, 0.008290},{1.819013, 0.057954, 0.007983}}],
    Polygon[{{1.817795, 0.058349, -0.008290},{1.819013, 0.057954, -0.007983},{
      1.819140, 0.058755, -0.007983},{1.817859, 0.058755, -0.008290}}],
    Polygon[{{1.819013, 0.057954, -0.007983},{1.820170, 0.057578, -0.007479},{
      1.820357, 0.058755, -0.007479},{1.819140, 0.058755, -0.007983}}],
    Polygon[{{1.820170, 0.057578, -0.007479},{1.821238, 0.057231, -0.006791},{
      1.821480, 0.058755, -0.006791},{1.820357, 0.058755, -0.007479}}],
    Polygon[{{1.821238, 0.057231, -0.006791},{1.822191, 0.056921, -0.005935},{
      1.822481, 0.058755, -0.005935},{1.821480, 0.058755, -0.006791}}],
    Polygon[{{1.822191, 0.056921, -0.005935},{1.823004, 0.056657, -0.004934},{
      1.823337, 0.058755, -0.004934},{1.822481, 0.058755, -0.005935}}],
    Polygon[{{1.823004, 0.056657, -0.004934},{1.823659, 0.056444, -0.003811},{
      1.824025, 0.058755, -0.003811},{1.823337, 0.058755, -0.004934}}],
    Polygon[{{1.823659, 0.056444, -0.003811},{1.824138, 0.056288, -0.002594},{
      1.824529, 0.058755, -0.002594},{1.824025, 0.058755, -0.003811}}],
    Polygon[{{1.824138, 0.056288, -0.002594},{1.824431, 0.056193, -0.001313},{
      1.824836, 0.058755, -0.001313},{1.824529, 0.058755, -0.002594}}],
    Polygon[{{1.824431, 0.056193, -0.001313},{1.824529, 0.056161, 0.000000},{
      1.824940, 0.058755, 0.000000},{1.824836, 0.058755, -0.001313}}],
    Polygon[{{1.824529, 0.056161, 0.000000},{1.824431, 0.056193, 0.001313},{
      1.824836, 0.058755, 0.001313},{1.824940, 0.058755, 0.000000}}],
    Polygon[{{1.824431, 0.056193, 0.001313},{1.824138, 0.056288, 0.002594},{
      1.824529, 0.058755, 0.002594},{1.824836, 0.058755, 0.001313}}],
    Polygon[{{1.824138, 0.056288, 0.002594},{1.823659, 0.056444, 0.003811},{
      1.824025, 0.058755, 0.003811},{1.824529, 0.058755, 0.002594}}],
    Polygon[{{1.823659, 0.056444, 0.003811},{1.823004, 0.056657, 0.004934},{
      1.823337, 0.058755, 0.004934},{1.824025, 0.058755, 0.003811}}],
    Polygon[{{1.823004, 0.056657, 0.004934},{1.822191, 0.056921, 0.005935},{
      1.822481, 0.058755, 0.005935},{1.823337, 0.058755, 0.004934}}],
    Polygon[{{1.822191, 0.056921, 0.005935},{1.821238, 0.057231, 0.006791},{
      1.821480, 0.058755, 0.006791},{1.822481, 0.058755, 0.005935}}],
    Polygon[{{1.821238, 0.057231, 0.006791},{1.820170, 0.057578, 0.007479},{
      1.820357, 0.058755, 0.007479},{1.821480, 0.058755, 0.006791}}],
    Polygon[{{1.820170, 0.057578, 0.007479},{1.819013, 0.057954, 0.007983},{
      1.819140, 0.058755, 0.007983},{1.820357, 0.058755, 0.007479}}],
    Polygon[{{1.819013, 0.057954, 0.007983},{1.817795, 0.058349, 0.008290},{
      1.817859, 0.058755, 0.008290},{1.819140, 0.058755, 0.007983}}],
    Polygon[{{1.885479, 0.153775, -0.025466},{1.889413, 0.153775, -0.024521},{
      1.889023, 0.156237, -0.024521},{1.885282, 0.155021, -0.025466}}],
    Polygon[{{1.889413, 0.153775, -0.024521},{1.893151, 0.153775, -0.022973},{
      1.892578, 0.157392, -0.022973},{1.889023, 0.156237, -0.024521}}],
    Polygon[{{1.893151, 0.153775, -0.022973},{1.896601, 0.153775, -0.020859},{
      1.895859, 0.158458, -0.020859},{1.892578, 0.157392, -0.022973}}],
    Polygon[{{1.896601, 0.153775, -0.020859},{1.899678, 0.153775, -0.018232},{
      1.898785, 0.159409, -0.018232},{1.895859, 0.158458, -0.020859}}],
    Polygon[{{1.899678, 0.153775, -0.018232},{1.902305, 0.153775, -0.015155},{
      1.901284, 0.160221, -0.015155},{1.898785, 0.159409, -0.018232}}],
    Polygon[{{1.902305, 0.153775, -0.015155},{1.904419, 0.153775, -0.011705},{
      1.903295, 0.160874, -0.011705},{1.901284, 0.160221, -0.015155}}],
    Polygon[{{1.904419, 0.153775, -0.011705},{1.905967, 0.153775, -0.007968},{
      1.904767, 0.161353, -0.007968},{1.903295, 0.160874, -0.011705}}],
    Polygon[{{1.905967, 0.153775, -0.007968},{1.906912, 0.153775, -0.004033},{
      1.905665, 0.161644, -0.004033},{1.904767, 0.161353, -0.007968}}],
    Polygon[{{1.906912, 0.153775, -0.004033},{1.907229, 0.153775, 0.000000},{
      1.905967, 0.161742, 0.000000},{1.905665, 0.161644, -0.004033}}],
    Polygon[{{1.907229, 0.153775, 0.000000},{1.906912, 0.153775, 0.004033},{
      1.905665, 0.161644, 0.004033},{1.905967, 0.161742, 0.000000}}],
    Polygon[{{1.906912, 0.153775, 0.004033},{1.905967, 0.153775, 0.007968},{
      1.904767, 0.161353, 0.007968},{1.905665, 0.161644, 0.004033}}],
    Polygon[{{1.905967, 0.153775, 0.007968},{1.904419, 0.153775, 0.011705},{
      1.903295, 0.160874, 0.011705},{1.904767, 0.161353, 0.007968}}],
    Polygon[{{1.904419, 0.153775, 0.011705},{1.902305, 0.153775, 0.015155},{
      1.901284, 0.160221, 0.015155},{1.903295, 0.160874, 0.011705}}],
    Polygon[{{1.902305, 0.153775, 0.015155},{1.899678, 0.153775, 0.018232},{
      1.898785, 0.159409, 0.018232},{1.901284, 0.160221, 0.015155}}],
    Polygon[{{1.899678, 0.153775, 0.018232},{1.896601, 0.153775, 0.020859},{
      1.895859, 0.158458, 0.020859},{1.898785, 0.159409, 0.018232}}],
    Polygon[{{1.896601, 0.153775, 0.020859},{1.893151, 0.153775, 0.022973},{
      1.892578, 0.157392, 0.022973},{1.895859, 0.158458, 0.020859}}],
    Polygon[{{1.893151, 0.153775, 0.022973},{1.889413, 0.153775, 0.024521},{
      1.889023, 0.156237, 0.024521},{1.892578, 0.157392, 0.022973}}],
    Polygon[{{1.889413, 0.153775, 0.024521},{1.885479, 0.153775, 0.025466},{
      1.885282, 0.155021, 0.025466},{1.889023, 0.156237, 0.024521}}],
    Polygon[{{1.885282, 0.155021, -0.025466},{1.889023, 0.156237, -0.024521},{
      1.887892, 0.158458, -0.024521},{1.884709, 0.156146, -0.025466}}],
    Polygon[{{1.889023, 0.156237, -0.024521},{1.892578, 0.157392, -0.022973},{
      1.890916, 0.160655, -0.022973},{1.887892, 0.158458, -0.024521}}],
    Polygon[{{1.892578, 0.157392, -0.022973},{1.895859, 0.158458, -0.020859},{
      1.893707, 0.162683, -0.020859},{1.890916, 0.160655, -0.022973}}],
    Polygon[{{1.895859, 0.158458, -0.020859},{1.898785, 0.159409, -0.018232},{
      1.896196, 0.164491, -0.018232},{1.893707, 0.162683, -0.020859}}],
    Polygon[{{1.898785, 0.159409, -0.018232},{1.901284, 0.160221, -0.015155},{
      1.898321, 0.166036, -0.015155},{1.896196, 0.164491, -0.018232}}],
    Polygon[{{1.901284, 0.160221, -0.015155},{1.903295, 0.160874, -0.011705},{
      1.900032, 0.167278, -0.011705},{1.898321, 0.166036, -0.015155}}],
    Polygon[{{1.903295, 0.160874, -0.011705},{1.904767, 0.161353, -0.007968},{
      1.901284, 0.168188, -0.007968},{1.900032, 0.167278, -0.011705}}],
    Polygon[{{1.904767, 0.161353, -0.007968},{1.905665, 0.161644, -0.004033},{
      1.902048, 0.168743, -0.004033},{1.901284, 0.168188, -0.007968}}],
    Polygon[{{1.905665, 0.161644, -0.004033},{1.905967, 0.161742, 0.000000},{
      1.902305, 0.168930, 0.000000},{1.902048, 0.168743, -0.004033}}],
    Polygon[{{1.905967, 0.161742, 0.000000},{1.905665, 0.161644, 0.004033},{
      1.902048, 0.168743, 0.004033},{1.902305, 0.168930, 0.000000}}],
    Polygon[{{1.905665, 0.161644, 0.004033},{1.904767, 0.161353, 0.007968},{
      1.901284, 0.168188, 0.007968},{1.902048, 0.168743, 0.004033}}],
    Polygon[{{1.904767, 0.161353, 0.007968},{1.903295, 0.160874, 0.011705},{
      1.900032, 0.167278, 0.011705},{1.901284, 0.168188, 0.007968}}],
    Polygon[{{1.903295, 0.160874, 0.011705},{1.901284, 0.160221, 0.015155},{
      1.898321, 0.166036, 0.015155},{1.900032, 0.167278, 0.011705}}],
    Polygon[{{1.901284, 0.160221, 0.015155},{1.898785, 0.159409, 0.018232},{
      1.896196, 0.164491, 0.018232},{1.898321, 0.166036, 0.015155}}],
    Polygon[{{1.898785, 0.159409, 0.018232},{1.895859, 0.158458, 0.020859},{
      1.893707, 0.162683, 0.020859},{1.896196, 0.164491, 0.018232}}],
    Polygon[{{1.895859, 0.158458, 0.020859},{1.892578, 0.157392, 0.022973},{
      1.890916, 0.160655, 0.022973},{1.893707, 0.162683, 0.020859}}],
    Polygon[{{1.892578, 0.157392, 0.022973},{1.889023, 0.156237, 0.024521},{
      1.887892, 0.158458, 0.024521},{1.890916, 0.160655, 0.022973}}],
    Polygon[{{1.889023, 0.156237, 0.024521},{1.885282, 0.155021, 0.025466},{
      1.884709, 0.156146, 0.025466},{1.887892, 0.158458, 0.024521}}],
    Polygon[{{1.884709, 0.156146, -0.025466},{1.887892, 0.158458, -0.024521},{
      1.886129, 0.160221, -0.024521},{1.883817, 0.157038, -0.025466}}],
    Polygon[{{1.887892, 0.158458, -0.024521},{1.890916, 0.160655, -0.022973},{
      1.888326, 0.163245, -0.022973},{1.886129, 0.160221, -0.024521}}],
    Polygon[{{1.890916, 0.160655, -0.022973},{1.893707, 0.162683, -0.020859},{
      1.890354, 0.166036, -0.020859},{1.888326, 0.163245, -0.022973}}],
    Polygon[{{1.893707, 0.162683, -0.020859},{1.896196, 0.164491, -0.018232},{
      1.892162, 0.168525, -0.018232},{1.890354, 0.166036, -0.020859}}],
    Polygon[{{1.896196, 0.164491, -0.018232},{1.898321, 0.166036, -0.015155},{
      1.893707, 0.170650, -0.015155},{1.892162, 0.168525, -0.018232}}],
    Polygon[{{1.898321, 0.166036, -0.015155},{1.900032, 0.167278, -0.011705},{
      1.894949, 0.172361, -0.011705},{1.893707, 0.170650, -0.015155}}],
    Polygon[{{1.900032, 0.167278, -0.011705},{1.901284, 0.168188, -0.007968},{
      1.895859, 0.173613, -0.007968},{1.894949, 0.172361, -0.011705}}],
    Polygon[{{1.901284, 0.168188, -0.007968},{1.902048, 0.168743, -0.004033},{
      1.896414, 0.174377, -0.004033},{1.895859, 0.173613, -0.007968}}],
    Polygon[{{1.902048, 0.168743, -0.004033},{1.902305, 0.168930, 0.000000},{
      1.896601, 0.174634, 0.000000},{1.896414, 0.174377, -0.004033}}],
    Polygon[{{1.902305, 0.168930, 0.000000},{1.902048, 0.168743, 0.004033},{
      1.896414, 0.174377, 0.004033},{1.896601, 0.174634, 0.000000}}],
    Polygon[{{1.902048, 0.168743, 0.004033},{1.901284, 0.168188, 0.007968},{
      1.895859, 0.173613, 0.007968},{1.896414, 0.174377, 0.004033}}],
    Polygon[{{1.901284, 0.168188, 0.007968},{1.900032, 0.167278, 0.011705},{
      1.894949, 0.172361, 0.011705},{1.895859, 0.173613, 0.007968}}],
    Polygon[{{1.900032, 0.167278, 0.011705},{1.898321, 0.166036, 0.015155},{
      1.893707, 0.170650, 0.015155},{1.894949, 0.172361, 0.011705}}],
    Polygon[{{1.898321, 0.166036, 0.015155},{1.896196, 0.164491, 0.018232},{
      1.892162, 0.168525, 0.018232},{1.893707, 0.170650, 0.015155}}],
    Polygon[{{1.896196, 0.164491, 0.018232},{1.893707, 0.162683, 0.020859},{
      1.890354, 0.166036, 0.020859},{1.892162, 0.168525, 0.018232}}],
    Polygon[{{1.893707, 0.162683, 0.020859},{1.890916, 0.160655, 0.022973},{
      1.888326, 0.163245, 0.022973},{1.890354, 0.166036, 0.020859}}],
    Polygon[{{1.890916, 0.160655, 0.022973},{1.887892, 0.158458, 0.024521},{
      1.886129, 0.160221, 0.024521},{1.888326, 0.163245, 0.022973}}],
    Polygon[{{1.887892, 0.158458, 0.024521},{1.884709, 0.156146, 0.025466},{
      1.883817, 0.157038, 0.025466},{1.886129, 0.160221, 0.024521}}],
    Polygon[{{1.883817, 0.157038, -0.025466},{1.886129, 0.160221, -0.024521},{
      1.883908, 0.161353, -0.024521},{1.882692, 0.157611, -0.025466}}],
    Polygon[{{1.886129, 0.160221, -0.024521},{1.888326, 0.163245, -0.022973},{
      1.885063, 0.164907, -0.022973},{1.883908, 0.161353, -0.024521}}],
    Polygon[{{1.888326, 0.163245, -0.022973},{1.890354, 0.166036, -0.020859},{
      1.886129, 0.168188, -0.020859},{1.885063, 0.164907, -0.022973}}],
    Polygon[{{1.890354, 0.166036, -0.020859},{1.892162, 0.168525, -0.018232},{
      1.887080, 0.171114, -0.018232},{1.886129, 0.168188, -0.020859}}],
    Polygon[{{1.892162, 0.168525, -0.018232},{1.893707, 0.170650, -0.015155},{
      1.887892, 0.173613, -0.015155},{1.887080, 0.171114, -0.018232}}],
    Polygon[{{1.893707, 0.170650, -0.015155},{1.894949, 0.172361, -0.011705},{
      1.888545, 0.175624, -0.011705},{1.887892, 0.173613, -0.015155}}],
    Polygon[{{1.894949, 0.172361, -0.011705},{1.895859, 0.173613, -0.007968},{
      1.889023, 0.177096, -0.007968},{1.888545, 0.175624, -0.011705}}],
    Polygon[{{1.895859, 0.173613, -0.007968},{1.896414, 0.174377, -0.004033},{
      1.889315, 0.177995, -0.004033},{1.889023, 0.177096, -0.007968}}],
    Polygon[{{1.896414, 0.174377, -0.004033},{1.896601, 0.174634, 0.000000},{
      1.889413, 0.178296, 0.000000},{1.889315, 0.177995, -0.004033}}],
    Polygon[{{1.896601, 0.174634, 0.000000},{1.896414, 0.174377, 0.004033},{
      1.889315, 0.177995, 0.004033},{1.889413, 0.178296, 0.000000}}],
    Polygon[{{1.896414, 0.174377, 0.004033},{1.895859, 0.173613, 0.007968},{
      1.889023, 0.177096, 0.007968},{1.889315, 0.177995, 0.004033}}],
    Polygon[{{1.895859, 0.173613, 0.007968},{1.894949, 0.172361, 0.011705},{
      1.888545, 0.175624, 0.011705},{1.889023, 0.177096, 0.007968}}],
    Polygon[{{1.894949, 0.172361, 0.011705},{1.893707, 0.170650, 0.015155},{
      1.887892, 0.173613, 0.015155},{1.888545, 0.175624, 0.011705}}],
    Polygon[{{1.893707, 0.170650, 0.015155},{1.892162, 0.168525, 0.018232},{
      1.887080, 0.171114, 0.018232},{1.887892, 0.173613, 0.015155}}],
    Polygon[{{1.892162, 0.168525, 0.018232},{1.890354, 0.166036, 0.020859},{
      1.886129, 0.168188, 0.020859},{1.887080, 0.171114, 0.018232}}],
    Polygon[{{1.890354, 0.166036, 0.020859},{1.888326, 0.163245, 0.022973},{
      1.885063, 0.164907, 0.022973},{1.886129, 0.168188, 0.020859}}],
    Polygon[{{1.888326, 0.163245, 0.022973},{1.886129, 0.160221, 0.024521},{
      1.883908, 0.161353, 0.024521},{1.885063, 0.164907, 0.022973}}],
    Polygon[{{1.886129, 0.160221, 0.024521},{1.883817, 0.157038, 0.025466},{
      1.882692, 0.157611, 0.025466},{1.883908, 0.161353, 0.024521}}],
    Polygon[{{1.882692, 0.157611, -0.025466},{1.883908, 0.161353, -0.024521},{
      1.881446, 0.161742, -0.024521},{1.881446, 0.157808, -0.025466}}],
    Polygon[{{1.883908, 0.161353, -0.024521},{1.885063, 0.164907, -0.022973},{
      1.881446, 0.165480, -0.022973},{1.881446, 0.161742, -0.024521}}],
    Polygon[{{1.885063, 0.164907, -0.022973},{1.886129, 0.168188, -0.020859},{
      1.881446, 0.168930, -0.020859},{1.881446, 0.165480, -0.022973}}],
    Polygon[{{1.886129, 0.168188, -0.020859},{1.887080, 0.171114, -0.018232},{
      1.881446, 0.172007, -0.018232},{1.881446, 0.168930, -0.020859}}],
    Polygon[{{1.887080, 0.171114, -0.018232},{1.887892, 0.173613, -0.015155},{
      1.881446, 0.174634, -0.015155},{1.881446, 0.172007, -0.018232}}],
    Polygon[{{1.887892, 0.173613, -0.015155},{1.888545, 0.175624, -0.011705},{
      1.881446, 0.176748, -0.011705},{1.881446, 0.174634, -0.015155}}],
    Polygon[{{1.888545, 0.175624, -0.011705},{1.889023, 0.177096, -0.007968},{
      1.881446, 0.178296, -0.007968},{1.881446, 0.176748, -0.011705}}],
    Polygon[{{1.889023, 0.177096, -0.007968},{1.889315, 0.177995, -0.004033},{
      1.881446, 0.179241, -0.004033},{1.881446, 0.178296, -0.007968}}],
    Polygon[{{1.889315, 0.177995, -0.004033},{1.889413, 0.178296, 0.000000},{
      1.881446, 0.179558, 0.000000},{1.881446, 0.179241, -0.004033}}],
    Polygon[{{1.889413, 0.178296, 0.000000},{1.889315, 0.177995, 0.004033},{
      1.881446, 0.179241, 0.004033},{1.881446, 0.179558, 0.000000}}],
    Polygon[{{1.889315, 0.177995, 0.004033},{1.889023, 0.177096, 0.007968},{
      1.881446, 0.178296, 0.007968},{1.881446, 0.179241, 0.004033}}],
    Polygon[{{1.889023, 0.177096, 0.007968},{1.888545, 0.175624, 0.011705},{
      1.881446, 0.176748, 0.011705},{1.881446, 0.178296, 0.007968}}],
    Polygon[{{1.888545, 0.175624, 0.011705},{1.887892, 0.173613, 0.015155},{
      1.881446, 0.174634, 0.015155},{1.881446, 0.176748, 0.011705}}],
    Polygon[{{1.887892, 0.173613, 0.015155},{1.887080, 0.171114, 0.018232},{
      1.881446, 0.172007, 0.018232},{1.881446, 0.174634, 0.015155}}],
    Polygon[{{1.887080, 0.171114, 0.018232},{1.886129, 0.168188, 0.020859},{
      1.881446, 0.168930, 0.020859},{1.881446, 0.172007, 0.018232}}],
    Polygon[{{1.886129, 0.168188, 0.020859},{1.885063, 0.164907, 0.022973},{
      1.881446, 0.165480, 0.022973},{1.881446, 0.168930, 0.020859}}],
    Polygon[{{1.885063, 0.164907, 0.022973},{1.883908, 0.161353, 0.024521},{
      1.881446, 0.161742, 0.024521},{1.881446, 0.165480, 0.022973}}],
    Polygon[{{1.883908, 0.161353, 0.024521},{1.882692, 0.157611, 0.025466},{
      1.881446, 0.157808, 0.025466},{1.881446, 0.161742, 0.024521}}],
    Polygon[{{1.881446, 0.157808, -0.025466},{1.881446, 0.161742, -0.024521},{
      1.878984, 0.161353, -0.024521},{1.880199, 0.157611, -0.025466}}],
    Polygon[{{1.881446, 0.161742, -0.024521},{1.881446, 0.165480, -0.022973},{
      1.877829, 0.164907, -0.022973},{1.878984, 0.161353, -0.024521}}],
    Polygon[{{1.881446, 0.165480, -0.022973},{1.881446, 0.168930, -0.020859},{
      1.876763, 0.168188, -0.020859},{1.877829, 0.164907, -0.022973}}],
    Polygon[{{1.881446, 0.168930, -0.020859},{1.881446, 0.172007, -0.018232},{
      1.875812, 0.171114, -0.018232},{1.876763, 0.168188, -0.020859}}],
    Polygon[{{1.881446, 0.172007, -0.018232},{1.881446, 0.174634, -0.015155},{
      1.875000, 0.173613, -0.015155},{1.875812, 0.171114, -0.018232}}],
    Polygon[{{1.881446, 0.174634, -0.015155},{1.881446, 0.176748, -0.011705},{
      1.874347, 0.175624, -0.011705},{1.875000, 0.173613, -0.015155}}],
    Polygon[{{1.881446, 0.176748, -0.011705},{1.881446, 0.178296, -0.007968},{
      1.873868, 0.177096, -0.007968},{1.874347, 0.175624, -0.011705}}],
    Polygon[{{1.881446, 0.178296, -0.007968},{1.881446, 0.179241, -0.004033},{
      1.873576, 0.177995, -0.004033},{1.873868, 0.177096, -0.007968}}],
    Polygon[{{1.881446, 0.179241, -0.004033},{1.881446, 0.179558, 0.000000},{
      1.873478, 0.178296, 0.000000},{1.873576, 0.177995, -0.004033}}],
    Polygon[{{1.881446, 0.179558, 0.000000},{1.881446, 0.179241, 0.004033},{
      1.873576, 0.177995, 0.004033},{1.873478, 0.178296, 0.000000}}],
    Polygon[{{1.881446, 0.179241, 0.004033},{1.881446, 0.178296, 0.007968},{
      1.873868, 0.177096, 0.007968},{1.873576, 0.177995, 0.004033}}],
    Polygon[{{1.881446, 0.178296, 0.007968},{1.881446, 0.176748, 0.011705},{
      1.874347, 0.175624, 0.011705},{1.873868, 0.177096, 0.007968}}],
    Polygon[{{1.881446, 0.176748, 0.011705},{1.881446, 0.174634, 0.015155},{
      1.875000, 0.173613, 0.015155},{1.874347, 0.175624, 0.011705}}],
    Polygon[{{1.881446, 0.174634, 0.015155},{1.881446, 0.172007, 0.018232},{
      1.875812, 0.171114, 0.018232},{1.875000, 0.173613, 0.015155}}],
    Polygon[{{1.881446, 0.172007, 0.018232},{1.881446, 0.168930, 0.020859},{
      1.876763, 0.168188, 0.020859},{1.875812, 0.171114, 0.018232}}],
    Polygon[{{1.881446, 0.168930, 0.020859},{1.881446, 0.165480, 0.022973},{
      1.877829, 0.164907, 0.022973},{1.876763, 0.168188, 0.020859}}],
    Polygon[{{1.881446, 0.165480, 0.022973},{1.881446, 0.161742, 0.024521},{
      1.878984, 0.161353, 0.024521},{1.877829, 0.164907, 0.022973}}],
    Polygon[{{1.881446, 0.161742, 0.024521},{1.881446, 0.157808, 0.025466},{
      1.880199, 0.157611, 0.025466},{1.878984, 0.161353, 0.024521}}],
    Polygon[{{1.880199, 0.157611, -0.025466},{1.878984, 0.161353, -0.024521},{
      1.876763, 0.160221, -0.024521},{1.879075, 0.157038, -0.025466}}],
    Polygon[{{1.878984, 0.161353, -0.024521},{1.877829, 0.164907, -0.022973},{
      1.874566, 0.163245, -0.022973},{1.876763, 0.160221, -0.024521}}],
    Polygon[{{1.877829, 0.164907, -0.022973},{1.876763, 0.168188, -0.020859},{
      1.872538, 0.166036, -0.020859},{1.874566, 0.163245, -0.022973}}],
    Polygon[{{1.876763, 0.168188, -0.020859},{1.875812, 0.171114, -0.018232},{
      1.870730, 0.168525, -0.018232},{1.872538, 0.166036, -0.020859}}],
    Polygon[{{1.875812, 0.171114, -0.018232},{1.875000, 0.173613, -0.015155},{
      1.869185, 0.170650, -0.015155},{1.870730, 0.168525, -0.018232}}],
    Polygon[{{1.875000, 0.173613, -0.015155},{1.874347, 0.175624, -0.011705},{
      1.867943, 0.172361, -0.011705},{1.869185, 0.170650, -0.015155}}],
    Polygon[{{1.874347, 0.175624, -0.011705},{1.873868, 0.177096, -0.007968},{
      1.867033, 0.173613, -0.007968},{1.867943, 0.172361, -0.011705}}],
    Polygon[{{1.873868, 0.177096, -0.007968},{1.873576, 0.177995, -0.004033},{
      1.866477, 0.174377, -0.004033},{1.867033, 0.173613, -0.007968}}],
    Polygon[{{1.873576, 0.177995, -0.004033},{1.873478, 0.178296, 0.000000},{
      1.866291, 0.174634, 0.000000},{1.866477, 0.174377, -0.004033}}],
    Polygon[{{1.873478, 0.178296, 0.000000},{1.873576, 0.177995, 0.004033},{
      1.866477, 0.174377, 0.004033},{1.866291, 0.174634, 0.000000}}],
    Polygon[{{1.873576, 0.177995, 0.004033},{1.873868, 0.177096, 0.007968},{
      1.867033, 0.173613, 0.007968},{1.866477, 0.174377, 0.004033}}],
    Polygon[{{1.873868, 0.177096, 0.007968},{1.874347, 0.175624, 0.011705},{
      1.867943, 0.172361, 0.011705},{1.867033, 0.173613, 0.007968}}],
    Polygon[{{1.874347, 0.175624, 0.011705},{1.875000, 0.173613, 0.015155},{
      1.869185, 0.170650, 0.015155},{1.867943, 0.172361, 0.011705}}],
    Polygon[{{1.875000, 0.173613, 0.015155},{1.875812, 0.171114, 0.018232},{
      1.870730, 0.168525, 0.018232},{1.869185, 0.170650, 0.015155}}],
    Polygon[{{1.875812, 0.171114, 0.018232},{1.876763, 0.168188, 0.020859},{
      1.872538, 0.166036, 0.020859},{1.870730, 0.168525, 0.018232}}],
    Polygon[{{1.876763, 0.168188, 0.020859},{1.877829, 0.164907, 0.022973},{
      1.874566, 0.163245, 0.022973},{1.872538, 0.166036, 0.020859}}],
    Polygon[{{1.877829, 0.164907, 0.022973},{1.878984, 0.161353, 0.024521},{
      1.876763, 0.160221, 0.024521},{1.874566, 0.163245, 0.022973}}],
    Polygon[{{1.878984, 0.161353, 0.024521},{1.880199, 0.157611, 0.025466},{
      1.879075, 0.157038, 0.025466},{1.876763, 0.160221, 0.024521}}],
    Polygon[{{1.879075, 0.157038, -0.025466},{1.876763, 0.160221, -0.024521},{
      1.875000, 0.158458, -0.024521},{1.878183, 0.156146, -0.025466}}],
    Polygon[{{1.876763, 0.160221, -0.024521},{1.874566, 0.163245, -0.022973},{
      1.871976, 0.160655, -0.022973},{1.875000, 0.158458, -0.024521}}],
    Polygon[{{1.874566, 0.163245, -0.022973},{1.872538, 0.166036, -0.020859},{
      1.869185, 0.162683, -0.020859},{1.871976, 0.160655, -0.022973}}],
    Polygon[{{1.872538, 0.166036, -0.020859},{1.870730, 0.168525, -0.018232},{
      1.866696, 0.164491, -0.018232},{1.869185, 0.162683, -0.020859}}],
    Polygon[{{1.870730, 0.168525, -0.018232},{1.869185, 0.170650, -0.015155},{
      1.864570, 0.166036, -0.015155},{1.866696, 0.164491, -0.018232}}],
    Polygon[{{1.869185, 0.170650, -0.015155},{1.867943, 0.172361, -0.011705},{
      1.862860, 0.167278, -0.011705},{1.864570, 0.166036, -0.015155}}],
    Polygon[{{1.867943, 0.172361, -0.011705},{1.867033, 0.173613, -0.007968},{
      1.861608, 0.168188, -0.007968},{1.862860, 0.167278, -0.011705}}],
    Polygon[{{1.867033, 0.173613, -0.007968},{1.866477, 0.174377, -0.004033},{
      1.860843, 0.168743, -0.004033},{1.861608, 0.168188, -0.007968}}],
    Polygon[{{1.866477, 0.174377, -0.004033},{1.866291, 0.174634, 0.000000},{
      1.860587, 0.168930, 0.000000},{1.860843, 0.168743, -0.004033}}],
    Polygon[{{1.866291, 0.174634, 0.000000},{1.866477, 0.174377, 0.004033},{
      1.860843, 0.168743, 0.004033},{1.860587, 0.168930, 0.000000}}],
    Polygon[{{1.866477, 0.174377, 0.004033},{1.867033, 0.173613, 0.007968},{
      1.861608, 0.168188, 0.007968},{1.860843, 0.168743, 0.004033}}],
    Polygon[{{1.867033, 0.173613, 0.007968},{1.867943, 0.172361, 0.011705},{
      1.862860, 0.167278, 0.011705},{1.861608, 0.168188, 0.007968}}],
    Polygon[{{1.867943, 0.172361, 0.011705},{1.869185, 0.170650, 0.015155},{
      1.864570, 0.166036, 0.015155},{1.862860, 0.167278, 0.011705}}],
    Polygon[{{1.869185, 0.170650, 0.015155},{1.870730, 0.168525, 0.018232},{
      1.866696, 0.164491, 0.018232},{1.864570, 0.166036, 0.015155}}],
    Polygon[{{1.870730, 0.168525, 0.018232},{1.872538, 0.166036, 0.020859},{
      1.869185, 0.162683, 0.020859},{1.866696, 0.164491, 0.018232}}],
    Polygon[{{1.872538, 0.166036, 0.020859},{1.874566, 0.163245, 0.022973},{
      1.871976, 0.160655, 0.022973},{1.869185, 0.162683, 0.020859}}],
    Polygon[{{1.874566, 0.163245, 0.022973},{1.876763, 0.160221, 0.024521},{
      1.875000, 0.158458, 0.024521},{1.871976, 0.160655, 0.022973}}],
    Polygon[{{1.876763, 0.160221, 0.024521},{1.879075, 0.157038, 0.025466},{
      1.878183, 0.156146, 0.025466},{1.875000, 0.158458, 0.024521}}],
    Polygon[{{1.878183, 0.156146, -0.025466},{1.875000, 0.158458, -0.024521},{
      1.873868, 0.156237, -0.024521},{1.877610, 0.155021, -0.025466}}],
    Polygon[{{1.875000, 0.158458, -0.024521},{1.871976, 0.160655, -0.022973},{
      1.870313, 0.157392, -0.022973},{1.873868, 0.156237, -0.024521}}],
    Polygon[{{1.871976, 0.160655, -0.022973},{1.869185, 0.162683, -0.020859},{
      1.867033, 0.158458, -0.020859},{1.870313, 0.157392, -0.022973}}],
    Polygon[{{1.869185, 0.162683, -0.020859},{1.866696, 0.164491, -0.018232},{
      1.864107, 0.159409, -0.018232},{1.867033, 0.158458, -0.020859}}],
    Polygon[{{1.866696, 0.164491, -0.018232},{1.864570, 0.166036, -0.015155},{
      1.861608, 0.160221, -0.015155},{1.864107, 0.159409, -0.018232}}],
    Polygon[{{1.864570, 0.166036, -0.015155},{1.862860, 0.167278, -0.011705},{
      1.859597, 0.160874, -0.011705},{1.861608, 0.160221, -0.015155}}],
    Polygon[{{1.862860, 0.167278, -0.011705},{1.861608, 0.168188, -0.007968},{
      1.858124, 0.161353, -0.007968},{1.859597, 0.160874, -0.011705}}],
    Polygon[{{1.861608, 0.168188, -0.007968},{1.860843, 0.168743, -0.004033},{
      1.857226, 0.161644, -0.004033},{1.858124, 0.161353, -0.007968}}],
    Polygon[{{1.860843, 0.168743, -0.004033},{1.860587, 0.168930, 0.000000},{
      1.856924, 0.161742, 0.000000},{1.857226, 0.161644, -0.004033}}],
    Polygon[{{1.860587, 0.168930, 0.000000},{1.860843, 0.168743, 0.004033},{
      1.857226, 0.161644, 0.004033},{1.856924, 0.161742, 0.000000}}],
    Polygon[{{1.860843, 0.168743, 0.004033},{1.861608, 0.168188, 0.007968},{
      1.858124, 0.161353, 0.007968},{1.857226, 0.161644, 0.004033}}],
    Polygon[{{1.861608, 0.168188, 0.007968},{1.862860, 0.167278, 0.011705},{
      1.859597, 0.160874, 0.011705},{1.858124, 0.161353, 0.007968}}],
    Polygon[{{1.862860, 0.167278, 0.011705},{1.864570, 0.166036, 0.015155},{
      1.861608, 0.160221, 0.015155},{1.859597, 0.160874, 0.011705}}],
    Polygon[{{1.864570, 0.166036, 0.015155},{1.866696, 0.164491, 0.018232},{
      1.864107, 0.159409, 0.018232},{1.861608, 0.160221, 0.015155}}],
    Polygon[{{1.866696, 0.164491, 0.018232},{1.869185, 0.162683, 0.020859},{
      1.867033, 0.158458, 0.020859},{1.864107, 0.159409, 0.018232}}],
    Polygon[{{1.869185, 0.162683, 0.020859},{1.871976, 0.160655, 0.022973},{
      1.870313, 0.157392, 0.022973},{1.867033, 0.158458, 0.020859}}],
    Polygon[{{1.871976, 0.160655, 0.022973},{1.875000, 0.158458, 0.024521},{
      1.873868, 0.156237, 0.024521},{1.870313, 0.157392, 0.022973}}],
    Polygon[{{1.875000, 0.158458, 0.024521},{1.878183, 0.156146, 0.025466},{
      1.877610, 0.155021, 0.025466},{1.873868, 0.156237, 0.024521}}],
    Polygon[{{1.877610, 0.155021, -0.025466},{1.873868, 0.156237, -0.024521},{
      1.873478, 0.153775, -0.024521},{1.877412, 0.153775, -0.025466}}],
    Polygon[{{1.873868, 0.156237, -0.024521},{1.870313, 0.157392, -0.022973},{
      1.869740, 0.153775, -0.022973},{1.873478, 0.153775, -0.024521}}],
    Polygon[{{1.870313, 0.157392, -0.022973},{1.867033, 0.158458, -0.020859},{
      1.866291, 0.153775, -0.020859},{1.869740, 0.153775, -0.022973}}],
    Polygon[{{1.867033, 0.158458, -0.020859},{1.864107, 0.159409, -0.018232},{
      1.863214, 0.153775, -0.018232},{1.866291, 0.153775, -0.020859}}],
    Polygon[{{1.864107, 0.159409, -0.018232},{1.861608, 0.160221, -0.015155},{
      1.860587, 0.153775, -0.015155},{1.863214, 0.153775, -0.018232}}],
    Polygon[{{1.861608, 0.160221, -0.015155},{1.859597, 0.160874, -0.011705},{
      1.858473, 0.153775, -0.011705},{1.860587, 0.153775, -0.015155}}],
    Polygon[{{1.859597, 0.160874, -0.011705},{1.858124, 0.161353, -0.007968},{
      1.856924, 0.153775, -0.007968},{1.858473, 0.153775, -0.011705}}],
    Polygon[{{1.858124, 0.161353, -0.007968},{1.857226, 0.161644, -0.004033},{
      1.855980, 0.153775, -0.004033},{1.856924, 0.153775, -0.007968}}],
    Polygon[{{1.857226, 0.161644, -0.004033},{1.856924, 0.161742, 0.000000},{
      1.855662, 0.153775, 0.000000},{1.855980, 0.153775, -0.004033}}],
    Polygon[{{1.856924, 0.161742, 0.000000},{1.857226, 0.161644, 0.004033},{
      1.855980, 0.153775, 0.004033},{1.855662, 0.153775, 0.000000}}],
    Polygon[{{1.857226, 0.161644, 0.004033},{1.858124, 0.161353, 0.007968},{
      1.856924, 0.153775, 0.007968},{1.855980, 0.153775, 0.004033}}],
    Polygon[{{1.858124, 0.161353, 0.007968},{1.859597, 0.160874, 0.011705},{
      1.858473, 0.153775, 0.011705},{1.856924, 0.153775, 0.007968}}],
    Polygon[{{1.859597, 0.160874, 0.011705},{1.861608, 0.160221, 0.015155},{
      1.860587, 0.153775, 0.015155},{1.858473, 0.153775, 0.011705}}],
    Polygon[{{1.861608, 0.160221, 0.015155},{1.864107, 0.159409, 0.018232},{
      1.863214, 0.153775, 0.018232},{1.860587, 0.153775, 0.015155}}],
    Polygon[{{1.864107, 0.159409, 0.018232},{1.867033, 0.158458, 0.020859},{
      1.866291, 0.153775, 0.020859},{1.863214, 0.153775, 0.018232}}],
    Polygon[{{1.867033, 0.158458, 0.020859},{1.870313, 0.157392, 0.022973},{
      1.869740, 0.153775, 0.022973},{1.866291, 0.153775, 0.020859}}],
    Polygon[{{1.870313, 0.157392, 0.022973},{1.873868, 0.156237, 0.024521},{
      1.873478, 0.153775, 0.024521},{1.869740, 0.153775, 0.022973}}],
    Polygon[{{1.873868, 0.156237, 0.024521},{1.877610, 0.155021, 0.025466},{
      1.877412, 0.153775, 0.025466},{1.873478, 0.153775, 0.024521}}],
    Polygon[{{1.877412, 0.153775, -0.025466},{1.873478, 0.153775, -0.024521},{
      1.873868, 0.151313, -0.024521},{1.877610, 0.152529, -0.025466}}],
    Polygon[{{1.873478, 0.153775, -0.024521},{1.869740, 0.153775, -0.022973},{
      1.870313, 0.150158, -0.022973},{1.873868, 0.151313, -0.024521}}],
    Polygon[{{1.869740, 0.153775, -0.022973},{1.866291, 0.153775, -0.020859},{
      1.867033, 0.149092, -0.020859},{1.870313, 0.150158, -0.022973}}],
    Polygon[{{1.866291, 0.153775, -0.020859},{1.863214, 0.153775, -0.018232},{
      1.864107, 0.148141, -0.018232},{1.867033, 0.149092, -0.020859}}],
    Polygon[{{1.863214, 0.153775, -0.018232},{1.860587, 0.153775, -0.015155},{
      1.861608, 0.147329, -0.015155},{1.864107, 0.148141, -0.018232}}],
    Polygon[{{1.860587, 0.153775, -0.015155},{1.858473, 0.153775, -0.011705},{
      1.859597, 0.146676, -0.011705},{1.861608, 0.147329, -0.015155}}],
    Polygon[{{1.858473, 0.153775, -0.011705},{1.856924, 0.153775, -0.007968},{
      1.858124, 0.146197, -0.007968},{1.859597, 0.146676, -0.011705}}],
    Polygon[{{1.856924, 0.153775, -0.007968},{1.855980, 0.153775, -0.004033},{
      1.857226, 0.145906, -0.004033},{1.858124, 0.146197, -0.007968}}],
    Polygon[{{1.855980, 0.153775, -0.004033},{1.855662, 0.153775, 0.000000},{
      1.856924, 0.145807, 0.000000},{1.857226, 0.145906, -0.004033}}],
    Polygon[{{1.855662, 0.153775, 0.000000},{1.855980, 0.153775, 0.004033},{
      1.857226, 0.145906, 0.004033},{1.856924, 0.145807, 0.000000}}],
    Polygon[{{1.855980, 0.153775, 0.004033},{1.856924, 0.153775, 0.007968},{
      1.858124, 0.146197, 0.007968},{1.857226, 0.145906, 0.004033}}],
    Polygon[{{1.856924, 0.153775, 0.007968},{1.858473, 0.153775, 0.011705},{
      1.859597, 0.146676, 0.011705},{1.858124, 0.146197, 0.007968}}],
    Polygon[{{1.858473, 0.153775, 0.011705},{1.860587, 0.153775, 0.015155},{
      1.861608, 0.147329, 0.015155},{1.859597, 0.146676, 0.011705}}],
    Polygon[{{1.860587, 0.153775, 0.015155},{1.863214, 0.153775, 0.018232},{
      1.864107, 0.148141, 0.018232},{1.861608, 0.147329, 0.015155}}],
    Polygon[{{1.863214, 0.153775, 0.018232},{1.866291, 0.153775, 0.020859},{
      1.867033, 0.149092, 0.020859},{1.864107, 0.148141, 0.018232}}],
    Polygon[{{1.866291, 0.153775, 0.020859},{1.869740, 0.153775, 0.022973},{
      1.870313, 0.150158, 0.022973},{1.867033, 0.149092, 0.020859}}],
    Polygon[{{1.869740, 0.153775, 0.022973},{1.873478, 0.153775, 0.024521},{
      1.873868, 0.151313, 0.024521},{1.870313, 0.150158, 0.022973}}],
    Polygon[{{1.873478, 0.153775, 0.024521},{1.877412, 0.153775, 0.025466},{
      1.877610, 0.152529, 0.025466},{1.873868, 0.151313, 0.024521}}],
    Polygon[{{1.877610, 0.152529, -0.025466},{1.873868, 0.151313, -0.024521},{
      1.875000, 0.149092, -0.024521},{1.878183, 0.151404, -0.025466}}],
    Polygon[{{1.873868, 0.151313, -0.024521},{1.870313, 0.150158, -0.022973},{
      1.871976, 0.146895, -0.022973},{1.875000, 0.149092, -0.024521}}],
    Polygon[{{1.870313, 0.150158, -0.022973},{1.867033, 0.149092, -0.020859},{
      1.869185, 0.144867, -0.020859},{1.871976, 0.146895, -0.022973}}],
    Polygon[{{1.867033, 0.149092, -0.020859},{1.864107, 0.148141, -0.018232},{
      1.866696, 0.143059, -0.018232},{1.869185, 0.144867, -0.020859}}],
    Polygon[{{1.864107, 0.148141, -0.018232},{1.861608, 0.147329, -0.015155},{
      1.864570, 0.141514, -0.015155},{1.866696, 0.143059, -0.018232}}],
    Polygon[{{1.861608, 0.147329, -0.015155},{1.859597, 0.146676, -0.011705},{
      1.862860, 0.140272, -0.011705},{1.864570, 0.141514, -0.015155}}],
    Polygon[{{1.859597, 0.146676, -0.011705},{1.858124, 0.146197, -0.007968},{
      1.861608, 0.139362, -0.007968},{1.862860, 0.140272, -0.011705}}],
    Polygon[{{1.858124, 0.146197, -0.007968},{1.857226, 0.145906, -0.004033},{
      1.860843, 0.138806, -0.004033},{1.861608, 0.139362, -0.007968}}],
    Polygon[{{1.857226, 0.145906, -0.004033},{1.856924, 0.145807, 0.000000},{
      1.860587, 0.138620, 0.000000},{1.860843, 0.138806, -0.004033}}],
    Polygon[{{1.856924, 0.145807, 0.000000},{1.857226, 0.145906, 0.004033},{
      1.860843, 0.138806, 0.004033},{1.860587, 0.138620, 0.000000}}],
    Polygon[{{1.857226, 0.145906, 0.004033},{1.858124, 0.146197, 0.007968},{
      1.861608, 0.139362, 0.007968},{1.860843, 0.138806, 0.004033}}],
    Polygon[{{1.858124, 0.146197, 0.007968},{1.859597, 0.146676, 0.011705},{
      1.862860, 0.140272, 0.011705},{1.861608, 0.139362, 0.007968}}],
    Polygon[{{1.859597, 0.146676, 0.011705},{1.861608, 0.147329, 0.015155},{
      1.864570, 0.141514, 0.015155},{1.862860, 0.140272, 0.011705}}],
    Polygon[{{1.861608, 0.147329, 0.015155},{1.864107, 0.148141, 0.018232},{
      1.866696, 0.143059, 0.018232},{1.864570, 0.141514, 0.015155}}],
    Polygon[{{1.864107, 0.148141, 0.018232},{1.867033, 0.149092, 0.020859},{
      1.869185, 0.144867, 0.020859},{1.866696, 0.143059, 0.018232}}],
    Polygon[{{1.867033, 0.149092, 0.020859},{1.870313, 0.150158, 0.022973},{
      1.871976, 0.146895, 0.022973},{1.869185, 0.144867, 0.020859}}],
    Polygon[{{1.870313, 0.150158, 0.022973},{1.873868, 0.151313, 0.024521},{
      1.875000, 0.149092, 0.024521},{1.871976, 0.146895, 0.022973}}],
    Polygon[{{1.873868, 0.151313, 0.024521},{1.877610, 0.152529, 0.025466},{
      1.878183, 0.151404, 0.025466},{1.875000, 0.149092, 0.024521}}],
    Polygon[{{1.878183, 0.151404, -0.025466},{1.875000, 0.149092, -0.024521},{
      1.876763, 0.147329, -0.024521},{1.879075, 0.150512, -0.025466}}],
    Polygon[{{1.875000, 0.149092, -0.024521},{1.871976, 0.146895, -0.022973},{
      1.874566, 0.144305, -0.022973},{1.876763, 0.147329, -0.024521}}],
    Polygon[{{1.871976, 0.146895, -0.022973},{1.869185, 0.144867, -0.020859},{
      1.872538, 0.141514, -0.020859},{1.874566, 0.144305, -0.022973}}],
    Polygon[{{1.869185, 0.144867, -0.020859},{1.866696, 0.143059, -0.018232},{
      1.870730, 0.139025, -0.018232},{1.872538, 0.141514, -0.020859}}],
    Polygon[{{1.866696, 0.143059, -0.018232},{1.864570, 0.141514, -0.015155},{
      1.869185, 0.136899, -0.015155},{1.870730, 0.139025, -0.018232}}],
    Polygon[{{1.864570, 0.141514, -0.015155},{1.862860, 0.140272, -0.011705},{
      1.867943, 0.135189, -0.011705},{1.869185, 0.136899, -0.015155}}],
    Polygon[{{1.862860, 0.140272, -0.011705},{1.861608, 0.139362, -0.007968},{
      1.867033, 0.133937, -0.007968},{1.867943, 0.135189, -0.011705}}],
    Polygon[{{1.861608, 0.139362, -0.007968},{1.860843, 0.138806, -0.004033},{
      1.866477, 0.133173, -0.004033},{1.867033, 0.133937, -0.007968}}],
    Polygon[{{1.860843, 0.138806, -0.004033},{1.860587, 0.138620, 0.000000},{
      1.866291, 0.132916, 0.000000},{1.866477, 0.133173, -0.004033}}],
    Polygon[{{1.860587, 0.138620, 0.000000},{1.860843, 0.138806, 0.004033},{
      1.866477, 0.133173, 0.004033},{1.866291, 0.132916, 0.000000}}],
    Polygon[{{1.860843, 0.138806, 0.004033},{1.861608, 0.139362, 0.007968},{
      1.867033, 0.133937, 0.007968},{1.866477, 0.133173, 0.004033}}],
    Polygon[{{1.861608, 0.139362, 0.007968},{1.862860, 0.140272, 0.011705},{
      1.867943, 0.135189, 0.011705},{1.867033, 0.133937, 0.007968}}],
    Polygon[{{1.862860, 0.140272, 0.011705},{1.864570, 0.141514, 0.015155},{
      1.869185, 0.136899, 0.015155},{1.867943, 0.135189, 0.011705}}],
    Polygon[{{1.864570, 0.141514, 0.015155},{1.866696, 0.143059, 0.018232},{
      1.870730, 0.139025, 0.018232},{1.869185, 0.136899, 0.015155}}],
    Polygon[{{1.866696, 0.143059, 0.018232},{1.869185, 0.144867, 0.020859},{
      1.872538, 0.141514, 0.020859},{1.870730, 0.139025, 0.018232}}],
    Polygon[{{1.869185, 0.144867, 0.020859},{1.871976, 0.146895, 0.022973},{
      1.874566, 0.144305, 0.022973},{1.872538, 0.141514, 0.020859}}],
    Polygon[{{1.871976, 0.146895, 0.022973},{1.875000, 0.149092, 0.024521},{
      1.876763, 0.147329, 0.024521},{1.874566, 0.144305, 0.022973}}],
    Polygon[{{1.875000, 0.149092, 0.024521},{1.878183, 0.151404, 0.025466},{
      1.879075, 0.150512, 0.025466},{1.876763, 0.147329, 0.024521}}],
    Polygon[{{1.879075, 0.150512, -0.025466},{1.876763, 0.147329, -0.024521},{
      1.878984, 0.146197, -0.024521},{1.880199, 0.149939, -0.025466}}],
    Polygon[{{1.876763, 0.147329, -0.024521},{1.874566, 0.144305, -0.022973},{
      1.877829, 0.142642, -0.022973},{1.878984, 0.146197, -0.024521}}],
    Polygon[{{1.874566, 0.144305, -0.022973},{1.872538, 0.141514, -0.020859},{
      1.876763, 0.139362, -0.020859},{1.877829, 0.142642, -0.022973}}],
    Polygon[{{1.872538, 0.141514, -0.020859},{1.870730, 0.139025, -0.018232},{
      1.875812, 0.136436, -0.018232},{1.876763, 0.139362, -0.020859}}],
    Polygon[{{1.870730, 0.139025, -0.018232},{1.869185, 0.136899, -0.015155},{
      1.875000, 0.133937, -0.015155},{1.875812, 0.136436, -0.018232}}],
    Polygon[{{1.869185, 0.136899, -0.015155},{1.867943, 0.135189, -0.011705},{
      1.874347, 0.131926, -0.011705},{1.875000, 0.133937, -0.015155}}],
    Polygon[{{1.867943, 0.135189, -0.011705},{1.867033, 0.133937, -0.007968},{
      1.873868, 0.130454, -0.007968},{1.874347, 0.131926, -0.011705}}],
    Polygon[{{1.867033, 0.133937, -0.007968},{1.866477, 0.133173, -0.004033},{
      1.873576, 0.129555, -0.004033},{1.873868, 0.130454, -0.007968}}],
    Polygon[{{1.866477, 0.133173, -0.004033},{1.866291, 0.132916, 0.000000},{
      1.873478, 0.129253, 0.000000},{1.873576, 0.129555, -0.004033}}],
    Polygon[{{1.866291, 0.132916, 0.000000},{1.866477, 0.133173, 0.004033},{
      1.873576, 0.129555, 0.004033},{1.873478, 0.129253, 0.000000}}],
    Polygon[{{1.866477, 0.133173, 0.004033},{1.867033, 0.133937, 0.007968},{
      1.873868, 0.130454, 0.007968},{1.873576, 0.129555, 0.004033}}],
    Polygon[{{1.867033, 0.133937, 0.007968},{1.867943, 0.135189, 0.011705},{
      1.874347, 0.131926, 0.011705},{1.873868, 0.130454, 0.007968}}],
    Polygon[{{1.867943, 0.135189, 0.011705},{1.869185, 0.136899, 0.015155},{
      1.875000, 0.133937, 0.015155},{1.874347, 0.131926, 0.011705}}],
    Polygon[{{1.869185, 0.136899, 0.015155},{1.870730, 0.139025, 0.018232},{
      1.875812, 0.136436, 0.018232},{1.875000, 0.133937, 0.015155}}],
    Polygon[{{1.870730, 0.139025, 0.018232},{1.872538, 0.141514, 0.020859},{
      1.876763, 0.139362, 0.020859},{1.875812, 0.136436, 0.018232}}],
    Polygon[{{1.872538, 0.141514, 0.020859},{1.874566, 0.144305, 0.022973},{
      1.877829, 0.142642, 0.022973},{1.876763, 0.139362, 0.020859}}],
    Polygon[{{1.874566, 0.144305, 0.022973},{1.876763, 0.147329, 0.024521},{
      1.878984, 0.146197, 0.024521},{1.877829, 0.142642, 0.022973}}],
    Polygon[{{1.876763, 0.147329, 0.024521},{1.879075, 0.150512, 0.025466},{
      1.880199, 0.149939, 0.025466},{1.878984, 0.146197, 0.024521}}],
    Polygon[{{1.880199, 0.149939, -0.025466},{1.878984, 0.146197, -0.024521},{
      1.881446, 0.145807, -0.024521},{1.881446, 0.149742, -0.025466}}],
    Polygon[{{1.878984, 0.146197, -0.024521},{1.877829, 0.142642, -0.022973},{
      1.881446, 0.142070, -0.022973},{1.881446, 0.145807, -0.024521}}],
    Polygon[{{1.877829, 0.142642, -0.022973},{1.876763, 0.139362, -0.020859},{
      1.881446, 0.138620, -0.020859},{1.881446, 0.142070, -0.022973}}],
    Polygon[{{1.876763, 0.139362, -0.020859},{1.875812, 0.136436, -0.018232},{
      1.881446, 0.135543, -0.018232},{1.881446, 0.138620, -0.020859}}],
    Polygon[{{1.875812, 0.136436, -0.018232},{1.875000, 0.133937, -0.015155},{
      1.881446, 0.132916, -0.015155},{1.881446, 0.135543, -0.018232}}],
    Polygon[{{1.875000, 0.133937, -0.015155},{1.874347, 0.131926, -0.011705},{
      1.881446, 0.130802, -0.011705},{1.881446, 0.132916, -0.015155}}],
    Polygon[{{1.874347, 0.131926, -0.011705},{1.873868, 0.130454, -0.007968},{
      1.881446, 0.129253, -0.007968},{1.881446, 0.130802, -0.011705}}],
    Polygon[{{1.873868, 0.130454, -0.007968},{1.873576, 0.129555, -0.004033},{
      1.881446, 0.128309, -0.004033},{1.881446, 0.129253, -0.007968}}],
    Polygon[{{1.873576, 0.129555, -0.004033},{1.873478, 0.129253, 0.000000},{
      1.881446, 0.127992, 0.000000},{1.881446, 0.128309, -0.004033}}],
    Polygon[{{1.873478, 0.129253, 0.000000},{1.873576, 0.129555, 0.004033},{
      1.881446, 0.128309, 0.004033},{1.881446, 0.127992, 0.000000}}],
    Polygon[{{1.873576, 0.129555, 0.004033},{1.873868, 0.130454, 0.007968},{
      1.881446, 0.129253, 0.007968},{1.881446, 0.128309, 0.004033}}],
    Polygon[{{1.873868, 0.130454, 0.007968},{1.874347, 0.131926, 0.011705},{
      1.881446, 0.130802, 0.011705},{1.881446, 0.129253, 0.007968}}],
    Polygon[{{1.874347, 0.131926, 0.011705},{1.875000, 0.133937, 0.015155},{
      1.881446, 0.132916, 0.015155},{1.881446, 0.130802, 0.011705}}],
    Polygon[{{1.875000, 0.133937, 0.015155},{1.875812, 0.136436, 0.018232},{
      1.881446, 0.135543, 0.018232},{1.881446, 0.132916, 0.015155}}],
    Polygon[{{1.875812, 0.136436, 0.018232},{1.876763, 0.139362, 0.020859},{
      1.881446, 0.138620, 0.020859},{1.881446, 0.135543, 0.018232}}],
    Polygon[{{1.876763, 0.139362, 0.020859},{1.877829, 0.142642, 0.022973},{
      1.881446, 0.142070, 0.022973},{1.881446, 0.138620, 0.020859}}],
    Polygon[{{1.877829, 0.142642, 0.022973},{1.878984, 0.146197, 0.024521},{
      1.881446, 0.145807, 0.024521},{1.881446, 0.142070, 0.022973}}],
    Polygon[{{1.878984, 0.146197, 0.024521},{1.880199, 0.149939, 0.025466},{
      1.881446, 0.149742, 0.025466},{1.881446, 0.145807, 0.024521}}],
    Polygon[{{1.881446, 0.149742, -0.025466},{1.881446, 0.145807, -0.024521},{
      1.883908, 0.146197, -0.024521},{1.882692, 0.149939, -0.025466}}],
    Polygon[{{1.881446, 0.145807, -0.024521},{1.881446, 0.142070, -0.022973},{
      1.885063, 0.142642, -0.022973},{1.883908, 0.146197, -0.024521}}],
    Polygon[{{1.881446, 0.142070, -0.022973},{1.881446, 0.138620, -0.020859},{
      1.886129, 0.139362, -0.020859},{1.885063, 0.142642, -0.022973}}],
    Polygon[{{1.881446, 0.138620, -0.020859},{1.881446, 0.135543, -0.018232},{
      1.887080, 0.136436, -0.018232},{1.886129, 0.139362, -0.020859}}],
    Polygon[{{1.881446, 0.135543, -0.018232},{1.881446, 0.132916, -0.015155},{
      1.887892, 0.133937, -0.015155},{1.887080, 0.136436, -0.018232}}],
    Polygon[{{1.881446, 0.132916, -0.015155},{1.881446, 0.130802, -0.011705},{
      1.888545, 0.131926, -0.011705},{1.887892, 0.133937, -0.015155}}],
    Polygon[{{1.881446, 0.130802, -0.011705},{1.881446, 0.129253, -0.007968},{
      1.889023, 0.130454, -0.007968},{1.888545, 0.131926, -0.011705}}],
    Polygon[{{1.881446, 0.129253, -0.007968},{1.881446, 0.128309, -0.004033},{
      1.889315, 0.129555, -0.004033},{1.889023, 0.130454, -0.007968}}],
    Polygon[{{1.881446, 0.128309, -0.004033},{1.881446, 0.127992, 0.000000},{
      1.889413, 0.129253, 0.000000},{1.889315, 0.129555, -0.004033}}],
    Polygon[{{1.881446, 0.127992, 0.000000},{1.881446, 0.128309, 0.004033},{
      1.889315, 0.129555, 0.004033},{1.889413, 0.129253, 0.000000}}],
    Polygon[{{1.881446, 0.128309, 0.004033},{1.881446, 0.129253, 0.007968},{
      1.889023, 0.130454, 0.007968},{1.889315, 0.129555, 0.004033}}],
    Polygon[{{1.881446, 0.129253, 0.007968},{1.881446, 0.130802, 0.011705},{
      1.888545, 0.131926, 0.011705},{1.889023, 0.130454, 0.007968}}],
    Polygon[{{1.881446, 0.130802, 0.011705},{1.881446, 0.132916, 0.015155},{
      1.887892, 0.133937, 0.015155},{1.888545, 0.131926, 0.011705}}],
    Polygon[{{1.881446, 0.132916, 0.015155},{1.881446, 0.135543, 0.018232},{
      1.887080, 0.136436, 0.018232},{1.887892, 0.133937, 0.015155}}],
    Polygon[{{1.881446, 0.135543, 0.018232},{1.881446, 0.138620, 0.020859},{
      1.886129, 0.139362, 0.020859},{1.887080, 0.136436, 0.018232}}],
    Polygon[{{1.881446, 0.138620, 0.020859},{1.881446, 0.142070, 0.022973},{
      1.885063, 0.142642, 0.022973},{1.886129, 0.139362, 0.020859}}],
    Polygon[{{1.881446, 0.142070, 0.022973},{1.881446, 0.145807, 0.024521},{
      1.883908, 0.146197, 0.024521},{1.885063, 0.142642, 0.022973}}],
    Polygon[{{1.881446, 0.145807, 0.024521},{1.881446, 0.149742, 0.025466},{
      1.882692, 0.149939, 0.025466},{1.883908, 0.146197, 0.024521}}],
    Polygon[{{1.882692, 0.149939, -0.025466},{1.883908, 0.146197, -0.024521},{
      1.886129, 0.147329, -0.024521},{1.883817, 0.150512, -0.025466}}],
    Polygon[{{1.883908, 0.146197, -0.024521},{1.885063, 0.142642, -0.022973},{
      1.888326, 0.144305, -0.022973},{1.886129, 0.147329, -0.024521}}],
    Polygon[{{1.885063, 0.142642, -0.022973},{1.886129, 0.139362, -0.020859},{
      1.890354, 0.141514, -0.020859},{1.888326, 0.144305, -0.022973}}],
    Polygon[{{1.886129, 0.139362, -0.020859},{1.887080, 0.136436, -0.018232},{
      1.892162, 0.139025, -0.018232},{1.890354, 0.141514, -0.020859}}],
    Polygon[{{1.887080, 0.136436, -0.018232},{1.887892, 0.133937, -0.015155},{
      1.893707, 0.136899, -0.015155},{1.892162, 0.139025, -0.018232}}],
    Polygon[{{1.887892, 0.133937, -0.015155},{1.888545, 0.131926, -0.011705},{
      1.894949, 0.135189, -0.011705},{1.893707, 0.136899, -0.015155}}],
    Polygon[{{1.888545, 0.131926, -0.011705},{1.889023, 0.130454, -0.007968},{
      1.895859, 0.133937, -0.007968},{1.894949, 0.135189, -0.011705}}],
    Polygon[{{1.889023, 0.130454, -0.007968},{1.889315, 0.129555, -0.004033},{
      1.896414, 0.133173, -0.004033},{1.895859, 0.133937, -0.007968}}],
    Polygon[{{1.889315, 0.129555, -0.004033},{1.889413, 0.129253, 0.000000},{
      1.896601, 0.132916, 0.000000},{1.896414, 0.133173, -0.004033}}],
    Polygon[{{1.889413, 0.129253, 0.000000},{1.889315, 0.129555, 0.004033},{
      1.896414, 0.133173, 0.004033},{1.896601, 0.132916, 0.000000}}],
    Polygon[{{1.889315, 0.129555, 0.004033},{1.889023, 0.130454, 0.007968},{
      1.895859, 0.133937, 0.007968},{1.896414, 0.133173, 0.004033}}],
    Polygon[{{1.889023, 0.130454, 0.007968},{1.888545, 0.131926, 0.011705},{
      1.894949, 0.135189, 0.011705},{1.895859, 0.133937, 0.007968}}],
    Polygon[{{1.888545, 0.131926, 0.011705},{1.887892, 0.133937, 0.015155},{
      1.893707, 0.136899, 0.015155},{1.894949, 0.135189, 0.011705}}],
    Polygon[{{1.887892, 0.133937, 0.015155},{1.887080, 0.136436, 0.018232},{
      1.892162, 0.139025, 0.018232},{1.893707, 0.136899, 0.015155}}],
    Polygon[{{1.887080, 0.136436, 0.018232},{1.886129, 0.139362, 0.020859},{
      1.890354, 0.141514, 0.020859},{1.892162, 0.139025, 0.018232}}],
    Polygon[{{1.886129, 0.139362, 0.020859},{1.885063, 0.142642, 0.022973},{
      1.888326, 0.144305, 0.022973},{1.890354, 0.141514, 0.020859}}],
    Polygon[{{1.885063, 0.142642, 0.022973},{1.883908, 0.146197, 0.024521},{
      1.886129, 0.147329, 0.024521},{1.888326, 0.144305, 0.022973}}],
    Polygon[{{1.883908, 0.146197, 0.024521},{1.882692, 0.149939, 0.025466},{
      1.883817, 0.150512, 0.025466},{1.886129, 0.147329, 0.024521}}],
    Polygon[{{1.883817, 0.150512, -0.025466},{1.886129, 0.147329, -0.024521},{
      1.887892, 0.149092, -0.024521},{1.884709, 0.151404, -0.025466}}],
    Polygon[{{1.886129, 0.147329, -0.024521},{1.888326, 0.144305, -0.022973},{
      1.890916, 0.146895, -0.022973},{1.887892, 0.149092, -0.024521}}],
    Polygon[{{1.888326, 0.144305, -0.022973},{1.890354, 0.141514, -0.020859},{
      1.893707, 0.144867, -0.020859},{1.890916, 0.146895, -0.022973}}],
    Polygon[{{1.890354, 0.141514, -0.020859},{1.892162, 0.139025, -0.018232},{
      1.896196, 0.143059, -0.018232},{1.893707, 0.144867, -0.020859}}],
    Polygon[{{1.892162, 0.139025, -0.018232},{1.893707, 0.136899, -0.015155},{
      1.898321, 0.141514, -0.015155},{1.896196, 0.143059, -0.018232}}],
    Polygon[{{1.893707, 0.136899, -0.015155},{1.894949, 0.135189, -0.011705},{
      1.900032, 0.140272, -0.011705},{1.898321, 0.141514, -0.015155}}],
    Polygon[{{1.894949, 0.135189, -0.011705},{1.895859, 0.133937, -0.007968},{
      1.901284, 0.139362, -0.007968},{1.900032, 0.140272, -0.011705}}],
    Polygon[{{1.895859, 0.133937, -0.007968},{1.896414, 0.133173, -0.004033},{
      1.902048, 0.138806, -0.004033},{1.901284, 0.139362, -0.007968}}],
    Polygon[{{1.896414, 0.133173, -0.004033},{1.896601, 0.132916, 0.000000},{
      1.902305, 0.138620, 0.000000},{1.902048, 0.138806, -0.004033}}],
    Polygon[{{1.896601, 0.132916, 0.000000},{1.896414, 0.133173, 0.004033},{
      1.902048, 0.138806, 0.004033},{1.902305, 0.138620, 0.000000}}],
    Polygon[{{1.896414, 0.133173, 0.004033},{1.895859, 0.133937, 0.007968},{
      1.901284, 0.139362, 0.007968},{1.902048, 0.138806, 0.004033}}],
    Polygon[{{1.895859, 0.133937, 0.007968},{1.894949, 0.135189, 0.011705},{
      1.900032, 0.140272, 0.011705},{1.901284, 0.139362, 0.007968}}],
    Polygon[{{1.894949, 0.135189, 0.011705},{1.893707, 0.136899, 0.015155},{
      1.898321, 0.141514, 0.015155},{1.900032, 0.140272, 0.011705}}],
    Polygon[{{1.893707, 0.136899, 0.015155},{1.892162, 0.139025, 0.018232},{
      1.896196, 0.143059, 0.018232},{1.898321, 0.141514, 0.015155}}],
    Polygon[{{1.892162, 0.139025, 0.018232},{1.890354, 0.141514, 0.020859},{
      1.893707, 0.144867, 0.020859},{1.896196, 0.143059, 0.018232}}],
    Polygon[{{1.890354, 0.141514, 0.020859},{1.888326, 0.144305, 0.022973},{
      1.890916, 0.146895, 0.022973},{1.893707, 0.144867, 0.020859}}],
    Polygon[{{1.888326, 0.144305, 0.022973},{1.886129, 0.147329, 0.024521},{
      1.887892, 0.149092, 0.024521},{1.890916, 0.146895, 0.022973}}],
    Polygon[{{1.886129, 0.147329, 0.024521},{1.883817, 0.150512, 0.025466},{
      1.884709, 0.151404, 0.025466},{1.887892, 0.149092, 0.024521}}],
    Polygon[{{1.884709, 0.151404, -0.025466},{1.887892, 0.149092, -0.024521},{
      1.889023, 0.151313, -0.024521},{1.885282, 0.152529, -0.025466}}],
    Polygon[{{1.887892, 0.149092, -0.024521},{1.890916, 0.146895, -0.022973},{
      1.892578, 0.150158, -0.022973},{1.889023, 0.151313, -0.024521}}],
    Polygon[{{1.890916, 0.146895, -0.022973},{1.893707, 0.144867, -0.020859},{
      1.895859, 0.149092, -0.020859},{1.892578, 0.150158, -0.022973}}],
    Polygon[{{1.893707, 0.144867, -0.020859},{1.896196, 0.143059, -0.018232},{
      1.898785, 0.148141, -0.018232},{1.895859, 0.149092, -0.020859}}],
    Polygon[{{1.896196, 0.143059, -0.018232},{1.898321, 0.141514, -0.015155},{
      1.901284, 0.147329, -0.015155},{1.898785, 0.148141, -0.018232}}],
    Polygon[{{1.898321, 0.141514, -0.015155},{1.900032, 0.140272, -0.011705},{
      1.903295, 0.146676, -0.011705},{1.901284, 0.147329, -0.015155}}],
    Polygon[{{1.900032, 0.140272, -0.011705},{1.901284, 0.139362, -0.007968},{
      1.904767, 0.146197, -0.007968},{1.903295, 0.146676, -0.011705}}],
    Polygon[{{1.901284, 0.139362, -0.007968},{1.902048, 0.138806, -0.004033},{
      1.905665, 0.145906, -0.004033},{1.904767, 0.146197, -0.007968}}],
    Polygon[{{1.902048, 0.138806, -0.004033},{1.902305, 0.138620, 0.000000},{
      1.905967, 0.145807, 0.000000},{1.905665, 0.145906, -0.004033}}],
    Polygon[{{1.902305, 0.138620, 0.000000},{1.902048, 0.138806, 0.004033},{
      1.905665, 0.145906, 0.004033},{1.905967, 0.145807, 0.000000}}],
    Polygon[{{1.902048, 0.138806, 0.004033},{1.901284, 0.139362, 0.007968},{
      1.904767, 0.146197, 0.007968},{1.905665, 0.145906, 0.004033}}],
    Polygon[{{1.901284, 0.139362, 0.007968},{1.900032, 0.140272, 0.011705},{
      1.903295, 0.146676, 0.011705},{1.904767, 0.146197, 0.007968}}],
    Polygon[{{1.900032, 0.140272, 0.011705},{1.898321, 0.141514, 0.015155},{
      1.901284, 0.147329, 0.015155},{1.903295, 0.146676, 0.011705}}],
    Polygon[{{1.898321, 0.141514, 0.015155},{1.896196, 0.143059, 0.018232},{
      1.898785, 0.148141, 0.018232},{1.901284, 0.147329, 0.015155}}],
    Polygon[{{1.896196, 0.143059, 0.018232},{1.893707, 0.144867, 0.020859},{
      1.895859, 0.149092, 0.020859},{1.898785, 0.148141, 0.018232}}],
    Polygon[{{1.893707, 0.144867, 0.020859},{1.890916, 0.146895, 0.022973},{
      1.892578, 0.150158, 0.022973},{1.895859, 0.149092, 0.020859}}],
    Polygon[{{1.890916, 0.146895, 0.022973},{1.887892, 0.149092, 0.024521},{
      1.889023, 0.151313, 0.024521},{1.892578, 0.150158, 0.022973}}],
    Polygon[{{1.887892, 0.149092, 0.024521},{1.884709, 0.151404, 0.025466},{
      1.885282, 0.152529, 0.025466},{1.889023, 0.151313, 0.024521}}],
    Polygon[{{1.885282, 0.152529, -0.025466},{1.889023, 0.151313, -0.024521},{
      1.889413, 0.153775, -0.024521},{1.885479, 0.153775, -0.025466}}],
    Polygon[{{1.889023, 0.151313, -0.024521},{1.892578, 0.150158, -0.022973},{
      1.893151, 0.153775, -0.022973},{1.889413, 0.153775, -0.024521}}],
    Polygon[{{1.892578, 0.150158, -0.022973},{1.895859, 0.149092, -0.020859},{
      1.896601, 0.153775, -0.020859},{1.893151, 0.153775, -0.022973}}],
    Polygon[{{1.895859, 0.149092, -0.020859},{1.898785, 0.148141, -0.018232},{
      1.899678, 0.153775, -0.018232},{1.896601, 0.153775, -0.020859}}],
    Polygon[{{1.898785, 0.148141, -0.018232},{1.901284, 0.147329, -0.015155},{
      1.902305, 0.153775, -0.015155},{1.899678, 0.153775, -0.018232}}],
    Polygon[{{1.901284, 0.147329, -0.015155},{1.903295, 0.146676, -0.011705},{
      1.904419, 0.153775, -0.011705},{1.902305, 0.153775, -0.015155}}],
    Polygon[{{1.903295, 0.146676, -0.011705},{1.904767, 0.146197, -0.007968},{
      1.905967, 0.153775, -0.007968},{1.904419, 0.153775, -0.011705}}],
    Polygon[{{1.904767, 0.146197, -0.007968},{1.905665, 0.145906, -0.004033},{
      1.906912, 0.153775, -0.004033},{1.905967, 0.153775, -0.007968}}],
    Polygon[{{1.905665, 0.145906, -0.004033},{1.905967, 0.145807, 0.000000},{
      1.907229, 0.153775, 0.000000},{1.906912, 0.153775, -0.004033}}],
    Polygon[{{1.905967, 0.145807, 0.000000},{1.905665, 0.145906, 0.004033},{
      1.906912, 0.153775, 0.004033},{1.907229, 0.153775, 0.000000}}],
    Polygon[{{1.905665, 0.145906, 0.004033},{1.904767, 0.146197, 0.007968},{
      1.905967, 0.153775, 0.007968},{1.906912, 0.153775, 0.004033}}],
    Polygon[{{1.904767, 0.146197, 0.007968},{1.903295, 0.146676, 0.011705},{
      1.904419, 0.153775, 0.011705},{1.905967, 0.153775, 0.007968}}],
    Polygon[{{1.903295, 0.146676, 0.011705},{1.901284, 0.147329, 0.015155},{
      1.902305, 0.153775, 0.015155},{1.904419, 0.153775, 0.011705}}],
    Polygon[{{1.901284, 0.147329, 0.015155},{1.898785, 0.148141, 0.018232},{
      1.899678, 0.153775, 0.018232},{1.902305, 0.153775, 0.015155}}],
    Polygon[{{1.898785, 0.148141, 0.018232},{1.895859, 0.149092, 0.020859},{
      1.896601, 0.153775, 0.020859},{1.899678, 0.153775, 0.018232}}],
    Polygon[{{1.895859, 0.149092, 0.020859},{1.892578, 0.150158, 0.022973},{
      1.893151, 0.153775, 0.022973},{1.896601, 0.153775, 0.020859}}],
    Polygon[{{1.892578, 0.150158, 0.022973},{1.889023, 0.151313, 0.024521},{
      1.889413, 0.153775, 0.024521},{1.893151, 0.153775, 0.022973}}],
    Polygon[{{1.889023, 0.151313, 0.024521},{1.885282, 0.152529, 0.025466},{
      1.885479, 0.153775, 0.025466},{1.889413, 0.153775, 0.024521}}],
    Polygon[{{1.875096, 0.192450, -0.013647},{1.877204, 0.192450, -0.013141},{
      1.876995, 0.193770, -0.013141},{1.874990, 0.193118, -0.013647}}],
    Polygon[{{1.877204, 0.192450, -0.013141},{1.879207, 0.192450, -0.012311},{
      1.878900, 0.194389, -0.012311},{1.876995, 0.193770, -0.013141}}],
    Polygon[{{1.879207, 0.192450, -0.012311},{1.881056, 0.192450, -0.011178},{
      1.880658, 0.194960, -0.011178},{1.878900, 0.194389, -0.012311}}],
    Polygon[{{1.881056, 0.192450, -0.011178},{1.882704, 0.192450, -0.009770},{
      1.882226, 0.195469, -0.009770},{1.880658, 0.194960, -0.011178}}],
    Polygon[{{1.882704, 0.192450, -0.009770},{1.884112, 0.192450, -0.008122},{
      1.883565, 0.195904, -0.008122},{1.882226, 0.195469, -0.009770}}],
    Polygon[{{1.884112, 0.192450, -0.008122},{1.885245, 0.192450, -0.006273},{
      1.884643, 0.196254, -0.006273},{1.883565, 0.195904, -0.008122}}],
    Polygon[{{1.885245, 0.192450, -0.006273},{1.886075, 0.192450, -0.004270},{
      1.885432, 0.196511, -0.004270},{1.884643, 0.196254, -0.006273}}],
    Polygon[{{1.886075, 0.192450, -0.004270},{1.886581, 0.192450, -0.002162},{
      1.885913, 0.196667, -0.002162},{1.885432, 0.196511, -0.004270}}],
    Polygon[{{1.886581, 0.192450, -0.002162},{1.886751, 0.192450, 0.000000},{
      1.886075, 0.196720, 0.000000},{1.885913, 0.196667, -0.002162}}],
    Polygon[{{1.886751, 0.192450, 0.000000},{1.886581, 0.192450, 0.002162},{
      1.885913, 0.196667, 0.002162},{1.886075, 0.196720, 0.000000}}],
    Polygon[{{1.886581, 0.192450, 0.002162},{1.886075, 0.192450, 0.004270},{
      1.885432, 0.196511, 0.004270},{1.885913, 0.196667, 0.002162}}],
    Polygon[{{1.886075, 0.192450, 0.004270},{1.885245, 0.192450, 0.006273},{
      1.884643, 0.196254, 0.006273},{1.885432, 0.196511, 0.004270}}],
    Polygon[{{1.885245, 0.192450, 0.006273},{1.884112, 0.192450, 0.008122},{
      1.883565, 0.195904, 0.008122},{1.884643, 0.196254, 0.006273}}],
    Polygon[{{1.884112, 0.192450, 0.008122},{1.882704, 0.192450, 0.009770},{
      1.882226, 0.195469, 0.009770},{1.883565, 0.195904, 0.008122}}],
    Polygon[{{1.882704, 0.192450, 0.009770},{1.881056, 0.192450, 0.011178},{
      1.880658, 0.194960, 0.011178},{1.882226, 0.195469, 0.009770}}],
    Polygon[{{1.881056, 0.192450, 0.011178},{1.879207, 0.192450, 0.012311},{
      1.878900, 0.194389, 0.012311},{1.880658, 0.194960, 0.011178}}],
    Polygon[{{1.879207, 0.192450, 0.012311},{1.877204, 0.192450, 0.013141},{
      1.876995, 0.193770, 0.013141},{1.878900, 0.194389, 0.012311}}],
    Polygon[{{1.877204, 0.192450, 0.013141},{1.875096, 0.192450, 0.013647},{
      1.874990, 0.193118, 0.013647},{1.876995, 0.193770, 0.013141}}],
    Polygon[{{1.874990, 0.193118, -0.013647},{1.876995, 0.193770, -0.013141},{
      1.876388, 0.194960, -0.013141},{1.874683, 0.193721, -0.013647}}],
    Polygon[{{1.876995, 0.193770, -0.013141},{1.878900, 0.194389, -0.012311},{
      1.878009, 0.196137, -0.012311},{1.876388, 0.194960, -0.013141}}],
    Polygon[{{1.878900, 0.194389, -0.012311},{1.880658, 0.194960, -0.011178},{
      1.879505, 0.197224, -0.011178},{1.878009, 0.196137, -0.012311}}],
    Polygon[{{1.880658, 0.194960, -0.011178},{1.882226, 0.195469, -0.009770},{
      1.880838, 0.198193, -0.009770},{1.879505, 0.197224, -0.011178}}],
    Polygon[{{1.882226, 0.195469, -0.009770},{1.883565, 0.195904, -0.008122},{
      1.881978, 0.199021, -0.008122},{1.880838, 0.198193, -0.009770}}],
    Polygon[{{1.883565, 0.195904, -0.008122},{1.884643, 0.196254, -0.006273},{
      1.882894, 0.199686, -0.006273},{1.881978, 0.199021, -0.008122}}],
    Polygon[{{1.884643, 0.196254, -0.006273},{1.885432, 0.196511, -0.004270},{
      1.883565, 0.200174, -0.004270},{1.882894, 0.199686, -0.006273}}],
    Polygon[{{1.885432, 0.196511, -0.004270},{1.885913, 0.196667, -0.002162},{
      1.883975, 0.200472, -0.002162},{1.883565, 0.200174, -0.004270}}],
    Polygon[{{1.885913, 0.196667, -0.002162},{1.886075, 0.196720, 0.000000},{
      1.884112, 0.200572, 0.000000},{1.883975, 0.200472, -0.002162}}],
    Polygon[{{1.886075, 0.196720, 0.000000},{1.885913, 0.196667, 0.002162},{
      1.883975, 0.200472, 0.002162},{1.884112, 0.200572, 0.000000}}],
    Polygon[{{1.885913, 0.196667, 0.002162},{1.885432, 0.196511, 0.004270},{
      1.883565, 0.200174, 0.004270},{1.883975, 0.200472, 0.002162}}],
    Polygon[{{1.885432, 0.196511, 0.004270},{1.884643, 0.196254, 0.006273},{
      1.882894, 0.199686, 0.006273},{1.883565, 0.200174, 0.004270}}],
    Polygon[{{1.884643, 0.196254, 0.006273},{1.883565, 0.195904, 0.008122},{
      1.881978, 0.199021, 0.008122},{1.882894, 0.199686, 0.006273}}],
    Polygon[{{1.883565, 0.195904, 0.008122},{1.882226, 0.195469, 0.009770},{
      1.880838, 0.198193, 0.009770},{1.881978, 0.199021, 0.008122}}],
    Polygon[{{1.882226, 0.195469, 0.009770},{1.880658, 0.194960, 0.011178},{
      1.879505, 0.197224, 0.011178},{1.880838, 0.198193, 0.009770}}],
    Polygon[{{1.880658, 0.194960, 0.011178},{1.878900, 0.194389, 0.012311},{
      1.878009, 0.196137, 0.012311},{1.879505, 0.197224, 0.011178}}],
    Polygon[{{1.878900, 0.194389, 0.012311},{1.876995, 0.193770, 0.013141},{
      1.876388, 0.194960, 0.013141},{1.878009, 0.196137, 0.012311}}],
    Polygon[{{1.876995, 0.193770, 0.013141},{1.874990, 0.193118, 0.013647},{
      1.874683, 0.193721, 0.013647},{1.876388, 0.194960, 0.013141}}],
    Polygon[{{1.874683, 0.193721, -0.013647},{1.876388, 0.194960, -0.013141},{
      1.875444, 0.195904, -0.013141},{1.874205, 0.194199, -0.013647}}],
    Polygon[{{1.876388, 0.194960, -0.013141},{1.878009, 0.196137, -0.012311},{
      1.876621, 0.197525, -0.012311},{1.875444, 0.195904, -0.013141}}],
    Polygon[{{1.878009, 0.196137, -0.012311},{1.879505, 0.197224, -0.011178},{
      1.877708, 0.199021, -0.011178},{1.876621, 0.197525, -0.012311}}],
    Polygon[{{1.879505, 0.197224, -0.011178},{1.880838, 0.198193, -0.009770},{
      1.878677, 0.200354, -0.009770},{1.877708, 0.199021, -0.011178}}],
    Polygon[{{1.880838, 0.198193, -0.009770},{1.881978, 0.199021, -0.008122},{
      1.879505, 0.201494, -0.008122},{1.878677, 0.200354, -0.009770}}],
    Polygon[{{1.881978, 0.199021, -0.008122},{1.882894, 0.199686, -0.006273},{
      1.880170, 0.202410, -0.006273},{1.879505, 0.201494, -0.008122}}],
    Polygon[{{1.882894, 0.199686, -0.006273},{1.883565, 0.200174, -0.004270},{
      1.880658, 0.203081, -0.004270},{1.880170, 0.202410, -0.006273}}],
    Polygon[{{1.883565, 0.200174, -0.004270},{1.883975, 0.200472, -0.002162},{
      1.880956, 0.203491, -0.002162},{1.880658, 0.203081, -0.004270}}],
    Polygon[{{1.883975, 0.200472, -0.002162},{1.884112, 0.200572, 0.000000},{
      1.881056, 0.203629, 0.000000},{1.880956, 0.203491, -0.002162}}],
    Polygon[{{1.884112, 0.200572, 0.000000},{1.883975, 0.200472, 0.002162},{
      1.880956, 0.203491, 0.002162},{1.881056, 0.203629, 0.000000}}],
    Polygon[{{1.883975, 0.200472, 0.002162},{1.883565, 0.200174, 0.004270},{
      1.880658, 0.203081, 0.004270},{1.880956, 0.203491, 0.002162}}],
    Polygon[{{1.883565, 0.200174, 0.004270},{1.882894, 0.199686, 0.006273},{
      1.880170, 0.202410, 0.006273},{1.880658, 0.203081, 0.004270}}],
    Polygon[{{1.882894, 0.199686, 0.006273},{1.881978, 0.199021, 0.008122},{
      1.879505, 0.201494, 0.008122},{1.880170, 0.202410, 0.006273}}],
    Polygon[{{1.881978, 0.199021, 0.008122},{1.880838, 0.198193, 0.009770},{
      1.878677, 0.200354, 0.009770},{1.879505, 0.201494, 0.008122}}],
    Polygon[{{1.880838, 0.198193, 0.009770},{1.879505, 0.197224, 0.011178},{
      1.877708, 0.199021, 0.011178},{1.878677, 0.200354, 0.009770}}],
    Polygon[{{1.879505, 0.197224, 0.011178},{1.878009, 0.196137, 0.012311},{
      1.876621, 0.197525, 0.012311},{1.877708, 0.199021, 0.011178}}],
    Polygon[{{1.878009, 0.196137, 0.012311},{1.876388, 0.194960, 0.013141},{
      1.875444, 0.195904, 0.013141},{1.876621, 0.197525, 0.012311}}],
    Polygon[{{1.876388, 0.194960, 0.013141},{1.874683, 0.193721, 0.013647},{
      1.874205, 0.194199, 0.013647},{1.875444, 0.195904, 0.013141}}],
    Polygon[{{1.874205, 0.194199, -0.013647},{1.875444, 0.195904, -0.013141},{
      1.874254, 0.196511, -0.013141},{1.873602, 0.194506, -0.013647}}],
    Polygon[{{1.875444, 0.195904, -0.013141},{1.876621, 0.197525, -0.012311},{
      1.874872, 0.198416, -0.012311},{1.874254, 0.196511, -0.013141}}],
    Polygon[{{1.876621, 0.197525, -0.012311},{1.877708, 0.199021, -0.011178},{
      1.875444, 0.200174, -0.011178},{1.874872, 0.198416, -0.012311}}],
    Polygon[{{1.877708, 0.199021, -0.011178},{1.878677, 0.200354, -0.009770},{
      1.875953, 0.201742, -0.009770},{1.875444, 0.200174, -0.011178}}],
    Polygon[{{1.878677, 0.200354, -0.009770},{1.879505, 0.201494, -0.008122},{
      1.876388, 0.203081, -0.008122},{1.875953, 0.201742, -0.009770}}],
    Polygon[{{1.879505, 0.201494, -0.008122},{1.880170, 0.202410, -0.006273},{
      1.876738, 0.204159, -0.006273},{1.876388, 0.203081, -0.008122}}],
    Polygon[{{1.880170, 0.202410, -0.006273},{1.880658, 0.203081, -0.004270},{
      1.876995, 0.204948, -0.004270},{1.876738, 0.204159, -0.006273}}],
    Polygon[{{1.880658, 0.203081, -0.004270},{1.880956, 0.203491, -0.002162},{
      1.877151, 0.205429, -0.002162},{1.876995, 0.204948, -0.004270}}],
    Polygon[{{1.880956, 0.203491, -0.002162},{1.881056, 0.203629, 0.000000},{
      1.877204, 0.205591, 0.000000},{1.877151, 0.205429, -0.002162}}],
    Polygon[{{1.881056, 0.203629, 0.000000},{1.880956, 0.203491, 0.002162},{
      1.877151, 0.205429, 0.002162},{1.877204, 0.205591, 0.000000}}],
    Polygon[{{1.880956, 0.203491, 0.002162},{1.880658, 0.203081, 0.004270},{
      1.876995, 0.204948, 0.004270},{1.877151, 0.205429, 0.002162}}],
    Polygon[{{1.880658, 0.203081, 0.004270},{1.880170, 0.202410, 0.006273},{
      1.876738, 0.204159, 0.006273},{1.876995, 0.204948, 0.004270}}],
    Polygon[{{1.880170, 0.202410, 0.006273},{1.879505, 0.201494, 0.008122},{
      1.876388, 0.203081, 0.008122},{1.876738, 0.204159, 0.006273}}],
    Polygon[{{1.879505, 0.201494, 0.008122},{1.878677, 0.200354, 0.009770},{
      1.875953, 0.201742, 0.009770},{1.876388, 0.203081, 0.008122}}],
    Polygon[{{1.878677, 0.200354, 0.009770},{1.877708, 0.199021, 0.011178},{
      1.875444, 0.200174, 0.011178},{1.875953, 0.201742, 0.009770}}],
    Polygon[{{1.877708, 0.199021, 0.011178},{1.876621, 0.197525, 0.012311},{
      1.874872, 0.198416, 0.012311},{1.875444, 0.200174, 0.011178}}],
    Polygon[{{1.876621, 0.197525, 0.012311},{1.875444, 0.195904, 0.013141},{
      1.874254, 0.196511, 0.013141},{1.874872, 0.198416, 0.012311}}],
    Polygon[{{1.875444, 0.195904, 0.013141},{1.874205, 0.194199, 0.013647},{
      1.873602, 0.194506, 0.013647},{1.874254, 0.196511, 0.013141}}],
    Polygon[{{1.873602, 0.194506, -0.013647},{1.874254, 0.196511, -0.013141},{
      1.872934, 0.196720, -0.013141},{1.872934, 0.194612, -0.013647}}],
    Polygon[{{1.874254, 0.196511, -0.013141},{1.874872, 0.198416, -0.012311},{
      1.872934, 0.198723, -0.012311},{1.872934, 0.196720, -0.013141}}],
    Polygon[{{1.874872, 0.198416, -0.012311},{1.875444, 0.200174, -0.011178},{
      1.872934, 0.200572, -0.011178},{1.872934, 0.198723, -0.012311}}],
    Polygon[{{1.875444, 0.200174, -0.011178},{1.875953, 0.201742, -0.009770},{
      1.872934, 0.202220, -0.009770},{1.872934, 0.200572, -0.011178}}],
    Polygon[{{1.875953, 0.201742, -0.009770},{1.876388, 0.203081, -0.008122},{
      1.872934, 0.203629, -0.008122},{1.872934, 0.202220, -0.009770}}],
    Polygon[{{1.876388, 0.203081, -0.008122},{1.876738, 0.204159, -0.006273},{
      1.872934, 0.204761, -0.006273},{1.872934, 0.203629, -0.008122}}],
    Polygon[{{1.876738, 0.204159, -0.006273},{1.876995, 0.204948, -0.004270},{
      1.872934, 0.205591, -0.004270},{1.872934, 0.204761, -0.006273}}],
    Polygon[{{1.876995, 0.204948, -0.004270},{1.877151, 0.205429, -0.002162},{
      1.872934, 0.206097, -0.002162},{1.872934, 0.205591, -0.004270}}],
    Polygon[{{1.877151, 0.205429, -0.002162},{1.877204, 0.205591, 0.000000},{
      1.872934, 0.206267, 0.000000},{1.872934, 0.206097, -0.002162}}],
    Polygon[{{1.877204, 0.205591, 0.000000},{1.877151, 0.205429, 0.002162},{
      1.872934, 0.206097, 0.002162},{1.872934, 0.206267, 0.000000}}],
    Polygon[{{1.877151, 0.205429, 0.002162},{1.876995, 0.204948, 0.004270},{
      1.872934, 0.205591, 0.004270},{1.872934, 0.206097, 0.002162}}],
    Polygon[{{1.876995, 0.204948, 0.004270},{1.876738, 0.204159, 0.006273},{
      1.872934, 0.204761, 0.006273},{1.872934, 0.205591, 0.004270}}],
    Polygon[{{1.876738, 0.204159, 0.006273},{1.876388, 0.203081, 0.008122},{
      1.872934, 0.203629, 0.008122},{1.872934, 0.204761, 0.006273}}],
    Polygon[{{1.876388, 0.203081, 0.008122},{1.875953, 0.201742, 0.009770},{
      1.872934, 0.202220, 0.009770},{1.872934, 0.203629, 0.008122}}],
    Polygon[{{1.875953, 0.201742, 0.009770},{1.875444, 0.200174, 0.011178},{
      1.872934, 0.200572, 0.011178},{1.872934, 0.202220, 0.009770}}],
    Polygon[{{1.875444, 0.200174, 0.011178},{1.874872, 0.198416, 0.012311},{
      1.872934, 0.198723, 0.012311},{1.872934, 0.200572, 0.011178}}],
    Polygon[{{1.874872, 0.198416, 0.012311},{1.874254, 0.196511, 0.013141},{
      1.872934, 0.196720, 0.013141},{1.872934, 0.198723, 0.012311}}],
    Polygon[{{1.874254, 0.196511, 0.013141},{1.873602, 0.194506, 0.013647},{
      1.872934, 0.194612, 0.013647},{1.872934, 0.196720, 0.013141}}],
    Polygon[{{1.872934, 0.194612, -0.013647},{1.872934, 0.196720, -0.013141},{
      1.871615, 0.196511, -0.013141},{1.872266, 0.194506, -0.013647}}],
    Polygon[{{1.872934, 0.196720, -0.013141},{1.872934, 0.198723, -0.012311},{
      1.870996, 0.198416, -0.012311},{1.871615, 0.196511, -0.013141}}],
    Polygon[{{1.872934, 0.198723, -0.012311},{1.872934, 0.200572, -0.011178},{
      1.870424, 0.200174, -0.011178},{1.870996, 0.198416, -0.012311}}],
    Polygon[{{1.872934, 0.200572, -0.011178},{1.872934, 0.202220, -0.009770},{
      1.869915, 0.201742, -0.009770},{1.870424, 0.200174, -0.011178}}],
    Polygon[{{1.872934, 0.202220, -0.009770},{1.872934, 0.203629, -0.008122},{
      1.869480, 0.203081, -0.008122},{1.869915, 0.201742, -0.009770}}],
    Polygon[{{1.872934, 0.203629, -0.008122},{1.872934, 0.204761, -0.006273},{
      1.869130, 0.204159, -0.006273},{1.869480, 0.203081, -0.008122}}],
    Polygon[{{1.872934, 0.204761, -0.006273},{1.872934, 0.205591, -0.004270},{
      1.868873, 0.204948, -0.004270},{1.869130, 0.204159, -0.006273}}],
    Polygon[{{1.872934, 0.205591, -0.004270},{1.872934, 0.206097, -0.002162},{
      1.868717, 0.205429, -0.002162},{1.868873, 0.204948, -0.004270}}],
    Polygon[{{1.872934, 0.206097, -0.002162},{1.872934, 0.206267, 0.000000},{
      1.868664, 0.205591, 0.000000},{1.868717, 0.205429, -0.002162}}],
    Polygon[{{1.872934, 0.206267, 0.000000},{1.872934, 0.206097, 0.002162},{
      1.868717, 0.205429, 0.002162},{1.868664, 0.205591, 0.000000}}],
    Polygon[{{1.872934, 0.206097, 0.002162},{1.872934, 0.205591, 0.004270},{
      1.868873, 0.204948, 0.004270},{1.868717, 0.205429, 0.002162}}],
    Polygon[{{1.872934, 0.205591, 0.004270},{1.872934, 0.204761, 0.006273},{
      1.869130, 0.204159, 0.006273},{1.868873, 0.204948, 0.004270}}],
    Polygon[{{1.872934, 0.204761, 0.006273},{1.872934, 0.203629, 0.008122},{
      1.869480, 0.203081, 0.008122},{1.869130, 0.204159, 0.006273}}],
    Polygon[{{1.872934, 0.203629, 0.008122},{1.872934, 0.202220, 0.009770},{
      1.869915, 0.201742, 0.009770},{1.869480, 0.203081, 0.008122}}],
    Polygon[{{1.872934, 0.202220, 0.009770},{1.872934, 0.200572, 0.011178},{
      1.870424, 0.200174, 0.011178},{1.869915, 0.201742, 0.009770}}],
    Polygon[{{1.872934, 0.200572, 0.011178},{1.872934, 0.198723, 0.012311},{
      1.870996, 0.198416, 0.012311},{1.870424, 0.200174, 0.011178}}],
    Polygon[{{1.872934, 0.198723, 0.012311},{1.872934, 0.196720, 0.013141},{
      1.871615, 0.196511, 0.013141},{1.870996, 0.198416, 0.012311}}],
    Polygon[{{1.872934, 0.196720, 0.013141},{1.872934, 0.194612, 0.013647},{
      1.872266, 0.194506, 0.013647},{1.871615, 0.196511, 0.013141}}],
    Polygon[{{1.872266, 0.194506, -0.013647},{1.871615, 0.196511, -0.013141},{
      1.870424, 0.195904, -0.013141},{1.871664, 0.194199, -0.013647}}],
    Polygon[{{1.871615, 0.196511, -0.013141},{1.870996, 0.198416, -0.012311},{
      1.869247, 0.197525, -0.012311},{1.870424, 0.195904, -0.013141}}],
    Polygon[{{1.870996, 0.198416, -0.012311},{1.870424, 0.200174, -0.011178},{
      1.868160, 0.199021, -0.011178},{1.869247, 0.197525, -0.012311}}],
    Polygon[{{1.870424, 0.200174, -0.011178},{1.869915, 0.201742, -0.009770},{
      1.867191, 0.200354, -0.009770},{1.868160, 0.199021, -0.011178}}],
    Polygon[{{1.869915, 0.201742, -0.009770},{1.869480, 0.203081, -0.008122},{
      1.866364, 0.201494, -0.008122},{1.867191, 0.200354, -0.009770}}],
    Polygon[{{1.869480, 0.203081, -0.008122},{1.869130, 0.204159, -0.006273},{
      1.865698, 0.202410, -0.006273},{1.866364, 0.201494, -0.008122}}],
    Polygon[{{1.869130, 0.204159, -0.006273},{1.868873, 0.204948, -0.004270},{
      1.865210, 0.203081, -0.004270},{1.865698, 0.202410, -0.006273}}],
    Polygon[{{1.868873, 0.204948, -0.004270},{1.868717, 0.205429, -0.002162},{
      1.864912, 0.203491, -0.002162},{1.865210, 0.203081, -0.004270}}],
    Polygon[{{1.868717, 0.205429, -0.002162},{1.868664, 0.205591, 0.000000},{
      1.864812, 0.203629, 0.000000},{1.864912, 0.203491, -0.002162}}],
    Polygon[{{1.868664, 0.205591, 0.000000},{1.868717, 0.205429, 0.002162},{
      1.864912, 0.203491, 0.002162},{1.864812, 0.203629, 0.000000}}],
    Polygon[{{1.868717, 0.205429, 0.002162},{1.868873, 0.204948, 0.004270},{
      1.865210, 0.203081, 0.004270},{1.864912, 0.203491, 0.002162}}],
    Polygon[{{1.868873, 0.204948, 0.004270},{1.869130, 0.204159, 0.006273},{
      1.865698, 0.202410, 0.006273},{1.865210, 0.203081, 0.004270}}],
    Polygon[{{1.869130, 0.204159, 0.006273},{1.869480, 0.203081, 0.008122},{
      1.866364, 0.201494, 0.008122},{1.865698, 0.202410, 0.006273}}],
    Polygon[{{1.869480, 0.203081, 0.008122},{1.869915, 0.201742, 0.009770},{
      1.867191, 0.200354, 0.009770},{1.866364, 0.201494, 0.008122}}],
    Polygon[{{1.869915, 0.201742, 0.009770},{1.870424, 0.200174, 0.011178},{
      1.868160, 0.199021, 0.011178},{1.867191, 0.200354, 0.009770}}],
    Polygon[{{1.870424, 0.200174, 0.011178},{1.870996, 0.198416, 0.012311},{
      1.869247, 0.197525, 0.012311},{1.868160, 0.199021, 0.011178}}],
    Polygon[{{1.870996, 0.198416, 0.012311},{1.871615, 0.196511, 0.013141},{
      1.870424, 0.195904, 0.013141},{1.869247, 0.197525, 0.012311}}],
    Polygon[{{1.871615, 0.196511, 0.013141},{1.872266, 0.194506, 0.013647},{
      1.871664, 0.194199, 0.013647},{1.870424, 0.195904, 0.013141}}],
    Polygon[{{1.871664, 0.194199, -0.013647},{1.870424, 0.195904, -0.013141},{
      1.869480, 0.194960, -0.013141},{1.871185, 0.193721, -0.013647}}],
    Polygon[{{1.870424, 0.195904, -0.013141},{1.869247, 0.197525, -0.012311},{
      1.867859, 0.196137, -0.012311},{1.869480, 0.194960, -0.013141}}],
    Polygon[{{1.869247, 0.197525, -0.012311},{1.868160, 0.199021, -0.011178},{
      1.866364, 0.197224, -0.011178},{1.867859, 0.196137, -0.012311}}],
    Polygon[{{1.868160, 0.199021, -0.011178},{1.867191, 0.200354, -0.009770},{
      1.865030, 0.198193, -0.009770},{1.866364, 0.197224, -0.011178}}],
    Polygon[{{1.867191, 0.200354, -0.009770},{1.866364, 0.201494, -0.008122},{
      1.863891, 0.199021, -0.008122},{1.865030, 0.198193, -0.009770}}],
    Polygon[{{1.866364, 0.201494, -0.008122},{1.865698, 0.202410, -0.006273},{
      1.862974, 0.199686, -0.006273},{1.863891, 0.199021, -0.008122}}],
    Polygon[{{1.865698, 0.202410, -0.006273},{1.865210, 0.203081, -0.004270},{
      1.862303, 0.200174, -0.004270},{1.862974, 0.199686, -0.006273}}],
    Polygon[{{1.865210, 0.203081, -0.004270},{1.864912, 0.203491, -0.002162},{
      1.861893, 0.200472, -0.002162},{1.862303, 0.200174, -0.004270}}],
    Polygon[{{1.864912, 0.203491, -0.002162},{1.864812, 0.203629, 0.000000},{
      1.861756, 0.200572, 0.000000},{1.861893, 0.200472, -0.002162}}],
    Polygon[{{1.864812, 0.203629, 0.000000},{1.864912, 0.203491, 0.002162},{
      1.861893, 0.200472, 0.002162},{1.861756, 0.200572, 0.000000}}],
    Polygon[{{1.864912, 0.203491, 0.002162},{1.865210, 0.203081, 0.004270},{
      1.862303, 0.200174, 0.004270},{1.861893, 0.200472, 0.002162}}],
    Polygon[{{1.865210, 0.203081, 0.004270},{1.865698, 0.202410, 0.006273},{
      1.862974, 0.199686, 0.006273},{1.862303, 0.200174, 0.004270}}],
    Polygon[{{1.865698, 0.202410, 0.006273},{1.866364, 0.201494, 0.008122},{
      1.863891, 0.199021, 0.008122},{1.862974, 0.199686, 0.006273}}],
    Polygon[{{1.866364, 0.201494, 0.008122},{1.867191, 0.200354, 0.009770},{
      1.865030, 0.198193, 0.009770},{1.863891, 0.199021, 0.008122}}],
    Polygon[{{1.867191, 0.200354, 0.009770},{1.868160, 0.199021, 0.011178},{
      1.866364, 0.197224, 0.011178},{1.865030, 0.198193, 0.009770}}],
    Polygon[{{1.868160, 0.199021, 0.011178},{1.869247, 0.197525, 0.012311},{
      1.867859, 0.196137, 0.012311},{1.866364, 0.197224, 0.011178}}],
    Polygon[{{1.869247, 0.197525, 0.012311},{1.870424, 0.195904, 0.013141},{
      1.869480, 0.194960, 0.013141},{1.867859, 0.196137, 0.012311}}],
    Polygon[{{1.870424, 0.195904, 0.013141},{1.871664, 0.194199, 0.013647},{
      1.871185, 0.193721, 0.013647},{1.869480, 0.194960, 0.013141}}],
    Polygon[{{1.871185, 0.193721, -0.013647},{1.869480, 0.194960, -0.013141},{
      1.868873, 0.193770, -0.013141},{1.870878, 0.193118, -0.013647}}],
    Polygon[{{1.869480, 0.194960, -0.013141},{1.867859, 0.196137, -0.012311},{
      1.866968, 0.194389, -0.012311},{1.868873, 0.193770, -0.013141}}],
    Polygon[{{1.867859, 0.196137, -0.012311},{1.866364, 0.197224, -0.011178},{
      1.865210, 0.194960, -0.011178},{1.866968, 0.194389, -0.012311}}],
    Polygon[{{1.866364, 0.197224, -0.011178},{1.865030, 0.198193, -0.009770},{
      1.863642, 0.195469, -0.009770},{1.865210, 0.194960, -0.011178}}],
    Polygon[{{1.865030, 0.198193, -0.009770},{1.863891, 0.199021, -0.008122},{
      1.862303, 0.195904, -0.008122},{1.863642, 0.195469, -0.009770}}],
    Polygon[{{1.863891, 0.199021, -0.008122},{1.862974, 0.199686, -0.006273},{
      1.861225, 0.196254, -0.006273},{1.862303, 0.195904, -0.008122}}],
    Polygon[{{1.862974, 0.199686, -0.006273},{1.862303, 0.200174, -0.004270},{
      1.860436, 0.196511, -0.004270},{1.861225, 0.196254, -0.006273}}],
    Polygon[{{1.862303, 0.200174, -0.004270},{1.861893, 0.200472, -0.002162},{
      1.859955, 0.196667, -0.002162},{1.860436, 0.196511, -0.004270}}],
    Polygon[{{1.861893, 0.200472, -0.002162},{1.861756, 0.200572, 0.000000},{
      1.859793, 0.196720, 0.000000},{1.859955, 0.196667, -0.002162}}],
    Polygon[{{1.861756, 0.200572, 0.000000},{1.861893, 0.200472, 0.002162},{
      1.859955, 0.196667, 0.002162},{1.859793, 0.196720, 0.000000}}],
    Polygon[{{1.861893, 0.200472, 0.002162},{1.862303, 0.200174, 0.004270},{
      1.860436, 0.196511, 0.004270},{1.859955, 0.196667, 0.002162}}],
    Polygon[{{1.862303, 0.200174, 0.004270},{1.862974, 0.199686, 0.006273},{
      1.861225, 0.196254, 0.006273},{1.860436, 0.196511, 0.004270}}],
    Polygon[{{1.862974, 0.199686, 0.006273},{1.863891, 0.199021, 0.008122},{
      1.862303, 0.195904, 0.008122},{1.861225, 0.196254, 0.006273}}],
    Polygon[{{1.863891, 0.199021, 0.008122},{1.865030, 0.198193, 0.009770},{
      1.863642, 0.195469, 0.009770},{1.862303, 0.195904, 0.008122}}],
    Polygon[{{1.865030, 0.198193, 0.009770},{1.866364, 0.197224, 0.011178},{
      1.865210, 0.194960, 0.011178},{1.863642, 0.195469, 0.009770}}],
    Polygon[{{1.866364, 0.197224, 0.011178},{1.867859, 0.196137, 0.012311},{
      1.866968, 0.194389, 0.012311},{1.865210, 0.194960, 0.011178}}],
    Polygon[{{1.867859, 0.196137, 0.012311},{1.869480, 0.194960, 0.013141},{
      1.868873, 0.193770, 0.013141},{1.866968, 0.194389, 0.012311}}],
    Polygon[{{1.869480, 0.194960, 0.013141},{1.871185, 0.193721, 0.013647},{
      1.870878, 0.193118, 0.013647},{1.868873, 0.193770, 0.013141}}],
    Polygon[{{1.870878, 0.193118, -0.013647},{1.868873, 0.193770, -0.013141},{
      1.868664, 0.192450, -0.013141},{1.870773, 0.192450, -0.013647}}],
    Polygon[{{1.868873, 0.193770, -0.013141},{1.866968, 0.194389, -0.012311},{
      1.866661, 0.192450, -0.012311},{1.868664, 0.192450, -0.013141}}],
    Polygon[{{1.866968, 0.194389, -0.012311},{1.865210, 0.194960, -0.011178},{
      1.864812, 0.192450, -0.011178},{1.866661, 0.192450, -0.012311}}],
    Polygon[{{1.865210, 0.194960, -0.011178},{1.863642, 0.195469, -0.009770},{
      1.863164, 0.192450, -0.009770},{1.864812, 0.192450, -0.011178}}],
    Polygon[{{1.863642, 0.195469, -0.009770},{1.862303, 0.195904, -0.008122},{
      1.861756, 0.192450, -0.008122},{1.863164, 0.192450, -0.009770}}],
    Polygon[{{1.862303, 0.195904, -0.008122},{1.861225, 0.196254, -0.006273},{
      1.860623, 0.192450, -0.006273},{1.861756, 0.192450, -0.008122}}],
    Polygon[{{1.861225, 0.196254, -0.006273},{1.860436, 0.196511, -0.004270},{
      1.859793, 0.192450, -0.004270},{1.860623, 0.192450, -0.006273}}],
    Polygon[{{1.860436, 0.196511, -0.004270},{1.859955, 0.196667, -0.002162},{
      1.859287, 0.192450, -0.002162},{1.859793, 0.192450, -0.004270}}],
    Polygon[{{1.859955, 0.196667, -0.002162},{1.859793, 0.196720, 0.000000},{
      1.859117, 0.192450, 0.000000},{1.859287, 0.192450, -0.002162}}],
    Polygon[{{1.859793, 0.196720, 0.000000},{1.859955, 0.196667, 0.002162},{
      1.859287, 0.192450, 0.002162},{1.859117, 0.192450, 0.000000}}],
    Polygon[{{1.859955, 0.196667, 0.002162},{1.860436, 0.196511, 0.004270},{
      1.859793, 0.192450, 0.004270},{1.859287, 0.192450, 0.002162}}],
    Polygon[{{1.860436, 0.196511, 0.004270},{1.861225, 0.196254, 0.006273},{
      1.860623, 0.192450, 0.006273},{1.859793, 0.192450, 0.004270}}],
    Polygon[{{1.861225, 0.196254, 0.006273},{1.862303, 0.195904, 0.008122},{
      1.861756, 0.192450, 0.008122},{1.860623, 0.192450, 0.006273}}],
    Polygon[{{1.862303, 0.195904, 0.008122},{1.863642, 0.195469, 0.009770},{
      1.863164, 0.192450, 0.009770},{1.861756, 0.192450, 0.008122}}],
    Polygon[{{1.863642, 0.195469, 0.009770},{1.865210, 0.194960, 0.011178},{
      1.864812, 0.192450, 0.011178},{1.863164, 0.192450, 0.009770}}],
    Polygon[{{1.865210, 0.194960, 0.011178},{1.866968, 0.194389, 0.012311},{
      1.866661, 0.192450, 0.012311},{1.864812, 0.192450, 0.011178}}],
    Polygon[{{1.866968, 0.194389, 0.012311},{1.868873, 0.193770, 0.013141},{
      1.868664, 0.192450, 0.013141},{1.866661, 0.192450, 0.012311}}],
    Polygon[{{1.868873, 0.193770, 0.013141},{1.870878, 0.193118, 0.013647},{
      1.870773, 0.192450, 0.013647},{1.868664, 0.192450, 0.013141}}],
    Polygon[{{1.870773, 0.192450, -0.013647},{1.868664, 0.192450, -0.013141},{
      1.868873, 0.191131, -0.013141},{1.870878, 0.191782, -0.013647}}],
    Polygon[{{1.868664, 0.192450, -0.013141},{1.866661, 0.192450, -0.012311},{
      1.866968, 0.190512, -0.012311},{1.868873, 0.191131, -0.013141}}],
    Polygon[{{1.866661, 0.192450, -0.012311},{1.864812, 0.192450, -0.011178},{
      1.865210, 0.189940, -0.011178},{1.866968, 0.190512, -0.012311}}],
    Polygon[{{1.864812, 0.192450, -0.011178},{1.863164, 0.192450, -0.009770},{
      1.863642, 0.189431, -0.009770},{1.865210, 0.189940, -0.011178}}],
    Polygon[{{1.863164, 0.192450, -0.009770},{1.861756, 0.192450, -0.008122},{
      1.862303, 0.188996, -0.008122},{1.863642, 0.189431, -0.009770}}],
    Polygon[{{1.861756, 0.192450, -0.008122},{1.860623, 0.192450, -0.006273},{
      1.861225, 0.188646, -0.006273},{1.862303, 0.188996, -0.008122}}],
    Polygon[{{1.860623, 0.192450, -0.006273},{1.859793, 0.192450, -0.004270},{
      1.860436, 0.188389, -0.004270},{1.861225, 0.188646, -0.006273}}],
    Polygon[{{1.859793, 0.192450, -0.004270},{1.859287, 0.192450, -0.002162},{
      1.859955, 0.188233, -0.002162},{1.860436, 0.188389, -0.004270}}],
    Polygon[{{1.859287, 0.192450, -0.002162},{1.859117, 0.192450, 0.000000},{
      1.859793, 0.188180, 0.000000},{1.859955, 0.188233, -0.002162}}],
    Polygon[{{1.859117, 0.192450, 0.000000},{1.859287, 0.192450, 0.002162},{
      1.859955, 0.188233, 0.002162},{1.859793, 0.188180, 0.000000}}],
    Polygon[{{1.859287, 0.192450, 0.002162},{1.859793, 0.192450, 0.004270},{
      1.860436, 0.188389, 0.004270},{1.859955, 0.188233, 0.002162}}],
    Polygon[{{1.859793, 0.192450, 0.004270},{1.860623, 0.192450, 0.006273},{
      1.861225, 0.188646, 0.006273},{1.860436, 0.188389, 0.004270}}],
    Polygon[{{1.860623, 0.192450, 0.006273},{1.861756, 0.192450, 0.008122},{
      1.862303, 0.188996, 0.008122},{1.861225, 0.188646, 0.006273}}],
    Polygon[{{1.861756, 0.192450, 0.008122},{1.863164, 0.192450, 0.009770},{
      1.863642, 0.189431, 0.009770},{1.862303, 0.188996, 0.008122}}],
    Polygon[{{1.863164, 0.192450, 0.009770},{1.864812, 0.192450, 0.011178},{
      1.865210, 0.189940, 0.011178},{1.863642, 0.189431, 0.009770}}],
    Polygon[{{1.864812, 0.192450, 0.011178},{1.866661, 0.192450, 0.012311},{
      1.866968, 0.190512, 0.012311},{1.865210, 0.189940, 0.011178}}],
    Polygon[{{1.866661, 0.192450, 0.012311},{1.868664, 0.192450, 0.013141},{
      1.868873, 0.191131, 0.013141},{1.866968, 0.190512, 0.012311}}],
    Polygon[{{1.868664, 0.192450, 0.013141},{1.870773, 0.192450, 0.013647},{
      1.870878, 0.191782, 0.013647},{1.868873, 0.191131, 0.013141}}],
    Polygon[{{1.870878, 0.191782, -0.013647},{1.868873, 0.191131, -0.013141},{
      1.869480, 0.189940, -0.013141},{1.871185, 0.191180, -0.013647}}],
    Polygon[{{1.868873, 0.191131, -0.013141},{1.866968, 0.190512, -0.012311},{
      1.867859, 0.188763, -0.012311},{1.869480, 0.189940, -0.013141}}],
    Polygon[{{1.866968, 0.190512, -0.012311},{1.865210, 0.189940, -0.011178},{
      1.866364, 0.187676, -0.011178},{1.867859, 0.188763, -0.012311}}],
    Polygon[{{1.865210, 0.189940, -0.011178},{1.863642, 0.189431, -0.009770},{
      1.865030, 0.186707, -0.009770},{1.866364, 0.187676, -0.011178}}],
    Polygon[{{1.863642, 0.189431, -0.009770},{1.862303, 0.188996, -0.008122},{
      1.863891, 0.185880, -0.008122},{1.865030, 0.186707, -0.009770}}],
    Polygon[{{1.862303, 0.188996, -0.008122},{1.861225, 0.188646, -0.006273},{
      1.862974, 0.185214, -0.006273},{1.863891, 0.185880, -0.008122}}],
    Polygon[{{1.861225, 0.188646, -0.006273},{1.860436, 0.188389, -0.004270},{
      1.862303, 0.184726, -0.004270},{1.862974, 0.185214, -0.006273}}],
    Polygon[{{1.860436, 0.188389, -0.004270},{1.859955, 0.188233, -0.002162},{
      1.861893, 0.184428, -0.002162},{1.862303, 0.184726, -0.004270}}],
    Polygon[{{1.859955, 0.188233, -0.002162},{1.859793, 0.188180, 0.000000},{
      1.861756, 0.184328, 0.000000},{1.861893, 0.184428, -0.002162}}],
    Polygon[{{1.859793, 0.188180, 0.000000},{1.859955, 0.188233, 0.002162},{
      1.861893, 0.184428, 0.002162},{1.861756, 0.184328, 0.000000}}],
    Polygon[{{1.859955, 0.188233, 0.002162},{1.860436, 0.188389, 0.004270},{
      1.862303, 0.184726, 0.004270},{1.861893, 0.184428, 0.002162}}],
    Polygon[{{1.860436, 0.188389, 0.004270},{1.861225, 0.188646, 0.006273},{
      1.862974, 0.185214, 0.006273},{1.862303, 0.184726, 0.004270}}],
    Polygon[{{1.861225, 0.188646, 0.006273},{1.862303, 0.188996, 0.008122},{
      1.863891, 0.185880, 0.008122},{1.862974, 0.185214, 0.006273}}],
    Polygon[{{1.862303, 0.188996, 0.008122},{1.863642, 0.189431, 0.009770},{
      1.865030, 0.186707, 0.009770},{1.863891, 0.185880, 0.008122}}],
    Polygon[{{1.863642, 0.189431, 0.009770},{1.865210, 0.189940, 0.011178},{
      1.866364, 0.187676, 0.011178},{1.865030, 0.186707, 0.009770}}],
    Polygon[{{1.865210, 0.189940, 0.011178},{1.866968, 0.190512, 0.012311},{
      1.867859, 0.188763, 0.012311},{1.866364, 0.187676, 0.011178}}],
    Polygon[{{1.866968, 0.190512, 0.012311},{1.868873, 0.191131, 0.013141},{
      1.869480, 0.189940, 0.013141},{1.867859, 0.188763, 0.012311}}],
    Polygon[{{1.868873, 0.191131, 0.013141},{1.870878, 0.191782, 0.013647},{
      1.871185, 0.191180, 0.013647},{1.869480, 0.189940, 0.013141}}],
    Polygon[{{1.871185, 0.191180, -0.013647},{1.869480, 0.189940, -0.013141},{
      1.870424, 0.188996, -0.013141},{1.871664, 0.190701, -0.013647}}],
    Polygon[{{1.869480, 0.189940, -0.013141},{1.867859, 0.188763, -0.012311},{
      1.869247, 0.187375, -0.012311},{1.870424, 0.188996, -0.013141}}],
    Polygon[{{1.867859, 0.188763, -0.012311},{1.866364, 0.187676, -0.011178},{
      1.868160, 0.185880, -0.011178},{1.869247, 0.187375, -0.012311}}],
    Polygon[{{1.866364, 0.187676, -0.011178},{1.865030, 0.186707, -0.009770},{
      1.867191, 0.184546, -0.009770},{1.868160, 0.185880, -0.011178}}],
    Polygon[{{1.865030, 0.186707, -0.009770},{1.863891, 0.185880, -0.008122},{
      1.866364, 0.183407, -0.008122},{1.867191, 0.184546, -0.009770}}],
    Polygon[{{1.863891, 0.185880, -0.008122},{1.862974, 0.185214, -0.006273},{
      1.865698, 0.182490, -0.006273},{1.866364, 0.183407, -0.008122}}],
    Polygon[{{1.862974, 0.185214, -0.006273},{1.862303, 0.184726, -0.004270},{
      1.865210, 0.181819, -0.004270},{1.865698, 0.182490, -0.006273}}],
    Polygon[{{1.862303, 0.184726, -0.004270},{1.861893, 0.184428, -0.002162},{
      1.864912, 0.181409, -0.002162},{1.865210, 0.181819, -0.004270}}],
    Polygon[{{1.861893, 0.184428, -0.002162},{1.861756, 0.184328, 0.000000},{
      1.864812, 0.181272, 0.000000},{1.864912, 0.181409, -0.002162}}],
    Polygon[{{1.861756, 0.184328, 0.000000},{1.861893, 0.184428, 0.002162},{
      1.864912, 0.181409, 0.002162},{1.864812, 0.181272, 0.000000}}],
    Polygon[{{1.861893, 0.184428, 0.002162},{1.862303, 0.184726, 0.004270},{
      1.865210, 0.181819, 0.004270},{1.864912, 0.181409, 0.002162}}],
    Polygon[{{1.862303, 0.184726, 0.004270},{1.862974, 0.185214, 0.006273},{
      1.865698, 0.182490, 0.006273},{1.865210, 0.181819, 0.004270}}],
    Polygon[{{1.862974, 0.185214, 0.006273},{1.863891, 0.185880, 0.008122},{
      1.866364, 0.183407, 0.008122},{1.865698, 0.182490, 0.006273}}],
    Polygon[{{1.863891, 0.185880, 0.008122},{1.865030, 0.186707, 0.009770},{
      1.867191, 0.184546, 0.009770},{1.866364, 0.183407, 0.008122}}],
    Polygon[{{1.865030, 0.186707, 0.009770},{1.866364, 0.187676, 0.011178},{
      1.868160, 0.185880, 0.011178},{1.867191, 0.184546, 0.009770}}],
    Polygon[{{1.866364, 0.187676, 0.011178},{1.867859, 0.188763, 0.012311},{
      1.869247, 0.187375, 0.012311},{1.868160, 0.185880, 0.011178}}],
    Polygon[{{1.867859, 0.188763, 0.012311},{1.869480, 0.189940, 0.013141},{
      1.870424, 0.188996, 0.013141},{1.869247, 0.187375, 0.012311}}],
    Polygon[{{1.869480, 0.189940, 0.013141},{1.871185, 0.191180, 0.013647},{
      1.871664, 0.190701, 0.013647},{1.870424, 0.188996, 0.013141}}],
    Polygon[{{1.871664, 0.190701, -0.013647},{1.870424, 0.188996, -0.013141},{
      1.871615, 0.188389, -0.013141},{1.872266, 0.190394, -0.013647}}],
    Polygon[{{1.870424, 0.188996, -0.013141},{1.869247, 0.187375, -0.012311},{
      1.870996, 0.186484, -0.012311},{1.871615, 0.188389, -0.013141}}],
    Polygon[{{1.869247, 0.187375, -0.012311},{1.868160, 0.185880, -0.011178},{
      1.870424, 0.184726, -0.011178},{1.870996, 0.186484, -0.012311}}],
    Polygon[{{1.868160, 0.185880, -0.011178},{1.867191, 0.184546, -0.009770},{
      1.869915, 0.183158, -0.009770},{1.870424, 0.184726, -0.011178}}],
    Polygon[{{1.867191, 0.184546, -0.009770},{1.866364, 0.183407, -0.008122},{
      1.869480, 0.181819, -0.008122},{1.869915, 0.183158, -0.009770}}],
    Polygon[{{1.866364, 0.183407, -0.008122},{1.865698, 0.182490, -0.006273},{
      1.869130, 0.180741, -0.006273},{1.869480, 0.181819, -0.008122}}],
    Polygon[{{1.865698, 0.182490, -0.006273},{1.865210, 0.181819, -0.004270},{
      1.868873, 0.179952, -0.004270},{1.869130, 0.180741, -0.006273}}],
    Polygon[{{1.865210, 0.181819, -0.004270},{1.864912, 0.181409, -0.002162},{
      1.868717, 0.179471, -0.002162},{1.868873, 0.179952, -0.004270}}],
    Polygon[{{1.864912, 0.181409, -0.002162},{1.864812, 0.181272, 0.000000},{
      1.868664, 0.179309, 0.000000},{1.868717, 0.179471, -0.002162}}],
    Polygon[{{1.864812, 0.181272, 0.000000},{1.864912, 0.181409, 0.002162},{
      1.868717, 0.179471, 0.002162},{1.868664, 0.179309, 0.000000}}],
    Polygon[{{1.864912, 0.181409, 0.002162},{1.865210, 0.181819, 0.004270},{
      1.868873, 0.179952, 0.004270},{1.868717, 0.179471, 0.002162}}],
    Polygon[{{1.865210, 0.181819, 0.004270},{1.865698, 0.182490, 0.006273},{
      1.869130, 0.180741, 0.006273},{1.868873, 0.179952, 0.004270}}],
    Polygon[{{1.865698, 0.182490, 0.006273},{1.866364, 0.183407, 0.008122},{
      1.869480, 0.181819, 0.008122},{1.869130, 0.180741, 0.006273}}],
    Polygon[{{1.866364, 0.183407, 0.008122},{1.867191, 0.184546, 0.009770},{
      1.869915, 0.183158, 0.009770},{1.869480, 0.181819, 0.008122}}],
    Polygon[{{1.867191, 0.184546, 0.009770},{1.868160, 0.185880, 0.011178},{
      1.870424, 0.184726, 0.011178},{1.869915, 0.183158, 0.009770}}],
    Polygon[{{1.868160, 0.185880, 0.011178},{1.869247, 0.187375, 0.012311},{
      1.870996, 0.186484, 0.012311},{1.870424, 0.184726, 0.011178}}],
    Polygon[{{1.869247, 0.187375, 0.012311},{1.870424, 0.188996, 0.013141},{
      1.871615, 0.188389, 0.013141},{1.870996, 0.186484, 0.012311}}],
    Polygon[{{1.870424, 0.188996, 0.013141},{1.871664, 0.190701, 0.013647},{
      1.872266, 0.190394, 0.013647},{1.871615, 0.188389, 0.013141}}],
    Polygon[{{1.872266, 0.190394, -0.013647},{1.871615, 0.188389, -0.013141},{
      1.872934, 0.188180, -0.013141},{1.872934, 0.190289, -0.013647}}],
    Polygon[{{1.871615, 0.188389, -0.013141},{1.870996, 0.186484, -0.012311},{
      1.872934, 0.186177, -0.012311},{1.872934, 0.188180, -0.013141}}],
    Polygon[{{1.870996, 0.186484, -0.012311},{1.870424, 0.184726, -0.011178},{
      1.872934, 0.184328, -0.011178},{1.872934, 0.186177, -0.012311}}],
    Polygon[{{1.870424, 0.184726, -0.011178},{1.869915, 0.183158, -0.009770},{
      1.872934, 0.182680, -0.009770},{1.872934, 0.184328, -0.011178}}],
    Polygon[{{1.869915, 0.183158, -0.009770},{1.869480, 0.181819, -0.008122},{
      1.872934, 0.181272, -0.008122},{1.872934, 0.182680, -0.009770}}],
    Polygon[{{1.869480, 0.181819, -0.008122},{1.869130, 0.180741, -0.006273},{
      1.872934, 0.180139, -0.006273},{1.872934, 0.181272, -0.008122}}],
    Polygon[{{1.869130, 0.180741, -0.006273},{1.868873, 0.179952, -0.004270},{
      1.872934, 0.179309, -0.004270},{1.872934, 0.180139, -0.006273}}],
    Polygon[{{1.868873, 0.179952, -0.004270},{1.868717, 0.179471, -0.002162},{
      1.872934, 0.178803, -0.002162},{1.872934, 0.179309, -0.004270}}],
    Polygon[{{1.868717, 0.179471, -0.002162},{1.868664, 0.179309, 0.000000},{
      1.872934, 0.178633, 0.000000},{1.872934, 0.178803, -0.002162}}],
    Polygon[{{1.868664, 0.179309, 0.000000},{1.868717, 0.179471, 0.002162},{
      1.872934, 0.178803, 0.002162},{1.872934, 0.178633, 0.000000}}],
    Polygon[{{1.868717, 0.179471, 0.002162},{1.868873, 0.179952, 0.004270},{
      1.872934, 0.179309, 0.004270},{1.872934, 0.178803, 0.002162}}],
    Polygon[{{1.868873, 0.179952, 0.004270},{1.869130, 0.180741, 0.006273},{
      1.872934, 0.180139, 0.006273},{1.872934, 0.179309, 0.004270}}],
    Polygon[{{1.869130, 0.180741, 0.006273},{1.869480, 0.181819, 0.008122},{
      1.872934, 0.181272, 0.008122},{1.872934, 0.180139, 0.006273}}],
    Polygon[{{1.869480, 0.181819, 0.008122},{1.869915, 0.183158, 0.009770},{
      1.872934, 0.182680, 0.009770},{1.872934, 0.181272, 0.008122}}],
    Polygon[{{1.869915, 0.183158, 0.009770},{1.870424, 0.184726, 0.011178},{
      1.872934, 0.184328, 0.011178},{1.872934, 0.182680, 0.009770}}],
    Polygon[{{1.870424, 0.184726, 0.011178},{1.870996, 0.186484, 0.012311},{
      1.872934, 0.186177, 0.012311},{1.872934, 0.184328, 0.011178}}],
    Polygon[{{1.870996, 0.186484, 0.012311},{1.871615, 0.188389, 0.013141},{
      1.872934, 0.188180, 0.013141},{1.872934, 0.186177, 0.012311}}],
    Polygon[{{1.871615, 0.188389, 0.013141},{1.872266, 0.190394, 0.013647},{
      1.872934, 0.190289, 0.013647},{1.872934, 0.188180, 0.013141}}],
    Polygon[{{1.872934, 0.190289, -0.013647},{1.872934, 0.188180, -0.013141},{
      1.874254, 0.188389, -0.013141},{1.873602, 0.190394, -0.013647}}],
    Polygon[{{1.872934, 0.188180, -0.013141},{1.872934, 0.186177, -0.012311},{
      1.874872, 0.186484, -0.012311},{1.874254, 0.188389, -0.013141}}],
    Polygon[{{1.872934, 0.186177, -0.012311},{1.872934, 0.184328, -0.011178},{
      1.875444, 0.184726, -0.011178},{1.874872, 0.186484, -0.012311}}],
    Polygon[{{1.872934, 0.184328, -0.011178},{1.872934, 0.182680, -0.009770},{
      1.875953, 0.183158, -0.009770},{1.875444, 0.184726, -0.011178}}],
    Polygon[{{1.872934, 0.182680, -0.009770},{1.872934, 0.181272, -0.008122},{
      1.876388, 0.181819, -0.008122},{1.875953, 0.183158, -0.009770}}],
    Polygon[{{1.872934, 0.181272, -0.008122},{1.872934, 0.180139, -0.006273},{
      1.876738, 0.180741, -0.006273},{1.876388, 0.181819, -0.008122}}],
    Polygon[{{1.872934, 0.180139, -0.006273},{1.872934, 0.179309, -0.004270},{
      1.876995, 0.179952, -0.004270},{1.876738, 0.180741, -0.006273}}],
    Polygon[{{1.872934, 0.179309, -0.004270},{1.872934, 0.178803, -0.002162},{
      1.877151, 0.179471, -0.002162},{1.876995, 0.179952, -0.004270}}],
    Polygon[{{1.872934, 0.178803, -0.002162},{1.872934, 0.178633, 0.000000},{
      1.877204, 0.179309, 0.000000},{1.877151, 0.179471, -0.002162}}],
    Polygon[{{1.872934, 0.178633, 0.000000},{1.872934, 0.178803, 0.002162},{
      1.877151, 0.179471, 0.002162},{1.877204, 0.179309, 0.000000}}],
    Polygon[{{1.872934, 0.178803, 0.002162},{1.872934, 0.179309, 0.004270},{
      1.876995, 0.179952, 0.004270},{1.877151, 0.179471, 0.002162}}],
    Polygon[{{1.872934, 0.179309, 0.004270},{1.872934, 0.180139, 0.006273},{
      1.876738, 0.180741, 0.006273},{1.876995, 0.179952, 0.004270}}],
    Polygon[{{1.872934, 0.180139, 0.006273},{1.872934, 0.181272, 0.008122},{
      1.876388, 0.181819, 0.008122},{1.876738, 0.180741, 0.006273}}],
    Polygon[{{1.872934, 0.181272, 0.008122},{1.872934, 0.182680, 0.009770},{
      1.875953, 0.183158, 0.009770},{1.876388, 0.181819, 0.008122}}],
    Polygon[{{1.872934, 0.182680, 0.009770},{1.872934, 0.184328, 0.011178},{
      1.875444, 0.184726, 0.011178},{1.875953, 0.183158, 0.009770}}],
    Polygon[{{1.872934, 0.184328, 0.011178},{1.872934, 0.186177, 0.012311},{
      1.874872, 0.186484, 0.012311},{1.875444, 0.184726, 0.011178}}],
    Polygon[{{1.872934, 0.186177, 0.012311},{1.872934, 0.188180, 0.013141},{
      1.874254, 0.188389, 0.013141},{1.874872, 0.186484, 0.012311}}],
    Polygon[{{1.872934, 0.188180, 0.013141},{1.872934, 0.190289, 0.013647},{
      1.873602, 0.190394, 0.013647},{1.874254, 0.188389, 0.013141}}],
    Polygon[{{1.873602, 0.190394, -0.013647},{1.874254, 0.188389, -0.013141},{
      1.875444, 0.188996, -0.013141},{1.874205, 0.190701, -0.013647}}],
    Polygon[{{1.874254, 0.188389, -0.013141},{1.874872, 0.186484, -0.012311},{
      1.876621, 0.187375, -0.012311},{1.875444, 0.188996, -0.013141}}],
    Polygon[{{1.874872, 0.186484, -0.012311},{1.875444, 0.184726, -0.011178},{
      1.877708, 0.185880, -0.011178},{1.876621, 0.187375, -0.012311}}],
    Polygon[{{1.875444, 0.184726, -0.011178},{1.875953, 0.183158, -0.009770},{
      1.878677, 0.184546, -0.009770},{1.877708, 0.185880, -0.011178}}],
    Polygon[{{1.875953, 0.183158, -0.009770},{1.876388, 0.181819, -0.008122},{
      1.879505, 0.183407, -0.008122},{1.878677, 0.184546, -0.009770}}],
    Polygon[{{1.876388, 0.181819, -0.008122},{1.876738, 0.180741, -0.006273},{
      1.880170, 0.182490, -0.006273},{1.879505, 0.183407, -0.008122}}],
    Polygon[{{1.876738, 0.180741, -0.006273},{1.876995, 0.179952, -0.004270},{
      1.880658, 0.181819, -0.004270},{1.880170, 0.182490, -0.006273}}],
    Polygon[{{1.876995, 0.179952, -0.004270},{1.877151, 0.179471, -0.002162},{
      1.880956, 0.181409, -0.002162},{1.880658, 0.181819, -0.004270}}],
    Polygon[{{1.877151, 0.179471, -0.002162},{1.877204, 0.179309, 0.000000},{
      1.881056, 0.181272, 0.000000},{1.880956, 0.181409, -0.002162}}],
    Polygon[{{1.877204, 0.179309, 0.000000},{1.877151, 0.179471, 0.002162},{
      1.880956, 0.181409, 0.002162},{1.881056, 0.181272, 0.000000}}],
    Polygon[{{1.877151, 0.179471, 0.002162},{1.876995, 0.179952, 0.004270},{
      1.880658, 0.181819, 0.004270},{1.880956, 0.181409, 0.002162}}],
    Polygon[{{1.876995, 0.179952, 0.004270},{1.876738, 0.180741, 0.006273},{
      1.880170, 0.182490, 0.006273},{1.880658, 0.181819, 0.004270}}],
    Polygon[{{1.876738, 0.180741, 0.006273},{1.876388, 0.181819, 0.008122},{
      1.879505, 0.183407, 0.008122},{1.880170, 0.182490, 0.006273}}],
    Polygon[{{1.876388, 0.181819, 0.008122},{1.875953, 0.183158, 0.009770},{
      1.878677, 0.184546, 0.009770},{1.879505, 0.183407, 0.008122}}],
    Polygon[{{1.875953, 0.183158, 0.009770},{1.875444, 0.184726, 0.011178},{
      1.877708, 0.185880, 0.011178},{1.878677, 0.184546, 0.009770}}],
    Polygon[{{1.875444, 0.184726, 0.011178},{1.874872, 0.186484, 0.012311},{
      1.876621, 0.187375, 0.012311},{1.877708, 0.185880, 0.011178}}],
    Polygon[{{1.874872, 0.186484, 0.012311},{1.874254, 0.188389, 0.013141},{
      1.875444, 0.188996, 0.013141},{1.876621, 0.187375, 0.012311}}],
    Polygon[{{1.874254, 0.188389, 0.013141},{1.873602, 0.190394, 0.013647},{
      1.874205, 0.190701, 0.013647},{1.875444, 0.188996, 0.013141}}],
    Polygon[{{1.874205, 0.190701, -0.013647},{1.875444, 0.188996, -0.013141},{
      1.876388, 0.189940, -0.013141},{1.874683, 0.191180, -0.013647}}],
    Polygon[{{1.875444, 0.188996, -0.013141},{1.876621, 0.187375, -0.012311},{
      1.878009, 0.188763, -0.012311},{1.876388, 0.189940, -0.013141}}],
    Polygon[{{1.876621, 0.187375, -0.012311},{1.877708, 0.185880, -0.011178},{
      1.879505, 0.187676, -0.011178},{1.878009, 0.188763, -0.012311}}],
    Polygon[{{1.877708, 0.185880, -0.011178},{1.878677, 0.184546, -0.009770},{
      1.880838, 0.186707, -0.009770},{1.879505, 0.187676, -0.011178}}],
    Polygon[{{1.878677, 0.184546, -0.009770},{1.879505, 0.183407, -0.008122},{
      1.881978, 0.185880, -0.008122},{1.880838, 0.186707, -0.009770}}],
    Polygon[{{1.879505, 0.183407, -0.008122},{1.880170, 0.182490, -0.006273},{
      1.882894, 0.185214, -0.006273},{1.881978, 0.185880, -0.008122}}],
    Polygon[{{1.880170, 0.182490, -0.006273},{1.880658, 0.181819, -0.004270},{
      1.883565, 0.184726, -0.004270},{1.882894, 0.185214, -0.006273}}],
    Polygon[{{1.880658, 0.181819, -0.004270},{1.880956, 0.181409, -0.002162},{
      1.883975, 0.184428, -0.002162},{1.883565, 0.184726, -0.004270}}],
    Polygon[{{1.880956, 0.181409, -0.002162},{1.881056, 0.181272, 0.000000},{
      1.884112, 0.184328, 0.000000},{1.883975, 0.184428, -0.002162}}],
    Polygon[{{1.881056, 0.181272, 0.000000},{1.880956, 0.181409, 0.002162},{
      1.883975, 0.184428, 0.002162},{1.884112, 0.184328, 0.000000}}],
    Polygon[{{1.880956, 0.181409, 0.002162},{1.880658, 0.181819, 0.004270},{
      1.883565, 0.184726, 0.004270},{1.883975, 0.184428, 0.002162}}],
    Polygon[{{1.880658, 0.181819, 0.004270},{1.880170, 0.182490, 0.006273},{
      1.882894, 0.185214, 0.006273},{1.883565, 0.184726, 0.004270}}],
    Polygon[{{1.880170, 0.182490, 0.006273},{1.879505, 0.183407, 0.008122},{
      1.881978, 0.185880, 0.008122},{1.882894, 0.185214, 0.006273}}],
    Polygon[{{1.879505, 0.183407, 0.008122},{1.878677, 0.184546, 0.009770},{
      1.880838, 0.186707, 0.009770},{1.881978, 0.185880, 0.008122}}],
    Polygon[{{1.878677, 0.184546, 0.009770},{1.877708, 0.185880, 0.011178},{
      1.879505, 0.187676, 0.011178},{1.880838, 0.186707, 0.009770}}],
    Polygon[{{1.877708, 0.185880, 0.011178},{1.876621, 0.187375, 0.012311},{
      1.878009, 0.188763, 0.012311},{1.879505, 0.187676, 0.011178}}],
    Polygon[{{1.876621, 0.187375, 0.012311},{1.875444, 0.188996, 0.013141},{
      1.876388, 0.189940, 0.013141},{1.878009, 0.188763, 0.012311}}],
    Polygon[{{1.875444, 0.188996, 0.013141},{1.874205, 0.190701, 0.013647},{
      1.874683, 0.191180, 0.013647},{1.876388, 0.189940, 0.013141}}],
    Polygon[{{1.874683, 0.191180, -0.013647},{1.876388, 0.189940, -0.013141},{
      1.876995, 0.191131, -0.013141},{1.874990, 0.191782, -0.013647}}],
    Polygon[{{1.876388, 0.189940, -0.013141},{1.878009, 0.188763, -0.012311},{
      1.878900, 0.190512, -0.012311},{1.876995, 0.191131, -0.013141}}],
    Polygon[{{1.878009, 0.188763, -0.012311},{1.879505, 0.187676, -0.011178},{
      1.880658, 0.189940, -0.011178},{1.878900, 0.190512, -0.012311}}],
    Polygon[{{1.879505, 0.187676, -0.011178},{1.880838, 0.186707, -0.009770},{
      1.882226, 0.189431, -0.009770},{1.880658, 0.189940, -0.011178}}],
    Polygon[{{1.880838, 0.186707, -0.009770},{1.881978, 0.185880, -0.008122},{
      1.883565, 0.188996, -0.008122},{1.882226, 0.189431, -0.009770}}],
    Polygon[{{1.881978, 0.185880, -0.008122},{1.882894, 0.185214, -0.006273},{
      1.884643, 0.188646, -0.006273},{1.883565, 0.188996, -0.008122}}],
    Polygon[{{1.882894, 0.185214, -0.006273},{1.883565, 0.184726, -0.004270},{
      1.885432, 0.188389, -0.004270},{1.884643, 0.188646, -0.006273}}],
    Polygon[{{1.883565, 0.184726, -0.004270},{1.883975, 0.184428, -0.002162},{
      1.885913, 0.188233, -0.002162},{1.885432, 0.188389, -0.004270}}],
    Polygon[{{1.883975, 0.184428, -0.002162},{1.884112, 0.184328, 0.000000},{
      1.886075, 0.188180, 0.000000},{1.885913, 0.188233, -0.002162}}],
    Polygon[{{1.884112, 0.184328, 0.000000},{1.883975, 0.184428, 0.002162},{
      1.885913, 0.188233, 0.002162},{1.886075, 0.188180, 0.000000}}],
    Polygon[{{1.883975, 0.184428, 0.002162},{1.883565, 0.184726, 0.004270},{
      1.885432, 0.188389, 0.004270},{1.885913, 0.188233, 0.002162}}],
    Polygon[{{1.883565, 0.184726, 0.004270},{1.882894, 0.185214, 0.006273},{
      1.884643, 0.188646, 0.006273},{1.885432, 0.188389, 0.004270}}],
    Polygon[{{1.882894, 0.185214, 0.006273},{1.881978, 0.185880, 0.008122},{
      1.883565, 0.188996, 0.008122},{1.884643, 0.188646, 0.006273}}],
    Polygon[{{1.881978, 0.185880, 0.008122},{1.880838, 0.186707, 0.009770},{
      1.882226, 0.189431, 0.009770},{1.883565, 0.188996, 0.008122}}],
    Polygon[{{1.880838, 0.186707, 0.009770},{1.879505, 0.187676, 0.011178},{
      1.880658, 0.189940, 0.011178},{1.882226, 0.189431, 0.009770}}],
    Polygon[{{1.879505, 0.187676, 0.011178},{1.878009, 0.188763, 0.012311},{
      1.878900, 0.190512, 0.012311},{1.880658, 0.189940, 0.011178}}],
    Polygon[{{1.878009, 0.188763, 0.012311},{1.876388, 0.189940, 0.013141},{
      1.876995, 0.191131, 0.013141},{1.878900, 0.190512, 0.012311}}],
    Polygon[{{1.876388, 0.189940, 0.013141},{1.874683, 0.191180, 0.013647},{
      1.874990, 0.191782, 0.013647},{1.876995, 0.191131, 0.013141}}],
    Polygon[{{1.874990, 0.191782, -0.013647},{1.876995, 0.191131, -0.013141},{
      1.877204, 0.192450, -0.013141},{1.875096, 0.192450, -0.013647}}],
    Polygon[{{1.876995, 0.191131, -0.013141},{1.878900, 0.190512, -0.012311},{
      1.879207, 0.192450, -0.012311},{1.877204, 0.192450, -0.013141}}],
    Polygon[{{1.878900, 0.190512, -0.012311},{1.880658, 0.189940, -0.011178},{
      1.881056, 0.192450, -0.011178},{1.879207, 0.192450, -0.012311}}],
    Polygon[{{1.880658, 0.189940, -0.011178},{1.882226, 0.189431, -0.009770},{
      1.882704, 0.192450, -0.009770},{1.881056, 0.192450, -0.011178}}],
    Polygon[{{1.882226, 0.189431, -0.009770},{1.883565, 0.188996, -0.008122},{
      1.884112, 0.192450, -0.008122},{1.882704, 0.192450, -0.009770}}],
    Polygon[{{1.883565, 0.188996, -0.008122},{1.884643, 0.188646, -0.006273},{
      1.885245, 0.192450, -0.006273},{1.884112, 0.192450, -0.008122}}],
    Polygon[{{1.884643, 0.188646, -0.006273},{1.885432, 0.188389, -0.004270},{
      1.886075, 0.192450, -0.004270},{1.885245, 0.192450, -0.006273}}],
    Polygon[{{1.885432, 0.188389, -0.004270},{1.885913, 0.188233, -0.002162},{
      1.886581, 0.192450, -0.002162},{1.886075, 0.192450, -0.004270}}],
    Polygon[{{1.885913, 0.188233, -0.002162},{1.886075, 0.188180, 0.000000},{
      1.886751, 0.192450, 0.000000},{1.886581, 0.192450, -0.002162}}],
    Polygon[{{1.886075, 0.188180, 0.000000},{1.885913, 0.188233, 0.002162},{
      1.886581, 0.192450, 0.002162},{1.886751, 0.192450, 0.000000}}],
    Polygon[{{1.885913, 0.188233, 0.002162},{1.885432, 0.188389, 0.004270},{
      1.886075, 0.192450, 0.004270},{1.886581, 0.192450, 0.002162}}],
    Polygon[{{1.885432, 0.188389, 0.004270},{1.884643, 0.188646, 0.006273},{
      1.885245, 0.192450, 0.006273},{1.886075, 0.192450, 0.004270}}],
    Polygon[{{1.884643, 0.188646, 0.006273},{1.883565, 0.188996, 0.008122},{
      1.884112, 0.192450, 0.008122},{1.885245, 0.192450, 0.006273}}],
    Polygon[{{1.883565, 0.188996, 0.008122},{1.882226, 0.189431, 0.009770},{
      1.882704, 0.192450, 0.009770},{1.884112, 0.192450, 0.008122}}],
    Polygon[{{1.882226, 0.189431, 0.009770},{1.880658, 0.189940, 0.011178},{
      1.881056, 0.192450, 0.011178},{1.882704, 0.192450, 0.009770}}],
    Polygon[{{1.880658, 0.189940, 0.011178},{1.878900, 0.190512, 0.012311},{
      1.879207, 0.192450, 0.012311},{1.881056, 0.192450, 0.011178}}],
    Polygon[{{1.878900, 0.190512, 0.012311},{1.876995, 0.191131, 0.013141},{
      1.877204, 0.192450, 0.013141},{1.879207, 0.192450, 0.012311}}],
    Polygon[{{1.876995, 0.191131, 0.013141},{1.874990, 0.191782, 0.013647},{
      1.875096, 0.192450, 0.013647},{1.877204, 0.192450, 0.013141}}],
    Polygon[{{1.912702, 0.134507, -0.009538},{1.914175, 0.134507, -0.009185},{
      1.914029, 0.135429, -0.009185},{1.912628, 0.134974, -0.009538}}],
    Polygon[{{1.914175, 0.134507, -0.009185},{1.915575, 0.134507, -0.008605},{
      1.915361, 0.135862, -0.008605},{1.914029, 0.135429, -0.009185}}],
    Polygon[{{1.915575, 0.134507, -0.008605},{1.916867, 0.134507, -0.007813},{
      1.916590, 0.136261, -0.007813},{1.915361, 0.135862, -0.008605}}],
    Polygon[{{1.916867, 0.134507, -0.007813},{1.918020, 0.134507, -0.006829},{
      1.917686, 0.136617, -0.006829},{1.916590, 0.136261, -0.007813}}],
    Polygon[{{1.918020, 0.134507, -0.006829},{1.919004, 0.134507, -0.005676},{
      1.918622, 0.136921, -0.005676},{1.917686, 0.136617, -0.006829}}],
    Polygon[{{1.919004, 0.134507, -0.005676},{1.919796, 0.134507, -0.004384},{
      1.919375, 0.137166, -0.004384},{1.918622, 0.136921, -0.005676}}],
    Polygon[{{1.919796, 0.134507, -0.004384},{1.920376, 0.134507, -0.002984},{
      1.919926, 0.137345, -0.002984},{1.919375, 0.137166, -0.004384}}],
    Polygon[{{1.920376, 0.134507, -0.002984},{1.920729, 0.134507, -0.001511},{
      1.920263, 0.137455, -0.001511},{1.919926, 0.137345, -0.002984}}],
    Polygon[{{1.920729, 0.134507, -0.001511},{1.920848, 0.134507, 0.000000},{
      1.920376, 0.137491, 0.000000},{1.920263, 0.137455, -0.001511}}],
    Polygon[{{1.920848, 0.134507, 0.000000},{1.920729, 0.134507, 0.001511},{
      1.920263, 0.137455, 0.001511},{1.920376, 0.137491, 0.000000}}],
    Polygon[{{1.920729, 0.134507, 0.001511},{1.920376, 0.134507, 0.002984},{
      1.919926, 0.137345, 0.002984},{1.920263, 0.137455, 0.001511}}],
    Polygon[{{1.920376, 0.134507, 0.002984},{1.919796, 0.134507, 0.004384},{
      1.919375, 0.137166, 0.004384},{1.919926, 0.137345, 0.002984}}],
    Polygon[{{1.919796, 0.134507, 0.004384},{1.919004, 0.134507, 0.005676},{
      1.918622, 0.136921, 0.005676},{1.919375, 0.137166, 0.004384}}],
    Polygon[{{1.919004, 0.134507, 0.005676},{1.918020, 0.134507, 0.006829},{
      1.917686, 0.136617, 0.006829},{1.918622, 0.136921, 0.005676}}],
    Polygon[{{1.918020, 0.134507, 0.006829},{1.916867, 0.134507, 0.007813},{
      1.916590, 0.136261, 0.007813},{1.917686, 0.136617, 0.006829}}],
    Polygon[{{1.916867, 0.134507, 0.007813},{1.915575, 0.134507, 0.008605},{
      1.915361, 0.135862, 0.008605},{1.916590, 0.136261, 0.007813}}],
    Polygon[{{1.915575, 0.134507, 0.008605},{1.914175, 0.134507, 0.009185},{
      1.914029, 0.135429, 0.009185},{1.915361, 0.135862, 0.008605}}],
    Polygon[{{1.914175, 0.134507, 0.009185},{1.912702, 0.134507, 0.009538},{
      1.912628, 0.134974, 0.009538},{1.914029, 0.135429, 0.009185}}],
    Polygon[{{1.912628, 0.134974, -0.009538},{1.914029, 0.135429, -0.009185},{
      1.913605, 0.136261, -0.009185},{1.912413, 0.135395, -0.009538}}],
    Polygon[{{1.914029, 0.135429, -0.009185},{1.915361, 0.135862, -0.008605},{
      1.914738, 0.137084, -0.008605},{1.913605, 0.136261, -0.009185}}],
    Polygon[{{1.915361, 0.135862, -0.008605},{1.916590, 0.136261, -0.007813},{
      1.915783, 0.137844, -0.007813},{1.914738, 0.137084, -0.008605}}],
    Polygon[{{1.916590, 0.136261, -0.007813},{1.917686, 0.136617, -0.006829},{
      1.916716, 0.138521, -0.006829},{1.915783, 0.137844, -0.007813}}],
    Polygon[{{1.917686, 0.136617, -0.006829},{1.918622, 0.136921, -0.005676},{
      1.917512, 0.139099, -0.005676},{1.916716, 0.138521, -0.006829}}],
    Polygon[{{1.918622, 0.136921, -0.005676},{1.919375, 0.137166, -0.004384},{
      1.918152, 0.139565, -0.004384},{1.917512, 0.139099, -0.005676}}],
    Polygon[{{1.919375, 0.137166, -0.004384},{1.919926, 0.137345, -0.002984},{
      1.918622, 0.139906, -0.002984},{1.918152, 0.139565, -0.004384}}],
    Polygon[{{1.919926, 0.137345, -0.002984},{1.920263, 0.137455, -0.001511},{
      1.918908, 0.140114, -0.001511},{1.918622, 0.139906, -0.002984}}],
    Polygon[{{1.920263, 0.137455, -0.001511},{1.920376, 0.137491, 0.000000},{
      1.919004, 0.140183, 0.000000},{1.918908, 0.140114, -0.001511}}],
    Polygon[{{1.920376, 0.137491, 0.000000},{1.920263, 0.137455, 0.001511},{
      1.918908, 0.140114, 0.001511},{1.919004, 0.140183, 0.000000}}],
    Polygon[{{1.920263, 0.137455, 0.001511},{1.919926, 0.137345, 0.002984},{
      1.918622, 0.139906, 0.002984},{1.918908, 0.140114, 0.001511}}],
    Polygon[{{1.919926, 0.137345, 0.002984},{1.919375, 0.137166, 0.004384},{
      1.918152, 0.139565, 0.004384},{1.918622, 0.139906, 0.002984}}],
    Polygon[{{1.919375, 0.137166, 0.004384},{1.918622, 0.136921, 0.005676},{
      1.917512, 0.139099, 0.005676},{1.918152, 0.139565, 0.004384}}],
    Polygon[{{1.918622, 0.136921, 0.005676},{1.917686, 0.136617, 0.006829},{
      1.916716, 0.138521, 0.006829},{1.917512, 0.139099, 0.005676}}],
    Polygon[{{1.917686, 0.136617, 0.006829},{1.916590, 0.136261, 0.007813},{
      1.915783, 0.137844, 0.007813},{1.916716, 0.138521, 0.006829}}],
    Polygon[{{1.916590, 0.136261, 0.007813},{1.915361, 0.135862, 0.008605},{
      1.914738, 0.137084, 0.008605},{1.915783, 0.137844, 0.007813}}],
    Polygon[{{1.915361, 0.135862, 0.008605},{1.914029, 0.135429, 0.009185},{
      1.913605, 0.136261, 0.009185},{1.914738, 0.137084, 0.008605}}],
    Polygon[{{1.914029, 0.135429, 0.009185},{1.912628, 0.134974, 0.009538},{
      1.912413, 0.135395, 0.009538},{1.913605, 0.136261, 0.009185}}],
    Polygon[{{1.912413, 0.135395, -0.009538},{1.913605, 0.136261, -0.009185},{
      1.912945, 0.136921, -0.009185},{1.912079, 0.135729, -0.009538}}],
    Polygon[{{1.913605, 0.136261, -0.009185},{1.914738, 0.137084, -0.008605},{
      1.913768, 0.138054, -0.008605},{1.912945, 0.136921, -0.009185}}],
    Polygon[{{1.914738, 0.137084, -0.008605},{1.915783, 0.137844, -0.007813},{
      1.914528, 0.139099, -0.007813},{1.913768, 0.138054, -0.008605}}],
    Polygon[{{1.915783, 0.137844, -0.007813},{1.916716, 0.138521, -0.006829},{
      1.915205, 0.140032, -0.006829},{1.914528, 0.139099, -0.007813}}],
    Polygon[{{1.916716, 0.138521, -0.006829},{1.917512, 0.139099, -0.005676},{
      1.915783, 0.140828, -0.005676},{1.915205, 0.140032, -0.006829}}],
    Polygon[{{1.917512, 0.139099, -0.005676},{1.918152, 0.139565, -0.004384},{
      1.916249, 0.141468, -0.004384},{1.915783, 0.140828, -0.005676}}],
    Polygon[{{1.918152, 0.139565, -0.004384},{1.918622, 0.139906, -0.002984},{
      1.916590, 0.141937, -0.002984},{1.916249, 0.141468, -0.004384}}],
    Polygon[{{1.918622, 0.139906, -0.002984},{1.918908, 0.140114, -0.001511},{
      1.916798, 0.142224, -0.001511},{1.916590, 0.141937, -0.002984}}],
    Polygon[{{1.918908, 0.140114, -0.001511},{1.919004, 0.140183, 0.000000},{
      1.916867, 0.142320, 0.000000},{1.916798, 0.142224, -0.001511}}],
    Polygon[{{1.919004, 0.140183, 0.000000},{1.918908, 0.140114, 0.001511},{
      1.916798, 0.142224, 0.001511},{1.916867, 0.142320, 0.000000}}],
    Polygon[{{1.918908, 0.140114, 0.001511},{1.918622, 0.139906, 0.002984},{
      1.916590, 0.141937, 0.002984},{1.916798, 0.142224, 0.001511}}],
    Polygon[{{1.918622, 0.139906, 0.002984},{1.918152, 0.139565, 0.004384},{
      1.916249, 0.141468, 0.004384},{1.916590, 0.141937, 0.002984}}],
    Polygon[{{1.918152, 0.139565, 0.004384},{1.917512, 0.139099, 0.005676},{
      1.915783, 0.140828, 0.005676},{1.916249, 0.141468, 0.004384}}],
    Polygon[{{1.917512, 0.139099, 0.005676},{1.916716, 0.138521, 0.006829},{
      1.915205, 0.140032, 0.006829},{1.915783, 0.140828, 0.005676}}],
    Polygon[{{1.916716, 0.138521, 0.006829},{1.915783, 0.137844, 0.007813},{
      1.914528, 0.139099, 0.007813},{1.915205, 0.140032, 0.006829}}],
    Polygon[{{1.915783, 0.137844, 0.007813},{1.914738, 0.137084, 0.008605},{
      1.913768, 0.138054, 0.008605},{1.914528, 0.139099, 0.007813}}],
    Polygon[{{1.914738, 0.137084, 0.008605},{1.913605, 0.136261, 0.009185},{
      1.912945, 0.136921, 0.009185},{1.913768, 0.138054, 0.008605}}],
    Polygon[{{1.913605, 0.136261, 0.009185},{1.912413, 0.135395, 0.009538},{
      1.912079, 0.135729, 0.009538},{1.912945, 0.136921, 0.009185}}],
    Polygon[{{1.912079, 0.135729, -0.009538},{1.912945, 0.136921, -0.009185},{
      1.912113, 0.137345, -0.009185},{1.911658, 0.135944, -0.009538}}],
    Polygon[{{1.912945, 0.136921, -0.009185},{1.913768, 0.138054, -0.008605},{
      1.912546, 0.138677, -0.008605},{1.912113, 0.137345, -0.009185}}],
    Polygon[{{1.913768, 0.138054, -0.008605},{1.914528, 0.139099, -0.007813},{
      1.912945, 0.139906, -0.007813},{1.912546, 0.138677, -0.008605}}],
    Polygon[{{1.914528, 0.139099, -0.007813},{1.915205, 0.140032, -0.006829},{
      1.913301, 0.141001, -0.006829},{1.912945, 0.139906, -0.007813}}],
    Polygon[{{1.915205, 0.140032, -0.006829},{1.915783, 0.140828, -0.005676},{
      1.913605, 0.141937, -0.005676},{1.913301, 0.141001, -0.006829}}],
    Polygon[{{1.915783, 0.140828, -0.005676},{1.916249, 0.141468, -0.004384},{
      1.913850, 0.142691, -0.004384},{1.913605, 0.141937, -0.005676}}],
    Polygon[{{1.916249, 0.141468, -0.004384},{1.916590, 0.141937, -0.002984},{
      1.914029, 0.143242, -0.002984},{1.913850, 0.142691, -0.004384}}],
    Polygon[{{1.916590, 0.141937, -0.002984},{1.916798, 0.142224, -0.001511},{
      1.914139, 0.143578, -0.001511},{1.914029, 0.143242, -0.002984}}],
    Polygon[{{1.916798, 0.142224, -0.001511},{1.916867, 0.142320, 0.000000},{
      1.914175, 0.143692, 0.000000},{1.914139, 0.143578, -0.001511}}],
    Polygon[{{1.916867, 0.142320, 0.000000},{1.916798, 0.142224, 0.001511},{
      1.914139, 0.143578, 0.001511},{1.914175, 0.143692, 0.000000}}],
    Polygon[{{1.916798, 0.142224, 0.001511},{1.916590, 0.141937, 0.002984},{
      1.914029, 0.143242, 0.002984},{1.914139, 0.143578, 0.001511}}],
    Polygon[{{1.916590, 0.141937, 0.002984},{1.916249, 0.141468, 0.004384},{
      1.913850, 0.142691, 0.004384},{1.914029, 0.143242, 0.002984}}],
    Polygon[{{1.916249, 0.141468, 0.004384},{1.915783, 0.140828, 0.005676},{
      1.913605, 0.141937, 0.005676},{1.913850, 0.142691, 0.004384}}],
    Polygon[{{1.915783, 0.140828, 0.005676},{1.915205, 0.140032, 0.006829},{
      1.913301, 0.141001, 0.006829},{1.913605, 0.141937, 0.005676}}],
    Polygon[{{1.915205, 0.140032, 0.006829},{1.914528, 0.139099, 0.007813},{
      1.912945, 0.139906, 0.007813},{1.913301, 0.141001, 0.006829}}],
    Polygon[{{1.914528, 0.139099, 0.007813},{1.913768, 0.138054, 0.008605},{
      1.912546, 0.138677, 0.008605},{1.912945, 0.139906, 0.007813}}],
    Polygon[{{1.913768, 0.138054, 0.008605},{1.912945, 0.136921, 0.009185},{
      1.912113, 0.137345, 0.009185},{1.912546, 0.138677, 0.008605}}],
    Polygon[{{1.912945, 0.136921, 0.009185},{1.912079, 0.135729, 0.009538},{
      1.911658, 0.135944, 0.009538},{1.912113, 0.137345, 0.009185}}],
    Polygon[{{1.911658, 0.135944, -0.009538},{1.912113, 0.137345, -0.009185},{
      1.911191, 0.137491, -0.009185},{1.911191, 0.136018, -0.009538}}],
    Polygon[{{1.912113, 0.137345, -0.009185},{1.912546, 0.138677, -0.008605},{
      1.911191, 0.138891, -0.008605},{1.911191, 0.137491, -0.009185}}],
    Polygon[{{1.912546, 0.138677, -0.008605},{1.912945, 0.139906, -0.007813},{
      1.911191, 0.140183, -0.007813},{1.911191, 0.138891, -0.008605}}],
    Polygon[{{1.912945, 0.139906, -0.007813},{1.913301, 0.141001, -0.006829},{
      1.911191, 0.141336, -0.006829},{1.911191, 0.140183, -0.007813}}],
    Polygon[{{1.913301, 0.141001, -0.006829},{1.913605, 0.141937, -0.005676},{
      1.911191, 0.142320, -0.005676},{1.911191, 0.141336, -0.006829}}],
    Polygon[{{1.913605, 0.141937, -0.005676},{1.913850, 0.142691, -0.004384},{
      1.911191, 0.143112, -0.004384},{1.911191, 0.142320, -0.005676}}],
    Polygon[{{1.913850, 0.142691, -0.004384},{1.914029, 0.143242, -0.002984},{
      1.911191, 0.143692, -0.002984},{1.911191, 0.143112, -0.004384}}],
    Polygon[{{1.914029, 0.143242, -0.002984},{1.914139, 0.143578, -0.001511},{
      1.911191, 0.144045, -0.001511},{1.911191, 0.143692, -0.002984}}],
    Polygon[{{1.914139, 0.143578, -0.001511},{1.914175, 0.143692, 0.000000},{
      1.911191, 0.144164, 0.000000},{1.911191, 0.144045, -0.001511}}],
    Polygon[{{1.914175, 0.143692, 0.000000},{1.914139, 0.143578, 0.001511},{
      1.911191, 0.144045, 0.001511},{1.911191, 0.144164, 0.000000}}],
    Polygon[{{1.914139, 0.143578, 0.001511},{1.914029, 0.143242, 0.002984},{
      1.911191, 0.143692, 0.002984},{1.911191, 0.144045, 0.001511}}],
    Polygon[{{1.914029, 0.143242, 0.002984},{1.913850, 0.142691, 0.004384},{
      1.911191, 0.143112, 0.004384},{1.911191, 0.143692, 0.002984}}],
    Polygon[{{1.913850, 0.142691, 0.004384},{1.913605, 0.141937, 0.005676},{
      1.911191, 0.142320, 0.005676},{1.911191, 0.143112, 0.004384}}],
    Polygon[{{1.913605, 0.141937, 0.005676},{1.913301, 0.141001, 0.006829},{
      1.911191, 0.141336, 0.006829},{1.911191, 0.142320, 0.005676}}],
    Polygon[{{1.913301, 0.141001, 0.006829},{1.912945, 0.139906, 0.007813},{
      1.911191, 0.140183, 0.007813},{1.911191, 0.141336, 0.006829}}],
    Polygon[{{1.912945, 0.139906, 0.007813},{1.912546, 0.138677, 0.008605},{
      1.911191, 0.138891, 0.008605},{1.911191, 0.140183, 0.007813}}],
    Polygon[{{1.912546, 0.138677, 0.008605},{1.912113, 0.137345, 0.009185},{
      1.911191, 0.137491, 0.009185},{1.911191, 0.138891, 0.008605}}],
    Polygon[{{1.912113, 0.137345, 0.009185},{1.911658, 0.135944, 0.009538},{
      1.911191, 0.136018, 0.009538},{1.911191, 0.137491, 0.009185}}],
    Polygon[{{1.911191, 0.136018, -0.009538},{1.911191, 0.137491, -0.009185},{
      1.910269, 0.137345, -0.009185},{1.910724, 0.135944, -0.009538}}],
    Polygon[{{1.911191, 0.137491, -0.009185},{1.911191, 0.138891, -0.008605},{
      1.909836, 0.138677, -0.008605},{1.910269, 0.137345, -0.009185}}],
    Polygon[{{1.911191, 0.138891, -0.008605},{1.911191, 0.140183, -0.007813},{
      1.909437, 0.139906, -0.007813},{1.909836, 0.138677, -0.008605}}],
    Polygon[{{1.911191, 0.140183, -0.007813},{1.911191, 0.141336, -0.006829},{
      1.909081, 0.141001, -0.006829},{1.909437, 0.139906, -0.007813}}],
    Polygon[{{1.911191, 0.141336, -0.006829},{1.911191, 0.142320, -0.005676},{
      1.908777, 0.141937, -0.005676},{1.909081, 0.141001, -0.006829}}],
    Polygon[{{1.911191, 0.142320, -0.005676},{1.911191, 0.143112, -0.004384},{
      1.908532, 0.142691, -0.004384},{1.908777, 0.141937, -0.005676}}],
    Polygon[{{1.911191, 0.143112, -0.004384},{1.911191, 0.143692, -0.002984},{
      1.908353, 0.143242, -0.002984},{1.908532, 0.142691, -0.004384}}],
    Polygon[{{1.911191, 0.143692, -0.002984},{1.911191, 0.144045, -0.001511},{
      1.908244, 0.143578, -0.001511},{1.908353, 0.143242, -0.002984}}],
    Polygon[{{1.911191, 0.144045, -0.001511},{1.911191, 0.144164, 0.000000},{
      1.908207, 0.143692, 0.000000},{1.908244, 0.143578, -0.001511}}],
    Polygon[{{1.911191, 0.144164, 0.000000},{1.911191, 0.144045, 0.001511},{
      1.908244, 0.143578, 0.001511},{1.908207, 0.143692, 0.000000}}],
    Polygon[{{1.911191, 0.144045, 0.001511},{1.911191, 0.143692, 0.002984},{
      1.908353, 0.143242, 0.002984},{1.908244, 0.143578, 0.001511}}],
    Polygon[{{1.911191, 0.143692, 0.002984},{1.911191, 0.143112, 0.004384},{
      1.908532, 0.142691, 0.004384},{1.908353, 0.143242, 0.002984}}],
    Polygon[{{1.911191, 0.143112, 0.004384},{1.911191, 0.142320, 0.005676},{
      1.908777, 0.141937, 0.005676},{1.908532, 0.142691, 0.004384}}],
    Polygon[{{1.911191, 0.142320, 0.005676},{1.911191, 0.141336, 0.006829},{
      1.909081, 0.141001, 0.006829},{1.908777, 0.141937, 0.005676}}],
    Polygon[{{1.911191, 0.141336, 0.006829},{1.911191, 0.140183, 0.007813},{
      1.909437, 0.139906, 0.007813},{1.909081, 0.141001, 0.006829}}],
    Polygon[{{1.911191, 0.140183, 0.007813},{1.911191, 0.138891, 0.008605},{
      1.909836, 0.138677, 0.008605},{1.909437, 0.139906, 0.007813}}],
    Polygon[{{1.911191, 0.138891, 0.008605},{1.911191, 0.137491, 0.009185},{
      1.910269, 0.137345, 0.009185},{1.909836, 0.138677, 0.008605}}],
    Polygon[{{1.911191, 0.137491, 0.009185},{1.911191, 0.136018, 0.009538},{
      1.910724, 0.135944, 0.009538},{1.910269, 0.137345, 0.009185}}],
    Polygon[{{1.910724, 0.135944, -0.009538},{1.910269, 0.137345, -0.009185},{
      1.909437, 0.136921, -0.009185},{1.910303, 0.135729, -0.009538}}],
    Polygon[{{1.910269, 0.137345, -0.009185},{1.909836, 0.138677, -0.008605},{
      1.908614, 0.138054, -0.008605},{1.909437, 0.136921, -0.009185}}],
    Polygon[{{1.909836, 0.138677, -0.008605},{1.909437, 0.139906, -0.007813},{
      1.907855, 0.139099, -0.007813},{1.908614, 0.138054, -0.008605}}],
    Polygon[{{1.909437, 0.139906, -0.007813},{1.909081, 0.141001, -0.006829},{
      1.907177, 0.140032, -0.006829},{1.907855, 0.139099, -0.007813}}],
    Polygon[{{1.909081, 0.141001, -0.006829},{1.908777, 0.141937, -0.005676},{
      1.906599, 0.140828, -0.005676},{1.907177, 0.140032, -0.006829}}],
    Polygon[{{1.908777, 0.141937, -0.005676},{1.908532, 0.142691, -0.004384},{
      1.906134, 0.141468, -0.004384},{1.906599, 0.140828, -0.005676}}],
    Polygon[{{1.908532, 0.142691, -0.004384},{1.908353, 0.143242, -0.002984},{
      1.905793, 0.141937, -0.002984},{1.906134, 0.141468, -0.004384}}],
    Polygon[{{1.908353, 0.143242, -0.002984},{1.908244, 0.143578, -0.001511},{
      1.905585, 0.142224, -0.001511},{1.905793, 0.141937, -0.002984}}],
    Polygon[{{1.908244, 0.143578, -0.001511},{1.908207, 0.143692, 0.000000},{
      1.905515, 0.142320, 0.000000},{1.905585, 0.142224, -0.001511}}],
    Polygon[{{1.908207, 0.143692, 0.000000},{1.908244, 0.143578, 0.001511},{
      1.905585, 0.142224, 0.001511},{1.905515, 0.142320, 0.000000}}],
    Polygon[{{1.908244, 0.143578, 0.001511},{1.908353, 0.143242, 0.002984},{
      1.905793, 0.141937, 0.002984},{1.905585, 0.142224, 0.001511}}],
    Polygon[{{1.908353, 0.143242, 0.002984},{1.908532, 0.142691, 0.004384},{
      1.906134, 0.141468, 0.004384},{1.905793, 0.141937, 0.002984}}],
    Polygon[{{1.908532, 0.142691, 0.004384},{1.908777, 0.141937, 0.005676},{
      1.906599, 0.140828, 0.005676},{1.906134, 0.141468, 0.004384}}],
    Polygon[{{1.908777, 0.141937, 0.005676},{1.909081, 0.141001, 0.006829},{
      1.907177, 0.140032, 0.006829},{1.906599, 0.140828, 0.005676}}],
    Polygon[{{1.909081, 0.141001, 0.006829},{1.909437, 0.139906, 0.007813},{
      1.907855, 0.139099, 0.007813},{1.907177, 0.140032, 0.006829}}],
    Polygon[{{1.909437, 0.139906, 0.007813},{1.909836, 0.138677, 0.008605},{
      1.908614, 0.138054, 0.008605},{1.907855, 0.139099, 0.007813}}],
    Polygon[{{1.909836, 0.138677, 0.008605},{1.910269, 0.137345, 0.009185},{
      1.909437, 0.136921, 0.009185},{1.908614, 0.138054, 0.008605}}],
    Polygon[{{1.910269, 0.137345, 0.009185},{1.910724, 0.135944, 0.009538},{
      1.910303, 0.135729, 0.009538},{1.909437, 0.136921, 0.009185}}],
    Polygon[{{1.910303, 0.135729, -0.009538},{1.909437, 0.136921, -0.009185},{
      1.908777, 0.136261, -0.009185},{1.909969, 0.135395, -0.009538}}],
    Polygon[{{1.909437, 0.136921, -0.009185},{1.908614, 0.138054, -0.008605},{
      1.907644, 0.137084, -0.008605},{1.908777, 0.136261, -0.009185}}],
    Polygon[{{1.908614, 0.138054, -0.008605},{1.907855, 0.139099, -0.007813},{
      1.906599, 0.137844, -0.007813},{1.907644, 0.137084, -0.008605}}],
    Polygon[{{1.907855, 0.139099, -0.007813},{1.907177, 0.140032, -0.006829},{
      1.905667, 0.138521, -0.006829},{1.906599, 0.137844, -0.007813}}],
    Polygon[{{1.907177, 0.140032, -0.006829},{1.906599, 0.140828, -0.005676},{
      1.904871, 0.139099, -0.005676},{1.905667, 0.138521, -0.006829}}],
    Polygon[{{1.906599, 0.140828, -0.005676},{1.906134, 0.141468, -0.004384},{
      1.904230, 0.139565, -0.004384},{1.904871, 0.139099, -0.005676}}],
    Polygon[{{1.906134, 0.141468, -0.004384},{1.905793, 0.141937, -0.002984},{
      1.903761, 0.139906, -0.002984},{1.904230, 0.139565, -0.004384}}],
    Polygon[{{1.905793, 0.141937, -0.002984},{1.905585, 0.142224, -0.001511},{
      1.903475, 0.140114, -0.001511},{1.903761, 0.139906, -0.002984}}],
    Polygon[{{1.905585, 0.142224, -0.001511},{1.905515, 0.142320, 0.000000},{
      1.903378, 0.140183, 0.000000},{1.903475, 0.140114, -0.001511}}],
    Polygon[{{1.905515, 0.142320, 0.000000},{1.905585, 0.142224, 0.001511},{
      1.903475, 0.140114, 0.001511},{1.903378, 0.140183, 0.000000}}],
    Polygon[{{1.905585, 0.142224, 0.001511},{1.905793, 0.141937, 0.002984},{
      1.903761, 0.139906, 0.002984},{1.903475, 0.140114, 0.001511}}],
    Polygon[{{1.905793, 0.141937, 0.002984},{1.906134, 0.141468, 0.004384},{
      1.904230, 0.139565, 0.004384},{1.903761, 0.139906, 0.002984}}],
    Polygon[{{1.906134, 0.141468, 0.004384},{1.906599, 0.140828, 0.005676},{
      1.904871, 0.139099, 0.005676},{1.904230, 0.139565, 0.004384}}],
    Polygon[{{1.906599, 0.140828, 0.005676},{1.907177, 0.140032, 0.006829},{
      1.905667, 0.138521, 0.006829},{1.904871, 0.139099, 0.005676}}],
    Polygon[{{1.907177, 0.140032, 0.006829},{1.907855, 0.139099, 0.007813},{
      1.906599, 0.137844, 0.007813},{1.905667, 0.138521, 0.006829}}],
    Polygon[{{1.907855, 0.139099, 0.007813},{1.908614, 0.138054, 0.008605},{
      1.907644, 0.137084, 0.008605},{1.906599, 0.137844, 0.007813}}],
    Polygon[{{1.908614, 0.138054, 0.008605},{1.909437, 0.136921, 0.009185},{
      1.908777, 0.136261, 0.009185},{1.907644, 0.137084, 0.008605}}],
    Polygon[{{1.909437, 0.136921, 0.009185},{1.910303, 0.135729, 0.009538},{
      1.909969, 0.135395, 0.009538},{1.908777, 0.136261, 0.009185}}],
    Polygon[{{1.909969, 0.135395, -0.009538},{1.908777, 0.136261, -0.009185},{
      1.908353, 0.135429, -0.009185},{1.909754, 0.134974, -0.009538}}],
    Polygon[{{1.908777, 0.136261, -0.009185},{1.907644, 0.137084, -0.008605},{
      1.907022, 0.135862, -0.008605},{1.908353, 0.135429, -0.009185}}],
    Polygon[{{1.907644, 0.137084, -0.008605},{1.906599, 0.137844, -0.007813},{
      1.905793, 0.136261, -0.007813},{1.907022, 0.135862, -0.008605}}],
    Polygon[{{1.906599, 0.137844, -0.007813},{1.905667, 0.138521, -0.006829},{
      1.904697, 0.136617, -0.006829},{1.905793, 0.136261, -0.007813}}],
    Polygon[{{1.905667, 0.138521, -0.006829},{1.904871, 0.139099, -0.005676},{
      1.903761, 0.136921, -0.005676},{1.904697, 0.136617, -0.006829}}],
    Polygon[{{1.904871, 0.139099, -0.005676},{1.904230, 0.139565, -0.004384},{
      1.903008, 0.137166, -0.004384},{1.903761, 0.136921, -0.005676}}],
    Polygon[{{1.904230, 0.139565, -0.004384},{1.903761, 0.139906, -0.002984},{
      1.902456, 0.137345, -0.002984},{1.903008, 0.137166, -0.004384}}],
    Polygon[{{1.903761, 0.139906, -0.002984},{1.903475, 0.140114, -0.001511},{
      1.902120, 0.137455, -0.001511},{1.902456, 0.137345, -0.002984}}],
    Polygon[{{1.903475, 0.140114, -0.001511},{1.903378, 0.140183, 0.000000},{
      1.902007, 0.137491, 0.000000},{1.902120, 0.137455, -0.001511}}],
    Polygon[{{1.903378, 0.140183, 0.000000},{1.903475, 0.140114, 0.001511},{
      1.902120, 0.137455, 0.001511},{1.902007, 0.137491, 0.000000}}],
    Polygon[{{1.903475, 0.140114, 0.001511},{1.903761, 0.139906, 0.002984},{
      1.902456, 0.137345, 0.002984},{1.902120, 0.137455, 0.001511}}],
    Polygon[{{1.903761, 0.139906, 0.002984},{1.904230, 0.139565, 0.004384},{
      1.903008, 0.137166, 0.004384},{1.902456, 0.137345, 0.002984}}],
    Polygon[{{1.904230, 0.139565, 0.004384},{1.904871, 0.139099, 0.005676},{
      1.903761, 0.136921, 0.005676},{1.903008, 0.137166, 0.004384}}],
    Polygon[{{1.904871, 0.139099, 0.005676},{1.905667, 0.138521, 0.006829},{
      1.904697, 0.136617, 0.006829},{1.903761, 0.136921, 0.005676}}],
    Polygon[{{1.905667, 0.138521, 0.006829},{1.906599, 0.137844, 0.007813},{
      1.905793, 0.136261, 0.007813},{1.904697, 0.136617, 0.006829}}],
    Polygon[{{1.906599, 0.137844, 0.007813},{1.907644, 0.137084, 0.008605},{
      1.907022, 0.135862, 0.008605},{1.905793, 0.136261, 0.007813}}],
    Polygon[{{1.907644, 0.137084, 0.008605},{1.908777, 0.136261, 0.009185},{
      1.908353, 0.135429, 0.009185},{1.907022, 0.135862, 0.008605}}],
    Polygon[{{1.908777, 0.136261, 0.009185},{1.909969, 0.135395, 0.009538},{
      1.909754, 0.134974, 0.009538},{1.908353, 0.135429, 0.009185}}],
    Polygon[{{1.909754, 0.134974, -0.009538},{1.908353, 0.135429, -0.009185},{
      1.908207, 0.134507, -0.009185},{1.909680, 0.134507, -0.009538}}],
    Polygon[{{1.908353, 0.135429, -0.009185},{1.907022, 0.135862, -0.008605},{
      1.906807, 0.134507, -0.008605},{1.908207, 0.134507, -0.009185}}],
    Polygon[{{1.907022, 0.135862, -0.008605},{1.905793, 0.136261, -0.007813},{
      1.905515, 0.134507, -0.007813},{1.906807, 0.134507, -0.008605}}],
    Polygon[{{1.905793, 0.136261, -0.007813},{1.904697, 0.136617, -0.006829},{
      1.904363, 0.134507, -0.006829},{1.905515, 0.134507, -0.007813}}],
    Polygon[{{1.904697, 0.136617, -0.006829},{1.903761, 0.136921, -0.005676},{
      1.903378, 0.134507, -0.005676},{1.904363, 0.134507, -0.006829}}],
    Polygon[{{1.903761, 0.136921, -0.005676},{1.903008, 0.137166, -0.004384},{
      1.902587, 0.134507, -0.004384},{1.903378, 0.134507, -0.005676}}],
    Polygon[{{1.903008, 0.137166, -0.004384},{1.902456, 0.137345, -0.002984},{
      1.902007, 0.134507, -0.002984},{1.902587, 0.134507, -0.004384}}],
    Polygon[{{1.902456, 0.137345, -0.002984},{1.902120, 0.137455, -0.001511},{
      1.901653, 0.134507, -0.001511},{1.902007, 0.134507, -0.002984}}],
    Polygon[{{1.902120, 0.137455, -0.001511},{1.902007, 0.137491, 0.000000},{
      1.901534, 0.134507, 0.000000},{1.901653, 0.134507, -0.001511}}],
    Polygon[{{1.902007, 0.137491, 0.000000},{1.902120, 0.137455, 0.001511},{
      1.901653, 0.134507, 0.001511},{1.901534, 0.134507, 0.000000}}],
    Polygon[{{1.902120, 0.137455, 0.001511},{1.902456, 0.137345, 0.002984},{
      1.902007, 0.134507, 0.002984},{1.901653, 0.134507, 0.001511}}],
    Polygon[{{1.902456, 0.137345, 0.002984},{1.903008, 0.137166, 0.004384},{
      1.902587, 0.134507, 0.004384},{1.902007, 0.134507, 0.002984}}],
    Polygon[{{1.903008, 0.137166, 0.004384},{1.903761, 0.136921, 0.005676},{
      1.903378, 0.134507, 0.005676},{1.902587, 0.134507, 0.004384}}],
    Polygon[{{1.903761, 0.136921, 0.005676},{1.904697, 0.136617, 0.006829},{
      1.904363, 0.134507, 0.006829},{1.903378, 0.134507, 0.005676}}],
    Polygon[{{1.904697, 0.136617, 0.006829},{1.905793, 0.136261, 0.007813},{
      1.905515, 0.134507, 0.007813},{1.904363, 0.134507, 0.006829}}],
    Polygon[{{1.905793, 0.136261, 0.007813},{1.907022, 0.135862, 0.008605},{
      1.906807, 0.134507, 0.008605},{1.905515, 0.134507, 0.007813}}],
    Polygon[{{1.907022, 0.135862, 0.008605},{1.908353, 0.135429, 0.009185},{
      1.908207, 0.134507, 0.009185},{1.906807, 0.134507, 0.008605}}],
    Polygon[{{1.908353, 0.135429, 0.009185},{1.909754, 0.134974, 0.009538},{
      1.909680, 0.134507, 0.009538},{1.908207, 0.134507, 0.009185}}],
    Polygon[{{1.909680, 0.134507, -0.009538},{1.908207, 0.134507, -0.009185},{
      1.908353, 0.133585, -0.009185},{1.909754, 0.134040, -0.009538}}],
    Polygon[{{1.908207, 0.134507, -0.009185},{1.906807, 0.134507, -0.008605},{
      1.907022, 0.133152, -0.008605},{1.908353, 0.133585, -0.009185}}],
    Polygon[{{1.906807, 0.134507, -0.008605},{1.905515, 0.134507, -0.007813},{
      1.905793, 0.132753, -0.007813},{1.907022, 0.133152, -0.008605}}],
    Polygon[{{1.905515, 0.134507, -0.007813},{1.904363, 0.134507, -0.006829},{
      1.904697, 0.132397, -0.006829},{1.905793, 0.132753, -0.007813}}],
    Polygon[{{1.904363, 0.134507, -0.006829},{1.903378, 0.134507, -0.005676},{
      1.903761, 0.132093, -0.005676},{1.904697, 0.132397, -0.006829}}],
    Polygon[{{1.903378, 0.134507, -0.005676},{1.902587, 0.134507, -0.004384},{
      1.903008, 0.131848, -0.004384},{1.903761, 0.132093, -0.005676}}],
    Polygon[{{1.902587, 0.134507, -0.004384},{1.902007, 0.134507, -0.002984},{
      1.902456, 0.131669, -0.002984},{1.903008, 0.131848, -0.004384}}],
    Polygon[{{1.902007, 0.134507, -0.002984},{1.901653, 0.134507, -0.001511},{
      1.902120, 0.131560, -0.001511},{1.902456, 0.131669, -0.002984}}],
    Polygon[{{1.901653, 0.134507, -0.001511},{1.901534, 0.134507, 0.000000},{
      1.902007, 0.131523, 0.000000},{1.902120, 0.131560, -0.001511}}],
    Polygon[{{1.901534, 0.134507, 0.000000},{1.901653, 0.134507, 0.001511},{
      1.902120, 0.131560, 0.001511},{1.902007, 0.131523, 0.000000}}],
    Polygon[{{1.901653, 0.134507, 0.001511},{1.902007, 0.134507, 0.002984},{
      1.902456, 0.131669, 0.002984},{1.902120, 0.131560, 0.001511}}],
    Polygon[{{1.902007, 0.134507, 0.002984},{1.902587, 0.134507, 0.004384},{
      1.903008, 0.131848, 0.004384},{1.902456, 0.131669, 0.002984}}],
    Polygon[{{1.902587, 0.134507, 0.004384},{1.903378, 0.134507, 0.005676},{
      1.903761, 0.132093, 0.005676},{1.903008, 0.131848, 0.004384}}],
    Polygon[{{1.903378, 0.134507, 0.005676},{1.904363, 0.134507, 0.006829},{
      1.904697, 0.132397, 0.006829},{1.903761, 0.132093, 0.005676}}],
    Polygon[{{1.904363, 0.134507, 0.006829},{1.905515, 0.134507, 0.007813},{
      1.905793, 0.132753, 0.007813},{1.904697, 0.132397, 0.006829}}],
    Polygon[{{1.905515, 0.134507, 0.007813},{1.906807, 0.134507, 0.008605},{
      1.907022, 0.133152, 0.008605},{1.905793, 0.132753, 0.007813}}],
    Polygon[{{1.906807, 0.134507, 0.008605},{1.908207, 0.134507, 0.009185},{
      1.908353, 0.133585, 0.009185},{1.907022, 0.133152, 0.008605}}],
    Polygon[{{1.908207, 0.134507, 0.009185},{1.909680, 0.134507, 0.009538},{
      1.909754, 0.134040, 0.009538},{1.908353, 0.133585, 0.009185}}],
    Polygon[{{1.909754, 0.134040, -0.009538},{1.908353, 0.133585, -0.009185},{
      1.908777, 0.132753, -0.009185},{1.909969, 0.133619, -0.009538}}],
    Polygon[{{1.908353, 0.133585, -0.009185},{1.907022, 0.133152, -0.008605},{
      1.907644, 0.131930, -0.008605},{1.908777, 0.132753, -0.009185}}],
    Polygon[{{1.907022, 0.133152, -0.008605},{1.905793, 0.132753, -0.007813},{
      1.906599, 0.131171, -0.007813},{1.907644, 0.131930, -0.008605}}],
    Polygon[{{1.905793, 0.132753, -0.007813},{1.904697, 0.132397, -0.006829},{
      1.905667, 0.130493, -0.006829},{1.906599, 0.131171, -0.007813}}],
    Polygon[{{1.904697, 0.132397, -0.006829},{1.903761, 0.132093, -0.005676},{
      1.904871, 0.129915, -0.005676},{1.905667, 0.130493, -0.006829}}],
    Polygon[{{1.903761, 0.132093, -0.005676},{1.903008, 0.131848, -0.004384},{
      1.904230, 0.129449, -0.004384},{1.904871, 0.129915, -0.005676}}],
    Polygon[{{1.903008, 0.131848, -0.004384},{1.902456, 0.131669, -0.002984},{
      1.903761, 0.129109, -0.002984},{1.904230, 0.129449, -0.004384}}],
    Polygon[{{1.902456, 0.131669, -0.002984},{1.902120, 0.131560, -0.001511},{
      1.903475, 0.128901, -0.001511},{1.903761, 0.129109, -0.002984}}],
    Polygon[{{1.902120, 0.131560, -0.001511},{1.902007, 0.131523, 0.000000},{
      1.903378, 0.128831, 0.000000},{1.903475, 0.128901, -0.001511}}],
    Polygon[{{1.902007, 0.131523, 0.000000},{1.902120, 0.131560, 0.001511},{
      1.903475, 0.128901, 0.001511},{1.903378, 0.128831, 0.000000}}],
    Polygon[{{1.902120, 0.131560, 0.001511},{1.902456, 0.131669, 0.002984},{
      1.903761, 0.129109, 0.002984},{1.903475, 0.128901, 0.001511}}],
    Polygon[{{1.902456, 0.131669, 0.002984},{1.903008, 0.131848, 0.004384},{
      1.904230, 0.129449, 0.004384},{1.903761, 0.129109, 0.002984}}],
    Polygon[{{1.903008, 0.131848, 0.004384},{1.903761, 0.132093, 0.005676},{
      1.904871, 0.129915, 0.005676},{1.904230, 0.129449, 0.004384}}],
    Polygon[{{1.903761, 0.132093, 0.005676},{1.904697, 0.132397, 0.006829},{
      1.905667, 0.130493, 0.006829},{1.904871, 0.129915, 0.005676}}],
    Polygon[{{1.904697, 0.132397, 0.006829},{1.905793, 0.132753, 0.007813},{
      1.906599, 0.131171, 0.007813},{1.905667, 0.130493, 0.006829}}],
    Polygon[{{1.905793, 0.132753, 0.007813},{1.907022, 0.133152, 0.008605},{
      1.907644, 0.131930, 0.008605},{1.906599, 0.131171, 0.007813}}],
    Polygon[{{1.907022, 0.133152, 0.008605},{1.908353, 0.133585, 0.009185},{
      1.908777, 0.132753, 0.009185},{1.907644, 0.131930, 0.008605}}],
    Polygon[{{1.908353, 0.133585, 0.009185},{1.909754, 0.134040, 0.009538},{
      1.909969, 0.133619, 0.009538},{1.908777, 0.132753, 0.009185}}],
    Polygon[{{1.909969, 0.133619, -0.009538},{1.908777, 0.132753, -0.009185},{
      1.909437, 0.132093, -0.009185},{1.910303, 0.133285, -0.009538}}],
    Polygon[{{1.908777, 0.132753, -0.009185},{1.907644, 0.131930, -0.008605},{
      1.908614, 0.130960, -0.008605},{1.909437, 0.132093, -0.009185}}],
    Polygon[{{1.907644, 0.131930, -0.008605},{1.906599, 0.131171, -0.007813},{
      1.907855, 0.129915, -0.007813},{1.908614, 0.130960, -0.008605}}],
    Polygon[{{1.906599, 0.131171, -0.007813},{1.905667, 0.130493, -0.006829},{
      1.907177, 0.128983, -0.006829},{1.907855, 0.129915, -0.007813}}],
    Polygon[{{1.905667, 0.130493, -0.006829},{1.904871, 0.129915, -0.005676},{
      1.906599, 0.128186, -0.005676},{1.907177, 0.128983, -0.006829}}],
    Polygon[{{1.904871, 0.129915, -0.005676},{1.904230, 0.129449, -0.004384},{
      1.906134, 0.127546, -0.004384},{1.906599, 0.128186, -0.005676}}],
    Polygon[{{1.904230, 0.129449, -0.004384},{1.903761, 0.129109, -0.002984},{
      1.905793, 0.127077, -0.002984},{1.906134, 0.127546, -0.004384}}],
    Polygon[{{1.903761, 0.129109, -0.002984},{1.903475, 0.128901, -0.001511},{
      1.905585, 0.126790, -0.001511},{1.905793, 0.127077, -0.002984}}],
    Polygon[{{1.903475, 0.128901, -0.001511},{1.903378, 0.128831, 0.000000},{
      1.905515, 0.126694, 0.000000},{1.905585, 0.126790, -0.001511}}],
    Polygon[{{1.903378, 0.128831, 0.000000},{1.903475, 0.128901, 0.001511},{
      1.905585, 0.126790, 0.001511},{1.905515, 0.126694, 0.000000}}],
    Polygon[{{1.903475, 0.128901, 0.001511},{1.903761, 0.129109, 0.002984},{
      1.905793, 0.127077, 0.002984},{1.905585, 0.126790, 0.001511}}],
    Polygon[{{1.903761, 0.129109, 0.002984},{1.904230, 0.129449, 0.004384},{
      1.906134, 0.127546, 0.004384},{1.905793, 0.127077, 0.002984}}],
    Polygon[{{1.904230, 0.129449, 0.004384},{1.904871, 0.129915, 0.005676},{
      1.906599, 0.128186, 0.005676},{1.906134, 0.127546, 0.004384}}],
    Polygon[{{1.904871, 0.129915, 0.005676},{1.905667, 0.130493, 0.006829},{
      1.907177, 0.128983, 0.006829},{1.906599, 0.128186, 0.005676}}],
    Polygon[{{1.905667, 0.130493, 0.006829},{1.906599, 0.131171, 0.007813},{
      1.907855, 0.129915, 0.007813},{1.907177, 0.128983, 0.006829}}],
    Polygon[{{1.906599, 0.131171, 0.007813},{1.907644, 0.131930, 0.008605},{
      1.908614, 0.130960, 0.008605},{1.907855, 0.129915, 0.007813}}],
    Polygon[{{1.907644, 0.131930, 0.008605},{1.908777, 0.132753, 0.009185},{
      1.909437, 0.132093, 0.009185},{1.908614, 0.130960, 0.008605}}],
    Polygon[{{1.908777, 0.132753, 0.009185},{1.909969, 0.133619, 0.009538},{
      1.910303, 0.133285, 0.009538},{1.909437, 0.132093, 0.009185}}],
    Polygon[{{1.910303, 0.133285, -0.009538},{1.909437, 0.132093, -0.009185},{
      1.910269, 0.131669, -0.009185},{1.910724, 0.133070, -0.009538}}],
    Polygon[{{1.909437, 0.132093, -0.009185},{1.908614, 0.130960, -0.008605},{
      1.909836, 0.130337, -0.008605},{1.910269, 0.131669, -0.009185}}],
    Polygon[{{1.908614, 0.130960, -0.008605},{1.907855, 0.129915, -0.007813},{
      1.909437, 0.129109, -0.007813},{1.909836, 0.130337, -0.008605}}],
    Polygon[{{1.907855, 0.129915, -0.007813},{1.907177, 0.128983, -0.006829},{
      1.909081, 0.128013, -0.006829},{1.909437, 0.129109, -0.007813}}],
    Polygon[{{1.907177, 0.128983, -0.006829},{1.906599, 0.128186, -0.005676},{
      1.908777, 0.127077, -0.005676},{1.909081, 0.128013, -0.006829}}],
    Polygon[{{1.906599, 0.128186, -0.005676},{1.906134, 0.127546, -0.004384},{
      1.908532, 0.126324, -0.004384},{1.908777, 0.127077, -0.005676}}],
    Polygon[{{1.906134, 0.127546, -0.004384},{1.905793, 0.127077, -0.002984},{
      1.908353, 0.125772, -0.002984},{1.908532, 0.126324, -0.004384}}],
    Polygon[{{1.905793, 0.127077, -0.002984},{1.905585, 0.126790, -0.001511},{
      1.908244, 0.125436, -0.001511},{1.908353, 0.125772, -0.002984}}],
    Polygon[{{1.905585, 0.126790, -0.001511},{1.905515, 0.126694, 0.000000},{
      1.908207, 0.125323, 0.000000},{1.908244, 0.125436, -0.001511}}],
    Polygon[{{1.905515, 0.126694, 0.000000},{1.905585, 0.126790, 0.001511},{
      1.908244, 0.125436, 0.001511},{1.908207, 0.125323, 0.000000}}],
    Polygon[{{1.905585, 0.126790, 0.001511},{1.905793, 0.127077, 0.002984},{
      1.908353, 0.125772, 0.002984},{1.908244, 0.125436, 0.001511}}],
    Polygon[{{1.905793, 0.127077, 0.002984},{1.906134, 0.127546, 0.004384},{
      1.908532, 0.126324, 0.004384},{1.908353, 0.125772, 0.002984}}],
    Polygon[{{1.906134, 0.127546, 0.004384},{1.906599, 0.128186, 0.005676},{
      1.908777, 0.127077, 0.005676},{1.908532, 0.126324, 0.004384}}],
    Polygon[{{1.906599, 0.128186, 0.005676},{1.907177, 0.128983, 0.006829},{
      1.909081, 0.128013, 0.006829},{1.908777, 0.127077, 0.005676}}],
    Polygon[{{1.907177, 0.128983, 0.006829},{1.907855, 0.129915, 0.007813},{
      1.909437, 0.129109, 0.007813},{1.909081, 0.128013, 0.006829}}],
    Polygon[{{1.907855, 0.129915, 0.007813},{1.908614, 0.130960, 0.008605},{
      1.909836, 0.130337, 0.008605},{1.909437, 0.129109, 0.007813}}],
    Polygon[{{1.908614, 0.130960, 0.008605},{1.909437, 0.132093, 0.009185},{
      1.910269, 0.131669, 0.009185},{1.909836, 0.130337, 0.008605}}],
    Polygon[{{1.909437, 0.132093, 0.009185},{1.910303, 0.133285, 0.009538},{
      1.910724, 0.133070, 0.009538},{1.910269, 0.131669, 0.009185}}],
    Polygon[{{1.910724, 0.133070, -0.009538},{1.910269, 0.131669, -0.009185},{
      1.911191, 0.131523, -0.009185},{1.911191, 0.132996, -0.009538}}],
    Polygon[{{1.910269, 0.131669, -0.009185},{1.909836, 0.130337, -0.008605},{
      1.911191, 0.130123, -0.008605},{1.911191, 0.131523, -0.009185}}],
    Polygon[{{1.909836, 0.130337, -0.008605},{1.909437, 0.129109, -0.007813},{
      1.911191, 0.128831, -0.007813},{1.911191, 0.130123, -0.008605}}],
    Polygon[{{1.909437, 0.129109, -0.007813},{1.909081, 0.128013, -0.006829},{
      1.911191, 0.127678, -0.006829},{1.911191, 0.128831, -0.007813}}],
    Polygon[{{1.909081, 0.128013, -0.006829},{1.908777, 0.127077, -0.005676},{
      1.911191, 0.126694, -0.005676},{1.911191, 0.127678, -0.006829}}],
    Polygon[{{1.908777, 0.127077, -0.005676},{1.908532, 0.126324, -0.004384},{
      1.911191, 0.125902, -0.004384},{1.911191, 0.126694, -0.005676}}],
    Polygon[{{1.908532, 0.126324, -0.004384},{1.908353, 0.125772, -0.002984},{
      1.911191, 0.125323, -0.002984},{1.911191, 0.125902, -0.004384}}],
    Polygon[{{1.908353, 0.125772, -0.002984},{1.908244, 0.125436, -0.001511},{
      1.911191, 0.124969, -0.001511},{1.911191, 0.125323, -0.002984}}],
    Polygon[{{1.908244, 0.125436, -0.001511},{1.908207, 0.125323, 0.000000},{
      1.911191, 0.124850, 0.000000},{1.911191, 0.124969, -0.001511}}],
    Polygon[{{1.908207, 0.125323, 0.000000},{1.908244, 0.125436, 0.001511},{
      1.911191, 0.124969, 0.001511},{1.911191, 0.124850, 0.000000}}],
    Polygon[{{1.908244, 0.125436, 0.001511},{1.908353, 0.125772, 0.002984},{
      1.911191, 0.125323, 0.002984},{1.911191, 0.124969, 0.001511}}],
    Polygon[{{1.908353, 0.125772, 0.002984},{1.908532, 0.126324, 0.004384},{
      1.911191, 0.125902, 0.004384},{1.911191, 0.125323, 0.002984}}],
    Polygon[{{1.908532, 0.126324, 0.004384},{1.908777, 0.127077, 0.005676},{
      1.911191, 0.126694, 0.005676},{1.911191, 0.125902, 0.004384}}],
    Polygon[{{1.908777, 0.127077, 0.005676},{1.909081, 0.128013, 0.006829},{
      1.911191, 0.127678, 0.006829},{1.911191, 0.126694, 0.005676}}],
    Polygon[{{1.909081, 0.128013, 0.006829},{1.909437, 0.129109, 0.007813},{
      1.911191, 0.128831, 0.007813},{1.911191, 0.127678, 0.006829}}],
    Polygon[{{1.909437, 0.129109, 0.007813},{1.909836, 0.130337, 0.008605},{
      1.911191, 0.130123, 0.008605},{1.911191, 0.128831, 0.007813}}],
    Polygon[{{1.909836, 0.130337, 0.008605},{1.910269, 0.131669, 0.009185},{
      1.911191, 0.131523, 0.009185},{1.911191, 0.130123, 0.008605}}],
    Polygon[{{1.910269, 0.131669, 0.009185},{1.910724, 0.133070, 0.009538},{
      1.911191, 0.132996, 0.009538},{1.911191, 0.131523, 0.009185}}],
    Polygon[{{1.911191, 0.132996, -0.009538},{1.911191, 0.131523, -0.009185},{
      1.912113, 0.131669, -0.009185},{1.911658, 0.133070, -0.009538}}],
    Polygon[{{1.911191, 0.131523, -0.009185},{1.911191, 0.130123, -0.008605},{
      1.912546, 0.130337, -0.008605},{1.912113, 0.131669, -0.009185}}],
    Polygon[{{1.911191, 0.130123, -0.008605},{1.911191, 0.128831, -0.007813},{
      1.912945, 0.129109, -0.007813},{1.912546, 0.130337, -0.008605}}],
    Polygon[{{1.911191, 0.128831, -0.007813},{1.911191, 0.127678, -0.006829},{
      1.913301, 0.128013, -0.006829},{1.912945, 0.129109, -0.007813}}],
    Polygon[{{1.911191, 0.127678, -0.006829},{1.911191, 0.126694, -0.005676},{
      1.913605, 0.127077, -0.005676},{1.913301, 0.128013, -0.006829}}],
    Polygon[{{1.911191, 0.126694, -0.005676},{1.911191, 0.125902, -0.004384},{
      1.913850, 0.126324, -0.004384},{1.913605, 0.127077, -0.005676}}],
    Polygon[{{1.911191, 0.125902, -0.004384},{1.911191, 0.125323, -0.002984},{
      1.914029, 0.125772, -0.002984},{1.913850, 0.126324, -0.004384}}],
    Polygon[{{1.911191, 0.125323, -0.002984},{1.911191, 0.124969, -0.001511},{
      1.914139, 0.125436, -0.001511},{1.914029, 0.125772, -0.002984}}],
    Polygon[{{1.911191, 0.124969, -0.001511},{1.911191, 0.124850, 0.000000},{
      1.914175, 0.125323, 0.000000},{1.914139, 0.125436, -0.001511}}],
    Polygon[{{1.911191, 0.124850, 0.000000},{1.911191, 0.124969, 0.001511},{
      1.914139, 0.125436, 0.001511},{1.914175, 0.125323, 0.000000}}],
    Polygon[{{1.911191, 0.124969, 0.001511},{1.911191, 0.125323, 0.002984},{
      1.914029, 0.125772, 0.002984},{1.914139, 0.125436, 0.001511}}],
    Polygon[{{1.911191, 0.125323, 0.002984},{1.911191, 0.125902, 0.004384},{
      1.913850, 0.126324, 0.004384},{1.914029, 0.125772, 0.002984}}],
    Polygon[{{1.911191, 0.125902, 0.004384},{1.911191, 0.126694, 0.005676},{
      1.913605, 0.127077, 0.005676},{1.913850, 0.126324, 0.004384}}],
    Polygon[{{1.911191, 0.126694, 0.005676},{1.911191, 0.127678, 0.006829},{
      1.913301, 0.128013, 0.006829},{1.913605, 0.127077, 0.005676}}],
    Polygon[{{1.911191, 0.127678, 0.006829},{1.911191, 0.128831, 0.007813},{
      1.912945, 0.129109, 0.007813},{1.913301, 0.128013, 0.006829}}],
    Polygon[{{1.911191, 0.128831, 0.007813},{1.911191, 0.130123, 0.008605},{
      1.912546, 0.130337, 0.008605},{1.912945, 0.129109, 0.007813}}],
    Polygon[{{1.911191, 0.130123, 0.008605},{1.911191, 0.131523, 0.009185},{
      1.912113, 0.131669, 0.009185},{1.912546, 0.130337, 0.008605}}],
    Polygon[{{1.911191, 0.131523, 0.009185},{1.911191, 0.132996, 0.009538},{
      1.911658, 0.133070, 0.009538},{1.912113, 0.131669, 0.009185}}],
    Polygon[{{1.911658, 0.133070, -0.009538},{1.912113, 0.131669, -0.009185},{
      1.912945, 0.132093, -0.009185},{1.912079, 0.133285, -0.009538}}],
    Polygon[{{1.912113, 0.131669, -0.009185},{1.912546, 0.130337, -0.008605},{
      1.913768, 0.130960, -0.008605},{1.912945, 0.132093, -0.009185}}],
    Polygon[{{1.912546, 0.130337, -0.008605},{1.912945, 0.129109, -0.007813},{
      1.914528, 0.129915, -0.007813},{1.913768, 0.130960, -0.008605}}],
    Polygon[{{1.912945, 0.129109, -0.007813},{1.913301, 0.128013, -0.006829},{
      1.915205, 0.128983, -0.006829},{1.914528, 0.129915, -0.007813}}],
    Polygon[{{1.913301, 0.128013, -0.006829},{1.913605, 0.127077, -0.005676},{
      1.915783, 0.128186, -0.005676},{1.915205, 0.128983, -0.006829}}],
    Polygon[{{1.913605, 0.127077, -0.005676},{1.913850, 0.126324, -0.004384},{
      1.916249, 0.127546, -0.004384},{1.915783, 0.128186, -0.005676}}],
    Polygon[{{1.913850, 0.126324, -0.004384},{1.914029, 0.125772, -0.002984},{
      1.916590, 0.127077, -0.002984},{1.916249, 0.127546, -0.004384}}],
    Polygon[{{1.914029, 0.125772, -0.002984},{1.914139, 0.125436, -0.001511},{
      1.916798, 0.126790, -0.001511},{1.916590, 0.127077, -0.002984}}],
    Polygon[{{1.914139, 0.125436, -0.001511},{1.914175, 0.125323, 0.000000},{
      1.916867, 0.126694, 0.000000},{1.916798, 0.126790, -0.001511}}],
    Polygon[{{1.914175, 0.125323, 0.000000},{1.914139, 0.125436, 0.001511},{
      1.916798, 0.126790, 0.001511},{1.916867, 0.126694, 0.000000}}],
    Polygon[{{1.914139, 0.125436, 0.001511},{1.914029, 0.125772, 0.002984},{
      1.916590, 0.127077, 0.002984},{1.916798, 0.126790, 0.001511}}],
    Polygon[{{1.914029, 0.125772, 0.002984},{1.913850, 0.126324, 0.004384},{
      1.916249, 0.127546, 0.004384},{1.916590, 0.127077, 0.002984}}],
    Polygon[{{1.913850, 0.126324, 0.004384},{1.913605, 0.127077, 0.005676},{
      1.915783, 0.128186, 0.005676},{1.916249, 0.127546, 0.004384}}],
    Polygon[{{1.913605, 0.127077, 0.005676},{1.913301, 0.128013, 0.006829},{
      1.915205, 0.128983, 0.006829},{1.915783, 0.128186, 0.005676}}],
    Polygon[{{1.913301, 0.128013, 0.006829},{1.912945, 0.129109, 0.007813},{
      1.914528, 0.129915, 0.007813},{1.915205, 0.128983, 0.006829}}],
    Polygon[{{1.912945, 0.129109, 0.007813},{1.912546, 0.130337, 0.008605},{
      1.913768, 0.130960, 0.008605},{1.914528, 0.129915, 0.007813}}],
    Polygon[{{1.912546, 0.130337, 0.008605},{1.912113, 0.131669, 0.009185},{
      1.912945, 0.132093, 0.009185},{1.913768, 0.130960, 0.008605}}],
    Polygon[{{1.912113, 0.131669, 0.009185},{1.911658, 0.133070, 0.009538},{
      1.912079, 0.133285, 0.009538},{1.912945, 0.132093, 0.009185}}],
    Polygon[{{1.912079, 0.133285, -0.009538},{1.912945, 0.132093, -0.009185},{
      1.913605, 0.132753, -0.009185},{1.912413, 0.133619, -0.009538}}],
    Polygon[{{1.912945, 0.132093, -0.009185},{1.913768, 0.130960, -0.008605},{
      1.914738, 0.131930, -0.008605},{1.913605, 0.132753, -0.009185}}],
    Polygon[{{1.913768, 0.130960, -0.008605},{1.914528, 0.129915, -0.007813},{
      1.915783, 0.131171, -0.007813},{1.914738, 0.131930, -0.008605}}],
    Polygon[{{1.914528, 0.129915, -0.007813},{1.915205, 0.128983, -0.006829},{
      1.916716, 0.130493, -0.006829},{1.915783, 0.131171, -0.007813}}],
    Polygon[{{1.915205, 0.128983, -0.006829},{1.915783, 0.128186, -0.005676},{
      1.917512, 0.129915, -0.005676},{1.916716, 0.130493, -0.006829}}],
    Polygon[{{1.915783, 0.128186, -0.005676},{1.916249, 0.127546, -0.004384},{
      1.918152, 0.129449, -0.004384},{1.917512, 0.129915, -0.005676}}],
    Polygon[{{1.916249, 0.127546, -0.004384},{1.916590, 0.127077, -0.002984},{
      1.918622, 0.129109, -0.002984},{1.918152, 0.129449, -0.004384}}],
    Polygon[{{1.916590, 0.127077, -0.002984},{1.916798, 0.126790, -0.001511},{
      1.918908, 0.128901, -0.001511},{1.918622, 0.129109, -0.002984}}],
    Polygon[{{1.916798, 0.126790, -0.001511},{1.916867, 0.126694, 0.000000},{
      1.919004, 0.128831, 0.000000},{1.918908, 0.128901, -0.001511}}],
    Polygon[{{1.916867, 0.126694, 0.000000},{1.916798, 0.126790, 0.001511},{
      1.918908, 0.128901, 0.001511},{1.919004, 0.128831, 0.000000}}],
    Polygon[{{1.916798, 0.126790, 0.001511},{1.916590, 0.127077, 0.002984},{
      1.918622, 0.129109, 0.002984},{1.918908, 0.128901, 0.001511}}],
    Polygon[{{1.916590, 0.127077, 0.002984},{1.916249, 0.127546, 0.004384},{
      1.918152, 0.129449, 0.004384},{1.918622, 0.129109, 0.002984}}],
    Polygon[{{1.916249, 0.127546, 0.004384},{1.915783, 0.128186, 0.005676},{
      1.917512, 0.129915, 0.005676},{1.918152, 0.129449, 0.004384}}],
    Polygon[{{1.915783, 0.128186, 0.005676},{1.915205, 0.128983, 0.006829},{
      1.916716, 0.130493, 0.006829},{1.917512, 0.129915, 0.005676}}],
    Polygon[{{1.915205, 0.128983, 0.006829},{1.914528, 0.129915, 0.007813},{
      1.915783, 0.131171, 0.007813},{1.916716, 0.130493, 0.006829}}],
    Polygon[{{1.914528, 0.129915, 0.007813},{1.913768, 0.130960, 0.008605},{
      1.914738, 0.131930, 0.008605},{1.915783, 0.131171, 0.007813}}],
    Polygon[{{1.913768, 0.130960, 0.008605},{1.912945, 0.132093, 0.009185},{
      1.913605, 0.132753, 0.009185},{1.914738, 0.131930, 0.008605}}],
    Polygon[{{1.912945, 0.132093, 0.009185},{1.912079, 0.133285, 0.009538},{
      1.912413, 0.133619, 0.009538},{1.913605, 0.132753, 0.009185}}],
    Polygon[{{1.912413, 0.133619, -0.009538},{1.913605, 0.132753, -0.009185},{
      1.914029, 0.133585, -0.009185},{1.912628, 0.134040, -0.009538}}],
    Polygon[{{1.913605, 0.132753, -0.009185},{1.914738, 0.131930, -0.008605},{
      1.915361, 0.133152, -0.008605},{1.914029, 0.133585, -0.009185}}],
    Polygon[{{1.914738, 0.131930, -0.008605},{1.915783, 0.131171, -0.007813},{
      1.916590, 0.132753, -0.007813},{1.915361, 0.133152, -0.008605}}],
    Polygon[{{1.915783, 0.131171, -0.007813},{1.916716, 0.130493, -0.006829},{
      1.917686, 0.132397, -0.006829},{1.916590, 0.132753, -0.007813}}],
    Polygon[{{1.916716, 0.130493, -0.006829},{1.917512, 0.129915, -0.005676},{
      1.918622, 0.132093, -0.005676},{1.917686, 0.132397, -0.006829}}],
    Polygon[{{1.917512, 0.129915, -0.005676},{1.918152, 0.129449, -0.004384},{
      1.919375, 0.131848, -0.004384},{1.918622, 0.132093, -0.005676}}],
    Polygon[{{1.918152, 0.129449, -0.004384},{1.918622, 0.129109, -0.002984},{
      1.919926, 0.131669, -0.002984},{1.919375, 0.131848, -0.004384}}],
    Polygon[{{1.918622, 0.129109, -0.002984},{1.918908, 0.128901, -0.001511},{
      1.920263, 0.131560, -0.001511},{1.919926, 0.131669, -0.002984}}],
    Polygon[{{1.918908, 0.128901, -0.001511},{1.919004, 0.128831, 0.000000},{
      1.920376, 0.131523, 0.000000},{1.920263, 0.131560, -0.001511}}],
    Polygon[{{1.919004, 0.128831, 0.000000},{1.918908, 0.128901, 0.001511},{
      1.920263, 0.131560, 0.001511},{1.920376, 0.131523, 0.000000}}],
    Polygon[{{1.918908, 0.128901, 0.001511},{1.918622, 0.129109, 0.002984},{
      1.919926, 0.131669, 0.002984},{1.920263, 0.131560, 0.001511}}],
    Polygon[{{1.918622, 0.129109, 0.002984},{1.918152, 0.129449, 0.004384},{
      1.919375, 0.131848, 0.004384},{1.919926, 0.131669, 0.002984}}],
    Polygon[{{1.918152, 0.129449, 0.004384},{1.917512, 0.129915, 0.005676},{
      1.918622, 0.132093, 0.005676},{1.919375, 0.131848, 0.004384}}],
    Polygon[{{1.917512, 0.129915, 0.005676},{1.916716, 0.130493, 0.006829},{
      1.917686, 0.132397, 0.006829},{1.918622, 0.132093, 0.005676}}],
    Polygon[{{1.916716, 0.130493, 0.006829},{1.915783, 0.131171, 0.007813},{
      1.916590, 0.132753, 0.007813},{1.917686, 0.132397, 0.006829}}],
    Polygon[{{1.915783, 0.131171, 0.007813},{1.914738, 0.131930, 0.008605},{
      1.915361, 0.133152, 0.008605},{1.916590, 0.132753, 0.007813}}],
    Polygon[{{1.914738, 0.131930, 0.008605},{1.913605, 0.132753, 0.009185},{
      1.914029, 0.133585, 0.009185},{1.915361, 0.133152, 0.008605}}],
    Polygon[{{1.913605, 0.132753, 0.009185},{1.912413, 0.133619, 0.009538},{
      1.912628, 0.134040, 0.009538},{1.914029, 0.133585, 0.009185}}],
    Polygon[{{1.912628, 0.134040, -0.009538},{1.914029, 0.133585, -0.009185},{
      1.914175, 0.134507, -0.009185},{1.912702, 0.134507, -0.009538}}],
    Polygon[{{1.914029, 0.133585, -0.009185},{1.915361, 0.133152, -0.008605},{
      1.915575, 0.134507, -0.008605},{1.914175, 0.134507, -0.009185}}],
    Polygon[{{1.915361, 0.133152, -0.008605},{1.916590, 0.132753, -0.007813},{
      1.916867, 0.134507, -0.007813},{1.915575, 0.134507, -0.008605}}],
    Polygon[{{1.916590, 0.132753, -0.007813},{1.917686, 0.132397, -0.006829},{
      1.918020, 0.134507, -0.006829},{1.916867, 0.134507, -0.007813}}],
    Polygon[{{1.917686, 0.132397, -0.006829},{1.918622, 0.132093, -0.005676},{
      1.919004, 0.134507, -0.005676},{1.918020, 0.134507, -0.006829}}],
    Polygon[{{1.918622, 0.132093, -0.005676},{1.919375, 0.131848, -0.004384},{
      1.919796, 0.134507, -0.004384},{1.919004, 0.134507, -0.005676}}],
    Polygon[{{1.919375, 0.131848, -0.004384},{1.919926, 0.131669, -0.002984},{
      1.920376, 0.134507, -0.002984},{1.919796, 0.134507, -0.004384}}],
    Polygon[{{1.919926, 0.131669, -0.002984},{1.920263, 0.131560, -0.001511},{
      1.920729, 0.134507, -0.001511},{1.920376, 0.134507, -0.002984}}],
    Polygon[{{1.920263, 0.131560, -0.001511},{1.920376, 0.131523, 0.000000},{
      1.920848, 0.134507, 0.000000},{1.920729, 0.134507, -0.001511}}],
    Polygon[{{1.920376, 0.131523, 0.000000},{1.920263, 0.131560, 0.001511},{
      1.920729, 0.134507, 0.001511},{1.920848, 0.134507, 0.000000}}],
    Polygon[{{1.920263, 0.131560, 0.001511},{1.919926, 0.131669, 0.002984},{
      1.920376, 0.134507, 0.002984},{1.920729, 0.134507, 0.001511}}],
    Polygon[{{1.919926, 0.131669, 0.002984},{1.919375, 0.131848, 0.004384},{
      1.919796, 0.134507, 0.004384},{1.920376, 0.134507, 0.002984}}],
    Polygon[{{1.919375, 0.131848, 0.004384},{1.918622, 0.132093, 0.005676},{
      1.919004, 0.134507, 0.005676},{1.919796, 0.134507, 0.004384}}],
    Polygon[{{1.918622, 0.132093, 0.005676},{1.917686, 0.132397, 0.006829},{
      1.918020, 0.134507, 0.006829},{1.919004, 0.134507, 0.005676}}],
    Polygon[{{1.917686, 0.132397, 0.006829},{1.916590, 0.132753, 0.007813},{
      1.916867, 0.134507, 0.007813},{1.918020, 0.134507, 0.006829}}],
    Polygon[{{1.916590, 0.132753, 0.007813},{1.915361, 0.133152, 0.008605},{
      1.915575, 0.134507, 0.008605},{1.916867, 0.134507, 0.007813}}],
    Polygon[{{1.915361, 0.133152, 0.008605},{1.914029, 0.133585, 0.009185},{
      1.914175, 0.134507, 0.009185},{1.915575, 0.134507, 0.008605}}],
    Polygon[{{1.914029, 0.133585, 0.009185},{1.912628, 0.134040, 0.009538},{
      1.912702, 0.134507, 0.009538},{1.914175, 0.134507, 0.009185}}],
    Polygon[{{1.858703, 0.129498, -0.008290},{1.859983, 0.129498, -0.007983},{
      1.859856, 0.130300, -0.007983},{1.858638, 0.129904, -0.008290}}],
    Polygon[{{1.859983, 0.129498, -0.007983},{1.861200, 0.129498, -0.007479},{
      1.861014, 0.130676, -0.007479},{1.859856, 0.130300, -0.007983}}],
    Polygon[{{1.861200, 0.129498, -0.007479},{1.862323, 0.129498, -0.006791},{
      1.862082, 0.131023, -0.006791},{1.861014, 0.130676, -0.007479}}],
    Polygon[{{1.862323, 0.129498, -0.006791},{1.863325, 0.129498, -0.005935},{
      1.863034, 0.131332, -0.005935},{1.862082, 0.131023, -0.006791}}],
    Polygon[{{1.863325, 0.129498, -0.005935},{1.864180, 0.129498, -0.004934},{
      1.863848, 0.131597, -0.004934},{1.863034, 0.131332, -0.005935}}],
    Polygon[{{1.864180, 0.129498, -0.004934},{1.864868, 0.129498, -0.003811},{
      1.864502, 0.131809, -0.003811},{1.863848, 0.131597, -0.004934}}],
    Polygon[{{1.864868, 0.129498, -0.003811},{1.865372, 0.129498, -0.002594},{
      1.864982, 0.131965, -0.002594},{1.864502, 0.131809, -0.003811}}],
    Polygon[{{1.865372, 0.129498, -0.002594},{1.865680, 0.129498, -0.001313},{
      1.865274, 0.132060, -0.001313},{1.864982, 0.131965, -0.002594}}],
    Polygon[{{1.865680, 0.129498, -0.001313},{1.865783, 0.129498, 0.000000},{
      1.865372, 0.132092, 0.000000},{1.865274, 0.132060, -0.001313}}],
    Polygon[{{1.865783, 0.129498, 0.000000},{1.865680, 0.129498, 0.001313},{
      1.865274, 0.132060, 0.001313},{1.865372, 0.132092, 0.000000}}],
    Polygon[{{1.865680, 0.129498, 0.001313},{1.865372, 0.129498, 0.002594},{
      1.864982, 0.131965, 0.002594},{1.865274, 0.132060, 0.001313}}],
    Polygon[{{1.865372, 0.129498, 0.002594},{1.864868, 0.129498, 0.003811},{
      1.864502, 0.131809, 0.003811},{1.864982, 0.131965, 0.002594}}],
    Polygon[{{1.864868, 0.129498, 0.003811},{1.864180, 0.129498, 0.004934},{
      1.863848, 0.131597, 0.004934},{1.864502, 0.131809, 0.003811}}],
    Polygon[{{1.864180, 0.129498, 0.004934},{1.863325, 0.129498, 0.005935},{
      1.863034, 0.131332, 0.005935},{1.863848, 0.131597, 0.004934}}],
    Polygon[{{1.863325, 0.129498, 0.005935},{1.862323, 0.129498, 0.006791},{
      1.862082, 0.131023, 0.006791},{1.863034, 0.131332, 0.005935}}],
    Polygon[{{1.862323, 0.129498, 0.006791},{1.861200, 0.129498, 0.007479},{
      1.861014, 0.130676, 0.007479},{1.862082, 0.131023, 0.006791}}],
    Polygon[{{1.861200, 0.129498, 0.007479},{1.859983, 0.129498, 0.007983},{
      1.859856, 0.130300, 0.007983},{1.861014, 0.130676, 0.007479}}],
    Polygon[{{1.859983, 0.129498, 0.007983},{1.858703, 0.129498, 0.008290},{
      1.858638, 0.129904, 0.008290},{1.859856, 0.130300, 0.007983}}],
    Polygon[{{1.858638, 0.129904, -0.008290},{1.859856, 0.130300, -0.007983},{
      1.859488, 0.131023, -0.007983},{1.858452, 0.130270, -0.008290}}],
    Polygon[{{1.859856, 0.130300, -0.007983},{1.861014, 0.130676, -0.007479},{
      1.860472, 0.131738, -0.007479},{1.859488, 0.131023, -0.007983}}],
    Polygon[{{1.861014, 0.130676, -0.007479},{1.862082, 0.131023, -0.006791},{
      1.861381, 0.132398, -0.006791},{1.860472, 0.131738, -0.007479}}],
    Polygon[{{1.862082, 0.131023, -0.006791},{1.863034, 0.131332, -0.005935},{
      1.862191, 0.132987, -0.005935},{1.861381, 0.132398, -0.006791}}],
    Polygon[{{1.863034, 0.131332, -0.005935},{1.863848, 0.131597, -0.004934},{
      1.862883, 0.133490, -0.004934},{1.862191, 0.132987, -0.005935}}],
    Polygon[{{1.863848, 0.131597, -0.004934},{1.864502, 0.131809, -0.003811},{
      1.863440, 0.133894, -0.003811},{1.862883, 0.133490, -0.004934}}],
    Polygon[{{1.864502, 0.131809, -0.003811},{1.864982, 0.131965, -0.002594},{
      1.863848, 0.134190, -0.002594},{1.863440, 0.133894, -0.003811}}],
    Polygon[{{1.864982, 0.131965, -0.002594},{1.865274, 0.132060, -0.001313},{
      1.864097, 0.134371, -0.001313},{1.863848, 0.134190, -0.002594}}],
    Polygon[{{1.865274, 0.132060, -0.001313},{1.865372, 0.132092, 0.000000},{
      1.864180, 0.134432, 0.000000},{1.864097, 0.134371, -0.001313}}],
    Polygon[{{1.865372, 0.132092, 0.000000},{1.865274, 0.132060, 0.001313},{
      1.864097, 0.134371, 0.001313},{1.864180, 0.134432, 0.000000}}],
    Polygon[{{1.865274, 0.132060, 0.001313},{1.864982, 0.131965, 0.002594},{
      1.863848, 0.134190, 0.002594},{1.864097, 0.134371, 0.001313}}],
    Polygon[{{1.864982, 0.131965, 0.002594},{1.864502, 0.131809, 0.003811},{
      1.863440, 0.133894, 0.003811},{1.863848, 0.134190, 0.002594}}],
    Polygon[{{1.864502, 0.131809, 0.003811},{1.863848, 0.131597, 0.004934},{
      1.862883, 0.133490, 0.004934},{1.863440, 0.133894, 0.003811}}],
    Polygon[{{1.863848, 0.131597, 0.004934},{1.863034, 0.131332, 0.005935},{
      1.862191, 0.132987, 0.005935},{1.862883, 0.133490, 0.004934}}],
    Polygon[{{1.863034, 0.131332, 0.005935},{1.862082, 0.131023, 0.006791},{
      1.861381, 0.132398, 0.006791},{1.862191, 0.132987, 0.005935}}],
    Polygon[{{1.862082, 0.131023, 0.006791},{1.861014, 0.130676, 0.007479},{
      1.860472, 0.131738, 0.007479},{1.861381, 0.132398, 0.006791}}],
    Polygon[{{1.861014, 0.130676, 0.007479},{1.859856, 0.130300, 0.007983},{
      1.859488, 0.131023, 0.007983},{1.860472, 0.131738, 0.007479}}],
    Polygon[{{1.859856, 0.130300, 0.007983},{1.858638, 0.129904, 0.008290},{
      1.858452, 0.130270, 0.008290},{1.859488, 0.131023, 0.007983}}],
    Polygon[{{1.858452, 0.130270, -0.008290},{1.859488, 0.131023, -0.007983},{
      1.858914, 0.131597, -0.007983},{1.858161, 0.130560, -0.008290}}],
    Polygon[{{1.859488, 0.131023, -0.007983},{1.860472, 0.131738, -0.007479},{
      1.859629, 0.132581, -0.007479},{1.858914, 0.131597, -0.007983}}],
    Polygon[{{1.860472, 0.131738, -0.007479},{1.861381, 0.132398, -0.006791},{
      1.860289, 0.133490, -0.006791},{1.859629, 0.132581, -0.007479}}],
    Polygon[{{1.861381, 0.132398, -0.006791},{1.862191, 0.132987, -0.005935},{
      1.860878, 0.134300, -0.005935},{1.860289, 0.133490, -0.006791}}],
    Polygon[{{1.862191, 0.132987, -0.005935},{1.862883, 0.133490, -0.004934},{
      1.861381, 0.134992, -0.004934},{1.860878, 0.134300, -0.005935}}],
    Polygon[{{1.862883, 0.133490, -0.004934},{1.863440, 0.133894, -0.003811},{
      1.861786, 0.135549, -0.003811},{1.861381, 0.134992, -0.004934}}],
    Polygon[{{1.863440, 0.133894, -0.003811},{1.863848, 0.134190, -0.002594},{
      1.862082, 0.135956, -0.002594},{1.861786, 0.135549, -0.003811}}],
    Polygon[{{1.863848, 0.134190, -0.002594},{1.864097, 0.134371, -0.001313},{
      1.862262, 0.136205, -0.001313},{1.862082, 0.135956, -0.002594}}],
    Polygon[{{1.864097, 0.134371, -0.001313},{1.864180, 0.134432, 0.000000},{
      1.862323, 0.136289, 0.000000},{1.862262, 0.136205, -0.001313}}],
    Polygon[{{1.864180, 0.134432, 0.000000},{1.864097, 0.134371, 0.001313},{
      1.862262, 0.136205, 0.001313},{1.862323, 0.136289, 0.000000}}],
    Polygon[{{1.864097, 0.134371, 0.001313},{1.863848, 0.134190, 0.002594},{
      1.862082, 0.135956, 0.002594},{1.862262, 0.136205, 0.001313}}],
    Polygon[{{1.863848, 0.134190, 0.002594},{1.863440, 0.133894, 0.003811},{
      1.861786, 0.135549, 0.003811},{1.862082, 0.135956, 0.002594}}],
    Polygon[{{1.863440, 0.133894, 0.003811},{1.862883, 0.133490, 0.004934},{
      1.861381, 0.134992, 0.004934},{1.861786, 0.135549, 0.003811}}],
    Polygon[{{1.862883, 0.133490, 0.004934},{1.862191, 0.132987, 0.005935},{
      1.860878, 0.134300, 0.005935},{1.861381, 0.134992, 0.004934}}],
    Polygon[{{1.862191, 0.132987, 0.005935},{1.861381, 0.132398, 0.006791},{
      1.860289, 0.133490, 0.006791},{1.860878, 0.134300, 0.005935}}],
    Polygon[{{1.861381, 0.132398, 0.006791},{1.860472, 0.131738, 0.007479},{
      1.859629, 0.132581, 0.007479},{1.860289, 0.133490, 0.006791}}],
    Polygon[{{1.860472, 0.131738, 0.007479},{1.859488, 0.131023, 0.007983},{
      1.858914, 0.131597, 0.007983},{1.859629, 0.132581, 0.007479}}],
    Polygon[{{1.859488, 0.131023, 0.007983},{1.858452, 0.130270, 0.008290},{
      1.858161, 0.130560, 0.008290},{1.858914, 0.131597, 0.007983}}],
    Polygon[{{1.858161, 0.130560, -0.008290},{1.858914, 0.131597, -0.007983},{
      1.858191, 0.131965, -0.007983},{1.857795, 0.130747, -0.008290}}],
    Polygon[{{1.858914, 0.131597, -0.007983},{1.859629, 0.132581, -0.007479},{
      1.858567, 0.133122, -0.007479},{1.858191, 0.131965, -0.007983}}],
    Polygon[{{1.859629, 0.132581, -0.007479},{1.860289, 0.133490, -0.006791},{
      1.858914, 0.134190, -0.006791},{1.858567, 0.133122, -0.007479}}],
    Polygon[{{1.860289, 0.133490, -0.006791},{1.860878, 0.134300, -0.005935},{
      1.859224, 0.135143, -0.005935},{1.858914, 0.134190, -0.006791}}],
    Polygon[{{1.860878, 0.134300, -0.005935},{1.861381, 0.134992, -0.004934},{
      1.859488, 0.135956, -0.004934},{1.859224, 0.135143, -0.005935}}],
    Polygon[{{1.861381, 0.134992, -0.004934},{1.861786, 0.135549, -0.003811},{
      1.859701, 0.136611, -0.003811},{1.859488, 0.135956, -0.004934}}],
    Polygon[{{1.861786, 0.135549, -0.003811},{1.862082, 0.135956, -0.002594},{
      1.859856, 0.137090, -0.002594},{1.859701, 0.136611, -0.003811}}],
    Polygon[{{1.862082, 0.135956, -0.002594},{1.862262, 0.136205, -0.001313},{
      1.859951, 0.137383, -0.001313},{1.859856, 0.137090, -0.002594}}],
    Polygon[{{1.862262, 0.136205, -0.001313},{1.862323, 0.136289, 0.000000},{
      1.859983, 0.137481, 0.000000},{1.859951, 0.137383, -0.001313}}],
    Polygon[{{1.862323, 0.136289, 0.000000},{1.862262, 0.136205, 0.001313},{
      1.859951, 0.137383, 0.001313},{1.859983, 0.137481, 0.000000}}],
    Polygon[{{1.862262, 0.136205, 0.001313},{1.862082, 0.135956, 0.002594},{
      1.859856, 0.137090, 0.002594},{1.859951, 0.137383, 0.001313}}],
    Polygon[{{1.862082, 0.135956, 0.002594},{1.861786, 0.135549, 0.003811},{
      1.859701, 0.136611, 0.003811},{1.859856, 0.137090, 0.002594}}],
    Polygon[{{1.861786, 0.135549, 0.003811},{1.861381, 0.134992, 0.004934},{
      1.859488, 0.135956, 0.004934},{1.859701, 0.136611, 0.003811}}],
    Polygon[{{1.861381, 0.134992, 0.004934},{1.860878, 0.134300, 0.005935},{
      1.859224, 0.135143, 0.005935},{1.859488, 0.135956, 0.004934}}],
    Polygon[{{1.860878, 0.134300, 0.005935},{1.860289, 0.133490, 0.006791},{
      1.858914, 0.134190, 0.006791},{1.859224, 0.135143, 0.005935}}],
    Polygon[{{1.860289, 0.133490, 0.006791},{1.859629, 0.132581, 0.007479},{
      1.858567, 0.133122, 0.007479},{1.858914, 0.134190, 0.006791}}],
    Polygon[{{1.859629, 0.132581, 0.007479},{1.858914, 0.131597, 0.007983},{
      1.858191, 0.131965, 0.007983},{1.858567, 0.133122, 0.007479}}],
    Polygon[{{1.858914, 0.131597, 0.007983},{1.858161, 0.130560, 0.008290},{
      1.857795, 0.130747, 0.008290},{1.858191, 0.131965, 0.007983}}],
    Polygon[{{1.857795, 0.130747, -0.008290},{1.858191, 0.131965, -0.007983},{
      1.857390, 0.132092, -0.007983},{1.857390, 0.130811, -0.008290}}],
    Polygon[{{1.858191, 0.131965, -0.007983},{1.858567, 0.133122, -0.007479},{
      1.857390, 0.133309, -0.007479},{1.857390, 0.132092, -0.007983}}],
    Polygon[{{1.858567, 0.133122, -0.007479},{1.858914, 0.134190, -0.006791},{
      1.857390, 0.134432, -0.006791},{1.857390, 0.133309, -0.007479}}],
    Polygon[{{1.858914, 0.134190, -0.006791},{1.859224, 0.135143, -0.005935},{
      1.857390, 0.135433, -0.005935},{1.857390, 0.134432, -0.006791}}],
    Polygon[{{1.859224, 0.135143, -0.005935},{1.859488, 0.135956, -0.004934},{
      1.857390, 0.136289, -0.004934},{1.857390, 0.135433, -0.005935}}],
    Polygon[{{1.859488, 0.135956, -0.004934},{1.859701, 0.136611, -0.003811},{
      1.857390, 0.136977, -0.003811},{1.857390, 0.136289, -0.004934}}],
    Polygon[{{1.859701, 0.136611, -0.003811},{1.859856, 0.137090, -0.002594},{
      1.857390, 0.137481, -0.002594},{1.857390, 0.136977, -0.003811}}],
    Polygon[{{1.859856, 0.137090, -0.002594},{1.859951, 0.137383, -0.001313},{
      1.857390, 0.137788, -0.001313},{1.857390, 0.137481, -0.002594}}],
    Polygon[{{1.859951, 0.137383, -0.001313},{1.859983, 0.137481, 0.000000},{
      1.857390, 0.137892, 0.000000},{1.857390, 0.137788, -0.001313}}],
    Polygon[{{1.859983, 0.137481, 0.000000},{1.859951, 0.137383, 0.001313},{
      1.857390, 0.137788, 0.001313},{1.857390, 0.137892, 0.000000}}],
    Polygon[{{1.859951, 0.137383, 0.001313},{1.859856, 0.137090, 0.002594},{
      1.857390, 0.137481, 0.002594},{1.857390, 0.137788, 0.001313}}],
    Polygon[{{1.859856, 0.137090, 0.002594},{1.859701, 0.136611, 0.003811},{
      1.857390, 0.136977, 0.003811},{1.857390, 0.137481, 0.002594}}],
    Polygon[{{1.859701, 0.136611, 0.003811},{1.859488, 0.135956, 0.004934},{
      1.857390, 0.136289, 0.004934},{1.857390, 0.136977, 0.003811}}],
    Polygon[{{1.859488, 0.135956, 0.004934},{1.859224, 0.135143, 0.005935},{
      1.857390, 0.135433, 0.005935},{1.857390, 0.136289, 0.004934}}],
    Polygon[{{1.859224, 0.135143, 0.005935},{1.858914, 0.134190, 0.006791},{
      1.857390, 0.134432, 0.006791},{1.857390, 0.135433, 0.005935}}],
    Polygon[{{1.858914, 0.134190, 0.006791},{1.858567, 0.133122, 0.007479},{
      1.857390, 0.133309, 0.007479},{1.857390, 0.134432, 0.006791}}],
    Polygon[{{1.858567, 0.133122, 0.007479},{1.858191, 0.131965, 0.007983},{
      1.857390, 0.132092, 0.007983},{1.857390, 0.133309, 0.007479}}],
    Polygon[{{1.858191, 0.131965, 0.007983},{1.857795, 0.130747, 0.008290},{
      1.857390, 0.130811, 0.008290},{1.857390, 0.132092, 0.007983}}],
    Polygon[{{1.857390, 0.130811, -0.008290},{1.857390, 0.132092, -0.007983},{
      1.856588, 0.131965, -0.007983},{1.856984, 0.130747, -0.008290}}],
    Polygon[{{1.857390, 0.132092, -0.007983},{1.857390, 0.133309, -0.007479},{
      1.856212, 0.133122, -0.007479},{1.856588, 0.131965, -0.007983}}],
    Polygon[{{1.857390, 0.133309, -0.007479},{1.857390, 0.134432, -0.006791},{
      1.855865, 0.134190, -0.006791},{1.856212, 0.133122, -0.007479}}],
    Polygon[{{1.857390, 0.134432, -0.006791},{1.857390, 0.135433, -0.005935},{
      1.855556, 0.135143, -0.005935},{1.855865, 0.134190, -0.006791}}],
    Polygon[{{1.857390, 0.135433, -0.005935},{1.857390, 0.136289, -0.004934},{
      1.855291, 0.135956, -0.004934},{1.855556, 0.135143, -0.005935}}],
    Polygon[{{1.857390, 0.136289, -0.004934},{1.857390, 0.136977, -0.003811},{
      1.855079, 0.136611, -0.003811},{1.855291, 0.135956, -0.004934}}],
    Polygon[{{1.857390, 0.136977, -0.003811},{1.857390, 0.137481, -0.002594},{
      1.854923, 0.137090, -0.002594},{1.855079, 0.136611, -0.003811}}],
    Polygon[{{1.857390, 0.137481, -0.002594},{1.857390, 0.137788, -0.001313},{
      1.854828, 0.137383, -0.001313},{1.854923, 0.137090, -0.002594}}],
    Polygon[{{1.857390, 0.137788, -0.001313},{1.857390, 0.137892, 0.000000},{
      1.854796, 0.137481, 0.000000},{1.854828, 0.137383, -0.001313}}],
    Polygon[{{1.857390, 0.137892, 0.000000},{1.857390, 0.137788, 0.001313},{
      1.854828, 0.137383, 0.001313},{1.854796, 0.137481, 0.000000}}],
    Polygon[{{1.857390, 0.137788, 0.001313},{1.857390, 0.137481, 0.002594},{
      1.854923, 0.137090, 0.002594},{1.854828, 0.137383, 0.001313}}],
    Polygon[{{1.857390, 0.137481, 0.002594},{1.857390, 0.136977, 0.003811},{
      1.855079, 0.136611, 0.003811},{1.854923, 0.137090, 0.002594}}],
    Polygon[{{1.857390, 0.136977, 0.003811},{1.857390, 0.136289, 0.004934},{
      1.855291, 0.135956, 0.004934},{1.855079, 0.136611, 0.003811}}],
    Polygon[{{1.857390, 0.136289, 0.004934},{1.857390, 0.135433, 0.005935},{
      1.855556, 0.135143, 0.005935},{1.855291, 0.135956, 0.004934}}],
    Polygon[{{1.857390, 0.135433, 0.005935},{1.857390, 0.134432, 0.006791},{
      1.855865, 0.134190, 0.006791},{1.855556, 0.135143, 0.005935}}],
    Polygon[{{1.857390, 0.134432, 0.006791},{1.857390, 0.133309, 0.007479},{
      1.856212, 0.133122, 0.007479},{1.855865, 0.134190, 0.006791}}],
    Polygon[{{1.857390, 0.133309, 0.007479},{1.857390, 0.132092, 0.007983},{
      1.856588, 0.131965, 0.007983},{1.856212, 0.133122, 0.007479}}],
    Polygon[{{1.857390, 0.132092, 0.007983},{1.857390, 0.130811, 0.008290},{
      1.856984, 0.130747, 0.008290},{1.856588, 0.131965, 0.007983}}],
    Polygon[{{1.856984, 0.130747, -0.008290},{1.856588, 0.131965, -0.007983},{
      1.855865, 0.131597, -0.007983},{1.856618, 0.130560, -0.008290}}],
    Polygon[{{1.856588, 0.131965, -0.007983},{1.856212, 0.133122, -0.007479},{
      1.855150, 0.132581, -0.007479},{1.855865, 0.131597, -0.007983}}],
    Polygon[{{1.856212, 0.133122, -0.007479},{1.855865, 0.134190, -0.006791},{
      1.854490, 0.133490, -0.006791},{1.855150, 0.132581, -0.007479}}],
    Polygon[{{1.855865, 0.134190, -0.006791},{1.855556, 0.135143, -0.005935},{
      1.853901, 0.134300, -0.005935},{1.854490, 0.133490, -0.006791}}],
    Polygon[{{1.855556, 0.135143, -0.005935},{1.855291, 0.135956, -0.004934},{
      1.853398, 0.134992, -0.004934},{1.853901, 0.134300, -0.005935}}],
    Polygon[{{1.855291, 0.135956, -0.004934},{1.855079, 0.136611, -0.003811},{
      1.852994, 0.135549, -0.003811},{1.853398, 0.134992, -0.004934}}],
    Polygon[{{1.855079, 0.136611, -0.003811},{1.854923, 0.137090, -0.002594},{
      1.852697, 0.135956, -0.002594},{1.852994, 0.135549, -0.003811}}],
    Polygon[{{1.854923, 0.137090, -0.002594},{1.854828, 0.137383, -0.001313},{
      1.852517, 0.136205, -0.001313},{1.852697, 0.135956, -0.002594}}],
    Polygon[{{1.854828, 0.137383, -0.001313},{1.854796, 0.137481, 0.000000},{
      1.852456, 0.136289, 0.000000},{1.852517, 0.136205, -0.001313}}],
    Polygon[{{1.854796, 0.137481, 0.000000},{1.854828, 0.137383, 0.001313},{
      1.852517, 0.136205, 0.001313},{1.852456, 0.136289, 0.000000}}],
    Polygon[{{1.854828, 0.137383, 0.001313},{1.854923, 0.137090, 0.002594},{
      1.852697, 0.135956, 0.002594},{1.852517, 0.136205, 0.001313}}],
    Polygon[{{1.854923, 0.137090, 0.002594},{1.855079, 0.136611, 0.003811},{
      1.852994, 0.135549, 0.003811},{1.852697, 0.135956, 0.002594}}],
    Polygon[{{1.855079, 0.136611, 0.003811},{1.855291, 0.135956, 0.004934},{
      1.853398, 0.134992, 0.004934},{1.852994, 0.135549, 0.003811}}],
    Polygon[{{1.855291, 0.135956, 0.004934},{1.855556, 0.135143, 0.005935},{
      1.853901, 0.134300, 0.005935},{1.853398, 0.134992, 0.004934}}],
    Polygon[{{1.855556, 0.135143, 0.005935},{1.855865, 0.134190, 0.006791},{
      1.854490, 0.133490, 0.006791},{1.853901, 0.134300, 0.005935}}],
    Polygon[{{1.855865, 0.134190, 0.006791},{1.856212, 0.133122, 0.007479},{
      1.855150, 0.132581, 0.007479},{1.854490, 0.133490, 0.006791}}],
    Polygon[{{1.856212, 0.133122, 0.007479},{1.856588, 0.131965, 0.007983},{
      1.855865, 0.131597, 0.007983},{1.855150, 0.132581, 0.007479}}],
    Polygon[{{1.856588, 0.131965, 0.007983},{1.856984, 0.130747, 0.008290},{
      1.856618, 0.130560, 0.008290},{1.855865, 0.131597, 0.007983}}],
    Polygon[{{1.856618, 0.130560, -0.008290},{1.855865, 0.131597, -0.007983},{
      1.855291, 0.131023, -0.007983},{1.856327, 0.130270, -0.008290}}],
    Polygon[{{1.855865, 0.131597, -0.007983},{1.855150, 0.132581, -0.007479},{
      1.854307, 0.131738, -0.007479},{1.855291, 0.131023, -0.007983}}],
    Polygon[{{1.855150, 0.132581, -0.007479},{1.854490, 0.133490, -0.006791},{
      1.853398, 0.132398, -0.006791},{1.854307, 0.131738, -0.007479}}],
    Polygon[{{1.854490, 0.133490, -0.006791},{1.853901, 0.134300, -0.005935},{
      1.852588, 0.132987, -0.005935},{1.853398, 0.132398, -0.006791}}],
    Polygon[{{1.853901, 0.134300, -0.005935},{1.853398, 0.134992, -0.004934},{
      1.851896, 0.133490, -0.004934},{1.852588, 0.132987, -0.005935}}],
    Polygon[{{1.853398, 0.134992, -0.004934},{1.852994, 0.135549, -0.003811},{
      1.851339, 0.133894, -0.003811},{1.851896, 0.133490, -0.004934}}],
    Polygon[{{1.852994, 0.135549, -0.003811},{1.852697, 0.135956, -0.002594},{
      1.850931, 0.134190, -0.002594},{1.851339, 0.133894, -0.003811}}],
    Polygon[{{1.852697, 0.135956, -0.002594},{1.852517, 0.136205, -0.001313},{
      1.850683, 0.134371, -0.001313},{1.850931, 0.134190, -0.002594}}],
    Polygon[{{1.852517, 0.136205, -0.001313},{1.852456, 0.136289, 0.000000},{
      1.850599, 0.134432, 0.000000},{1.850683, 0.134371, -0.001313}}],
    Polygon[{{1.852456, 0.136289, 0.000000},{1.852517, 0.136205, 0.001313},{
      1.850683, 0.134371, 0.001313},{1.850599, 0.134432, 0.000000}}],
    Polygon[{{1.852517, 0.136205, 0.001313},{1.852697, 0.135956, 0.002594},{
      1.850931, 0.134190, 0.002594},{1.850683, 0.134371, 0.001313}}],
    Polygon[{{1.852697, 0.135956, 0.002594},{1.852994, 0.135549, 0.003811},{
      1.851339, 0.133894, 0.003811},{1.850931, 0.134190, 0.002594}}],
    Polygon[{{1.852994, 0.135549, 0.003811},{1.853398, 0.134992, 0.004934},{
      1.851896, 0.133490, 0.004934},{1.851339, 0.133894, 0.003811}}],
    Polygon[{{1.853398, 0.134992, 0.004934},{1.853901, 0.134300, 0.005935},{
      1.852588, 0.132987, 0.005935},{1.851896, 0.133490, 0.004934}}],
    Polygon[{{1.853901, 0.134300, 0.005935},{1.854490, 0.133490, 0.006791},{
      1.853398, 0.132398, 0.006791},{1.852588, 0.132987, 0.005935}}],
    Polygon[{{1.854490, 0.133490, 0.006791},{1.855150, 0.132581, 0.007479},{
      1.854307, 0.131738, 0.007479},{1.853398, 0.132398, 0.006791}}],
    Polygon[{{1.855150, 0.132581, 0.007479},{1.855865, 0.131597, 0.007983},{
      1.855291, 0.131023, 0.007983},{1.854307, 0.131738, 0.007479}}],
    Polygon[{{1.855865, 0.131597, 0.007983},{1.856618, 0.130560, 0.008290},{
      1.856327, 0.130270, 0.008290},{1.855291, 0.131023, 0.007983}}],
    Polygon[{{1.856327, 0.130270, -0.008290},{1.855291, 0.131023, -0.007983},{
      1.854923, 0.130300, -0.007983},{1.856141, 0.129904, -0.008290}}],
    Polygon[{{1.855291, 0.131023, -0.007983},{1.854307, 0.131738, -0.007479},{
      1.853765, 0.130676, -0.007479},{1.854923, 0.130300, -0.007983}}],
    Polygon[{{1.854307, 0.131738, -0.007479},{1.853398, 0.132398, -0.006791},{
      1.852697, 0.131023, -0.006791},{1.853765, 0.130676, -0.007479}}],
    Polygon[{{1.853398, 0.132398, -0.006791},{1.852588, 0.132987, -0.005935},{
      1.851745, 0.131332, -0.005935},{1.852697, 0.131023, -0.006791}}],
    Polygon[{{1.852588, 0.132987, -0.005935},{1.851896, 0.133490, -0.004934},{
      1.850931, 0.131597, -0.004934},{1.851745, 0.131332, -0.005935}}],
    Polygon[{{1.851896, 0.133490, -0.004934},{1.851339, 0.133894, -0.003811},{
      1.850277, 0.131809, -0.003811},{1.850931, 0.131597, -0.004934}}],
    Polygon[{{1.851339, 0.133894, -0.003811},{1.850931, 0.134190, -0.002594},{
      1.849797, 0.131965, -0.002594},{1.850277, 0.131809, -0.003811}}],
    Polygon[{{1.850931, 0.134190, -0.002594},{1.850683, 0.134371, -0.001313},{
      1.849505, 0.132060, -0.001313},{1.849797, 0.131965, -0.002594}}],
    Polygon[{{1.850683, 0.134371, -0.001313},{1.850599, 0.134432, 0.000000},{
      1.849407, 0.132092, 0.000000},{1.849505, 0.132060, -0.001313}}],
    Polygon[{{1.850599, 0.134432, 0.000000},{1.850683, 0.134371, 0.001313},{
      1.849505, 0.132060, 0.001313},{1.849407, 0.132092, 0.000000}}],
    Polygon[{{1.850683, 0.134371, 0.001313},{1.850931, 0.134190, 0.002594},{
      1.849797, 0.131965, 0.002594},{1.849505, 0.132060, 0.001313}}],
    Polygon[{{1.850931, 0.134190, 0.002594},{1.851339, 0.133894, 0.003811},{
      1.850277, 0.131809, 0.003811},{1.849797, 0.131965, 0.002594}}],
    Polygon[{{1.851339, 0.133894, 0.003811},{1.851896, 0.133490, 0.004934},{
      1.850931, 0.131597, 0.004934},{1.850277, 0.131809, 0.003811}}],
    Polygon[{{1.851896, 0.133490, 0.004934},{1.852588, 0.132987, 0.005935},{
      1.851745, 0.131332, 0.005935},{1.850931, 0.131597, 0.004934}}],
    Polygon[{{1.852588, 0.132987, 0.005935},{1.853398, 0.132398, 0.006791},{
      1.852697, 0.131023, 0.006791},{1.851745, 0.131332, 0.005935}}],
    Polygon[{{1.853398, 0.132398, 0.006791},{1.854307, 0.131738, 0.007479},{
      1.853765, 0.130676, 0.007479},{1.852697, 0.131023, 0.006791}}],
    Polygon[{{1.854307, 0.131738, 0.007479},{1.855291, 0.131023, 0.007983},{
      1.854923, 0.130300, 0.007983},{1.853765, 0.130676, 0.007479}}],
    Polygon[{{1.855291, 0.131023, 0.007983},{1.856327, 0.130270, 0.008290},{
      1.856141, 0.129904, 0.008290},{1.854923, 0.130300, 0.007983}}],
    Polygon[{{1.856141, 0.129904, -0.008290},{1.854923, 0.130300, -0.007983},{
      1.854796, 0.129498, -0.007983},{1.856077, 0.129498, -0.008290}}],
    Polygon[{{1.854923, 0.130300, -0.007983},{1.853765, 0.130676, -0.007479},{
      1.853579, 0.129498, -0.007479},{1.854796, 0.129498, -0.007983}}],
    Polygon[{{1.853765, 0.130676, -0.007479},{1.852697, 0.131023, -0.006791},{
      1.852456, 0.129498, -0.006791},{1.853579, 0.129498, -0.007479}}],
    Polygon[{{1.852697, 0.131023, -0.006791},{1.851745, 0.131332, -0.005935},{
      1.851454, 0.129498, -0.005935},{1.852456, 0.129498, -0.006791}}],
    Polygon[{{1.851745, 0.131332, -0.005935},{1.850931, 0.131597, -0.004934},{
      1.850599, 0.129498, -0.004934},{1.851454, 0.129498, -0.005935}}],
    Polygon[{{1.850931, 0.131597, -0.004934},{1.850277, 0.131809, -0.003811},{
      1.849911, 0.129498, -0.003811},{1.850599, 0.129498, -0.004934}}],
    Polygon[{{1.850277, 0.131809, -0.003811},{1.849797, 0.131965, -0.002594},{
      1.849407, 0.129498, -0.002594},{1.849911, 0.129498, -0.003811}}],
    Polygon[{{1.849797, 0.131965, -0.002594},{1.849505, 0.132060, -0.001313},{
      1.849099, 0.129498, -0.001313},{1.849407, 0.129498, -0.002594}}],
    Polygon[{{1.849505, 0.132060, -0.001313},{1.849407, 0.132092, 0.000000},{
      1.848996, 0.129498, 0.000000},{1.849099, 0.129498, -0.001313}}],
    Polygon[{{1.849407, 0.132092, 0.000000},{1.849505, 0.132060, 0.001313},{
      1.849099, 0.129498, 0.001313},{1.848996, 0.129498, 0.000000}}],
    Polygon[{{1.849505, 0.132060, 0.001313},{1.849797, 0.131965, 0.002594},{
      1.849407, 0.129498, 0.002594},{1.849099, 0.129498, 0.001313}}],
    Polygon[{{1.849797, 0.131965, 0.002594},{1.850277, 0.131809, 0.003811},{
      1.849911, 0.129498, 0.003811},{1.849407, 0.129498, 0.002594}}],
    Polygon[{{1.850277, 0.131809, 0.003811},{1.850931, 0.131597, 0.004934},{
      1.850599, 0.129498, 0.004934},{1.849911, 0.129498, 0.003811}}],
    Polygon[{{1.850931, 0.131597, 0.004934},{1.851745, 0.131332, 0.005935},{
      1.851454, 0.129498, 0.005935},{1.850599, 0.129498, 0.004934}}],
    Polygon[{{1.851745, 0.131332, 0.005935},{1.852697, 0.131023, 0.006791},{
      1.852456, 0.129498, 0.006791},{1.851454, 0.129498, 0.005935}}],
    Polygon[{{1.852697, 0.131023, 0.006791},{1.853765, 0.130676, 0.007479},{
      1.853579, 0.129498, 0.007479},{1.852456, 0.129498, 0.006791}}],
    Polygon[{{1.853765, 0.130676, 0.007479},{1.854923, 0.130300, 0.007983},{
      1.854796, 0.129498, 0.007983},{1.853579, 0.129498, 0.007479}}],
    Polygon[{{1.854923, 0.130300, 0.007983},{1.856141, 0.129904, 0.008290},{
      1.856077, 0.129498, 0.008290},{1.854796, 0.129498, 0.007983}}],
    Polygon[{{1.856077, 0.129498, -0.008290},{1.854796, 0.129498, -0.007983},{
      1.854923, 0.128697, -0.007983},{1.856141, 0.129092, -0.008290}}],
    Polygon[{{1.854796, 0.129498, -0.007983},{1.853579, 0.129498, -0.007479},{
      1.853765, 0.128321, -0.007479},{1.854923, 0.128697, -0.007983}}],
    Polygon[{{1.853579, 0.129498, -0.007479},{1.852456, 0.129498, -0.006791},{
      1.852697, 0.127974, -0.006791},{1.853765, 0.128321, -0.007479}}],
    Polygon[{{1.852456, 0.129498, -0.006791},{1.851454, 0.129498, -0.005935},{
      1.851745, 0.127664, -0.005935},{1.852697, 0.127974, -0.006791}}],
    Polygon[{{1.851454, 0.129498, -0.005935},{1.850599, 0.129498, -0.004934},{
      1.850931, 0.127400, -0.004934},{1.851745, 0.127664, -0.005935}}],
    Polygon[{{1.850599, 0.129498, -0.004934},{1.849911, 0.129498, -0.003811},{
      1.850277, 0.127187, -0.003811},{1.850931, 0.127400, -0.004934}}],
    Polygon[{{1.849911, 0.129498, -0.003811},{1.849407, 0.129498, -0.002594},{
      1.849797, 0.127031, -0.002594},{1.850277, 0.127187, -0.003811}}],
    Polygon[{{1.849407, 0.129498, -0.002594},{1.849099, 0.129498, -0.001313},{
      1.849505, 0.126936, -0.001313},{1.849797, 0.127031, -0.002594}}],
    Polygon[{{1.849099, 0.129498, -0.001313},{1.848996, 0.129498, 0.000000},{
      1.849407, 0.126904, 0.000000},{1.849505, 0.126936, -0.001313}}],
    Polygon[{{1.848996, 0.129498, 0.000000},{1.849099, 0.129498, 0.001313},{
      1.849505, 0.126936, 0.001313},{1.849407, 0.126904, 0.000000}}],
    Polygon[{{1.849099, 0.129498, 0.001313},{1.849407, 0.129498, 0.002594},{
      1.849797, 0.127031, 0.002594},{1.849505, 0.126936, 0.001313}}],
    Polygon[{{1.849407, 0.129498, 0.002594},{1.849911, 0.129498, 0.003811},{
      1.850277, 0.127187, 0.003811},{1.849797, 0.127031, 0.002594}}],
    Polygon[{{1.849911, 0.129498, 0.003811},{1.850599, 0.129498, 0.004934},{
      1.850931, 0.127400, 0.004934},{1.850277, 0.127187, 0.003811}}],
    Polygon[{{1.850599, 0.129498, 0.004934},{1.851454, 0.129498, 0.005935},{
      1.851745, 0.127664, 0.005935},{1.850931, 0.127400, 0.004934}}],
    Polygon[{{1.851454, 0.129498, 0.005935},{1.852456, 0.129498, 0.006791},{
      1.852697, 0.127974, 0.006791},{1.851745, 0.127664, 0.005935}}],
    Polygon[{{1.852456, 0.129498, 0.006791},{1.853579, 0.129498, 0.007479},{
      1.853765, 0.128321, 0.007479},{1.852697, 0.127974, 0.006791}}],
    Polygon[{{1.853579, 0.129498, 0.007479},{1.854796, 0.129498, 0.007983},{
      1.854923, 0.128697, 0.007983},{1.853765, 0.128321, 0.007479}}],
    Polygon[{{1.854796, 0.129498, 0.007983},{1.856077, 0.129498, 0.008290},{
      1.856141, 0.129092, 0.008290},{1.854923, 0.128697, 0.007983}}],
    Polygon[{{1.856141, 0.129092, -0.008290},{1.854923, 0.128697, -0.007983},{
      1.855291, 0.127974, -0.007983},{1.856327, 0.128726, -0.008290}}],
    Polygon[{{1.854923, 0.128697, -0.007983},{1.853765, 0.128321, -0.007479},{
      1.854307, 0.127258, -0.007479},{1.855291, 0.127974, -0.007983}}],
    Polygon[{{1.853765, 0.128321, -0.007479},{1.852697, 0.127974, -0.006791},{
      1.853398, 0.126598, -0.006791},{1.854307, 0.127258, -0.007479}}],
    Polygon[{{1.852697, 0.127974, -0.006791},{1.851745, 0.127664, -0.005935},{
      1.852588, 0.126010, -0.005935},{1.853398, 0.126598, -0.006791}}],
    Polygon[{{1.851745, 0.127664, -0.005935},{1.850931, 0.127400, -0.004934},{
      1.851896, 0.125507, -0.004934},{1.852588, 0.126010, -0.005935}}],
    Polygon[{{1.850931, 0.127400, -0.004934},{1.850277, 0.127187, -0.003811},{
      1.851339, 0.125102, -0.003811},{1.851896, 0.125507, -0.004934}}],
    Polygon[{{1.850277, 0.127187, -0.003811},{1.849797, 0.127031, -0.002594},{
      1.850931, 0.124806, -0.002594},{1.851339, 0.125102, -0.003811}}],
    Polygon[{{1.849797, 0.127031, -0.002594},{1.849505, 0.126936, -0.001313},{
      1.850683, 0.124625, -0.001313},{1.850931, 0.124806, -0.002594}}],
    Polygon[{{1.849505, 0.126936, -0.001313},{1.849407, 0.126904, 0.000000},{
      1.850599, 0.124564, 0.000000},{1.850683, 0.124625, -0.001313}}],
    Polygon[{{1.849407, 0.126904, 0.000000},{1.849505, 0.126936, 0.001313},{
      1.850683, 0.124625, 0.001313},{1.850599, 0.124564, 0.000000}}],
    Polygon[{{1.849505, 0.126936, 0.001313},{1.849797, 0.127031, 0.002594},{
      1.850931, 0.124806, 0.002594},{1.850683, 0.124625, 0.001313}}],
    Polygon[{{1.849797, 0.127031, 0.002594},{1.850277, 0.127187, 0.003811},{
      1.851339, 0.125102, 0.003811},{1.850931, 0.124806, 0.002594}}],
    Polygon[{{1.850277, 0.127187, 0.003811},{1.850931, 0.127400, 0.004934},{
      1.851896, 0.125507, 0.004934},{1.851339, 0.125102, 0.003811}}],
    Polygon[{{1.850931, 0.127400, 0.004934},{1.851745, 0.127664, 0.005935},{
      1.852588, 0.126010, 0.005935},{1.851896, 0.125507, 0.004934}}],
    Polygon[{{1.851745, 0.127664, 0.005935},{1.852697, 0.127974, 0.006791},{
      1.853398, 0.126598, 0.006791},{1.852588, 0.126010, 0.005935}}],
    Polygon[{{1.852697, 0.127974, 0.006791},{1.853765, 0.128321, 0.007479},{
      1.854307, 0.127258, 0.007479},{1.853398, 0.126598, 0.006791}}],
    Polygon[{{1.853765, 0.128321, 0.007479},{1.854923, 0.128697, 0.007983},{
      1.855291, 0.127974, 0.007983},{1.854307, 0.127258, 0.007479}}],
    Polygon[{{1.854923, 0.128697, 0.007983},{1.856141, 0.129092, 0.008290},{
      1.856327, 0.128726, 0.008290},{1.855291, 0.127974, 0.007983}}],
    Polygon[{{1.856327, 0.128726, -0.008290},{1.855291, 0.127974, -0.007983},{
      1.855865, 0.127400, -0.007983},{1.856618, 0.128436, -0.008290}}],
    Polygon[{{1.855291, 0.127974, -0.007983},{1.854307, 0.127258, -0.007479},{
      1.855150, 0.126415, -0.007479},{1.855865, 0.127400, -0.007983}}],
    Polygon[{{1.854307, 0.127258, -0.007479},{1.853398, 0.126598, -0.006791},{
      1.854490, 0.125507, -0.006791},{1.855150, 0.126415, -0.007479}}],
    Polygon[{{1.853398, 0.126598, -0.006791},{1.852588, 0.126010, -0.005935},{
      1.853901, 0.124696, -0.005935},{1.854490, 0.125507, -0.006791}}],
    Polygon[{{1.852588, 0.126010, -0.005935},{1.851896, 0.125507, -0.004934},{
      1.853398, 0.124004, -0.004934},{1.853901, 0.124696, -0.005935}}],
    Polygon[{{1.851896, 0.125507, -0.004934},{1.851339, 0.125102, -0.003811},{
      1.852994, 0.123448, -0.003811},{1.853398, 0.124004, -0.004934}}],
    Polygon[{{1.851339, 0.125102, -0.003811},{1.850931, 0.124806, -0.002594},{
      1.852697, 0.123040, -0.002594},{1.852994, 0.123448, -0.003811}}],
    Polygon[{{1.850931, 0.124806, -0.002594},{1.850683, 0.124625, -0.001313},{
      1.852517, 0.122791, -0.001313},{1.852697, 0.123040, -0.002594}}],
    Polygon[{{1.850683, 0.124625, -0.001313},{1.850599, 0.124564, 0.000000},{
      1.852456, 0.122708, 0.000000},{1.852517, 0.122791, -0.001313}}],
    Polygon[{{1.850599, 0.124564, 0.000000},{1.850683, 0.124625, 0.001313},{
      1.852517, 0.122791, 0.001313},{1.852456, 0.122708, 0.000000}}],
    Polygon[{{1.850683, 0.124625, 0.001313},{1.850931, 0.124806, 0.002594},{
      1.852697, 0.123040, 0.002594},{1.852517, 0.122791, 0.001313}}],
    Polygon[{{1.850931, 0.124806, 0.002594},{1.851339, 0.125102, 0.003811},{
      1.852994, 0.123448, 0.003811},{1.852697, 0.123040, 0.002594}}],
    Polygon[{{1.851339, 0.125102, 0.003811},{1.851896, 0.125507, 0.004934},{
      1.853398, 0.124004, 0.004934},{1.852994, 0.123448, 0.003811}}],
    Polygon[{{1.851896, 0.125507, 0.004934},{1.852588, 0.126010, 0.005935},{
      1.853901, 0.124696, 0.005935},{1.853398, 0.124004, 0.004934}}],
    Polygon[{{1.852588, 0.126010, 0.005935},{1.853398, 0.126598, 0.006791},{
      1.854490, 0.125507, 0.006791},{1.853901, 0.124696, 0.005935}}],
    Polygon[{{1.853398, 0.126598, 0.006791},{1.854307, 0.127258, 0.007479},{
      1.855150, 0.126415, 0.007479},{1.854490, 0.125507, 0.006791}}],
    Polygon[{{1.854307, 0.127258, 0.007479},{1.855291, 0.127974, 0.007983},{
      1.855865, 0.127400, 0.007983},{1.855150, 0.126415, 0.007479}}],
    Polygon[{{1.855291, 0.127974, 0.007983},{1.856327, 0.128726, 0.008290},{
      1.856618, 0.128436, 0.008290},{1.855865, 0.127400, 0.007983}}],
    Polygon[{{1.856618, 0.128436, -0.008290},{1.855865, 0.127400, -0.007983},{
      1.856588, 0.127031, -0.007983},{1.856984, 0.128249, -0.008290}}],
    Polygon[{{1.855865, 0.127400, -0.007983},{1.855150, 0.126415, -0.007479},{
      1.856212, 0.125874, -0.007479},{1.856588, 0.127031, -0.007983}}],
    Polygon[{{1.855150, 0.126415, -0.007479},{1.854490, 0.125507, -0.006791},{
      1.855865, 0.124806, -0.006791},{1.856212, 0.125874, -0.007479}}],
    Polygon[{{1.854490, 0.125507, -0.006791},{1.853901, 0.124696, -0.005935},{
      1.855556, 0.123853, -0.005935},{1.855865, 0.124806, -0.006791}}],
    Polygon[{{1.853901, 0.124696, -0.005935},{1.853398, 0.124004, -0.004934},{
      1.855291, 0.123040, -0.004934},{1.855556, 0.123853, -0.005935}}],
    Polygon[{{1.853398, 0.124004, -0.004934},{1.852994, 0.123448, -0.003811},{
      1.855079, 0.122385, -0.003811},{1.855291, 0.123040, -0.004934}}],
    Polygon[{{1.852994, 0.123448, -0.003811},{1.852697, 0.123040, -0.002594},{
      1.854923, 0.121906, -0.002594},{1.855079, 0.122385, -0.003811}}],
    Polygon[{{1.852697, 0.123040, -0.002594},{1.852517, 0.122791, -0.001313},{
      1.854828, 0.121614, -0.001313},{1.854923, 0.121906, -0.002594}}],
    Polygon[{{1.852517, 0.122791, -0.001313},{1.852456, 0.122708, 0.000000},{
      1.854796, 0.121515, 0.000000},{1.854828, 0.121614, -0.001313}}],
    Polygon[{{1.852456, 0.122708, 0.000000},{1.852517, 0.122791, 0.001313},{
      1.854828, 0.121614, 0.001313},{1.854796, 0.121515, 0.000000}}],
    Polygon[{{1.852517, 0.122791, 0.001313},{1.852697, 0.123040, 0.002594},{
      1.854923, 0.121906, 0.002594},{1.854828, 0.121614, 0.001313}}],
    Polygon[{{1.852697, 0.123040, 0.002594},{1.852994, 0.123448, 0.003811},{
      1.855079, 0.122385, 0.003811},{1.854923, 0.121906, 0.002594}}],
    Polygon[{{1.852994, 0.123448, 0.003811},{1.853398, 0.124004, 0.004934},{
      1.855291, 0.123040, 0.004934},{1.855079, 0.122385, 0.003811}}],
    Polygon[{{1.853398, 0.124004, 0.004934},{1.853901, 0.124696, 0.005935},{
      1.855556, 0.123853, 0.005935},{1.855291, 0.123040, 0.004934}}],
    Polygon[{{1.853901, 0.124696, 0.005935},{1.854490, 0.125507, 0.006791},{
      1.855865, 0.124806, 0.006791},{1.855556, 0.123853, 0.005935}}],
    Polygon[{{1.854490, 0.125507, 0.006791},{1.855150, 0.126415, 0.007479},{
      1.856212, 0.125874, 0.007479},{1.855865, 0.124806, 0.006791}}],
    Polygon[{{1.855150, 0.126415, 0.007479},{1.855865, 0.127400, 0.007983},{
      1.856588, 0.127031, 0.007983},{1.856212, 0.125874, 0.007479}}],
    Polygon[{{1.855865, 0.127400, 0.007983},{1.856618, 0.128436, 0.008290},{
      1.856984, 0.128249, 0.008290},{1.856588, 0.127031, 0.007983}}],
    Polygon[{{1.856984, 0.128249, -0.008290},{1.856588, 0.127031, -0.007983},{
      1.857390, 0.126904, -0.007983},{1.857390, 0.128185, -0.008290}}],
    Polygon[{{1.856588, 0.127031, -0.007983},{1.856212, 0.125874, -0.007479},{
      1.857390, 0.125687, -0.007479},{1.857390, 0.126904, -0.007983}}],
    Polygon[{{1.856212, 0.125874, -0.007479},{1.855865, 0.124806, -0.006791},{
      1.857390, 0.124564, -0.006791},{1.857390, 0.125687, -0.007479}}],
    Polygon[{{1.855865, 0.124806, -0.006791},{1.855556, 0.123853, -0.005935},{
      1.857390, 0.123563, -0.005935},{1.857390, 0.124564, -0.006791}}],
    Polygon[{{1.855556, 0.123853, -0.005935},{1.855291, 0.123040, -0.004934},{
      1.857390, 0.122708, -0.004934},{1.857390, 0.123563, -0.005935}}],
    Polygon[{{1.855291, 0.123040, -0.004934},{1.855079, 0.122385, -0.003811},{
      1.857390, 0.122019, -0.003811},{1.857390, 0.122708, -0.004934}}],
    Polygon[{{1.855079, 0.122385, -0.003811},{1.854923, 0.121906, -0.002594},{
      1.857390, 0.121515, -0.002594},{1.857390, 0.122019, -0.003811}}],
    Polygon[{{1.854923, 0.121906, -0.002594},{1.854828, 0.121614, -0.001313},{
      1.857390, 0.121208, -0.001313},{1.857390, 0.121515, -0.002594}}],
    Polygon[{{1.854828, 0.121614, -0.001313},{1.854796, 0.121515, 0.000000},{
      1.857390, 0.121105, 0.000000},{1.857390, 0.121208, -0.001313}}],
    Polygon[{{1.854796, 0.121515, 0.000000},{1.854828, 0.121614, 0.001313},{
      1.857390, 0.121208, 0.001313},{1.857390, 0.121105, 0.000000}}],
    Polygon[{{1.854828, 0.121614, 0.001313},{1.854923, 0.121906, 0.002594},{
      1.857390, 0.121515, 0.002594},{1.857390, 0.121208, 0.001313}}],
    Polygon[{{1.854923, 0.121906, 0.002594},{1.855079, 0.122385, 0.003811},{
      1.857390, 0.122019, 0.003811},{1.857390, 0.121515, 0.002594}}],
    Polygon[{{1.855079, 0.122385, 0.003811},{1.855291, 0.123040, 0.004934},{
      1.857390, 0.122708, 0.004934},{1.857390, 0.122019, 0.003811}}],
    Polygon[{{1.855291, 0.123040, 0.004934},{1.855556, 0.123853, 0.005935},{
      1.857390, 0.123563, 0.005935},{1.857390, 0.122708, 0.004934}}],
    Polygon[{{1.855556, 0.123853, 0.005935},{1.855865, 0.124806, 0.006791},{
      1.857390, 0.124564, 0.006791},{1.857390, 0.123563, 0.005935}}],
    Polygon[{{1.855865, 0.124806, 0.006791},{1.856212, 0.125874, 0.007479},{
      1.857390, 0.125687, 0.007479},{1.857390, 0.124564, 0.006791}}],
    Polygon[{{1.856212, 0.125874, 0.007479},{1.856588, 0.127031, 0.007983},{
      1.857390, 0.126904, 0.007983},{1.857390, 0.125687, 0.007479}}],
    Polygon[{{1.856588, 0.127031, 0.007983},{1.856984, 0.128249, 0.008290},{
      1.857390, 0.128185, 0.008290},{1.857390, 0.126904, 0.007983}}],
    Polygon[{{1.857390, 0.128185, -0.008290},{1.857390, 0.126904, -0.007983},{
      1.858191, 0.127031, -0.007983},{1.857795, 0.128249, -0.008290}}],
    Polygon[{{1.857390, 0.126904, -0.007983},{1.857390, 0.125687, -0.007479},{
      1.858567, 0.125874, -0.007479},{1.858191, 0.127031, -0.007983}}],
    Polygon[{{1.857390, 0.125687, -0.007479},{1.857390, 0.124564, -0.006791},{
      1.858914, 0.124806, -0.006791},{1.858567, 0.125874, -0.007479}}],
    Polygon[{{1.857390, 0.124564, -0.006791},{1.857390, 0.123563, -0.005935},{
      1.859224, 0.123853, -0.005935},{1.858914, 0.124806, -0.006791}}],
    Polygon[{{1.857390, 0.123563, -0.005935},{1.857390, 0.122708, -0.004934},{
      1.859488, 0.123040, -0.004934},{1.859224, 0.123853, -0.005935}}],
    Polygon[{{1.857390, 0.122708, -0.004934},{1.857390, 0.122019, -0.003811},{
      1.859701, 0.122385, -0.003811},{1.859488, 0.123040, -0.004934}}],
    Polygon[{{1.857390, 0.122019, -0.003811},{1.857390, 0.121515, -0.002594},{
      1.859856, 0.121906, -0.002594},{1.859701, 0.122385, -0.003811}}],
    Polygon[{{1.857390, 0.121515, -0.002594},{1.857390, 0.121208, -0.001313},{
      1.859951, 0.121614, -0.001313},{1.859856, 0.121906, -0.002594}}],
    Polygon[{{1.857390, 0.121208, -0.001313},{1.857390, 0.121105, 0.000000},{
      1.859983, 0.121515, 0.000000},{1.859951, 0.121614, -0.001313}}],
    Polygon[{{1.857390, 0.121105, 0.000000},{1.857390, 0.121208, 0.001313},{
      1.859951, 0.121614, 0.001313},{1.859983, 0.121515, 0.000000}}],
    Polygon[{{1.857390, 0.121208, 0.001313},{1.857390, 0.121515, 0.002594},{
      1.859856, 0.121906, 0.002594},{1.859951, 0.121614, 0.001313}}],
    Polygon[{{1.857390, 0.121515, 0.002594},{1.857390, 0.122019, 0.003811},{
      1.859701, 0.122385, 0.003811},{1.859856, 0.121906, 0.002594}}],
    Polygon[{{1.857390, 0.122019, 0.003811},{1.857390, 0.122708, 0.004934},{
      1.859488, 0.123040, 0.004934},{1.859701, 0.122385, 0.003811}}],
    Polygon[{{1.857390, 0.122708, 0.004934},{1.857390, 0.123563, 0.005935},{
      1.859224, 0.123853, 0.005935},{1.859488, 0.123040, 0.004934}}],
    Polygon[{{1.857390, 0.123563, 0.005935},{1.857390, 0.124564, 0.006791},{
      1.858914, 0.124806, 0.006791},{1.859224, 0.123853, 0.005935}}],
    Polygon[{{1.857390, 0.124564, 0.006791},{1.857390, 0.125687, 0.007479},{
      1.858567, 0.125874, 0.007479},{1.858914, 0.124806, 0.006791}}],
    Polygon[{{1.857390, 0.125687, 0.007479},{1.857390, 0.126904, 0.007983},{
      1.858191, 0.127031, 0.007983},{1.858567, 0.125874, 0.007479}}],
    Polygon[{{1.857390, 0.126904, 0.007983},{1.857390, 0.128185, 0.008290},{
      1.857795, 0.128249, 0.008290},{1.858191, 0.127031, 0.007983}}],
    Polygon[{{1.857795, 0.128249, -0.008290},{1.858191, 0.127031, -0.007983},{
      1.858914, 0.127400, -0.007983},{1.858161, 0.128436, -0.008290}}],
    Polygon[{{1.858191, 0.127031, -0.007983},{1.858567, 0.125874, -0.007479},{
      1.859629, 0.126415, -0.007479},{1.858914, 0.127400, -0.007983}}],
    Polygon[{{1.858567, 0.125874, -0.007479},{1.858914, 0.124806, -0.006791},{
      1.860289, 0.125507, -0.006791},{1.859629, 0.126415, -0.007479}}],
    Polygon[{{1.858914, 0.124806, -0.006791},{1.859224, 0.123853, -0.005935},{
      1.860878, 0.124696, -0.005935},{1.860289, 0.125507, -0.006791}}],
    Polygon[{{1.859224, 0.123853, -0.005935},{1.859488, 0.123040, -0.004934},{
      1.861381, 0.124004, -0.004934},{1.860878, 0.124696, -0.005935}}],
    Polygon[{{1.859488, 0.123040, -0.004934},{1.859701, 0.122385, -0.003811},{
      1.861786, 0.123448, -0.003811},{1.861381, 0.124004, -0.004934}}],
    Polygon[{{1.859701, 0.122385, -0.003811},{1.859856, 0.121906, -0.002594},{
      1.862082, 0.123040, -0.002594},{1.861786, 0.123448, -0.003811}}],
    Polygon[{{1.859856, 0.121906, -0.002594},{1.859951, 0.121614, -0.001313},{
      1.862262, 0.122791, -0.001313},{1.862082, 0.123040, -0.002594}}],
    Polygon[{{1.859951, 0.121614, -0.001313},{1.859983, 0.121515, 0.000000},{
      1.862323, 0.122708, 0.000000},{1.862262, 0.122791, -0.001313}}],
    Polygon[{{1.859983, 0.121515, 0.000000},{1.859951, 0.121614, 0.001313},{
      1.862262, 0.122791, 0.001313},{1.862323, 0.122708, 0.000000}}],
    Polygon[{{1.859951, 0.121614, 0.001313},{1.859856, 0.121906, 0.002594},{
      1.862082, 0.123040, 0.002594},{1.862262, 0.122791, 0.001313}}],
    Polygon[{{1.859856, 0.121906, 0.002594},{1.859701, 0.122385, 0.003811},{
      1.861786, 0.123448, 0.003811},{1.862082, 0.123040, 0.002594}}],
    Polygon[{{1.859701, 0.122385, 0.003811},{1.859488, 0.123040, 0.004934},{
      1.861381, 0.124004, 0.004934},{1.861786, 0.123448, 0.003811}}],
    Polygon[{{1.859488, 0.123040, 0.004934},{1.859224, 0.123853, 0.005935},{
      1.860878, 0.124696, 0.005935},{1.861381, 0.124004, 0.004934}}],
    Polygon[{{1.859224, 0.123853, 0.005935},{1.858914, 0.124806, 0.006791},{
      1.860289, 0.125507, 0.006791},{1.860878, 0.124696, 0.005935}}],
    Polygon[{{1.858914, 0.124806, 0.006791},{1.858567, 0.125874, 0.007479},{
      1.859629, 0.126415, 0.007479},{1.860289, 0.125507, 0.006791}}],
    Polygon[{{1.858567, 0.125874, 0.007479},{1.858191, 0.127031, 0.007983},{
      1.858914, 0.127400, 0.007983},{1.859629, 0.126415, 0.007479}}],
    Polygon[{{1.858191, 0.127031, 0.007983},{1.857795, 0.128249, 0.008290},{
      1.858161, 0.128436, 0.008290},{1.858914, 0.127400, 0.007983}}],
    Polygon[{{1.858161, 0.128436, -0.008290},{1.858914, 0.127400, -0.007983},{
      1.859488, 0.127974, -0.007983},{1.858452, 0.128726, -0.008290}}],
    Polygon[{{1.858914, 0.127400, -0.007983},{1.859629, 0.126415, -0.007479},{
      1.860472, 0.127258, -0.007479},{1.859488, 0.127974, -0.007983}}],
    Polygon[{{1.859629, 0.126415, -0.007479},{1.860289, 0.125507, -0.006791},{
      1.861381, 0.126598, -0.006791},{1.860472, 0.127258, -0.007479}}],
    Polygon[{{1.860289, 0.125507, -0.006791},{1.860878, 0.124696, -0.005935},{
      1.862191, 0.126010, -0.005935},{1.861381, 0.126598, -0.006791}}],
    Polygon[{{1.860878, 0.124696, -0.005935},{1.861381, 0.124004, -0.004934},{
      1.862883, 0.125507, -0.004934},{1.862191, 0.126010, -0.005935}}],
    Polygon[{{1.861381, 0.124004, -0.004934},{1.861786, 0.123448, -0.003811},{
      1.863440, 0.125102, -0.003811},{1.862883, 0.125507, -0.004934}}],
    Polygon[{{1.861786, 0.123448, -0.003811},{1.862082, 0.123040, -0.002594},{
      1.863848, 0.124806, -0.002594},{1.863440, 0.125102, -0.003811}}],
    Polygon[{{1.862082, 0.123040, -0.002594},{1.862262, 0.122791, -0.001313},{
      1.864097, 0.124625, -0.001313},{1.863848, 0.124806, -0.002594}}],
    Polygon[{{1.862262, 0.122791, -0.001313},{1.862323, 0.122708, 0.000000},{
      1.864180, 0.124564, 0.000000},{1.864097, 0.124625, -0.001313}}],
    Polygon[{{1.862323, 0.122708, 0.000000},{1.862262, 0.122791, 0.001313},{
      1.864097, 0.124625, 0.001313},{1.864180, 0.124564, 0.000000}}],
    Polygon[{{1.862262, 0.122791, 0.001313},{1.862082, 0.123040, 0.002594},{
      1.863848, 0.124806, 0.002594},{1.864097, 0.124625, 0.001313}}],
    Polygon[{{1.862082, 0.123040, 0.002594},{1.861786, 0.123448, 0.003811},{
      1.863440, 0.125102, 0.003811},{1.863848, 0.124806, 0.002594}}],
    Polygon[{{1.861786, 0.123448, 0.003811},{1.861381, 0.124004, 0.004934},{
      1.862883, 0.125507, 0.004934},{1.863440, 0.125102, 0.003811}}],
    Polygon[{{1.861381, 0.124004, 0.004934},{1.860878, 0.124696, 0.005935},{
      1.862191, 0.126010, 0.005935},{1.862883, 0.125507, 0.004934}}],
    Polygon[{{1.860878, 0.124696, 0.005935},{1.860289, 0.125507, 0.006791},{
      1.861381, 0.126598, 0.006791},{1.862191, 0.126010, 0.005935}}],
    Polygon[{{1.860289, 0.125507, 0.006791},{1.859629, 0.126415, 0.007479},{
      1.860472, 0.127258, 0.007479},{1.861381, 0.126598, 0.006791}}],
    Polygon[{{1.859629, 0.126415, 0.007479},{1.858914, 0.127400, 0.007983},{
      1.859488, 0.127974, 0.007983},{1.860472, 0.127258, 0.007479}}],
    Polygon[{{1.858914, 0.127400, 0.007983},{1.858161, 0.128436, 0.008290},{
      1.858452, 0.128726, 0.008290},{1.859488, 0.127974, 0.007983}}],
    Polygon[{{1.858452, 0.128726, -0.008290},{1.859488, 0.127974, -0.007983},{
      1.859856, 0.128697, -0.007983},{1.858638, 0.129092, -0.008290}}],
    Polygon[{{1.859488, 0.127974, -0.007983},{1.860472, 0.127258, -0.007479},{
      1.861014, 0.128321, -0.007479},{1.859856, 0.128697, -0.007983}}],
    Polygon[{{1.860472, 0.127258, -0.007479},{1.861381, 0.126598, -0.006791},{
      1.862082, 0.127974, -0.006791},{1.861014, 0.128321, -0.007479}}],
    Polygon[{{1.861381, 0.126598, -0.006791},{1.862191, 0.126010, -0.005935},{
      1.863034, 0.127664, -0.005935},{1.862082, 0.127974, -0.006791}}],
    Polygon[{{1.862191, 0.126010, -0.005935},{1.862883, 0.125507, -0.004934},{
      1.863848, 0.127400, -0.004934},{1.863034, 0.127664, -0.005935}}],
    Polygon[{{1.862883, 0.125507, -0.004934},{1.863440, 0.125102, -0.003811},{
      1.864502, 0.127187, -0.003811},{1.863848, 0.127400, -0.004934}}],
    Polygon[{{1.863440, 0.125102, -0.003811},{1.863848, 0.124806, -0.002594},{
      1.864982, 0.127031, -0.002594},{1.864502, 0.127187, -0.003811}}],
    Polygon[{{1.863848, 0.124806, -0.002594},{1.864097, 0.124625, -0.001313},{
      1.865274, 0.126936, -0.001313},{1.864982, 0.127031, -0.002594}}],
    Polygon[{{1.864097, 0.124625, -0.001313},{1.864180, 0.124564, 0.000000},{
      1.865372, 0.126904, 0.000000},{1.865274, 0.126936, -0.001313}}],
    Polygon[{{1.864180, 0.124564, 0.000000},{1.864097, 0.124625, 0.001313},{
      1.865274, 0.126936, 0.001313},{1.865372, 0.126904, 0.000000}}],
    Polygon[{{1.864097, 0.124625, 0.001313},{1.863848, 0.124806, 0.002594},{
      1.864982, 0.127031, 0.002594},{1.865274, 0.126936, 0.001313}}],
    Polygon[{{1.863848, 0.124806, 0.002594},{1.863440, 0.125102, 0.003811},{
      1.864502, 0.127187, 0.003811},{1.864982, 0.127031, 0.002594}}],
    Polygon[{{1.863440, 0.125102, 0.003811},{1.862883, 0.125507, 0.004934},{
      1.863848, 0.127400, 0.004934},{1.864502, 0.127187, 0.003811}}],
    Polygon[{{1.862883, 0.125507, 0.004934},{1.862191, 0.126010, 0.005935},{
      1.863034, 0.127664, 0.005935},{1.863848, 0.127400, 0.004934}}],
    Polygon[{{1.862191, 0.126010, 0.005935},{1.861381, 0.126598, 0.006791},{
      1.862082, 0.127974, 0.006791},{1.863034, 0.127664, 0.005935}}],
    Polygon[{{1.861381, 0.126598, 0.006791},{1.860472, 0.127258, 0.007479},{
      1.861014, 0.128321, 0.007479},{1.862082, 0.127974, 0.006791}}],
    Polygon[{{1.860472, 0.127258, 0.007479},{1.859488, 0.127974, 0.007983},{
      1.859856, 0.128697, 0.007983},{1.861014, 0.128321, 0.007479}}],
    Polygon[{{1.859488, 0.127974, 0.007983},{1.858452, 0.128726, 0.008290},{
      1.858638, 0.129092, 0.008290},{1.859856, 0.128697, 0.007983}}],
    Polygon[{{1.858638, 0.129092, -0.008290},{1.859856, 0.128697, -0.007983},{
      1.859983, 0.129498, -0.007983},{1.858703, 0.129498, -0.008290}}],
    Polygon[{{1.859856, 0.128697, -0.007983},{1.861014, 0.128321, -0.007479},{
      1.861200, 0.129498, -0.007479},{1.859983, 0.129498, -0.007983}}],
    Polygon[{{1.861014, 0.128321, -0.007479},{1.862082, 0.127974, -0.006791},{
      1.862323, 0.129498, -0.006791},{1.861200, 0.129498, -0.007479}}],
    Polygon[{{1.862082, 0.127974, -0.006791},{1.863034, 0.127664, -0.005935},{
      1.863325, 0.129498, -0.005935},{1.862323, 0.129498, -0.006791}}],
    Polygon[{{1.863034, 0.127664, -0.005935},{1.863848, 0.127400, -0.004934},{
      1.864180, 0.129498, -0.004934},{1.863325, 0.129498, -0.005935}}],
    Polygon[{{1.863848, 0.127400, -0.004934},{1.864502, 0.127187, -0.003811},{
      1.864868, 0.129498, -0.003811},{1.864180, 0.129498, -0.004934}}],
    Polygon[{{1.864502, 0.127187, -0.003811},{1.864982, 0.127031, -0.002594},{
      1.865372, 0.129498, -0.002594},{1.864868, 0.129498, -0.003811}}],
    Polygon[{{1.864982, 0.127031, -0.002594},{1.865274, 0.126936, -0.001313},{
      1.865680, 0.129498, -0.001313},{1.865372, 0.129498, -0.002594}}],
    Polygon[{{1.865274, 0.126936, -0.001313},{1.865372, 0.126904, 0.000000},{
      1.865783, 0.129498, 0.000000},{1.865680, 0.129498, -0.001313}}],
    Polygon[{{1.865372, 0.126904, 0.000000},{1.865274, 0.126936, 0.001313},{
      1.865680, 0.129498, 0.001313},{1.865783, 0.129498, 0.000000}}],
    Polygon[{{1.865274, 0.126936, 0.001313},{1.864982, 0.127031, 0.002594},{
      1.865372, 0.129498, 0.002594},{1.865680, 0.129498, 0.001313}}],
    Polygon[{{1.864982, 0.127031, 0.002594},{1.864502, 0.127187, 0.003811},{
      1.864868, 0.129498, 0.003811},{1.865372, 0.129498, 0.002594}}],
    Polygon[{{1.864502, 0.127187, 0.003811},{1.863848, 0.127400, 0.004934},{
      1.864180, 0.129498, 0.004934},{1.864868, 0.129498, 0.003811}}],
    Polygon[{{1.863848, 0.127400, 0.004934},{1.863034, 0.127664, 0.005935},{
      1.863325, 0.129498, 0.005935},{1.864180, 0.129498, 0.004934}}],
    Polygon[{{1.863034, 0.127664, 0.005935},{1.862082, 0.127974, 0.006791},{
      1.862323, 0.129498, 0.006791},{1.863325, 0.129498, 0.005935}}],
    Polygon[{{1.862082, 0.127974, 0.006791},{1.861014, 0.128321, 0.007479},{
      1.861200, 0.129498, 0.007479},{1.862323, 0.129498, 0.006791}}],
    Polygon[{{1.861014, 0.128321, 0.007479},{1.859856, 0.128697, 0.007983},{
      1.859983, 0.129498, 0.007983},{1.861200, 0.129498, 0.007479}}],
    Polygon[{{1.859856, 0.128697, 0.007983},{1.858638, 0.129092, 0.008290},{
      1.858703, 0.129498, 0.008290},{1.859983, 0.129498, 0.007983}}],
    Polygon[{{1.434750, 0.077350, -0.076398},{1.446552, 0.077350, -0.073564},{
      1.445382, 0.084737, -0.073564},{1.434158, 0.081089, -0.076398}}],
    Polygon[{{1.446552, 0.077350, -0.073564},{1.457766, 0.077350, -0.068920},{
      1.456047, 0.088202, -0.068920},{1.445382, 0.084737, -0.073564}}],
    Polygon[{{1.457766, 0.077350, -0.068920},{1.468115, 0.077350, -0.062578},{
      1.465890, 0.091400, -0.062578},{1.456047, 0.088202, -0.068920}}],
    Polygon[{{1.468115, 0.077350, -0.062578},{1.477345, 0.077350, -0.054695},{
      1.474668, 0.094252, -0.054695},{1.465890, 0.091400, -0.062578}}],
    Polygon[{{1.477345, 0.077350, -0.054695},{1.485227, 0.077350, -0.045465},{
      1.482165, 0.096688, -0.045465},{1.474668, 0.094252, -0.054695}}],
    Polygon[{{1.485227, 0.077350, -0.045465},{1.491569, 0.077350, -0.035116},{
      1.488196, 0.098648, -0.035116},{1.482165, 0.096688, -0.045465}}],
    Polygon[{{1.491569, 0.077350, -0.035116},{1.496214, 0.077350, -0.023903},{
      1.492614, 0.100083, -0.023903},{1.488196, 0.098648, -0.035116}}],
    Polygon[{{1.496214, 0.077350, -0.023903},{1.499048, 0.077350, -0.012100},{
      1.495309, 0.100959, -0.012100},{1.492614, 0.100083, -0.023903}}],
    Polygon[{{1.499048, 0.077350, -0.012100},{1.500000, 0.077350, 0.000000},{
      1.496214, 0.101253, 0.000000},{1.495309, 0.100959, -0.012100}}],
    Polygon[{{1.500000, 0.077350, 0.000000},{1.499048, 0.077350, 0.012100},{
      1.495309, 0.100959, 0.012100},{1.496214, 0.101253, 0.000000}}],
    Polygon[{{1.499048, 0.077350, 0.012100},{1.496214, 0.077350, 0.023903},{
      1.492614, 0.100083, 0.023903},{1.495309, 0.100959, 0.012100}}],
    Polygon[{{1.496214, 0.077350, 0.023903},{1.491569, 0.077350, 0.035116},{
      1.488196, 0.098648, 0.035116},{1.492614, 0.100083, 0.023903}}],
    Polygon[{{1.491569, 0.077350, 0.035116},{1.485227, 0.077350, 0.045465},{
      1.482165, 0.096688, 0.045465},{1.488196, 0.098648, 0.035116}}],
    Polygon[{{1.485227, 0.077350, 0.045465},{1.477345, 0.077350, 0.054695},{
      1.474668, 0.094252, 0.054695},{1.482165, 0.096688, 0.045465}}],
    Polygon[{{1.477345, 0.077350, 0.054695},{1.468115, 0.077350, 0.062578},{
      1.465890, 0.091400, 0.062578},{1.474668, 0.094252, 0.054695}}],
    Polygon[{{1.468115, 0.077350, 0.062578},{1.457766, 0.077350, 0.068920},{
      1.456047, 0.088202, 0.068920},{1.465890, 0.091400, 0.062578}}],
    Polygon[{{1.457766, 0.077350, 0.068920},{1.446552, 0.077350, 0.073564},{
      1.445382, 0.084737, 0.073564},{1.456047, 0.088202, 0.068920}}],
    Polygon[{{1.446552, 0.077350, 0.073564},{1.434750, 0.077350, 0.076398},{
      1.434158, 0.081089, 0.076398},{1.445382, 0.084737, 0.073564}}],
    Polygon[{{1.434158, 0.081089, -0.076398},{1.445382, 0.084737, -0.073564},{
      1.441987, 0.091400, -0.073564},{1.432439, 0.084463, -0.076398}}],
    Polygon[{{1.445382, 0.084737, -0.073564},{1.456047, 0.088202, -0.068920},{
      1.451059, 0.097991, -0.068920},{1.441987, 0.091400, -0.073564}}],
    Polygon[{{1.456047, 0.088202, -0.068920},{1.465890, 0.091400, -0.062578},{
      1.459432, 0.104074, -0.062578},{1.451059, 0.097991, -0.068920}}],
    Polygon[{{1.465890, 0.091400, -0.062578},{1.474668, 0.094252, -0.054695},{
      1.466899, 0.109499, -0.054695},{1.459432, 0.104074, -0.062578}}],
    Polygon[{{1.474668, 0.094252, -0.054695},{1.482165, 0.096688, -0.045465},{
      1.473276, 0.114133, -0.045465},{1.466899, 0.109499, -0.054695}}],
    Polygon[{{1.482165, 0.096688, -0.045465},{1.488196, 0.098648, -0.035116},{
      1.478407, 0.117860, -0.035116},{1.473276, 0.114133, -0.045465}}],
    Polygon[{{1.488196, 0.098648, -0.035116},{1.492614, 0.100083, -0.023903},{
      1.482165, 0.120590, -0.023903},{1.478407, 0.117860, -0.035116}}],
    Polygon[{{1.492614, 0.100083, -0.023903},{1.495309, 0.100959, -0.012100},{
      1.484457, 0.122256, -0.012100},{1.482165, 0.120590, -0.023903}}],
    Polygon[{{1.495309, 0.100959, -0.012100},{1.496214, 0.101253, 0.000000},{
      1.485227, 0.122816, 0.000000},{1.484457, 0.122256, -0.012100}}],
    Polygon[{{1.496214, 0.101253, 0.000000},{1.495309, 0.100959, 0.012100},{
      1.484457, 0.122256, 0.012100},{1.485227, 0.122816, 0.000000}}],
    Polygon[{{1.495309, 0.100959, 0.012100},{1.492614, 0.100083, 0.023903},{
      1.482165, 0.120590, 0.023903},{1.484457, 0.122256, 0.012100}}],
    Polygon[{{1.492614, 0.100083, 0.023903},{1.488196, 0.098648, 0.035116},{
      1.478407, 0.117860, 0.035116},{1.482165, 0.120590, 0.023903}}],
    Polygon[{{1.488196, 0.098648, 0.035116},{1.482165, 0.096688, 0.045465},{
      1.473276, 0.114133, 0.045465},{1.478407, 0.117860, 0.035116}}],
    Polygon[{{1.482165, 0.096688, 0.045465},{1.474668, 0.094252, 0.054695},{
      1.466899, 0.109499, 0.054695},{1.473276, 0.114133, 0.045465}}],
    Polygon[{{1.474668, 0.094252, 0.054695},{1.465890, 0.091400, 0.062578},{
      1.459432, 0.104074, 0.062578},{1.466899, 0.109499, 0.054695}}],
    Polygon[{{1.465890, 0.091400, 0.062578},{1.456047, 0.088202, 0.068920},{
      1.451059, 0.097991, 0.068920},{1.459432, 0.104074, 0.062578}}],
    Polygon[{{1.456047, 0.088202, 0.068920},{1.445382, 0.084737, 0.073564},{
      1.441987, 0.091400, 0.073564},{1.451059, 0.097991, 0.068920}}],
    Polygon[{{1.445382, 0.084737, 0.073564},{1.434158, 0.081089, 0.076398},{
      1.432439, 0.084463, 0.076398},{1.441987, 0.091400, 0.073564}}],
    Polygon[{{1.432439, 0.084463, -0.076398},{1.441987, 0.091400, -0.073564},{
      1.436699, 0.096688, -0.073564},{1.429762, 0.087140, -0.076398}}],
    Polygon[{{1.441987, 0.091400, -0.073564},{1.451059, 0.097991, -0.068920},{
      1.443291, 0.105760, -0.068920},{1.436699, 0.096688, -0.073564}}],
    Polygon[{{1.451059, 0.097991, -0.068920},{1.459432, 0.104074, -0.062578},{
      1.449374, 0.114133, -0.062578},{1.443291, 0.105760, -0.068920}}],
    Polygon[{{1.459432, 0.104074, -0.062578},{1.466899, 0.109499, -0.054695},{
      1.454799, 0.121599, -0.054695},{1.449374, 0.114133, -0.062578}}],
    Polygon[{{1.466899, 0.109499, -0.054695},{1.473276, 0.114133, -0.045465},{
      1.459432, 0.127977, -0.045465},{1.454799, 0.121599, -0.054695}}],
    Polygon[{{1.473276, 0.114133, -0.045465},{1.478407, 0.117860, -0.035116},{
      1.463160, 0.133107, -0.035116},{1.459432, 0.127977, -0.045465}}],
    Polygon[{{1.478407, 0.117860, -0.035116},{1.482165, 0.120590, -0.023903},{
      1.465890, 0.136865, -0.023903},{1.463160, 0.133107, -0.035116}}],
    Polygon[{{1.482165, 0.120590, -0.023903},{1.484457, 0.122256, -0.012100},{
      1.467555, 0.139158, -0.012100},{1.465890, 0.136865, -0.023903}}],
    Polygon[{{1.484457, 0.122256, -0.012100},{1.485227, 0.122816, 0.000000},{
      1.468115, 0.139928, 0.000000},{1.467555, 0.139158, -0.012100}}],
    Polygon[{{1.485227, 0.122816, 0.000000},{1.484457, 0.122256, 0.012100},{
      1.467555, 0.139158, 0.012100},{1.468115, 0.139928, 0.000000}}],
    Polygon[{{1.484457, 0.122256, 0.012100},{1.482165, 0.120590, 0.023903},{
      1.465890, 0.136865, 0.023903},{1.467555, 0.139158, 0.012100}}],
    Polygon[{{1.482165, 0.120590, 0.023903},{1.478407, 0.117860, 0.035116},{
      1.463160, 0.133107, 0.035116},{1.465890, 0.136865, 0.023903}}],
    Polygon[{{1.478407, 0.117860, 0.035116},{1.473276, 0.114133, 0.045465},{
      1.459432, 0.127977, 0.045465},{1.463160, 0.133107, 0.035116}}],
    Polygon[{{1.473276, 0.114133, 0.045465},{1.466899, 0.109499, 0.054695},{
      1.454799, 0.121599, 0.054695},{1.459432, 0.127977, 0.045465}}],
    Polygon[{{1.466899, 0.109499, 0.054695},{1.459432, 0.104074, 0.062578},{
      1.449374, 0.114133, 0.062578},{1.454799, 0.121599, 0.054695}}],
    Polygon[{{1.459432, 0.104074, 0.062578},{1.451059, 0.097991, 0.068920},{
      1.443291, 0.105760, 0.068920},{1.449374, 0.114133, 0.062578}}],
    Polygon[{{1.451059, 0.097991, 0.068920},{1.441987, 0.091400, 0.073564},{
      1.436699, 0.096688, 0.073564},{1.443291, 0.105760, 0.068920}}],
    Polygon[{{1.441987, 0.091400, 0.073564},{1.432439, 0.084463, 0.076398},{
      1.429762, 0.087140, 0.076398},{1.436699, 0.096688, 0.073564}}],
    Polygon[{{1.429762, 0.087140, -0.076398},{1.436699, 0.096688, -0.073564},{
      1.430036, 0.100083, -0.073564},{1.426389, 0.088858, -0.076398}}],
    Polygon[{{1.436699, 0.096688, -0.073564},{1.443291, 0.105760, -0.068920},{
      1.433501, 0.110748, -0.068920},{1.430036, 0.100083, -0.073564}}],
    Polygon[{{1.443291, 0.105760, -0.068920},{1.449374, 0.114133, -0.062578},{
      1.436699, 0.120590, -0.062578},{1.433501, 0.110748, -0.068920}}],
    Polygon[{{1.449374, 0.114133, -0.062578},{1.454799, 0.121599, -0.054695},{
      1.439551, 0.129368, -0.054695},{1.436699, 0.120590, -0.062578}}],
    Polygon[{{1.454799, 0.121599, -0.054695},{1.459432, 0.127977, -0.045465},{
      1.441987, 0.136865, -0.045465},{1.439551, 0.129368, -0.054695}}],
    Polygon[{{1.459432, 0.127977, -0.045465},{1.463160, 0.133107, -0.035116},{
      1.443947, 0.142897, -0.035116},{1.441987, 0.136865, -0.045465}}],
    Polygon[{{1.463160, 0.133107, -0.035116},{1.465890, 0.136865, -0.023903},{
      1.445382, 0.147314, -0.023903},{1.443947, 0.142897, -0.035116}}],
    Polygon[{{1.465890, 0.136865, -0.023903},{1.467555, 0.139158, -0.012100},{
      1.446258, 0.150009, -0.012100},{1.445382, 0.147314, -0.023903}}],
    Polygon[{{1.467555, 0.139158, -0.012100},{1.468115, 0.139928, 0.000000},{
      1.446552, 0.150915, 0.000000},{1.446258, 0.150009, -0.012100}}],
    Polygon[{{1.468115, 0.139928, 0.000000},{1.467555, 0.139158, 0.012100},{
      1.446258, 0.150009, 0.012100},{1.446552, 0.150915, 0.000000}}],
    Polygon[{{1.467555, 0.139158, 0.012100},{1.465890, 0.136865, 0.023903},{
      1.445382, 0.147314, 0.023903},{1.446258, 0.150009, 0.012100}}],
    Polygon[{{1.465890, 0.136865, 0.023903},{1.463160, 0.133107, 0.035116},{
      1.443947, 0.142897, 0.035116},{1.445382, 0.147314, 0.023903}}],
    Polygon[{{1.463160, 0.133107, 0.035116},{1.459432, 0.127977, 0.045465},{
      1.441987, 0.136865, 0.045465},{1.443947, 0.142897, 0.035116}}],
    Polygon[{{1.459432, 0.127977, 0.045465},{1.454799, 0.121599, 0.054695},{
      1.439551, 0.129368, 0.054695},{1.441987, 0.136865, 0.045465}}],
    Polygon[{{1.454799, 0.121599, 0.054695},{1.449374, 0.114133, 0.062578},{
      1.436699, 0.120590, 0.062578},{1.439551, 0.129368, 0.054695}}],
    Polygon[{{1.449374, 0.114133, 0.062578},{1.443291, 0.105760, 0.068920},{
      1.433501, 0.110748, 0.068920},{1.436699, 0.120590, 0.062578}}],
    Polygon[{{1.443291, 0.105760, 0.068920},{1.436699, 0.096688, 0.073564},{
      1.430036, 0.100083, 0.073564},{1.433501, 0.110748, 0.068920}}],
    Polygon[{{1.436699, 0.096688, 0.073564},{1.429762, 0.087140, 0.076398},{
      1.426389, 0.088858, 0.076398},{1.430036, 0.100083, 0.073564}}],
    Polygon[{{1.426389, 0.088858, -0.076398},{1.430036, 0.100083, -0.073564},{
      1.422650, 0.101253, -0.073564},{1.422650, 0.089451, -0.076398}}],
    Polygon[{{1.430036, 0.100083, -0.073564},{1.433501, 0.110748, -0.068920},{
      1.422650, 0.112467, -0.068920},{1.422650, 0.101253, -0.073564}}],
    Polygon[{{1.433501, 0.110748, -0.068920},{1.436699, 0.120590, -0.062578},{
      1.422650, 0.122816, -0.062578},{1.422650, 0.112467, -0.068920}}],
    Polygon[{{1.436699, 0.120590, -0.062578},{1.439551, 0.129368, -0.054695},{
      1.422650, 0.132045, -0.054695},{1.422650, 0.122816, -0.062578}}],
    Polygon[{{1.439551, 0.129368, -0.054695},{1.441987, 0.136865, -0.045465},{
      1.422650, 0.139928, -0.045465},{1.422650, 0.132045, -0.054695}}],
    Polygon[{{1.441987, 0.136865, -0.045465},{1.443947, 0.142897, -0.035116},{
      1.422650, 0.146270, -0.035116},{1.422650, 0.139928, -0.045465}}],
    Polygon[{{1.443947, 0.142897, -0.035116},{1.445382, 0.147314, -0.023903},{
      1.422650, 0.150915, -0.023903},{1.422650, 0.146270, -0.035116}}],
    Polygon[{{1.445382, 0.147314, -0.023903},{1.446258, 0.150009, -0.012100},{
      1.422650, 0.153748, -0.012100},{1.422650, 0.150915, -0.023903}}],
    Polygon[{{1.446258, 0.150009, -0.012100},{1.446552, 0.150915, 0.000000},{
      1.422650, 0.154701, 0.000000},{1.422650, 0.153748, -0.012100}}],
    Polygon[{{1.446552, 0.150915, 0.000000},{1.446258, 0.150009, 0.012100},{
      1.422650, 0.153748, 0.012100},{1.422650, 0.154701, 0.000000}}],
    Polygon[{{1.446258, 0.150009, 0.012100},{1.445382, 0.147314, 0.023903},{
      1.422650, 0.150915, 0.023903},{1.422650, 0.153748, 0.012100}}],
    Polygon[{{1.445382, 0.147314, 0.023903},{1.443947, 0.142897, 0.035116},{
      1.422650, 0.146270, 0.035116},{1.422650, 0.150915, 0.023903}}],
    Polygon[{{1.443947, 0.142897, 0.035116},{1.441987, 0.136865, 0.045465},{
      1.422650, 0.139928, 0.045465},{1.422650, 0.146270, 0.035116}}],
    Polygon[{{1.441987, 0.136865, 0.045465},{1.439551, 0.129368, 0.054695},{
      1.422650, 0.132045, 0.054695},{1.422650, 0.139928, 0.045465}}],
    Polygon[{{1.439551, 0.129368, 0.054695},{1.436699, 0.120590, 0.062578},{
      1.422650, 0.122816, 0.062578},{1.422650, 0.132045, 0.054695}}],
    Polygon[{{1.436699, 0.120590, 0.062578},{1.433501, 0.110748, 0.068920},{
      1.422650, 0.112467, 0.068920},{1.422650, 0.122816, 0.062578}}],
    Polygon[{{1.433501, 0.110748, 0.068920},{1.430036, 0.100083, 0.073564},{
      1.422650, 0.101253, 0.073564},{1.422650, 0.112467, 0.068920}}],
    Polygon[{{1.430036, 0.100083, 0.073564},{1.426389, 0.088858, 0.076398},{
      1.422650, 0.089451, 0.076398},{1.422650, 0.101253, 0.073564}}],
    Polygon[{{1.422650, 0.089451, -0.076398},{1.422650, 0.101253, -0.073564},{
      1.415263, 0.100083, -0.073564},{1.418911, 0.088858, -0.076398}}],
    Polygon[{{1.422650, 0.101253, -0.073564},{1.422650, 0.112467, -0.068920},{
      1.411798, 0.110748, -0.068920},{1.415263, 0.100083, -0.073564}}],
    Polygon[{{1.422650, 0.112467, -0.068920},{1.422650, 0.122816, -0.062578},{
      1.408600, 0.120590, -0.062578},{1.411798, 0.110748, -0.068920}}],
    Polygon[{{1.422650, 0.122816, -0.062578},{1.422650, 0.132045, -0.054695},{
      1.405748, 0.129368, -0.054695},{1.408600, 0.120590, -0.062578}}],
    Polygon[{{1.422650, 0.132045, -0.054695},{1.422650, 0.139928, -0.045465},{
      1.403312, 0.136865, -0.045465},{1.405748, 0.129368, -0.054695}}],
    Polygon[{{1.422650, 0.139928, -0.045465},{1.422650, 0.146270, -0.035116},{
      1.401352, 0.142897, -0.035116},{1.403312, 0.136865, -0.045465}}],
    Polygon[{{1.422650, 0.146270, -0.035116},{1.422650, 0.150915, -0.023903},{
      1.399917, 0.147314, -0.023903},{1.401352, 0.142897, -0.035116}}],
    Polygon[{{1.422650, 0.150915, -0.023903},{1.422650, 0.153748, -0.012100},{
      1.399041, 0.150009, -0.012100},{1.399917, 0.147314, -0.023903}}],
    Polygon[{{1.422650, 0.153748, -0.012100},{1.422650, 0.154701, 0.000000},{
      1.398747, 0.150915, 0.000000},{1.399041, 0.150009, -0.012100}}],
    Polygon[{{1.422650, 0.154701, 0.000000},{1.422650, 0.153748, 0.012100},{
      1.399041, 0.150009, 0.012100},{1.398747, 0.150915, 0.000000}}],
    Polygon[{{1.422650, 0.153748, 0.012100},{1.422650, 0.150915, 0.023903},{
      1.399917, 0.147314, 0.023903},{1.399041, 0.150009, 0.012100}}],
    Polygon[{{1.422650, 0.150915, 0.023903},{1.422650, 0.146270, 0.035116},{
      1.401352, 0.142897, 0.035116},{1.399917, 0.147314, 0.023903}}],
    Polygon[{{1.422650, 0.146270, 0.035116},{1.422650, 0.139928, 0.045465},{
      1.403312, 0.136865, 0.045465},{1.401352, 0.142897, 0.035116}}],
    Polygon[{{1.422650, 0.139928, 0.045465},{1.422650, 0.132045, 0.054695},{
      1.405748, 0.129368, 0.054695},{1.403312, 0.136865, 0.045465}}],
    Polygon[{{1.422650, 0.132045, 0.054695},{1.422650, 0.122816, 0.062578},{
      1.408600, 0.120590, 0.062578},{1.405748, 0.129368, 0.054695}}],
    Polygon[{{1.422650, 0.122816, 0.062578},{1.422650, 0.112467, 0.068920},{
      1.411798, 0.110748, 0.068920},{1.408600, 0.120590, 0.062578}}],
    Polygon[{{1.422650, 0.112467, 0.068920},{1.422650, 0.101253, 0.073564},{
      1.415263, 0.100083, 0.073564},{1.411798, 0.110748, 0.068920}}],
    Polygon[{{1.422650, 0.101253, 0.073564},{1.422650, 0.089451, 0.076398},{
      1.418911, 0.088858, 0.076398},{1.415263, 0.100083, 0.073564}}],
    Polygon[{{1.418911, 0.088858, -0.076398},{1.415263, 0.100083, -0.073564},{
      1.408600, 0.096688, -0.073564},{1.415537, 0.087140, -0.076398}}],
    Polygon[{{1.415263, 0.100083, -0.073564},{1.411798, 0.110748, -0.068920},{
      1.402009, 0.105760, -0.068920},{1.408600, 0.096688, -0.073564}}],
    Polygon[{{1.411798, 0.110748, -0.068920},{1.408600, 0.120590, -0.062578},{
      1.395926, 0.114133, -0.062578},{1.402009, 0.105760, -0.068920}}],
    Polygon[{{1.408600, 0.120590, -0.062578},{1.405748, 0.129368, -0.054695},{
      1.390501, 0.121599, -0.054695},{1.395926, 0.114133, -0.062578}}],
    Polygon[{{1.405748, 0.129368, -0.054695},{1.403312, 0.136865, -0.045465},{
      1.385867, 0.127977, -0.045465},{1.390501, 0.121599, -0.054695}}],
    Polygon[{{1.403312, 0.136865, -0.045465},{1.401352, 0.142897, -0.035116},{
      1.382140, 0.133107, -0.035116},{1.385867, 0.127977, -0.045465}}],
    Polygon[{{1.401352, 0.142897, -0.035116},{1.399917, 0.147314, -0.023903},{
      1.379410, 0.136865, -0.023903},{1.382140, 0.133107, -0.035116}}],
    Polygon[{{1.399917, 0.147314, -0.023903},{1.399041, 0.150009, -0.012100},{
      1.377744, 0.139158, -0.012100},{1.379410, 0.136865, -0.023903}}],
    Polygon[{{1.399041, 0.150009, -0.012100},{1.398747, 0.150915, 0.000000},{
      1.377184, 0.139928, 0.000000},{1.377744, 0.139158, -0.012100}}],
    Polygon[{{1.398747, 0.150915, 0.000000},{1.399041, 0.150009, 0.012100},{
      1.377744, 0.139158, 0.012100},{1.377184, 0.139928, 0.000000}}],
    Polygon[{{1.399041, 0.150009, 0.012100},{1.399917, 0.147314, 0.023903},{
      1.379410, 0.136865, 0.023903},{1.377744, 0.139158, 0.012100}}],
    Polygon[{{1.399917, 0.147314, 0.023903},{1.401352, 0.142897, 0.035116},{
      1.382140, 0.133107, 0.035116},{1.379410, 0.136865, 0.023903}}],
    Polygon[{{1.401352, 0.142897, 0.035116},{1.403312, 0.136865, 0.045465},{
      1.385867, 0.127977, 0.045465},{1.382140, 0.133107, 0.035116}}],
    Polygon[{{1.403312, 0.136865, 0.045465},{1.405748, 0.129368, 0.054695},{
      1.390501, 0.121599, 0.054695},{1.385867, 0.127977, 0.045465}}],
    Polygon[{{1.405748, 0.129368, 0.054695},{1.408600, 0.120590, 0.062578},{
      1.395926, 0.114133, 0.062578},{1.390501, 0.121599, 0.054695}}],
    Polygon[{{1.408600, 0.120590, 0.062578},{1.411798, 0.110748, 0.068920},{
      1.402009, 0.105760, 0.068920},{1.395926, 0.114133, 0.062578}}],
    Polygon[{{1.411798, 0.110748, 0.068920},{1.415263, 0.100083, 0.073564},{
      1.408600, 0.096688, 0.073564},{1.402009, 0.105760, 0.068920}}],
    Polygon[{{1.415263, 0.100083, 0.073564},{1.418911, 0.088858, 0.076398},{
      1.415537, 0.087140, 0.076398},{1.408600, 0.096688, 0.073564}}],
    Polygon[{{1.415537, 0.087140, -0.076398},{1.408600, 0.096688, -0.073564},{
      1.403312, 0.091400, -0.073564},{1.412860, 0.084463, -0.076398}}],
    Polygon[{{1.408600, 0.096688, -0.073564},{1.402009, 0.105760, -0.068920},{
      1.394240, 0.097991, -0.068920},{1.403312, 0.091400, -0.073564}}],
    Polygon[{{1.402009, 0.105760, -0.068920},{1.395926, 0.114133, -0.062578},{
      1.385867, 0.104074, -0.062578},{1.394240, 0.097991, -0.068920}}],
    Polygon[{{1.395926, 0.114133, -0.062578},{1.390501, 0.121599, -0.054695},{
      1.378401, 0.109499, -0.054695},{1.385867, 0.104074, -0.062578}}],
    Polygon[{{1.390501, 0.121599, -0.054695},{1.385867, 0.127977, -0.045465},{
      1.372023, 0.114133, -0.045465},{1.378401, 0.109499, -0.054695}}],
    Polygon[{{1.385867, 0.127977, -0.045465},{1.382140, 0.133107, -0.035116},{
      1.366893, 0.117860, -0.035116},{1.372023, 0.114133, -0.045465}}],
    Polygon[{{1.382140, 0.133107, -0.035116},{1.379410, 0.136865, -0.023903},{
      1.363135, 0.120590, -0.023903},{1.366893, 0.117860, -0.035116}}],
    Polygon[{{1.379410, 0.136865, -0.023903},{1.377744, 0.139158, -0.012100},{
      1.360842, 0.122256, -0.012100},{1.363135, 0.120590, -0.023903}}],
    Polygon[{{1.377744, 0.139158, -0.012100},{1.377184, 0.139928, 0.000000},{
      1.360072, 0.122816, 0.000000},{1.360842, 0.122256, -0.012100}}],
    Polygon[{{1.377184, 0.139928, 0.000000},{1.377744, 0.139158, 0.012100},{
      1.360842, 0.122256, 0.012100},{1.360072, 0.122816, 0.000000}}],
    Polygon[{{1.377744, 0.139158, 0.012100},{1.379410, 0.136865, 0.023903},{
      1.363135, 0.120590, 0.023903},{1.360842, 0.122256, 0.012100}}],
    Polygon[{{1.379410, 0.136865, 0.023903},{1.382140, 0.133107, 0.035116},{
      1.366893, 0.117860, 0.035116},{1.363135, 0.120590, 0.023903}}],
    Polygon[{{1.382140, 0.133107, 0.035116},{1.385867, 0.127977, 0.045465},{
      1.372023, 0.114133, 0.045465},{1.366893, 0.117860, 0.035116}}],
    Polygon[{{1.385867, 0.127977, 0.045465},{1.390501, 0.121599, 0.054695},{
      1.378401, 0.109499, 0.054695},{1.372023, 0.114133, 0.045465}}],
    Polygon[{{1.390501, 0.121599, 0.054695},{1.395926, 0.114133, 0.062578},{
      1.385867, 0.104074, 0.062578},{1.378401, 0.109499, 0.054695}}],
    Polygon[{{1.395926, 0.114133, 0.062578},{1.402009, 0.105760, 0.068920},{
      1.394240, 0.097991, 0.068920},{1.385867, 0.104074, 0.062578}}],
    Polygon[{{1.402009, 0.105760, 0.068920},{1.408600, 0.096688, 0.073564},{
      1.403312, 0.091400, 0.073564},{1.394240, 0.097991, 0.068920}}],
    Polygon[{{1.408600, 0.096688, 0.073564},{1.415537, 0.087140, 0.076398},{
      1.412860, 0.084463, 0.076398},{1.403312, 0.091400, 0.073564}}],
    Polygon[{{1.412860, 0.084463, -0.076398},{1.403312, 0.091400, -0.073564},{
      1.399917, 0.084737, -0.073564},{1.411142, 0.081089, -0.076398}}],
    Polygon[{{1.403312, 0.091400, -0.073564},{1.394240, 0.097991, -0.068920},{
      1.389252, 0.088202, -0.068920},{1.399917, 0.084737, -0.073564}}],
    Polygon[{{1.394240, 0.097991, -0.068920},{1.385867, 0.104074, -0.062578},{
      1.379410, 0.091400, -0.062578},{1.389252, 0.088202, -0.068920}}],
    Polygon[{{1.385867, 0.104074, -0.062578},{1.378401, 0.109499, -0.054695},{
      1.370632, 0.094252, -0.054695},{1.379410, 0.091400, -0.062578}}],
    Polygon[{{1.378401, 0.109499, -0.054695},{1.372023, 0.114133, -0.045465},{
      1.363135, 0.096688, -0.045465},{1.370632, 0.094252, -0.054695}}],
    Polygon[{{1.372023, 0.114133, -0.045465},{1.366893, 0.117860, -0.035116},{
      1.357103, 0.098648, -0.035116},{1.363135, 0.096688, -0.045465}}],
    Polygon[{{1.366893, 0.117860, -0.035116},{1.363135, 0.120590, -0.023903},{
      1.352686, 0.100083, -0.023903},{1.357103, 0.098648, -0.035116}}],
    Polygon[{{1.363135, 0.120590, -0.023903},{1.360842, 0.122256, -0.012100},{
      1.349991, 0.100959, -0.012100},{1.352686, 0.100083, -0.023903}}],
    Polygon[{{1.360842, 0.122256, -0.012100},{1.360072, 0.122816, 0.000000},{
      1.349085, 0.101253, 0.000000},{1.349991, 0.100959, -0.012100}}],
    Polygon[{{1.360072, 0.122816, 0.000000},{1.360842, 0.122256, 0.012100},{
      1.349991, 0.100959, 0.012100},{1.349085, 0.101253, 0.000000}}],
    Polygon[{{1.360842, 0.122256, 0.012100},{1.363135, 0.120590, 0.023903},{
      1.352686, 0.100083, 0.023903},{1.349991, 0.100959, 0.012100}}],
    Polygon[{{1.363135, 0.120590, 0.023903},{1.366893, 0.117860, 0.035116},{
      1.357103, 0.098648, 0.035116},{1.352686, 0.100083, 0.023903}}],
    Polygon[{{1.366893, 0.117860, 0.035116},{1.372023, 0.114133, 0.045465},{
      1.363135, 0.096688, 0.045465},{1.357103, 0.098648, 0.035116}}],
    Polygon[{{1.372023, 0.114133, 0.045465},{1.378401, 0.109499, 0.054695},{
      1.370632, 0.094252, 0.054695},{1.363135, 0.096688, 0.045465}}],
    Polygon[{{1.378401, 0.109499, 0.054695},{1.385867, 0.104074, 0.062578},{
      1.379410, 0.091400, 0.062578},{1.370632, 0.094252, 0.054695}}],
    Polygon[{{1.385867, 0.104074, 0.062578},{1.394240, 0.097991, 0.068920},{
      1.389252, 0.088202, 0.068920},{1.379410, 0.091400, 0.062578}}],
    Polygon[{{1.394240, 0.097991, 0.068920},{1.403312, 0.091400, 0.073564},{
      1.399917, 0.084737, 0.073564},{1.389252, 0.088202, 0.068920}}],
    Polygon[{{1.403312, 0.091400, 0.073564},{1.412860, 0.084463, 0.076398},{
      1.411142, 0.081089, 0.076398},{1.399917, 0.084737, 0.073564}}],
    Polygon[{{1.411142, 0.081089, -0.076398},{1.399917, 0.084737, -0.073564},{
      1.398747, 0.077350, -0.073564},{1.410550, 0.077350, -0.076398}}],
    Polygon[{{1.399917, 0.084737, -0.073564},{1.389252, 0.088202, -0.068920},{
      1.387533, 0.077350, -0.068920},{1.398747, 0.077350, -0.073564}}],
    Polygon[{{1.389252, 0.088202, -0.068920},{1.379410, 0.091400, -0.062578},{
      1.377184, 0.077350, -0.062578},{1.387533, 0.077350, -0.068920}}],
    Polygon[{{1.379410, 0.091400, -0.062578},{1.370632, 0.094252, -0.054695},{
      1.367955, 0.077350, -0.054695},{1.377184, 0.077350, -0.062578}}],
    Polygon[{{1.370632, 0.094252, -0.054695},{1.363135, 0.096688, -0.045465},{
      1.360072, 0.077350, -0.045465},{1.367955, 0.077350, -0.054695}}],
    Polygon[{{1.363135, 0.096688, -0.045465},{1.357103, 0.098648, -0.035116},{
      1.353730, 0.077350, -0.035116},{1.360072, 0.077350, -0.045465}}],
    Polygon[{{1.357103, 0.098648, -0.035116},{1.352686, 0.100083, -0.023903},{
      1.349085, 0.077350, -0.023903},{1.353730, 0.077350, -0.035116}}],
    Polygon[{{1.352686, 0.100083, -0.023903},{1.349991, 0.100959, -0.012100},{
      1.346252, 0.077350, -0.012100},{1.349085, 0.077350, -0.023903}}],
    Polygon[{{1.349991, 0.100959, -0.012100},{1.349085, 0.101253, 0.000000},{
      1.345299, 0.077350, 0.000000},{1.346252, 0.077350, -0.012100}}],
    Polygon[{{1.349085, 0.101253, 0.000000},{1.349991, 0.100959, 0.012100},{
      1.346252, 0.077350, 0.012100},{1.345299, 0.077350, 0.000000}}],
    Polygon[{{1.349991, 0.100959, 0.012100},{1.352686, 0.100083, 0.023903},{
      1.349085, 0.077350, 0.023903},{1.346252, 0.077350, 0.012100}}],
    Polygon[{{1.352686, 0.100083, 0.023903},{1.357103, 0.098648, 0.035116},{
      1.353730, 0.077350, 0.035116},{1.349085, 0.077350, 0.023903}}],
    Polygon[{{1.357103, 0.098648, 0.035116},{1.363135, 0.096688, 0.045465},{
      1.360072, 0.077350, 0.045465},{1.353730, 0.077350, 0.035116}}],
    Polygon[{{1.363135, 0.096688, 0.045465},{1.370632, 0.094252, 0.054695},{
      1.367955, 0.077350, 0.054695},{1.360072, 0.077350, 0.045465}}],
    Polygon[{{1.370632, 0.094252, 0.054695},{1.379410, 0.091400, 0.062578},{
      1.377184, 0.077350, 0.062578},{1.367955, 0.077350, 0.054695}}],
    Polygon[{{1.379410, 0.091400, 0.062578},{1.389252, 0.088202, 0.068920},{
      1.387533, 0.077350, 0.068920},{1.377184, 0.077350, 0.062578}}],
    Polygon[{{1.389252, 0.088202, 0.068920},{1.399917, 0.084737, 0.073564},{
      1.398747, 0.077350, 0.073564},{1.387533, 0.077350, 0.068920}}],
    Polygon[{{1.399917, 0.084737, 0.073564},{1.411142, 0.081089, 0.076398},{
      1.410550, 0.077350, 0.076398},{1.398747, 0.077350, 0.073564}}],
    Polygon[{{1.410550, 0.077350, -0.076398},{1.398747, 0.077350, -0.073564},{
      1.399917, 0.069964, -0.073564},{1.411142, 0.073611, -0.076398}}],
    Polygon[{{1.398747, 0.077350, -0.073564},{1.387533, 0.077350, -0.068920},{
      1.389252, 0.066499, -0.068920},{1.399917, 0.069964, -0.073564}}],
    Polygon[{{1.387533, 0.077350, -0.068920},{1.377184, 0.077350, -0.062578},{
      1.379410, 0.063301, -0.062578},{1.389252, 0.066499, -0.068920}}],
    Polygon[{{1.377184, 0.077350, -0.062578},{1.367955, 0.077350, -0.054695},{
      1.370632, 0.060449, -0.054695},{1.379410, 0.063301, -0.062578}}],
    Polygon[{{1.367955, 0.077350, -0.054695},{1.360072, 0.077350, -0.045465},{
      1.363135, 0.058013, -0.045465},{1.370632, 0.060449, -0.054695}}],
    Polygon[{{1.360072, 0.077350, -0.045465},{1.353730, 0.077350, -0.035116},{
      1.357103, 0.056053, -0.035116},{1.363135, 0.058013, -0.045465}}],
    Polygon[{{1.353730, 0.077350, -0.035116},{1.349085, 0.077350, -0.023903},{
      1.352686, 0.054618, -0.023903},{1.357103, 0.056053, -0.035116}}],
    Polygon[{{1.349085, 0.077350, -0.023903},{1.346252, 0.077350, -0.012100},{
      1.349991, 0.053742, -0.012100},{1.352686, 0.054618, -0.023903}}],
    Polygon[{{1.346252, 0.077350, -0.012100},{1.345299, 0.077350, 0.000000},{
      1.349085, 0.053448, 0.000000},{1.349991, 0.053742, -0.012100}}],
    Polygon[{{1.345299, 0.077350, 0.000000},{1.346252, 0.077350, 0.012100},{
      1.349991, 0.053742, 0.012100},{1.349085, 0.053448, 0.000000}}],
    Polygon[{{1.346252, 0.077350, 0.012100},{1.349085, 0.077350, 0.023903},{
      1.352686, 0.054618, 0.023903},{1.349991, 0.053742, 0.012100}}],
    Polygon[{{1.349085, 0.077350, 0.023903},{1.353730, 0.077350, 0.035116},{
      1.357103, 0.056053, 0.035116},{1.352686, 0.054618, 0.023903}}],
    Polygon[{{1.353730, 0.077350, 0.035116},{1.360072, 0.077350, 0.045465},{
      1.363135, 0.058013, 0.045465},{1.357103, 0.056053, 0.035116}}],
    Polygon[{{1.360072, 0.077350, 0.045465},{1.367955, 0.077350, 0.054695},{
      1.370632, 0.060449, 0.054695},{1.363135, 0.058013, 0.045465}}],
    Polygon[{{1.367955, 0.077350, 0.054695},{1.377184, 0.077350, 0.062578},{
      1.379410, 0.063301, 0.062578},{1.370632, 0.060449, 0.054695}}],
    Polygon[{{1.377184, 0.077350, 0.062578},{1.387533, 0.077350, 0.068920},{
      1.389252, 0.066499, 0.068920},{1.379410, 0.063301, 0.062578}}],
    Polygon[{{1.387533, 0.077350, 0.068920},{1.398747, 0.077350, 0.073564},{
      1.399917, 0.069964, 0.073564},{1.389252, 0.066499, 0.068920}}],
    Polygon[{{1.398747, 0.077350, 0.073564},{1.410550, 0.077350, 0.076398},{
      1.411142, 0.073611, 0.076398},{1.399917, 0.069964, 0.073564}}],
    Polygon[{{1.411142, 0.073611, -0.076398},{1.399917, 0.069964, -0.073564},{
      1.403312, 0.063301, -0.073564},{1.412860, 0.070238, -0.076398}}],
    Polygon[{{1.399917, 0.069964, -0.073564},{1.389252, 0.066499, -0.068920},{
      1.394240, 0.056709, -0.068920},{1.403312, 0.063301, -0.073564}}],
    Polygon[{{1.389252, 0.066499, -0.068920},{1.379410, 0.063301, -0.062578},{
      1.385867, 0.050626, -0.062578},{1.394240, 0.056709, -0.068920}}],
    Polygon[{{1.379410, 0.063301, -0.062578},{1.370632, 0.060449, -0.054695},{
      1.378401, 0.045201, -0.054695},{1.385867, 0.050626, -0.062578}}],
    Polygon[{{1.370632, 0.060449, -0.054695},{1.363135, 0.058013, -0.045465},{
      1.372023, 0.040568, -0.045465},{1.378401, 0.045201, -0.054695}}],
    Polygon[{{1.363135, 0.058013, -0.045465},{1.357103, 0.056053, -0.035116},{
      1.366893, 0.036840, -0.035116},{1.372023, 0.040568, -0.045465}}],
    Polygon[{{1.357103, 0.056053, -0.035116},{1.352686, 0.054618, -0.023903},{
      1.363135, 0.034110, -0.023903},{1.366893, 0.036840, -0.035116}}],
    Polygon[{{1.352686, 0.054618, -0.023903},{1.349991, 0.053742, -0.012100},{
      1.360842, 0.032445, -0.012100},{1.363135, 0.034110, -0.023903}}],
    Polygon[{{1.349991, 0.053742, -0.012100},{1.349085, 0.053448, 0.000000},{
      1.360072, 0.031885, 0.000000},{1.360842, 0.032445, -0.012100}}],
    Polygon[{{1.349085, 0.053448, 0.000000},{1.349991, 0.053742, 0.012100},{
      1.360842, 0.032445, 0.012100},{1.360072, 0.031885, 0.000000}}],
    Polygon[{{1.349991, 0.053742, 0.012100},{1.352686, 0.054618, 0.023903},{
      1.363135, 0.034110, 0.023903},{1.360842, 0.032445, 0.012100}}],
    Polygon[{{1.352686, 0.054618, 0.023903},{1.357103, 0.056053, 0.035116},{
      1.366893, 0.036840, 0.035116},{1.363135, 0.034110, 0.023903}}],
    Polygon[{{1.357103, 0.056053, 0.035116},{1.363135, 0.058013, 0.045465},{
      1.372023, 0.040568, 0.045465},{1.366893, 0.036840, 0.035116}}],
    Polygon[{{1.363135, 0.058013, 0.045465},{1.370632, 0.060449, 0.054695},{
      1.378401, 0.045201, 0.054695},{1.372023, 0.040568, 0.045465}}],
    Polygon[{{1.370632, 0.060449, 0.054695},{1.379410, 0.063301, 0.062578},{
      1.385867, 0.050626, 0.062578},{1.378401, 0.045201, 0.054695}}],
    Polygon[{{1.379410, 0.063301, 0.062578},{1.389252, 0.066499, 0.068920},{
      1.394240, 0.056709, 0.068920},{1.385867, 0.050626, 0.062578}}],
    Polygon[{{1.389252, 0.066499, 0.068920},{1.399917, 0.069964, 0.073564},{
      1.403312, 0.063301, 0.073564},{1.394240, 0.056709, 0.068920}}],
    Polygon[{{1.399917, 0.069964, 0.073564},{1.411142, 0.073611, 0.076398},{
      1.412860, 0.070238, 0.076398},{1.403312, 0.063301, 0.073564}}],
    Polygon[{{1.412860, 0.070238, -0.076398},{1.403312, 0.063301, -0.073564},{
      1.408600, 0.058013, -0.073564},{1.415537, 0.067561, -0.076398}}],
    Polygon[{{1.403312, 0.063301, -0.073564},{1.394240, 0.056709, -0.068920},{
      1.402009, 0.048941, -0.068920},{1.408600, 0.058013, -0.073564}}],
    Polygon[{{1.394240, 0.056709, -0.068920},{1.385867, 0.050626, -0.062578},{
      1.395926, 0.040568, -0.062578},{1.402009, 0.048941, -0.068920}}],
    Polygon[{{1.385867, 0.050626, -0.062578},{1.378401, 0.045201, -0.054695},{
      1.390501, 0.033101, -0.054695},{1.395926, 0.040568, -0.062578}}],
    Polygon[{{1.378401, 0.045201, -0.054695},{1.372023, 0.040568, -0.045465},{
      1.385867, 0.026724, -0.045465},{1.390501, 0.033101, -0.054695}}],
    Polygon[{{1.372023, 0.040568, -0.045465},{1.366893, 0.036840, -0.035116},{
      1.382140, 0.021593, -0.035116},{1.385867, 0.026724, -0.045465}}],
    Polygon[{{1.366893, 0.036840, -0.035116},{1.363135, 0.034110, -0.023903},{
      1.379410, 0.017835, -0.023903},{1.382140, 0.021593, -0.035116}}],
    Polygon[{{1.363135, 0.034110, -0.023903},{1.360842, 0.032445, -0.012100},{
      1.377744, 0.015543, -0.012100},{1.379410, 0.017835, -0.023903}}],
    Polygon[{{1.360842, 0.032445, -0.012100},{1.360072, 0.031885, 0.000000},{
      1.377184, 0.014773, 0.000000},{1.377744, 0.015543, -0.012100}}],
    Polygon[{{1.360072, 0.031885, 0.000000},{1.360842, 0.032445, 0.012100},{
      1.377744, 0.015543, 0.012100},{1.377184, 0.014773, 0.000000}}],
    Polygon[{{1.360842, 0.032445, 0.012100},{1.363135, 0.034110, 0.023903},{
      1.379410, 0.017835, 0.023903},{1.377744, 0.015543, 0.012100}}],
    Polygon[{{1.363135, 0.034110, 0.023903},{1.366893, 0.036840, 0.035116},{
      1.382140, 0.021593, 0.035116},{1.379410, 0.017835, 0.023903}}],
    Polygon[{{1.366893, 0.036840, 0.035116},{1.372023, 0.040568, 0.045465},{
      1.385867, 0.026724, 0.045465},{1.382140, 0.021593, 0.035116}}],
    Polygon[{{1.372023, 0.040568, 0.045465},{1.378401, 0.045201, 0.054695},{
      1.390501, 0.033101, 0.054695},{1.385867, 0.026724, 0.045465}}],
    Polygon[{{1.378401, 0.045201, 0.054695},{1.385867, 0.050626, 0.062578},{
      1.395926, 0.040568, 0.062578},{1.390501, 0.033101, 0.054695}}],
    Polygon[{{1.385867, 0.050626, 0.062578},{1.394240, 0.056709, 0.068920},{
      1.402009, 0.048941, 0.068920},{1.395926, 0.040568, 0.062578}}],
    Polygon[{{1.394240, 0.056709, 0.068920},{1.403312, 0.063301, 0.073564},{
      1.408600, 0.058013, 0.073564},{1.402009, 0.048941, 0.068920}}],
    Polygon[{{1.403312, 0.063301, 0.073564},{1.412860, 0.070238, 0.076398},{
      1.415537, 0.067561, 0.076398},{1.408600, 0.058013, 0.073564}}],
    Polygon[{{1.415537, 0.067561, -0.076398},{1.408600, 0.058013, -0.073564},{
      1.415263, 0.054618, -0.073564},{1.418911, 0.065842, -0.076398}}],
    Polygon[{{1.408600, 0.058013, -0.073564},{1.402009, 0.048941, -0.068920},{
      1.411798, 0.043953, -0.068920},{1.415263, 0.054618, -0.073564}}],
    Polygon[{{1.402009, 0.048941, -0.068920},{1.395926, 0.040568, -0.062578},{
      1.408600, 0.034110, -0.062578},{1.411798, 0.043953, -0.068920}}],
    Polygon[{{1.395926, 0.040568, -0.062578},{1.390501, 0.033101, -0.054695},{
      1.405748, 0.025332, -0.054695},{1.408600, 0.034110, -0.062578}}],
    Polygon[{{1.390501, 0.033101, -0.054695},{1.385867, 0.026724, -0.045465},{
      1.403312, 0.017835, -0.045465},{1.405748, 0.025332, -0.054695}}],
    Polygon[{{1.385867, 0.026724, -0.045465},{1.382140, 0.021593, -0.035116},{
      1.401352, 0.011804, -0.035116},{1.403312, 0.017835, -0.045465}}],
    Polygon[{{1.382140, 0.021593, -0.035116},{1.379410, 0.017835, -0.023903},{
      1.399917, 0.007386, -0.023903},{1.401352, 0.011804, -0.035116}}],
    Polygon[{{1.379410, 0.017835, -0.023903},{1.377744, 0.015543, -0.012100},{
      1.399041, 0.004691, -0.012100},{1.399917, 0.007386, -0.023903}}],
    Polygon[{{1.377744, 0.015543, -0.012100},{1.377184, 0.014773, 0.000000},{
      1.398747, 0.003786, 0.000000},{1.399041, 0.004691, -0.012100}}],
    Polygon[{{1.377184, 0.014773, 0.000000},{1.377744, 0.015543, 0.012100},{
      1.399041, 0.004691, 0.012100},{1.398747, 0.003786, 0.000000}}],
    Polygon[{{1.377744, 0.015543, 0.012100},{1.379410, 0.017835, 0.023903},{
      1.399917, 0.007386, 0.023903},{1.399041, 0.004691, 0.012100}}],
    Polygon[{{1.379410, 0.017835, 0.023903},{1.382140, 0.021593, 0.035116},{
      1.401352, 0.011804, 0.035116},{1.399917, 0.007386, 0.023903}}],
    Polygon[{{1.382140, 0.021593, 0.035116},{1.385867, 0.026724, 0.045465},{
      1.403312, 0.017835, 0.045465},{1.401352, 0.011804, 0.035116}}],
    Polygon[{{1.385867, 0.026724, 0.045465},{1.390501, 0.033101, 0.054695},{
      1.405748, 0.025332, 0.054695},{1.403312, 0.017835, 0.045465}}],
    Polygon[{{1.390501, 0.033101, 0.054695},{1.395926, 0.040568, 0.062578},{
      1.408600, 0.034110, 0.062578},{1.405748, 0.025332, 0.054695}}],
    Polygon[{{1.395926, 0.040568, 0.062578},{1.402009, 0.048941, 0.068920},{
      1.411798, 0.043953, 0.068920},{1.408600, 0.034110, 0.062578}}],
    Polygon[{{1.402009, 0.048941, 0.068920},{1.408600, 0.058013, 0.073564},{
      1.415263, 0.054618, 0.073564},{1.411798, 0.043953, 0.068920}}],
    Polygon[{{1.408600, 0.058013, 0.073564},{1.415537, 0.067561, 0.076398},{
      1.418911, 0.065842, 0.076398},{1.415263, 0.054618, 0.073564}}],
    Polygon[{{1.418911, 0.065842, -0.076398},{1.415263, 0.054618, -0.073564},{
      1.422650, 0.053448, -0.073564},{1.422650, 0.065250, -0.076398}}],
    Polygon[{{1.415263, 0.054618, -0.073564},{1.411798, 0.043953, -0.068920},{
      1.422650, 0.042234, -0.068920},{1.422650, 0.053448, -0.073564}}],
    Polygon[{{1.411798, 0.043953, -0.068920},{1.408600, 0.034110, -0.062578},{
      1.422650, 0.031885, -0.062578},{1.422650, 0.042234, -0.068920}}],
    Polygon[{{1.408600, 0.034110, -0.062578},{1.405748, 0.025332, -0.054695},{
      1.422650, 0.022655, -0.054695},{1.422650, 0.031885, -0.062578}}],
    Polygon[{{1.405748, 0.025332, -0.054695},{1.403312, 0.017835, -0.045465},{
      1.422650, 0.014773, -0.045465},{1.422650, 0.022655, -0.054695}}],
    Polygon[{{1.403312, 0.017835, -0.045465},{1.401352, 0.011804, -0.035116},{
      1.422650, 0.008431, -0.035116},{1.422650, 0.014773, -0.045465}}],
    Polygon[{{1.401352, 0.011804, -0.035116},{1.399917, 0.007386, -0.023903},{
      1.422650, 0.003786, -0.023903},{1.422650, 0.008431, -0.035116}}],
    Polygon[{{1.399917, 0.007386, -0.023903},{1.399041, 0.004691, -0.012100},{
      1.422650, 0.000952, -0.012100},{1.422650, 0.003786, -0.023903}}],
    Polygon[{{1.399041, 0.004691, -0.012100},{1.398747, 0.003786, 0.000000},{
      1.422650, 0.000000, 0.000000},{1.422650, 0.000952, -0.012100}}],
    Polygon[{{1.398747, 0.003786, 0.000000},{1.399041, 0.004691, 0.012100},{
      1.422650, 0.000952, 0.012100},{1.422650, 0.000000, 0.000000}}],
    Polygon[{{1.399041, 0.004691, 0.012100},{1.399917, 0.007386, 0.023903},{
      1.422650, 0.003786, 0.023903},{1.422650, 0.000952, 0.012100}}],
    Polygon[{{1.399917, 0.007386, 0.023903},{1.401352, 0.011804, 0.035116},{
      1.422650, 0.008431, 0.035116},{1.422650, 0.003786, 0.023903}}],
    Polygon[{{1.401352, 0.011804, 0.035116},{1.403312, 0.017835, 0.045465},{
      1.422650, 0.014773, 0.045465},{1.422650, 0.008431, 0.035116}}],
    Polygon[{{1.403312, 0.017835, 0.045465},{1.405748, 0.025332, 0.054695},{
      1.422650, 0.022655, 0.054695},{1.422650, 0.014773, 0.045465}}],
    Polygon[{{1.405748, 0.025332, 0.054695},{1.408600, 0.034110, 0.062578},{
      1.422650, 0.031885, 0.062578},{1.422650, 0.022655, 0.054695}}],
    Polygon[{{1.408600, 0.034110, 0.062578},{1.411798, 0.043953, 0.068920},{
      1.422650, 0.042234, 0.068920},{1.422650, 0.031885, 0.062578}}],
    Polygon[{{1.411798, 0.043953, 0.068920},{1.415263, 0.054618, 0.073564},{
      1.422650, 0.053448, 0.073564},{1.422650, 0.042234, 0.068920}}],
    Polygon[{{1.415263, 0.054618, 0.073564},{1.418911, 0.065842, 0.076398},{
      1.422650, 0.065250, 0.076398},{1.422650, 0.053448, 0.073564}}],
    Polygon[{{1.422650, 0.065250, -0.076398},{1.422650, 0.053448, -0.073564},{
      1.430036, 0.054618, -0.073564},{1.426389, 0.065842, -0.076398}}],
    Polygon[{{1.422650, 0.053448, -0.073564},{1.422650, 0.042234, -0.068920},{
      1.433501, 0.043953, -0.068920},{1.430036, 0.054618, -0.073564}}],
    Polygon[{{1.422650, 0.042234, -0.068920},{1.422650, 0.031885, -0.062578},{
      1.436699, 0.034110, -0.062578},{1.433501, 0.043953, -0.068920}}],
    Polygon[{{1.422650, 0.031885, -0.062578},{1.422650, 0.022655, -0.054695},{
      1.439551, 0.025332, -0.054695},{1.436699, 0.034110, -0.062578}}],
    Polygon[{{1.422650, 0.022655, -0.054695},{1.422650, 0.014773, -0.045465},{
      1.441987, 0.017835, -0.045465},{1.439551, 0.025332, -0.054695}}],
    Polygon[{{1.422650, 0.014773, -0.045465},{1.422650, 0.008431, -0.035116},{
      1.443947, 0.011804, -0.035116},{1.441987, 0.017835, -0.045465}}],
    Polygon[{{1.422650, 0.008431, -0.035116},{1.422650, 0.003786, -0.023903},{
      1.445382, 0.007386, -0.023903},{1.443947, 0.011804, -0.035116}}],
    Polygon[{{1.422650, 0.003786, -0.023903},{1.422650, 0.000952, -0.012100},{
      1.446258, 0.004691, -0.012100},{1.445382, 0.007386, -0.023903}}],
    Polygon[{{1.422650, 0.000952, -0.012100},{1.422650, 0.000000, 0.000000},{
      1.446552, 0.003786, 0.000000},{1.446258, 0.004691, -0.012100}}],
    Polygon[{{1.422650, 0.000000, 0.000000},{1.422650, 0.000952, 0.012100},{
      1.446258, 0.004691, 0.012100},{1.446552, 0.003786, 0.000000}}],
    Polygon[{{1.422650, 0.000952, 0.012100},{1.422650, 0.003786, 0.023903},{
      1.445382, 0.007386, 0.023903},{1.446258, 0.004691, 0.012100}}],
    Polygon[{{1.422650, 0.003786, 0.023903},{1.422650, 0.008431, 0.035116},{
      1.443947, 0.011804, 0.035116},{1.445382, 0.007386, 0.023903}}],
    Polygon[{{1.422650, 0.008431, 0.035116},{1.422650, 0.014773, 0.045465},{
      1.441987, 0.017835, 0.045465},{1.443947, 0.011804, 0.035116}}],
    Polygon[{{1.422650, 0.014773, 0.045465},{1.422650, 0.022655, 0.054695},{
      1.439551, 0.025332, 0.054695},{1.441987, 0.017835, 0.045465}}],
    Polygon[{{1.422650, 0.022655, 0.054695},{1.422650, 0.031885, 0.062578},{
      1.436699, 0.034110, 0.062578},{1.439551, 0.025332, 0.054695}}],
    Polygon[{{1.422650, 0.031885, 0.062578},{1.422650, 0.042234, 0.068920},{
      1.433501, 0.043953, 0.068920},{1.436699, 0.034110, 0.062578}}],
    Polygon[{{1.422650, 0.042234, 0.068920},{1.422650, 0.053448, 0.073564},{
      1.430036, 0.054618, 0.073564},{1.433501, 0.043953, 0.068920}}],
    Polygon[{{1.422650, 0.053448, 0.073564},{1.422650, 0.065250, 0.076398},{
      1.426389, 0.065842, 0.076398},{1.430036, 0.054618, 0.073564}}],
    Polygon[{{1.426389, 0.065842, -0.076398},{1.430036, 0.054618, -0.073564},{
      1.436699, 0.058013, -0.073564},{1.429762, 0.067561, -0.076398}}],
    Polygon[{{1.430036, 0.054618, -0.073564},{1.433501, 0.043953, -0.068920},{
      1.443291, 0.048941, -0.068920},{1.436699, 0.058013, -0.073564}}],
    Polygon[{{1.433501, 0.043953, -0.068920},{1.436699, 0.034110, -0.062578},{
      1.449374, 0.040568, -0.062578},{1.443291, 0.048941, -0.068920}}],
    Polygon[{{1.436699, 0.034110, -0.062578},{1.439551, 0.025332, -0.054695},{
      1.454799, 0.033101, -0.054695},{1.449374, 0.040568, -0.062578}}],
    Polygon[{{1.439551, 0.025332, -0.054695},{1.441987, 0.017835, -0.045465},{
      1.459432, 0.026724, -0.045465},{1.454799, 0.033101, -0.054695}}],
    Polygon[{{1.441987, 0.017835, -0.045465},{1.443947, 0.011804, -0.035116},{
      1.463160, 0.021593, -0.035116},{1.459432, 0.026724, -0.045465}}],
    Polygon[{{1.443947, 0.011804, -0.035116},{1.445382, 0.007386, -0.023903},{
      1.465890, 0.017835, -0.023903},{1.463160, 0.021593, -0.035116}}],
    Polygon[{{1.445382, 0.007386, -0.023903},{1.446258, 0.004691, -0.012100},{
      1.467555, 0.015543, -0.012100},{1.465890, 0.017835, -0.023903}}],
    Polygon[{{1.446258, 0.004691, -0.012100},{1.446552, 0.003786, 0.000000},{
      1.468115, 0.014773, 0.000000},{1.467555, 0.015543, -0.012100}}],
    Polygon[{{1.446552, 0.003786, 0.000000},{1.446258, 0.004691, 0.012100},{
      1.467555, 0.015543, 0.012100},{1.468115, 0.014773, 0.000000}}],
    Polygon[{{1.446258, 0.004691, 0.012100},{1.445382, 0.007386, 0.023903},{
      1.465890, 0.017835, 0.023903},{1.467555, 0.015543, 0.012100}}],
    Polygon[{{1.445382, 0.007386, 0.023903},{1.443947, 0.011804, 0.035116},{
      1.463160, 0.021593, 0.035116},{1.465890, 0.017835, 0.023903}}],
    Polygon[{{1.443947, 0.011804, 0.035116},{1.441987, 0.017835, 0.045465},{
      1.459432, 0.026724, 0.045465},{1.463160, 0.021593, 0.035116}}],
    Polygon[{{1.441987, 0.017835, 0.045465},{1.439551, 0.025332, 0.054695},{
      1.454799, 0.033101, 0.054695},{1.459432, 0.026724, 0.045465}}],
    Polygon[{{1.439551, 0.025332, 0.054695},{1.436699, 0.034110, 0.062578},{
      1.449374, 0.040568, 0.062578},{1.454799, 0.033101, 0.054695}}],
    Polygon[{{1.436699, 0.034110, 0.062578},{1.433501, 0.043953, 0.068920},{
      1.443291, 0.048941, 0.068920},{1.449374, 0.040568, 0.062578}}],
    Polygon[{{1.433501, 0.043953, 0.068920},{1.430036, 0.054618, 0.073564},{
      1.436699, 0.058013, 0.073564},{1.443291, 0.048941, 0.068920}}],
    Polygon[{{1.430036, 0.054618, 0.073564},{1.426389, 0.065842, 0.076398},{
      1.429762, 0.067561, 0.076398},{1.436699, 0.058013, 0.073564}}],
    Polygon[{{1.429762, 0.067561, -0.076398},{1.436699, 0.058013, -0.073564},{
      1.441987, 0.063301, -0.073564},{1.432439, 0.070238, -0.076398}}],
    Polygon[{{1.436699, 0.058013, -0.073564},{1.443291, 0.048941, -0.068920},{
      1.451059, 0.056709, -0.068920},{1.441987, 0.063301, -0.073564}}],
    Polygon[{{1.443291, 0.048941, -0.068920},{1.449374, 0.040568, -0.062578},{
      1.459432, 0.050626, -0.062578},{1.451059, 0.056709, -0.068920}}],
    Polygon[{{1.449374, 0.040568, -0.062578},{1.454799, 0.033101, -0.054695},{
      1.466899, 0.045201, -0.054695},{1.459432, 0.050626, -0.062578}}],
    Polygon[{{1.454799, 0.033101, -0.054695},{1.459432, 0.026724, -0.045465},{
      1.473276, 0.040568, -0.045465},{1.466899, 0.045201, -0.054695}}],
    Polygon[{{1.459432, 0.026724, -0.045465},{1.463160, 0.021593, -0.035116},{
      1.478407, 0.036840, -0.035116},{1.473276, 0.040568, -0.045465}}],
    Polygon[{{1.463160, 0.021593, -0.035116},{1.465890, 0.017835, -0.023903},{
      1.482165, 0.034110, -0.023903},{1.478407, 0.036840, -0.035116}}],
    Polygon[{{1.465890, 0.017835, -0.023903},{1.467555, 0.015543, -0.012100},{
      1.484457, 0.032445, -0.012100},{1.482165, 0.034110, -0.023903}}],
    Polygon[{{1.467555, 0.015543, -0.012100},{1.468115, 0.014773, 0.000000},{
      1.485227, 0.031885, 0.000000},{1.484457, 0.032445, -0.012100}}],
    Polygon[{{1.468115, 0.014773, 0.000000},{1.467555, 0.015543, 0.012100},{
      1.484457, 0.032445, 0.012100},{1.485227, 0.031885, 0.000000}}],
    Polygon[{{1.467555, 0.015543, 0.012100},{1.465890, 0.017835, 0.023903},{
      1.482165, 0.034110, 0.023903},{1.484457, 0.032445, 0.012100}}],
    Polygon[{{1.465890, 0.017835, 0.023903},{1.463160, 0.021593, 0.035116},{
      1.478407, 0.036840, 0.035116},{1.482165, 0.034110, 0.023903}}],
    Polygon[{{1.463160, 0.021593, 0.035116},{1.459432, 0.026724, 0.045465},{
      1.473276, 0.040568, 0.045465},{1.478407, 0.036840, 0.035116}}],
    Polygon[{{1.459432, 0.026724, 0.045465},{1.454799, 0.033101, 0.054695},{
      1.466899, 0.045201, 0.054695},{1.473276, 0.040568, 0.045465}}],
    Polygon[{{1.454799, 0.033101, 0.054695},{1.449374, 0.040568, 0.062578},{
      1.459432, 0.050626, 0.062578},{1.466899, 0.045201, 0.054695}}],
    Polygon[{{1.449374, 0.040568, 0.062578},{1.443291, 0.048941, 0.068920},{
      1.451059, 0.056709, 0.068920},{1.459432, 0.050626, 0.062578}}],
    Polygon[{{1.443291, 0.048941, 0.068920},{1.436699, 0.058013, 0.073564},{
      1.441987, 0.063301, 0.073564},{1.451059, 0.056709, 0.068920}}],
    Polygon[{{1.436699, 0.058013, 0.073564},{1.429762, 0.067561, 0.076398},{
      1.432439, 0.070238, 0.076398},{1.441987, 0.063301, 0.073564}}],
    Polygon[{{1.432439, 0.070238, -0.076398},{1.441987, 0.063301, -0.073564},{
      1.445382, 0.069964, -0.073564},{1.434158, 0.073611, -0.076398}}],
    Polygon[{{1.441987, 0.063301, -0.073564},{1.451059, 0.056709, -0.068920},{
      1.456047, 0.066499, -0.068920},{1.445382, 0.069964, -0.073564}}],
    Polygon[{{1.451059, 0.056709, -0.068920},{1.459432, 0.050626, -0.062578},{
      1.465890, 0.063301, -0.062578},{1.456047, 0.066499, -0.068920}}],
    Polygon[{{1.459432, 0.050626, -0.062578},{1.466899, 0.045201, -0.054695},{
      1.474668, 0.060449, -0.054695},{1.465890, 0.063301, -0.062578}}],
    Polygon[{{1.466899, 0.045201, -0.054695},{1.473276, 0.040568, -0.045465},{
      1.482165, 0.058013, -0.045465},{1.474668, 0.060449, -0.054695}}],
    Polygon[{{1.473276, 0.040568, -0.045465},{1.478407, 0.036840, -0.035116},{
      1.488196, 0.056053, -0.035116},{1.482165, 0.058013, -0.045465}}],
    Polygon[{{1.478407, 0.036840, -0.035116},{1.482165, 0.034110, -0.023903},{
      1.492614, 0.054618, -0.023903},{1.488196, 0.056053, -0.035116}}],
    Polygon[{{1.482165, 0.034110, -0.023903},{1.484457, 0.032445, -0.012100},{
      1.495309, 0.053742, -0.012100},{1.492614, 0.054618, -0.023903}}],
    Polygon[{{1.484457, 0.032445, -0.012100},{1.485227, 0.031885, 0.000000},{
      1.496214, 0.053448, 0.000000},{1.495309, 0.053742, -0.012100}}],
    Polygon[{{1.485227, 0.031885, 0.000000},{1.484457, 0.032445, 0.012100},{
      1.495309, 0.053742, 0.012100},{1.496214, 0.053448, 0.000000}}],
    Polygon[{{1.484457, 0.032445, 0.012100},{1.482165, 0.034110, 0.023903},{
      1.492614, 0.054618, 0.023903},{1.495309, 0.053742, 0.012100}}],
    Polygon[{{1.482165, 0.034110, 0.023903},{1.478407, 0.036840, 0.035116},{
      1.488196, 0.056053, 0.035116},{1.492614, 0.054618, 0.023903}}],
    Polygon[{{1.478407, 0.036840, 0.035116},{1.473276, 0.040568, 0.045465},{
      1.482165, 0.058013, 0.045465},{1.488196, 0.056053, 0.035116}}],
    Polygon[{{1.473276, 0.040568, 0.045465},{1.466899, 0.045201, 0.054695},{
      1.474668, 0.060449, 0.054695},{1.482165, 0.058013, 0.045465}}],
    Polygon[{{1.466899, 0.045201, 0.054695},{1.459432, 0.050626, 0.062578},{
      1.465890, 0.063301, 0.062578},{1.474668, 0.060449, 0.054695}}],
    Polygon[{{1.459432, 0.050626, 0.062578},{1.451059, 0.056709, 0.068920},{
      1.456047, 0.066499, 0.068920},{1.465890, 0.063301, 0.062578}}],
    Polygon[{{1.451059, 0.056709, 0.068920},{1.441987, 0.063301, 0.073564},{
      1.445382, 0.069964, 0.073564},{1.456047, 0.066499, 0.068920}}],
    Polygon[{{1.441987, 0.063301, 0.073564},{1.432439, 0.070238, 0.076398},{
      1.434158, 0.073611, 0.076398},{1.445382, 0.069964, 0.073564}}],
    Polygon[{{1.434158, 0.073611, -0.076398},{1.445382, 0.069964, -0.073564},{
      1.446552, 0.077350, -0.073564},{1.434750, 0.077350, -0.076398}}],
    Polygon[{{1.445382, 0.069964, -0.073564},{1.456047, 0.066499, -0.068920},{
      1.457766, 0.077350, -0.068920},{1.446552, 0.077350, -0.073564}}],
    Polygon[{{1.456047, 0.066499, -0.068920},{1.465890, 0.063301, -0.062578},{
      1.468115, 0.077350, -0.062578},{1.457766, 0.077350, -0.068920}}],
    Polygon[{{1.465890, 0.063301, -0.062578},{1.474668, 0.060449, -0.054695},{
      1.477345, 0.077350, -0.054695},{1.468115, 0.077350, -0.062578}}],
    Polygon[{{1.474668, 0.060449, -0.054695},{1.482165, 0.058013, -0.045465},{
      1.485227, 0.077350, -0.045465},{1.477345, 0.077350, -0.054695}}],
    Polygon[{{1.482165, 0.058013, -0.045465},{1.488196, 0.056053, -0.035116},{
      1.491569, 0.077350, -0.035116},{1.485227, 0.077350, -0.045465}}],
    Polygon[{{1.488196, 0.056053, -0.035116},{1.492614, 0.054618, -0.023903},{
      1.496214, 0.077350, -0.023903},{1.491569, 0.077350, -0.035116}}],
    Polygon[{{1.492614, 0.054618, -0.023903},{1.495309, 0.053742, -0.012100},{
      1.499048, 0.077350, -0.012100},{1.496214, 0.077350, -0.023903}}],
    Polygon[{{1.495309, 0.053742, -0.012100},{1.496214, 0.053448, 0.000000},{
      1.500000, 0.077350, 0.000000},{1.499048, 0.077350, -0.012100}}],
    Polygon[{{1.496214, 0.053448, 0.000000},{1.495309, 0.053742, 0.012100},{
      1.499048, 0.077350, 0.012100},{1.500000, 0.077350, 0.000000}}],
    Polygon[{{1.495309, 0.053742, 0.012100},{1.492614, 0.054618, 0.023903},{
      1.496214, 0.077350, 0.023903},{1.499048, 0.077350, 0.012100}}],
    Polygon[{{1.492614, 0.054618, 0.023903},{1.488196, 0.056053, 0.035116},{
      1.491569, 0.077350, 0.035116},{1.496214, 0.077350, 0.023903}}],
    Polygon[{{1.488196, 0.056053, 0.035116},{1.482165, 0.058013, 0.045465},{
      1.485227, 0.077350, 0.045465},{1.491569, 0.077350, 0.035116}}],
    Polygon[{{1.482165, 0.058013, 0.045465},{1.474668, 0.060449, 0.054695},{
      1.477345, 0.077350, 0.054695},{1.485227, 0.077350, 0.045465}}],
    Polygon[{{1.474668, 0.060449, 0.054695},{1.465890, 0.063301, 0.062578},{
      1.468115, 0.077350, 0.062578},{1.477345, 0.077350, 0.054695}}],
    Polygon[{{1.465890, 0.063301, 0.062578},{1.456047, 0.066499, 0.068920},{
      1.457766, 0.077350, 0.068920},{1.468115, 0.077350, 0.062578}}],
    Polygon[{{1.456047, 0.066499, 0.068920},{1.445382, 0.069964, 0.073564},{
      1.446552, 0.077350, 0.073564},{1.457766, 0.077350, 0.068920}}],
    Polygon[{{1.445382, 0.069964, 0.073564},{1.434158, 0.073611, 0.076398},{
      1.434750, 0.077350, 0.076398},{1.446552, 0.077350, 0.073564}}],
    Polygon[{{1.315886, 0.041452, -0.040942},{1.322210, 0.041452, -0.039423},{
      1.321584, 0.045410, -0.039423},{1.315568, 0.043456, -0.040942}}],
    Polygon[{{1.322210, 0.041452, -0.039423},{1.328220, 0.041452, -0.036934},{
      1.327299, 0.047267, -0.036934},{1.321584, 0.045410, -0.039423}}],
    Polygon[{{1.328220, 0.041452, -0.036934},{1.333766, 0.041452, -0.033535},{
      1.332573, 0.048981, -0.033535},{1.327299, 0.047267, -0.036934}}],
    Polygon[{{1.333766, 0.041452, -0.033535},{1.338712, 0.041452, -0.029311},{
      1.337277, 0.050509, -0.029311},{1.332573, 0.048981, -0.033535}}],
    Polygon[{{1.338712, 0.041452, -0.029311},{1.342936, 0.041452, -0.024365},{
      1.341295, 0.051815, -0.024365},{1.337277, 0.050509, -0.029311}}],
    Polygon[{{1.342936, 0.041452, -0.024365},{1.346335, 0.041452, -0.018819},{
      1.344527, 0.052865, -0.018819},{1.341295, 0.051815, -0.024365}}],
    Polygon[{{1.346335, 0.041452, -0.018819},{1.348824, 0.041452, -0.012809},{
      1.346895, 0.053634, -0.012809},{1.344527, 0.052865, -0.018819}}],
    Polygon[{{1.348824, 0.041452, -0.012809},{1.350343, 0.041452, -0.006485},{
      1.348339, 0.054104, -0.006485},{1.346895, 0.053634, -0.012809}}],
    Polygon[{{1.350343, 0.041452, -0.006485},{1.350853, 0.041452, 0.000000},{
      1.348824, 0.054261, 0.000000},{1.348339, 0.054104, -0.006485}}],
    Polygon[{{1.350853, 0.041452, 0.000000},{1.350343, 0.041452, 0.006485},{
      1.348339, 0.054104, 0.006485},{1.348824, 0.054261, 0.000000}}],
    Polygon[{{1.350343, 0.041452, 0.006485},{1.348824, 0.041452, 0.012809},{
      1.346895, 0.053634, 0.012809},{1.348339, 0.054104, 0.006485}}],
    Polygon[{{1.348824, 0.041452, 0.012809},{1.346335, 0.041452, 0.018819},{
      1.344527, 0.052865, 0.018819},{1.346895, 0.053634, 0.012809}}],
    Polygon[{{1.346335, 0.041452, 0.018819},{1.342936, 0.041452, 0.024365},{
      1.341295, 0.051815, 0.024365},{1.344527, 0.052865, 0.018819}}],
    Polygon[{{1.342936, 0.041452, 0.024365},{1.338712, 0.041452, 0.029311},{
      1.337277, 0.050509, 0.029311},{1.341295, 0.051815, 0.024365}}],
    Polygon[{{1.338712, 0.041452, 0.029311},{1.333766, 0.041452, 0.033535},{
      1.332573, 0.048981, 0.033535},{1.337277, 0.050509, 0.029311}}],
    Polygon[{{1.333766, 0.041452, 0.033535},{1.328220, 0.041452, 0.036934},{
      1.327299, 0.047267, 0.036934},{1.332573, 0.048981, 0.033535}}],
    Polygon[{{1.328220, 0.041452, 0.036934},{1.322210, 0.041452, 0.039423},{
      1.321584, 0.045410, 0.039423},{1.327299, 0.047267, 0.036934}}],
    Polygon[{{1.322210, 0.041452, 0.039423},{1.315886, 0.041452, 0.040942},{
      1.315568, 0.043456, 0.040942},{1.321584, 0.045410, 0.039423}}],
    Polygon[{{1.315568, 0.043456, -0.040942},{1.321584, 0.045410, -0.039423},{
      1.319764, 0.048981, -0.039423},{1.314647, 0.045263, -0.040942}}],
    Polygon[{{1.321584, 0.045410, -0.039423},{1.327299, 0.047267, -0.036934},{
      1.324626, 0.052513, -0.036934},{1.319764, 0.048981, -0.039423}}],
    Polygon[{{1.327299, 0.047267, -0.036934},{1.332573, 0.048981, -0.033535},{
      1.329113, 0.055773, -0.033535},{1.324626, 0.052513, -0.036934}}],
    Polygon[{{1.332573, 0.048981, -0.033535},{1.337277, 0.050509, -0.029311},{
      1.333114, 0.058680, -0.029311},{1.329113, 0.055773, -0.033535}}],
    Polygon[{{1.337277, 0.050509, -0.029311},{1.341295, 0.051815, -0.024365},{
      1.336532, 0.061163, -0.024365},{1.333114, 0.058680, -0.029311}}],
    Polygon[{{1.341295, 0.051815, -0.024365},{1.344527, 0.052865, -0.018819},{
      1.339281, 0.063161, -0.018819},{1.336532, 0.061163, -0.024365}}],
    Polygon[{{1.344527, 0.052865, -0.018819},{1.346895, 0.053634, -0.012809},{
      1.341295, 0.064624, -0.012809},{1.339281, 0.063161, -0.018819}}],
    Polygon[{{1.346895, 0.053634, -0.012809},{1.348339, 0.054104, -0.006485},{
      1.342523, 0.065517, -0.006485},{1.341295, 0.064624, -0.012809}}],
    Polygon[{{1.348339, 0.054104, -0.006485},{1.348824, 0.054261, 0.000000},{
      1.342936, 0.065817, 0.000000},{1.342523, 0.065517, -0.006485}}],
    Polygon[{{1.348824, 0.054261, 0.000000},{1.348339, 0.054104, 0.006485},{
      1.342523, 0.065517, 0.006485},{1.342936, 0.065817, 0.000000}}],
    Polygon[{{1.348339, 0.054104, 0.006485},{1.346895, 0.053634, 0.012809},{
      1.341295, 0.064624, 0.012809},{1.342523, 0.065517, 0.006485}}],
    Polygon[{{1.346895, 0.053634, 0.012809},{1.344527, 0.052865, 0.018819},{
      1.339281, 0.063161, 0.018819},{1.341295, 0.064624, 0.012809}}],
    Polygon[{{1.344527, 0.052865, 0.018819},{1.341295, 0.051815, 0.024365},{
      1.336532, 0.061163, 0.024365},{1.339281, 0.063161, 0.018819}}],
    Polygon[{{1.341295, 0.051815, 0.024365},{1.337277, 0.050509, 0.029311},{
      1.333114, 0.058680, 0.029311},{1.336532, 0.061163, 0.024365}}],
    Polygon[{{1.337277, 0.050509, 0.029311},{1.332573, 0.048981, 0.033535},{
      1.329113, 0.055773, 0.033535},{1.333114, 0.058680, 0.029311}}],
    Polygon[{{1.332573, 0.048981, 0.033535},{1.327299, 0.047267, 0.036934},{
      1.324626, 0.052513, 0.036934},{1.329113, 0.055773, 0.033535}}],
    Polygon[{{1.327299, 0.047267, 0.036934},{1.321584, 0.045410, 0.039423},{
      1.319764, 0.048981, 0.039423},{1.324626, 0.052513, 0.036934}}],
    Polygon[{{1.321584, 0.045410, 0.039423},{1.315568, 0.043456, 0.040942},{
      1.314647, 0.045263, 0.040942},{1.319764, 0.048981, 0.039423}}],
    Polygon[{{1.314647, 0.045263, -0.040942},{1.319764, 0.048981, -0.039423},{
      1.316930, 0.051815, -0.039423},{1.313213, 0.046698, -0.040942}}],
    Polygon[{{1.319764, 0.048981, -0.039423},{1.324626, 0.052513, -0.036934},{
      1.320462, 0.056677, -0.036934},{1.316930, 0.051815, -0.039423}}],
    Polygon[{{1.324626, 0.052513, -0.036934},{1.329113, 0.055773, -0.033535},{
      1.323722, 0.061163, -0.033535},{1.320462, 0.056677, -0.036934}}],
    Polygon[{{1.329113, 0.055773, -0.033535},{1.333114, 0.058680, -0.029311},{
      1.326630, 0.065165, -0.029311},{1.323722, 0.061163, -0.033535}}],
    Polygon[{{1.333114, 0.058680, -0.029311},{1.336532, 0.061163, -0.024365},{
      1.329113, 0.068582, -0.024365},{1.326630, 0.065165, -0.029311}}],
    Polygon[{{1.336532, 0.061163, -0.024365},{1.339281, 0.063161, -0.018819},{
      1.331110, 0.071332, -0.018819},{1.329113, 0.068582, -0.024365}}],
    Polygon[{{1.339281, 0.063161, -0.018819},{1.341295, 0.064624, -0.012809},{
      1.332573, 0.073346, -0.012809},{1.331110, 0.071332, -0.018819}}],
    Polygon[{{1.341295, 0.064624, -0.012809},{1.342523, 0.065517, -0.006485},{
      1.333466, 0.074574, -0.006485},{1.332573, 0.073346, -0.012809}}],
    Polygon[{{1.342523, 0.065517, -0.006485},{1.342936, 0.065817, 0.000000},{
      1.333766, 0.074987, 0.000000},{1.333466, 0.074574, -0.006485}}],
    Polygon[{{1.342936, 0.065817, 0.000000},{1.342523, 0.065517, 0.006485},{
      1.333466, 0.074574, 0.006485},{1.333766, 0.074987, 0.000000}}],
    Polygon[{{1.342523, 0.065517, 0.006485},{1.341295, 0.064624, 0.012809},{
      1.332573, 0.073346, 0.012809},{1.333466, 0.074574, 0.006485}}],
    Polygon[{{1.341295, 0.064624, 0.012809},{1.339281, 0.063161, 0.018819},{
      1.331110, 0.071332, 0.018819},{1.332573, 0.073346, 0.012809}}],
    Polygon[{{1.339281, 0.063161, 0.018819},{1.336532, 0.061163, 0.024365},{
      1.329113, 0.068582, 0.024365},{1.331110, 0.071332, 0.018819}}],
    Polygon[{{1.336532, 0.061163, 0.024365},{1.333114, 0.058680, 0.029311},{
      1.326630, 0.065165, 0.029311},{1.329113, 0.068582, 0.024365}}],
    Polygon[{{1.333114, 0.058680, 0.029311},{1.329113, 0.055773, 0.033535},{
      1.323722, 0.061163, 0.033535},{1.326630, 0.065165, 0.029311}}],
    Polygon[{{1.329113, 0.055773, 0.033535},{1.324626, 0.052513, 0.036934},{
      1.320462, 0.056677, 0.036934},{1.323722, 0.061163, 0.033535}}],
    Polygon[{{1.324626, 0.052513, 0.036934},{1.319764, 0.048981, 0.039423},{
      1.316930, 0.051815, 0.039423},{1.320462, 0.056677, 0.036934}}],
    Polygon[{{1.319764, 0.048981, 0.039423},{1.314647, 0.045263, 0.040942},{
      1.313213, 0.046698, 0.040942},{1.316930, 0.051815, 0.039423}}],
    Polygon[{{1.313213, 0.046698, -0.040942},{1.316930, 0.051815, -0.039423},{
      1.313359, 0.053634, -0.039423},{1.311405, 0.047619, -0.040942}}],
    Polygon[{{1.316930, 0.051815, -0.039423},{1.320462, 0.056677, -0.036934},{
      1.315216, 0.059350, -0.036934},{1.313359, 0.053634, -0.039423}}],
    Polygon[{{1.320462, 0.056677, -0.036934},{1.323722, 0.061163, -0.033535},{
      1.316930, 0.064624, -0.033535},{1.315216, 0.059350, -0.036934}}],
    Polygon[{{1.323722, 0.061163, -0.033535},{1.326630, 0.065165, -0.029311},{
      1.318459, 0.069328, -0.029311},{1.316930, 0.064624, -0.033535}}],
    Polygon[{{1.326630, 0.065165, -0.029311},{1.329113, 0.068582, -0.024365},{
      1.319764, 0.073346, -0.024365},{1.318459, 0.069328, -0.029311}}],
    Polygon[{{1.329113, 0.068582, -0.024365},{1.331110, 0.071332, -0.018819},{
      1.320814, 0.076578, -0.018819},{1.319764, 0.073346, -0.024365}}],
    Polygon[{{1.331110, 0.071332, -0.018819},{1.332573, 0.073346, -0.012809},{
      1.321584, 0.078945, -0.012809},{1.320814, 0.076578, -0.018819}}],
    Polygon[{{1.332573, 0.073346, -0.012809},{1.333466, 0.074574, -0.006485},{
      1.322053, 0.080390, -0.006485},{1.321584, 0.078945, -0.012809}}],
    Polygon[{{1.333466, 0.074574, -0.006485},{1.333766, 0.074987, 0.000000},{
      1.322210, 0.080875, 0.000000},{1.322053, 0.080390, -0.006485}}],
    Polygon[{{1.333766, 0.074987, 0.000000},{1.333466, 0.074574, 0.006485},{
      1.322053, 0.080390, 0.006485},{1.322210, 0.080875, 0.000000}}],
    Polygon[{{1.333466, 0.074574, 0.006485},{1.332573, 0.073346, 0.012809},{
      1.321584, 0.078945, 0.012809},{1.322053, 0.080390, 0.006485}}],
    Polygon[{{1.332573, 0.073346, 0.012809},{1.331110, 0.071332, 0.018819},{
      1.320814, 0.076578, 0.018819},{1.321584, 0.078945, 0.012809}}],
    Polygon[{{1.331110, 0.071332, 0.018819},{1.329113, 0.068582, 0.024365},{
      1.319764, 0.073346, 0.024365},{1.320814, 0.076578, 0.018819}}],
    Polygon[{{1.329113, 0.068582, 0.024365},{1.326630, 0.065165, 0.029311},{
      1.318459, 0.069328, 0.029311},{1.319764, 0.073346, 0.024365}}],
    Polygon[{{1.326630, 0.065165, 0.029311},{1.323722, 0.061163, 0.033535},{
      1.316930, 0.064624, 0.033535},{1.318459, 0.069328, 0.029311}}],
    Polygon[{{1.323722, 0.061163, 0.033535},{1.320462, 0.056677, 0.036934},{
      1.315216, 0.059350, 0.036934},{1.316930, 0.064624, 0.033535}}],
    Polygon[{{1.320462, 0.056677, 0.036934},{1.316930, 0.051815, 0.039423},{
      1.313359, 0.053634, 0.039423},{1.315216, 0.059350, 0.036934}}],
    Polygon[{{1.316930, 0.051815, 0.039423},{1.313213, 0.046698, 0.040942},{
      1.311405, 0.047619, 0.040942},{1.313359, 0.053634, 0.039423}}],
    Polygon[{{1.311405, 0.047619, -0.040942},{1.313359, 0.053634, -0.039423},{
      1.309401, 0.054261, -0.039423},{1.309401, 0.047936, -0.040942}}],
    Polygon[{{1.313359, 0.053634, -0.039423},{1.315216, 0.059350, -0.036934},{
      1.309401, 0.060271, -0.036934},{1.309401, 0.054261, -0.039423}}],
    Polygon[{{1.315216, 0.059350, -0.036934},{1.316930, 0.064624, -0.033535},{
      1.309401, 0.065817, -0.033535},{1.309401, 0.060271, -0.036934}}],
    Polygon[{{1.316930, 0.064624, -0.033535},{1.318459, 0.069328, -0.029311},{
      1.309401, 0.070763, -0.029311},{1.309401, 0.065817, -0.033535}}],
    Polygon[{{1.318459, 0.069328, -0.029311},{1.319764, 0.073346, -0.024365},{
      1.309401, 0.074987, -0.024365},{1.309401, 0.070763, -0.029311}}],
    Polygon[{{1.319764, 0.073346, -0.024365},{1.320814, 0.076578, -0.018819},{
      1.309401, 0.078386, -0.018819},{1.309401, 0.074987, -0.024365}}],
    Polygon[{{1.320814, 0.076578, -0.018819},{1.321584, 0.078945, -0.012809},{
      1.309401, 0.080875, -0.012809},{1.309401, 0.078386, -0.018819}}],
    Polygon[{{1.321584, 0.078945, -0.012809},{1.322053, 0.080390, -0.006485},{
      1.309401, 0.082393, -0.006485},{1.309401, 0.080875, -0.012809}}],
    Polygon[{{1.322053, 0.080390, -0.006485},{1.322210, 0.080875, 0.000000},{
      1.309401, 0.082904, 0.000000},{1.309401, 0.082393, -0.006485}}],
    Polygon[{{1.322210, 0.080875, 0.000000},{1.322053, 0.080390, 0.006485},{
      1.309401, 0.082393, 0.006485},{1.309401, 0.082904, 0.000000}}],
    Polygon[{{1.322053, 0.080390, 0.006485},{1.321584, 0.078945, 0.012809},{
      1.309401, 0.080875, 0.012809},{1.309401, 0.082393, 0.006485}}],
    Polygon[{{1.321584, 0.078945, 0.012809},{1.320814, 0.076578, 0.018819},{
      1.309401, 0.078386, 0.018819},{1.309401, 0.080875, 0.012809}}],
    Polygon[{{1.320814, 0.076578, 0.018819},{1.319764, 0.073346, 0.024365},{
      1.309401, 0.074987, 0.024365},{1.309401, 0.078386, 0.018819}}],
    Polygon[{{1.319764, 0.073346, 0.024365},{1.318459, 0.069328, 0.029311},{
      1.309401, 0.070763, 0.029311},{1.309401, 0.074987, 0.024365}}],
    Polygon[{{1.318459, 0.069328, 0.029311},{1.316930, 0.064624, 0.033535},{
      1.309401, 0.065817, 0.033535},{1.309401, 0.070763, 0.029311}}],
    Polygon[{{1.316930, 0.064624, 0.033535},{1.315216, 0.059350, 0.036934},{
      1.309401, 0.060271, 0.036934},{1.309401, 0.065817, 0.033535}}],
    Polygon[{{1.315216, 0.059350, 0.036934},{1.313359, 0.053634, 0.039423},{
      1.309401, 0.054261, 0.039423},{1.309401, 0.060271, 0.036934}}],
    Polygon[{{1.313359, 0.053634, 0.039423},{1.311405, 0.047619, 0.040942},{
      1.309401, 0.047936, 0.040942},{1.309401, 0.054261, 0.039423}}],
    Polygon[{{1.309401, 0.047936, -0.040942},{1.309401, 0.054261, -0.039423},{
      1.305443, 0.053634, -0.039423},{1.307397, 0.047619, -0.040942}}],
    Polygon[{{1.309401, 0.054261, -0.039423},{1.309401, 0.060271, -0.036934},{
      1.303586, 0.059350, -0.036934},{1.305443, 0.053634, -0.039423}}],
    Polygon[{{1.309401, 0.060271, -0.036934},{1.309401, 0.065817, -0.033535},{
      1.301872, 0.064624, -0.033535},{1.303586, 0.059350, -0.036934}}],
    Polygon[{{1.309401, 0.065817, -0.033535},{1.309401, 0.070763, -0.029311},{
      1.300344, 0.069328, -0.029311},{1.301872, 0.064624, -0.033535}}],
    Polygon[{{1.309401, 0.070763, -0.029311},{1.309401, 0.074987, -0.024365},{
      1.299038, 0.073346, -0.024365},{1.300344, 0.069328, -0.029311}}],
    Polygon[{{1.309401, 0.074987, -0.024365},{1.309401, 0.078386, -0.018819},{
      1.297988, 0.076578, -0.018819},{1.299038, 0.073346, -0.024365}}],
    Polygon[{{1.309401, 0.078386, -0.018819},{1.309401, 0.080875, -0.012809},{
      1.297219, 0.078945, -0.012809},{1.297988, 0.076578, -0.018819}}],
    Polygon[{{1.309401, 0.080875, -0.012809},{1.309401, 0.082393, -0.006485},{
      1.296749, 0.080390, -0.006485},{1.297219, 0.078945, -0.012809}}],
    Polygon[{{1.309401, 0.082393, -0.006485},{1.309401, 0.082904, 0.000000},{
      1.296592, 0.080875, 0.000000},{1.296749, 0.080390, -0.006485}}],
    Polygon[{{1.309401, 0.082904, 0.000000},{1.309401, 0.082393, 0.006485},{
      1.296749, 0.080390, 0.006485},{1.296592, 0.080875, 0.000000}}],
    Polygon[{{1.309401, 0.082393, 0.006485},{1.309401, 0.080875, 0.012809},{
      1.297219, 0.078945, 0.012809},{1.296749, 0.080390, 0.006485}}],
    Polygon[{{1.309401, 0.080875, 0.012809},{1.309401, 0.078386, 0.018819},{
      1.297988, 0.076578, 0.018819},{1.297219, 0.078945, 0.012809}}],
    Polygon[{{1.309401, 0.078386, 0.018819},{1.309401, 0.074987, 0.024365},{
      1.299038, 0.073346, 0.024365},{1.297988, 0.076578, 0.018819}}],
    Polygon[{{1.309401, 0.074987, 0.024365},{1.309401, 0.070763, 0.029311},{
      1.300344, 0.069328, 0.029311},{1.299038, 0.073346, 0.024365}}],
    Polygon[{{1.309401, 0.070763, 0.029311},{1.309401, 0.065817, 0.033535},{
      1.301872, 0.064624, 0.033535},{1.300344, 0.069328, 0.029311}}],
    Polygon[{{1.309401, 0.065817, 0.033535},{1.309401, 0.060271, 0.036934},{
      1.303586, 0.059350, 0.036934},{1.301872, 0.064624, 0.033535}}],
    Polygon[{{1.309401, 0.060271, 0.036934},{1.309401, 0.054261, 0.039423},{
      1.305443, 0.053634, 0.039423},{1.303586, 0.059350, 0.036934}}],
    Polygon[{{1.309401, 0.054261, 0.039423},{1.309401, 0.047936, 0.040942},{
      1.307397, 0.047619, 0.040942},{1.305443, 0.053634, 0.039423}}],
    Polygon[{{1.307397, 0.047619, -0.040942},{1.305443, 0.053634, -0.039423},{
      1.301872, 0.051815, -0.039423},{1.305590, 0.046698, -0.040942}}],
    Polygon[{{1.305443, 0.053634, -0.039423},{1.303586, 0.059350, -0.036934},{
      1.298340, 0.056677, -0.036934},{1.301872, 0.051815, -0.039423}}],
    Polygon[{{1.303586, 0.059350, -0.036934},{1.301872, 0.064624, -0.033535},{
      1.295080, 0.061163, -0.033535},{1.298340, 0.056677, -0.036934}}],
    Polygon[{{1.301872, 0.064624, -0.033535},{1.300344, 0.069328, -0.029311},{
      1.292173, 0.065165, -0.029311},{1.295080, 0.061163, -0.033535}}],
    Polygon[{{1.300344, 0.069328, -0.029311},{1.299038, 0.073346, -0.024365},{
      1.289690, 0.068582, -0.024365},{1.292173, 0.065165, -0.029311}}],
    Polygon[{{1.299038, 0.073346, -0.024365},{1.297988, 0.076578, -0.018819},{
      1.287692, 0.071332, -0.018819},{1.289690, 0.068582, -0.024365}}],
    Polygon[{{1.297988, 0.076578, -0.018819},{1.297219, 0.078945, -0.012809},{
      1.286229, 0.073346, -0.012809},{1.287692, 0.071332, -0.018819}}],
    Polygon[{{1.297219, 0.078945, -0.012809},{1.296749, 0.080390, -0.006485},{
      1.285336, 0.074574, -0.006485},{1.286229, 0.073346, -0.012809}}],
    Polygon[{{1.296749, 0.080390, -0.006485},{1.296592, 0.080875, 0.000000},{
      1.285036, 0.074987, 0.000000},{1.285336, 0.074574, -0.006485}}],
    Polygon[{{1.296592, 0.080875, 0.000000},{1.296749, 0.080390, 0.006485},{
      1.285336, 0.074574, 0.006485},{1.285036, 0.074987, 0.000000}}],
    Polygon[{{1.296749, 0.080390, 0.006485},{1.297219, 0.078945, 0.012809},{
      1.286229, 0.073346, 0.012809},{1.285336, 0.074574, 0.006485}}],
    Polygon[{{1.297219, 0.078945, 0.012809},{1.297988, 0.076578, 0.018819},{
      1.287692, 0.071332, 0.018819},{1.286229, 0.073346, 0.012809}}],
    Polygon[{{1.297988, 0.076578, 0.018819},{1.299038, 0.073346, 0.024365},{
      1.289690, 0.068582, 0.024365},{1.287692, 0.071332, 0.018819}}],
    Polygon[{{1.299038, 0.073346, 0.024365},{1.300344, 0.069328, 0.029311},{
      1.292173, 0.065165, 0.029311},{1.289690, 0.068582, 0.024365}}],
    Polygon[{{1.300344, 0.069328, 0.029311},{1.301872, 0.064624, 0.033535},{
      1.295080, 0.061163, 0.033535},{1.292173, 0.065165, 0.029311}}],
    Polygon[{{1.301872, 0.064624, 0.033535},{1.303586, 0.059350, 0.036934},{
      1.298340, 0.056677, 0.036934},{1.295080, 0.061163, 0.033535}}],
    Polygon[{{1.303586, 0.059350, 0.036934},{1.305443, 0.053634, 0.039423},{
      1.301872, 0.051815, 0.039423},{1.298340, 0.056677, 0.036934}}],
    Polygon[{{1.305443, 0.053634, 0.039423},{1.307397, 0.047619, 0.040942},{
      1.305590, 0.046698, 0.040942},{1.301872, 0.051815, 0.039423}}],
    Polygon[{{1.305590, 0.046698, -0.040942},{1.301872, 0.051815, -0.039423},{
      1.299038, 0.048981, -0.039423},{1.304155, 0.045263, -0.040942}}],
    Polygon[{{1.301872, 0.051815, -0.039423},{1.298340, 0.056677, -0.036934},{
      1.294176, 0.052513, -0.036934},{1.299038, 0.048981, -0.039423}}],
    Polygon[{{1.298340, 0.056677, -0.036934},{1.295080, 0.061163, -0.033535},{
      1.289690, 0.055773, -0.033535},{1.294176, 0.052513, -0.036934}}],
    Polygon[{{1.295080, 0.061163, -0.033535},{1.292173, 0.065165, -0.029311},{
      1.285688, 0.058680, -0.029311},{1.289690, 0.055773, -0.033535}}],
    Polygon[{{1.292173, 0.065165, -0.029311},{1.289690, 0.068582, -0.024365},{
      1.282270, 0.061163, -0.024365},{1.285688, 0.058680, -0.029311}}],
    Polygon[{{1.289690, 0.068582, -0.024365},{1.287692, 0.071332, -0.018819},{
      1.279521, 0.063161, -0.018819},{1.282270, 0.061163, -0.024365}}],
    Polygon[{{1.287692, 0.071332, -0.018819},{1.286229, 0.073346, -0.012809},{
      1.277507, 0.064624, -0.012809},{1.279521, 0.063161, -0.018819}}],
    Polygon[{{1.286229, 0.073346, -0.012809},{1.285336, 0.074574, -0.006485},{
      1.276279, 0.065517, -0.006485},{1.277507, 0.064624, -0.012809}}],
    Polygon[{{1.285336, 0.074574, -0.006485},{1.285036, 0.074987, 0.000000},{
      1.275866, 0.065817, 0.000000},{1.276279, 0.065517, -0.006485}}],
    Polygon[{{1.285036, 0.074987, 0.000000},{1.285336, 0.074574, 0.006485},{
      1.276279, 0.065517, 0.006485},{1.275866, 0.065817, 0.000000}}],
    Polygon[{{1.285336, 0.074574, 0.006485},{1.286229, 0.073346, 0.012809},{
      1.277507, 0.064624, 0.012809},{1.276279, 0.065517, 0.006485}}],
    Polygon[{{1.286229, 0.073346, 0.012809},{1.287692, 0.071332, 0.018819},{
      1.279521, 0.063161, 0.018819},{1.277507, 0.064624, 0.012809}}],
    Polygon[{{1.287692, 0.071332, 0.018819},{1.289690, 0.068582, 0.024365},{
      1.282270, 0.061163, 0.024365},{1.279521, 0.063161, 0.018819}}],
    Polygon[{{1.289690, 0.068582, 0.024365},{1.292173, 0.065165, 0.029311},{
      1.285688, 0.058680, 0.029311},{1.282270, 0.061163, 0.024365}}],
    Polygon[{{1.292173, 0.065165, 0.029311},{1.295080, 0.061163, 0.033535},{
      1.289690, 0.055773, 0.033535},{1.285688, 0.058680, 0.029311}}],
    Polygon[{{1.295080, 0.061163, 0.033535},{1.298340, 0.056677, 0.036934},{
      1.294176, 0.052513, 0.036934},{1.289690, 0.055773, 0.033535}}],
    Polygon[{{1.298340, 0.056677, 0.036934},{1.301872, 0.051815, 0.039423},{
      1.299038, 0.048981, 0.039423},{1.294176, 0.052513, 0.036934}}],
    Polygon[{{1.301872, 0.051815, 0.039423},{1.305590, 0.046698, 0.040942},{
      1.304155, 0.045263, 0.040942},{1.299038, 0.048981, 0.039423}}],
    Polygon[{{1.304155, 0.045263, -0.040942},{1.299038, 0.048981, -0.039423},{
      1.297219, 0.045410, -0.039423},{1.303234, 0.043456, -0.040942}}],
    Polygon[{{1.299038, 0.048981, -0.039423},{1.294176, 0.052513, -0.036934},{
      1.291503, 0.047267, -0.036934},{1.297219, 0.045410, -0.039423}}],
    Polygon[{{1.294176, 0.052513, -0.036934},{1.289690, 0.055773, -0.033535},{
      1.286229, 0.048981, -0.033535},{1.291503, 0.047267, -0.036934}}],
    Polygon[{{1.289690, 0.055773, -0.033535},{1.285688, 0.058680, -0.029311},{
      1.281525, 0.050509, -0.029311},{1.286229, 0.048981, -0.033535}}],
    Polygon[{{1.285688, 0.058680, -0.029311},{1.282270, 0.061163, -0.024365},{
      1.277507, 0.051815, -0.024365},{1.281525, 0.050509, -0.029311}}],
    Polygon[{{1.282270, 0.061163, -0.024365},{1.279521, 0.063161, -0.018819},{
      1.274275, 0.052865, -0.018819},{1.277507, 0.051815, -0.024365}}],
    Polygon[{{1.279521, 0.063161, -0.018819},{1.277507, 0.064624, -0.012809},{
      1.271907, 0.053634, -0.012809},{1.274275, 0.052865, -0.018819}}],
    Polygon[{{1.277507, 0.064624, -0.012809},{1.276279, 0.065517, -0.006485},{
      1.270463, 0.054104, -0.006485},{1.271907, 0.053634, -0.012809}}],
    Polygon[{{1.276279, 0.065517, -0.006485},{1.275866, 0.065817, 0.000000},{
      1.269978, 0.054261, 0.000000},{1.270463, 0.054104, -0.006485}}],
    Polygon[{{1.275866, 0.065817, 0.000000},{1.276279, 0.065517, 0.006485},{
      1.270463, 0.054104, 0.006485},{1.269978, 0.054261, 0.000000}}],
    Polygon[{{1.276279, 0.065517, 0.006485},{1.277507, 0.064624, 0.012809},{
      1.271907, 0.053634, 0.012809},{1.270463, 0.054104, 0.006485}}],
    Polygon[{{1.277507, 0.064624, 0.012809},{1.279521, 0.063161, 0.018819},{
      1.274275, 0.052865, 0.018819},{1.271907, 0.053634, 0.012809}}],
    Polygon[{{1.279521, 0.063161, 0.018819},{1.282270, 0.061163, 0.024365},{
      1.277507, 0.051815, 0.024365},{1.274275, 0.052865, 0.018819}}],
    Polygon[{{1.282270, 0.061163, 0.024365},{1.285688, 0.058680, 0.029311},{
      1.281525, 0.050509, 0.029311},{1.277507, 0.051815, 0.024365}}],
    Polygon[{{1.285688, 0.058680, 0.029311},{1.289690, 0.055773, 0.033535},{
      1.286229, 0.048981, 0.033535},{1.281525, 0.050509, 0.029311}}],
    Polygon[{{1.289690, 0.055773, 0.033535},{1.294176, 0.052513, 0.036934},{
      1.291503, 0.047267, 0.036934},{1.286229, 0.048981, 0.033535}}],
    Polygon[{{1.294176, 0.052513, 0.036934},{1.299038, 0.048981, 0.039423},{
      1.297219, 0.045410, 0.039423},{1.291503, 0.047267, 0.036934}}],
    Polygon[{{1.299038, 0.048981, 0.039423},{1.304155, 0.045263, 0.040942},{
      1.303234, 0.043456, 0.040942},{1.297219, 0.045410, 0.039423}}],
    Polygon[{{1.303234, 0.043456, -0.040942},{1.297219, 0.045410, -0.039423},{
      1.296592, 0.041452, -0.039423},{1.302917, 0.041452, -0.040942}}],
    Polygon[{{1.297219, 0.045410, -0.039423},{1.291503, 0.047267, -0.036934},{
      1.290582, 0.041452, -0.036934},{1.296592, 0.041452, -0.039423}}],
    Polygon[{{1.291503, 0.047267, -0.036934},{1.286229, 0.048981, -0.033535},{
      1.285036, 0.041452, -0.033535},{1.290582, 0.041452, -0.036934}}],
    Polygon[{{1.286229, 0.048981, -0.033535},{1.281525, 0.050509, -0.029311},{
      1.280090, 0.041452, -0.029311},{1.285036, 0.041452, -0.033535}}],
    Polygon[{{1.281525, 0.050509, -0.029311},{1.277507, 0.051815, -0.024365},{
      1.275866, 0.041452, -0.024365},{1.280090, 0.041452, -0.029311}}],
    Polygon[{{1.277507, 0.051815, -0.024365},{1.274275, 0.052865, -0.018819},{
      1.272467, 0.041452, -0.018819},{1.275866, 0.041452, -0.024365}}],
    Polygon[{{1.274275, 0.052865, -0.018819},{1.271907, 0.053634, -0.012809},{
      1.269978, 0.041452, -0.012809},{1.272467, 0.041452, -0.018819}}],
    Polygon[{{1.271907, 0.053634, -0.012809},{1.270463, 0.054104, -0.006485},{
      1.268460, 0.041452, -0.006485},{1.269978, 0.041452, -0.012809}}],
    Polygon[{{1.270463, 0.054104, -0.006485},{1.269978, 0.054261, 0.000000},{
      1.267949, 0.041452, 0.000000},{1.268460, 0.041452, -0.006485}}],
    Polygon[{{1.269978, 0.054261, 0.000000},{1.270463, 0.054104, 0.006485},{
      1.268460, 0.041452, 0.006485},{1.267949, 0.041452, 0.000000}}],
    Polygon[{{1.270463, 0.054104, 0.006485},{1.271907, 0.053634, 0.012809},{
      1.269978, 0.041452, 0.012809},{1.268460, 0.041452, 0.006485}}],
    Polygon[{{1.271907, 0.053634, 0.012809},{1.274275, 0.052865, 0.018819},{
      1.272467, 0.041452, 0.018819},{1.269978, 0.041452, 0.012809}}],
    Polygon[{{1.274275, 0.052865, 0.018819},{1.277507, 0.051815, 0.024365},{
      1.275866, 0.041452, 0.024365},{1.272467, 0.041452, 0.018819}}],
    Polygon[{{1.277507, 0.051815, 0.024365},{1.281525, 0.050509, 0.029311},{
      1.280090, 0.041452, 0.029311},{1.275866, 0.041452, 0.024365}}],
    Polygon[{{1.281525, 0.050509, 0.029311},{1.286229, 0.048981, 0.033535},{
      1.285036, 0.041452, 0.033535},{1.280090, 0.041452, 0.029311}}],
    Polygon[{{1.286229, 0.048981, 0.033535},{1.291503, 0.047267, 0.036934},{
      1.290582, 0.041452, 0.036934},{1.285036, 0.041452, 0.033535}}],
    Polygon[{{1.291503, 0.047267, 0.036934},{1.297219, 0.045410, 0.039423},{
      1.296592, 0.041452, 0.039423},{1.290582, 0.041452, 0.036934}}],
    Polygon[{{1.297219, 0.045410, 0.039423},{1.303234, 0.043456, 0.040942},{
      1.302917, 0.041452, 0.040942},{1.296592, 0.041452, 0.039423}}],
    Polygon[{{1.302917, 0.041452, -0.040942},{1.296592, 0.041452, -0.039423},{
      1.297219, 0.037494, -0.039423},{1.303234, 0.039448, -0.040942}}],
    Polygon[{{1.296592, 0.041452, -0.039423},{1.290582, 0.041452, -0.036934},{
      1.291503, 0.035637, -0.036934},{1.297219, 0.037494, -0.039423}}],
    Polygon[{{1.290582, 0.041452, -0.036934},{1.285036, 0.041452, -0.033535},{
      1.286229, 0.033923, -0.033535},{1.291503, 0.035637, -0.036934}}],
    Polygon[{{1.285036, 0.041452, -0.033535},{1.280090, 0.041452, -0.029311},{
      1.281525, 0.032394, -0.029311},{1.286229, 0.033923, -0.033535}}],
    Polygon[{{1.280090, 0.041452, -0.029311},{1.275866, 0.041452, -0.024365},{
      1.277507, 0.031089, -0.024365},{1.281525, 0.032394, -0.029311}}],
    Polygon[{{1.275866, 0.041452, -0.024365},{1.272467, 0.041452, -0.018819},{
      1.274275, 0.030039, -0.018819},{1.277507, 0.031089, -0.024365}}],
    Polygon[{{1.272467, 0.041452, -0.018819},{1.269978, 0.041452, -0.012809},{
      1.271907, 0.029269, -0.012809},{1.274275, 0.030039, -0.018819}}],
    Polygon[{{1.269978, 0.041452, -0.012809},{1.268460, 0.041452, -0.006485},{
      1.270463, 0.028800, -0.006485},{1.271907, 0.029269, -0.012809}}],
    Polygon[{{1.268460, 0.041452, -0.006485},{1.267949, 0.041452, 0.000000},{
      1.269978, 0.028643, 0.000000},{1.270463, 0.028800, -0.006485}}],
    Polygon[{{1.267949, 0.041452, 0.000000},{1.268460, 0.041452, 0.006485},{
      1.270463, 0.028800, 0.006485},{1.269978, 0.028643, 0.000000}}],
    Polygon[{{1.268460, 0.041452, 0.006485},{1.269978, 0.041452, 0.012809},{
      1.271907, 0.029269, 0.012809},{1.270463, 0.028800, 0.006485}}],
    Polygon[{{1.269978, 0.041452, 0.012809},{1.272467, 0.041452, 0.018819},{
      1.274275, 0.030039, 0.018819},{1.271907, 0.029269, 0.012809}}],
    Polygon[{{1.272467, 0.041452, 0.018819},{1.275866, 0.041452, 0.024365},{
      1.277507, 0.031089, 0.024365},{1.274275, 0.030039, 0.018819}}],
    Polygon[{{1.275866, 0.041452, 0.024365},{1.280090, 0.041452, 0.029311},{
      1.281525, 0.032394, 0.029311},{1.277507, 0.031089, 0.024365}}],
    Polygon[{{1.280090, 0.041452, 0.029311},{1.285036, 0.041452, 0.033535},{
      1.286229, 0.033923, 0.033535},{1.281525, 0.032394, 0.029311}}],
    Polygon[{{1.285036, 0.041452, 0.033535},{1.290582, 0.041452, 0.036934},{
      1.291503, 0.035637, 0.036934},{1.286229, 0.033923, 0.033535}}],
    Polygon[{{1.290582, 0.041452, 0.036934},{1.296592, 0.041452, 0.039423},{
      1.297219, 0.037494, 0.039423},{1.291503, 0.035637, 0.036934}}],
    Polygon[{{1.296592, 0.041452, 0.039423},{1.302917, 0.041452, 0.040942},{
      1.303234, 0.039448, 0.040942},{1.297219, 0.037494, 0.039423}}],
    Polygon[{{1.303234, 0.039448, -0.040942},{1.297219, 0.037494, -0.039423},{
      1.299038, 0.033923, -0.039423},{1.304155, 0.037640, -0.040942}}],
    Polygon[{{1.297219, 0.037494, -0.039423},{1.291503, 0.035637, -0.036934},{
      1.294176, 0.030390, -0.036934},{1.299038, 0.033923, -0.039423}}],
    Polygon[{{1.291503, 0.035637, -0.036934},{1.286229, 0.033923, -0.033535},{
      1.289690, 0.027131, -0.033535},{1.294176, 0.030390, -0.036934}}],
    Polygon[{{1.286229, 0.033923, -0.033535},{1.281525, 0.032394, -0.029311},{
      1.285688, 0.024223, -0.029311},{1.289690, 0.027131, -0.033535}}],
    Polygon[{{1.281525, 0.032394, -0.029311},{1.277507, 0.031089, -0.024365},{
      1.282270, 0.021740, -0.024365},{1.285688, 0.024223, -0.029311}}],
    Polygon[{{1.277507, 0.031089, -0.024365},{1.274275, 0.030039, -0.018819},{
      1.279521, 0.019743, -0.018819},{1.282270, 0.021740, -0.024365}}],
    Polygon[{{1.274275, 0.030039, -0.018819},{1.271907, 0.029269, -0.012809},{
      1.277507, 0.018280, -0.012809},{1.279521, 0.019743, -0.018819}}],
    Polygon[{{1.271907, 0.029269, -0.012809},{1.270463, 0.028800, -0.006485},{
      1.276279, 0.017387, -0.006485},{1.277507, 0.018280, -0.012809}}],
    Polygon[{{1.270463, 0.028800, -0.006485},{1.269978, 0.028643, 0.000000},{
      1.275866, 0.017087, 0.000000},{1.276279, 0.017387, -0.006485}}],
    Polygon[{{1.269978, 0.028643, 0.000000},{1.270463, 0.028800, 0.006485},{
      1.276279, 0.017387, 0.006485},{1.275866, 0.017087, 0.000000}}],
    Polygon[{{1.270463, 0.028800, 0.006485},{1.271907, 0.029269, 0.012809},{
      1.277507, 0.018280, 0.012809},{1.276279, 0.017387, 0.006485}}],
    Polygon[{{1.271907, 0.029269, 0.012809},{1.274275, 0.030039, 0.018819},{
      1.279521, 0.019743, 0.018819},{1.277507, 0.018280, 0.012809}}],
    Polygon[{{1.274275, 0.030039, 0.018819},{1.277507, 0.031089, 0.024365},{
      1.282270, 0.021740, 0.024365},{1.279521, 0.019743, 0.018819}}],
    Polygon[{{1.277507, 0.031089, 0.024365},{1.281525, 0.032394, 0.029311},{
      1.285688, 0.024223, 0.029311},{1.282270, 0.021740, 0.024365}}],
    Polygon[{{1.281525, 0.032394, 0.029311},{1.286229, 0.033923, 0.033535},{
      1.289690, 0.027131, 0.033535},{1.285688, 0.024223, 0.029311}}],
    Polygon[{{1.286229, 0.033923, 0.033535},{1.291503, 0.035637, 0.036934},{
      1.294176, 0.030390, 0.036934},{1.289690, 0.027131, 0.033535}}],
    Polygon[{{1.291503, 0.035637, 0.036934},{1.297219, 0.037494, 0.039423},{
      1.299038, 0.033923, 0.039423},{1.294176, 0.030390, 0.036934}}],
    Polygon[{{1.297219, 0.037494, 0.039423},{1.303234, 0.039448, 0.040942},{
      1.304155, 0.037640, 0.040942},{1.299038, 0.033923, 0.039423}}],
    Polygon[{{1.304155, 0.037640, -0.040942},{1.299038, 0.033923, -0.039423},{
      1.301872, 0.031089, -0.039423},{1.305590, 0.036206, -0.040942}}],
    Polygon[{{1.299038, 0.033923, -0.039423},{1.294176, 0.030390, -0.036934},{
      1.298340, 0.026227, -0.036934},{1.301872, 0.031089, -0.039423}}],
    Polygon[{{1.294176, 0.030390, -0.036934},{1.289690, 0.027131, -0.033535},{
      1.295080, 0.021740, -0.033535},{1.298340, 0.026227, -0.036934}}],
    Polygon[{{1.289690, 0.027131, -0.033535},{1.285688, 0.024223, -0.029311},{
      1.292173, 0.017739, -0.029311},{1.295080, 0.021740, -0.033535}}],
    Polygon[{{1.285688, 0.024223, -0.029311},{1.282270, 0.021740, -0.024365},{
      1.289690, 0.014321, -0.024365},{1.292173, 0.017739, -0.029311}}],
    Polygon[{{1.282270, 0.021740, -0.024365},{1.279521, 0.019743, -0.018819},{
      1.287692, 0.011572, -0.018819},{1.289690, 0.014321, -0.024365}}],
    Polygon[{{1.279521, 0.019743, -0.018819},{1.277507, 0.018280, -0.012809},{
      1.286229, 0.009558, -0.012809},{1.287692, 0.011572, -0.018819}}],
    Polygon[{{1.277507, 0.018280, -0.012809},{1.276279, 0.017387, -0.006485},{
      1.285336, 0.008329, -0.006485},{1.286229, 0.009558, -0.012809}}],
    Polygon[{{1.276279, 0.017387, -0.006485},{1.275866, 0.017087, 0.000000},{
      1.285036, 0.007917, 0.000000},{1.285336, 0.008329, -0.006485}}],
    Polygon[{{1.275866, 0.017087, 0.000000},{1.276279, 0.017387, 0.006485},{
      1.285336, 0.008329, 0.006485},{1.285036, 0.007917, 0.000000}}],
    Polygon[{{1.276279, 0.017387, 0.006485},{1.277507, 0.018280, 0.012809},{
      1.286229, 0.009558, 0.012809},{1.285336, 0.008329, 0.006485}}],
    Polygon[{{1.277507, 0.018280, 0.012809},{1.279521, 0.019743, 0.018819},{
      1.287692, 0.011572, 0.018819},{1.286229, 0.009558, 0.012809}}],
    Polygon[{{1.279521, 0.019743, 0.018819},{1.282270, 0.021740, 0.024365},{
      1.289690, 0.014321, 0.024365},{1.287692, 0.011572, 0.018819}}],
    Polygon[{{1.282270, 0.021740, 0.024365},{1.285688, 0.024223, 0.029311},{
      1.292173, 0.017739, 0.029311},{1.289690, 0.014321, 0.024365}}],
    Polygon[{{1.285688, 0.024223, 0.029311},{1.289690, 0.027131, 0.033535},{
      1.295080, 0.021740, 0.033535},{1.292173, 0.017739, 0.029311}}],
    Polygon[{{1.289690, 0.027131, 0.033535},{1.294176, 0.030390, 0.036934},{
      1.298340, 0.026227, 0.036934},{1.295080, 0.021740, 0.033535}}],
    Polygon[{{1.294176, 0.030390, 0.036934},{1.299038, 0.033923, 0.039423},{
      1.301872, 0.031089, 0.039423},{1.298340, 0.026227, 0.036934}}],
    Polygon[{{1.299038, 0.033923, 0.039423},{1.304155, 0.037640, 0.040942},{
      1.305590, 0.036206, 0.040942},{1.301872, 0.031089, 0.039423}}],
    Polygon[{{1.305590, 0.036206, -0.040942},{1.301872, 0.031089, -0.039423},{
      1.305443, 0.029269, -0.039423},{1.307397, 0.035285, -0.040942}}],
    Polygon[{{1.301872, 0.031089, -0.039423},{1.298340, 0.026227, -0.036934},{
      1.303586, 0.023554, -0.036934},{1.305443, 0.029269, -0.039423}}],
    Polygon[{{1.298340, 0.026227, -0.036934},{1.295080, 0.021740, -0.033535},{
      1.301872, 0.018280, -0.033535},{1.303586, 0.023554, -0.036934}}],
    Polygon[{{1.295080, 0.021740, -0.033535},{1.292173, 0.017739, -0.029311},{
      1.300344, 0.013576, -0.029311},{1.301872, 0.018280, -0.033535}}],
    Polygon[{{1.292173, 0.017739, -0.029311},{1.289690, 0.014321, -0.024365},{
      1.299038, 0.009558, -0.024365},{1.300344, 0.013576, -0.029311}}],
    Polygon[{{1.289690, 0.014321, -0.024365},{1.287692, 0.011572, -0.018819},{
      1.297988, 0.006326, -0.018819},{1.299038, 0.009558, -0.024365}}],
    Polygon[{{1.287692, 0.011572, -0.018819},{1.286229, 0.009558, -0.012809},{
      1.297219, 0.003958, -0.012809},{1.297988, 0.006326, -0.018819}}],
    Polygon[{{1.286229, 0.009558, -0.012809},{1.285336, 0.008329, -0.006485},{
      1.296749, 0.002514, -0.006485},{1.297219, 0.003958, -0.012809}}],
    Polygon[{{1.285336, 0.008329, -0.006485},{1.285036, 0.007917, 0.000000},{
      1.296592, 0.002029, 0.000000},{1.296749, 0.002514, -0.006485}}],
    Polygon[{{1.285036, 0.007917, 0.000000},{1.285336, 0.008329, 0.006485},{
      1.296749, 0.002514, 0.006485},{1.296592, 0.002029, 0.000000}}],
    Polygon[{{1.285336, 0.008329, 0.006485},{1.286229, 0.009558, 0.012809},{
      1.297219, 0.003958, 0.012809},{1.296749, 0.002514, 0.006485}}],
    Polygon[{{1.286229, 0.009558, 0.012809},{1.287692, 0.011572, 0.018819},{
      1.297988, 0.006326, 0.018819},{1.297219, 0.003958, 0.012809}}],
    Polygon[{{1.287692, 0.011572, 0.018819},{1.289690, 0.014321, 0.024365},{
      1.299038, 0.009558, 0.024365},{1.297988, 0.006326, 0.018819}}],
    Polygon[{{1.289690, 0.014321, 0.024365},{1.292173, 0.017739, 0.029311},{
      1.300344, 0.013576, 0.029311},{1.299038, 0.009558, 0.024365}}],
    Polygon[{{1.292173, 0.017739, 0.029311},{1.295080, 0.021740, 0.033535},{
      1.301872, 0.018280, 0.033535},{1.300344, 0.013576, 0.029311}}],
    Polygon[{{1.295080, 0.021740, 0.033535},{1.298340, 0.026227, 0.036934},{
      1.303586, 0.023554, 0.036934},{1.301872, 0.018280, 0.033535}}],
    Polygon[{{1.298340, 0.026227, 0.036934},{1.301872, 0.031089, 0.039423},{
      1.305443, 0.029269, 0.039423},{1.303586, 0.023554, 0.036934}}],
    Polygon[{{1.301872, 0.031089, 0.039423},{1.305590, 0.036206, 0.040942},{
      1.307397, 0.035285, 0.040942},{1.305443, 0.029269, 0.039423}}],
    Polygon[{{1.307397, 0.035285, -0.040942},{1.305443, 0.029269, -0.039423},{
      1.309401, 0.028643, -0.039423},{1.309401, 0.034967, -0.040942}}],
    Polygon[{{1.305443, 0.029269, -0.039423},{1.303586, 0.023554, -0.036934},{
      1.309401, 0.022633, -0.036934},{1.309401, 0.028643, -0.039423}}],
    Polygon[{{1.303586, 0.023554, -0.036934},{1.301872, 0.018280, -0.033535},{
      1.309401, 0.017087, -0.033535},{1.309401, 0.022633, -0.036934}}],
    Polygon[{{1.301872, 0.018280, -0.033535},{1.300344, 0.013576, -0.029311},{
      1.309401, 0.012141, -0.029311},{1.309401, 0.017087, -0.033535}}],
    Polygon[{{1.300344, 0.013576, -0.029311},{1.299038, 0.009558, -0.024365},{
      1.309401, 0.007917, -0.024365},{1.309401, 0.012141, -0.029311}}],
    Polygon[{{1.299038, 0.009558, -0.024365},{1.297988, 0.006326, -0.018819},{
      1.309401, 0.004518, -0.018819},{1.309401, 0.007917, -0.024365}}],
    Polygon[{{1.297988, 0.006326, -0.018819},{1.297219, 0.003958, -0.012809},{
      1.309401, 0.002029, -0.012809},{1.309401, 0.004518, -0.018819}}],
    Polygon[{{1.297219, 0.003958, -0.012809},{1.296749, 0.002514, -0.006485},{
      1.309401, 0.000510, -0.006485},{1.309401, 0.002029, -0.012809}}],
    Polygon[{{1.296749, 0.002514, -0.006485},{1.296592, 0.002029, 0.000000},{
      1.309401, 0.000000, 0.000000},{1.309401, 0.000510, -0.006485}}],
    Polygon[{{1.296592, 0.002029, 0.000000},{1.296749, 0.002514, 0.006485},{
      1.309401, 0.000510, 0.006485},{1.309401, 0.000000, 0.000000}}],
    Polygon[{{1.296749, 0.002514, 0.006485},{1.297219, 0.003958, 0.012809},{
      1.309401, 0.002029, 0.012809},{1.309401, 0.000510, 0.006485}}],
    Polygon[{{1.297219, 0.003958, 0.012809},{1.297988, 0.006326, 0.018819},{
      1.309401, 0.004518, 0.018819},{1.309401, 0.002029, 0.012809}}],
    Polygon[{{1.297988, 0.006326, 0.018819},{1.299038, 0.009558, 0.024365},{
      1.309401, 0.007917, 0.024365},{1.309401, 0.004518, 0.018819}}],
    Polygon[{{1.299038, 0.009558, 0.024365},{1.300344, 0.013576, 0.029311},{
      1.309401, 0.012141, 0.029311},{1.309401, 0.007917, 0.024365}}],
    Polygon[{{1.300344, 0.013576, 0.029311},{1.301872, 0.018280, 0.033535},{
      1.309401, 0.017087, 0.033535},{1.309401, 0.012141, 0.029311}}],
    Polygon[{{1.301872, 0.018280, 0.033535},{1.303586, 0.023554, 0.036934},{
      1.309401, 0.022633, 0.036934},{1.309401, 0.017087, 0.033535}}],
    Polygon[{{1.303586, 0.023554, 0.036934},{1.305443, 0.029269, 0.039423},{
      1.309401, 0.028643, 0.039423},{1.309401, 0.022633, 0.036934}}],
    Polygon[{{1.305443, 0.029269, 0.039423},{1.307397, 0.035285, 0.040942},{
      1.309401, 0.034967, 0.040942},{1.309401, 0.028643, 0.039423}}],
    Polygon[{{1.309401, 0.034967, -0.040942},{1.309401, 0.028643, -0.039423},{
      1.313359, 0.029269, -0.039423},{1.311405, 0.035285, -0.040942}}],
    Polygon[{{1.309401, 0.028643, -0.039423},{1.309401, 0.022633, -0.036934},{
      1.315216, 0.023554, -0.036934},{1.313359, 0.029269, -0.039423}}],
    Polygon[{{1.309401, 0.022633, -0.036934},{1.309401, 0.017087, -0.033535},{
      1.316930, 0.018280, -0.033535},{1.315216, 0.023554, -0.036934}}],
    Polygon[{{1.309401, 0.017087, -0.033535},{1.309401, 0.012141, -0.029311},{
      1.318459, 0.013576, -0.029311},{1.316930, 0.018280, -0.033535}}],
    Polygon[{{1.309401, 0.012141, -0.029311},{1.309401, 0.007917, -0.024365},{
      1.319764, 0.009558, -0.024365},{1.318459, 0.013576, -0.029311}}],
    Polygon[{{1.309401, 0.007917, -0.024365},{1.309401, 0.004518, -0.018819},{
      1.320814, 0.006326, -0.018819},{1.319764, 0.009558, -0.024365}}],
    Polygon[{{1.309401, 0.004518, -0.018819},{1.309401, 0.002029, -0.012809},{
      1.321584, 0.003958, -0.012809},{1.320814, 0.006326, -0.018819}}],
    Polygon[{{1.309401, 0.002029, -0.012809},{1.309401, 0.000510, -0.006485},{
      1.322053, 0.002514, -0.006485},{1.321584, 0.003958, -0.012809}}],
    Polygon[{{1.309401, 0.000510, -0.006485},{1.309401, 0.000000, 0.000000},{
      1.322210, 0.002029, 0.000000},{1.322053, 0.002514, -0.006485}}],
    Polygon[{{1.309401, 0.000000, 0.000000},{1.309401, 0.000510, 0.006485},{
      1.322053, 0.002514, 0.006485},{1.322210, 0.002029, 0.000000}}],
    Polygon[{{1.309401, 0.000510, 0.006485},{1.309401, 0.002029, 0.012809},{
      1.321584, 0.003958, 0.012809},{1.322053, 0.002514, 0.006485}}],
    Polygon[{{1.309401, 0.002029, 0.012809},{1.309401, 0.004518, 0.018819},{
      1.320814, 0.006326, 0.018819},{1.321584, 0.003958, 0.012809}}],
    Polygon[{{1.309401, 0.004518, 0.018819},{1.309401, 0.007917, 0.024365},{
      1.319764, 0.009558, 0.024365},{1.320814, 0.006326, 0.018819}}],
    Polygon[{{1.309401, 0.007917, 0.024365},{1.309401, 0.012141, 0.029311},{
      1.318459, 0.013576, 0.029311},{1.319764, 0.009558, 0.024365}}],
    Polygon[{{1.309401, 0.012141, 0.029311},{1.309401, 0.017087, 0.033535},{
      1.316930, 0.018280, 0.033535},{1.318459, 0.013576, 0.029311}}],
    Polygon[{{1.309401, 0.017087, 0.033535},{1.309401, 0.022633, 0.036934},{
      1.315216, 0.023554, 0.036934},{1.316930, 0.018280, 0.033535}}],
    Polygon[{{1.309401, 0.022633, 0.036934},{1.309401, 0.028643, 0.039423},{
      1.313359, 0.029269, 0.039423},{1.315216, 0.023554, 0.036934}}],
    Polygon[{{1.309401, 0.028643, 0.039423},{1.309401, 0.034967, 0.040942},{
      1.311405, 0.035285, 0.040942},{1.313359, 0.029269, 0.039423}}],
    Polygon[{{1.311405, 0.035285, -0.040942},{1.313359, 0.029269, -0.039423},{
      1.316930, 0.031089, -0.039423},{1.313213, 0.036206, -0.040942}}],
    Polygon[{{1.313359, 0.029269, -0.039423},{1.315216, 0.023554, -0.036934},{
      1.320462, 0.026227, -0.036934},{1.316930, 0.031089, -0.039423}}],
    Polygon[{{1.315216, 0.023554, -0.036934},{1.316930, 0.018280, -0.033535},{
      1.323722, 0.021740, -0.033535},{1.320462, 0.026227, -0.036934}}],
    Polygon[{{1.316930, 0.018280, -0.033535},{1.318459, 0.013576, -0.029311},{
      1.326630, 0.017739, -0.029311},{1.323722, 0.021740, -0.033535}}],
    Polygon[{{1.318459, 0.013576, -0.029311},{1.319764, 0.009558, -0.024365},{
      1.329113, 0.014321, -0.024365},{1.326630, 0.017739, -0.029311}}],
    Polygon[{{1.319764, 0.009558, -0.024365},{1.320814, 0.006326, -0.018819},{
      1.331110, 0.011572, -0.018819},{1.329113, 0.014321, -0.024365}}],
    Polygon[{{1.320814, 0.006326, -0.018819},{1.321584, 0.003958, -0.012809},{
      1.332573, 0.009558, -0.012809},{1.331110, 0.011572, -0.018819}}],
    Polygon[{{1.321584, 0.003958, -0.012809},{1.322053, 0.002514, -0.006485},{
      1.333466, 0.008329, -0.006485},{1.332573, 0.009558, -0.012809}}],
    Polygon[{{1.322053, 0.002514, -0.006485},{1.322210, 0.002029, 0.000000},{
      1.333766, 0.007917, 0.000000},{1.333466, 0.008329, -0.006485}}],
    Polygon[{{1.322210, 0.002029, 0.000000},{1.322053, 0.002514, 0.006485},{
      1.333466, 0.008329, 0.006485},{1.333766, 0.007917, 0.000000}}],
    Polygon[{{1.322053, 0.002514, 0.006485},{1.321584, 0.003958, 0.012809},{
      1.332573, 0.009558, 0.012809},{1.333466, 0.008329, 0.006485}}],
    Polygon[{{1.321584, 0.003958, 0.012809},{1.320814, 0.006326, 0.018819},{
      1.331110, 0.011572, 0.018819},{1.332573, 0.009558, 0.012809}}],
    Polygon[{{1.320814, 0.006326, 0.018819},{1.319764, 0.009558, 0.024365},{
      1.329113, 0.014321, 0.024365},{1.331110, 0.011572, 0.018819}}],
    Polygon[{{1.319764, 0.009558, 0.024365},{1.318459, 0.013576, 0.029311},{
      1.326630, 0.017739, 0.029311},{1.329113, 0.014321, 0.024365}}],
    Polygon[{{1.318459, 0.013576, 0.029311},{1.316930, 0.018280, 0.033535},{
      1.323722, 0.021740, 0.033535},{1.326630, 0.017739, 0.029311}}],
    Polygon[{{1.316930, 0.018280, 0.033535},{1.315216, 0.023554, 0.036934},{
      1.320462, 0.026227, 0.036934},{1.323722, 0.021740, 0.033535}}],
    Polygon[{{1.315216, 0.023554, 0.036934},{1.313359, 0.029269, 0.039423},{
      1.316930, 0.031089, 0.039423},{1.320462, 0.026227, 0.036934}}],
    Polygon[{{1.313359, 0.029269, 0.039423},{1.311405, 0.035285, 0.040942},{
      1.313213, 0.036206, 0.040942},{1.316930, 0.031089, 0.039423}}],
    Polygon[{{1.313213, 0.036206, -0.040942},{1.316930, 0.031089, -0.039423},{
      1.319764, 0.033923, -0.039423},{1.314647, 0.037640, -0.040942}}],
    Polygon[{{1.316930, 0.031089, -0.039423},{1.320462, 0.026227, -0.036934},{
      1.324626, 0.030390, -0.036934},{1.319764, 0.033923, -0.039423}}],
    Polygon[{{1.320462, 0.026227, -0.036934},{1.323722, 0.021740, -0.033535},{
      1.329113, 0.027131, -0.033535},{1.324626, 0.030390, -0.036934}}],
    Polygon[{{1.323722, 0.021740, -0.033535},{1.326630, 0.017739, -0.029311},{
      1.333114, 0.024223, -0.029311},{1.329113, 0.027131, -0.033535}}],
    Polygon[{{1.326630, 0.017739, -0.029311},{1.329113, 0.014321, -0.024365},{
      1.336532, 0.021740, -0.024365},{1.333114, 0.024223, -0.029311}}],
    Polygon[{{1.329113, 0.014321, -0.024365},{1.331110, 0.011572, -0.018819},{
      1.339281, 0.019743, -0.018819},{1.336532, 0.021740, -0.024365}}],
    Polygon[{{1.331110, 0.011572, -0.018819},{1.332573, 0.009558, -0.012809},{
      1.341295, 0.018280, -0.012809},{1.339281, 0.019743, -0.018819}}],
    Polygon[{{1.332573, 0.009558, -0.012809},{1.333466, 0.008329, -0.006485},{
      1.342523, 0.017387, -0.006485},{1.341295, 0.018280, -0.012809}}],
    Polygon[{{1.333466, 0.008329, -0.006485},{1.333766, 0.007917, 0.000000},{
      1.342936, 0.017087, 0.000000},{1.342523, 0.017387, -0.006485}}],
    Polygon[{{1.333766, 0.007917, 0.000000},{1.333466, 0.008329, 0.006485},{
      1.342523, 0.017387, 0.006485},{1.342936, 0.017087, 0.000000}}],
    Polygon[{{1.333466, 0.008329, 0.006485},{1.332573, 0.009558, 0.012809},{
      1.341295, 0.018280, 0.012809},{1.342523, 0.017387, 0.006485}}],
    Polygon[{{1.332573, 0.009558, 0.012809},{1.331110, 0.011572, 0.018819},{
      1.339281, 0.019743, 0.018819},{1.341295, 0.018280, 0.012809}}],
    Polygon[{{1.331110, 0.011572, 0.018819},{1.329113, 0.014321, 0.024365},{
      1.336532, 0.021740, 0.024365},{1.339281, 0.019743, 0.018819}}],
    Polygon[{{1.329113, 0.014321, 0.024365},{1.326630, 0.017739, 0.029311},{
      1.333114, 0.024223, 0.029311},{1.336532, 0.021740, 0.024365}}],
    Polygon[{{1.326630, 0.017739, 0.029311},{1.323722, 0.021740, 0.033535},{
      1.329113, 0.027131, 0.033535},{1.333114, 0.024223, 0.029311}}],
    Polygon[{{1.323722, 0.021740, 0.033535},{1.320462, 0.026227, 0.036934},{
      1.324626, 0.030390, 0.036934},{1.329113, 0.027131, 0.033535}}],
    Polygon[{{1.320462, 0.026227, 0.036934},{1.316930, 0.031089, 0.039423},{
      1.319764, 0.033923, 0.039423},{1.324626, 0.030390, 0.036934}}],
    Polygon[{{1.316930, 0.031089, 0.039423},{1.313213, 0.036206, 0.040942},{
      1.314647, 0.037640, 0.040942},{1.319764, 0.033923, 0.039423}}],
    Polygon[{{1.314647, 0.037640, -0.040942},{1.319764, 0.033923, -0.039423},{
      1.321584, 0.037494, -0.039423},{1.315568, 0.039448, -0.040942}}],
    Polygon[{{1.319764, 0.033923, -0.039423},{1.324626, 0.030390, -0.036934},{
      1.327299, 0.035637, -0.036934},{1.321584, 0.037494, -0.039423}}],
    Polygon[{{1.324626, 0.030390, -0.036934},{1.329113, 0.027131, -0.033535},{
      1.332573, 0.033923, -0.033535},{1.327299, 0.035637, -0.036934}}],
    Polygon[{{1.329113, 0.027131, -0.033535},{1.333114, 0.024223, -0.029311},{
      1.337277, 0.032394, -0.029311},{1.332573, 0.033923, -0.033535}}],
    Polygon[{{1.333114, 0.024223, -0.029311},{1.336532, 0.021740, -0.024365},{
      1.341295, 0.031089, -0.024365},{1.337277, 0.032394, -0.029311}}],
    Polygon[{{1.336532, 0.021740, -0.024365},{1.339281, 0.019743, -0.018819},{
      1.344527, 0.030039, -0.018819},{1.341295, 0.031089, -0.024365}}],
    Polygon[{{1.339281, 0.019743, -0.018819},{1.341295, 0.018280, -0.012809},{
      1.346895, 0.029269, -0.012809},{1.344527, 0.030039, -0.018819}}],
    Polygon[{{1.341295, 0.018280, -0.012809},{1.342523, 0.017387, -0.006485},{
      1.348339, 0.028800, -0.006485},{1.346895, 0.029269, -0.012809}}],
    Polygon[{{1.342523, 0.017387, -0.006485},{1.342936, 0.017087, 0.000000},{
      1.348824, 0.028643, 0.000000},{1.348339, 0.028800, -0.006485}}],
    Polygon[{{1.342936, 0.017087, 0.000000},{1.342523, 0.017387, 0.006485},{
      1.348339, 0.028800, 0.006485},{1.348824, 0.028643, 0.000000}}],
    Polygon[{{1.342523, 0.017387, 0.006485},{1.341295, 0.018280, 0.012809},{
      1.346895, 0.029269, 0.012809},{1.348339, 0.028800, 0.006485}}],
    Polygon[{{1.341295, 0.018280, 0.012809},{1.339281, 0.019743, 0.018819},{
      1.344527, 0.030039, 0.018819},{1.346895, 0.029269, 0.012809}}],
    Polygon[{{1.339281, 0.019743, 0.018819},{1.336532, 0.021740, 0.024365},{
      1.341295, 0.031089, 0.024365},{1.344527, 0.030039, 0.018819}}],
    Polygon[{{1.336532, 0.021740, 0.024365},{1.333114, 0.024223, 0.029311},{
      1.337277, 0.032394, 0.029311},{1.341295, 0.031089, 0.024365}}],
    Polygon[{{1.333114, 0.024223, 0.029311},{1.329113, 0.027131, 0.033535},{
      1.332573, 0.033923, 0.033535},{1.337277, 0.032394, 0.029311}}],
    Polygon[{{1.329113, 0.027131, 0.033535},{1.324626, 0.030390, 0.036934},{
      1.327299, 0.035637, 0.036934},{1.332573, 0.033923, 0.033535}}],
    Polygon[{{1.324626, 0.030390, 0.036934},{1.319764, 0.033923, 0.039423},{
      1.321584, 0.037494, 0.039423},{1.327299, 0.035637, 0.036934}}],
    Polygon[{{1.319764, 0.033923, 0.039423},{1.314647, 0.037640, 0.040942},{
      1.315568, 0.039448, 0.040942},{1.321584, 0.037494, 0.039423}}],
    Polygon[{{1.315568, 0.039448, -0.040942},{1.321584, 0.037494, -0.039423},{
      1.322210, 0.041452, -0.039423},{1.315886, 0.041452, -0.040942}}],
    Polygon[{{1.321584, 0.037494, -0.039423},{1.327299, 0.035637, -0.036934},{
      1.328220, 0.041452, -0.036934},{1.322210, 0.041452, -0.039423}}],
    Polygon[{{1.327299, 0.035637, -0.036934},{1.332573, 0.033923, -0.033535},{
      1.333766, 0.041452, -0.033535},{1.328220, 0.041452, -0.036934}}],
    Polygon[{{1.332573, 0.033923, -0.033535},{1.337277, 0.032394, -0.029311},{
      1.338712, 0.041452, -0.029311},{1.333766, 0.041452, -0.033535}}],
    Polygon[{{1.337277, 0.032394, -0.029311},{1.341295, 0.031089, -0.024365},{
      1.342936, 0.041452, -0.024365},{1.338712, 0.041452, -0.029311}}],
    Polygon[{{1.341295, 0.031089, -0.024365},{1.344527, 0.030039, -0.018819},{
      1.346335, 0.041452, -0.018819},{1.342936, 0.041452, -0.024365}}],
    Polygon[{{1.344527, 0.030039, -0.018819},{1.346895, 0.029269, -0.012809},{
      1.348824, 0.041452, -0.012809},{1.346335, 0.041452, -0.018819}}],
    Polygon[{{1.346895, 0.029269, -0.012809},{1.348339, 0.028800, -0.006485},{
      1.350343, 0.041452, -0.006485},{1.348824, 0.041452, -0.012809}}],
    Polygon[{{1.348339, 0.028800, -0.006485},{1.348824, 0.028643, 0.000000},{
      1.350853, 0.041452, 0.000000},{1.350343, 0.041452, -0.006485}}],
    Polygon[{{1.348824, 0.028643, 0.000000},{1.348339, 0.028800, 0.006485},{
      1.350343, 0.041452, 0.006485},{1.350853, 0.041452, 0.000000}}],
    Polygon[{{1.348339, 0.028800, 0.006485},{1.346895, 0.029269, 0.012809},{
      1.348824, 0.041452, 0.012809},{1.350343, 0.041452, 0.006485}}],
    Polygon[{{1.346895, 0.029269, 0.012809},{1.344527, 0.030039, 0.018819},{
      1.346335, 0.041452, 0.018819},{1.348824, 0.041452, 0.012809}}],
    Polygon[{{1.344527, 0.030039, 0.018819},{1.341295, 0.031089, 0.024365},{
      1.342936, 0.041452, 0.024365},{1.346335, 0.041452, 0.018819}}],
    Polygon[{{1.341295, 0.031089, 0.024365},{1.337277, 0.032394, 0.029311},{
      1.338712, 0.041452, 0.029311},{1.342936, 0.041452, 0.024365}}],
    Polygon[{{1.337277, 0.032394, 0.029311},{1.332573, 0.033923, 0.033535},{
      1.333766, 0.041452, 0.033535},{1.338712, 0.041452, 0.029311}}],
    Polygon[{{1.332573, 0.033923, 0.033535},{1.327299, 0.035637, 0.036934},{
      1.328220, 0.041452, 0.036934},{1.333766, 0.041452, 0.033535}}],
    Polygon[{{1.327299, 0.035637, 0.036934},{1.321584, 0.037494, 0.039423},{
      1.322210, 0.041452, 0.039423},{1.328220, 0.041452, 0.036934}}],
    Polygon[{{1.321584, 0.037494, 0.039423},{1.315568, 0.039448, 0.040942},{
      1.315886, 0.041452, 0.040942},{1.322210, 0.041452, 0.039423}}],
    Polygon[{{1.248050, 0.025783, -0.025466},{1.251984, 0.025783, -0.024521},{
      1.251595, 0.028246, -0.024521},{1.247853, 0.027030, -0.025466}}],
    Polygon[{{1.251984, 0.025783, -0.024521},{1.255722, 0.025783, -0.022973},{
      1.255149, 0.029401, -0.022973},{1.251595, 0.028246, -0.024521}}],
    Polygon[{{1.255722, 0.025783, -0.022973},{1.259172, 0.025783, -0.020859},{
      1.258430, 0.030467, -0.020859},{1.255149, 0.029401, -0.022973}}],
    Polygon[{{1.259172, 0.025783, -0.020859},{1.262249, 0.025783, -0.018232},{
      1.261356, 0.031417, -0.018232},{1.258430, 0.030467, -0.020859}}],
    Polygon[{{1.262249, 0.025783, -0.018232},{1.264876, 0.025783, -0.015155},{
      1.263855, 0.032229, -0.015155},{1.261356, 0.031417, -0.018232}}],
    Polygon[{{1.264876, 0.025783, -0.015155},{1.266990, 0.025783, -0.011705},{
      1.265866, 0.032883, -0.011705},{1.263855, 0.032229, -0.015155}}],
    Polygon[{{1.266990, 0.025783, -0.011705},{1.268538, 0.025783, -0.007968},{
      1.267338, 0.033361, -0.007968},{1.265866, 0.032883, -0.011705}}],
    Polygon[{{1.268538, 0.025783, -0.007968},{1.269483, 0.025783, -0.004033},{
      1.268237, 0.033653, -0.004033},{1.267338, 0.033361, -0.007968}}],
    Polygon[{{1.269483, 0.025783, -0.004033},{1.269800, 0.025783, 0.000000},{
      1.268538, 0.033751, 0.000000},{1.268237, 0.033653, -0.004033}}],
    Polygon[{{1.269800, 0.025783, 0.000000},{1.269483, 0.025783, 0.004033},{
      1.268237, 0.033653, 0.004033},{1.268538, 0.033751, 0.000000}}],
    Polygon[{{1.269483, 0.025783, 0.004033},{1.268538, 0.025783, 0.007968},{
      1.267338, 0.033361, 0.007968},{1.268237, 0.033653, 0.004033}}],
    Polygon[{{1.268538, 0.025783, 0.007968},{1.266990, 0.025783, 0.011705},{
      1.265866, 0.032883, 0.011705},{1.267338, 0.033361, 0.007968}}],
    Polygon[{{1.266990, 0.025783, 0.011705},{1.264876, 0.025783, 0.015155},{
      1.263855, 0.032229, 0.015155},{1.265866, 0.032883, 0.011705}}],
    Polygon[{{1.264876, 0.025783, 0.015155},{1.262249, 0.025783, 0.018232},{
      1.261356, 0.031417, 0.018232},{1.263855, 0.032229, 0.015155}}],
    Polygon[{{1.262249, 0.025783, 0.018232},{1.259172, 0.025783, 0.020859},{
      1.258430, 0.030467, 0.020859},{1.261356, 0.031417, 0.018232}}],
    Polygon[{{1.259172, 0.025783, 0.020859},{1.255722, 0.025783, 0.022973},{
      1.255149, 0.029401, 0.022973},{1.258430, 0.030467, 0.020859}}],
    Polygon[{{1.255722, 0.025783, 0.022973},{1.251984, 0.025783, 0.024521},{
      1.251595, 0.028246, 0.024521},{1.255149, 0.029401, 0.022973}}],
    Polygon[{{1.251984, 0.025783, 0.024521},{1.248050, 0.025783, 0.025466},{
      1.247853, 0.027030, 0.025466},{1.251595, 0.028246, 0.024521}}],
    Polygon[{{1.247853, 0.027030, -0.025466},{1.251595, 0.028246, -0.024521},{
      1.250463, 0.030467, -0.024521},{1.247280, 0.028154, -0.025466}}],
    Polygon[{{1.251595, 0.028246, -0.024521},{1.255149, 0.029401, -0.022973},{
      1.253487, 0.032664, -0.022973},{1.250463, 0.030467, -0.024521}}],
    Polygon[{{1.255149, 0.029401, -0.022973},{1.258430, 0.030467, -0.020859},{
      1.256278, 0.034691, -0.020859},{1.253487, 0.032664, -0.022973}}],
    Polygon[{{1.258430, 0.030467, -0.020859},{1.261356, 0.031417, -0.018232},{
      1.258767, 0.036500, -0.018232},{1.256278, 0.034691, -0.020859}}],
    Polygon[{{1.261356, 0.031417, -0.018232},{1.263855, 0.032229, -0.015155},{
      1.260892, 0.038044, -0.015155},{1.258767, 0.036500, -0.018232}}],
    Polygon[{{1.263855, 0.032229, -0.015155},{1.265866, 0.032883, -0.011705},{
      1.262603, 0.039287, -0.011705},{1.260892, 0.038044, -0.015155}}],
    Polygon[{{1.265866, 0.032883, -0.011705},{1.267338, 0.033361, -0.007968},{
      1.263855, 0.040197, -0.007968},{1.262603, 0.039287, -0.011705}}],
    Polygon[{{1.267338, 0.033361, -0.007968},{1.268237, 0.033653, -0.004033},{
      1.264619, 0.040752, -0.004033},{1.263855, 0.040197, -0.007968}}],
    Polygon[{{1.268237, 0.033653, -0.004033},{1.268538, 0.033751, 0.000000},{
      1.264876, 0.040939, 0.000000},{1.264619, 0.040752, -0.004033}}],
    Polygon[{{1.268538, 0.033751, 0.000000},{1.268237, 0.033653, 0.004033},{
      1.264619, 0.040752, 0.004033},{1.264876, 0.040939, 0.000000}}],
    Polygon[{{1.268237, 0.033653, 0.004033},{1.267338, 0.033361, 0.007968},{
      1.263855, 0.040197, 0.007968},{1.264619, 0.040752, 0.004033}}],
    Polygon[{{1.267338, 0.033361, 0.007968},{1.265866, 0.032883, 0.011705},{
      1.262603, 0.039287, 0.011705},{1.263855, 0.040197, 0.007968}}],
    Polygon[{{1.265866, 0.032883, 0.011705},{1.263855, 0.032229, 0.015155},{
      1.260892, 0.038044, 0.015155},{1.262603, 0.039287, 0.011705}}],
    Polygon[{{1.263855, 0.032229, 0.015155},{1.261356, 0.031417, 0.018232},{
      1.258767, 0.036500, 0.018232},{1.260892, 0.038044, 0.015155}}],
    Polygon[{{1.261356, 0.031417, 0.018232},{1.258430, 0.030467, 0.020859},{
      1.256278, 0.034691, 0.020859},{1.258767, 0.036500, 0.018232}}],
    Polygon[{{1.258430, 0.030467, 0.020859},{1.255149, 0.029401, 0.022973},{
      1.253487, 0.032664, 0.022973},{1.256278, 0.034691, 0.020859}}],
    Polygon[{{1.255149, 0.029401, 0.022973},{1.251595, 0.028246, 0.024521},{
      1.250463, 0.030467, 0.024521},{1.253487, 0.032664, 0.022973}}],
    Polygon[{{1.251595, 0.028246, 0.024521},{1.247853, 0.027030, 0.025466},{
      1.247280, 0.028154, 0.025466},{1.250463, 0.030467, 0.024521}}],
    Polygon[{{1.247280, 0.028154, -0.025466},{1.250463, 0.030467, -0.024521},{
      1.248700, 0.032229, -0.024521},{1.246388, 0.029047, -0.025466}}],
    Polygon[{{1.250463, 0.030467, -0.024521},{1.253487, 0.032664, -0.022973},{
      1.250897, 0.035253, -0.022973},{1.248700, 0.032229, -0.024521}}],
    Polygon[{{1.253487, 0.032664, -0.022973},{1.256278, 0.034691, -0.020859},{
      1.252925, 0.038044, -0.020859},{1.250897, 0.035253, -0.022973}}],
    Polygon[{{1.256278, 0.034691, -0.020859},{1.258767, 0.036500, -0.018232},{
      1.254733, 0.040533, -0.018232},{1.252925, 0.038044, -0.020859}}],
    Polygon[{{1.258767, 0.036500, -0.018232},{1.260892, 0.038044, -0.015155},{
      1.256278, 0.042659, -0.015155},{1.254733, 0.040533, -0.018232}}],
    Polygon[{{1.260892, 0.038044, -0.015155},{1.262603, 0.039287, -0.011705},{
      1.257520, 0.044369, -0.011705},{1.256278, 0.042659, -0.015155}}],
    Polygon[{{1.262603, 0.039287, -0.011705},{1.263855, 0.040197, -0.007968},{
      1.258430, 0.045622, -0.007968},{1.257520, 0.044369, -0.011705}}],
    Polygon[{{1.263855, 0.040197, -0.007968},{1.264619, 0.040752, -0.004033},{
      1.258986, 0.046386, -0.004033},{1.258430, 0.045622, -0.007968}}],
    Polygon[{{1.264619, 0.040752, -0.004033},{1.264876, 0.040939, 0.000000},{
      1.259172, 0.046643, 0.000000},{1.258986, 0.046386, -0.004033}}],
    Polygon[{{1.264876, 0.040939, 0.000000},{1.264619, 0.040752, 0.004033},{
      1.258986, 0.046386, 0.004033},{1.259172, 0.046643, 0.000000}}],
    Polygon[{{1.264619, 0.040752, 0.004033},{1.263855, 0.040197, 0.007968},{
      1.258430, 0.045622, 0.007968},{1.258986, 0.046386, 0.004033}}],
    Polygon[{{1.263855, 0.040197, 0.007968},{1.262603, 0.039287, 0.011705},{
      1.257520, 0.044369, 0.011705},{1.258430, 0.045622, 0.007968}}],
    Polygon[{{1.262603, 0.039287, 0.011705},{1.260892, 0.038044, 0.015155},{
      1.256278, 0.042659, 0.015155},{1.257520, 0.044369, 0.011705}}],
    Polygon[{{1.260892, 0.038044, 0.015155},{1.258767, 0.036500, 0.018232},{
      1.254733, 0.040533, 0.018232},{1.256278, 0.042659, 0.015155}}],
    Polygon[{{1.258767, 0.036500, 0.018232},{1.256278, 0.034691, 0.020859},{
      1.252925, 0.038044, 0.020859},{1.254733, 0.040533, 0.018232}}],
    Polygon[{{1.256278, 0.034691, 0.020859},{1.253487, 0.032664, 0.022973},{
      1.250897, 0.035253, 0.022973},{1.252925, 0.038044, 0.020859}}],
    Polygon[{{1.253487, 0.032664, 0.022973},{1.250463, 0.030467, 0.024521},{
      1.248700, 0.032229, 0.024521},{1.250897, 0.035253, 0.022973}}],
    Polygon[{{1.250463, 0.030467, 0.024521},{1.247280, 0.028154, 0.025466},{
      1.246388, 0.029047, 0.025466},{1.248700, 0.032229, 0.024521}}],
    Polygon[{{1.246388, 0.029047, -0.025466},{1.248700, 0.032229, -0.024521},{
      1.246479, 0.033361, -0.024521},{1.245263, 0.029619, -0.025466}}],
    Polygon[{{1.248700, 0.032229, -0.024521},{1.250897, 0.035253, -0.022973},{
      1.247634, 0.036916, -0.022973},{1.246479, 0.033361, -0.024521}}],
    Polygon[{{1.250897, 0.035253, -0.022973},{1.252925, 0.038044, -0.020859},{
      1.248700, 0.040197, -0.020859},{1.247634, 0.036916, -0.022973}}],
    Polygon[{{1.252925, 0.038044, -0.020859},{1.254733, 0.040533, -0.018232},{
      1.249651, 0.043123, -0.018232},{1.248700, 0.040197, -0.020859}}],
    Polygon[{{1.254733, 0.040533, -0.018232},{1.256278, 0.042659, -0.015155},{
      1.250463, 0.045622, -0.015155},{1.249651, 0.043123, -0.018232}}],
    Polygon[{{1.256278, 0.042659, -0.015155},{1.257520, 0.044369, -0.011705},{
      1.251116, 0.047632, -0.011705},{1.250463, 0.045622, -0.015155}}],
    Polygon[{{1.257520, 0.044369, -0.011705},{1.258430, 0.045622, -0.007968},{
      1.251595, 0.049105, -0.007968},{1.251116, 0.047632, -0.011705}}],
    Polygon[{{1.258430, 0.045622, -0.007968},{1.258986, 0.046386, -0.004033},{
      1.251886, 0.050003, -0.004033},{1.251595, 0.049105, -0.007968}}],
    Polygon[{{1.258986, 0.046386, -0.004033},{1.259172, 0.046643, 0.000000},{
      1.251984, 0.050305, 0.000000},{1.251886, 0.050003, -0.004033}}],
    Polygon[{{1.259172, 0.046643, 0.000000},{1.258986, 0.046386, 0.004033},{
      1.251886, 0.050003, 0.004033},{1.251984, 0.050305, 0.000000}}],
    Polygon[{{1.258986, 0.046386, 0.004033},{1.258430, 0.045622, 0.007968},{
      1.251595, 0.049105, 0.007968},{1.251886, 0.050003, 0.004033}}],
    Polygon[{{1.258430, 0.045622, 0.007968},{1.257520, 0.044369, 0.011705},{
      1.251116, 0.047632, 0.011705},{1.251595, 0.049105, 0.007968}}],
    Polygon[{{1.257520, 0.044369, 0.011705},{1.256278, 0.042659, 0.015155},{
      1.250463, 0.045622, 0.015155},{1.251116, 0.047632, 0.011705}}],
    Polygon[{{1.256278, 0.042659, 0.015155},{1.254733, 0.040533, 0.018232},{
      1.249651, 0.043123, 0.018232},{1.250463, 0.045622, 0.015155}}],
    Polygon[{{1.254733, 0.040533, 0.018232},{1.252925, 0.038044, 0.020859},{
      1.248700, 0.040197, 0.020859},{1.249651, 0.043123, 0.018232}}],
    Polygon[{{1.252925, 0.038044, 0.020859},{1.250897, 0.035253, 0.022973},{
      1.247634, 0.036916, 0.022973},{1.248700, 0.040197, 0.020859}}],
    Polygon[{{1.250897, 0.035253, 0.022973},{1.248700, 0.032229, 0.024521},{
      1.246479, 0.033361, 0.024521},{1.247634, 0.036916, 0.022973}}],
    Polygon[{{1.248700, 0.032229, 0.024521},{1.246388, 0.029047, 0.025466},{
      1.245263, 0.029619, 0.025466},{1.246479, 0.033361, 0.024521}}],
    Polygon[{{1.245263, 0.029619, -0.025466},{1.246479, 0.033361, -0.024521},{
      1.244017, 0.033751, -0.024521},{1.244017, 0.029817, -0.025466}}],
    Polygon[{{1.246479, 0.033361, -0.024521},{1.247634, 0.036916, -0.022973},{
      1.244017, 0.037489, -0.022973},{1.244017, 0.033751, -0.024521}}],
    Polygon[{{1.247634, 0.036916, -0.022973},{1.248700, 0.040197, -0.020859},{
      1.244017, 0.040939, -0.020859},{1.244017, 0.037489, -0.022973}}],
    Polygon[{{1.248700, 0.040197, -0.020859},{1.249651, 0.043123, -0.018232},{
      1.244017, 0.044015, -0.018232},{1.244017, 0.040939, -0.020859}}],
    Polygon[{{1.249651, 0.043123, -0.018232},{1.250463, 0.045622, -0.015155},{
      1.244017, 0.046643, -0.015155},{1.244017, 0.044015, -0.018232}}],
    Polygon[{{1.250463, 0.045622, -0.015155},{1.251116, 0.047632, -0.011705},{
      1.244017, 0.048757, -0.011705},{1.244017, 0.046643, -0.015155}}],
    Polygon[{{1.251116, 0.047632, -0.011705},{1.251595, 0.049105, -0.007968},{
      1.244017, 0.050305, -0.007968},{1.244017, 0.048757, -0.011705}}],
    Polygon[{{1.251595, 0.049105, -0.007968},{1.251886, 0.050003, -0.004033},{
      1.244017, 0.051249, -0.004033},{1.244017, 0.050305, -0.007968}}],
    Polygon[{{1.251886, 0.050003, -0.004033},{1.251984, 0.050305, 0.000000},{
      1.244017, 0.051567, 0.000000},{1.244017, 0.051249, -0.004033}}],
    Polygon[{{1.251984, 0.050305, 0.000000},{1.251886, 0.050003, 0.004033},{
      1.244017, 0.051249, 0.004033},{1.244017, 0.051567, 0.000000}}],
    Polygon[{{1.251886, 0.050003, 0.004033},{1.251595, 0.049105, 0.007968},{
      1.244017, 0.050305, 0.007968},{1.244017, 0.051249, 0.004033}}],
    Polygon[{{1.251595, 0.049105, 0.007968},{1.251116, 0.047632, 0.011705},{
      1.244017, 0.048757, 0.011705},{1.244017, 0.050305, 0.007968}}],
    Polygon[{{1.251116, 0.047632, 0.011705},{1.250463, 0.045622, 0.015155},{
      1.244017, 0.046643, 0.015155},{1.244017, 0.048757, 0.011705}}],
    Polygon[{{1.250463, 0.045622, 0.015155},{1.249651, 0.043123, 0.018232},{
      1.244017, 0.044015, 0.018232},{1.244017, 0.046643, 0.015155}}],
    Polygon[{{1.249651, 0.043123, 0.018232},{1.248700, 0.040197, 0.020859},{
      1.244017, 0.040939, 0.020859},{1.244017, 0.044015, 0.018232}}],
    Polygon[{{1.248700, 0.040197, 0.020859},{1.247634, 0.036916, 0.022973},{
      1.244017, 0.037489, 0.022973},{1.244017, 0.040939, 0.020859}}],
    Polygon[{{1.247634, 0.036916, 0.022973},{1.246479, 0.033361, 0.024521},{
      1.244017, 0.033751, 0.024521},{1.244017, 0.037489, 0.022973}}],
    Polygon[{{1.246479, 0.033361, 0.024521},{1.245263, 0.029619, 0.025466},{
      1.244017, 0.029817, 0.025466},{1.244017, 0.033751, 0.024521}}],
    Polygon[{{1.244017, 0.029817, -0.025466},{1.244017, 0.033751, -0.024521},{
      1.241555, 0.033361, -0.024521},{1.242771, 0.029619, -0.025466}}],
    Polygon[{{1.244017, 0.033751, -0.024521},{1.244017, 0.037489, -0.022973},{
      1.240400, 0.036916, -0.022973},{1.241555, 0.033361, -0.024521}}],
    Polygon[{{1.244017, 0.037489, -0.022973},{1.244017, 0.040939, -0.020859},{
      1.239334, 0.040197, -0.020859},{1.240400, 0.036916, -0.022973}}],
    Polygon[{{1.244017, 0.040939, -0.020859},{1.244017, 0.044015, -0.018232},{
      1.238383, 0.043123, -0.018232},{1.239334, 0.040197, -0.020859}}],
    Polygon[{{1.244017, 0.044015, -0.018232},{1.244017, 0.046643, -0.015155},{
      1.237571, 0.045622, -0.015155},{1.238383, 0.043123, -0.018232}}],
    Polygon[{{1.244017, 0.046643, -0.015155},{1.244017, 0.048757, -0.011705},{
      1.236918, 0.047632, -0.011705},{1.237571, 0.045622, -0.015155}}],
    Polygon[{{1.244017, 0.048757, -0.011705},{1.244017, 0.050305, -0.007968},{
      1.236439, 0.049105, -0.007968},{1.236918, 0.047632, -0.011705}}],
    Polygon[{{1.244017, 0.050305, -0.007968},{1.244017, 0.051249, -0.004033},{
      1.236148, 0.050003, -0.004033},{1.236439, 0.049105, -0.007968}}],
    Polygon[{{1.244017, 0.051249, -0.004033},{1.244017, 0.051567, 0.000000},{
      1.236049, 0.050305, 0.000000},{1.236148, 0.050003, -0.004033}}],
    Polygon[{{1.244017, 0.051567, 0.000000},{1.244017, 0.051249, 0.004033},{
      1.236148, 0.050003, 0.004033},{1.236049, 0.050305, 0.000000}}],
    Polygon[{{1.244017, 0.051249, 0.004033},{1.244017, 0.050305, 0.007968},{
      1.236439, 0.049105, 0.007968},{1.236148, 0.050003, 0.004033}}],
    Polygon[{{1.244017, 0.050305, 0.007968},{1.244017, 0.048757, 0.011705},{
      1.236918, 0.047632, 0.011705},{1.236439, 0.049105, 0.007968}}],
    Polygon[{{1.244017, 0.048757, 0.011705},{1.244017, 0.046643, 0.015155},{
      1.237571, 0.045622, 0.015155},{1.236918, 0.047632, 0.011705}}],
    Polygon[{{1.244017, 0.046643, 0.015155},{1.244017, 0.044015, 0.018232},{
      1.238383, 0.043123, 0.018232},{1.237571, 0.045622, 0.015155}}],
    Polygon[{{1.244017, 0.044015, 0.018232},{1.244017, 0.040939, 0.020859},{
      1.239334, 0.040197, 0.020859},{1.238383, 0.043123, 0.018232}}],
    Polygon[{{1.244017, 0.040939, 0.020859},{1.244017, 0.037489, 0.022973},{
      1.240400, 0.036916, 0.022973},{1.239334, 0.040197, 0.020859}}],
    Polygon[{{1.244017, 0.037489, 0.022973},{1.244017, 0.033751, 0.024521},{
      1.241555, 0.033361, 0.024521},{1.240400, 0.036916, 0.022973}}],
    Polygon[{{1.244017, 0.033751, 0.024521},{1.244017, 0.029817, 0.025466},{
      1.242771, 0.029619, 0.025466},{1.241555, 0.033361, 0.024521}}],
    Polygon[{{1.242771, 0.029619, -0.025466},{1.241555, 0.033361, -0.024521},{
      1.239334, 0.032229, -0.024521},{1.241646, 0.029047, -0.025466}}],
    Polygon[{{1.241555, 0.033361, -0.024521},{1.240400, 0.036916, -0.022973},{
      1.237137, 0.035253, -0.022973},{1.239334, 0.032229, -0.024521}}],
    Polygon[{{1.240400, 0.036916, -0.022973},{1.239334, 0.040197, -0.020859},{
      1.235109, 0.038044, -0.020859},{1.237137, 0.035253, -0.022973}}],
    Polygon[{{1.239334, 0.040197, -0.020859},{1.238383, 0.043123, -0.018232},{
      1.233301, 0.040533, -0.018232},{1.235109, 0.038044, -0.020859}}],
    Polygon[{{1.238383, 0.043123, -0.018232},{1.237571, 0.045622, -0.015155},{
      1.231756, 0.042659, -0.015155},{1.233301, 0.040533, -0.018232}}],
    Polygon[{{1.237571, 0.045622, -0.015155},{1.236918, 0.047632, -0.011705},{
      1.230514, 0.044369, -0.011705},{1.231756, 0.042659, -0.015155}}],
    Polygon[{{1.236918, 0.047632, -0.011705},{1.236439, 0.049105, -0.007968},{
      1.229604, 0.045622, -0.007968},{1.230514, 0.044369, -0.011705}}],
    Polygon[{{1.236439, 0.049105, -0.007968},{1.236148, 0.050003, -0.004033},{
      1.229048, 0.046386, -0.004033},{1.229604, 0.045622, -0.007968}}],
    Polygon[{{1.236148, 0.050003, -0.004033},{1.236049, 0.050305, 0.000000},{
      1.228862, 0.046643, 0.000000},{1.229048, 0.046386, -0.004033}}],
    Polygon[{{1.236049, 0.050305, 0.000000},{1.236148, 0.050003, 0.004033},{
      1.229048, 0.046386, 0.004033},{1.228862, 0.046643, 0.000000}}],
    Polygon[{{1.236148, 0.050003, 0.004033},{1.236439, 0.049105, 0.007968},{
      1.229604, 0.045622, 0.007968},{1.229048, 0.046386, 0.004033}}],
    Polygon[{{1.236439, 0.049105, 0.007968},{1.236918, 0.047632, 0.011705},{
      1.230514, 0.044369, 0.011705},{1.229604, 0.045622, 0.007968}}],
    Polygon[{{1.236918, 0.047632, 0.011705},{1.237571, 0.045622, 0.015155},{
      1.231756, 0.042659, 0.015155},{1.230514, 0.044369, 0.011705}}],
    Polygon[{{1.237571, 0.045622, 0.015155},{1.238383, 0.043123, 0.018232},{
      1.233301, 0.040533, 0.018232},{1.231756, 0.042659, 0.015155}}],
    Polygon[{{1.238383, 0.043123, 0.018232},{1.239334, 0.040197, 0.020859},{
      1.235109, 0.038044, 0.020859},{1.233301, 0.040533, 0.018232}}],
    Polygon[{{1.239334, 0.040197, 0.020859},{1.240400, 0.036916, 0.022973},{
      1.237137, 0.035253, 0.022973},{1.235109, 0.038044, 0.020859}}],
    Polygon[{{1.240400, 0.036916, 0.022973},{1.241555, 0.033361, 0.024521},{
      1.239334, 0.032229, 0.024521},{1.237137, 0.035253, 0.022973}}],
    Polygon[{{1.241555, 0.033361, 0.024521},{1.242771, 0.029619, 0.025466},{
      1.241646, 0.029047, 0.025466},{1.239334, 0.032229, 0.024521}}],
    Polygon[{{1.241646, 0.029047, -0.025466},{1.239334, 0.032229, -0.024521},{
      1.237571, 0.030467, -0.024521},{1.240754, 0.028154, -0.025466}}],
    Polygon[{{1.239334, 0.032229, -0.024521},{1.237137, 0.035253, -0.022973},{
      1.234547, 0.032664, -0.022973},{1.237571, 0.030467, -0.024521}}],
    Polygon[{{1.237137, 0.035253, -0.022973},{1.235109, 0.038044, -0.020859},{
      1.231756, 0.034691, -0.020859},{1.234547, 0.032664, -0.022973}}],
    Polygon[{{1.235109, 0.038044, -0.020859},{1.233301, 0.040533, -0.018232},{
      1.229267, 0.036500, -0.018232},{1.231756, 0.034691, -0.020859}}],
    Polygon[{{1.233301, 0.040533, -0.018232},{1.231756, 0.042659, -0.015155},{
      1.227141, 0.038044, -0.015155},{1.229267, 0.036500, -0.018232}}],
    Polygon[{{1.231756, 0.042659, -0.015155},{1.230514, 0.044369, -0.011705},{
      1.225431, 0.039287, -0.011705},{1.227141, 0.038044, -0.015155}}],
    Polygon[{{1.230514, 0.044369, -0.011705},{1.229604, 0.045622, -0.007968},{
      1.224179, 0.040197, -0.007968},{1.225431, 0.039287, -0.011705}}],
    Polygon[{{1.229604, 0.045622, -0.007968},{1.229048, 0.046386, -0.004033},{
      1.223415, 0.040752, -0.004033},{1.224179, 0.040197, -0.007968}}],
    Polygon[{{1.229048, 0.046386, -0.004033},{1.228862, 0.046643, 0.000000},{
      1.223158, 0.040939, 0.000000},{1.223415, 0.040752, -0.004033}}],
    Polygon[{{1.228862, 0.046643, 0.000000},{1.229048, 0.046386, 0.004033},{
      1.223415, 0.040752, 0.004033},{1.223158, 0.040939, 0.000000}}],
    Polygon[{{1.229048, 0.046386, 0.004033},{1.229604, 0.045622, 0.007968},{
      1.224179, 0.040197, 0.007968},{1.223415, 0.040752, 0.004033}}],
    Polygon[{{1.229604, 0.045622, 0.007968},{1.230514, 0.044369, 0.011705},{
      1.225431, 0.039287, 0.011705},{1.224179, 0.040197, 0.007968}}],
    Polygon[{{1.230514, 0.044369, 0.011705},{1.231756, 0.042659, 0.015155},{
      1.227141, 0.038044, 0.015155},{1.225431, 0.039287, 0.011705}}],
    Polygon[{{1.231756, 0.042659, 0.015155},{1.233301, 0.040533, 0.018232},{
      1.229267, 0.036500, 0.018232},{1.227141, 0.038044, 0.015155}}],
    Polygon[{{1.233301, 0.040533, 0.018232},{1.235109, 0.038044, 0.020859},{
      1.231756, 0.034691, 0.020859},{1.229267, 0.036500, 0.018232}}],
    Polygon[{{1.235109, 0.038044, 0.020859},{1.237137, 0.035253, 0.022973},{
      1.234547, 0.032664, 0.022973},{1.231756, 0.034691, 0.020859}}],
    Polygon[{{1.237137, 0.035253, 0.022973},{1.239334, 0.032229, 0.024521},{
      1.237571, 0.030467, 0.024521},{1.234547, 0.032664, 0.022973}}],
    Polygon[{{1.239334, 0.032229, 0.024521},{1.241646, 0.029047, 0.025466},{
      1.240754, 0.028154, 0.025466},{1.237571, 0.030467, 0.024521}}],
    Polygon[{{1.240754, 0.028154, -0.025466},{1.237571, 0.030467, -0.024521},{
      1.236439, 0.028246, -0.024521},{1.240181, 0.027030, -0.025466}}],
    Polygon[{{1.237571, 0.030467, -0.024521},{1.234547, 0.032664, -0.022973},{
      1.232884, 0.029401, -0.022973},{1.236439, 0.028246, -0.024521}}],
    Polygon[{{1.234547, 0.032664, -0.022973},{1.231756, 0.034691, -0.020859},{
      1.229604, 0.030467, -0.020859},{1.232884, 0.029401, -0.022973}}],
    Polygon[{{1.231756, 0.034691, -0.020859},{1.229267, 0.036500, -0.018232},{
      1.226678, 0.031417, -0.018232},{1.229604, 0.030467, -0.020859}}],
    Polygon[{{1.229267, 0.036500, -0.018232},{1.227141, 0.038044, -0.015155},{
      1.224179, 0.032229, -0.015155},{1.226678, 0.031417, -0.018232}}],
    Polygon[{{1.227141, 0.038044, -0.015155},{1.225431, 0.039287, -0.011705},{
      1.222168, 0.032883, -0.011705},{1.224179, 0.032229, -0.015155}}],
    Polygon[{{1.225431, 0.039287, -0.011705},{1.224179, 0.040197, -0.007968},{
      1.220696, 0.033361, -0.007968},{1.222168, 0.032883, -0.011705}}],
    Polygon[{{1.224179, 0.040197, -0.007968},{1.223415, 0.040752, -0.004033},{
      1.219797, 0.033653, -0.004033},{1.220696, 0.033361, -0.007968}}],
    Polygon[{{1.223415, 0.040752, -0.004033},{1.223158, 0.040939, 0.000000},{
      1.219495, 0.033751, 0.000000},{1.219797, 0.033653, -0.004033}}],
    Polygon[{{1.223158, 0.040939, 0.000000},{1.223415, 0.040752, 0.004033},{
      1.219797, 0.033653, 0.004033},{1.219495, 0.033751, 0.000000}}],
    Polygon[{{1.223415, 0.040752, 0.004033},{1.224179, 0.040197, 0.007968},{
      1.220696, 0.033361, 0.007968},{1.219797, 0.033653, 0.004033}}],
    Polygon[{{1.224179, 0.040197, 0.007968},{1.225431, 0.039287, 0.011705},{
      1.222168, 0.032883, 0.011705},{1.220696, 0.033361, 0.007968}}],
    Polygon[{{1.225431, 0.039287, 0.011705},{1.227141, 0.038044, 0.015155},{
      1.224179, 0.032229, 0.015155},{1.222168, 0.032883, 0.011705}}],
    Polygon[{{1.227141, 0.038044, 0.015155},{1.229267, 0.036500, 0.018232},{
      1.226678, 0.031417, 0.018232},{1.224179, 0.032229, 0.015155}}],
    Polygon[{{1.229267, 0.036500, 0.018232},{1.231756, 0.034691, 0.020859},{
      1.229604, 0.030467, 0.020859},{1.226678, 0.031417, 0.018232}}],
    Polygon[{{1.231756, 0.034691, 0.020859},{1.234547, 0.032664, 0.022973},{
      1.232884, 0.029401, 0.022973},{1.229604, 0.030467, 0.020859}}],
    Polygon[{{1.234547, 0.032664, 0.022973},{1.237571, 0.030467, 0.024521},{
      1.236439, 0.028246, 0.024521},{1.232884, 0.029401, 0.022973}}],
    Polygon[{{1.237571, 0.030467, 0.024521},{1.240754, 0.028154, 0.025466},{
      1.240181, 0.027030, 0.025466},{1.236439, 0.028246, 0.024521}}],
    Polygon[{{1.240181, 0.027030, -0.025466},{1.236439, 0.028246, -0.024521},{
      1.236049, 0.025783, -0.024521},{1.239984, 0.025783, -0.025466}}],
    Polygon[{{1.236439, 0.028246, -0.024521},{1.232884, 0.029401, -0.022973},{
      1.232311, 0.025783, -0.022973},{1.236049, 0.025783, -0.024521}}],
    Polygon[{{1.232884, 0.029401, -0.022973},{1.229604, 0.030467, -0.020859},{
      1.228862, 0.025783, -0.020859},{1.232311, 0.025783, -0.022973}}],
    Polygon[{{1.229604, 0.030467, -0.020859},{1.226678, 0.031417, -0.018232},{
      1.225785, 0.025783, -0.018232},{1.228862, 0.025783, -0.020859}}],
    Polygon[{{1.226678, 0.031417, -0.018232},{1.224179, 0.032229, -0.015155},{
      1.223158, 0.025783, -0.015155},{1.225785, 0.025783, -0.018232}}],
    Polygon[{{1.224179, 0.032229, -0.015155},{1.222168, 0.032883, -0.011705},{
      1.221044, 0.025783, -0.011705},{1.223158, 0.025783, -0.015155}}],
    Polygon[{{1.222168, 0.032883, -0.011705},{1.220696, 0.033361, -0.007968},{
      1.219495, 0.025783, -0.007968},{1.221044, 0.025783, -0.011705}}],
    Polygon[{{1.220696, 0.033361, -0.007968},{1.219797, 0.033653, -0.004033},{
      1.218551, 0.025783, -0.004033},{1.219495, 0.025783, -0.007968}}],
    Polygon[{{1.219797, 0.033653, -0.004033},{1.219495, 0.033751, 0.000000},{
      1.218233, 0.025783, 0.000000},{1.218551, 0.025783, -0.004033}}],
    Polygon[{{1.219495, 0.033751, 0.000000},{1.219797, 0.033653, 0.004033},{
      1.218551, 0.025783, 0.004033},{1.218233, 0.025783, 0.000000}}],
    Polygon[{{1.219797, 0.033653, 0.004033},{1.220696, 0.033361, 0.007968},{
      1.219495, 0.025783, 0.007968},{1.218551, 0.025783, 0.004033}}],
    Polygon[{{1.220696, 0.033361, 0.007968},{1.222168, 0.032883, 0.011705},{
      1.221044, 0.025783, 0.011705},{1.219495, 0.025783, 0.007968}}],
    Polygon[{{1.222168, 0.032883, 0.011705},{1.224179, 0.032229, 0.015155},{
      1.223158, 0.025783, 0.015155},{1.221044, 0.025783, 0.011705}}],
    Polygon[{{1.224179, 0.032229, 0.015155},{1.226678, 0.031417, 0.018232},{
      1.225785, 0.025783, 0.018232},{1.223158, 0.025783, 0.015155}}],
    Polygon[{{1.226678, 0.031417, 0.018232},{1.229604, 0.030467, 0.020859},{
      1.228862, 0.025783, 0.020859},{1.225785, 0.025783, 0.018232}}],
    Polygon[{{1.229604, 0.030467, 0.020859},{1.232884, 0.029401, 0.022973},{
      1.232311, 0.025783, 0.022973},{1.228862, 0.025783, 0.020859}}],
    Polygon[{{1.232884, 0.029401, 0.022973},{1.236439, 0.028246, 0.024521},{
      1.236049, 0.025783, 0.024521},{1.232311, 0.025783, 0.022973}}],
    Polygon[{{1.236439, 0.028246, 0.024521},{1.240181, 0.027030, 0.025466},{
      1.239984, 0.025783, 0.025466},{1.236049, 0.025783, 0.024521}}],
    Polygon[{{1.239984, 0.025783, -0.025466},{1.236049, 0.025783, -0.024521},{
      1.236439, 0.023321, -0.024521},{1.240181, 0.024537, -0.025466}}],
    Polygon[{{1.236049, 0.025783, -0.024521},{1.232311, 0.025783, -0.022973},{
      1.232884, 0.022166, -0.022973},{1.236439, 0.023321, -0.024521}}],
    Polygon[{{1.232311, 0.025783, -0.022973},{1.228862, 0.025783, -0.020859},{
      1.229604, 0.021100, -0.020859},{1.232884, 0.022166, -0.022973}}],
    Polygon[{{1.228862, 0.025783, -0.020859},{1.225785, 0.025783, -0.018232},{
      1.226678, 0.020150, -0.018232},{1.229604, 0.021100, -0.020859}}],
    Polygon[{{1.225785, 0.025783, -0.018232},{1.223158, 0.025783, -0.015155},{
      1.224179, 0.019338, -0.015155},{1.226678, 0.020150, -0.018232}}],
    Polygon[{{1.223158, 0.025783, -0.015155},{1.221044, 0.025783, -0.011705},{
      1.222168, 0.018684, -0.011705},{1.224179, 0.019338, -0.015155}}],
    Polygon[{{1.221044, 0.025783, -0.011705},{1.219495, 0.025783, -0.007968},{
      1.220696, 0.018206, -0.007968},{1.222168, 0.018684, -0.011705}}],
    Polygon[{{1.219495, 0.025783, -0.007968},{1.218551, 0.025783, -0.004033},{
      1.219797, 0.017914, -0.004033},{1.220696, 0.018206, -0.007968}}],
    Polygon[{{1.218551, 0.025783, -0.004033},{1.218233, 0.025783, 0.000000},{
      1.219495, 0.017816, 0.000000},{1.219797, 0.017914, -0.004033}}],
    Polygon[{{1.218233, 0.025783, 0.000000},{1.218551, 0.025783, 0.004033},{
      1.219797, 0.017914, 0.004033},{1.219495, 0.017816, 0.000000}}],
    Polygon[{{1.218551, 0.025783, 0.004033},{1.219495, 0.025783, 0.007968},{
      1.220696, 0.018206, 0.007968},{1.219797, 0.017914, 0.004033}}],
    Polygon[{{1.219495, 0.025783, 0.007968},{1.221044, 0.025783, 0.011705},{
      1.222168, 0.018684, 0.011705},{1.220696, 0.018206, 0.007968}}],
    Polygon[{{1.221044, 0.025783, 0.011705},{1.223158, 0.025783, 0.015155},{
      1.224179, 0.019338, 0.015155},{1.222168, 0.018684, 0.011705}}],
    Polygon[{{1.223158, 0.025783, 0.015155},{1.225785, 0.025783, 0.018232},{
      1.226678, 0.020150, 0.018232},{1.224179, 0.019338, 0.015155}}],
    Polygon[{{1.225785, 0.025783, 0.018232},{1.228862, 0.025783, 0.020859},{
      1.229604, 0.021100, 0.020859},{1.226678, 0.020150, 0.018232}}],
    Polygon[{{1.228862, 0.025783, 0.020859},{1.232311, 0.025783, 0.022973},{
      1.232884, 0.022166, 0.022973},{1.229604, 0.021100, 0.020859}}],
    Polygon[{{1.232311, 0.025783, 0.022973},{1.236049, 0.025783, 0.024521},{
      1.236439, 0.023321, 0.024521},{1.232884, 0.022166, 0.022973}}],
    Polygon[{{1.236049, 0.025783, 0.024521},{1.239984, 0.025783, 0.025466},{
      1.240181, 0.024537, 0.025466},{1.236439, 0.023321, 0.024521}}],
    Polygon[{{1.240181, 0.024537, -0.025466},{1.236439, 0.023321, -0.024521},{
      1.237571, 0.021100, -0.024521},{1.240754, 0.023413, -0.025466}}],
    Polygon[{{1.236439, 0.023321, -0.024521},{1.232884, 0.022166, -0.022973},{
      1.234547, 0.018903, -0.022973},{1.237571, 0.021100, -0.024521}}],
    Polygon[{{1.232884, 0.022166, -0.022973},{1.229604, 0.021100, -0.020859},{
      1.231756, 0.016875, -0.020859},{1.234547, 0.018903, -0.022973}}],
    Polygon[{{1.229604, 0.021100, -0.020859},{1.226678, 0.020150, -0.018232},{
      1.229267, 0.015067, -0.018232},{1.231756, 0.016875, -0.020859}}],
    Polygon[{{1.226678, 0.020150, -0.018232},{1.224179, 0.019338, -0.015155},{
      1.227141, 0.013523, -0.015155},{1.229267, 0.015067, -0.018232}}],
    Polygon[{{1.224179, 0.019338, -0.015155},{1.222168, 0.018684, -0.011705},{
      1.225431, 0.012280, -0.011705},{1.227141, 0.013523, -0.015155}}],
    Polygon[{{1.222168, 0.018684, -0.011705},{1.220696, 0.018206, -0.007968},{
      1.224179, 0.011370, -0.007968},{1.225431, 0.012280, -0.011705}}],
    Polygon[{{1.220696, 0.018206, -0.007968},{1.219797, 0.017914, -0.004033},{
      1.223415, 0.010815, -0.004033},{1.224179, 0.011370, -0.007968}}],
    Polygon[{{1.219797, 0.017914, -0.004033},{1.219495, 0.017816, 0.000000},{
      1.223158, 0.010628, 0.000000},{1.223415, 0.010815, -0.004033}}],
    Polygon[{{1.219495, 0.017816, 0.000000},{1.219797, 0.017914, 0.004033},{
      1.223415, 0.010815, 0.004033},{1.223158, 0.010628, 0.000000}}],
    Polygon[{{1.219797, 0.017914, 0.004033},{1.220696, 0.018206, 0.007968},{
      1.224179, 0.011370, 0.007968},{1.223415, 0.010815, 0.004033}}],
    Polygon[{{1.220696, 0.018206, 0.007968},{1.222168, 0.018684, 0.011705},{
      1.225431, 0.012280, 0.011705},{1.224179, 0.011370, 0.007968}}],
    Polygon[{{1.222168, 0.018684, 0.011705},{1.224179, 0.019338, 0.015155},{
      1.227141, 0.013523, 0.015155},{1.225431, 0.012280, 0.011705}}],
    Polygon[{{1.224179, 0.019338, 0.015155},{1.226678, 0.020150, 0.018232},{
      1.229267, 0.015067, 0.018232},{1.227141, 0.013523, 0.015155}}],
    Polygon[{{1.226678, 0.020150, 0.018232},{1.229604, 0.021100, 0.020859},{
      1.231756, 0.016875, 0.020859},{1.229267, 0.015067, 0.018232}}],
    Polygon[{{1.229604, 0.021100, 0.020859},{1.232884, 0.022166, 0.022973},{
      1.234547, 0.018903, 0.022973},{1.231756, 0.016875, 0.020859}}],
    Polygon[{{1.232884, 0.022166, 0.022973},{1.236439, 0.023321, 0.024521},{
      1.237571, 0.021100, 0.024521},{1.234547, 0.018903, 0.022973}}],
    Polygon[{{1.236439, 0.023321, 0.024521},{1.240181, 0.024537, 0.025466},{
      1.240754, 0.023413, 0.025466},{1.237571, 0.021100, 0.024521}}],
    Polygon[{{1.240754, 0.023413, -0.025466},{1.237571, 0.021100, -0.024521},{
      1.239334, 0.019338, -0.024521},{1.241646, 0.022520, -0.025466}}],
    Polygon[{{1.237571, 0.021100, -0.024521},{1.234547, 0.018903, -0.022973},{
      1.237137, 0.016314, -0.022973},{1.239334, 0.019338, -0.024521}}],
    Polygon[{{1.234547, 0.018903, -0.022973},{1.231756, 0.016875, -0.020859},{
      1.235109, 0.013523, -0.020859},{1.237137, 0.016314, -0.022973}}],
    Polygon[{{1.231756, 0.016875, -0.020859},{1.229267, 0.015067, -0.018232},{
      1.233301, 0.011034, -0.018232},{1.235109, 0.013523, -0.020859}}],
    Polygon[{{1.229267, 0.015067, -0.018232},{1.227141, 0.013523, -0.015155},{
      1.231756, 0.008908, -0.015155},{1.233301, 0.011034, -0.018232}}],
    Polygon[{{1.227141, 0.013523, -0.015155},{1.225431, 0.012280, -0.011705},{
      1.230514, 0.007198, -0.011705},{1.231756, 0.008908, -0.015155}}],
    Polygon[{{1.225431, 0.012280, -0.011705},{1.224179, 0.011370, -0.007968},{
      1.229604, 0.005945, -0.007968},{1.230514, 0.007198, -0.011705}}],
    Polygon[{{1.224179, 0.011370, -0.007968},{1.223415, 0.010815, -0.004033},{
      1.229048, 0.005181, -0.004033},{1.229604, 0.005945, -0.007968}}],
    Polygon[{{1.223415, 0.010815, -0.004033},{1.223158, 0.010628, 0.000000},{
      1.228862, 0.004924, 0.000000},{1.229048, 0.005181, -0.004033}}],
    Polygon[{{1.223158, 0.010628, 0.000000},{1.223415, 0.010815, 0.004033},{
      1.229048, 0.005181, 0.004033},{1.228862, 0.004924, 0.000000}}],
    Polygon[{{1.223415, 0.010815, 0.004033},{1.224179, 0.011370, 0.007968},{
      1.229604, 0.005945, 0.007968},{1.229048, 0.005181, 0.004033}}],
    Polygon[{{1.224179, 0.011370, 0.007968},{1.225431, 0.012280, 0.011705},{
      1.230514, 0.007198, 0.011705},{1.229604, 0.005945, 0.007968}}],
    Polygon[{{1.225431, 0.012280, 0.011705},{1.227141, 0.013523, 0.015155},{
      1.231756, 0.008908, 0.015155},{1.230514, 0.007198, 0.011705}}],
    Polygon[{{1.227141, 0.013523, 0.015155},{1.229267, 0.015067, 0.018232},{
      1.233301, 0.011034, 0.018232},{1.231756, 0.008908, 0.015155}}],
    Polygon[{{1.229267, 0.015067, 0.018232},{1.231756, 0.016875, 0.020859},{
      1.235109, 0.013523, 0.020859},{1.233301, 0.011034, 0.018232}}],
    Polygon[{{1.231756, 0.016875, 0.020859},{1.234547, 0.018903, 0.022973},{
      1.237137, 0.016314, 0.022973},{1.235109, 0.013523, 0.020859}}],
    Polygon[{{1.234547, 0.018903, 0.022973},{1.237571, 0.021100, 0.024521},{
      1.239334, 0.019338, 0.024521},{1.237137, 0.016314, 0.022973}}],
    Polygon[{{1.237571, 0.021100, 0.024521},{1.240754, 0.023413, 0.025466},{
      1.241646, 0.022520, 0.025466},{1.239334, 0.019338, 0.024521}}],
    Polygon[{{1.241646, 0.022520, -0.025466},{1.239334, 0.019338, -0.024521},{
      1.241555, 0.018206, -0.024521},{1.242771, 0.021947, -0.025466}}],
    Polygon[{{1.239334, 0.019338, -0.024521},{1.237137, 0.016314, -0.022973},{
      1.240400, 0.014651, -0.022973},{1.241555, 0.018206, -0.024521}}],
    Polygon[{{1.237137, 0.016314, -0.022973},{1.235109, 0.013523, -0.020859},{
      1.239334, 0.011370, -0.020859},{1.240400, 0.014651, -0.022973}}],
    Polygon[{{1.235109, 0.013523, -0.020859},{1.233301, 0.011034, -0.018232},{
      1.238383, 0.008444, -0.018232},{1.239334, 0.011370, -0.020859}}],
    Polygon[{{1.233301, 0.011034, -0.018232},{1.231756, 0.008908, -0.015155},{
      1.237571, 0.005945, -0.015155},{1.238383, 0.008444, -0.018232}}],
    Polygon[{{1.231756, 0.008908, -0.015155},{1.230514, 0.007198, -0.011705},{
      1.236918, 0.003935, -0.011705},{1.237571, 0.005945, -0.015155}}],
    Polygon[{{1.230514, 0.007198, -0.011705},{1.229604, 0.005945, -0.007968},{
      1.236439, 0.002462, -0.007968},{1.236918, 0.003935, -0.011705}}],
    Polygon[{{1.229604, 0.005945, -0.007968},{1.229048, 0.005181, -0.004033},{
      1.236148, 0.001564, -0.004033},{1.236439, 0.002462, -0.007968}}],
    Polygon[{{1.229048, 0.005181, -0.004033},{1.228862, 0.004924, 0.000000},{
      1.236049, 0.001262, 0.000000},{1.236148, 0.001564, -0.004033}}],
    Polygon[{{1.228862, 0.004924, 0.000000},{1.229048, 0.005181, 0.004033},{
      1.236148, 0.001564, 0.004033},{1.236049, 0.001262, 0.000000}}],
    Polygon[{{1.229048, 0.005181, 0.004033},{1.229604, 0.005945, 0.007968},{
      1.236439, 0.002462, 0.007968},{1.236148, 0.001564, 0.004033}}],
    Polygon[{{1.229604, 0.005945, 0.007968},{1.230514, 0.007198, 0.011705},{
      1.236918, 0.003935, 0.011705},{1.236439, 0.002462, 0.007968}}],
    Polygon[{{1.230514, 0.007198, 0.011705},{1.231756, 0.008908, 0.015155},{
      1.237571, 0.005945, 0.015155},{1.236918, 0.003935, 0.011705}}],
    Polygon[{{1.231756, 0.008908, 0.015155},{1.233301, 0.011034, 0.018232},{
      1.238383, 0.008444, 0.018232},{1.237571, 0.005945, 0.015155}}],
    Polygon[{{1.233301, 0.011034, 0.018232},{1.235109, 0.013523, 0.020859},{
      1.239334, 0.011370, 0.020859},{1.238383, 0.008444, 0.018232}}],
    Polygon[{{1.235109, 0.013523, 0.020859},{1.237137, 0.016314, 0.022973},{
      1.240400, 0.014651, 0.022973},{1.239334, 0.011370, 0.020859}}],
    Polygon[{{1.237137, 0.016314, 0.022973},{1.239334, 0.019338, 0.024521},{
      1.241555, 0.018206, 0.024521},{1.240400, 0.014651, 0.022973}}],
    Polygon[{{1.239334, 0.019338, 0.024521},{1.241646, 0.022520, 0.025466},{
      1.242771, 0.021947, 0.025466},{1.241555, 0.018206, 0.024521}}],
    Polygon[{{1.242771, 0.021947, -0.025466},{1.241555, 0.018206, -0.024521},{
      1.244017, 0.017816, -0.024521},{1.244017, 0.021750, -0.025466}}],
    Polygon[{{1.241555, 0.018206, -0.024521},{1.240400, 0.014651, -0.022973},{
      1.244017, 0.014078, -0.022973},{1.244017, 0.017816, -0.024521}}],
    Polygon[{{1.240400, 0.014651, -0.022973},{1.239334, 0.011370, -0.020859},{
      1.244017, 0.010628, -0.020859},{1.244017, 0.014078, -0.022973}}],
    Polygon[{{1.239334, 0.011370, -0.020859},{1.238383, 0.008444, -0.018232},{
      1.244017, 0.007552, -0.018232},{1.244017, 0.010628, -0.020859}}],
    Polygon[{{1.238383, 0.008444, -0.018232},{1.237571, 0.005945, -0.015155},{
      1.244017, 0.004924, -0.015155},{1.244017, 0.007552, -0.018232}}],
    Polygon[{{1.237571, 0.005945, -0.015155},{1.236918, 0.003935, -0.011705},{
      1.244017, 0.002810, -0.011705},{1.244017, 0.004924, -0.015155}}],
    Polygon[{{1.236918, 0.003935, -0.011705},{1.236439, 0.002462, -0.007968},{
      1.244017, 0.001262, -0.007968},{1.244017, 0.002810, -0.011705}}],
    Polygon[{{1.236439, 0.002462, -0.007968},{1.236148, 0.001564, -0.004033},{
      1.244017, 0.000317, -0.004033},{1.244017, 0.001262, -0.007968}}],
    Polygon[{{1.236148, 0.001564, -0.004033},{1.236049, 0.001262, 0.000000},{
      1.244017, 0.000000, 0.000000},{1.244017, 0.000317, -0.004033}}],
    Polygon[{{1.236049, 0.001262, 0.000000},{1.236148, 0.001564, 0.004033},{
      1.244017, 0.000317, 0.004033},{1.244017, 0.000000, 0.000000}}],
    Polygon[{{1.236148, 0.001564, 0.004033},{1.236439, 0.002462, 0.007968},{
      1.244017, 0.001262, 0.007968},{1.244017, 0.000317, 0.004033}}],
    Polygon[{{1.236439, 0.002462, 0.007968},{1.236918, 0.003935, 0.011705},{
      1.244017, 0.002810, 0.011705},{1.244017, 0.001262, 0.007968}}],
    Polygon[{{1.236918, 0.003935, 0.011705},{1.237571, 0.005945, 0.015155},{
      1.244017, 0.004924, 0.015155},{1.244017, 0.002810, 0.011705}}],
    Polygon[{{1.237571, 0.005945, 0.015155},{1.238383, 0.008444, 0.018232},{
      1.244017, 0.007552, 0.018232},{1.244017, 0.004924, 0.015155}}],
    Polygon[{{1.238383, 0.008444, 0.018232},{1.239334, 0.011370, 0.020859},{
      1.244017, 0.010628, 0.020859},{1.244017, 0.007552, 0.018232}}],
    Polygon[{{1.239334, 0.011370, 0.020859},{1.240400, 0.014651, 0.022973},{
      1.244017, 0.014078, 0.022973},{1.244017, 0.010628, 0.020859}}],
    Polygon[{{1.240400, 0.014651, 0.022973},{1.241555, 0.018206, 0.024521},{
      1.244017, 0.017816, 0.024521},{1.244017, 0.014078, 0.022973}}],
    Polygon[{{1.241555, 0.018206, 0.024521},{1.242771, 0.021947, 0.025466},{
      1.244017, 0.021750, 0.025466},{1.244017, 0.017816, 0.024521}}],
    Polygon[{{1.244017, 0.021750, -0.025466},{1.244017, 0.017816, -0.024521},{
      1.246479, 0.018206, -0.024521},{1.245263, 0.021947, -0.025466}}],
    Polygon[{{1.244017, 0.017816, -0.024521},{1.244017, 0.014078, -0.022973},{
      1.247634, 0.014651, -0.022973},{1.246479, 0.018206, -0.024521}}],
    Polygon[{{1.244017, 0.014078, -0.022973},{1.244017, 0.010628, -0.020859},{
      1.248700, 0.011370, -0.020859},{1.247634, 0.014651, -0.022973}}],
    Polygon[{{1.244017, 0.010628, -0.020859},{1.244017, 0.007552, -0.018232},{
      1.249651, 0.008444, -0.018232},{1.248700, 0.011370, -0.020859}}],
    Polygon[{{1.244017, 0.007552, -0.018232},{1.244017, 0.004924, -0.015155},{
      1.250463, 0.005945, -0.015155},{1.249651, 0.008444, -0.018232}}],
    Polygon[{{1.244017, 0.004924, -0.015155},{1.244017, 0.002810, -0.011705},{
      1.251116, 0.003935, -0.011705},{1.250463, 0.005945, -0.015155}}],
    Polygon[{{1.244017, 0.002810, -0.011705},{1.244017, 0.001262, -0.007968},{
      1.251595, 0.002462, -0.007968},{1.251116, 0.003935, -0.011705}}],
    Polygon[{{1.244017, 0.001262, -0.007968},{1.244017, 0.000317, -0.004033},{
      1.251886, 0.001564, -0.004033},{1.251595, 0.002462, -0.007968}}],
    Polygon[{{1.244017, 0.000317, -0.004033},{1.244017, 0.000000, 0.000000},{
      1.251984, 0.001262, 0.000000},{1.251886, 0.001564, -0.004033}}],
    Polygon[{{1.244017, 0.000000, 0.000000},{1.244017, 0.000317, 0.004033},{
      1.251886, 0.001564, 0.004033},{1.251984, 0.001262, 0.000000}}],
    Polygon[{{1.244017, 0.000317, 0.004033},{1.244017, 0.001262, 0.007968},{
      1.251595, 0.002462, 0.007968},{1.251886, 0.001564, 0.004033}}],
    Polygon[{{1.244017, 0.001262, 0.007968},{1.244017, 0.002810, 0.011705},{
      1.251116, 0.003935, 0.011705},{1.251595, 0.002462, 0.007968}}],
    Polygon[{{1.244017, 0.002810, 0.011705},{1.244017, 0.004924, 0.015155},{
      1.250463, 0.005945, 0.015155},{1.251116, 0.003935, 0.011705}}],
    Polygon[{{1.244017, 0.004924, 0.015155},{1.244017, 0.007552, 0.018232},{
      1.249651, 0.008444, 0.018232},{1.250463, 0.005945, 0.015155}}],
    Polygon[{{1.244017, 0.007552, 0.018232},{1.244017, 0.010628, 0.020859},{
      1.248700, 0.011370, 0.020859},{1.249651, 0.008444, 0.018232}}],
    Polygon[{{1.244017, 0.010628, 0.020859},{1.244017, 0.014078, 0.022973},{
      1.247634, 0.014651, 0.022973},{1.248700, 0.011370, 0.020859}}],
    Polygon[{{1.244017, 0.014078, 0.022973},{1.244017, 0.017816, 0.024521},{
      1.246479, 0.018206, 0.024521},{1.247634, 0.014651, 0.022973}}],
    Polygon[{{1.244017, 0.017816, 0.024521},{1.244017, 0.021750, 0.025466},{
      1.245263, 0.021947, 0.025466},{1.246479, 0.018206, 0.024521}}],
    Polygon[{{1.245263, 0.021947, -0.025466},{1.246479, 0.018206, -0.024521},{
      1.248700, 0.019338, -0.024521},{1.246388, 0.022520, -0.025466}}],
    Polygon[{{1.246479, 0.018206, -0.024521},{1.247634, 0.014651, -0.022973},{
      1.250897, 0.016314, -0.022973},{1.248700, 0.019338, -0.024521}}],
    Polygon[{{1.247634, 0.014651, -0.022973},{1.248700, 0.011370, -0.020859},{
      1.252925, 0.013523, -0.020859},{1.250897, 0.016314, -0.022973}}],
    Polygon[{{1.248700, 0.011370, -0.020859},{1.249651, 0.008444, -0.018232},{
      1.254733, 0.011034, -0.018232},{1.252925, 0.013523, -0.020859}}],
    Polygon[{{1.249651, 0.008444, -0.018232},{1.250463, 0.005945, -0.015155},{
      1.256278, 0.008908, -0.015155},{1.254733, 0.011034, -0.018232}}],
    Polygon[{{1.250463, 0.005945, -0.015155},{1.251116, 0.003935, -0.011705},{
      1.257520, 0.007198, -0.011705},{1.256278, 0.008908, -0.015155}}],
    Polygon[{{1.251116, 0.003935, -0.011705},{1.251595, 0.002462, -0.007968},{
      1.258430, 0.005945, -0.007968},{1.257520, 0.007198, -0.011705}}],
    Polygon[{{1.251595, 0.002462, -0.007968},{1.251886, 0.001564, -0.004033},{
      1.258986, 0.005181, -0.004033},{1.258430, 0.005945, -0.007968}}],
    Polygon[{{1.251886, 0.001564, -0.004033},{1.251984, 0.001262, 0.000000},{
      1.259172, 0.004924, 0.000000},{1.258986, 0.005181, -0.004033}}],
    Polygon[{{1.251984, 0.001262, 0.000000},{1.251886, 0.001564, 0.004033},{
      1.258986, 0.005181, 0.004033},{1.259172, 0.004924, 0.000000}}],
    Polygon[{{1.251886, 0.001564, 0.004033},{1.251595, 0.002462, 0.007968},{
      1.258430, 0.005945, 0.007968},{1.258986, 0.005181, 0.004033}}],
    Polygon[{{1.251595, 0.002462, 0.007968},{1.251116, 0.003935, 0.011705},{
      1.257520, 0.007198, 0.011705},{1.258430, 0.005945, 0.007968}}],
    Polygon[{{1.251116, 0.003935, 0.011705},{1.250463, 0.005945, 0.015155},{
      1.256278, 0.008908, 0.015155},{1.257520, 0.007198, 0.011705}}],
    Polygon[{{1.250463, 0.005945, 0.015155},{1.249651, 0.008444, 0.018232},{
      1.254733, 0.011034, 0.018232},{1.256278, 0.008908, 0.015155}}],
    Polygon[{{1.249651, 0.008444, 0.018232},{1.248700, 0.011370, 0.020859},{
      1.252925, 0.013523, 0.020859},{1.254733, 0.011034, 0.018232}}],
    Polygon[{{1.248700, 0.011370, 0.020859},{1.247634, 0.014651, 0.022973},{
      1.250897, 0.016314, 0.022973},{1.252925, 0.013523, 0.020859}}],
    Polygon[{{1.247634, 0.014651, 0.022973},{1.246479, 0.018206, 0.024521},{
      1.248700, 0.019338, 0.024521},{1.250897, 0.016314, 0.022973}}],
    Polygon[{{1.246479, 0.018206, 0.024521},{1.245263, 0.021947, 0.025466},{
      1.246388, 0.022520, 0.025466},{1.248700, 0.019338, 0.024521}}],
    Polygon[{{1.246388, 0.022520, -0.025466},{1.248700, 0.019338, -0.024521},{
      1.250463, 0.021100, -0.024521},{1.247280, 0.023413, -0.025466}}],
    Polygon[{{1.248700, 0.019338, -0.024521},{1.250897, 0.016314, -0.022973},{
      1.253487, 0.018903, -0.022973},{1.250463, 0.021100, -0.024521}}],
    Polygon[{{1.250897, 0.016314, -0.022973},{1.252925, 0.013523, -0.020859},{
      1.256278, 0.016875, -0.020859},{1.253487, 0.018903, -0.022973}}],
    Polygon[{{1.252925, 0.013523, -0.020859},{1.254733, 0.011034, -0.018232},{
      1.258767, 0.015067, -0.018232},{1.256278, 0.016875, -0.020859}}],
    Polygon[{{1.254733, 0.011034, -0.018232},{1.256278, 0.008908, -0.015155},{
      1.260892, 0.013523, -0.015155},{1.258767, 0.015067, -0.018232}}],
    Polygon[{{1.256278, 0.008908, -0.015155},{1.257520, 0.007198, -0.011705},{
      1.262603, 0.012280, -0.011705},{1.260892, 0.013523, -0.015155}}],
    Polygon[{{1.257520, 0.007198, -0.011705},{1.258430, 0.005945, -0.007968},{
      1.263855, 0.011370, -0.007968},{1.262603, 0.012280, -0.011705}}],
    Polygon[{{1.258430, 0.005945, -0.007968},{1.258986, 0.005181, -0.004033},{
      1.264619, 0.010815, -0.004033},{1.263855, 0.011370, -0.007968}}],
    Polygon[{{1.258986, 0.005181, -0.004033},{1.259172, 0.004924, 0.000000},{
      1.264876, 0.010628, 0.000000},{1.264619, 0.010815, -0.004033}}],
    Polygon[{{1.259172, 0.004924, 0.000000},{1.258986, 0.005181, 0.004033},{
      1.264619, 0.010815, 0.004033},{1.264876, 0.010628, 0.000000}}],
    Polygon[{{1.258986, 0.005181, 0.004033},{1.258430, 0.005945, 0.007968},{
      1.263855, 0.011370, 0.007968},{1.264619, 0.010815, 0.004033}}],
    Polygon[{{1.258430, 0.005945, 0.007968},{1.257520, 0.007198, 0.011705},{
      1.262603, 0.012280, 0.011705},{1.263855, 0.011370, 0.007968}}],
    Polygon[{{1.257520, 0.007198, 0.011705},{1.256278, 0.008908, 0.015155},{
      1.260892, 0.013523, 0.015155},{1.262603, 0.012280, 0.011705}}],
    Polygon[{{1.256278, 0.008908, 0.015155},{1.254733, 0.011034, 0.018232},{
      1.258767, 0.015067, 0.018232},{1.260892, 0.013523, 0.015155}}],
    Polygon[{{1.254733, 0.011034, 0.018232},{1.252925, 0.013523, 0.020859},{
      1.256278, 0.016875, 0.020859},{1.258767, 0.015067, 0.018232}}],
    Polygon[{{1.252925, 0.013523, 0.020859},{1.250897, 0.016314, 0.022973},{
      1.253487, 0.018903, 0.022973},{1.256278, 0.016875, 0.020859}}],
    Polygon[{{1.250897, 0.016314, 0.022973},{1.248700, 0.019338, 0.024521},{
      1.250463, 0.021100, 0.024521},{1.253487, 0.018903, 0.022973}}],
    Polygon[{{1.248700, 0.019338, 0.024521},{1.246388, 0.022520, 0.025466},{
      1.247280, 0.023413, 0.025466},{1.250463, 0.021100, 0.024521}}],
    Polygon[{{1.247280, 0.023413, -0.025466},{1.250463, 0.021100, -0.024521},{
      1.251595, 0.023321, -0.024521},{1.247853, 0.024537, -0.025466}}],
    Polygon[{{1.250463, 0.021100, -0.024521},{1.253487, 0.018903, -0.022973},{
      1.255149, 0.022166, -0.022973},{1.251595, 0.023321, -0.024521}}],
    Polygon[{{1.253487, 0.018903, -0.022973},{1.256278, 0.016875, -0.020859},{
      1.258430, 0.021100, -0.020859},{1.255149, 0.022166, -0.022973}}],
    Polygon[{{1.256278, 0.016875, -0.020859},{1.258767, 0.015067, -0.018232},{
      1.261356, 0.020150, -0.018232},{1.258430, 0.021100, -0.020859}}],
    Polygon[{{1.258767, 0.015067, -0.018232},{1.260892, 0.013523, -0.015155},{
      1.263855, 0.019338, -0.015155},{1.261356, 0.020150, -0.018232}}],
    Polygon[{{1.260892, 0.013523, -0.015155},{1.262603, 0.012280, -0.011705},{
      1.265866, 0.018684, -0.011705},{1.263855, 0.019338, -0.015155}}],
    Polygon[{{1.262603, 0.012280, -0.011705},{1.263855, 0.011370, -0.007968},{
      1.267338, 0.018206, -0.007968},{1.265866, 0.018684, -0.011705}}],
    Polygon[{{1.263855, 0.011370, -0.007968},{1.264619, 0.010815, -0.004033},{
      1.268237, 0.017914, -0.004033},{1.267338, 0.018206, -0.007968}}],
    Polygon[{{1.264619, 0.010815, -0.004033},{1.264876, 0.010628, 0.000000},{
      1.268538, 0.017816, 0.000000},{1.268237, 0.017914, -0.004033}}],
    Polygon[{{1.264876, 0.010628, 0.000000},{1.264619, 0.010815, 0.004033},{
      1.268237, 0.017914, 0.004033},{1.268538, 0.017816, 0.000000}}],
    Polygon[{{1.264619, 0.010815, 0.004033},{1.263855, 0.011370, 0.007968},{
      1.267338, 0.018206, 0.007968},{1.268237, 0.017914, 0.004033}}],
    Polygon[{{1.263855, 0.011370, 0.007968},{1.262603, 0.012280, 0.011705},{
      1.265866, 0.018684, 0.011705},{1.267338, 0.018206, 0.007968}}],
    Polygon[{{1.262603, 0.012280, 0.011705},{1.260892, 0.013523, 0.015155},{
      1.263855, 0.019338, 0.015155},{1.265866, 0.018684, 0.011705}}],
    Polygon[{{1.260892, 0.013523, 0.015155},{1.258767, 0.015067, 0.018232},{
      1.261356, 0.020150, 0.018232},{1.263855, 0.019338, 0.015155}}],
    Polygon[{{1.258767, 0.015067, 0.018232},{1.256278, 0.016875, 0.020859},{
      1.258430, 0.021100, 0.020859},{1.261356, 0.020150, 0.018232}}],
    Polygon[{{1.256278, 0.016875, 0.020859},{1.253487, 0.018903, 0.022973},{
      1.255149, 0.022166, 0.022973},{1.258430, 0.021100, 0.020859}}],
    Polygon[{{1.253487, 0.018903, 0.022973},{1.250463, 0.021100, 0.024521},{
      1.251595, 0.023321, 0.024521},{1.255149, 0.022166, 0.022973}}],
    Polygon[{{1.250463, 0.021100, 0.024521},{1.247280, 0.023413, 0.025466},{
      1.247853, 0.024537, 0.025466},{1.251595, 0.023321, 0.024521}}],
    Polygon[{{1.247853, 0.024537, -0.025466},{1.251595, 0.023321, -0.024521},{
      1.251984, 0.025783, -0.024521},{1.248050, 0.025783, -0.025466}}],
    Polygon[{{1.251595, 0.023321, -0.024521},{1.255149, 0.022166, -0.022973},{
      1.255722, 0.025783, -0.022973},{1.251984, 0.025783, -0.024521}}],
    Polygon[{{1.255149, 0.022166, -0.022973},{1.258430, 0.021100, -0.020859},{
      1.259172, 0.025783, -0.020859},{1.255722, 0.025783, -0.022973}}],
    Polygon[{{1.258430, 0.021100, -0.020859},{1.261356, 0.020150, -0.018232},{
      1.262249, 0.025783, -0.018232},{1.259172, 0.025783, -0.020859}}],
    Polygon[{{1.261356, 0.020150, -0.018232},{1.263855, 0.019338, -0.015155},{
      1.264876, 0.025783, -0.015155},{1.262249, 0.025783, -0.018232}}],
    Polygon[{{1.263855, 0.019338, -0.015155},{1.265866, 0.018684, -0.011705},{
      1.266990, 0.025783, -0.011705},{1.264876, 0.025783, -0.015155}}],
    Polygon[{{1.265866, 0.018684, -0.011705},{1.267338, 0.018206, -0.007968},{
      1.268538, 0.025783, -0.007968},{1.266990, 0.025783, -0.011705}}],
    Polygon[{{1.267338, 0.018206, -0.007968},{1.268237, 0.017914, -0.004033},{
      1.269483, 0.025783, -0.004033},{1.268538, 0.025783, -0.007968}}],
    Polygon[{{1.268237, 0.017914, -0.004033},{1.268538, 0.017816, 0.000000},{
      1.269800, 0.025783, 0.000000},{1.269483, 0.025783, -0.004033}}],
    Polygon[{{1.268538, 0.017816, 0.000000},{1.268237, 0.017914, 0.004033},{
      1.269483, 0.025783, 0.004033},{1.269800, 0.025783, 0.000000}}],
    Polygon[{{1.268237, 0.017914, 0.004033},{1.267338, 0.018206, 0.007968},{
      1.268538, 0.025783, 0.007968},{1.269483, 0.025783, 0.004033}}],
    Polygon[{{1.267338, 0.018206, 0.007968},{1.265866, 0.018684, 0.011705},{
      1.266990, 0.025783, 0.011705},{1.268538, 0.025783, 0.007968}}],
    Polygon[{{1.265866, 0.018684, 0.011705},{1.263855, 0.019338, 0.015155},{
      1.264876, 0.025783, 0.015155},{1.266990, 0.025783, 0.011705}}],
    Polygon[{{1.263855, 0.019338, 0.015155},{1.261356, 0.020150, 0.018232},{
      1.262249, 0.025783, 0.018232},{1.264876, 0.025783, 0.015155}}],
    Polygon[{{1.261356, 0.020150, 0.018232},{1.258430, 0.021100, 0.020859},{
      1.259172, 0.025783, 0.020859},{1.262249, 0.025783, 0.018232}}],
    Polygon[{{1.258430, 0.021100, 0.020859},{1.255149, 0.022166, 0.022973},{
      1.255722, 0.025783, 0.022973},{1.259172, 0.025783, 0.020859}}],
    Polygon[{{1.255149, 0.022166, 0.022973},{1.251595, 0.023321, 0.024521},{
      1.251984, 0.025783, 0.024521},{1.255722, 0.025783, 0.022973}}],
    Polygon[{{1.251595, 0.023321, 0.024521},{1.247853, 0.024537, 0.025466},{
      1.248050, 0.025783, 0.025466},{1.251984, 0.025783, 0.024521}}],
    Polygon[{{1.359427, 0.013817, -0.013647},{1.361535, 0.013817, -0.013141},{
      1.361326, 0.015137, -0.013141},{1.359321, 0.014485, -0.013647}}],
    Polygon[{{1.361535, 0.013817, -0.013141},{1.363539, 0.013817, -0.012311},{
      1.363232, 0.015756, -0.012311},{1.361326, 0.015137, -0.013141}}],
    Polygon[{{1.363539, 0.013817, -0.012311},{1.365387, 0.013817, -0.011178},{
      1.364990, 0.016327, -0.011178},{1.363232, 0.015756, -0.012311}}],
    Polygon[{{1.365387, 0.013817, -0.011178},{1.367036, 0.013817, -0.009770},{
      1.366558, 0.016836, -0.009770},{1.364990, 0.016327, -0.011178}}],
    Polygon[{{1.367036, 0.013817, -0.009770},{1.368444, 0.013817, -0.008122},{
      1.367897, 0.017272, -0.008122},{1.366558, 0.016836, -0.009770}}],
    Polygon[{{1.368444, 0.013817, -0.008122},{1.369577, 0.013817, -0.006273},{
      1.368974, 0.017622, -0.006273},{1.367897, 0.017272, -0.008122}}],
    Polygon[{{1.369577, 0.013817, -0.006273},{1.370407, 0.013817, -0.004270},{
      1.369763, 0.017878, -0.004270},{1.368974, 0.017622, -0.006273}}],
    Polygon[{{1.370407, 0.013817, -0.004270},{1.370913, 0.013817, -0.002162},{
      1.370245, 0.018035, -0.002162},{1.369763, 0.017878, -0.004270}}],
    Polygon[{{1.370913, 0.013817, -0.002162},{1.371083, 0.013817, 0.000000},{
      1.370407, 0.018087, 0.000000},{1.370245, 0.018035, -0.002162}}],
    Polygon[{{1.371083, 0.013817, 0.000000},{1.370913, 0.013817, 0.002162},{
      1.370245, 0.018035, 0.002162},{1.370407, 0.018087, 0.000000}}],
    Polygon[{{1.370913, 0.013817, 0.002162},{1.370407, 0.013817, 0.004270},{
      1.369763, 0.017878, 0.004270},{1.370245, 0.018035, 0.002162}}],
    Polygon[{{1.370407, 0.013817, 0.004270},{1.369577, 0.013817, 0.006273},{
      1.368974, 0.017622, 0.006273},{1.369763, 0.017878, 0.004270}}],
    Polygon[{{1.369577, 0.013817, 0.006273},{1.368444, 0.013817, 0.008122},{
      1.367897, 0.017272, 0.008122},{1.368974, 0.017622, 0.006273}}],
    Polygon[{{1.368444, 0.013817, 0.008122},{1.367036, 0.013817, 0.009770},{
      1.366558, 0.016836, 0.009770},{1.367897, 0.017272, 0.008122}}],
    Polygon[{{1.367036, 0.013817, 0.009770},{1.365387, 0.013817, 0.011178},{
      1.364990, 0.016327, 0.011178},{1.366558, 0.016836, 0.009770}}],
    Polygon[{{1.365387, 0.013817, 0.011178},{1.363539, 0.013817, 0.012311},{
      1.363232, 0.015756, 0.012311},{1.364990, 0.016327, 0.011178}}],
    Polygon[{{1.363539, 0.013817, 0.012311},{1.361535, 0.013817, 0.013141},{
      1.361326, 0.015137, 0.013141},{1.363232, 0.015756, 0.012311}}],
    Polygon[{{1.361535, 0.013817, 0.013141},{1.359427, 0.013817, 0.013647},{
      1.359321, 0.014485, 0.013647},{1.361326, 0.015137, 0.013141}}],
    Polygon[{{1.359321, 0.014485, -0.013647},{1.361326, 0.015137, -0.013141},{
      1.360720, 0.016327, -0.013141},{1.359014, 0.015088, -0.013647}}],
    Polygon[{{1.361326, 0.015137, -0.013141},{1.363232, 0.015756, -0.012311},{
      1.362340, 0.017504, -0.012311},{1.360720, 0.016327, -0.013141}}],
    Polygon[{{1.363232, 0.015756, -0.012311},{1.364990, 0.016327, -0.011178},{
      1.363836, 0.018591, -0.011178},{1.362340, 0.017504, -0.012311}}],
    Polygon[{{1.364990, 0.016327, -0.011178},{1.366558, 0.016836, -0.009770},{
      1.365170, 0.019560, -0.009770},{1.363836, 0.018591, -0.011178}}],
    Polygon[{{1.366558, 0.016836, -0.009770},{1.367897, 0.017272, -0.008122},{
      1.366309, 0.020388, -0.008122},{1.365170, 0.019560, -0.009770}}],
    Polygon[{{1.367897, 0.017272, -0.008122},{1.368974, 0.017622, -0.006273},{
      1.367226, 0.021054, -0.006273},{1.366309, 0.020388, -0.008122}}],
    Polygon[{{1.368974, 0.017622, -0.006273},{1.369763, 0.017878, -0.004270},{
      1.367897, 0.021541, -0.004270},{1.367226, 0.021054, -0.006273}}],
    Polygon[{{1.369763, 0.017878, -0.004270},{1.370245, 0.018035, -0.002162},{
      1.368306, 0.021839, -0.002162},{1.367897, 0.021541, -0.004270}}],
    Polygon[{{1.370245, 0.018035, -0.002162},{1.370407, 0.018087, 0.000000},{
      1.368444, 0.021939, 0.000000},{1.368306, 0.021839, -0.002162}}],
    Polygon[{{1.370407, 0.018087, 0.000000},{1.370245, 0.018035, 0.002162},{
      1.368306, 0.021839, 0.002162},{1.368444, 0.021939, 0.000000}}],
    Polygon[{{1.370245, 0.018035, 0.002162},{1.369763, 0.017878, 0.004270},{
      1.367897, 0.021541, 0.004270},{1.368306, 0.021839, 0.002162}}],
    Polygon[{{1.369763, 0.017878, 0.004270},{1.368974, 0.017622, 0.006273},{
      1.367226, 0.021054, 0.006273},{1.367897, 0.021541, 0.004270}}],
    Polygon[{{1.368974, 0.017622, 0.006273},{1.367897, 0.017272, 0.008122},{
      1.366309, 0.020388, 0.008122},{1.367226, 0.021054, 0.006273}}],
    Polygon[{{1.367897, 0.017272, 0.008122},{1.366558, 0.016836, 0.009770},{
      1.365170, 0.019560, 0.009770},{1.366309, 0.020388, 0.008122}}],
    Polygon[{{1.366558, 0.016836, 0.009770},{1.364990, 0.016327, 0.011178},{
      1.363836, 0.018591, 0.011178},{1.365170, 0.019560, 0.009770}}],
    Polygon[{{1.364990, 0.016327, 0.011178},{1.363232, 0.015756, 0.012311},{
      1.362340, 0.017504, 0.012311},{1.363836, 0.018591, 0.011178}}],
    Polygon[{{1.363232, 0.015756, 0.012311},{1.361326, 0.015137, 0.013141},{
      1.360720, 0.016327, 0.013141},{1.362340, 0.017504, 0.012311}}],
    Polygon[{{1.361326, 0.015137, 0.013141},{1.359321, 0.014485, 0.013647},{
      1.359014, 0.015088, 0.013647},{1.360720, 0.016327, 0.013141}}],
    Polygon[{{1.359014, 0.015088, -0.013647},{1.360720, 0.016327, -0.013141},{
      1.359775, 0.017272, -0.013141},{1.358536, 0.015566, -0.013647}}],
    Polygon[{{1.360720, 0.016327, -0.013141},{1.362340, 0.017504, -0.012311},{
      1.360953, 0.018892, -0.012311},{1.359775, 0.017272, -0.013141}}],
    Polygon[{{1.362340, 0.017504, -0.012311},{1.363836, 0.018591, -0.011178},{
      1.362039, 0.020388, -0.011178},{1.360953, 0.018892, -0.012311}}],
    Polygon[{{1.363836, 0.018591, -0.011178},{1.365170, 0.019560, -0.009770},{
      1.363008, 0.021722, -0.009770},{1.362039, 0.020388, -0.011178}}],
    Polygon[{{1.365170, 0.019560, -0.009770},{1.366309, 0.020388, -0.008122},{
      1.363836, 0.022861, -0.008122},{1.363008, 0.021722, -0.009770}}],
    Polygon[{{1.366309, 0.020388, -0.008122},{1.367226, 0.021054, -0.006273},{
      1.364502, 0.023777, -0.006273},{1.363836, 0.022861, -0.008122}}],
    Polygon[{{1.367226, 0.021054, -0.006273},{1.367897, 0.021541, -0.004270},{
      1.364990, 0.024449, -0.004270},{1.364502, 0.023777, -0.006273}}],
    Polygon[{{1.367897, 0.021541, -0.004270},{1.368306, 0.021839, -0.002162},{
      1.365287, 0.024858, -0.002162},{1.364990, 0.024449, -0.004270}}],
    Polygon[{{1.368306, 0.021839, -0.002162},{1.368444, 0.021939, 0.000000},{
      1.365387, 0.024996, 0.000000},{1.365287, 0.024858, -0.002162}}],
    Polygon[{{1.368444, 0.021939, 0.000000},{1.368306, 0.021839, 0.002162},{
      1.365287, 0.024858, 0.002162},{1.365387, 0.024996, 0.000000}}],
    Polygon[{{1.368306, 0.021839, 0.002162},{1.367897, 0.021541, 0.004270},{
      1.364990, 0.024449, 0.004270},{1.365287, 0.024858, 0.002162}}],
    Polygon[{{1.367897, 0.021541, 0.004270},{1.367226, 0.021054, 0.006273},{
      1.364502, 0.023777, 0.006273},{1.364990, 0.024449, 0.004270}}],
    Polygon[{{1.367226, 0.021054, 0.006273},{1.366309, 0.020388, 0.008122},{
      1.363836, 0.022861, 0.008122},{1.364502, 0.023777, 0.006273}}],
    Polygon[{{1.366309, 0.020388, 0.008122},{1.365170, 0.019560, 0.009770},{
      1.363008, 0.021722, 0.009770},{1.363836, 0.022861, 0.008122}}],
    Polygon[{{1.365170, 0.019560, 0.009770},{1.363836, 0.018591, 0.011178},{
      1.362039, 0.020388, 0.011178},{1.363008, 0.021722, 0.009770}}],
    Polygon[{{1.363836, 0.018591, 0.011178},{1.362340, 0.017504, 0.012311},{
      1.360953, 0.018892, 0.012311},{1.362039, 0.020388, 0.011178}}],
    Polygon[{{1.362340, 0.017504, 0.012311},{1.360720, 0.016327, 0.013141},{
      1.359775, 0.017272, 0.013141},{1.360953, 0.018892, 0.012311}}],
    Polygon[{{1.360720, 0.016327, 0.013141},{1.359014, 0.015088, 0.013647},{
      1.358536, 0.015566, 0.013647},{1.359775, 0.017272, 0.013141}}],
    Polygon[{{1.358536, 0.015566, -0.013647},{1.359775, 0.017272, -0.013141},{
      1.358585, 0.017878, -0.013141},{1.357934, 0.015873, -0.013647}}],
    Polygon[{{1.359775, 0.017272, -0.013141},{1.360953, 0.018892, -0.012311},{
      1.359204, 0.019783, -0.012311},{1.358585, 0.017878, -0.013141}}],
    Polygon[{{1.360953, 0.018892, -0.012311},{1.362039, 0.020388, -0.011178},{
      1.359775, 0.021541, -0.011178},{1.359204, 0.019783, -0.012311}}],
    Polygon[{{1.362039, 0.020388, -0.011178},{1.363008, 0.021722, -0.009770},{
      1.360285, 0.023109, -0.009770},{1.359775, 0.021541, -0.011178}}],
    Polygon[{{1.363008, 0.021722, -0.009770},{1.363836, 0.022861, -0.008122},{
      1.360720, 0.024449, -0.008122},{1.360285, 0.023109, -0.009770}}],
    Polygon[{{1.363836, 0.022861, -0.008122},{1.364502, 0.023777, -0.006273},{
      1.361070, 0.025526, -0.006273},{1.360720, 0.024449, -0.008122}}],
    Polygon[{{1.364502, 0.023777, -0.006273},{1.364990, 0.024449, -0.004270},{
      1.361326, 0.026315, -0.004270},{1.361070, 0.025526, -0.006273}}],
    Polygon[{{1.364990, 0.024449, -0.004270},{1.365287, 0.024858, -0.002162},{
      1.361483, 0.026797, -0.002162},{1.361326, 0.026315, -0.004270}}],
    Polygon[{{1.365287, 0.024858, -0.002162},{1.365387, 0.024996, 0.000000},{
      1.361535, 0.026958, 0.000000},{1.361483, 0.026797, -0.002162}}],
    Polygon[{{1.365387, 0.024996, 0.000000},{1.365287, 0.024858, 0.002162},{
      1.361483, 0.026797, 0.002162},{1.361535, 0.026958, 0.000000}}],
    Polygon[{{1.365287, 0.024858, 0.002162},{1.364990, 0.024449, 0.004270},{
      1.361326, 0.026315, 0.004270},{1.361483, 0.026797, 0.002162}}],
    Polygon[{{1.364990, 0.024449, 0.004270},{1.364502, 0.023777, 0.006273},{
      1.361070, 0.025526, 0.006273},{1.361326, 0.026315, 0.004270}}],
    Polygon[{{1.364502, 0.023777, 0.006273},{1.363836, 0.022861, 0.008122},{
      1.360720, 0.024449, 0.008122},{1.361070, 0.025526, 0.006273}}],
    Polygon[{{1.363836, 0.022861, 0.008122},{1.363008, 0.021722, 0.009770},{
      1.360285, 0.023109, 0.009770},{1.360720, 0.024449, 0.008122}}],
    Polygon[{{1.363008, 0.021722, 0.009770},{1.362039, 0.020388, 0.011178},{
      1.359775, 0.021541, 0.011178},{1.360285, 0.023109, 0.009770}}],
    Polygon[{{1.362039, 0.020388, 0.011178},{1.360953, 0.018892, 0.012311},{
      1.359204, 0.019783, 0.012311},{1.359775, 0.021541, 0.011178}}],
    Polygon[{{1.360953, 0.018892, 0.012311},{1.359775, 0.017272, 0.013141},{
      1.358585, 0.017878, 0.013141},{1.359204, 0.019783, 0.012311}}],
    Polygon[{{1.359775, 0.017272, 0.013141},{1.358536, 0.015566, 0.013647},{
      1.357934, 0.015873, 0.013647},{1.358585, 0.017878, 0.013141}}],
    Polygon[{{1.357934, 0.015873, -0.013647},{1.358585, 0.017878, -0.013141},{
      1.357266, 0.018087, -0.013141},{1.357266, 0.015979, -0.013647}}],
    Polygon[{{1.358585, 0.017878, -0.013141},{1.359204, 0.019783, -0.012311},{
      1.357266, 0.020090, -0.012311},{1.357266, 0.018087, -0.013141}}],
    Polygon[{{1.359204, 0.019783, -0.012311},{1.359775, 0.021541, -0.011178},{
      1.357266, 0.021939, -0.011178},{1.357266, 0.020090, -0.012311}}],
    Polygon[{{1.359775, 0.021541, -0.011178},{1.360285, 0.023109, -0.009770},{
      1.357266, 0.023588, -0.009770},{1.357266, 0.021939, -0.011178}}],
    Polygon[{{1.360285, 0.023109, -0.009770},{1.360720, 0.024449, -0.008122},{
      1.357266, 0.024996, -0.008122},{1.357266, 0.023588, -0.009770}}],
    Polygon[{{1.360720, 0.024449, -0.008122},{1.361070, 0.025526, -0.006273},{
      1.357266, 0.026129, -0.006273},{1.357266, 0.024996, -0.008122}}],
    Polygon[{{1.361070, 0.025526, -0.006273},{1.361326, 0.026315, -0.004270},{
      1.357266, 0.026958, -0.004270},{1.357266, 0.026129, -0.006273}}],
    Polygon[{{1.361326, 0.026315, -0.004270},{1.361483, 0.026797, -0.002162},{
      1.357266, 0.027464, -0.002162},{1.357266, 0.026958, -0.004270}}],
    Polygon[{{1.361483, 0.026797, -0.002162},{1.361535, 0.026958, 0.000000},{
      1.357266, 0.027635, 0.000000},{1.357266, 0.027464, -0.002162}}],
    Polygon[{{1.361535, 0.026958, 0.000000},{1.361483, 0.026797, 0.002162},{
      1.357266, 0.027464, 0.002162},{1.357266, 0.027635, 0.000000}}],
    Polygon[{{1.361483, 0.026797, 0.002162},{1.361326, 0.026315, 0.004270},{
      1.357266, 0.026958, 0.004270},{1.357266, 0.027464, 0.002162}}],
    Polygon[{{1.361326, 0.026315, 0.004270},{1.361070, 0.025526, 0.006273},{
      1.357266, 0.026129, 0.006273},{1.357266, 0.026958, 0.004270}}],
    Polygon[{{1.361070, 0.025526, 0.006273},{1.360720, 0.024449, 0.008122},{
      1.357266, 0.024996, 0.008122},{1.357266, 0.026129, 0.006273}}],
    Polygon[{{1.360720, 0.024449, 0.008122},{1.360285, 0.023109, 0.009770},{
      1.357266, 0.023588, 0.009770},{1.357266, 0.024996, 0.008122}}],
    Polygon[{{1.360285, 0.023109, 0.009770},{1.359775, 0.021541, 0.011178},{
      1.357266, 0.021939, 0.011178},{1.357266, 0.023588, 0.009770}}],
    Polygon[{{1.359775, 0.021541, 0.011178},{1.359204, 0.019783, 0.012311},{
      1.357266, 0.020090, 0.012311},{1.357266, 0.021939, 0.011178}}],
    Polygon[{{1.359204, 0.019783, 0.012311},{1.358585, 0.017878, 0.013141},{
      1.357266, 0.018087, 0.013141},{1.357266, 0.020090, 0.012311}}],
    Polygon[{{1.358585, 0.017878, 0.013141},{1.357934, 0.015873, 0.013647},{
      1.357266, 0.015979, 0.013647},{1.357266, 0.018087, 0.013141}}],
    Polygon[{{1.357266, 0.015979, -0.013647},{1.357266, 0.018087, -0.013141},{
      1.355946, 0.017878, -0.013141},{1.356598, 0.015873, -0.013647}}],
    Polygon[{{1.357266, 0.018087, -0.013141},{1.357266, 0.020090, -0.012311},{
      1.355327, 0.019783, -0.012311},{1.355946, 0.017878, -0.013141}}],
    Polygon[{{1.357266, 0.020090, -0.012311},{1.357266, 0.021939, -0.011178},{
      1.354756, 0.021541, -0.011178},{1.355327, 0.019783, -0.012311}}],
    Polygon[{{1.357266, 0.021939, -0.011178},{1.357266, 0.023588, -0.009770},{
      1.354246, 0.023109, -0.009770},{1.354756, 0.021541, -0.011178}}],
    Polygon[{{1.357266, 0.023588, -0.009770},{1.357266, 0.024996, -0.008122},{
      1.353811, 0.024449, -0.008122},{1.354246, 0.023109, -0.009770}}],
    Polygon[{{1.357266, 0.024996, -0.008122},{1.357266, 0.026129, -0.006273},{
      1.353461, 0.025526, -0.006273},{1.353811, 0.024449, -0.008122}}],
    Polygon[{{1.357266, 0.026129, -0.006273},{1.357266, 0.026958, -0.004270},{
      1.353205, 0.026315, -0.004270},{1.353461, 0.025526, -0.006273}}],
    Polygon[{{1.357266, 0.026958, -0.004270},{1.357266, 0.027464, -0.002162},{
      1.353048, 0.026797, -0.002162},{1.353205, 0.026315, -0.004270}}],
    Polygon[{{1.357266, 0.027464, -0.002162},{1.357266, 0.027635, 0.000000},{
      1.352996, 0.026958, 0.000000},{1.353048, 0.026797, -0.002162}}],
    Polygon[{{1.357266, 0.027635, 0.000000},{1.357266, 0.027464, 0.002162},{
      1.353048, 0.026797, 0.002162},{1.352996, 0.026958, 0.000000}}],
    Polygon[{{1.357266, 0.027464, 0.002162},{1.357266, 0.026958, 0.004270},{
      1.353205, 0.026315, 0.004270},{1.353048, 0.026797, 0.002162}}],
    Polygon[{{1.357266, 0.026958, 0.004270},{1.357266, 0.026129, 0.006273},{
      1.353461, 0.025526, 0.006273},{1.353205, 0.026315, 0.004270}}],
    Polygon[{{1.357266, 0.026129, 0.006273},{1.357266, 0.024996, 0.008122},{
      1.353811, 0.024449, 0.008122},{1.353461, 0.025526, 0.006273}}],
    Polygon[{{1.357266, 0.024996, 0.008122},{1.357266, 0.023588, 0.009770},{
      1.354246, 0.023109, 0.009770},{1.353811, 0.024449, 0.008122}}],
    Polygon[{{1.357266, 0.023588, 0.009770},{1.357266, 0.021939, 0.011178},{
      1.354756, 0.021541, 0.011178},{1.354246, 0.023109, 0.009770}}],
    Polygon[{{1.357266, 0.021939, 0.011178},{1.357266, 0.020090, 0.012311},{
      1.355327, 0.019783, 0.012311},{1.354756, 0.021541, 0.011178}}],
    Polygon[{{1.357266, 0.020090, 0.012311},{1.357266, 0.018087, 0.013141},{
      1.355946, 0.017878, 0.013141},{1.355327, 0.019783, 0.012311}}],
    Polygon[{{1.357266, 0.018087, 0.013141},{1.357266, 0.015979, 0.013647},{
      1.356598, 0.015873, 0.013647},{1.355946, 0.017878, 0.013141}}],
    Polygon[{{1.356598, 0.015873, -0.013647},{1.355946, 0.017878, -0.013141},{
      1.354756, 0.017272, -0.013141},{1.355995, 0.015566, -0.013647}}],
    Polygon[{{1.355946, 0.017878, -0.013141},{1.355327, 0.019783, -0.012311},{
      1.353578, 0.018892, -0.012311},{1.354756, 0.017272, -0.013141}}],
    Polygon[{{1.355327, 0.019783, -0.012311},{1.354756, 0.021541, -0.011178},{
      1.352492, 0.020388, -0.011178},{1.353578, 0.018892, -0.012311}}],
    Polygon[{{1.354756, 0.021541, -0.011178},{1.354246, 0.023109, -0.009770},{
      1.351523, 0.021722, -0.009770},{1.352492, 0.020388, -0.011178}}],
    Polygon[{{1.354246, 0.023109, -0.009770},{1.353811, 0.024449, -0.008122},{
      1.350695, 0.022861, -0.008122},{1.351523, 0.021722, -0.009770}}],
    Polygon[{{1.353811, 0.024449, -0.008122},{1.353461, 0.025526, -0.006273},{
      1.350029, 0.023777, -0.006273},{1.350695, 0.022861, -0.008122}}],
    Polygon[{{1.353461, 0.025526, -0.006273},{1.353205, 0.026315, -0.004270},{
      1.349542, 0.024449, -0.004270},{1.350029, 0.023777, -0.006273}}],
    Polygon[{{1.353205, 0.026315, -0.004270},{1.353048, 0.026797, -0.002162},{
      1.349244, 0.024858, -0.002162},{1.349542, 0.024449, -0.004270}}],
    Polygon[{{1.353048, 0.026797, -0.002162},{1.352996, 0.026958, 0.000000},{
      1.349144, 0.024996, 0.000000},{1.349244, 0.024858, -0.002162}}],
    Polygon[{{1.352996, 0.026958, 0.000000},{1.353048, 0.026797, 0.002162},{
      1.349244, 0.024858, 0.002162},{1.349144, 0.024996, 0.000000}}],
    Polygon[{{1.353048, 0.026797, 0.002162},{1.353205, 0.026315, 0.004270},{
      1.349542, 0.024449, 0.004270},{1.349244, 0.024858, 0.002162}}],
    Polygon[{{1.353205, 0.026315, 0.004270},{1.353461, 0.025526, 0.006273},{
      1.350029, 0.023777, 0.006273},{1.349542, 0.024449, 0.004270}}],
    Polygon[{{1.353461, 0.025526, 0.006273},{1.353811, 0.024449, 0.008122},{
      1.350695, 0.022861, 0.008122},{1.350029, 0.023777, 0.006273}}],
    Polygon[{{1.353811, 0.024449, 0.008122},{1.354246, 0.023109, 0.009770},{
      1.351523, 0.021722, 0.009770},{1.350695, 0.022861, 0.008122}}],
    Polygon[{{1.354246, 0.023109, 0.009770},{1.354756, 0.021541, 0.011178},{
      1.352492, 0.020388, 0.011178},{1.351523, 0.021722, 0.009770}}],
    Polygon[{{1.354756, 0.021541, 0.011178},{1.355327, 0.019783, 0.012311},{
      1.353578, 0.018892, 0.012311},{1.352492, 0.020388, 0.011178}}],
    Polygon[{{1.355327, 0.019783, 0.012311},{1.355946, 0.017878, 0.013141},{
      1.354756, 0.017272, 0.013141},{1.353578, 0.018892, 0.012311}}],
    Polygon[{{1.355946, 0.017878, 0.013141},{1.356598, 0.015873, 0.013647},{
      1.355995, 0.015566, 0.013647},{1.354756, 0.017272, 0.013141}}],
    Polygon[{{1.355995, 0.015566, -0.013647},{1.354756, 0.017272, -0.013141},{
      1.353811, 0.016327, -0.013141},{1.355517, 0.015088, -0.013647}}],
    Polygon[{{1.354756, 0.017272, -0.013141},{1.353578, 0.018892, -0.012311},{
      1.352191, 0.017504, -0.012311},{1.353811, 0.016327, -0.013141}}],
    Polygon[{{1.353578, 0.018892, -0.012311},{1.352492, 0.020388, -0.011178},{
      1.350695, 0.018591, -0.011178},{1.352191, 0.017504, -0.012311}}],
    Polygon[{{1.352492, 0.020388, -0.011178},{1.351523, 0.021722, -0.009770},{
      1.349361, 0.019560, -0.009770},{1.350695, 0.018591, -0.011178}}],
    Polygon[{{1.351523, 0.021722, -0.009770},{1.350695, 0.022861, -0.008122},{
      1.348222, 0.020388, -0.008122},{1.349361, 0.019560, -0.009770}}],
    Polygon[{{1.350695, 0.022861, -0.008122},{1.350029, 0.023777, -0.006273},{
      1.347306, 0.021054, -0.006273},{1.348222, 0.020388, -0.008122}}],
    Polygon[{{1.350029, 0.023777, -0.006273},{1.349542, 0.024449, -0.004270},{
      1.346634, 0.021541, -0.004270},{1.347306, 0.021054, -0.006273}}],
    Polygon[{{1.349542, 0.024449, -0.004270},{1.349244, 0.024858, -0.002162},{
      1.346225, 0.021839, -0.002162},{1.346634, 0.021541, -0.004270}}],
    Polygon[{{1.349244, 0.024858, -0.002162},{1.349144, 0.024996, 0.000000},{
      1.346087, 0.021939, 0.000000},{1.346225, 0.021839, -0.002162}}],
    Polygon[{{1.349144, 0.024996, 0.000000},{1.349244, 0.024858, 0.002162},{
      1.346225, 0.021839, 0.002162},{1.346087, 0.021939, 0.000000}}],
    Polygon[{{1.349244, 0.024858, 0.002162},{1.349542, 0.024449, 0.004270},{
      1.346634, 0.021541, 0.004270},{1.346225, 0.021839, 0.002162}}],
    Polygon[{{1.349542, 0.024449, 0.004270},{1.350029, 0.023777, 0.006273},{
      1.347306, 0.021054, 0.006273},{1.346634, 0.021541, 0.004270}}],
    Polygon[{{1.350029, 0.023777, 0.006273},{1.350695, 0.022861, 0.008122},{
      1.348222, 0.020388, 0.008122},{1.347306, 0.021054, 0.006273}}],
    Polygon[{{1.350695, 0.022861, 0.008122},{1.351523, 0.021722, 0.009770},{
      1.349361, 0.019560, 0.009770},{1.348222, 0.020388, 0.008122}}],
    Polygon[{{1.351523, 0.021722, 0.009770},{1.352492, 0.020388, 0.011178},{
      1.350695, 0.018591, 0.011178},{1.349361, 0.019560, 0.009770}}],
    Polygon[{{1.352492, 0.020388, 0.011178},{1.353578, 0.018892, 0.012311},{
      1.352191, 0.017504, 0.012311},{1.350695, 0.018591, 0.011178}}],
    Polygon[{{1.353578, 0.018892, 0.012311},{1.354756, 0.017272, 0.013141},{
      1.353811, 0.016327, 0.013141},{1.352191, 0.017504, 0.012311}}],
    Polygon[{{1.354756, 0.017272, 0.013141},{1.355995, 0.015566, 0.013647},{
      1.355517, 0.015088, 0.013647},{1.353811, 0.016327, 0.013141}}],
    Polygon[{{1.355517, 0.015088, -0.013647},{1.353811, 0.016327, -0.013141},{
      1.353205, 0.015137, -0.013141},{1.355210, 0.014485, -0.013647}}],
    Polygon[{{1.353811, 0.016327, -0.013141},{1.352191, 0.017504, -0.012311},{
      1.351300, 0.015756, -0.012311},{1.353205, 0.015137, -0.013141}}],
    Polygon[{{1.352191, 0.017504, -0.012311},{1.350695, 0.018591, -0.011178},{
      1.349542, 0.016327, -0.011178},{1.351300, 0.015756, -0.012311}}],
    Polygon[{{1.350695, 0.018591, -0.011178},{1.349361, 0.019560, -0.009770},{
      1.347973, 0.016836, -0.009770},{1.349542, 0.016327, -0.011178}}],
    Polygon[{{1.349361, 0.019560, -0.009770},{1.348222, 0.020388, -0.008122},{
      1.346634, 0.017272, -0.008122},{1.347973, 0.016836, -0.009770}}],
    Polygon[{{1.348222, 0.020388, -0.008122},{1.347306, 0.021054, -0.006273},{
      1.345557, 0.017622, -0.006273},{1.346634, 0.017272, -0.008122}}],
    Polygon[{{1.347306, 0.021054, -0.006273},{1.346634, 0.021541, -0.004270},{
      1.344768, 0.017878, -0.004270},{1.345557, 0.017622, -0.006273}}],
    Polygon[{{1.346634, 0.021541, -0.004270},{1.346225, 0.021839, -0.002162},{
      1.344286, 0.018035, -0.002162},{1.344768, 0.017878, -0.004270}}],
    Polygon[{{1.346225, 0.021839, -0.002162},{1.346087, 0.021939, 0.000000},{
      1.344125, 0.018087, 0.000000},{1.344286, 0.018035, -0.002162}}],
    Polygon[{{1.346087, 0.021939, 0.000000},{1.346225, 0.021839, 0.002162},{
      1.344286, 0.018035, 0.002162},{1.344125, 0.018087, 0.000000}}],
    Polygon[{{1.346225, 0.021839, 0.002162},{1.346634, 0.021541, 0.004270},{
      1.344768, 0.017878, 0.004270},{1.344286, 0.018035, 0.002162}}],
    Polygon[{{1.346634, 0.021541, 0.004270},{1.347306, 0.021054, 0.006273},{
      1.345557, 0.017622, 0.006273},{1.344768, 0.017878, 0.004270}}],
    Polygon[{{1.347306, 0.021054, 0.006273},{1.348222, 0.020388, 0.008122},{
      1.346634, 0.017272, 0.008122},{1.345557, 0.017622, 0.006273}}],
    Polygon[{{1.348222, 0.020388, 0.008122},{1.349361, 0.019560, 0.009770},{
      1.347973, 0.016836, 0.009770},{1.346634, 0.017272, 0.008122}}],
    Polygon[{{1.349361, 0.019560, 0.009770},{1.350695, 0.018591, 0.011178},{
      1.349542, 0.016327, 0.011178},{1.347973, 0.016836, 0.009770}}],
    Polygon[{{1.350695, 0.018591, 0.011178},{1.352191, 0.017504, 0.012311},{
      1.351300, 0.015756, 0.012311},{1.349542, 0.016327, 0.011178}}],
    Polygon[{{1.352191, 0.017504, 0.012311},{1.353811, 0.016327, 0.013141},{
      1.353205, 0.015137, 0.013141},{1.351300, 0.015756, 0.012311}}],
    Polygon[{{1.353811, 0.016327, 0.013141},{1.355517, 0.015088, 0.013647},{
      1.355210, 0.014485, 0.013647},{1.353205, 0.015137, 0.013141}}],
    Polygon[{{1.355210, 0.014485, -0.013647},{1.353205, 0.015137, -0.013141},{
      1.352996, 0.013817, -0.013141},{1.355104, 0.013817, -0.013647}}],
    Polygon[{{1.353205, 0.015137, -0.013141},{1.351300, 0.015756, -0.012311},{
      1.350993, 0.013817, -0.012311},{1.352996, 0.013817, -0.013141}}],
    Polygon[{{1.351300, 0.015756, -0.012311},{1.349542, 0.016327, -0.011178},{
      1.349144, 0.013817, -0.011178},{1.350993, 0.013817, -0.012311}}],
    Polygon[{{1.349542, 0.016327, -0.011178},{1.347973, 0.016836, -0.009770},{
      1.347495, 0.013817, -0.009770},{1.349144, 0.013817, -0.011178}}],
    Polygon[{{1.347973, 0.016836, -0.009770},{1.346634, 0.017272, -0.008122},{
      1.346087, 0.013817, -0.008122},{1.347495, 0.013817, -0.009770}}],
    Polygon[{{1.346634, 0.017272, -0.008122},{1.345557, 0.017622, -0.006273},{
      1.344954, 0.013817, -0.006273},{1.346087, 0.013817, -0.008122}}],
    Polygon[{{1.345557, 0.017622, -0.006273},{1.344768, 0.017878, -0.004270},{
      1.344125, 0.013817, -0.004270},{1.344954, 0.013817, -0.006273}}],
    Polygon[{{1.344768, 0.017878, -0.004270},{1.344286, 0.018035, -0.002162},{
      1.343618, 0.013817, -0.002162},{1.344125, 0.013817, -0.004270}}],
    Polygon[{{1.344286, 0.018035, -0.002162},{1.344125, 0.018087, 0.000000},{
      1.343448, 0.013817, 0.000000},{1.343618, 0.013817, -0.002162}}],
    Polygon[{{1.344125, 0.018087, 0.000000},{1.344286, 0.018035, 0.002162},{
      1.343618, 0.013817, 0.002162},{1.343448, 0.013817, 0.000000}}],
    Polygon[{{1.344286, 0.018035, 0.002162},{1.344768, 0.017878, 0.004270},{
      1.344125, 0.013817, 0.004270},{1.343618, 0.013817, 0.002162}}],
    Polygon[{{1.344768, 0.017878, 0.004270},{1.345557, 0.017622, 0.006273},{
      1.344954, 0.013817, 0.006273},{1.344125, 0.013817, 0.004270}}],
    Polygon[{{1.345557, 0.017622, 0.006273},{1.346634, 0.017272, 0.008122},{
      1.346087, 0.013817, 0.008122},{1.344954, 0.013817, 0.006273}}],
    Polygon[{{1.346634, 0.017272, 0.008122},{1.347973, 0.016836, 0.009770},{
      1.347495, 0.013817, 0.009770},{1.346087, 0.013817, 0.008122}}],
    Polygon[{{1.347973, 0.016836, 0.009770},{1.349542, 0.016327, 0.011178},{
      1.349144, 0.013817, 0.011178},{1.347495, 0.013817, 0.009770}}],
    Polygon[{{1.349542, 0.016327, 0.011178},{1.351300, 0.015756, 0.012311},{
      1.350993, 0.013817, 0.012311},{1.349144, 0.013817, 0.011178}}],
    Polygon[{{1.351300, 0.015756, 0.012311},{1.353205, 0.015137, 0.013141},{
      1.352996, 0.013817, 0.013141},{1.350993, 0.013817, 0.012311}}],
    Polygon[{{1.353205, 0.015137, 0.013141},{1.355210, 0.014485, 0.013647},{
      1.355104, 0.013817, 0.013647},{1.352996, 0.013817, 0.013141}}],
    Polygon[{{1.355104, 0.013817, -0.013647},{1.352996, 0.013817, -0.013141},{
      1.353205, 0.012498, -0.013141},{1.355210, 0.013149, -0.013647}}],
    Polygon[{{1.352996, 0.013817, -0.013141},{1.350993, 0.013817, -0.012311},{
      1.351300, 0.011879, -0.012311},{1.353205, 0.012498, -0.013141}}],
    Polygon[{{1.350993, 0.013817, -0.012311},{1.349144, 0.013817, -0.011178},{
      1.349542, 0.011308, -0.011178},{1.351300, 0.011879, -0.012311}}],
    Polygon[{{1.349144, 0.013817, -0.011178},{1.347495, 0.013817, -0.009770},{
      1.347973, 0.010798, -0.009770},{1.349542, 0.011308, -0.011178}}],
    Polygon[{{1.347495, 0.013817, -0.009770},{1.346087, 0.013817, -0.008122},{
      1.346634, 0.010363, -0.008122},{1.347973, 0.010798, -0.009770}}],
    Polygon[{{1.346087, 0.013817, -0.008122},{1.344954, 0.013817, -0.006273},{
      1.345557, 0.010013, -0.006273},{1.346634, 0.010363, -0.008122}}],
    Polygon[{{1.344954, 0.013817, -0.006273},{1.344125, 0.013817, -0.004270},{
      1.344768, 0.009756, -0.004270},{1.345557, 0.010013, -0.006273}}],
    Polygon[{{1.344125, 0.013817, -0.004270},{1.343618, 0.013817, -0.002162},{
      1.344286, 0.009600, -0.002162},{1.344768, 0.009756, -0.004270}}],
    Polygon[{{1.343618, 0.013817, -0.002162},{1.343448, 0.013817, 0.000000},{
      1.344125, 0.009548, 0.000000},{1.344286, 0.009600, -0.002162}}],
    Polygon[{{1.343448, 0.013817, 0.000000},{1.343618, 0.013817, 0.002162},{
      1.344286, 0.009600, 0.002162},{1.344125, 0.009548, 0.000000}}],
    Polygon[{{1.343618, 0.013817, 0.002162},{1.344125, 0.013817, 0.004270},{
      1.344768, 0.009756, 0.004270},{1.344286, 0.009600, 0.002162}}],
    Polygon[{{1.344125, 0.013817, 0.004270},{1.344954, 0.013817, 0.006273},{
      1.345557, 0.010013, 0.006273},{1.344768, 0.009756, 0.004270}}],
    Polygon[{{1.344954, 0.013817, 0.006273},{1.346087, 0.013817, 0.008122},{
      1.346634, 0.010363, 0.008122},{1.345557, 0.010013, 0.006273}}],
    Polygon[{{1.346087, 0.013817, 0.008122},{1.347495, 0.013817, 0.009770},{
      1.347973, 0.010798, 0.009770},{1.346634, 0.010363, 0.008122}}],
    Polygon[{{1.347495, 0.013817, 0.009770},{1.349144, 0.013817, 0.011178},{
      1.349542, 0.011308, 0.011178},{1.347973, 0.010798, 0.009770}}],
    Polygon[{{1.349144, 0.013817, 0.011178},{1.350993, 0.013817, 0.012311},{
      1.351300, 0.011879, 0.012311},{1.349542, 0.011308, 0.011178}}],
    Polygon[{{1.350993, 0.013817, 0.012311},{1.352996, 0.013817, 0.013141},{
      1.353205, 0.012498, 0.013141},{1.351300, 0.011879, 0.012311}}],
    Polygon[{{1.352996, 0.013817, 0.013141},{1.355104, 0.013817, 0.013647},{
      1.355210, 0.013149, 0.013647},{1.353205, 0.012498, 0.013141}}],
    Polygon[{{1.355210, 0.013149, -0.013647},{1.353205, 0.012498, -0.013141},{
      1.353811, 0.011308, -0.013141},{1.355517, 0.012547, -0.013647}}],
    Polygon[{{1.353205, 0.012498, -0.013141},{1.351300, 0.011879, -0.012311},{
      1.352191, 0.010130, -0.012311},{1.353811, 0.011308, -0.013141}}],
    Polygon[{{1.351300, 0.011879, -0.012311},{1.349542, 0.011308, -0.011178},{
      1.350695, 0.009044, -0.011178},{1.352191, 0.010130, -0.012311}}],
    Polygon[{{1.349542, 0.011308, -0.011178},{1.347973, 0.010798, -0.009770},{
      1.349361, 0.008074, -0.009770},{1.350695, 0.009044, -0.011178}}],
    Polygon[{{1.347973, 0.010798, -0.009770},{1.346634, 0.010363, -0.008122},{
      1.348222, 0.007247, -0.008122},{1.349361, 0.008074, -0.009770}}],
    Polygon[{{1.346634, 0.010363, -0.008122},{1.345557, 0.010013, -0.006273},{
      1.347306, 0.006581, -0.006273},{1.348222, 0.007247, -0.008122}}],
    Polygon[{{1.345557, 0.010013, -0.006273},{1.344768, 0.009756, -0.004270},{
      1.346634, 0.006093, -0.004270},{1.347306, 0.006581, -0.006273}}],
    Polygon[{{1.344768, 0.009756, -0.004270},{1.344286, 0.009600, -0.002162},{
      1.346225, 0.005796, -0.002162},{1.346634, 0.006093, -0.004270}}],
    Polygon[{{1.344286, 0.009600, -0.002162},{1.344125, 0.009548, 0.000000},{
      1.346087, 0.005696, 0.000000},{1.346225, 0.005796, -0.002162}}],
    Polygon[{{1.344125, 0.009548, 0.000000},{1.344286, 0.009600, 0.002162},{
      1.346225, 0.005796, 0.002162},{1.346087, 0.005696, 0.000000}}],
    Polygon[{{1.344286, 0.009600, 0.002162},{1.344768, 0.009756, 0.004270},{
      1.346634, 0.006093, 0.004270},{1.346225, 0.005796, 0.002162}}],
    Polygon[{{1.344768, 0.009756, 0.004270},{1.345557, 0.010013, 0.006273},{
      1.347306, 0.006581, 0.006273},{1.346634, 0.006093, 0.004270}}],
    Polygon[{{1.345557, 0.010013, 0.006273},{1.346634, 0.010363, 0.008122},{
      1.348222, 0.007247, 0.008122},{1.347306, 0.006581, 0.006273}}],
    Polygon[{{1.346634, 0.010363, 0.008122},{1.347973, 0.010798, 0.009770},{
      1.349361, 0.008074, 0.009770},{1.348222, 0.007247, 0.008122}}],
    Polygon[{{1.347973, 0.010798, 0.009770},{1.349542, 0.011308, 0.011178},{
      1.350695, 0.009044, 0.011178},{1.349361, 0.008074, 0.009770}}],
    Polygon[{{1.349542, 0.011308, 0.011178},{1.351300, 0.011879, 0.012311},{
      1.352191, 0.010130, 0.012311},{1.350695, 0.009044, 0.011178}}],
    Polygon[{{1.351300, 0.011879, 0.012311},{1.353205, 0.012498, 0.013141},{
      1.353811, 0.011308, 0.013141},{1.352191, 0.010130, 0.012311}}],
    Polygon[{{1.353205, 0.012498, 0.013141},{1.355210, 0.013149, 0.013647},{
      1.355517, 0.012547, 0.013647},{1.353811, 0.011308, 0.013141}}],
    Polygon[{{1.355517, 0.012547, -0.013647},{1.353811, 0.011308, -0.013141},{
      1.354756, 0.010363, -0.013141},{1.355995, 0.012069, -0.013647}}],
    Polygon[{{1.353811, 0.011308, -0.013141},{1.352191, 0.010130, -0.012311},{
      1.353578, 0.008742, -0.012311},{1.354756, 0.010363, -0.013141}}],
    Polygon[{{1.352191, 0.010130, -0.012311},{1.350695, 0.009044, -0.011178},{
      1.352492, 0.007247, -0.011178},{1.353578, 0.008742, -0.012311}}],
    Polygon[{{1.350695, 0.009044, -0.011178},{1.349361, 0.008074, -0.009770},{
      1.351523, 0.005913, -0.009770},{1.352492, 0.007247, -0.011178}}],
    Polygon[{{1.349361, 0.008074, -0.009770},{1.348222, 0.007247, -0.008122},{
      1.350695, 0.004774, -0.008122},{1.351523, 0.005913, -0.009770}}],
    Polygon[{{1.348222, 0.007247, -0.008122},{1.347306, 0.006581, -0.006273},{
      1.350029, 0.003857, -0.006273},{1.350695, 0.004774, -0.008122}}],
    Polygon[{{1.347306, 0.006581, -0.006273},{1.346634, 0.006093, -0.004270},{
      1.349542, 0.003186, -0.004270},{1.350029, 0.003857, -0.006273}}],
    Polygon[{{1.346634, 0.006093, -0.004270},{1.346225, 0.005796, -0.002162},{
      1.349244, 0.002776, -0.002162},{1.349542, 0.003186, -0.004270}}],
    Polygon[{{1.346225, 0.005796, -0.002162},{1.346087, 0.005696, 0.000000},{
      1.349144, 0.002639, 0.000000},{1.349244, 0.002776, -0.002162}}],
    Polygon[{{1.346087, 0.005696, 0.000000},{1.346225, 0.005796, 0.002162},{
      1.349244, 0.002776, 0.002162},{1.349144, 0.002639, 0.000000}}],
    Polygon[{{1.346225, 0.005796, 0.002162},{1.346634, 0.006093, 0.004270},{
      1.349542, 0.003186, 0.004270},{1.349244, 0.002776, 0.002162}}],
    Polygon[{{1.346634, 0.006093, 0.004270},{1.347306, 0.006581, 0.006273},{
      1.350029, 0.003857, 0.006273},{1.349542, 0.003186, 0.004270}}],
    Polygon[{{1.347306, 0.006581, 0.006273},{1.348222, 0.007247, 0.008122},{
      1.350695, 0.004774, 0.008122},{1.350029, 0.003857, 0.006273}}],
    Polygon[{{1.348222, 0.007247, 0.008122},{1.349361, 0.008074, 0.009770},{
      1.351523, 0.005913, 0.009770},{1.350695, 0.004774, 0.008122}}],
    Polygon[{{1.349361, 0.008074, 0.009770},{1.350695, 0.009044, 0.011178},{
      1.352492, 0.007247, 0.011178},{1.351523, 0.005913, 0.009770}}],
    Polygon[{{1.350695, 0.009044, 0.011178},{1.352191, 0.010130, 0.012311},{
      1.353578, 0.008742, 0.012311},{1.352492, 0.007247, 0.011178}}],
    Polygon[{{1.352191, 0.010130, 0.012311},{1.353811, 0.011308, 0.013141},{
      1.354756, 0.010363, 0.013141},{1.353578, 0.008742, 0.012311}}],
    Polygon[{{1.353811, 0.011308, 0.013141},{1.355517, 0.012547, 0.013647},{
      1.355995, 0.012069, 0.013647},{1.354756, 0.010363, 0.013141}}],
    Polygon[{{1.355995, 0.012069, -0.013647},{1.354756, 0.010363, -0.013141},{
      1.355946, 0.009756, -0.013141},{1.356598, 0.011762, -0.013647}}],
    Polygon[{{1.354756, 0.010363, -0.013141},{1.353578, 0.008742, -0.012311},{
      1.355327, 0.007851, -0.012311},{1.355946, 0.009756, -0.013141}}],
    Polygon[{{1.353578, 0.008742, -0.012311},{1.352492, 0.007247, -0.011178},{
      1.354756, 0.006093, -0.011178},{1.355327, 0.007851, -0.012311}}],
    Polygon[{{1.352492, 0.007247, -0.011178},{1.351523, 0.005913, -0.009770},{
      1.354246, 0.004525, -0.009770},{1.354756, 0.006093, -0.011178}}],
    Polygon[{{1.351523, 0.005913, -0.009770},{1.350695, 0.004774, -0.008122},{
      1.353811, 0.003186, -0.008122},{1.354246, 0.004525, -0.009770}}],
    Polygon[{{1.350695, 0.004774, -0.008122},{1.350029, 0.003857, -0.006273},{
      1.353461, 0.002109, -0.006273},{1.353811, 0.003186, -0.008122}}],
    Polygon[{{1.350029, 0.003857, -0.006273},{1.349542, 0.003186, -0.004270},{
      1.353205, 0.001319, -0.004270},{1.353461, 0.002109, -0.006273}}],
    Polygon[{{1.349542, 0.003186, -0.004270},{1.349244, 0.002776, -0.002162},{
      1.353048, 0.000838, -0.002162},{1.353205, 0.001319, -0.004270}}],
    Polygon[{{1.349244, 0.002776, -0.002162},{1.349144, 0.002639, 0.000000},{
      1.352996, 0.000676, 0.000000},{1.353048, 0.000838, -0.002162}}],
    Polygon[{{1.349144, 0.002639, 0.000000},{1.349244, 0.002776, 0.002162},{
      1.353048, 0.000838, 0.002162},{1.352996, 0.000676, 0.000000}}],
    Polygon[{{1.349244, 0.002776, 0.002162},{1.349542, 0.003186, 0.004270},{
      1.353205, 0.001319, 0.004270},{1.353048, 0.000838, 0.002162}}],
    Polygon[{{1.349542, 0.003186, 0.004270},{1.350029, 0.003857, 0.006273},{
      1.353461, 0.002109, 0.006273},{1.353205, 0.001319, 0.004270}}],
    Polygon[{{1.350029, 0.003857, 0.006273},{1.350695, 0.004774, 0.008122},{
      1.353811, 0.003186, 0.008122},{1.353461, 0.002109, 0.006273}}],
    Polygon[{{1.350695, 0.004774, 0.008122},{1.351523, 0.005913, 0.009770},{
      1.354246, 0.004525, 0.009770},{1.353811, 0.003186, 0.008122}}],
    Polygon[{{1.351523, 0.005913, 0.009770},{1.352492, 0.007247, 0.011178},{
      1.354756, 0.006093, 0.011178},{1.354246, 0.004525, 0.009770}}],
    Polygon[{{1.352492, 0.007247, 0.011178},{1.353578, 0.008742, 0.012311},{
      1.355327, 0.007851, 0.012311},{1.354756, 0.006093, 0.011178}}],
    Polygon[{{1.353578, 0.008742, 0.012311},{1.354756, 0.010363, 0.013141},{
      1.355946, 0.009756, 0.013141},{1.355327, 0.007851, 0.012311}}],
    Polygon[{{1.354756, 0.010363, 0.013141},{1.355995, 0.012069, 0.013647},{
      1.356598, 0.011762, 0.013647},{1.355946, 0.009756, 0.013141}}],
    Polygon[{{1.356598, 0.011762, -0.013647},{1.355946, 0.009756, -0.013141},{
      1.357266, 0.009548, -0.013141},{1.357266, 0.011656, -0.013647}}],
    Polygon[{{1.355946, 0.009756, -0.013141},{1.355327, 0.007851, -0.012311},{
      1.357266, 0.007544, -0.012311},{1.357266, 0.009548, -0.013141}}],
    Polygon[{{1.355327, 0.007851, -0.012311},{1.354756, 0.006093, -0.011178},{
      1.357266, 0.005696, -0.011178},{1.357266, 0.007544, -0.012311}}],
    Polygon[{{1.354756, 0.006093, -0.011178},{1.354246, 0.004525, -0.009770},{
      1.357266, 0.004047, -0.009770},{1.357266, 0.005696, -0.011178}}],
    Polygon[{{1.354246, 0.004525, -0.009770},{1.353811, 0.003186, -0.008122},{
      1.357266, 0.002639, -0.008122},{1.357266, 0.004047, -0.009770}}],
    Polygon[{{1.353811, 0.003186, -0.008122},{1.353461, 0.002109, -0.006273},{
      1.357266, 0.001506, -0.006273},{1.357266, 0.002639, -0.008122}}],
    Polygon[{{1.353461, 0.002109, -0.006273},{1.353205, 0.001319, -0.004270},{
      1.357266, 0.000676, -0.004270},{1.357266, 0.001506, -0.006273}}],
    Polygon[{{1.353205, 0.001319, -0.004270},{1.353048, 0.000838, -0.002162},{
      1.357266, 0.000170, -0.002162},{1.357266, 0.000676, -0.004270}}],
    Polygon[{{1.353048, 0.000838, -0.002162},{1.352996, 0.000676, 0.000000},{
      1.357266, 0.000000, 0.000000},{1.357266, 0.000170, -0.002162}}],
    Polygon[{{1.352996, 0.000676, 0.000000},{1.353048, 0.000838, 0.002162},{
      1.357266, 0.000170, 0.002162},{1.357266, 0.000000, 0.000000}}],
    Polygon[{{1.353048, 0.000838, 0.002162},{1.353205, 0.001319, 0.004270},{
      1.357266, 0.000676, 0.004270},{1.357266, 0.000170, 0.002162}}],
    Polygon[{{1.353205, 0.001319, 0.004270},{1.353461, 0.002109, 0.006273},{
      1.357266, 0.001506, 0.006273},{1.357266, 0.000676, 0.004270}}],
    Polygon[{{1.353461, 0.002109, 0.006273},{1.353811, 0.003186, 0.008122},{
      1.357266, 0.002639, 0.008122},{1.357266, 0.001506, 0.006273}}],
    Polygon[{{1.353811, 0.003186, 0.008122},{1.354246, 0.004525, 0.009770},{
      1.357266, 0.004047, 0.009770},{1.357266, 0.002639, 0.008122}}],
    Polygon[{{1.354246, 0.004525, 0.009770},{1.354756, 0.006093, 0.011178},{
      1.357266, 0.005696, 0.011178},{1.357266, 0.004047, 0.009770}}],
    Polygon[{{1.354756, 0.006093, 0.011178},{1.355327, 0.007851, 0.012311},{
      1.357266, 0.007544, 0.012311},{1.357266, 0.005696, 0.011178}}],
    Polygon[{{1.355327, 0.007851, 0.012311},{1.355946, 0.009756, 0.013141},{
      1.357266, 0.009548, 0.013141},{1.357266, 0.007544, 0.012311}}],
    Polygon[{{1.355946, 0.009756, 0.013141},{1.356598, 0.011762, 0.013647},{
      1.357266, 0.011656, 0.013647},{1.357266, 0.009548, 0.013141}}],
    Polygon[{{1.357266, 0.011656, -0.013647},{1.357266, 0.009548, -0.013141},{
      1.358585, 0.009756, -0.013141},{1.357934, 0.011762, -0.013647}}],
    Polygon[{{1.357266, 0.009548, -0.013141},{1.357266, 0.007544, -0.012311},{
      1.359204, 0.007851, -0.012311},{1.358585, 0.009756, -0.013141}}],
    Polygon[{{1.357266, 0.007544, -0.012311},{1.357266, 0.005696, -0.011178},{
      1.359775, 0.006093, -0.011178},{1.359204, 0.007851, -0.012311}}],
    Polygon[{{1.357266, 0.005696, -0.011178},{1.357266, 0.004047, -0.009770},{
      1.360285, 0.004525, -0.009770},{1.359775, 0.006093, -0.011178}}],
    Polygon[{{1.357266, 0.004047, -0.009770},{1.357266, 0.002639, -0.008122},{
      1.360720, 0.003186, -0.008122},{1.360285, 0.004525, -0.009770}}],
    Polygon[{{1.357266, 0.002639, -0.008122},{1.357266, 0.001506, -0.006273},{
      1.361070, 0.002109, -0.006273},{1.360720, 0.003186, -0.008122}}],
    Polygon[{{1.357266, 0.001506, -0.006273},{1.357266, 0.000676, -0.004270},{
      1.361326, 0.001319, -0.004270},{1.361070, 0.002109, -0.006273}}],
    Polygon[{{1.357266, 0.000676, -0.004270},{1.357266, 0.000170, -0.002162},{
      1.361483, 0.000838, -0.002162},{1.361326, 0.001319, -0.004270}}],
    Polygon[{{1.357266, 0.000170, -0.002162},{1.357266, 0.000000, 0.000000},{
      1.361535, 0.000676, 0.000000},{1.361483, 0.000838, -0.002162}}],
    Polygon[{{1.357266, 0.000000, 0.000000},{1.357266, 0.000170, 0.002162},{
      1.361483, 0.000838, 0.002162},{1.361535, 0.000676, 0.000000}}],
    Polygon[{{1.357266, 0.000170, 0.002162},{1.357266, 0.000676, 0.004270},{
      1.361326, 0.001319, 0.004270},{1.361483, 0.000838, 0.002162}}],
    Polygon[{{1.357266, 0.000676, 0.004270},{1.357266, 0.001506, 0.006273},{
      1.361070, 0.002109, 0.006273},{1.361326, 0.001319, 0.004270}}],
    Polygon[{{1.357266, 0.001506, 0.006273},{1.357266, 0.002639, 0.008122},{
      1.360720, 0.003186, 0.008122},{1.361070, 0.002109, 0.006273}}],
    Polygon[{{1.357266, 0.002639, 0.008122},{1.357266, 0.004047, 0.009770},{
      1.360285, 0.004525, 0.009770},{1.360720, 0.003186, 0.008122}}],
    Polygon[{{1.357266, 0.004047, 0.009770},{1.357266, 0.005696, 0.011178},{
      1.359775, 0.006093, 0.011178},{1.360285, 0.004525, 0.009770}}],
    Polygon[{{1.357266, 0.005696, 0.011178},{1.357266, 0.007544, 0.012311},{
      1.359204, 0.007851, 0.012311},{1.359775, 0.006093, 0.011178}}],
    Polygon[{{1.357266, 0.007544, 0.012311},{1.357266, 0.009548, 0.013141},{
      1.358585, 0.009756, 0.013141},{1.359204, 0.007851, 0.012311}}],
    Polygon[{{1.357266, 0.009548, 0.013141},{1.357266, 0.011656, 0.013647},{
      1.357934, 0.011762, 0.013647},{1.358585, 0.009756, 0.013141}}],
    Polygon[{{1.357934, 0.011762, -0.013647},{1.358585, 0.009756, -0.013141},{
      1.359775, 0.010363, -0.013141},{1.358536, 0.012069, -0.013647}}],
    Polygon[{{1.358585, 0.009756, -0.013141},{1.359204, 0.007851, -0.012311},{
      1.360953, 0.008742, -0.012311},{1.359775, 0.010363, -0.013141}}],
    Polygon[{{1.359204, 0.007851, -0.012311},{1.359775, 0.006093, -0.011178},{
      1.362039, 0.007247, -0.011178},{1.360953, 0.008742, -0.012311}}],
    Polygon[{{1.359775, 0.006093, -0.011178},{1.360285, 0.004525, -0.009770},{
      1.363008, 0.005913, -0.009770},{1.362039, 0.007247, -0.011178}}],
    Polygon[{{1.360285, 0.004525, -0.009770},{1.360720, 0.003186, -0.008122},{
      1.363836, 0.004774, -0.008122},{1.363008, 0.005913, -0.009770}}],
    Polygon[{{1.360720, 0.003186, -0.008122},{1.361070, 0.002109, -0.006273},{
      1.364502, 0.003857, -0.006273},{1.363836, 0.004774, -0.008122}}],
    Polygon[{{1.361070, 0.002109, -0.006273},{1.361326, 0.001319, -0.004270},{
      1.364990, 0.003186, -0.004270},{1.364502, 0.003857, -0.006273}}],
    Polygon[{{1.361326, 0.001319, -0.004270},{1.361483, 0.000838, -0.002162},{
      1.365287, 0.002776, -0.002162},{1.364990, 0.003186, -0.004270}}],
    Polygon[{{1.361483, 0.000838, -0.002162},{1.361535, 0.000676, 0.000000},{
      1.365387, 0.002639, 0.000000},{1.365287, 0.002776, -0.002162}}],
    Polygon[{{1.361535, 0.000676, 0.000000},{1.361483, 0.000838, 0.002162},{
      1.365287, 0.002776, 0.002162},{1.365387, 0.002639, 0.000000}}],
    Polygon[{{1.361483, 0.000838, 0.002162},{1.361326, 0.001319, 0.004270},{
      1.364990, 0.003186, 0.004270},{1.365287, 0.002776, 0.002162}}],
    Polygon[{{1.361326, 0.001319, 0.004270},{1.361070, 0.002109, 0.006273},{
      1.364502, 0.003857, 0.006273},{1.364990, 0.003186, 0.004270}}],
    Polygon[{{1.361070, 0.002109, 0.006273},{1.360720, 0.003186, 0.008122},{
      1.363836, 0.004774, 0.008122},{1.364502, 0.003857, 0.006273}}],
    Polygon[{{1.360720, 0.003186, 0.008122},{1.360285, 0.004525, 0.009770},{
      1.363008, 0.005913, 0.009770},{1.363836, 0.004774, 0.008122}}],
    Polygon[{{1.360285, 0.004525, 0.009770},{1.359775, 0.006093, 0.011178},{
      1.362039, 0.007247, 0.011178},{1.363008, 0.005913, 0.009770}}],
    Polygon[{{1.359775, 0.006093, 0.011178},{1.359204, 0.007851, 0.012311},{
      1.360953, 0.008742, 0.012311},{1.362039, 0.007247, 0.011178}}],
    Polygon[{{1.359204, 0.007851, 0.012311},{1.358585, 0.009756, 0.013141},{
      1.359775, 0.010363, 0.013141},{1.360953, 0.008742, 0.012311}}],
    Polygon[{{1.358585, 0.009756, 0.013141},{1.357934, 0.011762, 0.013647},{
      1.358536, 0.012069, 0.013647},{1.359775, 0.010363, 0.013141}}],
    Polygon[{{1.358536, 0.012069, -0.013647},{1.359775, 0.010363, -0.013141},{
      1.360720, 0.011308, -0.013141},{1.359014, 0.012547, -0.013647}}],
    Polygon[{{1.359775, 0.010363, -0.013141},{1.360953, 0.008742, -0.012311},{
      1.362340, 0.010130, -0.012311},{1.360720, 0.011308, -0.013141}}],
    Polygon[{{1.360953, 0.008742, -0.012311},{1.362039, 0.007247, -0.011178},{
      1.363836, 0.009044, -0.011178},{1.362340, 0.010130, -0.012311}}],
    Polygon[{{1.362039, 0.007247, -0.011178},{1.363008, 0.005913, -0.009770},{
      1.365170, 0.008074, -0.009770},{1.363836, 0.009044, -0.011178}}],
    Polygon[{{1.363008, 0.005913, -0.009770},{1.363836, 0.004774, -0.008122},{
      1.366309, 0.007247, -0.008122},{1.365170, 0.008074, -0.009770}}],
    Polygon[{{1.363836, 0.004774, -0.008122},{1.364502, 0.003857, -0.006273},{
      1.367226, 0.006581, -0.006273},{1.366309, 0.007247, -0.008122}}],
    Polygon[{{1.364502, 0.003857, -0.006273},{1.364990, 0.003186, -0.004270},{
      1.367897, 0.006093, -0.004270},{1.367226, 0.006581, -0.006273}}],
    Polygon[{{1.364990, 0.003186, -0.004270},{1.365287, 0.002776, -0.002162},{
      1.368306, 0.005796, -0.002162},{1.367897, 0.006093, -0.004270}}],
    Polygon[{{1.365287, 0.002776, -0.002162},{1.365387, 0.002639, 0.000000},{
      1.368444, 0.005696, 0.000000},{1.368306, 0.005796, -0.002162}}],
    Polygon[{{1.365387, 0.002639, 0.000000},{1.365287, 0.002776, 0.002162},{
      1.368306, 0.005796, 0.002162},{1.368444, 0.005696, 0.000000}}],
    Polygon[{{1.365287, 0.002776, 0.002162},{1.364990, 0.003186, 0.004270},{
      1.367897, 0.006093, 0.004270},{1.368306, 0.005796, 0.002162}}],
    Polygon[{{1.364990, 0.003186, 0.004270},{1.364502, 0.003857, 0.006273},{
      1.367226, 0.006581, 0.006273},{1.367897, 0.006093, 0.004270}}],
    Polygon[{{1.364502, 0.003857, 0.006273},{1.363836, 0.004774, 0.008122},{
      1.366309, 0.007247, 0.008122},{1.367226, 0.006581, 0.006273}}],
    Polygon[{{1.363836, 0.004774, 0.008122},{1.363008, 0.005913, 0.009770},{
      1.365170, 0.008074, 0.009770},{1.366309, 0.007247, 0.008122}}],
    Polygon[{{1.363008, 0.005913, 0.009770},{1.362039, 0.007247, 0.011178},{
      1.363836, 0.009044, 0.011178},{1.365170, 0.008074, 0.009770}}],
    Polygon[{{1.362039, 0.007247, 0.011178},{1.360953, 0.008742, 0.012311},{
      1.362340, 0.010130, 0.012311},{1.363836, 0.009044, 0.011178}}],
    Polygon[{{1.360953, 0.008742, 0.012311},{1.359775, 0.010363, 0.013141},{
      1.360720, 0.011308, 0.013141},{1.362340, 0.010130, 0.012311}}],
    Polygon[{{1.359775, 0.010363, 0.013141},{1.358536, 0.012069, 0.013647},{
      1.359014, 0.012547, 0.013647},{1.360720, 0.011308, 0.013141}}],
    Polygon[{{1.359014, 0.012547, -0.013647},{1.360720, 0.011308, -0.013141},{
      1.361326, 0.012498, -0.013141},{1.359321, 0.013149, -0.013647}}],
    Polygon[{{1.360720, 0.011308, -0.013141},{1.362340, 0.010130, -0.012311},{
      1.363232, 0.011879, -0.012311},{1.361326, 0.012498, -0.013141}}],
    Polygon[{{1.362340, 0.010130, -0.012311},{1.363836, 0.009044, -0.011178},{
      1.364990, 0.011308, -0.011178},{1.363232, 0.011879, -0.012311}}],
    Polygon[{{1.363836, 0.009044, -0.011178},{1.365170, 0.008074, -0.009770},{
      1.366558, 0.010798, -0.009770},{1.364990, 0.011308, -0.011178}}],
    Polygon[{{1.365170, 0.008074, -0.009770},{1.366309, 0.007247, -0.008122},{
      1.367897, 0.010363, -0.008122},{1.366558, 0.010798, -0.009770}}],
    Polygon[{{1.366309, 0.007247, -0.008122},{1.367226, 0.006581, -0.006273},{
      1.368974, 0.010013, -0.006273},{1.367897, 0.010363, -0.008122}}],
    Polygon[{{1.367226, 0.006581, -0.006273},{1.367897, 0.006093, -0.004270},{
      1.369763, 0.009756, -0.004270},{1.368974, 0.010013, -0.006273}}],
    Polygon[{{1.367897, 0.006093, -0.004270},{1.368306, 0.005796, -0.002162},{
      1.370245, 0.009600, -0.002162},{1.369763, 0.009756, -0.004270}}],
    Polygon[{{1.368306, 0.005796, -0.002162},{1.368444, 0.005696, 0.000000},{
      1.370407, 0.009548, 0.000000},{1.370245, 0.009600, -0.002162}}],
    Polygon[{{1.368444, 0.005696, 0.000000},{1.368306, 0.005796, 0.002162},{
      1.370245, 0.009600, 0.002162},{1.370407, 0.009548, 0.000000}}],
    Polygon[{{1.368306, 0.005796, 0.002162},{1.367897, 0.006093, 0.004270},{
      1.369763, 0.009756, 0.004270},{1.370245, 0.009600, 0.002162}}],
    Polygon[{{1.367897, 0.006093, 0.004270},{1.367226, 0.006581, 0.006273},{
      1.368974, 0.010013, 0.006273},{1.369763, 0.009756, 0.004270}}],
    Polygon[{{1.367226, 0.006581, 0.006273},{1.366309, 0.007247, 0.008122},{
      1.367897, 0.010363, 0.008122},{1.368974, 0.010013, 0.006273}}],
    Polygon[{{1.366309, 0.007247, 0.008122},{1.365170, 0.008074, 0.009770},{
      1.366558, 0.010798, 0.009770},{1.367897, 0.010363, 0.008122}}],
    Polygon[{{1.365170, 0.008074, 0.009770},{1.363836, 0.009044, 0.011178},{
      1.364990, 0.011308, 0.011178},{1.366558, 0.010798, 0.009770}}],
    Polygon[{{1.363836, 0.009044, 0.011178},{1.362340, 0.010130, 0.012311},{
      1.363232, 0.011879, 0.012311},{1.364990, 0.011308, 0.011178}}],
    Polygon[{{1.362340, 0.010130, 0.012311},{1.360720, 0.011308, 0.013141},{
      1.361326, 0.012498, 0.013141},{1.363232, 0.011879, 0.012311}}],
    Polygon[{{1.360720, 0.011308, 0.013141},{1.359014, 0.012547, 0.013647},{
      1.359321, 0.013149, 0.013647},{1.361326, 0.012498, 0.013141}}],
    Polygon[{{1.359321, 0.013149, -0.013647},{1.361326, 0.012498, -0.013141},{
      1.361535, 0.013817, -0.013141},{1.359427, 0.013817, -0.013647}}],
    Polygon[{{1.361326, 0.012498, -0.013141},{1.363232, 0.011879, -0.012311},{
      1.363539, 0.013817, -0.012311},{1.361535, 0.013817, -0.013141}}],
    Polygon[{{1.363232, 0.011879, -0.012311},{1.364990, 0.011308, -0.011178},{
      1.365387, 0.013817, -0.011178},{1.363539, 0.013817, -0.012311}}],
    Polygon[{{1.364990, 0.011308, -0.011178},{1.366558, 0.010798, -0.009770},{
      1.367036, 0.013817, -0.009770},{1.365387, 0.013817, -0.011178}}],
    Polygon[{{1.366558, 0.010798, -0.009770},{1.367897, 0.010363, -0.008122},{
      1.368444, 0.013817, -0.008122},{1.367036, 0.013817, -0.009770}}],
    Polygon[{{1.367897, 0.010363, -0.008122},{1.368974, 0.010013, -0.006273},{
      1.369577, 0.013817, -0.006273},{1.368444, 0.013817, -0.008122}}],
    Polygon[{{1.368974, 0.010013, -0.006273},{1.369763, 0.009756, -0.004270},{
      1.370407, 0.013817, -0.004270},{1.369577, 0.013817, -0.006273}}],
    Polygon[{{1.369763, 0.009756, -0.004270},{1.370245, 0.009600, -0.002162},{
      1.370913, 0.013817, -0.002162},{1.370407, 0.013817, -0.004270}}],
    Polygon[{{1.370245, 0.009600, -0.002162},{1.370407, 0.009548, 0.000000},{
      1.371083, 0.013817, 0.000000},{1.370913, 0.013817, -0.002162}}],
    Polygon[{{1.370407, 0.009548, 0.000000},{1.370245, 0.009600, 0.002162},{
      1.370913, 0.013817, 0.002162},{1.371083, 0.013817, 0.000000}}],
    Polygon[{{1.370245, 0.009600, 0.002162},{1.369763, 0.009756, 0.004270},{
      1.370407, 0.013817, 0.004270},{1.370913, 0.013817, 0.002162}}],
    Polygon[{{1.369763, 0.009756, 0.004270},{1.368974, 0.010013, 0.006273},{
      1.369577, 0.013817, 0.006273},{1.370407, 0.013817, 0.004270}}],
    Polygon[{{1.368974, 0.010013, 0.006273},{1.367897, 0.010363, 0.008122},{
      1.368444, 0.013817, 0.008122},{1.369577, 0.013817, 0.006273}}],
    Polygon[{{1.367897, 0.010363, 0.008122},{1.366558, 0.010798, 0.009770},{
      1.367036, 0.013817, 0.009770},{1.368444, 0.013817, 0.008122}}],
    Polygon[{{1.366558, 0.010798, 0.009770},{1.364990, 0.011308, 0.011178},{
      1.365387, 0.013817, 0.011178},{1.367036, 0.013817, 0.009770}}],
    Polygon[{{1.364990, 0.011308, 0.011178},{1.363232, 0.011879, 0.012311},{
      1.363539, 0.013817, 0.012311},{1.365387, 0.013817, 0.011178}}],
    Polygon[{{1.363232, 0.011879, 0.012311},{1.361326, 0.012498, 0.013141},{
      1.361535, 0.013817, 0.013141},{1.363539, 0.013817, 0.012311}}],
    Polygon[{{1.361326, 0.012498, 0.013141},{1.359321, 0.013149, 0.013647},{
      1.359427, 0.013817, 0.013647},{1.361535, 0.013817, 0.013141}}],
    Polygon[{{1.335350, 0.090242, -0.012733},{1.337317, 0.090242, -0.012261},{
      1.337122, 0.091473, -0.012261},{1.335251, 0.090865, -0.012733}}],
    Polygon[{{1.337317, 0.090242, -0.012261},{1.339186, 0.090242, -0.011487},{
      1.338900, 0.092051, -0.011487},{1.337122, 0.091473, -0.012261}}],
    Polygon[{{1.339186, 0.090242, -0.011487},{1.340911, 0.090242, -0.010430},{
      1.340540, 0.092584, -0.010430},{1.338900, 0.092051, -0.011487}}],
    Polygon[{{1.340911, 0.090242, -0.010430},{1.342449, 0.090242, -0.009116},{
      1.342003, 0.093059, -0.009116},{1.340540, 0.092584, -0.010430}}],
    Polygon[{{1.342449, 0.090242, -0.009116},{1.343763, 0.090242, -0.007578},{
      1.343253, 0.093465, -0.007578},{1.342003, 0.093059, -0.009116}}],
    Polygon[{{1.343763, 0.090242, -0.007578},{1.344820, 0.090242, -0.005853},{
      1.344258, 0.093792, -0.005853},{1.343253, 0.093465, -0.007578}}],
    Polygon[{{1.344820, 0.090242, -0.005853},{1.345594, 0.090242, -0.003984},{
      1.344994, 0.094031, -0.003984},{1.344258, 0.093792, -0.005853}}],
    Polygon[{{1.345594, 0.090242, -0.003984},{1.346066, 0.090242, -0.002017},{
      1.345443, 0.094177, -0.002017},{1.344994, 0.094031, -0.003984}}],
    Polygon[{{1.346066, 0.090242, -0.002017},{1.346225, 0.090242, 0.000000},{
      1.345594, 0.094226, 0.000000},{1.345443, 0.094177, -0.002017}}],
    Polygon[{{1.346225, 0.090242, 0.000000},{1.346066, 0.090242, 0.002017},{
      1.345443, 0.094177, 0.002017},{1.345594, 0.094226, 0.000000}}],
    Polygon[{{1.346066, 0.090242, 0.002017},{1.345594, 0.090242, 0.003984},{
      1.344994, 0.094031, 0.003984},{1.345443, 0.094177, 0.002017}}],
    Polygon[{{1.345594, 0.090242, 0.003984},{1.344820, 0.090242, 0.005853},{
      1.344258, 0.093792, 0.005853},{1.344994, 0.094031, 0.003984}}],
    Polygon[{{1.344820, 0.090242, 0.005853},{1.343763, 0.090242, 0.007578},{
      1.343253, 0.093465, 0.007578},{1.344258, 0.093792, 0.005853}}],
    Polygon[{{1.343763, 0.090242, 0.007578},{1.342449, 0.090242, 0.009116},{
      1.342003, 0.093059, 0.009116},{1.343253, 0.093465, 0.007578}}],
    Polygon[{{1.342449, 0.090242, 0.009116},{1.340911, 0.090242, 0.010430},{
      1.340540, 0.092584, 0.010430},{1.342003, 0.093059, 0.009116}}],
    Polygon[{{1.340911, 0.090242, 0.010430},{1.339186, 0.090242, 0.011487},{
      1.338900, 0.092051, 0.011487},{1.340540, 0.092584, 0.010430}}],
    Polygon[{{1.339186, 0.090242, 0.011487},{1.337317, 0.090242, 0.012261},{
      1.337122, 0.091473, 0.012261},{1.338900, 0.092051, 0.011487}}],
    Polygon[{{1.337317, 0.090242, 0.012261},{1.335350, 0.090242, 0.012733},{
      1.335251, 0.090865, 0.012733},{1.337122, 0.091473, 0.012261}}],
    Polygon[{{1.335251, 0.090865, -0.012733},{1.337122, 0.091473, -0.012261},{
      1.336556, 0.092584, -0.012261},{1.334965, 0.091427, -0.012733}}],
    Polygon[{{1.337122, 0.091473, -0.012261},{1.338900, 0.092051, -0.011487},{
      1.338068, 0.093682, -0.011487},{1.336556, 0.092584, -0.012261}}],
    Polygon[{{1.338900, 0.092051, -0.011487},{1.340540, 0.092584, -0.010430},{
      1.339464, 0.094696, -0.010430},{1.338068, 0.093682, -0.011487}}],
    Polygon[{{1.340540, 0.092584, -0.010430},{1.342003, 0.093059, -0.009116},{
      1.340708, 0.095600, -0.009116},{1.339464, 0.094696, -0.010430}}],
    Polygon[{{1.342003, 0.093059, -0.009116},{1.343253, 0.093465, -0.007578},{
      1.341771, 0.096372, -0.007578},{1.340708, 0.095600, -0.009116}}],
    Polygon[{{1.343253, 0.093465, -0.007578},{1.344258, 0.093792, -0.005853},{
      1.342626, 0.096994, -0.005853},{1.341771, 0.096372, -0.007578}}],
    Polygon[{{1.344258, 0.093792, -0.005853},{1.344994, 0.094031, -0.003984},{
      1.343253, 0.097449, -0.003984},{1.342626, 0.096994, -0.005853}}],
    Polygon[{{1.344994, 0.094031, -0.003984},{1.345443, 0.094177, -0.002017},{
      1.343634, 0.097726, -0.002017},{1.343253, 0.097449, -0.003984}}],
    Polygon[{{1.345443, 0.094177, -0.002017},{1.345594, 0.094226, 0.000000},{
      1.343763, 0.097820, 0.000000},{1.343634, 0.097726, -0.002017}}],
    Polygon[{{1.345594, 0.094226, 0.000000},{1.345443, 0.094177, 0.002017},{
      1.343634, 0.097726, 0.002017},{1.343763, 0.097820, 0.000000}}],
    Polygon[{{1.345443, 0.094177, 0.002017},{1.344994, 0.094031, 0.003984},{
      1.343253, 0.097449, 0.003984},{1.343634, 0.097726, 0.002017}}],
    Polygon[{{1.344994, 0.094031, 0.003984},{1.344258, 0.093792, 0.005853},{
      1.342626, 0.096994, 0.005853},{1.343253, 0.097449, 0.003984}}],
    Polygon[{{1.344258, 0.093792, 0.005853},{1.343253, 0.093465, 0.007578},{
      1.341771, 0.096372, 0.007578},{1.342626, 0.096994, 0.005853}}],
    Polygon[{{1.343253, 0.093465, 0.007578},{1.342003, 0.093059, 0.009116},{
      1.340708, 0.095600, 0.009116},{1.341771, 0.096372, 0.007578}}],
    Polygon[{{1.342003, 0.093059, 0.009116},{1.340540, 0.092584, 0.010430},{
      1.339464, 0.094696, 0.010430},{1.340708, 0.095600, 0.009116}}],
    Polygon[{{1.340540, 0.092584, 0.010430},{1.338900, 0.092051, 0.011487},{
      1.338068, 0.093682, 0.011487},{1.339464, 0.094696, 0.010430}}],
    Polygon[{{1.338900, 0.092051, 0.011487},{1.337122, 0.091473, 0.012261},{
      1.336556, 0.092584, 0.012261},{1.338068, 0.093682, 0.011487}}],
    Polygon[{{1.337122, 0.091473, 0.012261},{1.335251, 0.090865, 0.012733},{
      1.334965, 0.091427, 0.012733},{1.336556, 0.092584, 0.012261}}],
    Polygon[{{1.334965, 0.091427, -0.012733},{1.336556, 0.092584, -0.012261},{
      1.335675, 0.093465, -0.012261},{1.334519, 0.091874, -0.012733}}],
    Polygon[{{1.336556, 0.092584, -0.012261},{1.338068, 0.093682, -0.011487},{
      1.336774, 0.094977, -0.011487},{1.335675, 0.093465, -0.012261}}],
    Polygon[{{1.338068, 0.093682, -0.011487},{1.339464, 0.094696, -0.010430},{
      1.337787, 0.096372, -0.010430},{1.336774, 0.094977, -0.011487}}],
    Polygon[{{1.339464, 0.094696, -0.010430},{1.340708, 0.095600, -0.009116},{
      1.338691, 0.097617, -0.009116},{1.337787, 0.096372, -0.010430}}],
    Polygon[{{1.340708, 0.095600, -0.009116},{1.341771, 0.096372, -0.007578},{
      1.339464, 0.098680, -0.007578},{1.338691, 0.097617, -0.009116}}],
    Polygon[{{1.341771, 0.096372, -0.007578},{1.342626, 0.096994, -0.005853},{
      1.340085, 0.099535, -0.005853},{1.339464, 0.098680, -0.007578}}],
    Polygon[{{1.342626, 0.096994, -0.005853},{1.343253, 0.097449, -0.003984},{
      1.340540, 0.100161, -0.003984},{1.340085, 0.099535, -0.005853}}],
    Polygon[{{1.343253, 0.097449, -0.003984},{1.343634, 0.097726, -0.002017},{
      1.340818, 0.100543, -0.002017},{1.340540, 0.100161, -0.003984}}],
    Polygon[{{1.343634, 0.097726, -0.002017},{1.343763, 0.097820, 0.000000},{
      1.340911, 0.100672, 0.000000},{1.340818, 0.100543, -0.002017}}],
    Polygon[{{1.343763, 0.097820, 0.000000},{1.343634, 0.097726, 0.002017},{
      1.340818, 0.100543, 0.002017},{1.340911, 0.100672, 0.000000}}],
    Polygon[{{1.343634, 0.097726, 0.002017},{1.343253, 0.097449, 0.003984},{
      1.340540, 0.100161, 0.003984},{1.340818, 0.100543, 0.002017}}],
    Polygon[{{1.343253, 0.097449, 0.003984},{1.342626, 0.096994, 0.005853},{
      1.340085, 0.099535, 0.005853},{1.340540, 0.100161, 0.003984}}],
    Polygon[{{1.342626, 0.096994, 0.005853},{1.341771, 0.096372, 0.007578},{
      1.339464, 0.098680, 0.007578},{1.340085, 0.099535, 0.005853}}],
    Polygon[{{1.341771, 0.096372, 0.007578},{1.340708, 0.095600, 0.009116},{
      1.338691, 0.097617, 0.009116},{1.339464, 0.098680, 0.007578}}],
    Polygon[{{1.340708, 0.095600, 0.009116},{1.339464, 0.094696, 0.010430},{
      1.337787, 0.096372, 0.010430},{1.338691, 0.097617, 0.009116}}],
    Polygon[{{1.339464, 0.094696, 0.010430},{1.338068, 0.093682, 0.011487},{
      1.336774, 0.094977, 0.011487},{1.337787, 0.096372, 0.010430}}],
    Polygon[{{1.338068, 0.093682, 0.011487},{1.336556, 0.092584, 0.012261},{
      1.335675, 0.093465, 0.012261},{1.336774, 0.094977, 0.011487}}],
    Polygon[{{1.336556, 0.092584, 0.012261},{1.334965, 0.091427, 0.012733},{
      1.334519, 0.091874, 0.012733},{1.335675, 0.093465, 0.012261}}],
    Polygon[{{1.334519, 0.091874, -0.012733},{1.335675, 0.093465, -0.012261},{
      1.334564, 0.094031, -0.012261},{1.333956, 0.092160, -0.012733}}],
    Polygon[{{1.335675, 0.093465, -0.012261},{1.336774, 0.094977, -0.011487},{
      1.335142, 0.095808, -0.011487},{1.334564, 0.094031, -0.012261}}],
    Polygon[{{1.336774, 0.094977, -0.011487},{1.337787, 0.096372, -0.010430},{
      1.335675, 0.097449, -0.010430},{1.335142, 0.095808, -0.011487}}],
    Polygon[{{1.337787, 0.096372, -0.010430},{1.338691, 0.097617, -0.009116},{
      1.336150, 0.098912, -0.009116},{1.335675, 0.097449, -0.010430}}],
    Polygon[{{1.338691, 0.097617, -0.009116},{1.339464, 0.098680, -0.007578},{
      1.336556, 0.100161, -0.007578},{1.336150, 0.098912, -0.009116}}],
    Polygon[{{1.339464, 0.098680, -0.007578},{1.340085, 0.099535, -0.005853},{
      1.336883, 0.101166, -0.005853},{1.336556, 0.100161, -0.007578}}],
    Polygon[{{1.340085, 0.099535, -0.005853},{1.340540, 0.100161, -0.003984},{
      1.337122, 0.101903, -0.003984},{1.336883, 0.101166, -0.005853}}],
    Polygon[{{1.340540, 0.100161, -0.003984},{1.340818, 0.100543, -0.002017},{
      1.337268, 0.102352, -0.002017},{1.337122, 0.101903, -0.003984}}],
    Polygon[{{1.340818, 0.100543, -0.002017},{1.340911, 0.100672, 0.000000},{
      1.337317, 0.102503, 0.000000},{1.337268, 0.102352, -0.002017}}],
    Polygon[{{1.340911, 0.100672, 0.000000},{1.340818, 0.100543, 0.002017},{
      1.337268, 0.102352, 0.002017},{1.337317, 0.102503, 0.000000}}],
    Polygon[{{1.340818, 0.100543, 0.002017},{1.340540, 0.100161, 0.003984},{
      1.337122, 0.101903, 0.003984},{1.337268, 0.102352, 0.002017}}],
    Polygon[{{1.340540, 0.100161, 0.003984},{1.340085, 0.099535, 0.005853},{
      1.336883, 0.101166, 0.005853},{1.337122, 0.101903, 0.003984}}],
    Polygon[{{1.340085, 0.099535, 0.005853},{1.339464, 0.098680, 0.007578},{
      1.336556, 0.100161, 0.007578},{1.336883, 0.101166, 0.005853}}],
    Polygon[{{1.339464, 0.098680, 0.007578},{1.338691, 0.097617, 0.009116},{
      1.336150, 0.098912, 0.009116},{1.336556, 0.100161, 0.007578}}],
    Polygon[{{1.338691, 0.097617, 0.009116},{1.337787, 0.096372, 0.010430},{
      1.335675, 0.097449, 0.010430},{1.336150, 0.098912, 0.009116}}],
    Polygon[{{1.337787, 0.096372, 0.010430},{1.336774, 0.094977, 0.011487},{
      1.335142, 0.095808, 0.011487},{1.335675, 0.097449, 0.010430}}],
    Polygon[{{1.336774, 0.094977, 0.011487},{1.335675, 0.093465, 0.012261},{
      1.334564, 0.094031, 0.012261},{1.335142, 0.095808, 0.011487}}],
    Polygon[{{1.335675, 0.093465, 0.012261},{1.334519, 0.091874, 0.012733},{
      1.333956, 0.092160, 0.012733},{1.334564, 0.094031, 0.012261}}],
    Polygon[{{1.333956, 0.092160, -0.012733},{1.334564, 0.094031, -0.012261},{
      1.333333, 0.094226, -0.012261},{1.333333, 0.092259, -0.012733}}],
    Polygon[{{1.334564, 0.094031, -0.012261},{1.335142, 0.095808, -0.011487},{
      1.333333, 0.096095, -0.011487},{1.333333, 0.094226, -0.012261}}],
    Polygon[{{1.335142, 0.095808, -0.011487},{1.335675, 0.097449, -0.010430},{
      1.333333, 0.097820, -0.010430},{1.333333, 0.096095, -0.011487}}],
    Polygon[{{1.335675, 0.097449, -0.010430},{1.336150, 0.098912, -0.009116},{
      1.333333, 0.099358, -0.009116},{1.333333, 0.097820, -0.010430}}],
    Polygon[{{1.336150, 0.098912, -0.009116},{1.336556, 0.100161, -0.007578},{
      1.333333, 0.100672, -0.007578},{1.333333, 0.099358, -0.009116}}],
    Polygon[{{1.336556, 0.100161, -0.007578},{1.336883, 0.101166, -0.005853},{
      1.333333, 0.101729, -0.005853},{1.333333, 0.100672, -0.007578}}],
    Polygon[{{1.336883, 0.101166, -0.005853},{1.337122, 0.101903, -0.003984},{
      1.333333, 0.102503, -0.003984},{1.333333, 0.101729, -0.005853}}],
    Polygon[{{1.337122, 0.101903, -0.003984},{1.337268, 0.102352, -0.002017},{
      1.333333, 0.102975, -0.002017},{1.333333, 0.102503, -0.003984}}],
    Polygon[{{1.337268, 0.102352, -0.002017},{1.337317, 0.102503, 0.000000},{
      1.333333, 0.103134, 0.000000},{1.333333, 0.102975, -0.002017}}],
    Polygon[{{1.337317, 0.102503, 0.000000},{1.337268, 0.102352, 0.002017},{
      1.333333, 0.102975, 0.002017},{1.333333, 0.103134, 0.000000}}],
    Polygon[{{1.337268, 0.102352, 0.002017},{1.337122, 0.101903, 0.003984},{
      1.333333, 0.102503, 0.003984},{1.333333, 0.102975, 0.002017}}],
    Polygon[{{1.337122, 0.101903, 0.003984},{1.336883, 0.101166, 0.005853},{
      1.333333, 0.101729, 0.005853},{1.333333, 0.102503, 0.003984}}],
    Polygon[{{1.336883, 0.101166, 0.005853},{1.336556, 0.100161, 0.007578},{
      1.333333, 0.100672, 0.007578},{1.333333, 0.101729, 0.005853}}],
    Polygon[{{1.336556, 0.100161, 0.007578},{1.336150, 0.098912, 0.009116},{
      1.333333, 0.099358, 0.009116},{1.333333, 0.100672, 0.007578}}],
    Polygon[{{1.336150, 0.098912, 0.009116},{1.335675, 0.097449, 0.010430},{
      1.333333, 0.097820, 0.010430},{1.333333, 0.099358, 0.009116}}],
    Polygon[{{1.335675, 0.097449, 0.010430},{1.335142, 0.095808, 0.011487},{
      1.333333, 0.096095, 0.011487},{1.333333, 0.097820, 0.010430}}],
    Polygon[{{1.335142, 0.095808, 0.011487},{1.334564, 0.094031, 0.012261},{
      1.333333, 0.094226, 0.012261},{1.333333, 0.096095, 0.011487}}],
    Polygon[{{1.334564, 0.094031, 0.012261},{1.333956, 0.092160, 0.012733},{
      1.333333, 0.092259, 0.012733},{1.333333, 0.094226, 0.012261}}],
    Polygon[{{1.333333, 0.092259, -0.012733},{1.333333, 0.094226, -0.012261},{
      1.332102, 0.094031, -0.012261},{1.332710, 0.092160, -0.012733}}],
    Polygon[{{1.333333, 0.094226, -0.012261},{1.333333, 0.096095, -0.011487},{
      1.331525, 0.095808, -0.011487},{1.332102, 0.094031, -0.012261}}],
    Polygon[{{1.333333, 0.096095, -0.011487},{1.333333, 0.097820, -0.010430},{
      1.330992, 0.097449, -0.010430},{1.331525, 0.095808, -0.011487}}],
    Polygon[{{1.333333, 0.097820, -0.010430},{1.333333, 0.099358, -0.009116},{
      1.330516, 0.098912, -0.009116},{1.330992, 0.097449, -0.010430}}],
    Polygon[{{1.333333, 0.099358, -0.009116},{1.333333, 0.100672, -0.007578},{
      1.330110, 0.100161, -0.007578},{1.330516, 0.098912, -0.009116}}],
    Polygon[{{1.333333, 0.100672, -0.007578},{1.333333, 0.101729, -0.005853},{
      1.329784, 0.101166, -0.005853},{1.330110, 0.100161, -0.007578}}],
    Polygon[{{1.333333, 0.101729, -0.005853},{1.333333, 0.102503, -0.003984},{
      1.329545, 0.101903, -0.003984},{1.329784, 0.101166, -0.005853}}],
    Polygon[{{1.333333, 0.102503, -0.003984},{1.333333, 0.102975, -0.002017},{
      1.329399, 0.102352, -0.002017},{1.329545, 0.101903, -0.003984}}],
    Polygon[{{1.333333, 0.102975, -0.002017},{1.333333, 0.103134, 0.000000},{
      1.329350, 0.102503, 0.000000},{1.329399, 0.102352, -0.002017}}],
    Polygon[{{1.333333, 0.103134, 0.000000},{1.333333, 0.102975, 0.002017},{
      1.329399, 0.102352, 0.002017},{1.329350, 0.102503, 0.000000}}],
    Polygon[{{1.333333, 0.102975, 0.002017},{1.333333, 0.102503, 0.003984},{
      1.329545, 0.101903, 0.003984},{1.329399, 0.102352, 0.002017}}],
    Polygon[{{1.333333, 0.102503, 0.003984},{1.333333, 0.101729, 0.005853},{
      1.329784, 0.101166, 0.005853},{1.329545, 0.101903, 0.003984}}],
    Polygon[{{1.333333, 0.101729, 0.005853},{1.333333, 0.100672, 0.007578},{
      1.330110, 0.100161, 0.007578},{1.329784, 0.101166, 0.005853}}],
    Polygon[{{1.333333, 0.100672, 0.007578},{1.333333, 0.099358, 0.009116},{
      1.330516, 0.098912, 0.009116},{1.330110, 0.100161, 0.007578}}],
    Polygon[{{1.333333, 0.099358, 0.009116},{1.333333, 0.097820, 0.010430},{
      1.330992, 0.097449, 0.010430},{1.330516, 0.098912, 0.009116}}],
    Polygon[{{1.333333, 0.097820, 0.010430},{1.333333, 0.096095, 0.011487},{
      1.331525, 0.095808, 0.011487},{1.330992, 0.097449, 0.010430}}],
    Polygon[{{1.333333, 0.096095, 0.011487},{1.333333, 0.094226, 0.012261},{
      1.332102, 0.094031, 0.012261},{1.331525, 0.095808, 0.011487}}],
    Polygon[{{1.333333, 0.094226, 0.012261},{1.333333, 0.092259, 0.012733},{
      1.332710, 0.092160, 0.012733},{1.332102, 0.094031, 0.012261}}],
    Polygon[{{1.332710, 0.092160, -0.012733},{1.332102, 0.094031, -0.012261},{
      1.330992, 0.093465, -0.012261},{1.332148, 0.091874, -0.012733}}],
    Polygon[{{1.332102, 0.094031, -0.012261},{1.331525, 0.095808, -0.011487},{
      1.329893, 0.094977, -0.011487},{1.330992, 0.093465, -0.012261}}],
    Polygon[{{1.331525, 0.095808, -0.011487},{1.330992, 0.097449, -0.010430},{
      1.328879, 0.096372, -0.010430},{1.329893, 0.094977, -0.011487}}],
    Polygon[{{1.330992, 0.097449, -0.010430},{1.330516, 0.098912, -0.009116},{
      1.327975, 0.097617, -0.009116},{1.328879, 0.096372, -0.010430}}],
    Polygon[{{1.330516, 0.098912, -0.009116},{1.330110, 0.100161, -0.007578},{
      1.327203, 0.098680, -0.007578},{1.327975, 0.097617, -0.009116}}],
    Polygon[{{1.330110, 0.100161, -0.007578},{1.329784, 0.101166, -0.005853},{
      1.326582, 0.099535, -0.005853},{1.327203, 0.098680, -0.007578}}],
    Polygon[{{1.329784, 0.101166, -0.005853},{1.329545, 0.101903, -0.003984},{
      1.326127, 0.100161, -0.003984},{1.326582, 0.099535, -0.005853}}],
    Polygon[{{1.329545, 0.101903, -0.003984},{1.329399, 0.102352, -0.002017},{
      1.325849, 0.100543, -0.002017},{1.326127, 0.100161, -0.003984}}],
    Polygon[{{1.329399, 0.102352, -0.002017},{1.329350, 0.102503, 0.000000},{
      1.325756, 0.100672, 0.000000},{1.325849, 0.100543, -0.002017}}],
    Polygon[{{1.329350, 0.102503, 0.000000},{1.329399, 0.102352, 0.002017},{
      1.325849, 0.100543, 0.002017},{1.325756, 0.100672, 0.000000}}],
    Polygon[{{1.329399, 0.102352, 0.002017},{1.329545, 0.101903, 0.003984},{
      1.326127, 0.100161, 0.003984},{1.325849, 0.100543, 0.002017}}],
    Polygon[{{1.329545, 0.101903, 0.003984},{1.329784, 0.101166, 0.005853},{
      1.326582, 0.099535, 0.005853},{1.326127, 0.100161, 0.003984}}],
    Polygon[{{1.329784, 0.101166, 0.005853},{1.330110, 0.100161, 0.007578},{
      1.327203, 0.098680, 0.007578},{1.326582, 0.099535, 0.005853}}],
    Polygon[{{1.330110, 0.100161, 0.007578},{1.330516, 0.098912, 0.009116},{
      1.327975, 0.097617, 0.009116},{1.327203, 0.098680, 0.007578}}],
    Polygon[{{1.330516, 0.098912, 0.009116},{1.330992, 0.097449, 0.010430},{
      1.328879, 0.096372, 0.010430},{1.327975, 0.097617, 0.009116}}],
    Polygon[{{1.330992, 0.097449, 0.010430},{1.331525, 0.095808, 0.011487},{
      1.329893, 0.094977, 0.011487},{1.328879, 0.096372, 0.010430}}],
    Polygon[{{1.331525, 0.095808, 0.011487},{1.332102, 0.094031, 0.012261},{
      1.330992, 0.093465, 0.012261},{1.329893, 0.094977, 0.011487}}],
    Polygon[{{1.332102, 0.094031, 0.012261},{1.332710, 0.092160, 0.012733},{
      1.332148, 0.091874, 0.012733},{1.330992, 0.093465, 0.012261}}],
    Polygon[{{1.332148, 0.091874, -0.012733},{1.330992, 0.093465, -0.012261},{
      1.330110, 0.092584, -0.012261},{1.331702, 0.091427, -0.012733}}],
    Polygon[{{1.330992, 0.093465, -0.012261},{1.329893, 0.094977, -0.011487},{
      1.328598, 0.093682, -0.011487},{1.330110, 0.092584, -0.012261}}],
    Polygon[{{1.329893, 0.094977, -0.011487},{1.328879, 0.096372, -0.010430},{
      1.327203, 0.094696, -0.010430},{1.328598, 0.093682, -0.011487}}],
    Polygon[{{1.328879, 0.096372, -0.010430},{1.327975, 0.097617, -0.009116},{
      1.325958, 0.095600, -0.009116},{1.327203, 0.094696, -0.010430}}],
    Polygon[{{1.327975, 0.097617, -0.009116},{1.327203, 0.098680, -0.007578},{
      1.324896, 0.096372, -0.007578},{1.325958, 0.095600, -0.009116}}],
    Polygon[{{1.327203, 0.098680, -0.007578},{1.326582, 0.099535, -0.005853},{
      1.324041, 0.096994, -0.005853},{1.324896, 0.096372, -0.007578}}],
    Polygon[{{1.326582, 0.099535, -0.005853},{1.326127, 0.100161, -0.003984},{
      1.323414, 0.097449, -0.003984},{1.324041, 0.096994, -0.005853}}],
    Polygon[{{1.326127, 0.100161, -0.003984},{1.325849, 0.100543, -0.002017},{
      1.323032, 0.097726, -0.002017},{1.323414, 0.097449, -0.003984}}],
    Polygon[{{1.325849, 0.100543, -0.002017},{1.325756, 0.100672, 0.000000},{
      1.322904, 0.097820, 0.000000},{1.323032, 0.097726, -0.002017}}],
    Polygon[{{1.325756, 0.100672, 0.000000},{1.325849, 0.100543, 0.002017},{
      1.323032, 0.097726, 0.002017},{1.322904, 0.097820, 0.000000}}],
    Polygon[{{1.325849, 0.100543, 0.002017},{1.326127, 0.100161, 0.003984},{
      1.323414, 0.097449, 0.003984},{1.323032, 0.097726, 0.002017}}],
    Polygon[{{1.326127, 0.100161, 0.003984},{1.326582, 0.099535, 0.005853},{
      1.324041, 0.096994, 0.005853},{1.323414, 0.097449, 0.003984}}],
    Polygon[{{1.326582, 0.099535, 0.005853},{1.327203, 0.098680, 0.007578},{
      1.324896, 0.096372, 0.007578},{1.324041, 0.096994, 0.005853}}],
    Polygon[{{1.327203, 0.098680, 0.007578},{1.327975, 0.097617, 0.009116},{
      1.325958, 0.095600, 0.009116},{1.324896, 0.096372, 0.007578}}],
    Polygon[{{1.327975, 0.097617, 0.009116},{1.328879, 0.096372, 0.010430},{
      1.327203, 0.094696, 0.010430},{1.325958, 0.095600, 0.009116}}],
    Polygon[{{1.328879, 0.096372, 0.010430},{1.329893, 0.094977, 0.011487},{
      1.328598, 0.093682, 0.011487},{1.327203, 0.094696, 0.010430}}],
    Polygon[{{1.329893, 0.094977, 0.011487},{1.330992, 0.093465, 0.012261},{
      1.330110, 0.092584, 0.012261},{1.328598, 0.093682, 0.011487}}],
    Polygon[{{1.330992, 0.093465, 0.012261},{1.332148, 0.091874, 0.012733},{
      1.331702, 0.091427, 0.012733},{1.330110, 0.092584, 0.012261}}],
    Polygon[{{1.331702, 0.091427, -0.012733},{1.330110, 0.092584, -0.012261},{
      1.329545, 0.091473, -0.012261},{1.331415, 0.090865, -0.012733}}],
    Polygon[{{1.330110, 0.092584, -0.012261},{1.328598, 0.093682, -0.011487},{
      1.327767, 0.092051, -0.011487},{1.329545, 0.091473, -0.012261}}],
    Polygon[{{1.328598, 0.093682, -0.011487},{1.327203, 0.094696, -0.010430},{
      1.326127, 0.092584, -0.010430},{1.327767, 0.092051, -0.011487}}],
    Polygon[{{1.327203, 0.094696, -0.010430},{1.325958, 0.095600, -0.009116},{
      1.324664, 0.093059, -0.009116},{1.326127, 0.092584, -0.010430}}],
    Polygon[{{1.325958, 0.095600, -0.009116},{1.324896, 0.096372, -0.007578},{
      1.323414, 0.093465, -0.007578},{1.324664, 0.093059, -0.009116}}],
    Polygon[{{1.324896, 0.096372, -0.007578},{1.324041, 0.096994, -0.005853},{
      1.322409, 0.093792, -0.005853},{1.323414, 0.093465, -0.007578}}],
    Polygon[{{1.324041, 0.096994, -0.005853},{1.323414, 0.097449, -0.003984},{
      1.321673, 0.094031, -0.003984},{1.322409, 0.093792, -0.005853}}],
    Polygon[{{1.323414, 0.097449, -0.003984},{1.323032, 0.097726, -0.002017},{
      1.321223, 0.094177, -0.002017},{1.321673, 0.094031, -0.003984}}],
    Polygon[{{1.323032, 0.097726, -0.002017},{1.322904, 0.097820, 0.000000},{
      1.321073, 0.094226, 0.000000},{1.321223, 0.094177, -0.002017}}],
    Polygon[{{1.322904, 0.097820, 0.000000},{1.323032, 0.097726, 0.002017},{
      1.321223, 0.094177, 0.002017},{1.321073, 0.094226, 0.000000}}],
    Polygon[{{1.323032, 0.097726, 0.002017},{1.323414, 0.097449, 0.003984},{
      1.321673, 0.094031, 0.003984},{1.321223, 0.094177, 0.002017}}],
    Polygon[{{1.323414, 0.097449, 0.003984},{1.324041, 0.096994, 0.005853},{
      1.322409, 0.093792, 0.005853},{1.321673, 0.094031, 0.003984}}],
    Polygon[{{1.324041, 0.096994, 0.005853},{1.324896, 0.096372, 0.007578},{
      1.323414, 0.093465, 0.007578},{1.322409, 0.093792, 0.005853}}],
    Polygon[{{1.324896, 0.096372, 0.007578},{1.325958, 0.095600, 0.009116},{
      1.324664, 0.093059, 0.009116},{1.323414, 0.093465, 0.007578}}],
    Polygon[{{1.325958, 0.095600, 0.009116},{1.327203, 0.094696, 0.010430},{
      1.326127, 0.092584, 0.010430},{1.324664, 0.093059, 0.009116}}],
    Polygon[{{1.327203, 0.094696, 0.010430},{1.328598, 0.093682, 0.011487},{
      1.327767, 0.092051, 0.011487},{1.326127, 0.092584, 0.010430}}],
    Polygon[{{1.328598, 0.093682, 0.011487},{1.330110, 0.092584, 0.012261},{
      1.329545, 0.091473, 0.012261},{1.327767, 0.092051, 0.011487}}],
    Polygon[{{1.330110, 0.092584, 0.012261},{1.331702, 0.091427, 0.012733},{
      1.331415, 0.090865, 0.012733},{1.329545, 0.091473, 0.012261}}],
    Polygon[{{1.331415, 0.090865, -0.012733},{1.329545, 0.091473, -0.012261},{
      1.329350, 0.090242, -0.012261},{1.331317, 0.090242, -0.012733}}],
    Polygon[{{1.329545, 0.091473, -0.012261},{1.327767, 0.092051, -0.011487},{
      1.327481, 0.090242, -0.011487},{1.329350, 0.090242, -0.012261}}],
    Polygon[{{1.327767, 0.092051, -0.011487},{1.326127, 0.092584, -0.010430},{
      1.325756, 0.090242, -0.010430},{1.327481, 0.090242, -0.011487}}],
    Polygon[{{1.326127, 0.092584, -0.010430},{1.324664, 0.093059, -0.009116},{
      1.324218, 0.090242, -0.009116},{1.325756, 0.090242, -0.010430}}],
    Polygon[{{1.324664, 0.093059, -0.009116},{1.323414, 0.093465, -0.007578},{
      1.322904, 0.090242, -0.007578},{1.324218, 0.090242, -0.009116}}],
    Polygon[{{1.323414, 0.093465, -0.007578},{1.322409, 0.093792, -0.005853},{
      1.321847, 0.090242, -0.005853},{1.322904, 0.090242, -0.007578}}],
    Polygon[{{1.322409, 0.093792, -0.005853},{1.321673, 0.094031, -0.003984},{
      1.321073, 0.090242, -0.003984},{1.321847, 0.090242, -0.005853}}],
    Polygon[{{1.321673, 0.094031, -0.003984},{1.321223, 0.094177, -0.002017},{
      1.320600, 0.090242, -0.002017},{1.321073, 0.090242, -0.003984}}],
    Polygon[{{1.321223, 0.094177, -0.002017},{1.321073, 0.094226, 0.000000},{
      1.320442, 0.090242, 0.000000},{1.320600, 0.090242, -0.002017}}],
    Polygon[{{1.321073, 0.094226, 0.000000},{1.321223, 0.094177, 0.002017},{
      1.320600, 0.090242, 0.002017},{1.320442, 0.090242, 0.000000}}],
    Polygon[{{1.321223, 0.094177, 0.002017},{1.321673, 0.094031, 0.003984},{
      1.321073, 0.090242, 0.003984},{1.320600, 0.090242, 0.002017}}],
    Polygon[{{1.321673, 0.094031, 0.003984},{1.322409, 0.093792, 0.005853},{
      1.321847, 0.090242, 0.005853},{1.321073, 0.090242, 0.003984}}],
    Polygon[{{1.322409, 0.093792, 0.005853},{1.323414, 0.093465, 0.007578},{
      1.322904, 0.090242, 0.007578},{1.321847, 0.090242, 0.005853}}],
    Polygon[{{1.323414, 0.093465, 0.007578},{1.324664, 0.093059, 0.009116},{
      1.324218, 0.090242, 0.009116},{1.322904, 0.090242, 0.007578}}],
    Polygon[{{1.324664, 0.093059, 0.009116},{1.326127, 0.092584, 0.010430},{
      1.325756, 0.090242, 0.010430},{1.324218, 0.090242, 0.009116}}],
    Polygon[{{1.326127, 0.092584, 0.010430},{1.327767, 0.092051, 0.011487},{
      1.327481, 0.090242, 0.011487},{1.325756, 0.090242, 0.010430}}],
    Polygon[{{1.327767, 0.092051, 0.011487},{1.329545, 0.091473, 0.012261},{
      1.329350, 0.090242, 0.012261},{1.327481, 0.090242, 0.011487}}],
    Polygon[{{1.329545, 0.091473, 0.012261},{1.331415, 0.090865, 0.012733},{
      1.331317, 0.090242, 0.012733},{1.329350, 0.090242, 0.012261}}],
    Polygon[{{1.331317, 0.090242, -0.012733},{1.329350, 0.090242, -0.012261},{
      1.329545, 0.089011, -0.012261},{1.331415, 0.089619, -0.012733}}],
    Polygon[{{1.329350, 0.090242, -0.012261},{1.327481, 0.090242, -0.011487},{
      1.327767, 0.088433, -0.011487},{1.329545, 0.089011, -0.012261}}],
    Polygon[{{1.327481, 0.090242, -0.011487},{1.325756, 0.090242, -0.010430},{
      1.326127, 0.087900, -0.010430},{1.327767, 0.088433, -0.011487}}],
    Polygon[{{1.325756, 0.090242, -0.010430},{1.324218, 0.090242, -0.009116},{
      1.324664, 0.087425, -0.009116},{1.326127, 0.087900, -0.010430}}],
    Polygon[{{1.324218, 0.090242, -0.009116},{1.322904, 0.090242, -0.007578},{
      1.323414, 0.087019, -0.007578},{1.324664, 0.087425, -0.009116}}],
    Polygon[{{1.322904, 0.090242, -0.007578},{1.321847, 0.090242, -0.005853},{
      1.322409, 0.086692, -0.005853},{1.323414, 0.087019, -0.007578}}],
    Polygon[{{1.321847, 0.090242, -0.005853},{1.321073, 0.090242, -0.003984},{
      1.321673, 0.086453, -0.003984},{1.322409, 0.086692, -0.005853}}],
    Polygon[{{1.321073, 0.090242, -0.003984},{1.320600, 0.090242, -0.002017},{
      1.321223, 0.086307, -0.002017},{1.321673, 0.086453, -0.003984}}],
    Polygon[{{1.320600, 0.090242, -0.002017},{1.320442, 0.090242, 0.000000},{
      1.321073, 0.086258, 0.000000},{1.321223, 0.086307, -0.002017}}],
    Polygon[{{1.320442, 0.090242, 0.000000},{1.320600, 0.090242, 0.002017},{
      1.321223, 0.086307, 0.002017},{1.321073, 0.086258, 0.000000}}],
    Polygon[{{1.320600, 0.090242, 0.002017},{1.321073, 0.090242, 0.003984},{
      1.321673, 0.086453, 0.003984},{1.321223, 0.086307, 0.002017}}],
    Polygon[{{1.321073, 0.090242, 0.003984},{1.321847, 0.090242, 0.005853},{
      1.322409, 0.086692, 0.005853},{1.321673, 0.086453, 0.003984}}],
    Polygon[{{1.321847, 0.090242, 0.005853},{1.322904, 0.090242, 0.007578},{
      1.323414, 0.087019, 0.007578},{1.322409, 0.086692, 0.005853}}],
    Polygon[{{1.322904, 0.090242, 0.007578},{1.324218, 0.090242, 0.009116},{
      1.324664, 0.087425, 0.009116},{1.323414, 0.087019, 0.007578}}],
    Polygon[{{1.324218, 0.090242, 0.009116},{1.325756, 0.090242, 0.010430},{
      1.326127, 0.087900, 0.010430},{1.324664, 0.087425, 0.009116}}],
    Polygon[{{1.325756, 0.090242, 0.010430},{1.327481, 0.090242, 0.011487},{
      1.327767, 0.088433, 0.011487},{1.326127, 0.087900, 0.010430}}],
    Polygon[{{1.327481, 0.090242, 0.011487},{1.329350, 0.090242, 0.012261},{
      1.329545, 0.089011, 0.012261},{1.327767, 0.088433, 0.011487}}],
    Polygon[{{1.329350, 0.090242, 0.012261},{1.331317, 0.090242, 0.012733},{
      1.331415, 0.089619, 0.012733},{1.329545, 0.089011, 0.012261}}],
    Polygon[{{1.331415, 0.089619, -0.012733},{1.329545, 0.089011, -0.012261},{
      1.330110, 0.087900, -0.012261},{1.331702, 0.089057, -0.012733}}],
    Polygon[{{1.329545, 0.089011, -0.012261},{1.327767, 0.088433, -0.011487},{
      1.328598, 0.086802, -0.011487},{1.330110, 0.087900, -0.012261}}],
    Polygon[{{1.327767, 0.088433, -0.011487},{1.326127, 0.087900, -0.010430},{
      1.327203, 0.085788, -0.010430},{1.328598, 0.086802, -0.011487}}],
    Polygon[{{1.326127, 0.087900, -0.010430},{1.324664, 0.087425, -0.009116},{
      1.325958, 0.084884, -0.009116},{1.327203, 0.085788, -0.010430}}],
    Polygon[{{1.324664, 0.087425, -0.009116},{1.323414, 0.087019, -0.007578},{
      1.324896, 0.084112, -0.007578},{1.325958, 0.084884, -0.009116}}],
    Polygon[{{1.323414, 0.087019, -0.007578},{1.322409, 0.086692, -0.005853},{
      1.324041, 0.083490, -0.005853},{1.324896, 0.084112, -0.007578}}],
    Polygon[{{1.322409, 0.086692, -0.005853},{1.321673, 0.086453, -0.003984},{
      1.323414, 0.083035, -0.003984},{1.324041, 0.083490, -0.005853}}],
    Polygon[{{1.321673, 0.086453, -0.003984},{1.321223, 0.086307, -0.002017},{
      1.323032, 0.082758, -0.002017},{1.323414, 0.083035, -0.003984}}],
    Polygon[{{1.321223, 0.086307, -0.002017},{1.321073, 0.086258, 0.000000},{
      1.322904, 0.082664, 0.000000},{1.323032, 0.082758, -0.002017}}],
    Polygon[{{1.321073, 0.086258, 0.000000},{1.321223, 0.086307, 0.002017},{
      1.323032, 0.082758, 0.002017},{1.322904, 0.082664, 0.000000}}],
    Polygon[{{1.321223, 0.086307, 0.002017},{1.321673, 0.086453, 0.003984},{
      1.323414, 0.083035, 0.003984},{1.323032, 0.082758, 0.002017}}],
    Polygon[{{1.321673, 0.086453, 0.003984},{1.322409, 0.086692, 0.005853},{
      1.324041, 0.083490, 0.005853},{1.323414, 0.083035, 0.003984}}],
    Polygon[{{1.322409, 0.086692, 0.005853},{1.323414, 0.087019, 0.007578},{
      1.324896, 0.084112, 0.007578},{1.324041, 0.083490, 0.005853}}],
    Polygon[{{1.323414, 0.087019, 0.007578},{1.324664, 0.087425, 0.009116},{
      1.325958, 0.084884, 0.009116},{1.324896, 0.084112, 0.007578}}],
    Polygon[{{1.324664, 0.087425, 0.009116},{1.326127, 0.087900, 0.010430},{
      1.327203, 0.085788, 0.010430},{1.325958, 0.084884, 0.009116}}],
    Polygon[{{1.326127, 0.087900, 0.010430},{1.327767, 0.088433, 0.011487},{
      1.328598, 0.086802, 0.011487},{1.327203, 0.085788, 0.010430}}],
    Polygon[{{1.327767, 0.088433, 0.011487},{1.329545, 0.089011, 0.012261},{
      1.330110, 0.087900, 0.012261},{1.328598, 0.086802, 0.011487}}],
    Polygon[{{1.329545, 0.089011, 0.012261},{1.331415, 0.089619, 0.012733},{
      1.331702, 0.089057, 0.012733},{1.330110, 0.087900, 0.012261}}],
    Polygon[{{1.331702, 0.089057, -0.012733},{1.330110, 0.087900, -0.012261},{
      1.330992, 0.087019, -0.012261},{1.332148, 0.088610, -0.012733}}],
    Polygon[{{1.330110, 0.087900, -0.012261},{1.328598, 0.086802, -0.011487},{
      1.329893, 0.085507, -0.011487},{1.330992, 0.087019, -0.012261}}],
    Polygon[{{1.328598, 0.086802, -0.011487},{1.327203, 0.085788, -0.010430},{
      1.328879, 0.084112, -0.010430},{1.329893, 0.085507, -0.011487}}],
    Polygon[{{1.327203, 0.085788, -0.010430},{1.325958, 0.084884, -0.009116},{
      1.327975, 0.082867, -0.009116},{1.328879, 0.084112, -0.010430}}],
    Polygon[{{1.325958, 0.084884, -0.009116},{1.324896, 0.084112, -0.007578},{
      1.327203, 0.081804, -0.007578},{1.327975, 0.082867, -0.009116}}],
    Polygon[{{1.324896, 0.084112, -0.007578},{1.324041, 0.083490, -0.005853},{
      1.326582, 0.080949, -0.005853},{1.327203, 0.081804, -0.007578}}],
    Polygon[{{1.324041, 0.083490, -0.005853},{1.323414, 0.083035, -0.003984},{
      1.326127, 0.080323, -0.003984},{1.326582, 0.080949, -0.005853}}],
    Polygon[{{1.323414, 0.083035, -0.003984},{1.323032, 0.082758, -0.002017},{
      1.325849, 0.079941, -0.002017},{1.326127, 0.080323, -0.003984}}],
    Polygon[{{1.323032, 0.082758, -0.002017},{1.322904, 0.082664, 0.000000},{
      1.325756, 0.079812, 0.000000},{1.325849, 0.079941, -0.002017}}],
    Polygon[{{1.322904, 0.082664, 0.000000},{1.323032, 0.082758, 0.002017},{
      1.325849, 0.079941, 0.002017},{1.325756, 0.079812, 0.000000}}],
    Polygon[{{1.323032, 0.082758, 0.002017},{1.323414, 0.083035, 0.003984},{
      1.326127, 0.080323, 0.003984},{1.325849, 0.079941, 0.002017}}],
    Polygon[{{1.323414, 0.083035, 0.003984},{1.324041, 0.083490, 0.005853},{
      1.326582, 0.080949, 0.005853},{1.326127, 0.080323, 0.003984}}],
    Polygon[{{1.324041, 0.083490, 0.005853},{1.324896, 0.084112, 0.007578},{
      1.327203, 0.081804, 0.007578},{1.326582, 0.080949, 0.005853}}],
    Polygon[{{1.324896, 0.084112, 0.007578},{1.325958, 0.084884, 0.009116},{
      1.327975, 0.082867, 0.009116},{1.327203, 0.081804, 0.007578}}],
    Polygon[{{1.325958, 0.084884, 0.009116},{1.327203, 0.085788, 0.010430},{
      1.328879, 0.084112, 0.010430},{1.327975, 0.082867, 0.009116}}],
    Polygon[{{1.327203, 0.085788, 0.010430},{1.328598, 0.086802, 0.011487},{
      1.329893, 0.085507, 0.011487},{1.328879, 0.084112, 0.010430}}],
    Polygon[{{1.328598, 0.086802, 0.011487},{1.330110, 0.087900, 0.012261},{
      1.330992, 0.087019, 0.012261},{1.329893, 0.085507, 0.011487}}],
    Polygon[{{1.330110, 0.087900, 0.012261},{1.331702, 0.089057, 0.012733},{
      1.332148, 0.088610, 0.012733},{1.330992, 0.087019, 0.012261}}],
    Polygon[{{1.332148, 0.088610, -0.012733},{1.330992, 0.087019, -0.012261},{
      1.332102, 0.086453, -0.012261},{1.332710, 0.088324, -0.012733}}],
    Polygon[{{1.330992, 0.087019, -0.012261},{1.329893, 0.085507, -0.011487},{
      1.331525, 0.084676, -0.011487},{1.332102, 0.086453, -0.012261}}],
    Polygon[{{1.329893, 0.085507, -0.011487},{1.328879, 0.084112, -0.010430},{
      1.330992, 0.083035, -0.010430},{1.331525, 0.084676, -0.011487}}],
    Polygon[{{1.328879, 0.084112, -0.010430},{1.327975, 0.082867, -0.009116},{
      1.330516, 0.081572, -0.009116},{1.330992, 0.083035, -0.010430}}],
    Polygon[{{1.327975, 0.082867, -0.009116},{1.327203, 0.081804, -0.007578},{
      1.330110, 0.080323, -0.007578},{1.330516, 0.081572, -0.009116}}],
    Polygon[{{1.327203, 0.081804, -0.007578},{1.326582, 0.080949, -0.005853},{
      1.329784, 0.079318, -0.005853},{1.330110, 0.080323, -0.007578}}],
    Polygon[{{1.326582, 0.080949, -0.005853},{1.326127, 0.080323, -0.003984},{
      1.329545, 0.078581, -0.003984},{1.329784, 0.079318, -0.005853}}],
    Polygon[{{1.326127, 0.080323, -0.003984},{1.325849, 0.079941, -0.002017},{
      1.329399, 0.078132, -0.002017},{1.329545, 0.078581, -0.003984}}],
    Polygon[{{1.325849, 0.079941, -0.002017},{1.325756, 0.079812, 0.000000},{
      1.329350, 0.077981, 0.000000},{1.329399, 0.078132, -0.002017}}],
    Polygon[{{1.325756, 0.079812, 0.000000},{1.325849, 0.079941, 0.002017},{
      1.329399, 0.078132, 0.002017},{1.329350, 0.077981, 0.000000}}],
    Polygon[{{1.325849, 0.079941, 0.002017},{1.326127, 0.080323, 0.003984},{
      1.329545, 0.078581, 0.003984},{1.329399, 0.078132, 0.002017}}],
    Polygon[{{1.326127, 0.080323, 0.003984},{1.326582, 0.080949, 0.005853},{
      1.329784, 0.079318, 0.005853},{1.329545, 0.078581, 0.003984}}],
    Polygon[{{1.326582, 0.080949, 0.005853},{1.327203, 0.081804, 0.007578},{
      1.330110, 0.080323, 0.007578},{1.329784, 0.079318, 0.005853}}],
    Polygon[{{1.327203, 0.081804, 0.007578},{1.327975, 0.082867, 0.009116},{
      1.330516, 0.081572, 0.009116},{1.330110, 0.080323, 0.007578}}],
    Polygon[{{1.327975, 0.082867, 0.009116},{1.328879, 0.084112, 0.010430},{
      1.330992, 0.083035, 0.010430},{1.330516, 0.081572, 0.009116}}],
    Polygon[{{1.328879, 0.084112, 0.010430},{1.329893, 0.085507, 0.011487},{
      1.331525, 0.084676, 0.011487},{1.330992, 0.083035, 0.010430}}],
    Polygon[{{1.329893, 0.085507, 0.011487},{1.330992, 0.087019, 0.012261},{
      1.332102, 0.086453, 0.012261},{1.331525, 0.084676, 0.011487}}],
    Polygon[{{1.330992, 0.087019, 0.012261},{1.332148, 0.088610, 0.012733},{
      1.332710, 0.088324, 0.012733},{1.332102, 0.086453, 0.012261}}],
    Polygon[{{1.332710, 0.088324, -0.012733},{1.332102, 0.086453, -0.012261},{
      1.333333, 0.086258, -0.012261},{1.333333, 0.088225, -0.012733}}],
    Polygon[{{1.332102, 0.086453, -0.012261},{1.331525, 0.084676, -0.011487},{
      1.333333, 0.084389, -0.011487},{1.333333, 0.086258, -0.012261}}],
    Polygon[{{1.331525, 0.084676, -0.011487},{1.330992, 0.083035, -0.010430},{
      1.333333, 0.082664, -0.010430},{1.333333, 0.084389, -0.011487}}],
    Polygon[{{1.330992, 0.083035, -0.010430},{1.330516, 0.081572, -0.009116},{
      1.333333, 0.081126, -0.009116},{1.333333, 0.082664, -0.010430}}],
    Polygon[{{1.330516, 0.081572, -0.009116},{1.330110, 0.080323, -0.007578},{
      1.333333, 0.079812, -0.007578},{1.333333, 0.081126, -0.009116}}],
    Polygon[{{1.330110, 0.080323, -0.007578},{1.329784, 0.079318, -0.005853},{
      1.333333, 0.078755, -0.005853},{1.333333, 0.079812, -0.007578}}],
    Polygon[{{1.329784, 0.079318, -0.005853},{1.329545, 0.078581, -0.003984},{
      1.333333, 0.077981, -0.003984},{1.333333, 0.078755, -0.005853}}],
    Polygon[{{1.329545, 0.078581, -0.003984},{1.329399, 0.078132, -0.002017},{
      1.333333, 0.077509, -0.002017},{1.333333, 0.077981, -0.003984}}],
    Polygon[{{1.329399, 0.078132, -0.002017},{1.329350, 0.077981, 0.000000},{
      1.333333, 0.077350, 0.000000},{1.333333, 0.077509, -0.002017}}],
    Polygon[{{1.329350, 0.077981, 0.000000},{1.329399, 0.078132, 0.002017},{
      1.333333, 0.077509, 0.002017},{1.333333, 0.077350, 0.000000}}],
    Polygon[{{1.329399, 0.078132, 0.002017},{1.329545, 0.078581, 0.003984},{
      1.333333, 0.077981, 0.003984},{1.333333, 0.077509, 0.002017}}],
    Polygon[{{1.329545, 0.078581, 0.003984},{1.329784, 0.079318, 0.005853},{
      1.333333, 0.078755, 0.005853},{1.333333, 0.077981, 0.003984}}],
    Polygon[{{1.329784, 0.079318, 0.005853},{1.330110, 0.080323, 0.007578},{
      1.333333, 0.079812, 0.007578},{1.333333, 0.078755, 0.005853}}],
    Polygon[{{1.330110, 0.080323, 0.007578},{1.330516, 0.081572, 0.009116},{
      1.333333, 0.081126, 0.009116},{1.333333, 0.079812, 0.007578}}],
    Polygon[{{1.330516, 0.081572, 0.009116},{1.330992, 0.083035, 0.010430},{
      1.333333, 0.082664, 0.010430},{1.333333, 0.081126, 0.009116}}],
    Polygon[{{1.330992, 0.083035, 0.010430},{1.331525, 0.084676, 0.011487},{
      1.333333, 0.084389, 0.011487},{1.333333, 0.082664, 0.010430}}],
    Polygon[{{1.331525, 0.084676, 0.011487},{1.332102, 0.086453, 0.012261},{
      1.333333, 0.086258, 0.012261},{1.333333, 0.084389, 0.011487}}],
    Polygon[{{1.332102, 0.086453, 0.012261},{1.332710, 0.088324, 0.012733},{
      1.333333, 0.088225, 0.012733},{1.333333, 0.086258, 0.012261}}],
    Polygon[{{1.333333, 0.088225, -0.012733},{1.333333, 0.086258, -0.012261},{
      1.334564, 0.086453, -0.012261},{1.333956, 0.088324, -0.012733}}],
    Polygon[{{1.333333, 0.086258, -0.012261},{1.333333, 0.084389, -0.011487},{
      1.335142, 0.084676, -0.011487},{1.334564, 0.086453, -0.012261}}],
    Polygon[{{1.333333, 0.084389, -0.011487},{1.333333, 0.082664, -0.010430},{
      1.335675, 0.083035, -0.010430},{1.335142, 0.084676, -0.011487}}],
    Polygon[{{1.333333, 0.082664, -0.010430},{1.333333, 0.081126, -0.009116},{
      1.336150, 0.081572, -0.009116},{1.335675, 0.083035, -0.010430}}],
    Polygon[{{1.333333, 0.081126, -0.009116},{1.333333, 0.079812, -0.007578},{
      1.336556, 0.080323, -0.007578},{1.336150, 0.081572, -0.009116}}],
    Polygon[{{1.333333, 0.079812, -0.007578},{1.333333, 0.078755, -0.005853},{
      1.336883, 0.079318, -0.005853},{1.336556, 0.080323, -0.007578}}],
    Polygon[{{1.333333, 0.078755, -0.005853},{1.333333, 0.077981, -0.003984},{
      1.337122, 0.078581, -0.003984},{1.336883, 0.079318, -0.005853}}],
    Polygon[{{1.333333, 0.077981, -0.003984},{1.333333, 0.077509, -0.002017},{
      1.337268, 0.078132, -0.002017},{1.337122, 0.078581, -0.003984}}],
    Polygon[{{1.333333, 0.077509, -0.002017},{1.333333, 0.077350, 0.000000},{
      1.337317, 0.077981, 0.000000},{1.337268, 0.078132, -0.002017}}],
    Polygon[{{1.333333, 0.077350, 0.000000},{1.333333, 0.077509, 0.002017},{
      1.337268, 0.078132, 0.002017},{1.337317, 0.077981, 0.000000}}],
    Polygon[{{1.333333, 0.077509, 0.002017},{1.333333, 0.077981, 0.003984},{
      1.337122, 0.078581, 0.003984},{1.337268, 0.078132, 0.002017}}],
    Polygon[{{1.333333, 0.077981, 0.003984},{1.333333, 0.078755, 0.005853},{
      1.336883, 0.079318, 0.005853},{1.337122, 0.078581, 0.003984}}],
    Polygon[{{1.333333, 0.078755, 0.005853},{1.333333, 0.079812, 0.007578},{
      1.336556, 0.080323, 0.007578},{1.336883, 0.079318, 0.005853}}],
    Polygon[{{1.333333, 0.079812, 0.007578},{1.333333, 0.081126, 0.009116},{
      1.336150, 0.081572, 0.009116},{1.336556, 0.080323, 0.007578}}],
    Polygon[{{1.333333, 0.081126, 0.009116},{1.333333, 0.082664, 0.010430},{
      1.335675, 0.083035, 0.010430},{1.336150, 0.081572, 0.009116}}],
    Polygon[{{1.333333, 0.082664, 0.010430},{1.333333, 0.084389, 0.011487},{
      1.335142, 0.084676, 0.011487},{1.335675, 0.083035, 0.010430}}],
    Polygon[{{1.333333, 0.084389, 0.011487},{1.333333, 0.086258, 0.012261},{
      1.334564, 0.086453, 0.012261},{1.335142, 0.084676, 0.011487}}],
    Polygon[{{1.333333, 0.086258, 0.012261},{1.333333, 0.088225, 0.012733},{
      1.333956, 0.088324, 0.012733},{1.334564, 0.086453, 0.012261}}],
    Polygon[{{1.333956, 0.088324, -0.012733},{1.334564, 0.086453, -0.012261},{
      1.335675, 0.087019, -0.012261},{1.334519, 0.088610, -0.012733}}],
    Polygon[{{1.334564, 0.086453, -0.012261},{1.335142, 0.084676, -0.011487},{
      1.336774, 0.085507, -0.011487},{1.335675, 0.087019, -0.012261}}],
    Polygon[{{1.335142, 0.084676, -0.011487},{1.335675, 0.083035, -0.010430},{
      1.337787, 0.084112, -0.010430},{1.336774, 0.085507, -0.011487}}],
    Polygon[{{1.335675, 0.083035, -0.010430},{1.336150, 0.081572, -0.009116},{
      1.338691, 0.082867, -0.009116},{1.337787, 0.084112, -0.010430}}],
    Polygon[{{1.336150, 0.081572, -0.009116},{1.336556, 0.080323, -0.007578},{
      1.339464, 0.081804, -0.007578},{1.338691, 0.082867, -0.009116}}],
    Polygon[{{1.336556, 0.080323, -0.007578},{1.336883, 0.079318, -0.005853},{
      1.340085, 0.080949, -0.005853},{1.339464, 0.081804, -0.007578}}],
    Polygon[{{1.336883, 0.079318, -0.005853},{1.337122, 0.078581, -0.003984},{
      1.340540, 0.080323, -0.003984},{1.340085, 0.080949, -0.005853}}],
    Polygon[{{1.337122, 0.078581, -0.003984},{1.337268, 0.078132, -0.002017},{
      1.340818, 0.079941, -0.002017},{1.340540, 0.080323, -0.003984}}],
    Polygon[{{1.337268, 0.078132, -0.002017},{1.337317, 0.077981, 0.000000},{
      1.340911, 0.079812, 0.000000},{1.340818, 0.079941, -0.002017}}],
    Polygon[{{1.337317, 0.077981, 0.000000},{1.337268, 0.078132, 0.002017},{
      1.340818, 0.079941, 0.002017},{1.340911, 0.079812, 0.000000}}],
    Polygon[{{1.337268, 0.078132, 0.002017},{1.337122, 0.078581, 0.003984},{
      1.340540, 0.080323, 0.003984},{1.340818, 0.079941, 0.002017}}],
    Polygon[{{1.337122, 0.078581, 0.003984},{1.336883, 0.079318, 0.005853},{
      1.340085, 0.080949, 0.005853},{1.340540, 0.080323, 0.003984}}],
    Polygon[{{1.336883, 0.079318, 0.005853},{1.336556, 0.080323, 0.007578},{
      1.339464, 0.081804, 0.007578},{1.340085, 0.080949, 0.005853}}],
    Polygon[{{1.336556, 0.080323, 0.007578},{1.336150, 0.081572, 0.009116},{
      1.338691, 0.082867, 0.009116},{1.339464, 0.081804, 0.007578}}],
    Polygon[{{1.336150, 0.081572, 0.009116},{1.335675, 0.083035, 0.010430},{
      1.337787, 0.084112, 0.010430},{1.338691, 0.082867, 0.009116}}],
    Polygon[{{1.335675, 0.083035, 0.010430},{1.335142, 0.084676, 0.011487},{
      1.336774, 0.085507, 0.011487},{1.337787, 0.084112, 0.010430}}],
    Polygon[{{1.335142, 0.084676, 0.011487},{1.334564, 0.086453, 0.012261},{
      1.335675, 0.087019, 0.012261},{1.336774, 0.085507, 0.011487}}],
    Polygon[{{1.334564, 0.086453, 0.012261},{1.333956, 0.088324, 0.012733},{
      1.334519, 0.088610, 0.012733},{1.335675, 0.087019, 0.012261}}],
    Polygon[{{1.334519, 0.088610, -0.012733},{1.335675, 0.087019, -0.012261},{
      1.336556, 0.087900, -0.012261},{1.334965, 0.089057, -0.012733}}],
    Polygon[{{1.335675, 0.087019, -0.012261},{1.336774, 0.085507, -0.011487},{
      1.338068, 0.086802, -0.011487},{1.336556, 0.087900, -0.012261}}],
    Polygon[{{1.336774, 0.085507, -0.011487},{1.337787, 0.084112, -0.010430},{
      1.339464, 0.085788, -0.010430},{1.338068, 0.086802, -0.011487}}],
    Polygon[{{1.337787, 0.084112, -0.010430},{1.338691, 0.082867, -0.009116},{
      1.340708, 0.084884, -0.009116},{1.339464, 0.085788, -0.010430}}],
    Polygon[{{1.338691, 0.082867, -0.009116},{1.339464, 0.081804, -0.007578},{
      1.341771, 0.084112, -0.007578},{1.340708, 0.084884, -0.009116}}],
    Polygon[{{1.339464, 0.081804, -0.007578},{1.340085, 0.080949, -0.005853},{
      1.342626, 0.083490, -0.005853},{1.341771, 0.084112, -0.007578}}],
    Polygon[{{1.340085, 0.080949, -0.005853},{1.340540, 0.080323, -0.003984},{
      1.343253, 0.083035, -0.003984},{1.342626, 0.083490, -0.005853}}],
    Polygon[{{1.340540, 0.080323, -0.003984},{1.340818, 0.079941, -0.002017},{
      1.343634, 0.082758, -0.002017},{1.343253, 0.083035, -0.003984}}],
    Polygon[{{1.340818, 0.079941, -0.002017},{1.340911, 0.079812, 0.000000},{
      1.343763, 0.082664, 0.000000},{1.343634, 0.082758, -0.002017}}],
    Polygon[{{1.340911, 0.079812, 0.000000},{1.340818, 0.079941, 0.002017},{
      1.343634, 0.082758, 0.002017},{1.343763, 0.082664, 0.000000}}],
    Polygon[{{1.340818, 0.079941, 0.002017},{1.340540, 0.080323, 0.003984},{
      1.343253, 0.083035, 0.003984},{1.343634, 0.082758, 0.002017}}],
    Polygon[{{1.340540, 0.080323, 0.003984},{1.340085, 0.080949, 0.005853},{
      1.342626, 0.083490, 0.005853},{1.343253, 0.083035, 0.003984}}],
    Polygon[{{1.340085, 0.080949, 0.005853},{1.339464, 0.081804, 0.007578},{
      1.341771, 0.084112, 0.007578},{1.342626, 0.083490, 0.005853}}],
    Polygon[{{1.339464, 0.081804, 0.007578},{1.338691, 0.082867, 0.009116},{
      1.340708, 0.084884, 0.009116},{1.341771, 0.084112, 0.007578}}],
    Polygon[{{1.338691, 0.082867, 0.009116},{1.337787, 0.084112, 0.010430},{
      1.339464, 0.085788, 0.010430},{1.340708, 0.084884, 0.009116}}],
    Polygon[{{1.337787, 0.084112, 0.010430},{1.336774, 0.085507, 0.011487},{
      1.338068, 0.086802, 0.011487},{1.339464, 0.085788, 0.010430}}],
    Polygon[{{1.336774, 0.085507, 0.011487},{1.335675, 0.087019, 0.012261},{
      1.336556, 0.087900, 0.012261},{1.338068, 0.086802, 0.011487}}],
    Polygon[{{1.335675, 0.087019, 0.012261},{1.334519, 0.088610, 0.012733},{
      1.334965, 0.089057, 0.012733},{1.336556, 0.087900, 0.012261}}],
    Polygon[{{1.334965, 0.089057, -0.012733},{1.336556, 0.087900, -0.012261},{
      1.337122, 0.089011, -0.012261},{1.335251, 0.089619, -0.012733}}],
    Polygon[{{1.336556, 0.087900, -0.012261},{1.338068, 0.086802, -0.011487},{
      1.338900, 0.088433, -0.011487},{1.337122, 0.089011, -0.012261}}],
    Polygon[{{1.338068, 0.086802, -0.011487},{1.339464, 0.085788, -0.010430},{
      1.340540, 0.087900, -0.010430},{1.338900, 0.088433, -0.011487}}],
    Polygon[{{1.339464, 0.085788, -0.010430},{1.340708, 0.084884, -0.009116},{
      1.342003, 0.087425, -0.009116},{1.340540, 0.087900, -0.010430}}],
    Polygon[{{1.340708, 0.084884, -0.009116},{1.341771, 0.084112, -0.007578},{
      1.343253, 0.087019, -0.007578},{1.342003, 0.087425, -0.009116}}],
    Polygon[{{1.341771, 0.084112, -0.007578},{1.342626, 0.083490, -0.005853},{
      1.344258, 0.086692, -0.005853},{1.343253, 0.087019, -0.007578}}],
    Polygon[{{1.342626, 0.083490, -0.005853},{1.343253, 0.083035, -0.003984},{
      1.344994, 0.086453, -0.003984},{1.344258, 0.086692, -0.005853}}],
    Polygon[{{1.343253, 0.083035, -0.003984},{1.343634, 0.082758, -0.002017},{
      1.345443, 0.086307, -0.002017},{1.344994, 0.086453, -0.003984}}],
    Polygon[{{1.343634, 0.082758, -0.002017},{1.343763, 0.082664, 0.000000},{
      1.345594, 0.086258, 0.000000},{1.345443, 0.086307, -0.002017}}],
    Polygon[{{1.343763, 0.082664, 0.000000},{1.343634, 0.082758, 0.002017},{
      1.345443, 0.086307, 0.002017},{1.345594, 0.086258, 0.000000}}],
    Polygon[{{1.343634, 0.082758, 0.002017},{1.343253, 0.083035, 0.003984},{
      1.344994, 0.086453, 0.003984},{1.345443, 0.086307, 0.002017}}],
    Polygon[{{1.343253, 0.083035, 0.003984},{1.342626, 0.083490, 0.005853},{
      1.344258, 0.086692, 0.005853},{1.344994, 0.086453, 0.003984}}],
    Polygon[{{1.342626, 0.083490, 0.005853},{1.341771, 0.084112, 0.007578},{
      1.343253, 0.087019, 0.007578},{1.344258, 0.086692, 0.005853}}],
    Polygon[{{1.341771, 0.084112, 0.007578},{1.340708, 0.084884, 0.009116},{
      1.342003, 0.087425, 0.009116},{1.343253, 0.087019, 0.007578}}],
    Polygon[{{1.340708, 0.084884, 0.009116},{1.339464, 0.085788, 0.010430},{
      1.340540, 0.087900, 0.010430},{1.342003, 0.087425, 0.009116}}],
    Polygon[{{1.339464, 0.085788, 0.010430},{1.338068, 0.086802, 0.011487},{
      1.338900, 0.088433, 0.011487},{1.340540, 0.087900, 0.010430}}],
    Polygon[{{1.338068, 0.086802, 0.011487},{1.336556, 0.087900, 0.012261},{
      1.337122, 0.089011, 0.012261},{1.338900, 0.088433, 0.011487}}],
    Polygon[{{1.336556, 0.087900, 0.012261},{1.334965, 0.089057, 0.012733},{
      1.335251, 0.089619, 0.012733},{1.337122, 0.089011, 0.012261}}],
    Polygon[{{1.335251, 0.089619, -0.012733},{1.337122, 0.089011, -0.012261},{
      1.337317, 0.090242, -0.012261},{1.335350, 0.090242, -0.012733}}],
    Polygon[{{1.337122, 0.089011, -0.012261},{1.338900, 0.088433, -0.011487},{
      1.339186, 0.090242, -0.011487},{1.337317, 0.090242, -0.012261}}],
    Polygon[{{1.338900, 0.088433, -0.011487},{1.340540, 0.087900, -0.010430},{
      1.340911, 0.090242, -0.010430},{1.339186, 0.090242, -0.011487}}],
    Polygon[{{1.340540, 0.087900, -0.010430},{1.342003, 0.087425, -0.009116},{
      1.342449, 0.090242, -0.009116},{1.340911, 0.090242, -0.010430}}],
    Polygon[{{1.342003, 0.087425, -0.009116},{1.343253, 0.087019, -0.007578},{
      1.343763, 0.090242, -0.007578},{1.342449, 0.090242, -0.009116}}],
    Polygon[{{1.343253, 0.087019, -0.007578},{1.344258, 0.086692, -0.005853},{
      1.344820, 0.090242, -0.005853},{1.343763, 0.090242, -0.007578}}],
    Polygon[{{1.344258, 0.086692, -0.005853},{1.344994, 0.086453, -0.003984},{
      1.345594, 0.090242, -0.003984},{1.344820, 0.090242, -0.005853}}],
    Polygon[{{1.344994, 0.086453, -0.003984},{1.345443, 0.086307, -0.002017},{
      1.346066, 0.090242, -0.002017},{1.345594, 0.090242, -0.003984}}],
    Polygon[{{1.345443, 0.086307, -0.002017},{1.345594, 0.086258, 0.000000},{
      1.346225, 0.090242, 0.000000},{1.346066, 0.090242, -0.002017}}],
    Polygon[{{1.345594, 0.086258, 0.000000},{1.345443, 0.086307, 0.002017},{
      1.346066, 0.090242, 0.002017},{1.346225, 0.090242, 0.000000}}],
    Polygon[{{1.345443, 0.086307, 0.002017},{1.344994, 0.086453, 0.003984},{
      1.345594, 0.090242, 0.003984},{1.346066, 0.090242, 0.002017}}],
    Polygon[{{1.344994, 0.086453, 0.003984},{1.344258, 0.086692, 0.005853},{
      1.344820, 0.090242, 0.005853},{1.345594, 0.090242, 0.003984}}],
    Polygon[{{1.344258, 0.086692, 0.005853},{1.343253, 0.087019, 0.007578},{
      1.343763, 0.090242, 0.007578},{1.344820, 0.090242, 0.005853}}],
    Polygon[{{1.343253, 0.087019, 0.007578},{1.342003, 0.087425, 0.009116},{
      1.342449, 0.090242, 0.009116},{1.343763, 0.090242, 0.007578}}],
    Polygon[{{1.342003, 0.087425, 0.009116},{1.340540, 0.087900, 0.010430},{
      1.340911, 0.090242, 0.010430},{1.342449, 0.090242, 0.009116}}],
    Polygon[{{1.340540, 0.087900, 0.010430},{1.338900, 0.088433, 0.011487},{
      1.339186, 0.090242, 0.011487},{1.340911, 0.090242, 0.010430}}],
    Polygon[{{1.338900, 0.088433, 0.011487},{1.337122, 0.089011, 0.012261},{
      1.337317, 0.090242, 0.012261},{1.339186, 0.090242, 0.011487}}],
    Polygon[{{1.337122, 0.089011, 0.012261},{1.335251, 0.089619, 0.012733},{
      1.335350, 0.090242, 0.012733},{1.337317, 0.090242, 0.012261}}],
    Polygon[{{1.521859, 0.028972, -0.028615},{1.526280, 0.028972, -0.027554},{
      1.525842, 0.031738, -0.027554},{1.521638, 0.030372, -0.028615}}],
    Polygon[{{1.526280, 0.028972, -0.027554},{1.530480, 0.028972, -0.025814},{
      1.529836, 0.033036, -0.025814},{1.525842, 0.031738, -0.027554}}],
    Polygon[{{1.530480, 0.028972, -0.025814},{1.534356, 0.028972, -0.023438},{
      1.533523, 0.034234, -0.023438},{1.529836, 0.033036, -0.025814}}],
    Polygon[{{1.534356, 0.028972, -0.023438},{1.537813, 0.028972, -0.020486},{
      1.536811, 0.035302, -0.020486},{1.533523, 0.034234, -0.023438}}],
    Polygon[{{1.537813, 0.028972, -0.020486},{1.540766, 0.028972, -0.017029},{
      1.539618, 0.036214, -0.017029},{1.536811, 0.035302, -0.020486}}],
    Polygon[{{1.540766, 0.028972, -0.017029},{1.543141, 0.028972, -0.013153},{
      1.541878, 0.036948, -0.013153},{1.539618, 0.036214, -0.017029}}],
    Polygon[{{1.543141, 0.028972, -0.013153},{1.544881, 0.028972, -0.008953},{
      1.543532, 0.037486, -0.008953},{1.541878, 0.036948, -0.013153}}],
    Polygon[{{1.544881, 0.028972, -0.008953},{1.545942, 0.028972, -0.004532},{
      1.544541, 0.037814, -0.004532},{1.543532, 0.037486, -0.008953}}],
    Polygon[{{1.545942, 0.028972, -0.004532},{1.546299, 0.028972, 0.000000},{
      1.544881, 0.037924, 0.000000},{1.544541, 0.037814, -0.004532}}],
    Polygon[{{1.546299, 0.028972, 0.000000},{1.545942, 0.028972, 0.004532},{
      1.544541, 0.037814, 0.004532},{1.544881, 0.037924, 0.000000}}],
    Polygon[{{1.545942, 0.028972, 0.004532},{1.544881, 0.028972, 0.008953},{
      1.543532, 0.037486, 0.008953},{1.544541, 0.037814, 0.004532}}],
    Polygon[{{1.544881, 0.028972, 0.008953},{1.543141, 0.028972, 0.013153},{
      1.541878, 0.036948, 0.013153},{1.543532, 0.037486, 0.008953}}],
    Polygon[{{1.543141, 0.028972, 0.013153},{1.540766, 0.028972, 0.017029},{
      1.539618, 0.036214, 0.017029},{1.541878, 0.036948, 0.013153}}],
    Polygon[{{1.540766, 0.028972, 0.017029},{1.537813, 0.028972, 0.020486},{
      1.536811, 0.035302, 0.020486},{1.539618, 0.036214, 0.017029}}],
    Polygon[{{1.537813, 0.028972, 0.020486},{1.534356, 0.028972, 0.023438},{
      1.533523, 0.034234, 0.023438},{1.536811, 0.035302, 0.020486}}],
    Polygon[{{1.534356, 0.028972, 0.023438},{1.530480, 0.028972, 0.025814},{
      1.529836, 0.033036, 0.025814},{1.533523, 0.034234, 0.023438}}],
    Polygon[{{1.530480, 0.028972, 0.025814},{1.526280, 0.028972, 0.027554},{
      1.525842, 0.031738, 0.027554},{1.529836, 0.033036, 0.025814}}],
    Polygon[{{1.526280, 0.028972, 0.027554},{1.521859, 0.028972, 0.028615},{
      1.521638, 0.030372, 0.028615},{1.525842, 0.031738, 0.027554}}],
    Polygon[{{1.521638, 0.030372, -0.028615},{1.525842, 0.031738, -0.027554},{
      1.524570, 0.034234, -0.027554},{1.520994, 0.031635, -0.028615}}],
    Polygon[{{1.525842, 0.031738, -0.027554},{1.529836, 0.033036, -0.025814},{
      1.527968, 0.036703, -0.025814},{1.524570, 0.034234, -0.027554}}],
    Polygon[{{1.529836, 0.033036, -0.025814},{1.533523, 0.034234, -0.023438},{
      1.531104, 0.038981, -0.023438},{1.527968, 0.036703, -0.025814}}],
    Polygon[{{1.533523, 0.034234, -0.023438},{1.536811, 0.035302, -0.020486},{
      1.533901, 0.041013, -0.020486},{1.531104, 0.038981, -0.023438}}],
    Polygon[{{1.536811, 0.035302, -0.020486},{1.539618, 0.036214, -0.017029},{
      1.536289, 0.042748, -0.017029},{1.533901, 0.041013, -0.020486}}],
    Polygon[{{1.539618, 0.036214, -0.017029},{1.541878, 0.036948, -0.013153},{
      1.538211, 0.044144, -0.013153},{1.536289, 0.042748, -0.017029}}],
    Polygon[{{1.541878, 0.036948, -0.013153},{1.543532, 0.037486, -0.008953},{
      1.539618, 0.045167, -0.008953},{1.538211, 0.044144, -0.013153}}],
    Polygon[{{1.543532, 0.037486, -0.008953},{1.544541, 0.037814, -0.004532},{
      1.540477, 0.045791, -0.004532},{1.539618, 0.045167, -0.008953}}],
    Polygon[{{1.544541, 0.037814, -0.004532},{1.544881, 0.037924, 0.000000},{
      1.540766, 0.046001, 0.000000},{1.540477, 0.045791, -0.004532}}],
    Polygon[{{1.544881, 0.037924, 0.000000},{1.544541, 0.037814, 0.004532},{
      1.540477, 0.045791, 0.004532},{1.540766, 0.046001, 0.000000}}],
    Polygon[{{1.544541, 0.037814, 0.004532},{1.543532, 0.037486, 0.008953},{
      1.539618, 0.045167, 0.008953},{1.540477, 0.045791, 0.004532}}],
    Polygon[{{1.543532, 0.037486, 0.008953},{1.541878, 0.036948, 0.013153},{
      1.538211, 0.044144, 0.013153},{1.539618, 0.045167, 0.008953}}],
    Polygon[{{1.541878, 0.036948, 0.013153},{1.539618, 0.036214, 0.017029},{
      1.536289, 0.042748, 0.017029},{1.538211, 0.044144, 0.013153}}],
    Polygon[{{1.539618, 0.036214, 0.017029},{1.536811, 0.035302, 0.020486},{
      1.533901, 0.041013, 0.020486},{1.536289, 0.042748, 0.017029}}],
    Polygon[{{1.536811, 0.035302, 0.020486},{1.533523, 0.034234, 0.023438},{
      1.531104, 0.038981, 0.023438},{1.533901, 0.041013, 0.020486}}],
    Polygon[{{1.533523, 0.034234, 0.023438},{1.529836, 0.033036, 0.025814},{
      1.527968, 0.036703, 0.025814},{1.531104, 0.038981, 0.023438}}],
    Polygon[{{1.529836, 0.033036, 0.025814},{1.525842, 0.031738, 0.027554},{
      1.524570, 0.034234, 0.027554},{1.527968, 0.036703, 0.025814}}],
    Polygon[{{1.525842, 0.031738, 0.027554},{1.521638, 0.030372, 0.028615},{
      1.520994, 0.031635, 0.028615},{1.524570, 0.034234, 0.027554}}],
    Polygon[{{1.520994, 0.031635, -0.028615},{1.524570, 0.034234, -0.027554},{
      1.522589, 0.036214, -0.027554},{1.519991, 0.032638, -0.028615}}],
    Polygon[{{1.524570, 0.034234, -0.027554},{1.527968, 0.036703, -0.025814},{
      1.525058, 0.039612, -0.025814},{1.522589, 0.036214, -0.027554}}],
    Polygon[{{1.527968, 0.036703, -0.025814},{1.531104, 0.038981, -0.023438},{
      1.527337, 0.042748, -0.023438},{1.525058, 0.039612, -0.025814}}],
    Polygon[{{1.531104, 0.038981, -0.023438},{1.533901, 0.041013, -0.020486},{
      1.529369, 0.045545, -0.020486},{1.527337, 0.042748, -0.023438}}],
    Polygon[{{1.533901, 0.041013, -0.020486},{1.536289, 0.042748, -0.017029},{
      1.531104, 0.047934, -0.017029},{1.529369, 0.045545, -0.020486}}],
    Polygon[{{1.536289, 0.042748, -0.017029},{1.538211, 0.044144, -0.013153},{
      1.532500, 0.049855, -0.013153},{1.531104, 0.047934, -0.017029}}],
    Polygon[{{1.538211, 0.044144, -0.013153},{1.539618, 0.045167, -0.008953},{
      1.533523, 0.051263, -0.008953},{1.532500, 0.049855, -0.013153}}],
    Polygon[{{1.539618, 0.045167, -0.008953},{1.540477, 0.045791, -0.004532},{
      1.534147, 0.052121, -0.004532},{1.533523, 0.051263, -0.008953}}],
    Polygon[{{1.540477, 0.045791, -0.004532},{1.540766, 0.046001, 0.000000},{
      1.534356, 0.052410, 0.000000},{1.534147, 0.052121, -0.004532}}],
    Polygon[{{1.540766, 0.046001, 0.000000},{1.540477, 0.045791, 0.004532},{
      1.534147, 0.052121, 0.004532},{1.534356, 0.052410, 0.000000}}],
    Polygon[{{1.540477, 0.045791, 0.004532},{1.539618, 0.045167, 0.008953},{
      1.533523, 0.051263, 0.008953},{1.534147, 0.052121, 0.004532}}],
    Polygon[{{1.539618, 0.045167, 0.008953},{1.538211, 0.044144, 0.013153},{
      1.532500, 0.049855, 0.013153},{1.533523, 0.051263, 0.008953}}],
    Polygon[{{1.538211, 0.044144, 0.013153},{1.536289, 0.042748, 0.017029},{
      1.531104, 0.047934, 0.017029},{1.532500, 0.049855, 0.013153}}],
    Polygon[{{1.536289, 0.042748, 0.017029},{1.533901, 0.041013, 0.020486},{
      1.529369, 0.045545, 0.020486},{1.531104, 0.047934, 0.017029}}],
    Polygon[{{1.533901, 0.041013, 0.020486},{1.531104, 0.038981, 0.023438},{
      1.527337, 0.042748, 0.023438},{1.529369, 0.045545, 0.020486}}],
    Polygon[{{1.531104, 0.038981, 0.023438},{1.527968, 0.036703, 0.025814},{
      1.525058, 0.039612, 0.025814},{1.527337, 0.042748, 0.023438}}],
    Polygon[{{1.527968, 0.036703, 0.025814},{1.524570, 0.034234, 0.027554},{
      1.522589, 0.036214, 0.027554},{1.525058, 0.039612, 0.025814}}],
    Polygon[{{1.524570, 0.034234, 0.027554},{1.520994, 0.031635, 0.028615},{
      1.519991, 0.032638, 0.028615},{1.522589, 0.036214, 0.027554}}],
    Polygon[{{1.519991, 0.032638, -0.028615},{1.522589, 0.036214, -0.027554},{
      1.520094, 0.037486, -0.027554},{1.518728, 0.033282, -0.028615}}],
    Polygon[{{1.522589, 0.036214, -0.027554},{1.525058, 0.039612, -0.025814},{
      1.521392, 0.041481, -0.025814},{1.520094, 0.037486, -0.027554}}],
    Polygon[{{1.525058, 0.039612, -0.025814},{1.527337, 0.042748, -0.023438},{
      1.522589, 0.045167, -0.023438},{1.521392, 0.041481, -0.025814}}],
    Polygon[{{1.527337, 0.042748, -0.023438},{1.529369, 0.045545, -0.020486},{
      1.523658, 0.048455, -0.020486},{1.522589, 0.045167, -0.023438}}],
    Polygon[{{1.529369, 0.045545, -0.020486},{1.531104, 0.047934, -0.017029},{
      1.524570, 0.051263, -0.017029},{1.523658, 0.048455, -0.020486}}],
    Polygon[{{1.531104, 0.047934, -0.017029},{1.532500, 0.049855, -0.013153},{
      1.525304, 0.053522, -0.013153},{1.524570, 0.051263, -0.017029}}],
    Polygon[{{1.532500, 0.049855, -0.013153},{1.533523, 0.051263, -0.008953},{
      1.525842, 0.055177, -0.008953},{1.525304, 0.053522, -0.013153}}],
    Polygon[{{1.533523, 0.051263, -0.008953},{1.534147, 0.052121, -0.004532},{
      1.526170, 0.056186, -0.004532},{1.525842, 0.055177, -0.008953}}],
    Polygon[{{1.534147, 0.052121, -0.004532},{1.534356, 0.052410, 0.000000},{
      1.526280, 0.056525, 0.000000},{1.526170, 0.056186, -0.004532}}],
    Polygon[{{1.534356, 0.052410, 0.000000},{1.534147, 0.052121, 0.004532},{
      1.526170, 0.056186, 0.004532},{1.526280, 0.056525, 0.000000}}],
    Polygon[{{1.534147, 0.052121, 0.004532},{1.533523, 0.051263, 0.008953},{
      1.525842, 0.055177, 0.008953},{1.526170, 0.056186, 0.004532}}],
    Polygon[{{1.533523, 0.051263, 0.008953},{1.532500, 0.049855, 0.013153},{
      1.525304, 0.053522, 0.013153},{1.525842, 0.055177, 0.008953}}],
    Polygon[{{1.532500, 0.049855, 0.013153},{1.531104, 0.047934, 0.017029},{
      1.524570, 0.051263, 0.017029},{1.525304, 0.053522, 0.013153}}],
    Polygon[{{1.531104, 0.047934, 0.017029},{1.529369, 0.045545, 0.020486},{
      1.523658, 0.048455, 0.020486},{1.524570, 0.051263, 0.017029}}],
    Polygon[{{1.529369, 0.045545, 0.020486},{1.527337, 0.042748, 0.023438},{
      1.522589, 0.045167, 0.023438},{1.523658, 0.048455, 0.020486}}],
    Polygon[{{1.527337, 0.042748, 0.023438},{1.525058, 0.039612, 0.025814},{
      1.521392, 0.041481, 0.025814},{1.522589, 0.045167, 0.023438}}],
    Polygon[{{1.525058, 0.039612, 0.025814},{1.522589, 0.036214, 0.027554},{
      1.520094, 0.037486, 0.027554},{1.521392, 0.041481, 0.025814}}],
    Polygon[{{1.522589, 0.036214, 0.027554},{1.519991, 0.032638, 0.028615},{
      1.518728, 0.033282, 0.028615},{1.520094, 0.037486, 0.027554}}],
    Polygon[{{1.518728, 0.033282, -0.028615},{1.520094, 0.037486, -0.027554},{
      1.517327, 0.037924, -0.027554},{1.517327, 0.033504, -0.028615}}],
    Polygon[{{1.520094, 0.037486, -0.027554},{1.521392, 0.041481, -0.025814},{
      1.517327, 0.042124, -0.025814},{1.517327, 0.037924, -0.027554}}],
    Polygon[{{1.521392, 0.041481, -0.025814},{1.522589, 0.045167, -0.023438},{
      1.517327, 0.046001, -0.023438},{1.517327, 0.042124, -0.025814}}],
    Polygon[{{1.522589, 0.045167, -0.023438},{1.523658, 0.048455, -0.020486},{
      1.517327, 0.049457, -0.020486},{1.517327, 0.046001, -0.023438}}],
    Polygon[{{1.523658, 0.048455, -0.020486},{1.524570, 0.051263, -0.017029},{
      1.517327, 0.052410, -0.017029},{1.517327, 0.049457, -0.020486}}],
    Polygon[{{1.524570, 0.051263, -0.017029},{1.525304, 0.053522, -0.013153},{
      1.517327, 0.054785, -0.013153},{1.517327, 0.052410, -0.017029}}],
    Polygon[{{1.525304, 0.053522, -0.013153},{1.525842, 0.055177, -0.008953},{
      1.517327, 0.056525, -0.008953},{1.517327, 0.054785, -0.013153}}],
    Polygon[{{1.525842, 0.055177, -0.008953},{1.526170, 0.056186, -0.004532},{
      1.517327, 0.057586, -0.004532},{1.517327, 0.056525, -0.008953}}],
    Polygon[{{1.526170, 0.056186, -0.004532},{1.526280, 0.056525, 0.000000},{
      1.517327, 0.057943, 0.000000},{1.517327, 0.057586, -0.004532}}],
    Polygon[{{1.526280, 0.056525, 0.000000},{1.526170, 0.056186, 0.004532},{
      1.517327, 0.057586, 0.004532},{1.517327, 0.057943, 0.000000}}],
    Polygon[{{1.526170, 0.056186, 0.004532},{1.525842, 0.055177, 0.008953},{
      1.517327, 0.056525, 0.008953},{1.517327, 0.057586, 0.004532}}],
    Polygon[{{1.525842, 0.055177, 0.008953},{1.525304, 0.053522, 0.013153},{
      1.517327, 0.054785, 0.013153},{1.517327, 0.056525, 0.008953}}],
    Polygon[{{1.525304, 0.053522, 0.013153},{1.524570, 0.051263, 0.017029},{
      1.517327, 0.052410, 0.017029},{1.517327, 0.054785, 0.013153}}],
    Polygon[{{1.524570, 0.051263, 0.017029},{1.523658, 0.048455, 0.020486},{
      1.517327, 0.049457, 0.020486},{1.517327, 0.052410, 0.017029}}],
    Polygon[{{1.523658, 0.048455, 0.020486},{1.522589, 0.045167, 0.023438},{
      1.517327, 0.046001, 0.023438},{1.517327, 0.049457, 0.020486}}],
    Polygon[{{1.522589, 0.045167, 0.023438},{1.521392, 0.041481, 0.025814},{
      1.517327, 0.042124, 0.025814},{1.517327, 0.046001, 0.023438}}],
    Polygon[{{1.521392, 0.041481, 0.025814},{1.520094, 0.037486, 0.027554},{
      1.517327, 0.037924, 0.027554},{1.517327, 0.042124, 0.025814}}],
    Polygon[{{1.520094, 0.037486, 0.027554},{1.518728, 0.033282, 0.028615},{
      1.517327, 0.033504, 0.028615},{1.517327, 0.037924, 0.027554}}],
    Polygon[{{1.517327, 0.033504, -0.028615},{1.517327, 0.037924, -0.027554},{
      1.514561, 0.037486, -0.027554},{1.515927, 0.033282, -0.028615}}],
    Polygon[{{1.517327, 0.037924, -0.027554},{1.517327, 0.042124, -0.025814},{
      1.513263, 0.041481, -0.025814},{1.514561, 0.037486, -0.027554}}],
    Polygon[{{1.517327, 0.042124, -0.025814},{1.517327, 0.046001, -0.023438},{
      1.512065, 0.045167, -0.023438},{1.513263, 0.041481, -0.025814}}],
    Polygon[{{1.517327, 0.046001, -0.023438},{1.517327, 0.049457, -0.020486},{
      1.510997, 0.048455, -0.020486},{1.512065, 0.045167, -0.023438}}],
    Polygon[{{1.517327, 0.049457, -0.020486},{1.517327, 0.052410, -0.017029},{
      1.510084, 0.051263, -0.017029},{1.510997, 0.048455, -0.020486}}],
    Polygon[{{1.517327, 0.052410, -0.017029},{1.517327, 0.054785, -0.013153},{
      1.509350, 0.053522, -0.013153},{1.510084, 0.051263, -0.017029}}],
    Polygon[{{1.517327, 0.054785, -0.013153},{1.517327, 0.056525, -0.008953},{
      1.508813, 0.055177, -0.008953},{1.509350, 0.053522, -0.013153}}],
    Polygon[{{1.517327, 0.056525, -0.008953},{1.517327, 0.057586, -0.004532},{
      1.508485, 0.056186, -0.004532},{1.508813, 0.055177, -0.008953}}],
    Polygon[{{1.517327, 0.057586, -0.004532},{1.517327, 0.057943, 0.000000},{
      1.508374, 0.056525, 0.000000},{1.508485, 0.056186, -0.004532}}],
    Polygon[{{1.517327, 0.057943, 0.000000},{1.517327, 0.057586, 0.004532},{
      1.508485, 0.056186, 0.004532},{1.508374, 0.056525, 0.000000}}],
    Polygon[{{1.517327, 0.057586, 0.004532},{1.517327, 0.056525, 0.008953},{
      1.508813, 0.055177, 0.008953},{1.508485, 0.056186, 0.004532}}],
    Polygon[{{1.517327, 0.056525, 0.008953},{1.517327, 0.054785, 0.013153},{
      1.509350, 0.053522, 0.013153},{1.508813, 0.055177, 0.008953}}],
    Polygon[{{1.517327, 0.054785, 0.013153},{1.517327, 0.052410, 0.017029},{
      1.510084, 0.051263, 0.017029},{1.509350, 0.053522, 0.013153}}],
    Polygon[{{1.517327, 0.052410, 0.017029},{1.517327, 0.049457, 0.020486},{
      1.510997, 0.048455, 0.020486},{1.510084, 0.051263, 0.017029}}],
    Polygon[{{1.517327, 0.049457, 0.020486},{1.517327, 0.046001, 0.023438},{
      1.512065, 0.045167, 0.023438},{1.510997, 0.048455, 0.020486}}],
    Polygon[{{1.517327, 0.046001, 0.023438},{1.517327, 0.042124, 0.025814},{
      1.513263, 0.041481, 0.025814},{1.512065, 0.045167, 0.023438}}],
    Polygon[{{1.517327, 0.042124, 0.025814},{1.517327, 0.037924, 0.027554},{
      1.514561, 0.037486, 0.027554},{1.513263, 0.041481, 0.025814}}],
    Polygon[{{1.517327, 0.037924, 0.027554},{1.517327, 0.033504, 0.028615},{
      1.515927, 0.033282, 0.028615},{1.514561, 0.037486, 0.027554}}],
    Polygon[{{1.515927, 0.033282, -0.028615},{1.514561, 0.037486, -0.027554},{
      1.512065, 0.036214, -0.027554},{1.514663, 0.032638, -0.028615}}],
    Polygon[{{1.514561, 0.037486, -0.027554},{1.513263, 0.041481, -0.025814},{
      1.509596, 0.039612, -0.025814},{1.512065, 0.036214, -0.027554}}],
    Polygon[{{1.513263, 0.041481, -0.025814},{1.512065, 0.045167, -0.023438},{
      1.507318, 0.042748, -0.023438},{1.509596, 0.039612, -0.025814}}],
    Polygon[{{1.512065, 0.045167, -0.023438},{1.510997, 0.048455, -0.020486},{
      1.505286, 0.045545, -0.020486},{1.507318, 0.042748, -0.023438}}],
    Polygon[{{1.510997, 0.048455, -0.020486},{1.510084, 0.051263, -0.017029},{
      1.503550, 0.047934, -0.017029},{1.505286, 0.045545, -0.020486}}],
    Polygon[{{1.510084, 0.051263, -0.017029},{1.509350, 0.053522, -0.013153},{
      1.502154, 0.049855, -0.013153},{1.503550, 0.047934, -0.017029}}],
    Polygon[{{1.509350, 0.053522, -0.013153},{1.508813, 0.055177, -0.008953},{
      1.501132, 0.051263, -0.008953},{1.502154, 0.049855, -0.013153}}],
    Polygon[{{1.508813, 0.055177, -0.008953},{1.508485, 0.056186, -0.004532},{
      1.500508, 0.052121, -0.004532},{1.501132, 0.051263, -0.008953}}],
    Polygon[{{1.508485, 0.056186, -0.004532},{1.508374, 0.056525, 0.000000},{
      1.500298, 0.052410, 0.000000},{1.500508, 0.052121, -0.004532}}],
    Polygon[{{1.508374, 0.056525, 0.000000},{1.508485, 0.056186, 0.004532},{
      1.500508, 0.052121, 0.004532},{1.500298, 0.052410, 0.000000}}],
    Polygon[{{1.508485, 0.056186, 0.004532},{1.508813, 0.055177, 0.008953},{
      1.501132, 0.051263, 0.008953},{1.500508, 0.052121, 0.004532}}],
    Polygon[{{1.508813, 0.055177, 0.008953},{1.509350, 0.053522, 0.013153},{
      1.502154, 0.049855, 0.013153},{1.501132, 0.051263, 0.008953}}],
    Polygon[{{1.509350, 0.053522, 0.013153},{1.510084, 0.051263, 0.017029},{
      1.503550, 0.047934, 0.017029},{1.502154, 0.049855, 0.013153}}],
    Polygon[{{1.510084, 0.051263, 0.017029},{1.510997, 0.048455, 0.020486},{
      1.505286, 0.045545, 0.020486},{1.503550, 0.047934, 0.017029}}],
    Polygon[{{1.510997, 0.048455, 0.020486},{1.512065, 0.045167, 0.023438},{
      1.507318, 0.042748, 0.023438},{1.505286, 0.045545, 0.020486}}],
    Polygon[{{1.512065, 0.045167, 0.023438},{1.513263, 0.041481, 0.025814},{
      1.509596, 0.039612, 0.025814},{1.507318, 0.042748, 0.023438}}],
    Polygon[{{1.513263, 0.041481, 0.025814},{1.514561, 0.037486, 0.027554},{
      1.512065, 0.036214, 0.027554},{1.509596, 0.039612, 0.025814}}],
    Polygon[{{1.514561, 0.037486, 0.027554},{1.515927, 0.033282, 0.028615},{
      1.514663, 0.032638, 0.028615},{1.512065, 0.036214, 0.027554}}],
    Polygon[{{1.514663, 0.032638, -0.028615},{1.512065, 0.036214, -0.027554},{
      1.510084, 0.034234, -0.027554},{1.513661, 0.031635, -0.028615}}],
    Polygon[{{1.512065, 0.036214, -0.027554},{1.509596, 0.039612, -0.025814},{
      1.506686, 0.036703, -0.025814},{1.510084, 0.034234, -0.027554}}],
    Polygon[{{1.509596, 0.039612, -0.025814},{1.507318, 0.042748, -0.023438},{
      1.503550, 0.038981, -0.023438},{1.506686, 0.036703, -0.025814}}],
    Polygon[{{1.507318, 0.042748, -0.023438},{1.505286, 0.045545, -0.020486},{
      1.500754, 0.041013, -0.020486},{1.503550, 0.038981, -0.023438}}],
    Polygon[{{1.505286, 0.045545, -0.020486},{1.503550, 0.047934, -0.017029},{
      1.498365, 0.042748, -0.017029},{1.500754, 0.041013, -0.020486}}],
    Polygon[{{1.503550, 0.047934, -0.017029},{1.502154, 0.049855, -0.013153},{
      1.496443, 0.044144, -0.013153},{1.498365, 0.042748, -0.017029}}],
    Polygon[{{1.502154, 0.049855, -0.013153},{1.501132, 0.051263, -0.008953},{
      1.495036, 0.045167, -0.008953},{1.496443, 0.044144, -0.013153}}],
    Polygon[{{1.501132, 0.051263, -0.008953},{1.500508, 0.052121, -0.004532},{
      1.494177, 0.045791, -0.004532},{1.495036, 0.045167, -0.008953}}],
    Polygon[{{1.500508, 0.052121, -0.004532},{1.500298, 0.052410, 0.000000},{
      1.493889, 0.046001, 0.000000},{1.494177, 0.045791, -0.004532}}],
    Polygon[{{1.500298, 0.052410, 0.000000},{1.500508, 0.052121, 0.004532},{
      1.494177, 0.045791, 0.004532},{1.493889, 0.046001, 0.000000}}],
    Polygon[{{1.500508, 0.052121, 0.004532},{1.501132, 0.051263, 0.008953},{
      1.495036, 0.045167, 0.008953},{1.494177, 0.045791, 0.004532}}],
    Polygon[{{1.501132, 0.051263, 0.008953},{1.502154, 0.049855, 0.013153},{
      1.496443, 0.044144, 0.013153},{1.495036, 0.045167, 0.008953}}],
    Polygon[{{1.502154, 0.049855, 0.013153},{1.503550, 0.047934, 0.017029},{
      1.498365, 0.042748, 0.017029},{1.496443, 0.044144, 0.013153}}],
    Polygon[{{1.503550, 0.047934, 0.017029},{1.505286, 0.045545, 0.020486},{
      1.500754, 0.041013, 0.020486},{1.498365, 0.042748, 0.017029}}],
    Polygon[{{1.505286, 0.045545, 0.020486},{1.507318, 0.042748, 0.023438},{
      1.503550, 0.038981, 0.023438},{1.500754, 0.041013, 0.020486}}],
    Polygon[{{1.507318, 0.042748, 0.023438},{1.509596, 0.039612, 0.025814},{
      1.506686, 0.036703, 0.025814},{1.503550, 0.038981, 0.023438}}],
    Polygon[{{1.509596, 0.039612, 0.025814},{1.512065, 0.036214, 0.027554},{
      1.510084, 0.034234, 0.027554},{1.506686, 0.036703, 0.025814}}],
    Polygon[{{1.512065, 0.036214, 0.027554},{1.514663, 0.032638, 0.028615},{
      1.513661, 0.031635, 0.028615},{1.510084, 0.034234, 0.027554}}],
    Polygon[{{1.513661, 0.031635, -0.028615},{1.510084, 0.034234, -0.027554},{
      1.508813, 0.031738, -0.027554},{1.513017, 0.030372, -0.028615}}],
    Polygon[{{1.510084, 0.034234, -0.027554},{1.506686, 0.036703, -0.025814},{
      1.504818, 0.033036, -0.025814},{1.508813, 0.031738, -0.027554}}],
    Polygon[{{1.506686, 0.036703, -0.025814},{1.503550, 0.038981, -0.023438},{
      1.501132, 0.034234, -0.023438},{1.504818, 0.033036, -0.025814}}],
    Polygon[{{1.503550, 0.038981, -0.023438},{1.500754, 0.041013, -0.020486},{
      1.497844, 0.035302, -0.020486},{1.501132, 0.034234, -0.023438}}],
    Polygon[{{1.500754, 0.041013, -0.020486},{1.498365, 0.042748, -0.017029},{
      1.495036, 0.036214, -0.017029},{1.497844, 0.035302, -0.020486}}],
    Polygon[{{1.498365, 0.042748, -0.017029},{1.496443, 0.044144, -0.013153},{
      1.492777, 0.036948, -0.013153},{1.495036, 0.036214, -0.017029}}],
    Polygon[{{1.496443, 0.044144, -0.013153},{1.495036, 0.045167, -0.008953},{
      1.491122, 0.037486, -0.008953},{1.492777, 0.036948, -0.013153}}],
    Polygon[{{1.495036, 0.045167, -0.008953},{1.494177, 0.045791, -0.004532},{
      1.490113, 0.037814, -0.004532},{1.491122, 0.037486, -0.008953}}],
    Polygon[{{1.494177, 0.045791, -0.004532},{1.493889, 0.046001, 0.000000},{
      1.489774, 0.037924, 0.000000},{1.490113, 0.037814, -0.004532}}],
    Polygon[{{1.493889, 0.046001, 0.000000},{1.494177, 0.045791, 0.004532},{
      1.490113, 0.037814, 0.004532},{1.489774, 0.037924, 0.000000}}],
    Polygon[{{1.494177, 0.045791, 0.004532},{1.495036, 0.045167, 0.008953},{
      1.491122, 0.037486, 0.008953},{1.490113, 0.037814, 0.004532}}],
    Polygon[{{1.495036, 0.045167, 0.008953},{1.496443, 0.044144, 0.013153},{
      1.492777, 0.036948, 0.013153},{1.491122, 0.037486, 0.008953}}],
    Polygon[{{1.496443, 0.044144, 0.013153},{1.498365, 0.042748, 0.017029},{
      1.495036, 0.036214, 0.017029},{1.492777, 0.036948, 0.013153}}],
    Polygon[{{1.498365, 0.042748, 0.017029},{1.500754, 0.041013, 0.020486},{
      1.497844, 0.035302, 0.020486},{1.495036, 0.036214, 0.017029}}],
    Polygon[{{1.500754, 0.041013, 0.020486},{1.503550, 0.038981, 0.023438},{
      1.501132, 0.034234, 0.023438},{1.497844, 0.035302, 0.020486}}],
    Polygon[{{1.503550, 0.038981, 0.023438},{1.506686, 0.036703, 0.025814},{
      1.504818, 0.033036, 0.025814},{1.501132, 0.034234, 0.023438}}],
    Polygon[{{1.506686, 0.036703, 0.025814},{1.510084, 0.034234, 0.027554},{
      1.508813, 0.031738, 0.027554},{1.504818, 0.033036, 0.025814}}],
    Polygon[{{1.510084, 0.034234, 0.027554},{1.513661, 0.031635, 0.028615},{
      1.513017, 0.030372, 0.028615},{1.508813, 0.031738, 0.027554}}],
    Polygon[{{1.513017, 0.030372, -0.028615},{1.508813, 0.031738, -0.027554},{
      1.508374, 0.028972, -0.027554},{1.512795, 0.028972, -0.028615}}],
    Polygon[{{1.508813, 0.031738, -0.027554},{1.504818, 0.033036, -0.025814},{
      1.504174, 0.028972, -0.025814},{1.508374, 0.028972, -0.027554}}],
    Polygon[{{1.504818, 0.033036, -0.025814},{1.501132, 0.034234, -0.023438},{
      1.500298, 0.028972, -0.023438},{1.504174, 0.028972, -0.025814}}],
    Polygon[{{1.501132, 0.034234, -0.023438},{1.497844, 0.035302, -0.020486},{
      1.496841, 0.028972, -0.020486},{1.500298, 0.028972, -0.023438}}],
    Polygon[{{1.497844, 0.035302, -0.020486},{1.495036, 0.036214, -0.017029},{
      1.493889, 0.028972, -0.017029},{1.496841, 0.028972, -0.020486}}],
    Polygon[{{1.495036, 0.036214, -0.017029},{1.492777, 0.036948, -0.013153},{
      1.491513, 0.028972, -0.013153},{1.493889, 0.028972, -0.017029}}],
    Polygon[{{1.492777, 0.036948, -0.013153},{1.491122, 0.037486, -0.008953},{
      1.489774, 0.028972, -0.008953},{1.491513, 0.028972, -0.013153}}],
    Polygon[{{1.491122, 0.037486, -0.008953},{1.490113, 0.037814, -0.004532},{
      1.488712, 0.028972, -0.004532},{1.489774, 0.028972, -0.008953}}],
    Polygon[{{1.490113, 0.037814, -0.004532},{1.489774, 0.037924, 0.000000},{
      1.488356, 0.028972, 0.000000},{1.488712, 0.028972, -0.004532}}],
    Polygon[{{1.489774, 0.037924, 0.000000},{1.490113, 0.037814, 0.004532},{
      1.488712, 0.028972, 0.004532},{1.488356, 0.028972, 0.000000}}],
    Polygon[{{1.490113, 0.037814, 0.004532},{1.491122, 0.037486, 0.008953},{
      1.489774, 0.028972, 0.008953},{1.488712, 0.028972, 0.004532}}],
    Polygon[{{1.491122, 0.037486, 0.008953},{1.492777, 0.036948, 0.013153},{
      1.491513, 0.028972, 0.013153},{1.489774, 0.028972, 0.008953}}],
    Polygon[{{1.492777, 0.036948, 0.013153},{1.495036, 0.036214, 0.017029},{
      1.493889, 0.028972, 0.017029},{1.491513, 0.028972, 0.013153}}],
    Polygon[{{1.495036, 0.036214, 0.017029},{1.497844, 0.035302, 0.020486},{
      1.496841, 0.028972, 0.020486},{1.493889, 0.028972, 0.017029}}],
    Polygon[{{1.497844, 0.035302, 0.020486},{1.501132, 0.034234, 0.023438},{
      1.500298, 0.028972, 0.023438},{1.496841, 0.028972, 0.020486}}],
    Polygon[{{1.501132, 0.034234, 0.023438},{1.504818, 0.033036, 0.025814},{
      1.504174, 0.028972, 0.025814},{1.500298, 0.028972, 0.023438}}],
    Polygon[{{1.504818, 0.033036, 0.025814},{1.508813, 0.031738, 0.027554},{
      1.508374, 0.028972, 0.027554},{1.504174, 0.028972, 0.025814}}],
    Polygon[{{1.508813, 0.031738, 0.027554},{1.513017, 0.030372, 0.028615},{
      1.512795, 0.028972, 0.028615},{1.508374, 0.028972, 0.027554}}],
    Polygon[{{1.512795, 0.028972, -0.028615},{1.508374, 0.028972, -0.027554},{
      1.508813, 0.026205, -0.027554},{1.513017, 0.027571, -0.028615}}],
    Polygon[{{1.508374, 0.028972, -0.027554},{1.504174, 0.028972, -0.025814},{
      1.504818, 0.024907, -0.025814},{1.508813, 0.026205, -0.027554}}],
    Polygon[{{1.504174, 0.028972, -0.025814},{1.500298, 0.028972, -0.023438},{
      1.501132, 0.023709, -0.023438},{1.504818, 0.024907, -0.025814}}],
    Polygon[{{1.500298, 0.028972, -0.023438},{1.496841, 0.028972, -0.020486},{
      1.497844, 0.022641, -0.020486},{1.501132, 0.023709, -0.023438}}],
    Polygon[{{1.496841, 0.028972, -0.020486},{1.493889, 0.028972, -0.017029},{
      1.495036, 0.021729, -0.017029},{1.497844, 0.022641, -0.020486}}],
    Polygon[{{1.493889, 0.028972, -0.017029},{1.491513, 0.028972, -0.013153},{
      1.492777, 0.020995, -0.013153},{1.495036, 0.021729, -0.017029}}],
    Polygon[{{1.491513, 0.028972, -0.013153},{1.489774, 0.028972, -0.008953},{
      1.491122, 0.020457, -0.008953},{1.492777, 0.020995, -0.013153}}],
    Polygon[{{1.489774, 0.028972, -0.008953},{1.488712, 0.028972, -0.004532},{
      1.490113, 0.020129, -0.004532},{1.491122, 0.020457, -0.008953}}],
    Polygon[{{1.488712, 0.028972, -0.004532},{1.488356, 0.028972, 0.000000},{
      1.489774, 0.020019, 0.000000},{1.490113, 0.020129, -0.004532}}],
    Polygon[{{1.488356, 0.028972, 0.000000},{1.488712, 0.028972, 0.004532},{
      1.490113, 0.020129, 0.004532},{1.489774, 0.020019, 0.000000}}],
    Polygon[{{1.488712, 0.028972, 0.004532},{1.489774, 0.028972, 0.008953},{
      1.491122, 0.020457, 0.008953},{1.490113, 0.020129, 0.004532}}],
    Polygon[{{1.489774, 0.028972, 0.008953},{1.491513, 0.028972, 0.013153},{
      1.492777, 0.020995, 0.013153},{1.491122, 0.020457, 0.008953}}],
    Polygon[{{1.491513, 0.028972, 0.013153},{1.493889, 0.028972, 0.017029},{
      1.495036, 0.021729, 0.017029},{1.492777, 0.020995, 0.013153}}],
    Polygon[{{1.493889, 0.028972, 0.017029},{1.496841, 0.028972, 0.020486},{
      1.497844, 0.022641, 0.020486},{1.495036, 0.021729, 0.017029}}],
    Polygon[{{1.496841, 0.028972, 0.020486},{1.500298, 0.028972, 0.023438},{
      1.501132, 0.023709, 0.023438},{1.497844, 0.022641, 0.020486}}],
    Polygon[{{1.500298, 0.028972, 0.023438},{1.504174, 0.028972, 0.025814},{
      1.504818, 0.024907, 0.025814},{1.501132, 0.023709, 0.023438}}],
    Polygon[{{1.504174, 0.028972, 0.025814},{1.508374, 0.028972, 0.027554},{
      1.508813, 0.026205, 0.027554},{1.504818, 0.024907, 0.025814}}],
    Polygon[{{1.508374, 0.028972, 0.027554},{1.512795, 0.028972, 0.028615},{
      1.513017, 0.027571, 0.028615},{1.508813, 0.026205, 0.027554}}],
    Polygon[{{1.513017, 0.027571, -0.028615},{1.508813, 0.026205, -0.027554},{
      1.510084, 0.023709, -0.027554},{1.513661, 0.026308, -0.028615}}],
    Polygon[{{1.508813, 0.026205, -0.027554},{1.504818, 0.024907, -0.025814},{
      1.506686, 0.021240, -0.025814},{1.510084, 0.023709, -0.027554}}],
    Polygon[{{1.504818, 0.024907, -0.025814},{1.501132, 0.023709, -0.023438},{
      1.503550, 0.018962, -0.023438},{1.506686, 0.021240, -0.025814}}],
    Polygon[{{1.501132, 0.023709, -0.023438},{1.497844, 0.022641, -0.020486},{
      1.500754, 0.016930, -0.020486},{1.503550, 0.018962, -0.023438}}],
    Polygon[{{1.497844, 0.022641, -0.020486},{1.495036, 0.021729, -0.017029},{
      1.498365, 0.015195, -0.017029},{1.500754, 0.016930, -0.020486}}],
    Polygon[{{1.495036, 0.021729, -0.017029},{1.492777, 0.020995, -0.013153},{
      1.496443, 0.013799, -0.013153},{1.498365, 0.015195, -0.017029}}],
    Polygon[{{1.492777, 0.020995, -0.013153},{1.491122, 0.020457, -0.008953},{
      1.495036, 0.012776, -0.008953},{1.496443, 0.013799, -0.013153}}],
    Polygon[{{1.491122, 0.020457, -0.008953},{1.490113, 0.020129, -0.004532},{
      1.494177, 0.012152, -0.004532},{1.495036, 0.012776, -0.008953}}],
    Polygon[{{1.490113, 0.020129, -0.004532},{1.489774, 0.020019, 0.000000},{
      1.493889, 0.011942, 0.000000},{1.494177, 0.012152, -0.004532}}],
    Polygon[{{1.489774, 0.020019, 0.000000},{1.490113, 0.020129, 0.004532},{
      1.494177, 0.012152, 0.004532},{1.493889, 0.011942, 0.000000}}],
    Polygon[{{1.490113, 0.020129, 0.004532},{1.491122, 0.020457, 0.008953},{
      1.495036, 0.012776, 0.008953},{1.494177, 0.012152, 0.004532}}],
    Polygon[{{1.491122, 0.020457, 0.008953},{1.492777, 0.020995, 0.013153},{
      1.496443, 0.013799, 0.013153},{1.495036, 0.012776, 0.008953}}],
    Polygon[{{1.492777, 0.020995, 0.013153},{1.495036, 0.021729, 0.017029},{
      1.498365, 0.015195, 0.017029},{1.496443, 0.013799, 0.013153}}],
    Polygon[{{1.495036, 0.021729, 0.017029},{1.497844, 0.022641, 0.020486},{
      1.500754, 0.016930, 0.020486},{1.498365, 0.015195, 0.017029}}],
    Polygon[{{1.497844, 0.022641, 0.020486},{1.501132, 0.023709, 0.023438},{
      1.503550, 0.018962, 0.023438},{1.500754, 0.016930, 0.020486}}],
    Polygon[{{1.501132, 0.023709, 0.023438},{1.504818, 0.024907, 0.025814},{
      1.506686, 0.021240, 0.025814},{1.503550, 0.018962, 0.023438}}],
    Polygon[{{1.504818, 0.024907, 0.025814},{1.508813, 0.026205, 0.027554},{
      1.510084, 0.023709, 0.027554},{1.506686, 0.021240, 0.025814}}],
    Polygon[{{1.508813, 0.026205, 0.027554},{1.513017, 0.027571, 0.028615},{
      1.513661, 0.026308, 0.028615},{1.510084, 0.023709, 0.027554}}],
    Polygon[{{1.513661, 0.026308, -0.028615},{1.510084, 0.023709, -0.027554},{
      1.512065, 0.021729, -0.027554},{1.514663, 0.025305, -0.028615}}],
    Polygon[{{1.510084, 0.023709, -0.027554},{1.506686, 0.021240, -0.025814},{
      1.509596, 0.018331, -0.025814},{1.512065, 0.021729, -0.027554}}],
    Polygon[{{1.506686, 0.021240, -0.025814},{1.503550, 0.018962, -0.023438},{
      1.507318, 0.015195, -0.023438},{1.509596, 0.018331, -0.025814}}],
    Polygon[{{1.503550, 0.018962, -0.023438},{1.500754, 0.016930, -0.020486},{
      1.505286, 0.012398, -0.020486},{1.507318, 0.015195, -0.023438}}],
    Polygon[{{1.500754, 0.016930, -0.020486},{1.498365, 0.015195, -0.017029},{
      1.503550, 0.010009, -0.017029},{1.505286, 0.012398, -0.020486}}],
    Polygon[{{1.498365, 0.015195, -0.017029},{1.496443, 0.013799, -0.013153},{
      1.502154, 0.008088, -0.013153},{1.503550, 0.010009, -0.017029}}],
    Polygon[{{1.496443, 0.013799, -0.013153},{1.495036, 0.012776, -0.008953},{
      1.501132, 0.006680, -0.008953},{1.502154, 0.008088, -0.013153}}],
    Polygon[{{1.495036, 0.012776, -0.008953},{1.494177, 0.012152, -0.004532},{
      1.500508, 0.005822, -0.004532},{1.501132, 0.006680, -0.008953}}],
    Polygon[{{1.494177, 0.012152, -0.004532},{1.493889, 0.011942, 0.000000},{
      1.500298, 0.005533, 0.000000},{1.500508, 0.005822, -0.004532}}],
    Polygon[{{1.493889, 0.011942, 0.000000},{1.494177, 0.012152, 0.004532},{
      1.500508, 0.005822, 0.004532},{1.500298, 0.005533, 0.000000}}],
    Polygon[{{1.494177, 0.012152, 0.004532},{1.495036, 0.012776, 0.008953},{
      1.501132, 0.006680, 0.008953},{1.500508, 0.005822, 0.004532}}],
    Polygon[{{1.495036, 0.012776, 0.008953},{1.496443, 0.013799, 0.013153},{
      1.502154, 0.008088, 0.013153},{1.501132, 0.006680, 0.008953}}],
    Polygon[{{1.496443, 0.013799, 0.013153},{1.498365, 0.015195, 0.017029},{
      1.503550, 0.010009, 0.017029},{1.502154, 0.008088, 0.013153}}],
    Polygon[{{1.498365, 0.015195, 0.017029},{1.500754, 0.016930, 0.020486},{
      1.505286, 0.012398, 0.020486},{1.503550, 0.010009, 0.017029}}],
    Polygon[{{1.500754, 0.016930, 0.020486},{1.503550, 0.018962, 0.023438},{
      1.507318, 0.015195, 0.023438},{1.505286, 0.012398, 0.020486}}],
    Polygon[{{1.503550, 0.018962, 0.023438},{1.506686, 0.021240, 0.025814},{
      1.509596, 0.018331, 0.025814},{1.507318, 0.015195, 0.023438}}],
    Polygon[{{1.506686, 0.021240, 0.025814},{1.510084, 0.023709, 0.027554},{
      1.512065, 0.021729, 0.027554},{1.509596, 0.018331, 0.025814}}],
    Polygon[{{1.510084, 0.023709, 0.027554},{1.513661, 0.026308, 0.028615},{
      1.514663, 0.025305, 0.028615},{1.512065, 0.021729, 0.027554}}],
    Polygon[{{1.514663, 0.025305, -0.028615},{1.512065, 0.021729, -0.027554},{
      1.514561, 0.020457, -0.027554},{1.515927, 0.024661, -0.028615}}],
    Polygon[{{1.512065, 0.021729, -0.027554},{1.509596, 0.018331, -0.025814},{
      1.513263, 0.016462, -0.025814},{1.514561, 0.020457, -0.027554}}],
    Polygon[{{1.509596, 0.018331, -0.025814},{1.507318, 0.015195, -0.023438},{
      1.512065, 0.012776, -0.023438},{1.513263, 0.016462, -0.025814}}],
    Polygon[{{1.507318, 0.015195, -0.023438},{1.505286, 0.012398, -0.020486},{
      1.510997, 0.009488, -0.020486},{1.512065, 0.012776, -0.023438}}],
    Polygon[{{1.505286, 0.012398, -0.020486},{1.503550, 0.010009, -0.017029},{
      1.510084, 0.006680, -0.017029},{1.510997, 0.009488, -0.020486}}],
    Polygon[{{1.503550, 0.010009, -0.017029},{1.502154, 0.008088, -0.013153},{
      1.509350, 0.004421, -0.013153},{1.510084, 0.006680, -0.017029}}],
    Polygon[{{1.502154, 0.008088, -0.013153},{1.501132, 0.006680, -0.008953},{
      1.508813, 0.002767, -0.008953},{1.509350, 0.004421, -0.013153}}],
    Polygon[{{1.501132, 0.006680, -0.008953},{1.500508, 0.005822, -0.004532},{
      1.508485, 0.001757, -0.004532},{1.508813, 0.002767, -0.008953}}],
    Polygon[{{1.500508, 0.005822, -0.004532},{1.500298, 0.005533, 0.000000},{
      1.508374, 0.001418, 0.000000},{1.508485, 0.001757, -0.004532}}],
    Polygon[{{1.500298, 0.005533, 0.000000},{1.500508, 0.005822, 0.004532},{
      1.508485, 0.001757, 0.004532},{1.508374, 0.001418, 0.000000}}],
    Polygon[{{1.500508, 0.005822, 0.004532},{1.501132, 0.006680, 0.008953},{
      1.508813, 0.002767, 0.008953},{1.508485, 0.001757, 0.004532}}],
    Polygon[{{1.501132, 0.006680, 0.008953},{1.502154, 0.008088, 0.013153},{
      1.509350, 0.004421, 0.013153},{1.508813, 0.002767, 0.008953}}],
    Polygon[{{1.502154, 0.008088, 0.013153},{1.503550, 0.010009, 0.017029},{
      1.510084, 0.006680, 0.017029},{1.509350, 0.004421, 0.013153}}],
    Polygon[{{1.503550, 0.010009, 0.017029},{1.505286, 0.012398, 0.020486},{
      1.510997, 0.009488, 0.020486},{1.510084, 0.006680, 0.017029}}],
    Polygon[{{1.505286, 0.012398, 0.020486},{1.507318, 0.015195, 0.023438},{
      1.512065, 0.012776, 0.023438},{1.510997, 0.009488, 0.020486}}],
    Polygon[{{1.507318, 0.015195, 0.023438},{1.509596, 0.018331, 0.025814},{
      1.513263, 0.016462, 0.025814},{1.512065, 0.012776, 0.023438}}],
    Polygon[{{1.509596, 0.018331, 0.025814},{1.512065, 0.021729, 0.027554},{
      1.514561, 0.020457, 0.027554},{1.513263, 0.016462, 0.025814}}],
    Polygon[{{1.512065, 0.021729, 0.027554},{1.514663, 0.025305, 0.028615},{
      1.515927, 0.024661, 0.028615},{1.514561, 0.020457, 0.027554}}],
    Polygon[{{1.515927, 0.024661, -0.028615},{1.514561, 0.020457, -0.027554},{
      1.517327, 0.020019, -0.027554},{1.517327, 0.024439, -0.028615}}],
    Polygon[{{1.514561, 0.020457, -0.027554},{1.513263, 0.016462, -0.025814},{
      1.517327, 0.015819, -0.025814},{1.517327, 0.020019, -0.027554}}],
    Polygon[{{1.513263, 0.016462, -0.025814},{1.512065, 0.012776, -0.023438},{
      1.517327, 0.011942, -0.023438},{1.517327, 0.015819, -0.025814}}],
    Polygon[{{1.512065, 0.012776, -0.023438},{1.510997, 0.009488, -0.020486},{
      1.517327, 0.008486, -0.020486},{1.517327, 0.011942, -0.023438}}],
    Polygon[{{1.510997, 0.009488, -0.020486},{1.510084, 0.006680, -0.017029},{
      1.517327, 0.005533, -0.017029},{1.517327, 0.008486, -0.020486}}],
    Polygon[{{1.510084, 0.006680, -0.017029},{1.509350, 0.004421, -0.013153},{
      1.517327, 0.003158, -0.013153},{1.517327, 0.005533, -0.017029}}],
    Polygon[{{1.509350, 0.004421, -0.013153},{1.508813, 0.002767, -0.008953},{
      1.517327, 0.001418, -0.008953},{1.517327, 0.003158, -0.013153}}],
    Polygon[{{1.508813, 0.002767, -0.008953},{1.508485, 0.001757, -0.004532},{
      1.517327, 0.000357, -0.004532},{1.517327, 0.001418, -0.008953}}],
    Polygon[{{1.508485, 0.001757, -0.004532},{1.508374, 0.001418, 0.000000},{
      1.517327, 0.000000, 0.000000},{1.517327, 0.000357, -0.004532}}],
    Polygon[{{1.508374, 0.001418, 0.000000},{1.508485, 0.001757, 0.004532},{
      1.517327, 0.000357, 0.004532},{1.517327, 0.000000, 0.000000}}],
    Polygon[{{1.508485, 0.001757, 0.004532},{1.508813, 0.002767, 0.008953},{
      1.517327, 0.001418, 0.008953},{1.517327, 0.000357, 0.004532}}],
    Polygon[{{1.508813, 0.002767, 0.008953},{1.509350, 0.004421, 0.013153},{
      1.517327, 0.003158, 0.013153},{1.517327, 0.001418, 0.008953}}],
    Polygon[{{1.509350, 0.004421, 0.013153},{1.510084, 0.006680, 0.017029},{
      1.517327, 0.005533, 0.017029},{1.517327, 0.003158, 0.013153}}],
    Polygon[{{1.510084, 0.006680, 0.017029},{1.510997, 0.009488, 0.020486},{
      1.517327, 0.008486, 0.020486},{1.517327, 0.005533, 0.017029}}],
    Polygon[{{1.510997, 0.009488, 0.020486},{1.512065, 0.012776, 0.023438},{
      1.517327, 0.011942, 0.023438},{1.517327, 0.008486, 0.020486}}],
    Polygon[{{1.512065, 0.012776, 0.023438},{1.513263, 0.016462, 0.025814},{
      1.517327, 0.015819, 0.025814},{1.517327, 0.011942, 0.023438}}],
    Polygon[{{1.513263, 0.016462, 0.025814},{1.514561, 0.020457, 0.027554},{
      1.517327, 0.020019, 0.027554},{1.517327, 0.015819, 0.025814}}],
    Polygon[{{1.514561, 0.020457, 0.027554},{1.515927, 0.024661, 0.028615},{
      1.517327, 0.024439, 0.028615},{1.517327, 0.020019, 0.027554}}],
    Polygon[{{1.517327, 0.024439, -0.028615},{1.517327, 0.020019, -0.027554},{
      1.520094, 0.020457, -0.027554},{1.518728, 0.024661, -0.028615}}],
    Polygon[{{1.517327, 0.020019, -0.027554},{1.517327, 0.015819, -0.025814},{
      1.521392, 0.016462, -0.025814},{1.520094, 0.020457, -0.027554}}],
    Polygon[{{1.517327, 0.015819, -0.025814},{1.517327, 0.011942, -0.023438},{
      1.522589, 0.012776, -0.023438},{1.521392, 0.016462, -0.025814}}],
    Polygon[{{1.517327, 0.011942, -0.023438},{1.517327, 0.008486, -0.020486},{
      1.523658, 0.009488, -0.020486},{1.522589, 0.012776, -0.023438}}],
    Polygon[{{1.517327, 0.008486, -0.020486},{1.517327, 0.005533, -0.017029},{
      1.524570, 0.006680, -0.017029},{1.523658, 0.009488, -0.020486}}],
    Polygon[{{1.517327, 0.005533, -0.017029},{1.517327, 0.003158, -0.013153},{
      1.525304, 0.004421, -0.013153},{1.524570, 0.006680, -0.017029}}],
    Polygon[{{1.517327, 0.003158, -0.013153},{1.517327, 0.001418, -0.008953},{
      1.525842, 0.002767, -0.008953},{1.525304, 0.004421, -0.013153}}],
    Polygon[{{1.517327, 0.001418, -0.008953},{1.517327, 0.000357, -0.004532},{
      1.526170, 0.001757, -0.004532},{1.525842, 0.002767, -0.008953}}],
    Polygon[{{1.517327, 0.000357, -0.004532},{1.517327, 0.000000, 0.000000},{
      1.526280, 0.001418, 0.000000},{1.526170, 0.001757, -0.004532}}],
    Polygon[{{1.517327, 0.000000, 0.000000},{1.517327, 0.000357, 0.004532},{
      1.526170, 0.001757, 0.004532},{1.526280, 0.001418, 0.000000}}],
    Polygon[{{1.517327, 0.000357, 0.004532},{1.517327, 0.001418, 0.008953},{
      1.525842, 0.002767, 0.008953},{1.526170, 0.001757, 0.004532}}],
    Polygon[{{1.517327, 0.001418, 0.008953},{1.517327, 0.003158, 0.013153},{
      1.525304, 0.004421, 0.013153},{1.525842, 0.002767, 0.008953}}],
    Polygon[{{1.517327, 0.003158, 0.013153},{1.517327, 0.005533, 0.017029},{
      1.524570, 0.006680, 0.017029},{1.525304, 0.004421, 0.013153}}],
    Polygon[{{1.517327, 0.005533, 0.017029},{1.517327, 0.008486, 0.020486},{
      1.523658, 0.009488, 0.020486},{1.524570, 0.006680, 0.017029}}],
    Polygon[{{1.517327, 0.008486, 0.020486},{1.517327, 0.011942, 0.023438},{
      1.522589, 0.012776, 0.023438},{1.523658, 0.009488, 0.020486}}],
    Polygon[{{1.517327, 0.011942, 0.023438},{1.517327, 0.015819, 0.025814},{
      1.521392, 0.016462, 0.025814},{1.522589, 0.012776, 0.023438}}],
    Polygon[{{1.517327, 0.015819, 0.025814},{1.517327, 0.020019, 0.027554},{
      1.520094, 0.020457, 0.027554},{1.521392, 0.016462, 0.025814}}],
    Polygon[{{1.517327, 0.020019, 0.027554},{1.517327, 0.024439, 0.028615},{
      1.518728, 0.024661, 0.028615},{1.520094, 0.020457, 0.027554}}],
    Polygon[{{1.518728, 0.024661, -0.028615},{1.520094, 0.020457, -0.027554},{
      1.522589, 0.021729, -0.027554},{1.519991, 0.025305, -0.028615}}],
    Polygon[{{1.520094, 0.020457, -0.027554},{1.521392, 0.016462, -0.025814},{
      1.525058, 0.018331, -0.025814},{1.522589, 0.021729, -0.027554}}],
    Polygon[{{1.521392, 0.016462, -0.025814},{1.522589, 0.012776, -0.023438},{
      1.527337, 0.015195, -0.023438},{1.525058, 0.018331, -0.025814}}],
    Polygon[{{1.522589, 0.012776, -0.023438},{1.523658, 0.009488, -0.020486},{
      1.529369, 0.012398, -0.020486},{1.527337, 0.015195, -0.023438}}],
    Polygon[{{1.523658, 0.009488, -0.020486},{1.524570, 0.006680, -0.017029},{
      1.531104, 0.010009, -0.017029},{1.529369, 0.012398, -0.020486}}],
    Polygon[{{1.524570, 0.006680, -0.017029},{1.525304, 0.004421, -0.013153},{
      1.532500, 0.008088, -0.013153},{1.531104, 0.010009, -0.017029}}],
    Polygon[{{1.525304, 0.004421, -0.013153},{1.525842, 0.002767, -0.008953},{
      1.533523, 0.006680, -0.008953},{1.532500, 0.008088, -0.013153}}],
    Polygon[{{1.525842, 0.002767, -0.008953},{1.526170, 0.001757, -0.004532},{
      1.534147, 0.005822, -0.004532},{1.533523, 0.006680, -0.008953}}],
    Polygon[{{1.526170, 0.001757, -0.004532},{1.526280, 0.001418, 0.000000},{
      1.534356, 0.005533, 0.000000},{1.534147, 0.005822, -0.004532}}],
    Polygon[{{1.526280, 0.001418, 0.000000},{1.526170, 0.001757, 0.004532},{
      1.534147, 0.005822, 0.004532},{1.534356, 0.005533, 0.000000}}],
    Polygon[{{1.526170, 0.001757, 0.004532},{1.525842, 0.002767, 0.008953},{
      1.533523, 0.006680, 0.008953},{1.534147, 0.005822, 0.004532}}],
    Polygon[{{1.525842, 0.002767, 0.008953},{1.525304, 0.004421, 0.013153},{
      1.532500, 0.008088, 0.013153},{1.533523, 0.006680, 0.008953}}],
    Polygon[{{1.525304, 0.004421, 0.013153},{1.524570, 0.006680, 0.017029},{
      1.531104, 0.010009, 0.017029},{1.532500, 0.008088, 0.013153}}],
    Polygon[{{1.524570, 0.006680, 0.017029},{1.523658, 0.009488, 0.020486},{
      1.529369, 0.012398, 0.020486},{1.531104, 0.010009, 0.017029}}],
    Polygon[{{1.523658, 0.009488, 0.020486},{1.522589, 0.012776, 0.023438},{
      1.527337, 0.015195, 0.023438},{1.529369, 0.012398, 0.020486}}],
    Polygon[{{1.522589, 0.012776, 0.023438},{1.521392, 0.016462, 0.025814},{
      1.525058, 0.018331, 0.025814},{1.527337, 0.015195, 0.023438}}],
    Polygon[{{1.521392, 0.016462, 0.025814},{1.520094, 0.020457, 0.027554},{
      1.522589, 0.021729, 0.027554},{1.525058, 0.018331, 0.025814}}],
    Polygon[{{1.520094, 0.020457, 0.027554},{1.518728, 0.024661, 0.028615},{
      1.519991, 0.025305, 0.028615},{1.522589, 0.021729, 0.027554}}],
    Polygon[{{1.519991, 0.025305, -0.028615},{1.522589, 0.021729, -0.027554},{
      1.524570, 0.023709, -0.027554},{1.520994, 0.026308, -0.028615}}],
    Polygon[{{1.522589, 0.021729, -0.027554},{1.525058, 0.018331, -0.025814},{
      1.527968, 0.021240, -0.025814},{1.524570, 0.023709, -0.027554}}],
    Polygon[{{1.525058, 0.018331, -0.025814},{1.527337, 0.015195, -0.023438},{
      1.531104, 0.018962, -0.023438},{1.527968, 0.021240, -0.025814}}],
    Polygon[{{1.527337, 0.015195, -0.023438},{1.529369, 0.012398, -0.020486},{
      1.533901, 0.016930, -0.020486},{1.531104, 0.018962, -0.023438}}],
    Polygon[{{1.529369, 0.012398, -0.020486},{1.531104, 0.010009, -0.017029},{
      1.536289, 0.015195, -0.017029},{1.533901, 0.016930, -0.020486}}],
    Polygon[{{1.531104, 0.010009, -0.017029},{1.532500, 0.008088, -0.013153},{
      1.538211, 0.013799, -0.013153},{1.536289, 0.015195, -0.017029}}],
    Polygon[{{1.532500, 0.008088, -0.013153},{1.533523, 0.006680, -0.008953},{
      1.539618, 0.012776, -0.008953},{1.538211, 0.013799, -0.013153}}],
    Polygon[{{1.533523, 0.006680, -0.008953},{1.534147, 0.005822, -0.004532},{
      1.540477, 0.012152, -0.004532},{1.539618, 0.012776, -0.008953}}],
    Polygon[{{1.534147, 0.005822, -0.004532},{1.534356, 0.005533, 0.000000},{
      1.540766, 0.011942, 0.000000},{1.540477, 0.012152, -0.004532}}],
    Polygon[{{1.534356, 0.005533, 0.000000},{1.534147, 0.005822, 0.004532},{
      1.540477, 0.012152, 0.004532},{1.540766, 0.011942, 0.000000}}],
    Polygon[{{1.534147, 0.005822, 0.004532},{1.533523, 0.006680, 0.008953},{
      1.539618, 0.012776, 0.008953},{1.540477, 0.012152, 0.004532}}],
    Polygon[{{1.533523, 0.006680, 0.008953},{1.532500, 0.008088, 0.013153},{
      1.538211, 0.013799, 0.013153},{1.539618, 0.012776, 0.008953}}],
    Polygon[{{1.532500, 0.008088, 0.013153},{1.531104, 0.010009, 0.017029},{
      1.536289, 0.015195, 0.017029},{1.538211, 0.013799, 0.013153}}],
    Polygon[{{1.531104, 0.010009, 0.017029},{1.529369, 0.012398, 0.020486},{
      1.533901, 0.016930, 0.020486},{1.536289, 0.015195, 0.017029}}],
    Polygon[{{1.529369, 0.012398, 0.020486},{1.527337, 0.015195, 0.023438},{
      1.531104, 0.018962, 0.023438},{1.533901, 0.016930, 0.020486}}],
    Polygon[{{1.527337, 0.015195, 0.023438},{1.525058, 0.018331, 0.025814},{
      1.527968, 0.021240, 0.025814},{1.531104, 0.018962, 0.023438}}],
    Polygon[{{1.525058, 0.018331, 0.025814},{1.522589, 0.021729, 0.027554},{
      1.524570, 0.023709, 0.027554},{1.527968, 0.021240, 0.025814}}],
    Polygon[{{1.522589, 0.021729, 0.027554},{1.519991, 0.025305, 0.028615},{
      1.520994, 0.026308, 0.028615},{1.524570, 0.023709, 0.027554}}],
    Polygon[{{1.520994, 0.026308, -0.028615},{1.524570, 0.023709, -0.027554},{
      1.525842, 0.026205, -0.027554},{1.521638, 0.027571, -0.028615}}],
    Polygon[{{1.524570, 0.023709, -0.027554},{1.527968, 0.021240, -0.025814},{
      1.529836, 0.024907, -0.025814},{1.525842, 0.026205, -0.027554}}],
    Polygon[{{1.527968, 0.021240, -0.025814},{1.531104, 0.018962, -0.023438},{
      1.533523, 0.023709, -0.023438},{1.529836, 0.024907, -0.025814}}],
    Polygon[{{1.531104, 0.018962, -0.023438},{1.533901, 0.016930, -0.020486},{
      1.536811, 0.022641, -0.020486},{1.533523, 0.023709, -0.023438}}],
    Polygon[{{1.533901, 0.016930, -0.020486},{1.536289, 0.015195, -0.017029},{
      1.539618, 0.021729, -0.017029},{1.536811, 0.022641, -0.020486}}],
    Polygon[{{1.536289, 0.015195, -0.017029},{1.538211, 0.013799, -0.013153},{
      1.541878, 0.020995, -0.013153},{1.539618, 0.021729, -0.017029}}],
    Polygon[{{1.538211, 0.013799, -0.013153},{1.539618, 0.012776, -0.008953},{
      1.543532, 0.020457, -0.008953},{1.541878, 0.020995, -0.013153}}],
    Polygon[{{1.539618, 0.012776, -0.008953},{1.540477, 0.012152, -0.004532},{
      1.544541, 0.020129, -0.004532},{1.543532, 0.020457, -0.008953}}],
    Polygon[{{1.540477, 0.012152, -0.004532},{1.540766, 0.011942, 0.000000},{
      1.544881, 0.020019, 0.000000},{1.544541, 0.020129, -0.004532}}],
    Polygon[{{1.540766, 0.011942, 0.000000},{1.540477, 0.012152, 0.004532},{
      1.544541, 0.020129, 0.004532},{1.544881, 0.020019, 0.000000}}],
    Polygon[{{1.540477, 0.012152, 0.004532},{1.539618, 0.012776, 0.008953},{
      1.543532, 0.020457, 0.008953},{1.544541, 0.020129, 0.004532}}],
    Polygon[{{1.539618, 0.012776, 0.008953},{1.538211, 0.013799, 0.013153},{
      1.541878, 0.020995, 0.013153},{1.543532, 0.020457, 0.008953}}],
    Polygon[{{1.538211, 0.013799, 0.013153},{1.536289, 0.015195, 0.017029},{
      1.539618, 0.021729, 0.017029},{1.541878, 0.020995, 0.013153}}],
    Polygon[{{1.536289, 0.015195, 0.017029},{1.533901, 0.016930, 0.020486},{
      1.536811, 0.022641, 0.020486},{1.539618, 0.021729, 0.017029}}],
    Polygon[{{1.533901, 0.016930, 0.020486},{1.531104, 0.018962, 0.023438},{
      1.533523, 0.023709, 0.023438},{1.536811, 0.022641, 0.020486}}],
    Polygon[{{1.531104, 0.018962, 0.023438},{1.527968, 0.021240, 0.025814},{
      1.529836, 0.024907, 0.025814},{1.533523, 0.023709, 0.023438}}],
    Polygon[{{1.527968, 0.021240, 0.025814},{1.524570, 0.023709, 0.027554},{
      1.525842, 0.026205, 0.027554},{1.529836, 0.024907, 0.025814}}],
    Polygon[{{1.524570, 0.023709, 0.027554},{1.520994, 0.026308, 0.028615},{
      1.521638, 0.027571, 0.028615},{1.525842, 0.026205, 0.027554}}],
    Polygon[{{1.521638, 0.027571, -0.028615},{1.525842, 0.026205, -0.027554},{
      1.526280, 0.028972, -0.027554},{1.521859, 0.028972, -0.028615}}],
    Polygon[{{1.525842, 0.026205, -0.027554},{1.529836, 0.024907, -0.025814},{
      1.530480, 0.028972, -0.025814},{1.526280, 0.028972, -0.027554}}],
    Polygon[{{1.529836, 0.024907, -0.025814},{1.533523, 0.023709, -0.023438},{
      1.534356, 0.028972, -0.023438},{1.530480, 0.028972, -0.025814}}],
    Polygon[{{1.533523, 0.023709, -0.023438},{1.536811, 0.022641, -0.020486},{
      1.537813, 0.028972, -0.020486},{1.534356, 0.028972, -0.023438}}],
    Polygon[{{1.536811, 0.022641, -0.020486},{1.539618, 0.021729, -0.017029},{
      1.540766, 0.028972, -0.017029},{1.537813, 0.028972, -0.020486}}],
    Polygon[{{1.539618, 0.021729, -0.017029},{1.541878, 0.020995, -0.013153},{
      1.543141, 0.028972, -0.013153},{1.540766, 0.028972, -0.017029}}],
    Polygon[{{1.541878, 0.020995, -0.013153},{1.543532, 0.020457, -0.008953},{
      1.544881, 0.028972, -0.008953},{1.543141, 0.028972, -0.013153}}],
    Polygon[{{1.543532, 0.020457, -0.008953},{1.544541, 0.020129, -0.004532},{
      1.545942, 0.028972, -0.004532},{1.544881, 0.028972, -0.008953}}],
    Polygon[{{1.544541, 0.020129, -0.004532},{1.544881, 0.020019, 0.000000},{
      1.546299, 0.028972, 0.000000},{1.545942, 0.028972, -0.004532}}],
    Polygon[{{1.544881, 0.020019, 0.000000},{1.544541, 0.020129, 0.004532},{
      1.545942, 0.028972, 0.004532},{1.546299, 0.028972, 0.000000}}],
    Polygon[{{1.544541, 0.020129, 0.004532},{1.543532, 0.020457, 0.008953},{
      1.544881, 0.028972, 0.008953},{1.545942, 0.028972, 0.004532}}],
    Polygon[{{1.543532, 0.020457, 0.008953},{1.541878, 0.020995, 0.013153},{
      1.543141, 0.028972, 0.013153},{1.544881, 0.028972, 0.008953}}],
    Polygon[{{1.541878, 0.020995, 0.013153},{1.539618, 0.021729, 0.017029},{
      1.540766, 0.028972, 0.017029},{1.543141, 0.028972, 0.013153}}],
    Polygon[{{1.539618, 0.021729, 0.017029},{1.536811, 0.022641, 0.020486},{
      1.537813, 0.028972, 0.020486},{1.540766, 0.028972, 0.017029}}],
    Polygon[{{1.536811, 0.022641, 0.020486},{1.533523, 0.023709, 0.023438},{
      1.534356, 0.028972, 0.023438},{1.537813, 0.028972, 0.020486}}],
    Polygon[{{1.533523, 0.023709, 0.023438},{1.529836, 0.024907, 0.025814},{
      1.530480, 0.028972, 0.025814},{1.534356, 0.028972, 0.023438}}],
    Polygon[{{1.529836, 0.024907, 0.025814},{1.525842, 0.026205, 0.027554},{
      1.526280, 0.028972, 0.027554},{1.530480, 0.028972, 0.025814}}],
    Polygon[{{1.525842, 0.026205, 0.027554},{1.521638, 0.027571, 0.028615},{
      1.521859, 0.028972, 0.028615},{1.526280, 0.028972, 0.027554}}],
    Polygon[{{1.561425, 0.015038, -0.014853},{1.563720, 0.015038, -0.014302},{
      1.563493, 0.016474, -0.014302},{1.561310, 0.015765, -0.014853}}],
    Polygon[{{1.563720, 0.015038, -0.014302},{1.565900, 0.015038, -0.013399},{
      1.565566, 0.017148, -0.013399},{1.563493, 0.016474, -0.014302}}],
    Polygon[{{1.565900, 0.015038, -0.013399},{1.567912, 0.015038, -0.012166},{
      1.567480, 0.017770, -0.012166},{1.565566, 0.017148, -0.013399}}],
    Polygon[{{1.567912, 0.015038, -0.012166},{1.569707, 0.015038, -0.010634},{
      1.569186, 0.018324, -0.010634},{1.567480, 0.017770, -0.012166}}],
    Polygon[{{1.569707, 0.015038, -0.010634},{1.571239, 0.015038, -0.008839},{
      1.570644, 0.018798, -0.008839},{1.569186, 0.018324, -0.010634}}],
    Polygon[{{1.571239, 0.015038, -0.008839},{1.572472, 0.015038, -0.006827},{
      1.571816, 0.019179, -0.006827},{1.570644, 0.018798, -0.008839}}],
    Polygon[{{1.572472, 0.015038, -0.006827},{1.573375, 0.015038, -0.004647},{
      1.572675, 0.019458, -0.004647},{1.571816, 0.019179, -0.006827}}],
    Polygon[{{1.573375, 0.015038, -0.004647},{1.573926, 0.015038, -0.002352},{
      1.573199, 0.019628, -0.002352},{1.572675, 0.019458, -0.004647}}],
    Polygon[{{1.573926, 0.015038, -0.002352},{1.574111, 0.015038, 0.000000},{
      1.573375, 0.019685, 0.000000},{1.573199, 0.019628, -0.002352}}],
    Polygon[{{1.574111, 0.015038, 0.000000},{1.573926, 0.015038, 0.002352},{
      1.573199, 0.019628, 0.002352},{1.573375, 0.019685, 0.000000}}],
    Polygon[{{1.573926, 0.015038, 0.002352},{1.573375, 0.015038, 0.004647},{
      1.572675, 0.019458, 0.004647},{1.573199, 0.019628, 0.002352}}],
    Polygon[{{1.573375, 0.015038, 0.004647},{1.572472, 0.015038, 0.006827},{
      1.571816, 0.019179, 0.006827},{1.572675, 0.019458, 0.004647}}],
    Polygon[{{1.572472, 0.015038, 0.006827},{1.571239, 0.015038, 0.008839},{
      1.570644, 0.018798, 0.008839},{1.571816, 0.019179, 0.006827}}],
    Polygon[{{1.571239, 0.015038, 0.008839},{1.569707, 0.015038, 0.010634},{
      1.569186, 0.018324, 0.010634},{1.570644, 0.018798, 0.008839}}],
    Polygon[{{1.569707, 0.015038, 0.010634},{1.567912, 0.015038, 0.012166},{
      1.567480, 0.017770, 0.012166},{1.569186, 0.018324, 0.010634}}],
    Polygon[{{1.567912, 0.015038, 0.012166},{1.565900, 0.015038, 0.013399},{
      1.565566, 0.017148, 0.013399},{1.567480, 0.017770, 0.012166}}],
    Polygon[{{1.565900, 0.015038, 0.013399},{1.563720, 0.015038, 0.014302},{
      1.563493, 0.016474, 0.014302},{1.565566, 0.017148, 0.013399}}],
    Polygon[{{1.563720, 0.015038, 0.014302},{1.561425, 0.015038, 0.014853},{
      1.561310, 0.015765, 0.014853},{1.563493, 0.016474, 0.014302}}],
    Polygon[{{1.561310, 0.015765, -0.014853},{1.563493, 0.016474, -0.014302},{
      1.562833, 0.017770, -0.014302},{1.560976, 0.016421, -0.014853}}],
    Polygon[{{1.563493, 0.016474, -0.014302},{1.565566, 0.017148, -0.013399},{
      1.564596, 0.019051, -0.013399},{1.562833, 0.017770, -0.014302}}],
    Polygon[{{1.565566, 0.017148, -0.013399},{1.567480, 0.017770, -0.012166},{
      1.566224, 0.020234, -0.012166},{1.564596, 0.019051, -0.013399}}],
    Polygon[{{1.567480, 0.017770, -0.012166},{1.569186, 0.018324, -0.010634},{
      1.567676, 0.021288, -0.010634},{1.566224, 0.020234, -0.012166}}],
    Polygon[{{1.569186, 0.018324, -0.010634},{1.570644, 0.018798, -0.008839},{
      1.568916, 0.022189, -0.008839},{1.567676, 0.021288, -0.010634}}],
    Polygon[{{1.570644, 0.018798, -0.008839},{1.571816, 0.019179, -0.006827},{
      1.569913, 0.022914, -0.006827},{1.568916, 0.022189, -0.008839}}],
    Polygon[{{1.571816, 0.019179, -0.006827},{1.572675, 0.019458, -0.004647},{
      1.570644, 0.023445, -0.004647},{1.569913, 0.022914, -0.006827}}],
    Polygon[{{1.572675, 0.019458, -0.004647},{1.573199, 0.019628, -0.002352},{
      1.571089, 0.023769, -0.002352},{1.570644, 0.023445, -0.004647}}],
    Polygon[{{1.573199, 0.019628, -0.002352},{1.573375, 0.019685, 0.000000},{
      1.571239, 0.023877, 0.000000},{1.571089, 0.023769, -0.002352}}],
    Polygon[{{1.573375, 0.019685, 0.000000},{1.573199, 0.019628, 0.002352},{
      1.571089, 0.023769, 0.002352},{1.571239, 0.023877, 0.000000}}],
    Polygon[{{1.573199, 0.019628, 0.002352},{1.572675, 0.019458, 0.004647},{
      1.570644, 0.023445, 0.004647},{1.571089, 0.023769, 0.002352}}],
    Polygon[{{1.572675, 0.019458, 0.004647},{1.571816, 0.019179, 0.006827},{
      1.569913, 0.022914, 0.006827},{1.570644, 0.023445, 0.004647}}],
    Polygon[{{1.571816, 0.019179, 0.006827},{1.570644, 0.018798, 0.008839},{
      1.568916, 0.022189, 0.008839},{1.569913, 0.022914, 0.006827}}],
    Polygon[{{1.570644, 0.018798, 0.008839},{1.569186, 0.018324, 0.010634},{
      1.567676, 0.021288, 0.010634},{1.568916, 0.022189, 0.008839}}],
    Polygon[{{1.569186, 0.018324, 0.010634},{1.567480, 0.017770, 0.012166},{
      1.566224, 0.020234, 0.012166},{1.567676, 0.021288, 0.010634}}],
    Polygon[{{1.567480, 0.017770, 0.012166},{1.565566, 0.017148, 0.013399},{
      1.564596, 0.019051, 0.013399},{1.566224, 0.020234, 0.012166}}],
    Polygon[{{1.565566, 0.017148, 0.013399},{1.563493, 0.016474, 0.014302},{
      1.562833, 0.017770, 0.014302},{1.564596, 0.019051, 0.013399}}],
    Polygon[{{1.563493, 0.016474, 0.014302},{1.561310, 0.015765, 0.014853},{
      1.560976, 0.016421, 0.014853},{1.562833, 0.017770, 0.014302}}],
    Polygon[{{1.560976, 0.016421, -0.014853},{1.562833, 0.017770, -0.014302},{
      1.561805, 0.018798, -0.014302},{1.560456, 0.016941, -0.014853}}],
    Polygon[{{1.562833, 0.017770, -0.014302},{1.564596, 0.019051, -0.013399},{
      1.563086, 0.020561, -0.013399},{1.561805, 0.018798, -0.014302}}],
    Polygon[{{1.564596, 0.019051, -0.013399},{1.566224, 0.020234, -0.012166},{
      1.564269, 0.022189, -0.012166},{1.563086, 0.020561, -0.013399}}],
    Polygon[{{1.566224, 0.020234, -0.012166},{1.567676, 0.021288, -0.010634},{
      1.565323, 0.023641, -0.010634},{1.564269, 0.022189, -0.012166}}],
    Polygon[{{1.567676, 0.021288, -0.010634},{1.568916, 0.022189, -0.008839},{
      1.566224, 0.024881, -0.008839},{1.565323, 0.023641, -0.010634}}],
    Polygon[{{1.568916, 0.022189, -0.008839},{1.569913, 0.022914, -0.006827},{
      1.566949, 0.025878, -0.006827},{1.566224, 0.024881, -0.008839}}],
    Polygon[{{1.569913, 0.022914, -0.006827},{1.570644, 0.023445, -0.004647},{
      1.567480, 0.026609, -0.004647},{1.566949, 0.025878, -0.006827}}],
    Polygon[{{1.570644, 0.023445, -0.004647},{1.571089, 0.023769, -0.002352},{
      1.567803, 0.027055, -0.002352},{1.567480, 0.026609, -0.004647}}],
    Polygon[{{1.571089, 0.023769, -0.002352},{1.571239, 0.023877, 0.000000},{
      1.567912, 0.027204, 0.000000},{1.567803, 0.027055, -0.002352}}],
    Polygon[{{1.571239, 0.023877, 0.000000},{1.571089, 0.023769, 0.002352},{
      1.567803, 0.027055, 0.002352},{1.567912, 0.027204, 0.000000}}],
    Polygon[{{1.571089, 0.023769, 0.002352},{1.570644, 0.023445, 0.004647},{
      1.567480, 0.026609, 0.004647},{1.567803, 0.027055, 0.002352}}],
    Polygon[{{1.570644, 0.023445, 0.004647},{1.569913, 0.022914, 0.006827},{
      1.566949, 0.025878, 0.006827},{1.567480, 0.026609, 0.004647}}],
    Polygon[{{1.569913, 0.022914, 0.006827},{1.568916, 0.022189, 0.008839},{
      1.566224, 0.024881, 0.008839},{1.566949, 0.025878, 0.006827}}],
    Polygon[{{1.568916, 0.022189, 0.008839},{1.567676, 0.021288, 0.010634},{
      1.565323, 0.023641, 0.010634},{1.566224, 0.024881, 0.008839}}],
    Polygon[{{1.567676, 0.021288, 0.010634},{1.566224, 0.020234, 0.012166},{
      1.564269, 0.022189, 0.012166},{1.565323, 0.023641, 0.010634}}],
    Polygon[{{1.566224, 0.020234, 0.012166},{1.564596, 0.019051, 0.013399},{
      1.563086, 0.020561, 0.013399},{1.564269, 0.022189, 0.012166}}],
    Polygon[{{1.564596, 0.019051, 0.013399},{1.562833, 0.017770, 0.014302},{
      1.561805, 0.018798, 0.014302},{1.563086, 0.020561, 0.013399}}],
    Polygon[{{1.562833, 0.017770, 0.014302},{1.560976, 0.016421, 0.014853},{
      1.560456, 0.016941, 0.014853},{1.561805, 0.018798, 0.014302}}],
    Polygon[{{1.560456, 0.016941, -0.014853},{1.561805, 0.018798, -0.014302},{
      1.560509, 0.019458, -0.014302},{1.559800, 0.017276, -0.014853}}],
    Polygon[{{1.561805, 0.018798, -0.014302},{1.563086, 0.020561, -0.013399},{
      1.561183, 0.021531, -0.013399},{1.560509, 0.019458, -0.014302}}],
    Polygon[{{1.563086, 0.020561, -0.013399},{1.564269, 0.022189, -0.012166},{
      1.561805, 0.023445, -0.012166},{1.561183, 0.021531, -0.013399}}],
    Polygon[{{1.564269, 0.022189, -0.012166},{1.565323, 0.023641, -0.010634},{
      1.562359, 0.025151, -0.010634},{1.561805, 0.023445, -0.012166}}],
    Polygon[{{1.565323, 0.023641, -0.010634},{1.566224, 0.024881, -0.008839},{
      1.562833, 0.026609, -0.008839},{1.562359, 0.025151, -0.010634}}],
    Polygon[{{1.566224, 0.024881, -0.008839},{1.566949, 0.025878, -0.006827},{
      1.563214, 0.027781, -0.006827},{1.562833, 0.026609, -0.008839}}],
    Polygon[{{1.566949, 0.025878, -0.006827},{1.567480, 0.026609, -0.004647},{
      1.563493, 0.028640, -0.004647},{1.563214, 0.027781, -0.006827}}],
    Polygon[{{1.567480, 0.026609, -0.004647},{1.567803, 0.027055, -0.002352},{
      1.563663, 0.029164, -0.002352},{1.563493, 0.028640, -0.004647}}],
    Polygon[{{1.567803, 0.027055, -0.002352},{1.567912, 0.027204, 0.000000},{
      1.563720, 0.029340, 0.000000},{1.563663, 0.029164, -0.002352}}],
    Polygon[{{1.567912, 0.027204, 0.000000},{1.567803, 0.027055, 0.002352},{
      1.563663, 0.029164, 0.002352},{1.563720, 0.029340, 0.000000}}],
    Polygon[{{1.567803, 0.027055, 0.002352},{1.567480, 0.026609, 0.004647},{
      1.563493, 0.028640, 0.004647},{1.563663, 0.029164, 0.002352}}],
    Polygon[{{1.567480, 0.026609, 0.004647},{1.566949, 0.025878, 0.006827},{
      1.563214, 0.027781, 0.006827},{1.563493, 0.028640, 0.004647}}],
    Polygon[{{1.566949, 0.025878, 0.006827},{1.566224, 0.024881, 0.008839},{
      1.562833, 0.026609, 0.008839},{1.563214, 0.027781, 0.006827}}],
    Polygon[{{1.566224, 0.024881, 0.008839},{1.565323, 0.023641, 0.010634},{
      1.562359, 0.025151, 0.010634},{1.562833, 0.026609, 0.008839}}],
    Polygon[{{1.565323, 0.023641, 0.010634},{1.564269, 0.022189, 0.012166},{
      1.561805, 0.023445, 0.012166},{1.562359, 0.025151, 0.010634}}],
    Polygon[{{1.564269, 0.022189, 0.012166},{1.563086, 0.020561, 0.013399},{
      1.561183, 0.021531, 0.013399},{1.561805, 0.023445, 0.012166}}],
    Polygon[{{1.563086, 0.020561, 0.013399},{1.561805, 0.018798, 0.014302},{
      1.560509, 0.019458, 0.014302},{1.561183, 0.021531, 0.013399}}],
    Polygon[{{1.561805, 0.018798, 0.014302},{1.560456, 0.016941, 0.014853},{
      1.559800, 0.017276, 0.014853},{1.560509, 0.019458, 0.014302}}],
    Polygon[{{1.559800, 0.017276, -0.014853},{1.560509, 0.019458, -0.014302},{
      1.559073, 0.019685, -0.014302},{1.559073, 0.017391, -0.014853}}],
    Polygon[{{1.560509, 0.019458, -0.014302},{1.561183, 0.021531, -0.013399},{
      1.559073, 0.021865, -0.013399},{1.559073, 0.019685, -0.014302}}],
    Polygon[{{1.561183, 0.021531, -0.013399},{1.561805, 0.023445, -0.012166},{
      1.559073, 0.023877, -0.012166},{1.559073, 0.021865, -0.013399}}],
    Polygon[{{1.561805, 0.023445, -0.012166},{1.562359, 0.025151, -0.010634},{
      1.559073, 0.025672, -0.010634},{1.559073, 0.023877, -0.012166}}],
    Polygon[{{1.562359, 0.025151, -0.010634},{1.562833, 0.026609, -0.008839},{
      1.559073, 0.027204, -0.008839},{1.559073, 0.025672, -0.010634}}],
    Polygon[{{1.562833, 0.026609, -0.008839},{1.563214, 0.027781, -0.006827},{
      1.559073, 0.028437, -0.006827},{1.559073, 0.027204, -0.008839}}],
    Polygon[{{1.563214, 0.027781, -0.006827},{1.563493, 0.028640, -0.004647},{
      1.559073, 0.029340, -0.004647},{1.559073, 0.028437, -0.006827}}],
    Polygon[{{1.563493, 0.028640, -0.004647},{1.563663, 0.029164, -0.002352},{
      1.559073, 0.029891, -0.002352},{1.559073, 0.029340, -0.004647}}],
    Polygon[{{1.563663, 0.029164, -0.002352},{1.563720, 0.029340, 0.000000},{
      1.559073, 0.030076, 0.000000},{1.559073, 0.029891, -0.002352}}],
    Polygon[{{1.563720, 0.029340, 0.000000},{1.563663, 0.029164, 0.002352},{
      1.559073, 0.029891, 0.002352},{1.559073, 0.030076, 0.000000}}],
    Polygon[{{1.563663, 0.029164, 0.002352},{1.563493, 0.028640, 0.004647},{
      1.559073, 0.029340, 0.004647},{1.559073, 0.029891, 0.002352}}],
    Polygon[{{1.563493, 0.028640, 0.004647},{1.563214, 0.027781, 0.006827},{
      1.559073, 0.028437, 0.006827},{1.559073, 0.029340, 0.004647}}],
    Polygon[{{1.563214, 0.027781, 0.006827},{1.562833, 0.026609, 0.008839},{
      1.559073, 0.027204, 0.008839},{1.559073, 0.028437, 0.006827}}],
    Polygon[{{1.562833, 0.026609, 0.008839},{1.562359, 0.025151, 0.010634},{
      1.559073, 0.025672, 0.010634},{1.559073, 0.027204, 0.008839}}],
    Polygon[{{1.562359, 0.025151, 0.010634},{1.561805, 0.023445, 0.012166},{
      1.559073, 0.023877, 0.012166},{1.559073, 0.025672, 0.010634}}],
    Polygon[{{1.561805, 0.023445, 0.012166},{1.561183, 0.021531, 0.013399},{
      1.559073, 0.021865, 0.013399},{1.559073, 0.023877, 0.012166}}],
    Polygon[{{1.561183, 0.021531, 0.013399},{1.560509, 0.019458, 0.014302},{
      1.559073, 0.019685, 0.014302},{1.559073, 0.021865, 0.013399}}],
    Polygon[{{1.560509, 0.019458, 0.014302},{1.559800, 0.017276, 0.014853},{
      1.559073, 0.017391, 0.014853},{1.559073, 0.019685, 0.014302}}],
    Polygon[{{1.559073, 0.017391, -0.014853},{1.559073, 0.019685, -0.014302},{
      1.557637, 0.019458, -0.014302},{1.558346, 0.017276, -0.014853}}],
    Polygon[{{1.559073, 0.019685, -0.014302},{1.559073, 0.021865, -0.013399},{
      1.556963, 0.021531, -0.013399},{1.557637, 0.019458, -0.014302}}],
    Polygon[{{1.559073, 0.021865, -0.013399},{1.559073, 0.023877, -0.012166},{
      1.556342, 0.023445, -0.012166},{1.556963, 0.021531, -0.013399}}],
    Polygon[{{1.559073, 0.023877, -0.012166},{1.559073, 0.025672, -0.010634},{
      1.555787, 0.025151, -0.010634},{1.556342, 0.023445, -0.012166}}],
    Polygon[{{1.559073, 0.025672, -0.010634},{1.559073, 0.027204, -0.008839},{
      1.555313, 0.026609, -0.008839},{1.555787, 0.025151, -0.010634}}],
    Polygon[{{1.559073, 0.027204, -0.008839},{1.559073, 0.028437, -0.006827},{
      1.554932, 0.027781, -0.006827},{1.555313, 0.026609, -0.008839}}],
    Polygon[{{1.559073, 0.028437, -0.006827},{1.559073, 0.029340, -0.004647},{
      1.554653, 0.028640, -0.004647},{1.554932, 0.027781, -0.006827}}],
    Polygon[{{1.559073, 0.029340, -0.004647},{1.559073, 0.029891, -0.002352},{
      1.554483, 0.029164, -0.002352},{1.554653, 0.028640, -0.004647}}],
    Polygon[{{1.559073, 0.029891, -0.002352},{1.559073, 0.030076, 0.000000},{
      1.554426, 0.029340, 0.000000},{1.554483, 0.029164, -0.002352}}],
    Polygon[{{1.559073, 0.030076, 0.000000},{1.559073, 0.029891, 0.002352},{
      1.554483, 0.029164, 0.002352},{1.554426, 0.029340, 0.000000}}],
    Polygon[{{1.559073, 0.029891, 0.002352},{1.559073, 0.029340, 0.004647},{
      1.554653, 0.028640, 0.004647},{1.554483, 0.029164, 0.002352}}],
    Polygon[{{1.559073, 0.029340, 0.004647},{1.559073, 0.028437, 0.006827},{
      1.554932, 0.027781, 0.006827},{1.554653, 0.028640, 0.004647}}],
    Polygon[{{1.559073, 0.028437, 0.006827},{1.559073, 0.027204, 0.008839},{
      1.555313, 0.026609, 0.008839},{1.554932, 0.027781, 0.006827}}],
    Polygon[{{1.559073, 0.027204, 0.008839},{1.559073, 0.025672, 0.010634},{
      1.555787, 0.025151, 0.010634},{1.555313, 0.026609, 0.008839}}],
    Polygon[{{1.559073, 0.025672, 0.010634},{1.559073, 0.023877, 0.012166},{
      1.556342, 0.023445, 0.012166},{1.555787, 0.025151, 0.010634}}],
    Polygon[{{1.559073, 0.023877, 0.012166},{1.559073, 0.021865, 0.013399},{
      1.556963, 0.021531, 0.013399},{1.556342, 0.023445, 0.012166}}],
    Polygon[{{1.559073, 0.021865, 0.013399},{1.559073, 0.019685, 0.014302},{
      1.557637, 0.019458, 0.014302},{1.556963, 0.021531, 0.013399}}],
    Polygon[{{1.559073, 0.019685, 0.014302},{1.559073, 0.017391, 0.014853},{
      1.558346, 0.017276, 0.014853},{1.557637, 0.019458, 0.014302}}],
    Polygon[{{1.558346, 0.017276, -0.014853},{1.557637, 0.019458, -0.014302},{
      1.556342, 0.018798, -0.014302},{1.557690, 0.016941, -0.014853}}],
    Polygon[{{1.557637, 0.019458, -0.014302},{1.556963, 0.021531, -0.013399},{
      1.555060, 0.020561, -0.013399},{1.556342, 0.018798, -0.014302}}],
    Polygon[{{1.556963, 0.021531, -0.013399},{1.556342, 0.023445, -0.012166},{
      1.553877, 0.022189, -0.012166},{1.555060, 0.020561, -0.013399}}],
    Polygon[{{1.556342, 0.023445, -0.012166},{1.555787, 0.025151, -0.010634},{
      1.552823, 0.023641, -0.010634},{1.553877, 0.022189, -0.012166}}],
    Polygon[{{1.555787, 0.025151, -0.010634},{1.555313, 0.026609, -0.008839},{
      1.551922, 0.024881, -0.008839},{1.552823, 0.023641, -0.010634}}],
    Polygon[{{1.555313, 0.026609, -0.008839},{1.554932, 0.027781, -0.006827},{
      1.551197, 0.025878, -0.006827},{1.551922, 0.024881, -0.008839}}],
    Polygon[{{1.554932, 0.027781, -0.006827},{1.554653, 0.028640, -0.004647},{
      1.550666, 0.026609, -0.004647},{1.551197, 0.025878, -0.006827}}],
    Polygon[{{1.554653, 0.028640, -0.004647},{1.554483, 0.029164, -0.002352},{
      1.550343, 0.027055, -0.002352},{1.550666, 0.026609, -0.004647}}],
    Polygon[{{1.554483, 0.029164, -0.002352},{1.554426, 0.029340, 0.000000},{
      1.550234, 0.027204, 0.000000},{1.550343, 0.027055, -0.002352}}],
    Polygon[{{1.554426, 0.029340, 0.000000},{1.554483, 0.029164, 0.002352},{
      1.550343, 0.027055, 0.002352},{1.550234, 0.027204, 0.000000}}],
    Polygon[{{1.554483, 0.029164, 0.002352},{1.554653, 0.028640, 0.004647},{
      1.550666, 0.026609, 0.004647},{1.550343, 0.027055, 0.002352}}],
    Polygon[{{1.554653, 0.028640, 0.004647},{1.554932, 0.027781, 0.006827},{
      1.551197, 0.025878, 0.006827},{1.550666, 0.026609, 0.004647}}],
    Polygon[{{1.554932, 0.027781, 0.006827},{1.555313, 0.026609, 0.008839},{
      1.551922, 0.024881, 0.008839},{1.551197, 0.025878, 0.006827}}],
    Polygon[{{1.555313, 0.026609, 0.008839},{1.555787, 0.025151, 0.010634},{
      1.552823, 0.023641, 0.010634},{1.551922, 0.024881, 0.008839}}],
    Polygon[{{1.555787, 0.025151, 0.010634},{1.556342, 0.023445, 0.012166},{
      1.553877, 0.022189, 0.012166},{1.552823, 0.023641, 0.010634}}],
    Polygon[{{1.556342, 0.023445, 0.012166},{1.556963, 0.021531, 0.013399},{
      1.555060, 0.020561, 0.013399},{1.553877, 0.022189, 0.012166}}],
    Polygon[{{1.556963, 0.021531, 0.013399},{1.557637, 0.019458, 0.014302},{
      1.556342, 0.018798, 0.014302},{1.555060, 0.020561, 0.013399}}],
    Polygon[{{1.557637, 0.019458, 0.014302},{1.558346, 0.017276, 0.014853},{
      1.557690, 0.016941, 0.014853},{1.556342, 0.018798, 0.014302}}],
    Polygon[{{1.557690, 0.016941, -0.014853},{1.556342, 0.018798, -0.014302},{
      1.555313, 0.017770, -0.014302},{1.557170, 0.016421, -0.014853}}],
    Polygon[{{1.556342, 0.018798, -0.014302},{1.555060, 0.020561, -0.013399},{
      1.553550, 0.019051, -0.013399},{1.555313, 0.017770, -0.014302}}],
    Polygon[{{1.555060, 0.020561, -0.013399},{1.553877, 0.022189, -0.012166},{
      1.551922, 0.020234, -0.012166},{1.553550, 0.019051, -0.013399}}],
    Polygon[{{1.553877, 0.022189, -0.012166},{1.552823, 0.023641, -0.010634},{
      1.550470, 0.021288, -0.010634},{1.551922, 0.020234, -0.012166}}],
    Polygon[{{1.552823, 0.023641, -0.010634},{1.551922, 0.024881, -0.008839},{
      1.549230, 0.022189, -0.008839},{1.550470, 0.021288, -0.010634}}],
    Polygon[{{1.551922, 0.024881, -0.008839},{1.551197, 0.025878, -0.006827},{
      1.548233, 0.022914, -0.006827},{1.549230, 0.022189, -0.008839}}],
    Polygon[{{1.551197, 0.025878, -0.006827},{1.550666, 0.026609, -0.004647},{
      1.547502, 0.023445, -0.004647},{1.548233, 0.022914, -0.006827}}],
    Polygon[{{1.550666, 0.026609, -0.004647},{1.550343, 0.027055, -0.002352},{
      1.547057, 0.023769, -0.002352},{1.547502, 0.023445, -0.004647}}],
    Polygon[{{1.550343, 0.027055, -0.002352},{1.550234, 0.027204, 0.000000},{
      1.546907, 0.023877, 0.000000},{1.547057, 0.023769, -0.002352}}],
    Polygon[{{1.550234, 0.027204, 0.000000},{1.550343, 0.027055, 0.002352},{
      1.547057, 0.023769, 0.002352},{1.546907, 0.023877, 0.000000}}],
    Polygon[{{1.550343, 0.027055, 0.002352},{1.550666, 0.026609, 0.004647},{
      1.547502, 0.023445, 0.004647},{1.547057, 0.023769, 0.002352}}],
    Polygon[{{1.550666, 0.026609, 0.004647},{1.551197, 0.025878, 0.006827},{
      1.548233, 0.022914, 0.006827},{1.547502, 0.023445, 0.004647}}],
    Polygon[{{1.551197, 0.025878, 0.006827},{1.551922, 0.024881, 0.008839},{
      1.549230, 0.022189, 0.008839},{1.548233, 0.022914, 0.006827}}],
    Polygon[{{1.551922, 0.024881, 0.008839},{1.552823, 0.023641, 0.010634},{
      1.550470, 0.021288, 0.010634},{1.549230, 0.022189, 0.008839}}],
    Polygon[{{1.552823, 0.023641, 0.010634},{1.553877, 0.022189, 0.012166},{
      1.551922, 0.020234, 0.012166},{1.550470, 0.021288, 0.010634}}],
    Polygon[{{1.553877, 0.022189, 0.012166},{1.555060, 0.020561, 0.013399},{
      1.553550, 0.019051, 0.013399},{1.551922, 0.020234, 0.012166}}],
    Polygon[{{1.555060, 0.020561, 0.013399},{1.556342, 0.018798, 0.014302},{
      1.555313, 0.017770, 0.014302},{1.553550, 0.019051, 0.013399}}],
    Polygon[{{1.556342, 0.018798, 0.014302},{1.557690, 0.016941, 0.014853},{
      1.557170, 0.016421, 0.014853},{1.555313, 0.017770, 0.014302}}],
    Polygon[{{1.557170, 0.016421, -0.014853},{1.555313, 0.017770, -0.014302},{
      1.554653, 0.016474, -0.014302},{1.556836, 0.015765, -0.014853}}],
    Polygon[{{1.555313, 0.017770, -0.014302},{1.553550, 0.019051, -0.013399},{
      1.552580, 0.017148, -0.013399},{1.554653, 0.016474, -0.014302}}],
    Polygon[{{1.553550, 0.019051, -0.013399},{1.551922, 0.020234, -0.012166},{
      1.550666, 0.017770, -0.012166},{1.552580, 0.017148, -0.013399}}],
    Polygon[{{1.551922, 0.020234, -0.012166},{1.550470, 0.021288, -0.010634},{
      1.548960, 0.018324, -0.010634},{1.550666, 0.017770, -0.012166}}],
    Polygon[{{1.550470, 0.021288, -0.010634},{1.549230, 0.022189, -0.008839},{
      1.547502, 0.018798, -0.008839},{1.548960, 0.018324, -0.010634}}],
    Polygon[{{1.549230, 0.022189, -0.008839},{1.548233, 0.022914, -0.006827},{
      1.546330, 0.019179, -0.006827},{1.547502, 0.018798, -0.008839}}],
    Polygon[{{1.548233, 0.022914, -0.006827},{1.547502, 0.023445, -0.004647},{
      1.545471, 0.019458, -0.004647},{1.546330, 0.019179, -0.006827}}],
    Polygon[{{1.547502, 0.023445, -0.004647},{1.547057, 0.023769, -0.002352},{
      1.544947, 0.019628, -0.002352},{1.545471, 0.019458, -0.004647}}],
    Polygon[{{1.547057, 0.023769, -0.002352},{1.546907, 0.023877, 0.000000},{
      1.544771, 0.019685, 0.000000},{1.544947, 0.019628, -0.002352}}],
    Polygon[{{1.546907, 0.023877, 0.000000},{1.547057, 0.023769, 0.002352},{
      1.544947, 0.019628, 0.002352},{1.544771, 0.019685, 0.000000}}],
    Polygon[{{1.547057, 0.023769, 0.002352},{1.547502, 0.023445, 0.004647},{
      1.545471, 0.019458, 0.004647},{1.544947, 0.019628, 0.002352}}],
    Polygon[{{1.547502, 0.023445, 0.004647},{1.548233, 0.022914, 0.006827},{
      1.546330, 0.019179, 0.006827},{1.545471, 0.019458, 0.004647}}],
    Polygon[{{1.548233, 0.022914, 0.006827},{1.549230, 0.022189, 0.008839},{
      1.547502, 0.018798, 0.008839},{1.546330, 0.019179, 0.006827}}],
    Polygon[{{1.549230, 0.022189, 0.008839},{1.550470, 0.021288, 0.010634},{
      1.548960, 0.018324, 0.010634},{1.547502, 0.018798, 0.008839}}],
    Polygon[{{1.550470, 0.021288, 0.010634},{1.551922, 0.020234, 0.012166},{
      1.550666, 0.017770, 0.012166},{1.548960, 0.018324, 0.010634}}],
    Polygon[{{1.551922, 0.020234, 0.012166},{1.553550, 0.019051, 0.013399},{
      1.552580, 0.017148, 0.013399},{1.550666, 0.017770, 0.012166}}],
    Polygon[{{1.553550, 0.019051, 0.013399},{1.555313, 0.017770, 0.014302},{
      1.554653, 0.016474, 0.014302},{1.552580, 0.017148, 0.013399}}],
    Polygon[{{1.555313, 0.017770, 0.014302},{1.557170, 0.016421, 0.014853},{
      1.556836, 0.015765, 0.014853},{1.554653, 0.016474, 0.014302}}],
    Polygon[{{1.556836, 0.015765, -0.014853},{1.554653, 0.016474, -0.014302},{
      1.554426, 0.015038, -0.014302},{1.556720, 0.015038, -0.014853}}],
    Polygon[{{1.554653, 0.016474, -0.014302},{1.552580, 0.017148, -0.013399},{
      1.552246, 0.015038, -0.013399},{1.554426, 0.015038, -0.014302}}],
    Polygon[{{1.552580, 0.017148, -0.013399},{1.550666, 0.017770, -0.012166},{
      1.550234, 0.015038, -0.012166},{1.552246, 0.015038, -0.013399}}],
    Polygon[{{1.550666, 0.017770, -0.012166},{1.548960, 0.018324, -0.010634},{
      1.548439, 0.015038, -0.010634},{1.550234, 0.015038, -0.012166}}],
    Polygon[{{1.548960, 0.018324, -0.010634},{1.547502, 0.018798, -0.008839},{
      1.546907, 0.015038, -0.008839},{1.548439, 0.015038, -0.010634}}],
    Polygon[{{1.547502, 0.018798, -0.008839},{1.546330, 0.019179, -0.006827},{
      1.545674, 0.015038, -0.006827},{1.546907, 0.015038, -0.008839}}],
    Polygon[{{1.546330, 0.019179, -0.006827},{1.545471, 0.019458, -0.004647},{
      1.544771, 0.015038, -0.004647},{1.545674, 0.015038, -0.006827}}],
    Polygon[{{1.545471, 0.019458, -0.004647},{1.544947, 0.019628, -0.002352},{
      1.544220, 0.015038, -0.002352},{1.544771, 0.015038, -0.004647}}],
    Polygon[{{1.544947, 0.019628, -0.002352},{1.544771, 0.019685, 0.000000},{
      1.544035, 0.015038, 0.000000},{1.544220, 0.015038, -0.002352}}],
    Polygon[{{1.544771, 0.019685, 0.000000},{1.544947, 0.019628, 0.002352},{
      1.544220, 0.015038, 0.002352},{1.544035, 0.015038, 0.000000}}],
    Polygon[{{1.544947, 0.019628, 0.002352},{1.545471, 0.019458, 0.004647},{
      1.544771, 0.015038, 0.004647},{1.544220, 0.015038, 0.002352}}],
    Polygon[{{1.545471, 0.019458, 0.004647},{1.546330, 0.019179, 0.006827},{
      1.545674, 0.015038, 0.006827},{1.544771, 0.015038, 0.004647}}],
    Polygon[{{1.546330, 0.019179, 0.006827},{1.547502, 0.018798, 0.008839},{
      1.546907, 0.015038, 0.008839},{1.545674, 0.015038, 0.006827}}],
    Polygon[{{1.547502, 0.018798, 0.008839},{1.548960, 0.018324, 0.010634},{
      1.548439, 0.015038, 0.010634},{1.546907, 0.015038, 0.008839}}],
    Polygon[{{1.548960, 0.018324, 0.010634},{1.550666, 0.017770, 0.012166},{
      1.550234, 0.015038, 0.012166},{1.548439, 0.015038, 0.010634}}],
    Polygon[{{1.550666, 0.017770, 0.012166},{1.552580, 0.017148, 0.013399},{
      1.552246, 0.015038, 0.013399},{1.550234, 0.015038, 0.012166}}],
    Polygon[{{1.552580, 0.017148, 0.013399},{1.554653, 0.016474, 0.014302},{
      1.554426, 0.015038, 0.014302},{1.552246, 0.015038, 0.013399}}],
    Polygon[{{1.554653, 0.016474, 0.014302},{1.556836, 0.015765, 0.014853},{
      1.556720, 0.015038, 0.014853},{1.554426, 0.015038, 0.014302}}],
    Polygon[{{1.556720, 0.015038, -0.014853},{1.554426, 0.015038, -0.014302},{
      1.554653, 0.013602, -0.014302},{1.556836, 0.014311, -0.014853}}],
    Polygon[{{1.554426, 0.015038, -0.014302},{1.552246, 0.015038, -0.013399},{
      1.552580, 0.012928, -0.013399},{1.554653, 0.013602, -0.014302}}],
    Polygon[{{1.552246, 0.015038, -0.013399},{1.550234, 0.015038, -0.012166},{
      1.550666, 0.012307, -0.012166},{1.552580, 0.012928, -0.013399}}],
    Polygon[{{1.550234, 0.015038, -0.012166},{1.548439, 0.015038, -0.010634},{
      1.548960, 0.011752, -0.010634},{1.550666, 0.012307, -0.012166}}],
    Polygon[{{1.548439, 0.015038, -0.010634},{1.546907, 0.015038, -0.008839},{
      1.547502, 0.011279, -0.008839},{1.548960, 0.011752, -0.010634}}],
    Polygon[{{1.546907, 0.015038, -0.008839},{1.545674, 0.015038, -0.006827},{
      1.546330, 0.010898, -0.006827},{1.547502, 0.011279, -0.008839}}],
    Polygon[{{1.545674, 0.015038, -0.006827},{1.544771, 0.015038, -0.004647},{
      1.545471, 0.010619, -0.004647},{1.546330, 0.010898, -0.006827}}],
    Polygon[{{1.544771, 0.015038, -0.004647},{1.544220, 0.015038, -0.002352},{
      1.544947, 0.010448, -0.002352},{1.545471, 0.010619, -0.004647}}],
    Polygon[{{1.544220, 0.015038, -0.002352},{1.544035, 0.015038, 0.000000},{
      1.544771, 0.010391, 0.000000},{1.544947, 0.010448, -0.002352}}],
    Polygon[{{1.544035, 0.015038, 0.000000},{1.544220, 0.015038, 0.002352},{
      1.544947, 0.010448, 0.002352},{1.544771, 0.010391, 0.000000}}],
    Polygon[{{1.544220, 0.015038, 0.002352},{1.544771, 0.015038, 0.004647},{
      1.545471, 0.010619, 0.004647},{1.544947, 0.010448, 0.002352}}],
    Polygon[{{1.544771, 0.015038, 0.004647},{1.545674, 0.015038, 0.006827},{
      1.546330, 0.010898, 0.006827},{1.545471, 0.010619, 0.004647}}],
    Polygon[{{1.545674, 0.015038, 0.006827},{1.546907, 0.015038, 0.008839},{
      1.547502, 0.011279, 0.008839},{1.546330, 0.010898, 0.006827}}],
    Polygon[{{1.546907, 0.015038, 0.008839},{1.548439, 0.015038, 0.010634},{
      1.548960, 0.011752, 0.010634},{1.547502, 0.011279, 0.008839}}],
    Polygon[{{1.548439, 0.015038, 0.010634},{1.550234, 0.015038, 0.012166},{
      1.550666, 0.012307, 0.012166},{1.548960, 0.011752, 0.010634}}],
    Polygon[{{1.550234, 0.015038, 0.012166},{1.552246, 0.015038, 0.013399},{
      1.552580, 0.012928, 0.013399},{1.550666, 0.012307, 0.012166}}],
    Polygon[{{1.552246, 0.015038, 0.013399},{1.554426, 0.015038, 0.014302},{
      1.554653, 0.013602, 0.014302},{1.552580, 0.012928, 0.013399}}],
    Polygon[{{1.554426, 0.015038, 0.014302},{1.556720, 0.015038, 0.014853},{
      1.556836, 0.014311, 0.014853},{1.554653, 0.013602, 0.014302}}],
    Polygon[{{1.556836, 0.014311, -0.014853},{1.554653, 0.013602, -0.014302},{
      1.555313, 0.012307, -0.014302},{1.557170, 0.013655, -0.014853}}],
    Polygon[{{1.554653, 0.013602, -0.014302},{1.552580, 0.012928, -0.013399},{
      1.553550, 0.011025, -0.013399},{1.555313, 0.012307, -0.014302}}],
    Polygon[{{1.552580, 0.012928, -0.013399},{1.550666, 0.012307, -0.012166},{
      1.551922, 0.009843, -0.012166},{1.553550, 0.011025, -0.013399}}],
    Polygon[{{1.550666, 0.012307, -0.012166},{1.548960, 0.011752, -0.010634},{
      1.550470, 0.008788, -0.010634},{1.551922, 0.009843, -0.012166}}],
    Polygon[{{1.548960, 0.011752, -0.010634},{1.547502, 0.011279, -0.008839},{
      1.549230, 0.007887, -0.008839},{1.550470, 0.008788, -0.010634}}],
    Polygon[{{1.547502, 0.011279, -0.008839},{1.546330, 0.010898, -0.006827},{
      1.548233, 0.007162, -0.006827},{1.549230, 0.007887, -0.008839}}],
    Polygon[{{1.546330, 0.010898, -0.006827},{1.545471, 0.010619, -0.004647},{
      1.547502, 0.006632, -0.004647},{1.548233, 0.007162, -0.006827}}],
    Polygon[{{1.545471, 0.010619, -0.004647},{1.544947, 0.010448, -0.002352},{
      1.547057, 0.006308, -0.002352},{1.547502, 0.006632, -0.004647}}],
    Polygon[{{1.544947, 0.010448, -0.002352},{1.544771, 0.010391, 0.000000},{
      1.546907, 0.006199, 0.000000},{1.547057, 0.006308, -0.002352}}],
    Polygon[{{1.544771, 0.010391, 0.000000},{1.544947, 0.010448, 0.002352},{
      1.547057, 0.006308, 0.002352},{1.546907, 0.006199, 0.000000}}],
    Polygon[{{1.544947, 0.010448, 0.002352},{1.545471, 0.010619, 0.004647},{
      1.547502, 0.006632, 0.004647},{1.547057, 0.006308, 0.002352}}],
    Polygon[{{1.545471, 0.010619, 0.004647},{1.546330, 0.010898, 0.006827},{
      1.548233, 0.007162, 0.006827},{1.547502, 0.006632, 0.004647}}],
    Polygon[{{1.546330, 0.010898, 0.006827},{1.547502, 0.011279, 0.008839},{
      1.549230, 0.007887, 0.008839},{1.548233, 0.007162, 0.006827}}],
    Polygon[{{1.547502, 0.011279, 0.008839},{1.548960, 0.011752, 0.010634},{
      1.550470, 0.008788, 0.010634},{1.549230, 0.007887, 0.008839}}],
    Polygon[{{1.548960, 0.011752, 0.010634},{1.550666, 0.012307, 0.012166},{
      1.551922, 0.009843, 0.012166},{1.550470, 0.008788, 0.010634}}],
    Polygon[{{1.550666, 0.012307, 0.012166},{1.552580, 0.012928, 0.013399},{
      1.553550, 0.011025, 0.013399},{1.551922, 0.009843, 0.012166}}],
    Polygon[{{1.552580, 0.012928, 0.013399},{1.554653, 0.013602, 0.014302},{
      1.555313, 0.012307, 0.014302},{1.553550, 0.011025, 0.013399}}],
    Polygon[{{1.554653, 0.013602, 0.014302},{1.556836, 0.014311, 0.014853},{
      1.557170, 0.013655, 0.014853},{1.555313, 0.012307, 0.014302}}],
    Polygon[{{1.557170, 0.013655, -0.014853},{1.555313, 0.012307, -0.014302},{
      1.556342, 0.011279, -0.014302},{1.557690, 0.013135, -0.014853}}],
    Polygon[{{1.555313, 0.012307, -0.014302},{1.553550, 0.011025, -0.013399},{
      1.555060, 0.009515, -0.013399},{1.556342, 0.011279, -0.014302}}],
    Polygon[{{1.553550, 0.011025, -0.013399},{1.551922, 0.009843, -0.012166},{
      1.553877, 0.007887, -0.012166},{1.555060, 0.009515, -0.013399}}],
    Polygon[{{1.551922, 0.009843, -0.012166},{1.550470, 0.008788, -0.010634},{
      1.552823, 0.006435, -0.010634},{1.553877, 0.007887, -0.012166}}],
    Polygon[{{1.550470, 0.008788, -0.010634},{1.549230, 0.007887, -0.008839},{
      1.551922, 0.005196, -0.008839},{1.552823, 0.006435, -0.010634}}],
    Polygon[{{1.549230, 0.007887, -0.008839},{1.548233, 0.007162, -0.006827},{
      1.551197, 0.004198, -0.006827},{1.551922, 0.005196, -0.008839}}],
    Polygon[{{1.548233, 0.007162, -0.006827},{1.547502, 0.006632, -0.004647},{
      1.550666, 0.003467, -0.004647},{1.551197, 0.004198, -0.006827}}],
    Polygon[{{1.547502, 0.006632, -0.004647},{1.547057, 0.006308, -0.002352},{
      1.550343, 0.003022, -0.002352},{1.550666, 0.003467, -0.004647}}],
    Polygon[{{1.547057, 0.006308, -0.002352},{1.546907, 0.006199, 0.000000},{
      1.550234, 0.002872, 0.000000},{1.550343, 0.003022, -0.002352}}],
    Polygon[{{1.546907, 0.006199, 0.000000},{1.547057, 0.006308, 0.002352},{
      1.550343, 0.003022, 0.002352},{1.550234, 0.002872, 0.000000}}],
    Polygon[{{1.547057, 0.006308, 0.002352},{1.547502, 0.006632, 0.004647},{
      1.550666, 0.003467, 0.004647},{1.550343, 0.003022, 0.002352}}],
    Polygon[{{1.547502, 0.006632, 0.004647},{1.548233, 0.007162, 0.006827},{
      1.551197, 0.004198, 0.006827},{1.550666, 0.003467, 0.004647}}],
    Polygon[{{1.548233, 0.007162, 0.006827},{1.549230, 0.007887, 0.008839},{
      1.551922, 0.005196, 0.008839},{1.551197, 0.004198, 0.006827}}],
    Polygon[{{1.549230, 0.007887, 0.008839},{1.550470, 0.008788, 0.010634},{
      1.552823, 0.006435, 0.010634},{1.551922, 0.005196, 0.008839}}],
    Polygon[{{1.550470, 0.008788, 0.010634},{1.551922, 0.009843, 0.012166},{
      1.553877, 0.007887, 0.012166},{1.552823, 0.006435, 0.010634}}],
    Polygon[{{1.551922, 0.009843, 0.012166},{1.553550, 0.011025, 0.013399},{
      1.555060, 0.009515, 0.013399},{1.553877, 0.007887, 0.012166}}],
    Polygon[{{1.553550, 0.011025, 0.013399},{1.555313, 0.012307, 0.014302},{
      1.556342, 0.011279, 0.014302},{1.555060, 0.009515, 0.013399}}],
    Polygon[{{1.555313, 0.012307, 0.014302},{1.557170, 0.013655, 0.014853},{
      1.557690, 0.013135, 0.014853},{1.556342, 0.011279, 0.014302}}],
    Polygon[{{1.557690, 0.013135, -0.014853},{1.556342, 0.011279, -0.014302},{
      1.557637, 0.010619, -0.014302},{1.558346, 0.012801, -0.014853}}],
    Polygon[{{1.556342, 0.011279, -0.014302},{1.555060, 0.009515, -0.013399},{
      1.556963, 0.008545, -0.013399},{1.557637, 0.010619, -0.014302}}],
    Polygon[{{1.555060, 0.009515, -0.013399},{1.553877, 0.007887, -0.012166},{
      1.556342, 0.006632, -0.012166},{1.556963, 0.008545, -0.013399}}],
    Polygon[{{1.553877, 0.007887, -0.012166},{1.552823, 0.006435, -0.010634},{
      1.555787, 0.004925, -0.010634},{1.556342, 0.006632, -0.012166}}],
    Polygon[{{1.552823, 0.006435, -0.010634},{1.551922, 0.005196, -0.008839},{
      1.555313, 0.003467, -0.008839},{1.555787, 0.004925, -0.010634}}],
    Polygon[{{1.551922, 0.005196, -0.008839},{1.551197, 0.004198, -0.006827},{
      1.554932, 0.002295, -0.006827},{1.555313, 0.003467, -0.008839}}],
    Polygon[{{1.551197, 0.004198, -0.006827},{1.550666, 0.003467, -0.004647},{
      1.554653, 0.001436, -0.004647},{1.554932, 0.002295, -0.006827}}],
    Polygon[{{1.550666, 0.003467, -0.004647},{1.550343, 0.003022, -0.002352},{
      1.554483, 0.000912, -0.002352},{1.554653, 0.001436, -0.004647}}],
    Polygon[{{1.550343, 0.003022, -0.002352},{1.550234, 0.002872, 0.000000},{
      1.554426, 0.000736, 0.000000},{1.554483, 0.000912, -0.002352}}],
    Polygon[{{1.550234, 0.002872, 0.000000},{1.550343, 0.003022, 0.002352},{
      1.554483, 0.000912, 0.002352},{1.554426, 0.000736, 0.000000}}],
    Polygon[{{1.550343, 0.003022, 0.002352},{1.550666, 0.003467, 0.004647},{
      1.554653, 0.001436, 0.004647},{1.554483, 0.000912, 0.002352}}],
    Polygon[{{1.550666, 0.003467, 0.004647},{1.551197, 0.004198, 0.006827},{
      1.554932, 0.002295, 0.006827},{1.554653, 0.001436, 0.004647}}],
    Polygon[{{1.551197, 0.004198, 0.006827},{1.551922, 0.005196, 0.008839},{
      1.555313, 0.003467, 0.008839},{1.554932, 0.002295, 0.006827}}],
    Polygon[{{1.551922, 0.005196, 0.008839},{1.552823, 0.006435, 0.010634},{
      1.555787, 0.004925, 0.010634},{1.555313, 0.003467, 0.008839}}],
    Polygon[{{1.552823, 0.006435, 0.010634},{1.553877, 0.007887, 0.012166},{
      1.556342, 0.006632, 0.012166},{1.555787, 0.004925, 0.010634}}],
    Polygon[{{1.553877, 0.007887, 0.012166},{1.555060, 0.009515, 0.013399},{
      1.556963, 0.008545, 0.013399},{1.556342, 0.006632, 0.012166}}],
    Polygon[{{1.555060, 0.009515, 0.013399},{1.556342, 0.011279, 0.014302},{
      1.557637, 0.010619, 0.014302},{1.556963, 0.008545, 0.013399}}],
    Polygon[{{1.556342, 0.011279, 0.014302},{1.557690, 0.013135, 0.014853},{
      1.558346, 0.012801, 0.014853},{1.557637, 0.010619, 0.014302}}],
    Polygon[{{1.558346, 0.012801, -0.014853},{1.557637, 0.010619, -0.014302},{
      1.559073, 0.010391, -0.014302},{1.559073, 0.012686, -0.014853}}],
    Polygon[{{1.557637, 0.010619, -0.014302},{1.556963, 0.008545, -0.013399},{
      1.559073, 0.008211, -0.013399},{1.559073, 0.010391, -0.014302}}],
    Polygon[{{1.556963, 0.008545, -0.013399},{1.556342, 0.006632, -0.012166},{
      1.559073, 0.006199, -0.012166},{1.559073, 0.008211, -0.013399}}],
    Polygon[{{1.556342, 0.006632, -0.012166},{1.555787, 0.004925, -0.010634},{
      1.559073, 0.004405, -0.010634},{1.559073, 0.006199, -0.012166}}],
    Polygon[{{1.555787, 0.004925, -0.010634},{1.555313, 0.003467, -0.008839},{
      1.559073, 0.002872, -0.008839},{1.559073, 0.004405, -0.010634}}],
    Polygon[{{1.555313, 0.003467, -0.008839},{1.554932, 0.002295, -0.006827},{
      1.559073, 0.001639, -0.006827},{1.559073, 0.002872, -0.008839}}],
    Polygon[{{1.554932, 0.002295, -0.006827},{1.554653, 0.001436, -0.004647},{
      1.559073, 0.000736, -0.004647},{1.559073, 0.001639, -0.006827}}],
    Polygon[{{1.554653, 0.001436, -0.004647},{1.554483, 0.000912, -0.002352},{
      1.559073, 0.000185, -0.002352},{1.559073, 0.000736, -0.004647}}],
    Polygon[{{1.554483, 0.000912, -0.002352},{1.554426, 0.000736, 0.000000},{
      1.559073, 0.000000, 0.000000},{1.559073, 0.000185, -0.002352}}],
    Polygon[{{1.554426, 0.000736, 0.000000},{1.554483, 0.000912, 0.002352},{
      1.559073, 0.000185, 0.002352},{1.559073, 0.000000, 0.000000}}],
    Polygon[{{1.554483, 0.000912, 0.002352},{1.554653, 0.001436, 0.004647},{
      1.559073, 0.000736, 0.004647},{1.559073, 0.000185, 0.002352}}],
    Polygon[{{1.554653, 0.001436, 0.004647},{1.554932, 0.002295, 0.006827},{
      1.559073, 0.001639, 0.006827},{1.559073, 0.000736, 0.004647}}],
    Polygon[{{1.554932, 0.002295, 0.006827},{1.555313, 0.003467, 0.008839},{
      1.559073, 0.002872, 0.008839},{1.559073, 0.001639, 0.006827}}],
    Polygon[{{1.555313, 0.003467, 0.008839},{1.555787, 0.004925, 0.010634},{
      1.559073, 0.004405, 0.010634},{1.559073, 0.002872, 0.008839}}],
    Polygon[{{1.555787, 0.004925, 0.010634},{1.556342, 0.006632, 0.012166},{
      1.559073, 0.006199, 0.012166},{1.559073, 0.004405, 0.010634}}],
    Polygon[{{1.556342, 0.006632, 0.012166},{1.556963, 0.008545, 0.013399},{
      1.559073, 0.008211, 0.013399},{1.559073, 0.006199, 0.012166}}],
    Polygon[{{1.556963, 0.008545, 0.013399},{1.557637, 0.010619, 0.014302},{
      1.559073, 0.010391, 0.014302},{1.559073, 0.008211, 0.013399}}],
    Polygon[{{1.557637, 0.010619, 0.014302},{1.558346, 0.012801, 0.014853},{
      1.559073, 0.012686, 0.014853},{1.559073, 0.010391, 0.014302}}],
    Polygon[{{1.559073, 0.012686, -0.014853},{1.559073, 0.010391, -0.014302},{
      1.560509, 0.010619, -0.014302},{1.559800, 0.012801, -0.014853}}],
    Polygon[{{1.559073, 0.010391, -0.014302},{1.559073, 0.008211, -0.013399},{
      1.561183, 0.008545, -0.013399},{1.560509, 0.010619, -0.014302}}],
    Polygon[{{1.559073, 0.008211, -0.013399},{1.559073, 0.006199, -0.012166},{
      1.561805, 0.006632, -0.012166},{1.561183, 0.008545, -0.013399}}],
    Polygon[{{1.559073, 0.006199, -0.012166},{1.559073, 0.004405, -0.010634},{
      1.562359, 0.004925, -0.010634},{1.561805, 0.006632, -0.012166}}],
    Polygon[{{1.559073, 0.004405, -0.010634},{1.559073, 0.002872, -0.008839},{
      1.562833, 0.003467, -0.008839},{1.562359, 0.004925, -0.010634}}],
    Polygon[{{1.559073, 0.002872, -0.008839},{1.559073, 0.001639, -0.006827},{
      1.563214, 0.002295, -0.006827},{1.562833, 0.003467, -0.008839}}],
    Polygon[{{1.559073, 0.001639, -0.006827},{1.559073, 0.000736, -0.004647},{
      1.563493, 0.001436, -0.004647},{1.563214, 0.002295, -0.006827}}],
    Polygon[{{1.559073, 0.000736, -0.004647},{1.559073, 0.000185, -0.002352},{
      1.563663, 0.000912, -0.002352},{1.563493, 0.001436, -0.004647}}],
    Polygon[{{1.559073, 0.000185, -0.002352},{1.559073, 0.000000, 0.000000},{
      1.563720, 0.000736, 0.000000},{1.563663, 0.000912, -0.002352}}],
    Polygon[{{1.559073, 0.000000, 0.000000},{1.559073, 0.000185, 0.002352},{
      1.563663, 0.000912, 0.002352},{1.563720, 0.000736, 0.000000}}],
    Polygon[{{1.559073, 0.000185, 0.002352},{1.559073, 0.000736, 0.004647},{
      1.563493, 0.001436, 0.004647},{1.563663, 0.000912, 0.002352}}],
    Polygon[{{1.559073, 0.000736, 0.004647},{1.559073, 0.001639, 0.006827},{
      1.563214, 0.002295, 0.006827},{1.563493, 0.001436, 0.004647}}],
    Polygon[{{1.559073, 0.001639, 0.006827},{1.559073, 0.002872, 0.008839},{
      1.562833, 0.003467, 0.008839},{1.563214, 0.002295, 0.006827}}],
    Polygon[{{1.559073, 0.002872, 0.008839},{1.559073, 0.004405, 0.010634},{
      1.562359, 0.004925, 0.010634},{1.562833, 0.003467, 0.008839}}],
    Polygon[{{1.559073, 0.004405, 0.010634},{1.559073, 0.006199, 0.012166},{
      1.561805, 0.006632, 0.012166},{1.562359, 0.004925, 0.010634}}],
    Polygon[{{1.559073, 0.006199, 0.012166},{1.559073, 0.008211, 0.013399},{
      1.561183, 0.008545, 0.013399},{1.561805, 0.006632, 0.012166}}],
    Polygon[{{1.559073, 0.008211, 0.013399},{1.559073, 0.010391, 0.014302},{
      1.560509, 0.010619, 0.014302},{1.561183, 0.008545, 0.013399}}],
    Polygon[{{1.559073, 0.010391, 0.014302},{1.559073, 0.012686, 0.014853},{
      1.559800, 0.012801, 0.014853},{1.560509, 0.010619, 0.014302}}],
    Polygon[{{1.559800, 0.012801, -0.014853},{1.560509, 0.010619, -0.014302},{
      1.561805, 0.011279, -0.014302},{1.560456, 0.013135, -0.014853}}],
    Polygon[{{1.560509, 0.010619, -0.014302},{1.561183, 0.008545, -0.013399},{
      1.563086, 0.009515, -0.013399},{1.561805, 0.011279, -0.014302}}],
    Polygon[{{1.561183, 0.008545, -0.013399},{1.561805, 0.006632, -0.012166},{
      1.564269, 0.007887, -0.012166},{1.563086, 0.009515, -0.013399}}],
    Polygon[{{1.561805, 0.006632, -0.012166},{1.562359, 0.004925, -0.010634},{
      1.565323, 0.006435, -0.010634},{1.564269, 0.007887, -0.012166}}],
    Polygon[{{1.562359, 0.004925, -0.010634},{1.562833, 0.003467, -0.008839},{
      1.566224, 0.005196, -0.008839},{1.565323, 0.006435, -0.010634}}],
    Polygon[{{1.562833, 0.003467, -0.008839},{1.563214, 0.002295, -0.006827},{
      1.566949, 0.004198, -0.006827},{1.566224, 0.005196, -0.008839}}],
    Polygon[{{1.563214, 0.002295, -0.006827},{1.563493, 0.001436, -0.004647},{
      1.567480, 0.003467, -0.004647},{1.566949, 0.004198, -0.006827}}],
    Polygon[{{1.563493, 0.001436, -0.004647},{1.563663, 0.000912, -0.002352},{
      1.567803, 0.003022, -0.002352},{1.567480, 0.003467, -0.004647}}],
    Polygon[{{1.563663, 0.000912, -0.002352},{1.563720, 0.000736, 0.000000},{
      1.567912, 0.002872, 0.000000},{1.567803, 0.003022, -0.002352}}],
    Polygon[{{1.563720, 0.000736, 0.000000},{1.563663, 0.000912, 0.002352},{
      1.567803, 0.003022, 0.002352},{1.567912, 0.002872, 0.000000}}],
    Polygon[{{1.563663, 0.000912, 0.002352},{1.563493, 0.001436, 0.004647},{
      1.567480, 0.003467, 0.004647},{1.567803, 0.003022, 0.002352}}],
    Polygon[{{1.563493, 0.001436, 0.004647},{1.563214, 0.002295, 0.006827},{
      1.566949, 0.004198, 0.006827},{1.567480, 0.003467, 0.004647}}],
    Polygon[{{1.563214, 0.002295, 0.006827},{1.562833, 0.003467, 0.008839},{
      1.566224, 0.005196, 0.008839},{1.566949, 0.004198, 0.006827}}],
    Polygon[{{1.562833, 0.003467, 0.008839},{1.562359, 0.004925, 0.010634},{
      1.565323, 0.006435, 0.010634},{1.566224, 0.005196, 0.008839}}],
    Polygon[{{1.562359, 0.004925, 0.010634},{1.561805, 0.006632, 0.012166},{
      1.564269, 0.007887, 0.012166},{1.565323, 0.006435, 0.010634}}],
    Polygon[{{1.561805, 0.006632, 0.012166},{1.561183, 0.008545, 0.013399},{
      1.563086, 0.009515, 0.013399},{1.564269, 0.007887, 0.012166}}],
    Polygon[{{1.561183, 0.008545, 0.013399},{1.560509, 0.010619, 0.014302},{
      1.561805, 0.011279, 0.014302},{1.563086, 0.009515, 0.013399}}],
    Polygon[{{1.560509, 0.010619, 0.014302},{1.559800, 0.012801, 0.014853},{
      1.560456, 0.013135, 0.014853},{1.561805, 0.011279, 0.014302}}],
    Polygon[{{1.560456, 0.013135, -0.014853},{1.561805, 0.011279, -0.014302},{
      1.562833, 0.012307, -0.014302},{1.560976, 0.013655, -0.014853}}],
    Polygon[{{1.561805, 0.011279, -0.014302},{1.563086, 0.009515, -0.013399},{
      1.564596, 0.011025, -0.013399},{1.562833, 0.012307, -0.014302}}],
    Polygon[{{1.563086, 0.009515, -0.013399},{1.564269, 0.007887, -0.012166},{
      1.566224, 0.009843, -0.012166},{1.564596, 0.011025, -0.013399}}],
    Polygon[{{1.564269, 0.007887, -0.012166},{1.565323, 0.006435, -0.010634},{
      1.567676, 0.008788, -0.010634},{1.566224, 0.009843, -0.012166}}],
    Polygon[{{1.565323, 0.006435, -0.010634},{1.566224, 0.005196, -0.008839},{
      1.568916, 0.007887, -0.008839},{1.567676, 0.008788, -0.010634}}],
    Polygon[{{1.566224, 0.005196, -0.008839},{1.566949, 0.004198, -0.006827},{
      1.569913, 0.007162, -0.006827},{1.568916, 0.007887, -0.008839}}],
    Polygon[{{1.566949, 0.004198, -0.006827},{1.567480, 0.003467, -0.004647},{
      1.570644, 0.006632, -0.004647},{1.569913, 0.007162, -0.006827}}],
    Polygon[{{1.567480, 0.003467, -0.004647},{1.567803, 0.003022, -0.002352},{
      1.571089, 0.006308, -0.002352},{1.570644, 0.006632, -0.004647}}],
    Polygon[{{1.567803, 0.003022, -0.002352},{1.567912, 0.002872, 0.000000},{
      1.571239, 0.006199, 0.000000},{1.571089, 0.006308, -0.002352}}],
    Polygon[{{1.567912, 0.002872, 0.000000},{1.567803, 0.003022, 0.002352},{
      1.571089, 0.006308, 0.002352},{1.571239, 0.006199, 0.000000}}],
    Polygon[{{1.567803, 0.003022, 0.002352},{1.567480, 0.003467, 0.004647},{
      1.570644, 0.006632, 0.004647},{1.571089, 0.006308, 0.002352}}],
    Polygon[{{1.567480, 0.003467, 0.004647},{1.566949, 0.004198, 0.006827},{
      1.569913, 0.007162, 0.006827},{1.570644, 0.006632, 0.004647}}],
    Polygon[{{1.566949, 0.004198, 0.006827},{1.566224, 0.005196, 0.008839},{
      1.568916, 0.007887, 0.008839},{1.569913, 0.007162, 0.006827}}],
    Polygon[{{1.566224, 0.005196, 0.008839},{1.565323, 0.006435, 0.010634},{
      1.567676, 0.008788, 0.010634},{1.568916, 0.007887, 0.008839}}],
    Polygon[{{1.565323, 0.006435, 0.010634},{1.564269, 0.007887, 0.012166},{
      1.566224, 0.009843, 0.012166},{1.567676, 0.008788, 0.010634}}],
    Polygon[{{1.564269, 0.007887, 0.012166},{1.563086, 0.009515, 0.013399},{
      1.564596, 0.011025, 0.013399},{1.566224, 0.009843, 0.012166}}],
    Polygon[{{1.563086, 0.009515, 0.013399},{1.561805, 0.011279, 0.014302},{
      1.562833, 0.012307, 0.014302},{1.564596, 0.011025, 0.013399}}],
    Polygon[{{1.561805, 0.011279, 0.014302},{1.560456, 0.013135, 0.014853},{
      1.560976, 0.013655, 0.014853},{1.562833, 0.012307, 0.014302}}],
    Polygon[{{1.560976, 0.013655, -0.014853},{1.562833, 0.012307, -0.014302},{
      1.563493, 0.013602, -0.014302},{1.561310, 0.014311, -0.014853}}],
    Polygon[{{1.562833, 0.012307, -0.014302},{1.564596, 0.011025, -0.013399},{
      1.565566, 0.012928, -0.013399},{1.563493, 0.013602, -0.014302}}],
    Polygon[{{1.564596, 0.011025, -0.013399},{1.566224, 0.009843, -0.012166},{
      1.567480, 0.012307, -0.012166},{1.565566, 0.012928, -0.013399}}],
    Polygon[{{1.566224, 0.009843, -0.012166},{1.567676, 0.008788, -0.010634},{
      1.569186, 0.011752, -0.010634},{1.567480, 0.012307, -0.012166}}],
    Polygon[{{1.567676, 0.008788, -0.010634},{1.568916, 0.007887, -0.008839},{
      1.570644, 0.011279, -0.008839},{1.569186, 0.011752, -0.010634}}],
    Polygon[{{1.568916, 0.007887, -0.008839},{1.569913, 0.007162, -0.006827},{
      1.571816, 0.010898, -0.006827},{1.570644, 0.011279, -0.008839}}],
    Polygon[{{1.569913, 0.007162, -0.006827},{1.570644, 0.006632, -0.004647},{
      1.572675, 0.010619, -0.004647},{1.571816, 0.010898, -0.006827}}],
    Polygon[{{1.570644, 0.006632, -0.004647},{1.571089, 0.006308, -0.002352},{
      1.573199, 0.010448, -0.002352},{1.572675, 0.010619, -0.004647}}],
    Polygon[{{1.571089, 0.006308, -0.002352},{1.571239, 0.006199, 0.000000},{
      1.573375, 0.010391, 0.000000},{1.573199, 0.010448, -0.002352}}],
    Polygon[{{1.571239, 0.006199, 0.000000},{1.571089, 0.006308, 0.002352},{
      1.573199, 0.010448, 0.002352},{1.573375, 0.010391, 0.000000}}],
    Polygon[{{1.571089, 0.006308, 0.002352},{1.570644, 0.006632, 0.004647},{
      1.572675, 0.010619, 0.004647},{1.573199, 0.010448, 0.002352}}],
    Polygon[{{1.570644, 0.006632, 0.004647},{1.569913, 0.007162, 0.006827},{
      1.571816, 0.010898, 0.006827},{1.572675, 0.010619, 0.004647}}],
    Polygon[{{1.569913, 0.007162, 0.006827},{1.568916, 0.007887, 0.008839},{
      1.570644, 0.011279, 0.008839},{1.571816, 0.010898, 0.006827}}],
    Polygon[{{1.568916, 0.007887, 0.008839},{1.567676, 0.008788, 0.010634},{
      1.569186, 0.011752, 0.010634},{1.570644, 0.011279, 0.008839}}],
    Polygon[{{1.567676, 0.008788, 0.010634},{1.566224, 0.009843, 0.012166},{
      1.567480, 0.012307, 0.012166},{1.569186, 0.011752, 0.010634}}],
    Polygon[{{1.566224, 0.009843, 0.012166},{1.564596, 0.011025, 0.013399},{
      1.565566, 0.012928, 0.013399},{1.567480, 0.012307, 0.012166}}],
    Polygon[{{1.564596, 0.011025, 0.013399},{1.562833, 0.012307, 0.014302},{
      1.563493, 0.013602, 0.014302},{1.565566, 0.012928, 0.013399}}],
    Polygon[{{1.562833, 0.012307, 0.014302},{1.560976, 0.013655, 0.014853},{
      1.561310, 0.014311, 0.014853},{1.563493, 0.013602, 0.014302}}],
    Polygon[{{1.561310, 0.014311, -0.014853},{1.563493, 0.013602, -0.014302},{
      1.563720, 0.015038, -0.014302},{1.561425, 0.015038, -0.014853}}],
    Polygon[{{1.563493, 0.013602, -0.014302},{1.565566, 0.012928, -0.013399},{
      1.565900, 0.015038, -0.013399},{1.563720, 0.015038, -0.014302}}],
    Polygon[{{1.565566, 0.012928, -0.013399},{1.567480, 0.012307, -0.012166},{
      1.567912, 0.015038, -0.012166},{1.565900, 0.015038, -0.013399}}],
    Polygon[{{1.567480, 0.012307, -0.012166},{1.569186, 0.011752, -0.010634},{
      1.569707, 0.015038, -0.010634},{1.567912, 0.015038, -0.012166}}],
    Polygon[{{1.569186, 0.011752, -0.010634},{1.570644, 0.011279, -0.008839},{
      1.571239, 0.015038, -0.008839},{1.569707, 0.015038, -0.010634}}],
    Polygon[{{1.570644, 0.011279, -0.008839},{1.571816, 0.010898, -0.006827},{
      1.572472, 0.015038, -0.006827},{1.571239, 0.015038, -0.008839}}],
    Polygon[{{1.571816, 0.010898, -0.006827},{1.572675, 0.010619, -0.004647},{
      1.573375, 0.015038, -0.004647},{1.572472, 0.015038, -0.006827}}],
    Polygon[{{1.572675, 0.010619, -0.004647},{1.573199, 0.010448, -0.002352},{
      1.573926, 0.015038, -0.002352},{1.573375, 0.015038, -0.004647}}],
    Polygon[{{1.573199, 0.010448, -0.002352},{1.573375, 0.010391, 0.000000},{
      1.574111, 0.015038, 0.000000},{1.573926, 0.015038, -0.002352}}],
    Polygon[{{1.573375, 0.010391, 0.000000},{1.573199, 0.010448, 0.002352},{
      1.573926, 0.015038, 0.002352},{1.574111, 0.015038, 0.000000}}],
    Polygon[{{1.573199, 0.010448, 0.002352},{1.572675, 0.010619, 0.004647},{
      1.573375, 0.015038, 0.004647},{1.573926, 0.015038, 0.002352}}],
    Polygon[{{1.572675, 0.010619, 0.004647},{1.571816, 0.010898, 0.006827},{
      1.572472, 0.015038, 0.006827},{1.573375, 0.015038, 0.004647}}],
    Polygon[{{1.571816, 0.010898, 0.006827},{1.570644, 0.011279, 0.008839},{
      1.571239, 0.015038, 0.008839},{1.572472, 0.015038, 0.006827}}],
    Polygon[{{1.570644, 0.011279, 0.008839},{1.569186, 0.011752, 0.010634},{
      1.569707, 0.015038, 0.010634},{1.571239, 0.015038, 0.008839}}],
    Polygon[{{1.569186, 0.011752, 0.010634},{1.567480, 0.012307, 0.012166},{
      1.567912, 0.015038, 0.012166},{1.569707, 0.015038, 0.010634}}],
    Polygon[{{1.567480, 0.012307, 0.012166},{1.565566, 0.012928, 0.013399},{
      1.565900, 0.015038, 0.013399},{1.567912, 0.015038, 0.012166}}],
    Polygon[{{1.565566, 0.012928, 0.013399},{1.563493, 0.013602, 0.014302},{
      1.563720, 0.015038, 0.014302},{1.565900, 0.015038, 0.013399}}],
    Polygon[{{1.563493, 0.013602, 0.014302},{1.561310, 0.014311, 0.014853},{
      1.561425, 0.015038, 0.014853},{1.563720, 0.015038, 0.014302}}],
    Polygon[{{1.483127, 0.011149, -0.011012},{1.484828, 0.011149, -0.010603},{
      1.484659, 0.012214, -0.010603},{1.483041, 0.011688, -0.011012}}],
    Polygon[{{1.484828, 0.011149, -0.010603},{1.486444, 0.011149, -0.009934},{
      1.486196, 0.012713, -0.009934},{1.484659, 0.012214, -0.010603}}],
    Polygon[{{1.486444, 0.011149, -0.009934},{1.487936, 0.011149, -0.009020},{
      1.487615, 0.013174, -0.009020},{1.486196, 0.012713, -0.009934}}],
    Polygon[{{1.487936, 0.011149, -0.009020},{1.489266, 0.011149, -0.007884},{
      1.488880, 0.013585, -0.007884},{1.487615, 0.013174, -0.009020}}],
    Polygon[{{1.489266, 0.011149, -0.007884},{1.490402, 0.011149, -0.006553},{
      1.489961, 0.013936, -0.006553},{1.488880, 0.013585, -0.007884}}],
    Polygon[{{1.490402, 0.011149, -0.006553},{1.491316, 0.011149, -0.005062},{
      1.490830, 0.014219, -0.005062},{1.489961, 0.013936, -0.006553}}],
    Polygon[{{1.491316, 0.011149, -0.005062},{1.491986, 0.011149, -0.003445},{
      1.491467, 0.014426, -0.003445},{1.490830, 0.014219, -0.005062}}],
    Polygon[{{1.491986, 0.011149, -0.003445},{1.492394, 0.011149, -0.001744},{
      1.491855, 0.014552, -0.001744},{1.491467, 0.014426, -0.003445}}],
    Polygon[{{1.492394, 0.011149, -0.001744},{1.492532, 0.011149, 0.000000},{
      1.491986, 0.014594, 0.000000},{1.491855, 0.014552, -0.001744}}],
    Polygon[{{1.492532, 0.011149, 0.000000},{1.492394, 0.011149, 0.001744},{
      1.491855, 0.014552, 0.001744},{1.491986, 0.014594, 0.000000}}],
    Polygon[{{1.492394, 0.011149, 0.001744},{1.491986, 0.011149, 0.003445},{
      1.491467, 0.014426, 0.003445},{1.491855, 0.014552, 0.001744}}],
    Polygon[{{1.491986, 0.011149, 0.003445},{1.491316, 0.011149, 0.005062},{
      1.490830, 0.014219, 0.005062},{1.491467, 0.014426, 0.003445}}],
    Polygon[{{1.491316, 0.011149, 0.005062},{1.490402, 0.011149, 0.006553},{
      1.489961, 0.013936, 0.006553},{1.490830, 0.014219, 0.005062}}],
    Polygon[{{1.490402, 0.011149, 0.006553},{1.489266, 0.011149, 0.007884},{
      1.488880, 0.013585, 0.007884},{1.489961, 0.013936, 0.006553}}],
    Polygon[{{1.489266, 0.011149, 0.007884},{1.487936, 0.011149, 0.009020},{
      1.487615, 0.013174, 0.009020},{1.488880, 0.013585, 0.007884}}],
    Polygon[{{1.487936, 0.011149, 0.009020},{1.486444, 0.011149, 0.009934},{
      1.486196, 0.012713, 0.009934},{1.487615, 0.013174, 0.009020}}],
    Polygon[{{1.486444, 0.011149, 0.009934},{1.484828, 0.011149, 0.010603},{
      1.484659, 0.012214, 0.010603},{1.486196, 0.012713, 0.009934}}],
    Polygon[{{1.484828, 0.011149, 0.010603},{1.483127, 0.011149, 0.011012},{
      1.483041, 0.011688, 0.011012},{1.484659, 0.012214, 0.010603}}],
    Polygon[{{1.483041, 0.011688, -0.011012},{1.484659, 0.012214, -0.010603},{
      1.484170, 0.013174, -0.010603},{1.482793, 0.012174, -0.011012}}],
    Polygon[{{1.484659, 0.012214, -0.010603},{1.486196, 0.012713, -0.009934},{
      1.485477, 0.014124, -0.009934},{1.484170, 0.013174, -0.010603}}],
    Polygon[{{1.486196, 0.012713, -0.009934},{1.487615, 0.013174, -0.009020},{
      1.486684, 0.015001, -0.009020},{1.485477, 0.014124, -0.009934}}],
    Polygon[{{1.487615, 0.013174, -0.009020},{1.488880, 0.013585, -0.007884},{
      1.487760, 0.015783, -0.007884},{1.486684, 0.015001, -0.009020}}],
    Polygon[{{1.488880, 0.013585, -0.007884},{1.489961, 0.013936, -0.006553},{
      1.488680, 0.016451, -0.006553},{1.487760, 0.015783, -0.007884}}],
    Polygon[{{1.489961, 0.013936, -0.006553},{1.490830, 0.014219, -0.005062},{
      1.489419, 0.016988, -0.005062},{1.488680, 0.016451, -0.006553}}],
    Polygon[{{1.490830, 0.014219, -0.005062},{1.491467, 0.014426, -0.003445},{
      1.489961, 0.017382, -0.003445},{1.489419, 0.016988, -0.005062}}],
    Polygon[{{1.491467, 0.014426, -0.003445},{1.491855, 0.014552, -0.001744},{
      1.490291, 0.017622, -0.001744},{1.489961, 0.017382, -0.003445}}],
    Polygon[{{1.491855, 0.014552, -0.001744},{1.491986, 0.014594, 0.000000},{
      1.490402, 0.017702, 0.000000},{1.490291, 0.017622, -0.001744}}],
    Polygon[{{1.491986, 0.014594, 0.000000},{1.491855, 0.014552, 0.001744},{
      1.490291, 0.017622, 0.001744},{1.490402, 0.017702, 0.000000}}],
    Polygon[{{1.491855, 0.014552, 0.001744},{1.491467, 0.014426, 0.003445},{
      1.489961, 0.017382, 0.003445},{1.490291, 0.017622, 0.001744}}],
    Polygon[{{1.491467, 0.014426, 0.003445},{1.490830, 0.014219, 0.005062},{
      1.489419, 0.016988, 0.005062},{1.489961, 0.017382, 0.003445}}],
    Polygon[{{1.490830, 0.014219, 0.005062},{1.489961, 0.013936, 0.006553},{
      1.488680, 0.016451, 0.006553},{1.489419, 0.016988, 0.005062}}],
    Polygon[{{1.489961, 0.013936, 0.006553},{1.488880, 0.013585, 0.007884},{
      1.487760, 0.015783, 0.007884},{1.488680, 0.016451, 0.006553}}],
    Polygon[{{1.488880, 0.013585, 0.007884},{1.487615, 0.013174, 0.009020},{
      1.486684, 0.015001, 0.009020},{1.487760, 0.015783, 0.007884}}],
    Polygon[{{1.487615, 0.013174, 0.009020},{1.486196, 0.012713, 0.009934},{
      1.485477, 0.014124, 0.009934},{1.486684, 0.015001, 0.009020}}],
    Polygon[{{1.486196, 0.012713, 0.009934},{1.484659, 0.012214, 0.010603},{
      1.484170, 0.013174, 0.010603},{1.485477, 0.014124, 0.009934}}],
    Polygon[{{1.484659, 0.012214, 0.010603},{1.483041, 0.011688, 0.011012},{
      1.482793, 0.012174, 0.011012},{1.484170, 0.013174, 0.010603}}],
    Polygon[{{1.482793, 0.012174, -0.011012},{1.484170, 0.013174, -0.010603},{
      1.483407, 0.013936, -0.010603},{1.482408, 0.012560, -0.011012}}],
    Polygon[{{1.484170, 0.013174, -0.010603},{1.485477, 0.014124, -0.009934},{
      1.484358, 0.015244, -0.009934},{1.483407, 0.013936, -0.010603}}],
    Polygon[{{1.485477, 0.014124, -0.009934},{1.486684, 0.015001, -0.009020},{
      1.485234, 0.016451, -0.009020},{1.484358, 0.015244, -0.009934}}],
    Polygon[{{1.486684, 0.015001, -0.009020},{1.487760, 0.015783, -0.007884},{
      1.486016, 0.017527, -0.007884},{1.485234, 0.016451, -0.009020}}],
    Polygon[{{1.487760, 0.015783, -0.007884},{1.488680, 0.016451, -0.006553},{
      1.486684, 0.018446, -0.006553},{1.486016, 0.017527, -0.007884}}],
    Polygon[{{1.488680, 0.016451, -0.006553},{1.489419, 0.016988, -0.005062},{
      1.487221, 0.019186, -0.005062},{1.486684, 0.018446, -0.006553}}],
    Polygon[{{1.489419, 0.016988, -0.005062},{1.489961, 0.017382, -0.003445},{
      1.487615, 0.019727, -0.003445},{1.487221, 0.019186, -0.005062}}],
    Polygon[{{1.489961, 0.017382, -0.003445},{1.490291, 0.017622, -0.001744},{
      1.487855, 0.020058, -0.001744},{1.487615, 0.019727, -0.003445}}],
    Polygon[{{1.490291, 0.017622, -0.001744},{1.490402, 0.017702, 0.000000},{
      1.487936, 0.020169, 0.000000},{1.487855, 0.020058, -0.001744}}],
    Polygon[{{1.490402, 0.017702, 0.000000},{1.490291, 0.017622, 0.001744},{
      1.487855, 0.020058, 0.001744},{1.487936, 0.020169, 0.000000}}],
    Polygon[{{1.490291, 0.017622, 0.001744},{1.489961, 0.017382, 0.003445},{
      1.487615, 0.019727, 0.003445},{1.487855, 0.020058, 0.001744}}],
    Polygon[{{1.489961, 0.017382, 0.003445},{1.489419, 0.016988, 0.005062},{
      1.487221, 0.019186, 0.005062},{1.487615, 0.019727, 0.003445}}],
    Polygon[{{1.489419, 0.016988, 0.005062},{1.488680, 0.016451, 0.006553},{
      1.486684, 0.018446, 0.006553},{1.487221, 0.019186, 0.005062}}],
    Polygon[{{1.488680, 0.016451, 0.006553},{1.487760, 0.015783, 0.007884},{
      1.486016, 0.017527, 0.007884},{1.486684, 0.018446, 0.006553}}],
    Polygon[{{1.487760, 0.015783, 0.007884},{1.486684, 0.015001, 0.009020},{
      1.485234, 0.016451, 0.009020},{1.486016, 0.017527, 0.007884}}],
    Polygon[{{1.486684, 0.015001, 0.009020},{1.485477, 0.014124, 0.009934},{
      1.484358, 0.015244, 0.009934},{1.485234, 0.016451, 0.009020}}],
    Polygon[{{1.485477, 0.014124, 0.009934},{1.484170, 0.013174, 0.010603},{
      1.483407, 0.013936, 0.010603},{1.484358, 0.015244, 0.009934}}],
    Polygon[{{1.484170, 0.013174, 0.010603},{1.482793, 0.012174, 0.011012},{
      1.482408, 0.012560, 0.011012},{1.483407, 0.013936, 0.010603}}],
    Polygon[{{1.482408, 0.012560, -0.011012},{1.483407, 0.013936, -0.010603},{
      1.482447, 0.014426, -0.010603},{1.481921, 0.012808, -0.011012}}],
    Polygon[{{1.483407, 0.013936, -0.010603},{1.484358, 0.015244, -0.009934},{
      1.482947, 0.015963, -0.009934},{1.482447, 0.014426, -0.010603}}],
    Polygon[{{1.484358, 0.015244, -0.009934},{1.485234, 0.016451, -0.009020},{
      1.483407, 0.017382, -0.009020},{1.482947, 0.015963, -0.009934}}],
    Polygon[{{1.485234, 0.016451, -0.009020},{1.486016, 0.017527, -0.007884},{
      1.483819, 0.018647, -0.007884},{1.483407, 0.017382, -0.009020}}],
    Polygon[{{1.486016, 0.017527, -0.007884},{1.486684, 0.018446, -0.006553},{
      1.484170, 0.019727, -0.006553},{1.483819, 0.018647, -0.007884}}],
    Polygon[{{1.486684, 0.018446, -0.006553},{1.487221, 0.019186, -0.005062},{
      1.484452, 0.020597, -0.005062},{1.484170, 0.019727, -0.006553}}],
    Polygon[{{1.487221, 0.019186, -0.005062},{1.487615, 0.019727, -0.003445},{
      1.484659, 0.021233, -0.003445},{1.484452, 0.020597, -0.005062}}],
    Polygon[{{1.487615, 0.019727, -0.003445},{1.487855, 0.020058, -0.001744},{
      1.484785, 0.021622, -0.001744},{1.484659, 0.021233, -0.003445}}],
    Polygon[{{1.487855, 0.020058, -0.001744},{1.487936, 0.020169, 0.000000},{
      1.484828, 0.021752, 0.000000},{1.484785, 0.021622, -0.001744}}],
    Polygon[{{1.487936, 0.020169, 0.000000},{1.487855, 0.020058, 0.001744},{
      1.484785, 0.021622, 0.001744},{1.484828, 0.021752, 0.000000}}],
    Polygon[{{1.487855, 0.020058, 0.001744},{1.487615, 0.019727, 0.003445},{
      1.484659, 0.021233, 0.003445},{1.484785, 0.021622, 0.001744}}],
    Polygon[{{1.487615, 0.019727, 0.003445},{1.487221, 0.019186, 0.005062},{
      1.484452, 0.020597, 0.005062},{1.484659, 0.021233, 0.003445}}],
    Polygon[{{1.487221, 0.019186, 0.005062},{1.486684, 0.018446, 0.006553},{
      1.484170, 0.019727, 0.006553},{1.484452, 0.020597, 0.005062}}],
    Polygon[{{1.486684, 0.018446, 0.006553},{1.486016, 0.017527, 0.007884},{
      1.483819, 0.018647, 0.007884},{1.484170, 0.019727, 0.006553}}],
    Polygon[{{1.486016, 0.017527, 0.007884},{1.485234, 0.016451, 0.009020},{
      1.483407, 0.017382, 0.009020},{1.483819, 0.018647, 0.007884}}],
    Polygon[{{1.485234, 0.016451, 0.009020},{1.484358, 0.015244, 0.009934},{
      1.482947, 0.015963, 0.009934},{1.483407, 0.017382, 0.009020}}],
    Polygon[{{1.484358, 0.015244, 0.009934},{1.483407, 0.013936, 0.010603},{
      1.482447, 0.014426, 0.010603},{1.482947, 0.015963, 0.009934}}],
    Polygon[{{1.483407, 0.013936, 0.010603},{1.482408, 0.012560, 0.011012},{
      1.481921, 0.012808, 0.011012},{1.482447, 0.014426, 0.010603}}],
    Polygon[{{1.481921, 0.012808, -0.011012},{1.482447, 0.014426, -0.010603},{
      1.481382, 0.014594, -0.010603},{1.481382, 0.012893, -0.011012}}],
    Polygon[{{1.482447, 0.014426, -0.010603},{1.482947, 0.015963, -0.009934},{
      1.481382, 0.016211, -0.009934},{1.481382, 0.014594, -0.010603}}],
    Polygon[{{1.482947, 0.015963, -0.009934},{1.483407, 0.017382, -0.009020},{
      1.481382, 0.017702, -0.009020},{1.481382, 0.016211, -0.009934}}],
    Polygon[{{1.483407, 0.017382, -0.009020},{1.483819, 0.018647, -0.007884},{
      1.481382, 0.019033, -0.007884},{1.481382, 0.017702, -0.009020}}],
    Polygon[{{1.483819, 0.018647, -0.007884},{1.484170, 0.019727, -0.006553},{
      1.481382, 0.020169, -0.006553},{1.481382, 0.019033, -0.007884}}],
    Polygon[{{1.484170, 0.019727, -0.006553},{1.484452, 0.020597, -0.005062},{
      1.481382, 0.021083, -0.005062},{1.481382, 0.020169, -0.006553}}],
    Polygon[{{1.484452, 0.020597, -0.005062},{1.484659, 0.021233, -0.003445},{
      1.481382, 0.021752, -0.003445},{1.481382, 0.021083, -0.005062}}],
    Polygon[{{1.484659, 0.021233, -0.003445},{1.484785, 0.021622, -0.001744},{
      1.481382, 0.022161, -0.001744},{1.481382, 0.021752, -0.003445}}],
    Polygon[{{1.484785, 0.021622, -0.001744},{1.484828, 0.021752, 0.000000},{
      1.481382, 0.022298, 0.000000},{1.481382, 0.022161, -0.001744}}],
    Polygon[{{1.484828, 0.021752, 0.000000},{1.484785, 0.021622, 0.001744},{
      1.481382, 0.022161, 0.001744},{1.481382, 0.022298, 0.000000}}],
    Polygon[{{1.484785, 0.021622, 0.001744},{1.484659, 0.021233, 0.003445},{
      1.481382, 0.021752, 0.003445},{1.481382, 0.022161, 0.001744}}],
    Polygon[{{1.484659, 0.021233, 0.003445},{1.484452, 0.020597, 0.005062},{
      1.481382, 0.021083, 0.005062},{1.481382, 0.021752, 0.003445}}],
    Polygon[{{1.484452, 0.020597, 0.005062},{1.484170, 0.019727, 0.006553},{
      1.481382, 0.020169, 0.006553},{1.481382, 0.021083, 0.005062}}],
    Polygon[{{1.484170, 0.019727, 0.006553},{1.483819, 0.018647, 0.007884},{
      1.481382, 0.019033, 0.007884},{1.481382, 0.020169, 0.006553}}],
    Polygon[{{1.483819, 0.018647, 0.007884},{1.483407, 0.017382, 0.009020},{
      1.481382, 0.017702, 0.009020},{1.481382, 0.019033, 0.007884}}],
    Polygon[{{1.483407, 0.017382, 0.009020},{1.482947, 0.015963, 0.009934},{
      1.481382, 0.016211, 0.009934},{1.481382, 0.017702, 0.009020}}],
    Polygon[{{1.482947, 0.015963, 0.009934},{1.482447, 0.014426, 0.010603},{
      1.481382, 0.014594, 0.010603},{1.481382, 0.016211, 0.009934}}],
    Polygon[{{1.482447, 0.014426, 0.010603},{1.481921, 0.012808, 0.011012},{
      1.481382, 0.012893, 0.011012},{1.481382, 0.014594, 0.010603}}],
    Polygon[{{1.481382, 0.012893, -0.011012},{1.481382, 0.014594, -0.010603},{
      1.480318, 0.014426, -0.010603},{1.480844, 0.012808, -0.011012}}],
    Polygon[{{1.481382, 0.014594, -0.010603},{1.481382, 0.016211, -0.009934},{
      1.479818, 0.015963, -0.009934},{1.480318, 0.014426, -0.010603}}],
    Polygon[{{1.481382, 0.016211, -0.009934},{1.481382, 0.017702, -0.009020},{
      1.479357, 0.017382, -0.009020},{1.479818, 0.015963, -0.009934}}],
    Polygon[{{1.481382, 0.017702, -0.009020},{1.481382, 0.019033, -0.007884},{
      1.478946, 0.018647, -0.007884},{1.479357, 0.017382, -0.009020}}],
    Polygon[{{1.481382, 0.019033, -0.007884},{1.481382, 0.020169, -0.006553},{
      1.478595, 0.019727, -0.006553},{1.478946, 0.018647, -0.007884}}],
    Polygon[{{1.481382, 0.020169, -0.006553},{1.481382, 0.021083, -0.005062},{
      1.478313, 0.020597, -0.005062},{1.478595, 0.019727, -0.006553}}],
    Polygon[{{1.481382, 0.021083, -0.005062},{1.481382, 0.021752, -0.003445},{
      1.478106, 0.021233, -0.003445},{1.478313, 0.020597, -0.005062}}],
    Polygon[{{1.481382, 0.021752, -0.003445},{1.481382, 0.022161, -0.001744},{
      1.477980, 0.021622, -0.001744},{1.478106, 0.021233, -0.003445}}],
    Polygon[{{1.481382, 0.022161, -0.001744},{1.481382, 0.022298, 0.000000},{
      1.477937, 0.021752, 0.000000},{1.477980, 0.021622, -0.001744}}],
    Polygon[{{1.481382, 0.022298, 0.000000},{1.481382, 0.022161, 0.001744},{
      1.477980, 0.021622, 0.001744},{1.477937, 0.021752, 0.000000}}],
    Polygon[{{1.481382, 0.022161, 0.001744},{1.481382, 0.021752, 0.003445},{
      1.478106, 0.021233, 0.003445},{1.477980, 0.021622, 0.001744}}],
    Polygon[{{1.481382, 0.021752, 0.003445},{1.481382, 0.021083, 0.005062},{
      1.478313, 0.020597, 0.005062},{1.478106, 0.021233, 0.003445}}],
    Polygon[{{1.481382, 0.021083, 0.005062},{1.481382, 0.020169, 0.006553},{
      1.478595, 0.019727, 0.006553},{1.478313, 0.020597, 0.005062}}],
    Polygon[{{1.481382, 0.020169, 0.006553},{1.481382, 0.019033, 0.007884},{
      1.478946, 0.018647, 0.007884},{1.478595, 0.019727, 0.006553}}],
    Polygon[{{1.481382, 0.019033, 0.007884},{1.481382, 0.017702, 0.009020},{
      1.479357, 0.017382, 0.009020},{1.478946, 0.018647, 0.007884}}],
    Polygon[{{1.481382, 0.017702, 0.009020},{1.481382, 0.016211, 0.009934},{
      1.479818, 0.015963, 0.009934},{1.479357, 0.017382, 0.009020}}],
    Polygon[{{1.481382, 0.016211, 0.009934},{1.481382, 0.014594, 0.010603},{
      1.480318, 0.014426, 0.010603},{1.479818, 0.015963, 0.009934}}],
    Polygon[{{1.481382, 0.014594, 0.010603},{1.481382, 0.012893, 0.011012},{
      1.480844, 0.012808, 0.011012},{1.480318, 0.014426, 0.010603}}],
    Polygon[{{1.480844, 0.012808, -0.011012},{1.480318, 0.014426, -0.010603},{
      1.479357, 0.013936, -0.010603},{1.480357, 0.012560, -0.011012}}],
    Polygon[{{1.480318, 0.014426, -0.010603},{1.479818, 0.015963, -0.009934},{
      1.478407, 0.015244, -0.009934},{1.479357, 0.013936, -0.010603}}],
    Polygon[{{1.479818, 0.015963, -0.009934},{1.479357, 0.017382, -0.009020},{
      1.477531, 0.016451, -0.009020},{1.478407, 0.015244, -0.009934}}],
    Polygon[{{1.479357, 0.017382, -0.009020},{1.478946, 0.018647, -0.007884},{
      1.476749, 0.017527, -0.007884},{1.477531, 0.016451, -0.009020}}],
    Polygon[{{1.478946, 0.018647, -0.007884},{1.478595, 0.019727, -0.006553},{
      1.476081, 0.018446, -0.006553},{1.476749, 0.017527, -0.007884}}],
    Polygon[{{1.478595, 0.019727, -0.006553},{1.478313, 0.020597, -0.005062},{
      1.475543, 0.019186, -0.005062},{1.476081, 0.018446, -0.006553}}],
    Polygon[{{1.478313, 0.020597, -0.005062},{1.478106, 0.021233, -0.003445},{
      1.475150, 0.019727, -0.003445},{1.475543, 0.019186, -0.005062}}],
    Polygon[{{1.478106, 0.021233, -0.003445},{1.477980, 0.021622, -0.001744},{
      1.474910, 0.020058, -0.001744},{1.475150, 0.019727, -0.003445}}],
    Polygon[{{1.477980, 0.021622, -0.001744},{1.477937, 0.021752, 0.000000},{
      1.474829, 0.020169, 0.000000},{1.474910, 0.020058, -0.001744}}],
    Polygon[{{1.477937, 0.021752, 0.000000},{1.477980, 0.021622, 0.001744},{
      1.474910, 0.020058, 0.001744},{1.474829, 0.020169, 0.000000}}],
    Polygon[{{1.477980, 0.021622, 0.001744},{1.478106, 0.021233, 0.003445},{
      1.475150, 0.019727, 0.003445},{1.474910, 0.020058, 0.001744}}],
    Polygon[{{1.478106, 0.021233, 0.003445},{1.478313, 0.020597, 0.005062},{
      1.475543, 0.019186, 0.005062},{1.475150, 0.019727, 0.003445}}],
    Polygon[{{1.478313, 0.020597, 0.005062},{1.478595, 0.019727, 0.006553},{
      1.476081, 0.018446, 0.006553},{1.475543, 0.019186, 0.005062}}],
    Polygon[{{1.478595, 0.019727, 0.006553},{1.478946, 0.018647, 0.007884},{
      1.476749, 0.017527, 0.007884},{1.476081, 0.018446, 0.006553}}],
    Polygon[{{1.478946, 0.018647, 0.007884},{1.479357, 0.017382, 0.009020},{
      1.477531, 0.016451, 0.009020},{1.476749, 0.017527, 0.007884}}],
    Polygon[{{1.479357, 0.017382, 0.009020},{1.479818, 0.015963, 0.009934},{
      1.478407, 0.015244, 0.009934},{1.477531, 0.016451, 0.009020}}],
    Polygon[{{1.479818, 0.015963, 0.009934},{1.480318, 0.014426, 0.010603},{
      1.479357, 0.013936, 0.010603},{1.478407, 0.015244, 0.009934}}],
    Polygon[{{1.480318, 0.014426, 0.010603},{1.480844, 0.012808, 0.011012},{
      1.480357, 0.012560, 0.011012},{1.479357, 0.013936, 0.010603}}],
    Polygon[{{1.480357, 0.012560, -0.011012},{1.479357, 0.013936, -0.010603},{
      1.478595, 0.013174, -0.010603},{1.479971, 0.012174, -0.011012}}],
    Polygon[{{1.479357, 0.013936, -0.010603},{1.478407, 0.015244, -0.009934},{
      1.477288, 0.014124, -0.009934},{1.478595, 0.013174, -0.010603}}],
    Polygon[{{1.478407, 0.015244, -0.009934},{1.477531, 0.016451, -0.009020},{
      1.476081, 0.015001, -0.009020},{1.477288, 0.014124, -0.009934}}],
    Polygon[{{1.477531, 0.016451, -0.009020},{1.476749, 0.017527, -0.007884},{
      1.475005, 0.015783, -0.007884},{1.476081, 0.015001, -0.009020}}],
    Polygon[{{1.476749, 0.017527, -0.007884},{1.476081, 0.018446, -0.006553},{
      1.474085, 0.016451, -0.006553},{1.475005, 0.015783, -0.007884}}],
    Polygon[{{1.476081, 0.018446, -0.006553},{1.475543, 0.019186, -0.005062},{
      1.473346, 0.016988, -0.005062},{1.474085, 0.016451, -0.006553}}],
    Polygon[{{1.475543, 0.019186, -0.005062},{1.475150, 0.019727, -0.003445},{
      1.472804, 0.017382, -0.003445},{1.473346, 0.016988, -0.005062}}],
    Polygon[{{1.475150, 0.019727, -0.003445},{1.474910, 0.020058, -0.001744},{
      1.472474, 0.017622, -0.001744},{1.472804, 0.017382, -0.003445}}],
    Polygon[{{1.474910, 0.020058, -0.001744},{1.474829, 0.020169, 0.000000},{
      1.472363, 0.017702, 0.000000},{1.472474, 0.017622, -0.001744}}],
    Polygon[{{1.474829, 0.020169, 0.000000},{1.474910, 0.020058, 0.001744},{
      1.472474, 0.017622, 0.001744},{1.472363, 0.017702, 0.000000}}],
    Polygon[{{1.474910, 0.020058, 0.001744},{1.475150, 0.019727, 0.003445},{
      1.472804, 0.017382, 0.003445},{1.472474, 0.017622, 0.001744}}],
    Polygon[{{1.475150, 0.019727, 0.003445},{1.475543, 0.019186, 0.005062},{
      1.473346, 0.016988, 0.005062},{1.472804, 0.017382, 0.003445}}],
    Polygon[{{1.475543, 0.019186, 0.005062},{1.476081, 0.018446, 0.006553},{
      1.474085, 0.016451, 0.006553},{1.473346, 0.016988, 0.005062}}],
    Polygon[{{1.476081, 0.018446, 0.006553},{1.476749, 0.017527, 0.007884},{
      1.475005, 0.015783, 0.007884},{1.474085, 0.016451, 0.006553}}],
    Polygon[{{1.476749, 0.017527, 0.007884},{1.477531, 0.016451, 0.009020},{
      1.476081, 0.015001, 0.009020},{1.475005, 0.015783, 0.007884}}],
    Polygon[{{1.477531, 0.016451, 0.009020},{1.478407, 0.015244, 0.009934},{
      1.477288, 0.014124, 0.009934},{1.476081, 0.015001, 0.009020}}],
    Polygon[{{1.478407, 0.015244, 0.009934},{1.479357, 0.013936, 0.010603},{
      1.478595, 0.013174, 0.010603},{1.477288, 0.014124, 0.009934}}],
    Polygon[{{1.479357, 0.013936, 0.010603},{1.480357, 0.012560, 0.011012},{
      1.479971, 0.012174, 0.011012},{1.478595, 0.013174, 0.010603}}],
    Polygon[{{1.479971, 0.012174, -0.011012},{1.478595, 0.013174, -0.010603},{
      1.478106, 0.012214, -0.010603},{1.479724, 0.011688, -0.011012}}],
    Polygon[{{1.478595, 0.013174, -0.010603},{1.477288, 0.014124, -0.009934},{
      1.476569, 0.012713, -0.009934},{1.478106, 0.012214, -0.010603}}],
    Polygon[{{1.477288, 0.014124, -0.009934},{1.476081, 0.015001, -0.009020},{
      1.475150, 0.013174, -0.009020},{1.476569, 0.012713, -0.009934}}],
    Polygon[{{1.476081, 0.015001, -0.009020},{1.475005, 0.015783, -0.007884},{
      1.473885, 0.013585, -0.007884},{1.475150, 0.013174, -0.009020}}],
    Polygon[{{1.475005, 0.015783, -0.007884},{1.474085, 0.016451, -0.006553},{
      1.472804, 0.013936, -0.006553},{1.473885, 0.013585, -0.007884}}],
    Polygon[{{1.474085, 0.016451, -0.006553},{1.473346, 0.016988, -0.005062},{
      1.471935, 0.014219, -0.005062},{1.472804, 0.013936, -0.006553}}],
    Polygon[{{1.473346, 0.016988, -0.005062},{1.472804, 0.017382, -0.003445},{
      1.471298, 0.014426, -0.003445},{1.471935, 0.014219, -0.005062}}],
    Polygon[{{1.472804, 0.017382, -0.003445},{1.472474, 0.017622, -0.001744},{
      1.470910, 0.014552, -0.001744},{1.471298, 0.014426, -0.003445}}],
    Polygon[{{1.472474, 0.017622, -0.001744},{1.472363, 0.017702, 0.000000},{
      1.470779, 0.014594, 0.000000},{1.470910, 0.014552, -0.001744}}],
    Polygon[{{1.472363, 0.017702, 0.000000},{1.472474, 0.017622, 0.001744},{
      1.470910, 0.014552, 0.001744},{1.470779, 0.014594, 0.000000}}],
    Polygon[{{1.472474, 0.017622, 0.001744},{1.472804, 0.017382, 0.003445},{
      1.471298, 0.014426, 0.003445},{1.470910, 0.014552, 0.001744}}],
    Polygon[{{1.472804, 0.017382, 0.003445},{1.473346, 0.016988, 0.005062},{
      1.471935, 0.014219, 0.005062},{1.471298, 0.014426, 0.003445}}],
    Polygon[{{1.473346, 0.016988, 0.005062},{1.474085, 0.016451, 0.006553},{
      1.472804, 0.013936, 0.006553},{1.471935, 0.014219, 0.005062}}],
    Polygon[{{1.474085, 0.016451, 0.006553},{1.475005, 0.015783, 0.007884},{
      1.473885, 0.013585, 0.007884},{1.472804, 0.013936, 0.006553}}],
    Polygon[{{1.475005, 0.015783, 0.007884},{1.476081, 0.015001, 0.009020},{
      1.475150, 0.013174, 0.009020},{1.473885, 0.013585, 0.007884}}],
    Polygon[{{1.476081, 0.015001, 0.009020},{1.477288, 0.014124, 0.009934},{
      1.476569, 0.012713, 0.009934},{1.475150, 0.013174, 0.009020}}],
    Polygon[{{1.477288, 0.014124, 0.009934},{1.478595, 0.013174, 0.010603},{
      1.478106, 0.012214, 0.010603},{1.476569, 0.012713, 0.009934}}],
    Polygon[{{1.478595, 0.013174, 0.010603},{1.479971, 0.012174, 0.011012},{
      1.479724, 0.011688, 0.011012},{1.478106, 0.012214, 0.010603}}],
    Polygon[{{1.479724, 0.011688, -0.011012},{1.478106, 0.012214, -0.010603},{
      1.477937, 0.011149, -0.010603},{1.479638, 0.011149, -0.011012}}],
    Polygon[{{1.478106, 0.012214, -0.010603},{1.476569, 0.012713, -0.009934},{
      1.476321, 0.011149, -0.009934},{1.477937, 0.011149, -0.010603}}],
    Polygon[{{1.476569, 0.012713, -0.009934},{1.475150, 0.013174, -0.009020},{
      1.474829, 0.011149, -0.009020},{1.476321, 0.011149, -0.009934}}],
    Polygon[{{1.475150, 0.013174, -0.009020},{1.473885, 0.013585, -0.007884},{
      1.473499, 0.011149, -0.007884},{1.474829, 0.011149, -0.009020}}],
    Polygon[{{1.473885, 0.013585, -0.007884},{1.472804, 0.013936, -0.006553},{
      1.472363, 0.011149, -0.006553},{1.473499, 0.011149, -0.007884}}],
    Polygon[{{1.472804, 0.013936, -0.006553},{1.471935, 0.014219, -0.005062},{
      1.471449, 0.011149, -0.005062},{1.472363, 0.011149, -0.006553}}],
    Polygon[{{1.471935, 0.014219, -0.005062},{1.471298, 0.014426, -0.003445},{
      1.470779, 0.011149, -0.003445},{1.471449, 0.011149, -0.005062}}],
    Polygon[{{1.471298, 0.014426, -0.003445},{1.470910, 0.014552, -0.001744},{
      1.470371, 0.011149, -0.001744},{1.470779, 0.011149, -0.003445}}],
    Polygon[{{1.470910, 0.014552, -0.001744},{1.470779, 0.014594, 0.000000},{
      1.470233, 0.011149, 0.000000},{1.470371, 0.011149, -0.001744}}],
    Polygon[{{1.470779, 0.014594, 0.000000},{1.470910, 0.014552, 0.001744},{
      1.470371, 0.011149, 0.001744},{1.470233, 0.011149, 0.000000}}],
    Polygon[{{1.470910, 0.014552, 0.001744},{1.471298, 0.014426, 0.003445},{
      1.470779, 0.011149, 0.003445},{1.470371, 0.011149, 0.001744}}],
    Polygon[{{1.471298, 0.014426, 0.003445},{1.471935, 0.014219, 0.005062},{
      1.471449, 0.011149, 0.005062},{1.470779, 0.011149, 0.003445}}],
    Polygon[{{1.471935, 0.014219, 0.005062},{1.472804, 0.013936, 0.006553},{
      1.472363, 0.011149, 0.006553},{1.471449, 0.011149, 0.005062}}],
    Polygon[{{1.472804, 0.013936, 0.006553},{1.473885, 0.013585, 0.007884},{
      1.473499, 0.011149, 0.007884},{1.472363, 0.011149, 0.006553}}],
    Polygon[{{1.473885, 0.013585, 0.007884},{1.475150, 0.013174, 0.009020},{
      1.474829, 0.011149, 0.009020},{1.473499, 0.011149, 0.007884}}],
    Polygon[{{1.475150, 0.013174, 0.009020},{1.476569, 0.012713, 0.009934},{
      1.476321, 0.011149, 0.009934},{1.474829, 0.011149, 0.009020}}],
    Polygon[{{1.476569, 0.012713, 0.009934},{1.478106, 0.012214, 0.010603},{
      1.477937, 0.011149, 0.010603},{1.476321, 0.011149, 0.009934}}],
    Polygon[{{1.478106, 0.012214, 0.010603},{1.479724, 0.011688, 0.011012},{
      1.479638, 0.011149, 0.011012},{1.477937, 0.011149, 0.010603}}],
    Polygon[{{1.479638, 0.011149, -0.011012},{1.477937, 0.011149, -0.010603},{
      1.478106, 0.010084, -0.010603},{1.479724, 0.010610, -0.011012}}],
    Polygon[{{1.477937, 0.011149, -0.010603},{1.476321, 0.011149, -0.009934},{
      1.476569, 0.009585, -0.009934},{1.478106, 0.010084, -0.010603}}],
    Polygon[{{1.476321, 0.011149, -0.009934},{1.474829, 0.011149, -0.009020},{
      1.475150, 0.009124, -0.009020},{1.476569, 0.009585, -0.009934}}],
    Polygon[{{1.474829, 0.011149, -0.009020},{1.473499, 0.011149, -0.007884},{
      1.473885, 0.008713, -0.007884},{1.475150, 0.009124, -0.009020}}],
    Polygon[{{1.473499, 0.011149, -0.007884},{1.472363, 0.011149, -0.006553},{
      1.472804, 0.008362, -0.006553},{1.473885, 0.008713, -0.007884}}],
    Polygon[{{1.472363, 0.011149, -0.006553},{1.471449, 0.011149, -0.005062},{
      1.471935, 0.008079, -0.005062},{1.472804, 0.008362, -0.006553}}],
    Polygon[{{1.471449, 0.011149, -0.005062},{1.470779, 0.011149, -0.003445},{
      1.471298, 0.007872, -0.003445},{1.471935, 0.008079, -0.005062}}],
    Polygon[{{1.470779, 0.011149, -0.003445},{1.470371, 0.011149, -0.001744},{
      1.470910, 0.007746, -0.001744},{1.471298, 0.007872, -0.003445}}],
    Polygon[{{1.470371, 0.011149, -0.001744},{1.470233, 0.011149, 0.000000},{
      1.470779, 0.007704, 0.000000},{1.470910, 0.007746, -0.001744}}],
    Polygon[{{1.470233, 0.011149, 0.000000},{1.470371, 0.011149, 0.001744},{
      1.470910, 0.007746, 0.001744},{1.470779, 0.007704, 0.000000}}],
    Polygon[{{1.470371, 0.011149, 0.001744},{1.470779, 0.011149, 0.003445},{
      1.471298, 0.007872, 0.003445},{1.470910, 0.007746, 0.001744}}],
    Polygon[{{1.470779, 0.011149, 0.003445},{1.471449, 0.011149, 0.005062},{
      1.471935, 0.008079, 0.005062},{1.471298, 0.007872, 0.003445}}],
    Polygon[{{1.471449, 0.011149, 0.005062},{1.472363, 0.011149, 0.006553},{
      1.472804, 0.008362, 0.006553},{1.471935, 0.008079, 0.005062}}],
    Polygon[{{1.472363, 0.011149, 0.006553},{1.473499, 0.011149, 0.007884},{
      1.473885, 0.008713, 0.007884},{1.472804, 0.008362, 0.006553}}],
    Polygon[{{1.473499, 0.011149, 0.007884},{1.474829, 0.011149, 0.009020},{
      1.475150, 0.009124, 0.009020},{1.473885, 0.008713, 0.007884}}],
    Polygon[{{1.474829, 0.011149, 0.009020},{1.476321, 0.011149, 0.009934},{
      1.476569, 0.009585, 0.009934},{1.475150, 0.009124, 0.009020}}],
    Polygon[{{1.476321, 0.011149, 0.009934},{1.477937, 0.011149, 0.010603},{
      1.478106, 0.010084, 0.010603},{1.476569, 0.009585, 0.009934}}],
    Polygon[{{1.477937, 0.011149, 0.010603},{1.479638, 0.011149, 0.011012},{
      1.479724, 0.010610, 0.011012},{1.478106, 0.010084, 0.010603}}],
    Polygon[{{1.479724, 0.010610, -0.011012},{1.478106, 0.010084, -0.010603},{
      1.478595, 0.009124, -0.010603},{1.479971, 0.010124, -0.011012}}],
    Polygon[{{1.478106, 0.010084, -0.010603},{1.476569, 0.009585, -0.009934},{
      1.477288, 0.008174, -0.009934},{1.478595, 0.009124, -0.010603}}],
    Polygon[{{1.476569, 0.009585, -0.009934},{1.475150, 0.009124, -0.009020},{
      1.476081, 0.007297, -0.009020},{1.477288, 0.008174, -0.009934}}],
    Polygon[{{1.475150, 0.009124, -0.009020},{1.473885, 0.008713, -0.007884},{
      1.475005, 0.006515, -0.007884},{1.476081, 0.007297, -0.009020}}],
    Polygon[{{1.473885, 0.008713, -0.007884},{1.472804, 0.008362, -0.006553},{
      1.474085, 0.005847, -0.006553},{1.475005, 0.006515, -0.007884}}],
    Polygon[{{1.472804, 0.008362, -0.006553},{1.471935, 0.008079, -0.005062},{
      1.473346, 0.005310, -0.005062},{1.474085, 0.005847, -0.006553}}],
    Polygon[{{1.471935, 0.008079, -0.005062},{1.471298, 0.007872, -0.003445},{
      1.472804, 0.004917, -0.003445},{1.473346, 0.005310, -0.005062}}],
    Polygon[{{1.471298, 0.007872, -0.003445},{1.470910, 0.007746, -0.001744},{
      1.472474, 0.004676, -0.001744},{1.472804, 0.004917, -0.003445}}],
    Polygon[{{1.470910, 0.007746, -0.001744},{1.470779, 0.007704, 0.000000},{
      1.472363, 0.004596, 0.000000},{1.472474, 0.004676, -0.001744}}],
    Polygon[{{1.470779, 0.007704, 0.000000},{1.470910, 0.007746, 0.001744},{
      1.472474, 0.004676, 0.001744},{1.472363, 0.004596, 0.000000}}],
    Polygon[{{1.470910, 0.007746, 0.001744},{1.471298, 0.007872, 0.003445},{
      1.472804, 0.004917, 0.003445},{1.472474, 0.004676, 0.001744}}],
    Polygon[{{1.471298, 0.007872, 0.003445},{1.471935, 0.008079, 0.005062},{
      1.473346, 0.005310, 0.005062},{1.472804, 0.004917, 0.003445}}],
    Polygon[{{1.471935, 0.008079, 0.005062},{1.472804, 0.008362, 0.006553},{
      1.474085, 0.005847, 0.006553},{1.473346, 0.005310, 0.005062}}],
    Polygon[{{1.472804, 0.008362, 0.006553},{1.473885, 0.008713, 0.007884},{
      1.475005, 0.006515, 0.007884},{1.474085, 0.005847, 0.006553}}],
    Polygon[{{1.473885, 0.008713, 0.007884},{1.475150, 0.009124, 0.009020},{
      1.476081, 0.007297, 0.009020},{1.475005, 0.006515, 0.007884}}],
    Polygon[{{1.475150, 0.009124, 0.009020},{1.476569, 0.009585, 0.009934},{
      1.477288, 0.008174, 0.009934},{1.476081, 0.007297, 0.009020}}],
    Polygon[{{1.476569, 0.009585, 0.009934},{1.478106, 0.010084, 0.010603},{
      1.478595, 0.009124, 0.010603},{1.477288, 0.008174, 0.009934}}],
    Polygon[{{1.478106, 0.010084, 0.010603},{1.479724, 0.010610, 0.011012},{
      1.479971, 0.010124, 0.011012},{1.478595, 0.009124, 0.010603}}],
    Polygon[{{1.479971, 0.010124, -0.011012},{1.478595, 0.009124, -0.010603},{
      1.479357, 0.008362, -0.010603},{1.480357, 0.009738, -0.011012}}],
    Polygon[{{1.478595, 0.009124, -0.010603},{1.477288, 0.008174, -0.009934},{
      1.478407, 0.007054, -0.009934},{1.479357, 0.008362, -0.010603}}],
    Polygon[{{1.477288, 0.008174, -0.009934},{1.476081, 0.007297, -0.009020},{
      1.477531, 0.005847, -0.009020},{1.478407, 0.007054, -0.009934}}],
    Polygon[{{1.476081, 0.007297, -0.009020},{1.475005, 0.006515, -0.007884},{
      1.476749, 0.004771, -0.007884},{1.477531, 0.005847, -0.009020}}],
    Polygon[{{1.475005, 0.006515, -0.007884},{1.474085, 0.005847, -0.006553},{
      1.476081, 0.003852, -0.006553},{1.476749, 0.004771, -0.007884}}],
    Polygon[{{1.474085, 0.005847, -0.006553},{1.473346, 0.005310, -0.005062},{
      1.475543, 0.003112, -0.005062},{1.476081, 0.003852, -0.006553}}],
    Polygon[{{1.473346, 0.005310, -0.005062},{1.472804, 0.004917, -0.003445},{
      1.475150, 0.002571, -0.003445},{1.475543, 0.003112, -0.005062}}],
    Polygon[{{1.472804, 0.004917, -0.003445},{1.472474, 0.004676, -0.001744},{
      1.474910, 0.002240, -0.001744},{1.475150, 0.002571, -0.003445}}],
    Polygon[{{1.472474, 0.004676, -0.001744},{1.472363, 0.004596, 0.000000},{
      1.474829, 0.002129, 0.000000},{1.474910, 0.002240, -0.001744}}],
    Polygon[{{1.472363, 0.004596, 0.000000},{1.472474, 0.004676, 0.001744},{
      1.474910, 0.002240, 0.001744},{1.474829, 0.002129, 0.000000}}],
    Polygon[{{1.472474, 0.004676, 0.001744},{1.472804, 0.004917, 0.003445},{
      1.475150, 0.002571, 0.003445},{1.474910, 0.002240, 0.001744}}],
    Polygon[{{1.472804, 0.004917, 0.003445},{1.473346, 0.005310, 0.005062},{
      1.475543, 0.003112, 0.005062},{1.475150, 0.002571, 0.003445}}],
    Polygon[{{1.473346, 0.005310, 0.005062},{1.474085, 0.005847, 0.006553},{
      1.476081, 0.003852, 0.006553},{1.475543, 0.003112, 0.005062}}],
    Polygon[{{1.474085, 0.005847, 0.006553},{1.475005, 0.006515, 0.007884},{
      1.476749, 0.004771, 0.007884},{1.476081, 0.003852, 0.006553}}],
    Polygon[{{1.475005, 0.006515, 0.007884},{1.476081, 0.007297, 0.009020},{
      1.477531, 0.005847, 0.009020},{1.476749, 0.004771, 0.007884}}],
    Polygon[{{1.476081, 0.007297, 0.009020},{1.477288, 0.008174, 0.009934},{
      1.478407, 0.007054, 0.009934},{1.477531, 0.005847, 0.009020}}],
    Polygon[{{1.477288, 0.008174, 0.009934},{1.478595, 0.009124, 0.010603},{
      1.479357, 0.008362, 0.010603},{1.478407, 0.007054, 0.009934}}],
    Polygon[{{1.478595, 0.009124, 0.010603},{1.479971, 0.010124, 0.011012},{
      1.480357, 0.009738, 0.011012},{1.479357, 0.008362, 0.010603}}],
    Polygon[{{1.480357, 0.009738, -0.011012},{1.479357, 0.008362, -0.010603},{
      1.480318, 0.007872, -0.010603},{1.480844, 0.009490, -0.011012}}],
    Polygon[{{1.479357, 0.008362, -0.010603},{1.478407, 0.007054, -0.009934},{
      1.479818, 0.006335, -0.009934},{1.480318, 0.007872, -0.010603}}],
    Polygon[{{1.478407, 0.007054, -0.009934},{1.477531, 0.005847, -0.009020},{
      1.479357, 0.004917, -0.009020},{1.479818, 0.006335, -0.009934}}],
    Polygon[{{1.477531, 0.005847, -0.009020},{1.476749, 0.004771, -0.007884},{
      1.478946, 0.003651, -0.007884},{1.479357, 0.004917, -0.009020}}],
    Polygon[{{1.476749, 0.004771, -0.007884},{1.476081, 0.003852, -0.006553},{
      1.478595, 0.002571, -0.006553},{1.478946, 0.003651, -0.007884}}],
    Polygon[{{1.476081, 0.003852, -0.006553},{1.475543, 0.003112, -0.005062},{
      1.478313, 0.001701, -0.005062},{1.478595, 0.002571, -0.006553}}],
    Polygon[{{1.475543, 0.003112, -0.005062},{1.475150, 0.002571, -0.003445},{
      1.478106, 0.001065, -0.003445},{1.478313, 0.001701, -0.005062}}],
    Polygon[{{1.475150, 0.002571, -0.003445},{1.474910, 0.002240, -0.001744},{
      1.477980, 0.000676, -0.001744},{1.478106, 0.001065, -0.003445}}],
    Polygon[{{1.474910, 0.002240, -0.001744},{1.474829, 0.002129, 0.000000},{
      1.477937, 0.000546, 0.000000},{1.477980, 0.000676, -0.001744}}],
    Polygon[{{1.474829, 0.002129, 0.000000},{1.474910, 0.002240, 0.001744},{
      1.477980, 0.000676, 0.001744},{1.477937, 0.000546, 0.000000}}],
    Polygon[{{1.474910, 0.002240, 0.001744},{1.475150, 0.002571, 0.003445},{
      1.478106, 0.001065, 0.003445},{1.477980, 0.000676, 0.001744}}],
    Polygon[{{1.475150, 0.002571, 0.003445},{1.475543, 0.003112, 0.005062},{
      1.478313, 0.001701, 0.005062},{1.478106, 0.001065, 0.003445}}],
    Polygon[{{1.475543, 0.003112, 0.005062},{1.476081, 0.003852, 0.006553},{
      1.478595, 0.002571, 0.006553},{1.478313, 0.001701, 0.005062}}],
    Polygon[{{1.476081, 0.003852, 0.006553},{1.476749, 0.004771, 0.007884},{
      1.478946, 0.003651, 0.007884},{1.478595, 0.002571, 0.006553}}],
    Polygon[{{1.476749, 0.004771, 0.007884},{1.477531, 0.005847, 0.009020},{
      1.479357, 0.004917, 0.009020},{1.478946, 0.003651, 0.007884}}],
    Polygon[{{1.477531, 0.005847, 0.009020},{1.478407, 0.007054, 0.009934},{
      1.479818, 0.006335, 0.009934},{1.479357, 0.004917, 0.009020}}],
    Polygon[{{1.478407, 0.007054, 0.009934},{1.479357, 0.008362, 0.010603},{
      1.480318, 0.007872, 0.010603},{1.479818, 0.006335, 0.009934}}],
    Polygon[{{1.479357, 0.008362, 0.010603},{1.480357, 0.009738, 0.011012},{
      1.480844, 0.009490, 0.011012},{1.480318, 0.007872, 0.010603}}],
    Polygon[{{1.480844, 0.009490, -0.011012},{1.480318, 0.007872, -0.010603},{
      1.481382, 0.007704, -0.010603},{1.481382, 0.009405, -0.011012}}],
    Polygon[{{1.480318, 0.007872, -0.010603},{1.479818, 0.006335, -0.009934},{
      1.481382, 0.006087, -0.009934},{1.481382, 0.007704, -0.010603}}],
    Polygon[{{1.479818, 0.006335, -0.009934},{1.479357, 0.004917, -0.009020},{
      1.481382, 0.004596, -0.009020},{1.481382, 0.006087, -0.009934}}],
    Polygon[{{1.479357, 0.004917, -0.009020},{1.478946, 0.003651, -0.007884},{
      1.481382, 0.003265, -0.007884},{1.481382, 0.004596, -0.009020}}],
    Polygon[{{1.478946, 0.003651, -0.007884},{1.478595, 0.002571, -0.006553},{
      1.481382, 0.002129, -0.006553},{1.481382, 0.003265, -0.007884}}],
    Polygon[{{1.478595, 0.002571, -0.006553},{1.478313, 0.001701, -0.005062},{
      1.481382, 0.001215, -0.005062},{1.481382, 0.002129, -0.006553}}],
    Polygon[{{1.478313, 0.001701, -0.005062},{1.478106, 0.001065, -0.003445},{
      1.481382, 0.000546, -0.003445},{1.481382, 0.001215, -0.005062}}],
    Polygon[{{1.478106, 0.001065, -0.003445},{1.477980, 0.000676, -0.001744},{
      1.481382, 0.000137, -0.001744},{1.481382, 0.000546, -0.003445}}],
    Polygon[{{1.477980, 0.000676, -0.001744},{1.477937, 0.000546, 0.000000},{
      1.481382, 0.000000, 0.000000},{1.481382, 0.000137, -0.001744}}],
    Polygon[{{1.477937, 0.000546, 0.000000},{1.477980, 0.000676, 0.001744},{
      1.481382, 0.000137, 0.001744},{1.481382, 0.000000, 0.000000}}],
    Polygon[{{1.477980, 0.000676, 0.001744},{1.478106, 0.001065, 0.003445},{
      1.481382, 0.000546, 0.003445},{1.481382, 0.000137, 0.001744}}],
    Polygon[{{1.478106, 0.001065, 0.003445},{1.478313, 0.001701, 0.005062},{
      1.481382, 0.001215, 0.005062},{1.481382, 0.000546, 0.003445}}],
    Polygon[{{1.478313, 0.001701, 0.005062},{1.478595, 0.002571, 0.006553},{
      1.481382, 0.002129, 0.006553},{1.481382, 0.001215, 0.005062}}],
    Polygon[{{1.478595, 0.002571, 0.006553},{1.478946, 0.003651, 0.007884},{
      1.481382, 0.003265, 0.007884},{1.481382, 0.002129, 0.006553}}],
    Polygon[{{1.478946, 0.003651, 0.007884},{1.479357, 0.004917, 0.009020},{
      1.481382, 0.004596, 0.009020},{1.481382, 0.003265, 0.007884}}],
    Polygon[{{1.479357, 0.004917, 0.009020},{1.479818, 0.006335, 0.009934},{
      1.481382, 0.006087, 0.009934},{1.481382, 0.004596, 0.009020}}],
    Polygon[{{1.479818, 0.006335, 0.009934},{1.480318, 0.007872, 0.010603},{
      1.481382, 0.007704, 0.010603},{1.481382, 0.006087, 0.009934}}],
    Polygon[{{1.480318, 0.007872, 0.010603},{1.480844, 0.009490, 0.011012},{
      1.481382, 0.009405, 0.011012},{1.481382, 0.007704, 0.010603}}],
    Polygon[{{1.481382, 0.009405, -0.011012},{1.481382, 0.007704, -0.010603},{
      1.482447, 0.007872, -0.010603},{1.481921, 0.009490, -0.011012}}],
    Polygon[{{1.481382, 0.007704, -0.010603},{1.481382, 0.006087, -0.009934},{
      1.482947, 0.006335, -0.009934},{1.482447, 0.007872, -0.010603}}],
    Polygon[{{1.481382, 0.006087, -0.009934},{1.481382, 0.004596, -0.009020},{
      1.483407, 0.004917, -0.009020},{1.482947, 0.006335, -0.009934}}],
    Polygon[{{1.481382, 0.004596, -0.009020},{1.481382, 0.003265, -0.007884},{
      1.483819, 0.003651, -0.007884},{1.483407, 0.004917, -0.009020}}],
    Polygon[{{1.481382, 0.003265, -0.007884},{1.481382, 0.002129, -0.006553},{
      1.484170, 0.002571, -0.006553},{1.483819, 0.003651, -0.007884}}],
    Polygon[{{1.481382, 0.002129, -0.006553},{1.481382, 0.001215, -0.005062},{
      1.484452, 0.001701, -0.005062},{1.484170, 0.002571, -0.006553}}],
    Polygon[{{1.481382, 0.001215, -0.005062},{1.481382, 0.000546, -0.003445},{
      1.484659, 0.001065, -0.003445},{1.484452, 0.001701, -0.005062}}],
    Polygon[{{1.481382, 0.000546, -0.003445},{1.481382, 0.000137, -0.001744},{
      1.484785, 0.000676, -0.001744},{1.484659, 0.001065, -0.003445}}],
    Polygon[{{1.481382, 0.000137, -0.001744},{1.481382, 0.000000, 0.000000},{
      1.484828, 0.000546, 0.000000},{1.484785, 0.000676, -0.001744}}],
    Polygon[{{1.481382, 0.000000, 0.000000},{1.481382, 0.000137, 0.001744},{
      1.484785, 0.000676, 0.001744},{1.484828, 0.000546, 0.000000}}],
    Polygon[{{1.481382, 0.000137, 0.001744},{1.481382, 0.000546, 0.003445},{
      1.484659, 0.001065, 0.003445},{1.484785, 0.000676, 0.001744}}],
    Polygon[{{1.481382, 0.000546, 0.003445},{1.481382, 0.001215, 0.005062},{
      1.484452, 0.001701, 0.005062},{1.484659, 0.001065, 0.003445}}],
    Polygon[{{1.481382, 0.001215, 0.005062},{1.481382, 0.002129, 0.006553},{
      1.484170, 0.002571, 0.006553},{1.484452, 0.001701, 0.005062}}],
    Polygon[{{1.481382, 0.002129, 0.006553},{1.481382, 0.003265, 0.007884},{
      1.483819, 0.003651, 0.007884},{1.484170, 0.002571, 0.006553}}],
    Polygon[{{1.481382, 0.003265, 0.007884},{1.481382, 0.004596, 0.009020},{
      1.483407, 0.004917, 0.009020},{1.483819, 0.003651, 0.007884}}],
    Polygon[{{1.481382, 0.004596, 0.009020},{1.481382, 0.006087, 0.009934},{
      1.482947, 0.006335, 0.009934},{1.483407, 0.004917, 0.009020}}],
    Polygon[{{1.481382, 0.006087, 0.009934},{1.481382, 0.007704, 0.010603},{
      1.482447, 0.007872, 0.010603},{1.482947, 0.006335, 0.009934}}],
    Polygon[{{1.481382, 0.007704, 0.010603},{1.481382, 0.009405, 0.011012},{
      1.481921, 0.009490, 0.011012},{1.482447, 0.007872, 0.010603}}],
    Polygon[{{1.481921, 0.009490, -0.011012},{1.482447, 0.007872, -0.010603},{
      1.483407, 0.008362, -0.010603},{1.482408, 0.009738, -0.011012}}],
    Polygon[{{1.482447, 0.007872, -0.010603},{1.482947, 0.006335, -0.009934},{
      1.484358, 0.007054, -0.009934},{1.483407, 0.008362, -0.010603}}],
    Polygon[{{1.482947, 0.006335, -0.009934},{1.483407, 0.004917, -0.009020},{
      1.485234, 0.005847, -0.009020},{1.484358, 0.007054, -0.009934}}],
    Polygon[{{1.483407, 0.004917, -0.009020},{1.483819, 0.003651, -0.007884},{
      1.486016, 0.004771, -0.007884},{1.485234, 0.005847, -0.009020}}],
    Polygon[{{1.483819, 0.003651, -0.007884},{1.484170, 0.002571, -0.006553},{
      1.486684, 0.003852, -0.006553},{1.486016, 0.004771, -0.007884}}],
    Polygon[{{1.484170, 0.002571, -0.006553},{1.484452, 0.001701, -0.005062},{
      1.487221, 0.003112, -0.005062},{1.486684, 0.003852, -0.006553}}],
    Polygon[{{1.484452, 0.001701, -0.005062},{1.484659, 0.001065, -0.003445},{
      1.487615, 0.002571, -0.003445},{1.487221, 0.003112, -0.005062}}],
    Polygon[{{1.484659, 0.001065, -0.003445},{1.484785, 0.000676, -0.001744},{
      1.487855, 0.002240, -0.001744},{1.487615, 0.002571, -0.003445}}],
    Polygon[{{1.484785, 0.000676, -0.001744},{1.484828, 0.000546, 0.000000},{
      1.487936, 0.002129, 0.000000},{1.487855, 0.002240, -0.001744}}],
    Polygon[{{1.484828, 0.000546, 0.000000},{1.484785, 0.000676, 0.001744},{
      1.487855, 0.002240, 0.001744},{1.487936, 0.002129, 0.000000}}],
    Polygon[{{1.484785, 0.000676, 0.001744},{1.484659, 0.001065, 0.003445},{
      1.487615, 0.002571, 0.003445},{1.487855, 0.002240, 0.001744}}],
    Polygon[{{1.484659, 0.001065, 0.003445},{1.484452, 0.001701, 0.005062},{
      1.487221, 0.003112, 0.005062},{1.487615, 0.002571, 0.003445}}],
    Polygon[{{1.484452, 0.001701, 0.005062},{1.484170, 0.002571, 0.006553},{
      1.486684, 0.003852, 0.006553},{1.487221, 0.003112, 0.005062}}],
    Polygon[{{1.484170, 0.002571, 0.006553},{1.483819, 0.003651, 0.007884},{
      1.486016, 0.004771, 0.007884},{1.486684, 0.003852, 0.006553}}],
    Polygon[{{1.483819, 0.003651, 0.007884},{1.483407, 0.004917, 0.009020},{
      1.485234, 0.005847, 0.009020},{1.486016, 0.004771, 0.007884}}],
    Polygon[{{1.483407, 0.004917, 0.009020},{1.482947, 0.006335, 0.009934},{
      1.484358, 0.007054, 0.009934},{1.485234, 0.005847, 0.009020}}],
    Polygon[{{1.482947, 0.006335, 0.009934},{1.482447, 0.007872, 0.010603},{
      1.483407, 0.008362, 0.010603},{1.484358, 0.007054, 0.009934}}],
    Polygon[{{1.482447, 0.007872, 0.010603},{1.481921, 0.009490, 0.011012},{
      1.482408, 0.009738, 0.011012},{1.483407, 0.008362, 0.010603}}],
    Polygon[{{1.482408, 0.009738, -0.011012},{1.483407, 0.008362, -0.010603},{
      1.484170, 0.009124, -0.010603},{1.482793, 0.010124, -0.011012}}],
    Polygon[{{1.483407, 0.008362, -0.010603},{1.484358, 0.007054, -0.009934},{
      1.485477, 0.008174, -0.009934},{1.484170, 0.009124, -0.010603}}],
    Polygon[{{1.484358, 0.007054, -0.009934},{1.485234, 0.005847, -0.009020},{
      1.486684, 0.007297, -0.009020},{1.485477, 0.008174, -0.009934}}],
    Polygon[{{1.485234, 0.005847, -0.009020},{1.486016, 0.004771, -0.007884},{
      1.487760, 0.006515, -0.007884},{1.486684, 0.007297, -0.009020}}],
    Polygon[{{1.486016, 0.004771, -0.007884},{1.486684, 0.003852, -0.006553},{
      1.488680, 0.005847, -0.006553},{1.487760, 0.006515, -0.007884}}],
    Polygon[{{1.486684, 0.003852, -0.006553},{1.487221, 0.003112, -0.005062},{
      1.489419, 0.005310, -0.005062},{1.488680, 0.005847, -0.006553}}],
    Polygon[{{1.487221, 0.003112, -0.005062},{1.487615, 0.002571, -0.003445},{
      1.489961, 0.004917, -0.003445},{1.489419, 0.005310, -0.005062}}],
    Polygon[{{1.487615, 0.002571, -0.003445},{1.487855, 0.002240, -0.001744},{
      1.490291, 0.004676, -0.001744},{1.489961, 0.004917, -0.003445}}],
    Polygon[{{1.487855, 0.002240, -0.001744},{1.487936, 0.002129, 0.000000},{
      1.490402, 0.004596, 0.000000},{1.490291, 0.004676, -0.001744}}],
    Polygon[{{1.487936, 0.002129, 0.000000},{1.487855, 0.002240, 0.001744},{
      1.490291, 0.004676, 0.001744},{1.490402, 0.004596, 0.000000}}],
    Polygon[{{1.487855, 0.002240, 0.001744},{1.487615, 0.002571, 0.003445},{
      1.489961, 0.004917, 0.003445},{1.490291, 0.004676, 0.001744}}],
    Polygon[{{1.487615, 0.002571, 0.003445},{1.487221, 0.003112, 0.005062},{
      1.489419, 0.005310, 0.005062},{1.489961, 0.004917, 0.003445}}],
    Polygon[{{1.487221, 0.003112, 0.005062},{1.486684, 0.003852, 0.006553},{
      1.488680, 0.005847, 0.006553},{1.489419, 0.005310, 0.005062}}],
    Polygon[{{1.486684, 0.003852, 0.006553},{1.486016, 0.004771, 0.007884},{
      1.487760, 0.006515, 0.007884},{1.488680, 0.005847, 0.006553}}],
    Polygon[{{1.486016, 0.004771, 0.007884},{1.485234, 0.005847, 0.009020},{
      1.486684, 0.007297, 0.009020},{1.487760, 0.006515, 0.007884}}],
    Polygon[{{1.485234, 0.005847, 0.009020},{1.484358, 0.007054, 0.009934},{
      1.485477, 0.008174, 0.009934},{1.486684, 0.007297, 0.009020}}],
    Polygon[{{1.484358, 0.007054, 0.009934},{1.483407, 0.008362, 0.010603},{
      1.484170, 0.009124, 0.010603},{1.485477, 0.008174, 0.009934}}],
    Polygon[{{1.483407, 0.008362, 0.010603},{1.482408, 0.009738, 0.011012},{
      1.482793, 0.010124, 0.011012},{1.484170, 0.009124, 0.010603}}],
    Polygon[{{1.482793, 0.010124, -0.011012},{1.484170, 0.009124, -0.010603},{
      1.484659, 0.010084, -0.010603},{1.483041, 0.010610, -0.011012}}],
    Polygon[{{1.484170, 0.009124, -0.010603},{1.485477, 0.008174, -0.009934},{
      1.486196, 0.009585, -0.009934},{1.484659, 0.010084, -0.010603}}],
    Polygon[{{1.485477, 0.008174, -0.009934},{1.486684, 0.007297, -0.009020},{
      1.487615, 0.009124, -0.009020},{1.486196, 0.009585, -0.009934}}],
    Polygon[{{1.486684, 0.007297, -0.009020},{1.487760, 0.006515, -0.007884},{
      1.488880, 0.008713, -0.007884},{1.487615, 0.009124, -0.009020}}],
    Polygon[{{1.487760, 0.006515, -0.007884},{1.488680, 0.005847, -0.006553},{
      1.489961, 0.008362, -0.006553},{1.488880, 0.008713, -0.007884}}],
    Polygon[{{1.488680, 0.005847, -0.006553},{1.489419, 0.005310, -0.005062},{
      1.490830, 0.008079, -0.005062},{1.489961, 0.008362, -0.006553}}],
    Polygon[{{1.489419, 0.005310, -0.005062},{1.489961, 0.004917, -0.003445},{
      1.491467, 0.007872, -0.003445},{1.490830, 0.008079, -0.005062}}],
    Polygon[{{1.489961, 0.004917, -0.003445},{1.490291, 0.004676, -0.001744},{
      1.491855, 0.007746, -0.001744},{1.491467, 0.007872, -0.003445}}],
    Polygon[{{1.490291, 0.004676, -0.001744},{1.490402, 0.004596, 0.000000},{
      1.491986, 0.007704, 0.000000},{1.491855, 0.007746, -0.001744}}],
    Polygon[{{1.490402, 0.004596, 0.000000},{1.490291, 0.004676, 0.001744},{
      1.491855, 0.007746, 0.001744},{1.491986, 0.007704, 0.000000}}],
    Polygon[{{1.490291, 0.004676, 0.001744},{1.489961, 0.004917, 0.003445},{
      1.491467, 0.007872, 0.003445},{1.491855, 0.007746, 0.001744}}],
    Polygon[{{1.489961, 0.004917, 0.003445},{1.489419, 0.005310, 0.005062},{
      1.490830, 0.008079, 0.005062},{1.491467, 0.007872, 0.003445}}],
    Polygon[{{1.489419, 0.005310, 0.005062},{1.488680, 0.005847, 0.006553},{
      1.489961, 0.008362, 0.006553},{1.490830, 0.008079, 0.005062}}],
    Polygon[{{1.488680, 0.005847, 0.006553},{1.487760, 0.006515, 0.007884},{
      1.488880, 0.008713, 0.007884},{1.489961, 0.008362, 0.006553}}],
    Polygon[{{1.487760, 0.006515, 0.007884},{1.486684, 0.007297, 0.009020},{
      1.487615, 0.009124, 0.009020},{1.488880, 0.008713, 0.007884}}],
    Polygon[{{1.486684, 0.007297, 0.009020},{1.485477, 0.008174, 0.009934},{
      1.486196, 0.009585, 0.009934},{1.487615, 0.009124, 0.009020}}],
    Polygon[{{1.485477, 0.008174, 0.009934},{1.484170, 0.009124, 0.010603},{
      1.484659, 0.010084, 0.010603},{1.486196, 0.009585, 0.009934}}],
    Polygon[{{1.484170, 0.009124, 0.010603},{1.482793, 0.010124, 0.011012},{
      1.483041, 0.010610, 0.011012},{1.484659, 0.010084, 0.010603}}],
    Polygon[{{1.483041, 0.010610, -0.011012},{1.484659, 0.010084, -0.010603},{
      1.484828, 0.011149, -0.010603},{1.483127, 0.011149, -0.011012}}],
    Polygon[{{1.484659, 0.010084, -0.010603},{1.486196, 0.009585, -0.009934},{
      1.486444, 0.011149, -0.009934},{1.484828, 0.011149, -0.010603}}],
    Polygon[{{1.486196, 0.009585, -0.009934},{1.487615, 0.009124, -0.009020},{
      1.487936, 0.011149, -0.009020},{1.486444, 0.011149, -0.009934}}],
    Polygon[{{1.487615, 0.009124, -0.009020},{1.488880, 0.008713, -0.007884},{
      1.489266, 0.011149, -0.007884},{1.487936, 0.011149, -0.009020}}],
    Polygon[{{1.488880, 0.008713, -0.007884},{1.489961, 0.008362, -0.006553},{
      1.490402, 0.011149, -0.006553},{1.489266, 0.011149, -0.007884}}],
    Polygon[{{1.489961, 0.008362, -0.006553},{1.490830, 0.008079, -0.005062},{
      1.491316, 0.011149, -0.005062},{1.490402, 0.011149, -0.006553}}],
    Polygon[{{1.490830, 0.008079, -0.005062},{1.491467, 0.007872, -0.003445},{
      1.491986, 0.011149, -0.003445},{1.491316, 0.011149, -0.005062}}],
    Polygon[{{1.491467, 0.007872, -0.003445},{1.491855, 0.007746, -0.001744},{
      1.492394, 0.011149, -0.001744},{1.491986, 0.011149, -0.003445}}],
    Polygon[{{1.491855, 0.007746, -0.001744},{1.491986, 0.007704, 0.000000},{
      1.492532, 0.011149, 0.000000},{1.492394, 0.011149, -0.001744}}],
    Polygon[{{1.491986, 0.007704, 0.000000},{1.491855, 0.007746, 0.001744},{
      1.492394, 0.011149, 0.001744},{1.492532, 0.011149, 0.000000}}],
    Polygon[{{1.491855, 0.007746, 0.001744},{1.491467, 0.007872, 0.003445},{
      1.491986, 0.011149, 0.003445},{1.492394, 0.011149, 0.001744}}],
    Polygon[{{1.491467, 0.007872, 0.003445},{1.490830, 0.008079, 0.005062},{
      1.491316, 0.011149, 0.005062},{1.491986, 0.011149, 0.003445}}],
    Polygon[{{1.490830, 0.008079, 0.005062},{1.489961, 0.008362, 0.006553},{
      1.490402, 0.011149, 0.006553},{1.491316, 0.011149, 0.005062}}],
    Polygon[{{1.489961, 0.008362, 0.006553},{1.488880, 0.008713, 0.007884},{
      1.489266, 0.011149, 0.007884},{1.490402, 0.011149, 0.006553}}],
    Polygon[{{1.488880, 0.008713, 0.007884},{1.487615, 0.009124, 0.009020},{
      1.487936, 0.011149, 0.009020},{1.489266, 0.011149, 0.007884}}],
    Polygon[{{1.487615, 0.009124, 0.009020},{1.486196, 0.009585, 0.009934},{
      1.486444, 0.011149, 0.009934},{1.487936, 0.011149, 0.009020}}],
    Polygon[{{1.486196, 0.009585, 0.009934},{1.484659, 0.010084, 0.010603},{
      1.484828, 0.011149, 0.010603},{1.486444, 0.011149, 0.009934}}],
    Polygon[{{1.484659, 0.010084, 0.010603},{1.483041, 0.010610, 0.011012},{
      1.483127, 0.011149, 0.011012},{1.484828, 0.011149, 0.010603}}],
    Polygon[{{1.510302, 0.066488, -0.009381},{1.511752, 0.066488, -0.009033},{
      1.511608, 0.067395, -0.009033},{1.510229, 0.066947, -0.009381}}],
    Polygon[{{1.511752, 0.066488, -0.009033},{1.513129, 0.066488, -0.008463},{
      1.512917, 0.067821, -0.008463},{1.511608, 0.067395, -0.009033}}],
    Polygon[{{1.513129, 0.066488, -0.008463},{1.514399, 0.066488, -0.007684},{
      1.514126, 0.068213, -0.007684},{1.512917, 0.067821, -0.008463}}],
    Polygon[{{1.514399, 0.066488, -0.007684},{1.515533, 0.066488, -0.006716},{
      1.515204, 0.068564, -0.006716},{1.514126, 0.068213, -0.007684}}],
    Polygon[{{1.515533, 0.066488, -0.006716},{1.516501, 0.066488, -0.005583},{
      1.516124, 0.068863, -0.005583},{1.515204, 0.068564, -0.006716}}],
    Polygon[{{1.516501, 0.066488, -0.005583},{1.517279, 0.066488, -0.004312},{
      1.516865, 0.069103, -0.004312},{1.516124, 0.068863, -0.005583}}],
    Polygon[{{1.517279, 0.066488, -0.004312},{1.517850, 0.066488, -0.002935},{
      1.517408, 0.069280, -0.002935},{1.516865, 0.069103, -0.004312}}],
    Polygon[{{1.517850, 0.066488, -0.002935},{1.518198, 0.066488, -0.001486},{
      1.517739, 0.069387, -0.001486},{1.517408, 0.069280, -0.002935}}],
    Polygon[{{1.518198, 0.066488, -0.001486},{1.518315, 0.066488, 0.000000},{
      1.517850, 0.069423, 0.000000},{1.517739, 0.069387, -0.001486}}],
    Polygon[{{1.518315, 0.066488, 0.000000},{1.518198, 0.066488, 0.001486},{
      1.517739, 0.069387, 0.001486},{1.517850, 0.069423, 0.000000}}],
    Polygon[{{1.518198, 0.066488, 0.001486},{1.517850, 0.066488, 0.002935},{
      1.517408, 0.069280, 0.002935},{1.517739, 0.069387, 0.001486}}],
    Polygon[{{1.517850, 0.066488, 0.002935},{1.517279, 0.066488, 0.004312},{
      1.516865, 0.069103, 0.004312},{1.517408, 0.069280, 0.002935}}],
    Polygon[{{1.517279, 0.066488, 0.004312},{1.516501, 0.066488, 0.005583},{
      1.516124, 0.068863, 0.005583},{1.516865, 0.069103, 0.004312}}],
    Polygon[{{1.516501, 0.066488, 0.005583},{1.515533, 0.066488, 0.006716},{
      1.515204, 0.068564, 0.006716},{1.516124, 0.068863, 0.005583}}],
    Polygon[{{1.515533, 0.066488, 0.006716},{1.514399, 0.066488, 0.007684},{
      1.514126, 0.068213, 0.007684},{1.515204, 0.068564, 0.006716}}],
    Polygon[{{1.514399, 0.066488, 0.007684},{1.513129, 0.066488, 0.008463},{
      1.512917, 0.067821, 0.008463},{1.514126, 0.068213, 0.007684}}],
    Polygon[{{1.513129, 0.066488, 0.008463},{1.511752, 0.066488, 0.009033},{
      1.511608, 0.067395, 0.009033},{1.512917, 0.067821, 0.008463}}],
    Polygon[{{1.511752, 0.066488, 0.009033},{1.510302, 0.066488, 0.009381},{
      1.510229, 0.066947, 0.009381},{1.511608, 0.067395, 0.009033}}],
    Polygon[{{1.510229, 0.066947, -0.009381},{1.511608, 0.067395, -0.009033},{
      1.511191, 0.068213, -0.009033},{1.510018, 0.067361, -0.009381}}],
    Polygon[{{1.511608, 0.067395, -0.009033},{1.512917, 0.067821, -0.008463},{
      1.512305, 0.069023, -0.008463},{1.511191, 0.068213, -0.009033}}],
    Polygon[{{1.512917, 0.067821, -0.008463},{1.514126, 0.068213, -0.007684},{
      1.513333, 0.069770, -0.007684},{1.512305, 0.069023, -0.008463}}],
    Polygon[{{1.514126, 0.068213, -0.007684},{1.515204, 0.068564, -0.006716},{
      1.514250, 0.070436, -0.006716},{1.513333, 0.069770, -0.007684}}],
    Polygon[{{1.515204, 0.068564, -0.006716},{1.516124, 0.068863, -0.005583},{
      1.515033, 0.071005, -0.005583},{1.514250, 0.070436, -0.006716}}],
    Polygon[{{1.516124, 0.068863, -0.005583},{1.516865, 0.069103, -0.004312},{
      1.515663, 0.071463, -0.004312},{1.515033, 0.071005, -0.005583}}],
    Polygon[{{1.516865, 0.069103, -0.004312},{1.517408, 0.069280, -0.002935},{
      1.516124, 0.071798, -0.002935},{1.515663, 0.071463, -0.004312}}],
    Polygon[{{1.517408, 0.069280, -0.002935},{1.517739, 0.069387, -0.001486},{
      1.516406, 0.072002, -0.001486},{1.516124, 0.071798, -0.002935}}],
    Polygon[{{1.517739, 0.069387, -0.001486},{1.517850, 0.069423, 0.000000},{
      1.516501, 0.072071, 0.000000},{1.516406, 0.072002, -0.001486}}],
    Polygon[{{1.517850, 0.069423, 0.000000},{1.517739, 0.069387, 0.001486},{
      1.516406, 0.072002, 0.001486},{1.516501, 0.072071, 0.000000}}],
    Polygon[{{1.517739, 0.069387, 0.001486},{1.517408, 0.069280, 0.002935},{
      1.516124, 0.071798, 0.002935},{1.516406, 0.072002, 0.001486}}],
    Polygon[{{1.517408, 0.069280, 0.002935},{1.516865, 0.069103, 0.004312},{
      1.515663, 0.071463, 0.004312},{1.516124, 0.071798, 0.002935}}],
    Polygon[{{1.516865, 0.069103, 0.004312},{1.516124, 0.068863, 0.005583},{
      1.515033, 0.071005, 0.005583},{1.515663, 0.071463, 0.004312}}],
    Polygon[{{1.516124, 0.068863, 0.005583},{1.515204, 0.068564, 0.006716},{
      1.514250, 0.070436, 0.006716},{1.515033, 0.071005, 0.005583}}],
    Polygon[{{1.515204, 0.068564, 0.006716},{1.514126, 0.068213, 0.007684},{
      1.513333, 0.069770, 0.007684},{1.514250, 0.070436, 0.006716}}],
    Polygon[{{1.514126, 0.068213, 0.007684},{1.512917, 0.067821, 0.008463},{
      1.512305, 0.069023, 0.008463},{1.513333, 0.069770, 0.007684}}],
    Polygon[{{1.512917, 0.067821, 0.008463},{1.511608, 0.067395, 0.009033},{
      1.511191, 0.068213, 0.009033},{1.512305, 0.069023, 0.008463}}],
    Polygon[{{1.511608, 0.067395, 0.009033},{1.510229, 0.066947, 0.009381},{
      1.510018, 0.067361, 0.009381},{1.511191, 0.068213, 0.009033}}],
    Polygon[{{1.510018, 0.067361, -0.009381},{1.511191, 0.068213, -0.009033},{
      1.510542, 0.068863, -0.009033},{1.509690, 0.067690, -0.009381}}],
    Polygon[{{1.511191, 0.068213, -0.009033},{1.512305, 0.069023, -0.008463},{
      1.511351, 0.069977, -0.008463},{1.510542, 0.068863, -0.009033}}],
    Polygon[{{1.512305, 0.069023, -0.008463},{1.513333, 0.069770, -0.007684},{
      1.512098, 0.071005, -0.007684},{1.511351, 0.069977, -0.008463}}],
    Polygon[{{1.513333, 0.069770, -0.007684},{1.514250, 0.070436, -0.006716},{
      1.512764, 0.071922, -0.006716},{1.512098, 0.071005, -0.007684}}],
    Polygon[{{1.514250, 0.070436, -0.006716},{1.515033, 0.071005, -0.005583},{
      1.513333, 0.072705, -0.005583},{1.512764, 0.071922, -0.006716}}],
    Polygon[{{1.515033, 0.071005, -0.005583},{1.515663, 0.071463, -0.004312},{
      1.513791, 0.073335, -0.004312},{1.513333, 0.072705, -0.005583}}],
    Polygon[{{1.515663, 0.071463, -0.004312},{1.516124, 0.071798, -0.002935},{
      1.514126, 0.073796, -0.002935},{1.513791, 0.073335, -0.004312}}],
    Polygon[{{1.516124, 0.071798, -0.002935},{1.516406, 0.072002, -0.001486},{
      1.514331, 0.074078, -0.001486},{1.514126, 0.073796, -0.002935}}],
    Polygon[{{1.516406, 0.072002, -0.001486},{1.516501, 0.072071, 0.000000},{
      1.514399, 0.074172, 0.000000},{1.514331, 0.074078, -0.001486}}],
    Polygon[{{1.516501, 0.072071, 0.000000},{1.516406, 0.072002, 0.001486},{
      1.514331, 0.074078, 0.001486},{1.514399, 0.074172, 0.000000}}],
    Polygon[{{1.516406, 0.072002, 0.001486},{1.516124, 0.071798, 0.002935},{
      1.514126, 0.073796, 0.002935},{1.514331, 0.074078, 0.001486}}],
    Polygon[{{1.516124, 0.071798, 0.002935},{1.515663, 0.071463, 0.004312},{
      1.513791, 0.073335, 0.004312},{1.514126, 0.073796, 0.002935}}],
    Polygon[{{1.515663, 0.071463, 0.004312},{1.515033, 0.071005, 0.005583},{
      1.513333, 0.072705, 0.005583},{1.513791, 0.073335, 0.004312}}],
    Polygon[{{1.515033, 0.071005, 0.005583},{1.514250, 0.070436, 0.006716},{
      1.512764, 0.071922, 0.006716},{1.513333, 0.072705, 0.005583}}],
    Polygon[{{1.514250, 0.070436, 0.006716},{1.513333, 0.069770, 0.007684},{
      1.512098, 0.071005, 0.007684},{1.512764, 0.071922, 0.006716}}],
    Polygon[{{1.513333, 0.069770, 0.007684},{1.512305, 0.069023, 0.008463},{
      1.511351, 0.069977, 0.008463},{1.512098, 0.071005, 0.007684}}],
    Polygon[{{1.512305, 0.069023, 0.008463},{1.511191, 0.068213, 0.009033},{
      1.510542, 0.068863, 0.009033},{1.511351, 0.069977, 0.008463}}],
    Polygon[{{1.511191, 0.068213, 0.009033},{1.510018, 0.067361, 0.009381},{
      1.509690, 0.067690, 0.009381},{1.510542, 0.068863, 0.009033}}],
    Polygon[{{1.509690, 0.067690, -0.009381},{1.510542, 0.068863, -0.009033},{
      1.509723, 0.069280, -0.009033},{1.509276, 0.067901, -0.009381}}],
    Polygon[{{1.510542, 0.068863, -0.009033},{1.511351, 0.069977, -0.008463},{
      1.510149, 0.070589, -0.008463},{1.509723, 0.069280, -0.009033}}],
    Polygon[{{1.511351, 0.069977, -0.008463},{1.512098, 0.071005, -0.007684},{
      1.510542, 0.071798, -0.007684},{1.510149, 0.070589, -0.008463}}],
    Polygon[{{1.512098, 0.071005, -0.007684},{1.512764, 0.071922, -0.006716},{
      1.510892, 0.072876, -0.006716},{1.510542, 0.071798, -0.007684}}],
    Polygon[{{1.512764, 0.071922, -0.006716},{1.513333, 0.072705, -0.005583},{
      1.511191, 0.073796, -0.005583},{1.510892, 0.072876, -0.006716}}],
    Polygon[{{1.513333, 0.072705, -0.005583},{1.513791, 0.073335, -0.004312},{
      1.511432, 0.074537, -0.004312},{1.511191, 0.073796, -0.005583}}],
    Polygon[{{1.513791, 0.073335, -0.004312},{1.514126, 0.073796, -0.002935},{
      1.511608, 0.075079, -0.002935},{1.511432, 0.074537, -0.004312}}],
    Polygon[{{1.514126, 0.073796, -0.002935},{1.514331, 0.074078, -0.001486},{
      1.511715, 0.075410, -0.001486},{1.511608, 0.075079, -0.002935}}],
    Polygon[{{1.514331, 0.074078, -0.001486},{1.514399, 0.074172, 0.000000},{
      1.511752, 0.075521, 0.000000},{1.511715, 0.075410, -0.001486}}],
    Polygon[{{1.514399, 0.074172, 0.000000},{1.514331, 0.074078, 0.001486},{
      1.511715, 0.075410, 0.001486},{1.511752, 0.075521, 0.000000}}],
    Polygon[{{1.514331, 0.074078, 0.001486},{1.514126, 0.073796, 0.002935},{
      1.511608, 0.075079, 0.002935},{1.511715, 0.075410, 0.001486}}],
    Polygon[{{1.514126, 0.073796, 0.002935},{1.513791, 0.073335, 0.004312},{
      1.511432, 0.074537, 0.004312},{1.511608, 0.075079, 0.002935}}],
    Polygon[{{1.513791, 0.073335, 0.004312},{1.513333, 0.072705, 0.005583},{
      1.511191, 0.073796, 0.005583},{1.511432, 0.074537, 0.004312}}],
    Polygon[{{1.513333, 0.072705, 0.005583},{1.512764, 0.071922, 0.006716},{
      1.510892, 0.072876, 0.006716},{1.511191, 0.073796, 0.005583}}],
    Polygon[{{1.512764, 0.071922, 0.006716},{1.512098, 0.071005, 0.007684},{
      1.510542, 0.071798, 0.007684},{1.510892, 0.072876, 0.006716}}],
    Polygon[{{1.512098, 0.071005, 0.007684},{1.511351, 0.069977, 0.008463},{
      1.510149, 0.070589, 0.008463},{1.510542, 0.071798, 0.007684}}],
    Polygon[{{1.511351, 0.069977, 0.008463},{1.510542, 0.068863, 0.009033},{
      1.509723, 0.069280, 0.009033},{1.510149, 0.070589, 0.008463}}],
    Polygon[{{1.510542, 0.068863, 0.009033},{1.509690, 0.067690, 0.009381},{
      1.509276, 0.067901, 0.009381},{1.509723, 0.069280, 0.009033}}],
    Polygon[{{1.509276, 0.067901, -0.009381},{1.509723, 0.069280, -0.009033},{
      1.508816, 0.069423, -0.009033},{1.508816, 0.067974, -0.009381}}],
    Polygon[{{1.509723, 0.069280, -0.009033},{1.510149, 0.070589, -0.008463},{
      1.508816, 0.070800, -0.008463},{1.508816, 0.069423, -0.009033}}],
    Polygon[{{1.510149, 0.070589, -0.008463},{1.510542, 0.071798, -0.007684},{
      1.508816, 0.072071, -0.007684},{1.508816, 0.070800, -0.008463}}],
    Polygon[{{1.510542, 0.071798, -0.007684},{1.510892, 0.072876, -0.006716},{
      1.508816, 0.073204, -0.006716},{1.508816, 0.072071, -0.007684}}],
    Polygon[{{1.510892, 0.072876, -0.006716},{1.511191, 0.073796, -0.005583},{
      1.508816, 0.074172, -0.005583},{1.508816, 0.073204, -0.006716}}],
    Polygon[{{1.511191, 0.073796, -0.005583},{1.511432, 0.074537, -0.004312},{
      1.508816, 0.074951, -0.004312},{1.508816, 0.074172, -0.005583}}],
    Polygon[{{1.511432, 0.074537, -0.004312},{1.511608, 0.075079, -0.002935},{
      1.508816, 0.075521, -0.002935},{1.508816, 0.074951, -0.004312}}],
    Polygon[{{1.511608, 0.075079, -0.002935},{1.511715, 0.075410, -0.001486},{
      1.508816, 0.075869, -0.001486},{1.508816, 0.075521, -0.002935}}],
    Polygon[{{1.511715, 0.075410, -0.001486},{1.511752, 0.075521, 0.000000},{
      1.508816, 0.075986, 0.000000},{1.508816, 0.075869, -0.001486}}],
    Polygon[{{1.511752, 0.075521, 0.000000},{1.511715, 0.075410, 0.001486},{
      1.508816, 0.075869, 0.001486},{1.508816, 0.075986, 0.000000}}],
    Polygon[{{1.511715, 0.075410, 0.001486},{1.511608, 0.075079, 0.002935},{
      1.508816, 0.075521, 0.002935},{1.508816, 0.075869, 0.001486}}],
    Polygon[{{1.511608, 0.075079, 0.002935},{1.511432, 0.074537, 0.004312},{
      1.508816, 0.074951, 0.004312},{1.508816, 0.075521, 0.002935}}],
    Polygon[{{1.511432, 0.074537, 0.004312},{1.511191, 0.073796, 0.005583},{
      1.508816, 0.074172, 0.005583},{1.508816, 0.074951, 0.004312}}],
    Polygon[{{1.511191, 0.073796, 0.005583},{1.510892, 0.072876, 0.006716},{
      1.508816, 0.073204, 0.006716},{1.508816, 0.074172, 0.005583}}],
    Polygon[{{1.510892, 0.072876, 0.006716},{1.510542, 0.071798, 0.007684},{
      1.508816, 0.072071, 0.007684},{1.508816, 0.073204, 0.006716}}],
    Polygon[{{1.510542, 0.071798, 0.007684},{1.510149, 0.070589, 0.008463},{
      1.508816, 0.070800, 0.008463},{1.508816, 0.072071, 0.007684}}],
    Polygon[{{1.510149, 0.070589, 0.008463},{1.509723, 0.069280, 0.009033},{
      1.508816, 0.069423, 0.009033},{1.508816, 0.070800, 0.008463}}],
    Polygon[{{1.509723, 0.069280, 0.009033},{1.509276, 0.067901, 0.009381},{
      1.508816, 0.067974, 0.009381},{1.508816, 0.069423, 0.009033}}],
    Polygon[{{1.508816, 0.067974, -0.009381},{1.508816, 0.069423, -0.009033},{
      1.507909, 0.069280, -0.009033},{1.508357, 0.067901, -0.009381}}],
    Polygon[{{1.508816, 0.069423, -0.009033},{1.508816, 0.070800, -0.008463},{
      1.507484, 0.070589, -0.008463},{1.507909, 0.069280, -0.009033}}],
    Polygon[{{1.508816, 0.070800, -0.008463},{1.508816, 0.072071, -0.007684},{
      1.507091, 0.071798, -0.007684},{1.507484, 0.070589, -0.008463}}],
    Polygon[{{1.508816, 0.072071, -0.007684},{1.508816, 0.073204, -0.006716},{
      1.506741, 0.072876, -0.006716},{1.507091, 0.071798, -0.007684}}],
    Polygon[{{1.508816, 0.073204, -0.006716},{1.508816, 0.074172, -0.005583},{
      1.506442, 0.073796, -0.005583},{1.506741, 0.072876, -0.006716}}],
    Polygon[{{1.508816, 0.074172, -0.005583},{1.508816, 0.074951, -0.004312},{
      1.506201, 0.074537, -0.004312},{1.506442, 0.073796, -0.005583}}],
    Polygon[{{1.508816, 0.074951, -0.004312},{1.508816, 0.075521, -0.002935},{
      1.506025, 0.075079, -0.002935},{1.506201, 0.074537, -0.004312}}],
    Polygon[{{1.508816, 0.075521, -0.002935},{1.508816, 0.075869, -0.001486},{
      1.505917, 0.075410, -0.001486},{1.506025, 0.075079, -0.002935}}],
    Polygon[{{1.508816, 0.075869, -0.001486},{1.508816, 0.075986, 0.000000},{
      1.505881, 0.075521, 0.000000},{1.505917, 0.075410, -0.001486}}],
    Polygon[{{1.508816, 0.075986, 0.000000},{1.508816, 0.075869, 0.001486},{
      1.505917, 0.075410, 0.001486},{1.505881, 0.075521, 0.000000}}],
    Polygon[{{1.508816, 0.075869, 0.001486},{1.508816, 0.075521, 0.002935},{
      1.506025, 0.075079, 0.002935},{1.505917, 0.075410, 0.001486}}],
    Polygon[{{1.508816, 0.075521, 0.002935},{1.508816, 0.074951, 0.004312},{
      1.506201, 0.074537, 0.004312},{1.506025, 0.075079, 0.002935}}],
    Polygon[{{1.508816, 0.074951, 0.004312},{1.508816, 0.074172, 0.005583},{
      1.506442, 0.073796, 0.005583},{1.506201, 0.074537, 0.004312}}],
    Polygon[{{1.508816, 0.074172, 0.005583},{1.508816, 0.073204, 0.006716},{
      1.506741, 0.072876, 0.006716},{1.506442, 0.073796, 0.005583}}],
    Polygon[{{1.508816, 0.073204, 0.006716},{1.508816, 0.072071, 0.007684},{
      1.507091, 0.071798, 0.007684},{1.506741, 0.072876, 0.006716}}],
    Polygon[{{1.508816, 0.072071, 0.007684},{1.508816, 0.070800, 0.008463},{
      1.507484, 0.070589, 0.008463},{1.507091, 0.071798, 0.007684}}],
    Polygon[{{1.508816, 0.070800, 0.008463},{1.508816, 0.069423, 0.009033},{
      1.507909, 0.069280, 0.009033},{1.507484, 0.070589, 0.008463}}],
    Polygon[{{1.508816, 0.069423, 0.009033},{1.508816, 0.067974, 0.009381},{
      1.508357, 0.067901, 0.009381},{1.507909, 0.069280, 0.009033}}],
    Polygon[{{1.508357, 0.067901, -0.009381},{1.507909, 0.069280, -0.009033},{
      1.507091, 0.068863, -0.009033},{1.507943, 0.067690, -0.009381}}],
    Polygon[{{1.507909, 0.069280, -0.009033},{1.507484, 0.070589, -0.008463},{
      1.506282, 0.069977, -0.008463},{1.507091, 0.068863, -0.009033}}],
    Polygon[{{1.507484, 0.070589, -0.008463},{1.507091, 0.071798, -0.007684},{
      1.505535, 0.071005, -0.007684},{1.506282, 0.069977, -0.008463}}],
    Polygon[{{1.507091, 0.071798, -0.007684},{1.506741, 0.072876, -0.006716},{
      1.504869, 0.071922, -0.006716},{1.505535, 0.071005, -0.007684}}],
    Polygon[{{1.506741, 0.072876, -0.006716},{1.506442, 0.073796, -0.005583},{
      1.504300, 0.072705, -0.005583},{1.504869, 0.071922, -0.006716}}],
    Polygon[{{1.506442, 0.073796, -0.005583},{1.506201, 0.074537, -0.004312},{
      1.503842, 0.073335, -0.004312},{1.504300, 0.072705, -0.005583}}],
    Polygon[{{1.506201, 0.074537, -0.004312},{1.506025, 0.075079, -0.002935},{
      1.503507, 0.073796, -0.002935},{1.503842, 0.073335, -0.004312}}],
    Polygon[{{1.506025, 0.075079, -0.002935},{1.505917, 0.075410, -0.001486},{
      1.503302, 0.074078, -0.001486},{1.503507, 0.073796, -0.002935}}],
    Polygon[{{1.505917, 0.075410, -0.001486},{1.505881, 0.075521, 0.000000},{
      1.503233, 0.074172, 0.000000},{1.503302, 0.074078, -0.001486}}],
    Polygon[{{1.505881, 0.075521, 0.000000},{1.505917, 0.075410, 0.001486},{
      1.503302, 0.074078, 0.001486},{1.503233, 0.074172, 0.000000}}],
    Polygon[{{1.505917, 0.075410, 0.001486},{1.506025, 0.075079, 0.002935},{
      1.503507, 0.073796, 0.002935},{1.503302, 0.074078, 0.001486}}],
    Polygon[{{1.506025, 0.075079, 0.002935},{1.506201, 0.074537, 0.004312},{
      1.503842, 0.073335, 0.004312},{1.503507, 0.073796, 0.002935}}],
    Polygon[{{1.506201, 0.074537, 0.004312},{1.506442, 0.073796, 0.005583},{
      1.504300, 0.072705, 0.005583},{1.503842, 0.073335, 0.004312}}],
    Polygon[{{1.506442, 0.073796, 0.005583},{1.506741, 0.072876, 0.006716},{
      1.504869, 0.071922, 0.006716},{1.504300, 0.072705, 0.005583}}],
    Polygon[{{1.506741, 0.072876, 0.006716},{1.507091, 0.071798, 0.007684},{
      1.505535, 0.071005, 0.007684},{1.504869, 0.071922, 0.006716}}],
    Polygon[{{1.507091, 0.071798, 0.007684},{1.507484, 0.070589, 0.008463},{
      1.506282, 0.069977, 0.008463},{1.505535, 0.071005, 0.007684}}],
    Polygon[{{1.507484, 0.070589, 0.008463},{1.507909, 0.069280, 0.009033},{
      1.507091, 0.068863, 0.009033},{1.506282, 0.069977, 0.008463}}],
    Polygon[{{1.507909, 0.069280, 0.009033},{1.508357, 0.067901, 0.009381},{
      1.507943, 0.067690, 0.009381},{1.507091, 0.068863, 0.009033}}],
    Polygon[{{1.507943, 0.067690, -0.009381},{1.507091, 0.068863, -0.009033},{
      1.506442, 0.068213, -0.009033},{1.507614, 0.067361, -0.009381}}],
    Polygon[{{1.507091, 0.068863, -0.009033},{1.506282, 0.069977, -0.008463},{
      1.505328, 0.069023, -0.008463},{1.506442, 0.068213, -0.009033}}],
    Polygon[{{1.506282, 0.069977, -0.008463},{1.505535, 0.071005, -0.007684},{
      1.504300, 0.069770, -0.007684},{1.505328, 0.069023, -0.008463}}],
    Polygon[{{1.505535, 0.071005, -0.007684},{1.504869, 0.071922, -0.006716},{
      1.503383, 0.070436, -0.006716},{1.504300, 0.069770, -0.007684}}],
    Polygon[{{1.504869, 0.071922, -0.006716},{1.504300, 0.072705, -0.005583},{
      1.502600, 0.071005, -0.005583},{1.503383, 0.070436, -0.006716}}],
    Polygon[{{1.504300, 0.072705, -0.005583},{1.503842, 0.073335, -0.004312},{
      1.501970, 0.071463, -0.004312},{1.502600, 0.071005, -0.005583}}],
    Polygon[{{1.503842, 0.073335, -0.004312},{1.503507, 0.073796, -0.002935},{
      1.501508, 0.071798, -0.002935},{1.501970, 0.071463, -0.004312}}],
    Polygon[{{1.503507, 0.073796, -0.002935},{1.503302, 0.074078, -0.001486},{
      1.501227, 0.072002, -0.001486},{1.501508, 0.071798, -0.002935}}],
    Polygon[{{1.503302, 0.074078, -0.001486},{1.503233, 0.074172, 0.000000},{
      1.501132, 0.072071, 0.000000},{1.501227, 0.072002, -0.001486}}],
    Polygon[{{1.503233, 0.074172, 0.000000},{1.503302, 0.074078, 0.001486},{
      1.501227, 0.072002, 0.001486},{1.501132, 0.072071, 0.000000}}],
    Polygon[{{1.503302, 0.074078, 0.001486},{1.503507, 0.073796, 0.002935},{
      1.501508, 0.071798, 0.002935},{1.501227, 0.072002, 0.001486}}],
    Polygon[{{1.503507, 0.073796, 0.002935},{1.503842, 0.073335, 0.004312},{
      1.501970, 0.071463, 0.004312},{1.501508, 0.071798, 0.002935}}],
    Polygon[{{1.503842, 0.073335, 0.004312},{1.504300, 0.072705, 0.005583},{
      1.502600, 0.071005, 0.005583},{1.501970, 0.071463, 0.004312}}],
    Polygon[{{1.504300, 0.072705, 0.005583},{1.504869, 0.071922, 0.006716},{
      1.503383, 0.070436, 0.006716},{1.502600, 0.071005, 0.005583}}],
    Polygon[{{1.504869, 0.071922, 0.006716},{1.505535, 0.071005, 0.007684},{
      1.504300, 0.069770, 0.007684},{1.503383, 0.070436, 0.006716}}],
    Polygon[{{1.505535, 0.071005, 0.007684},{1.506282, 0.069977, 0.008463},{
      1.505328, 0.069023, 0.008463},{1.504300, 0.069770, 0.007684}}],
    Polygon[{{1.506282, 0.069977, 0.008463},{1.507091, 0.068863, 0.009033},{
      1.506442, 0.068213, 0.009033},{1.505328, 0.069023, 0.008463}}],
    Polygon[{{1.507091, 0.068863, 0.009033},{1.507943, 0.067690, 0.009381},{
      1.507614, 0.067361, 0.009381},{1.506442, 0.068213, 0.009033}}],
    Polygon[{{1.507614, 0.067361, -0.009381},{1.506442, 0.068213, -0.009033},{
      1.506025, 0.067395, -0.009033},{1.507403, 0.066947, -0.009381}}],
    Polygon[{{1.506442, 0.068213, -0.009033},{1.505328, 0.069023, -0.008463},{
      1.504715, 0.067821, -0.008463},{1.506025, 0.067395, -0.009033}}],
    Polygon[{{1.505328, 0.069023, -0.008463},{1.504300, 0.069770, -0.007684},{
      1.503507, 0.068213, -0.007684},{1.504715, 0.067821, -0.008463}}],
    Polygon[{{1.504300, 0.069770, -0.007684},{1.503383, 0.070436, -0.006716},{
      1.502429, 0.068564, -0.006716},{1.503507, 0.068213, -0.007684}}],
    Polygon[{{1.503383, 0.070436, -0.006716},{1.502600, 0.071005, -0.005583},{
      1.501508, 0.068863, -0.005583},{1.502429, 0.068564, -0.006716}}],
    Polygon[{{1.502600, 0.071005, -0.005583},{1.501970, 0.071463, -0.004312},{
      1.500767, 0.069103, -0.004312},{1.501508, 0.068863, -0.005583}}],
    Polygon[{{1.501970, 0.071463, -0.004312},{1.501508, 0.071798, -0.002935},{
      1.500225, 0.069280, -0.002935},{1.500767, 0.069103, -0.004312}}],
    Polygon[{{1.501508, 0.071798, -0.002935},{1.501227, 0.072002, -0.001486},{
      1.499894, 0.069387, -0.001486},{1.500225, 0.069280, -0.002935}}],
    Polygon[{{1.501227, 0.072002, -0.001486},{1.501132, 0.072071, 0.000000},{
      1.499783, 0.069423, 0.000000},{1.499894, 0.069387, -0.001486}}],
    Polygon[{{1.501132, 0.072071, 0.000000},{1.501227, 0.072002, 0.001486},{
      1.499894, 0.069387, 0.001486},{1.499783, 0.069423, 0.000000}}],
    Polygon[{{1.501227, 0.072002, 0.001486},{1.501508, 0.071798, 0.002935},{
      1.500225, 0.069280, 0.002935},{1.499894, 0.069387, 0.001486}}],
    Polygon[{{1.501508, 0.071798, 0.002935},{1.501970, 0.071463, 0.004312},{
      1.500767, 0.069103, 0.004312},{1.500225, 0.069280, 0.002935}}],
    Polygon[{{1.501970, 0.071463, 0.004312},{1.502600, 0.071005, 0.005583},{
      1.501508, 0.068863, 0.005583},{1.500767, 0.069103, 0.004312}}],
    Polygon[{{1.502600, 0.071005, 0.005583},{1.503383, 0.070436, 0.006716},{
      1.502429, 0.068564, 0.006716},{1.501508, 0.068863, 0.005583}}],
    Polygon[{{1.503383, 0.070436, 0.006716},{1.504300, 0.069770, 0.007684},{
      1.503507, 0.068213, 0.007684},{1.502429, 0.068564, 0.006716}}],
    Polygon[{{1.504300, 0.069770, 0.007684},{1.505328, 0.069023, 0.008463},{
      1.504715, 0.067821, 0.008463},{1.503507, 0.068213, 0.007684}}],
    Polygon[{{1.505328, 0.069023, 0.008463},{1.506442, 0.068213, 0.009033},{
      1.506025, 0.067395, 0.009033},{1.504715, 0.067821, 0.008463}}],
    Polygon[{{1.506442, 0.068213, 0.009033},{1.507614, 0.067361, 0.009381},{
      1.507403, 0.066947, 0.009381},{1.506025, 0.067395, 0.009033}}],
    Polygon[{{1.507403, 0.066947, -0.009381},{1.506025, 0.067395, -0.009033},{
      1.505881, 0.066488, -0.009033},{1.507331, 0.066488, -0.009381}}],
    Polygon[{{1.506025, 0.067395, -0.009033},{1.504715, 0.067821, -0.008463},{
      1.504504, 0.066488, -0.008463},{1.505881, 0.066488, -0.009033}}],
    Polygon[{{1.504715, 0.067821, -0.008463},{1.503507, 0.068213, -0.007684},{
      1.503233, 0.066488, -0.007684},{1.504504, 0.066488, -0.008463}}],
    Polygon[{{1.503507, 0.068213, -0.007684},{1.502429, 0.068564, -0.006716},{
      1.502100, 0.066488, -0.006716},{1.503233, 0.066488, -0.007684}}],
    Polygon[{{1.502429, 0.068564, -0.006716},{1.501508, 0.068863, -0.005583},{
      1.501132, 0.066488, -0.005583},{1.502100, 0.066488, -0.006716}}],
    Polygon[{{1.501508, 0.068863, -0.005583},{1.500767, 0.069103, -0.004312},{
      1.500353, 0.066488, -0.004312},{1.501132, 0.066488, -0.005583}}],
    Polygon[{{1.500767, 0.069103, -0.004312},{1.500225, 0.069280, -0.002935},{
      1.499783, 0.066488, -0.002935},{1.500353, 0.066488, -0.004312}}],
    Polygon[{{1.500225, 0.069280, -0.002935},{1.499894, 0.069387, -0.001486},{
      1.499435, 0.066488, -0.001486},{1.499783, 0.066488, -0.002935}}],
    Polygon[{{1.499894, 0.069387, -0.001486},{1.499783, 0.069423, 0.000000},{
      1.499318, 0.066488, 0.000000},{1.499435, 0.066488, -0.001486}}],
    Polygon[{{1.499783, 0.069423, 0.000000},{1.499894, 0.069387, 0.001486},{
      1.499435, 0.066488, 0.001486},{1.499318, 0.066488, 0.000000}}],
    Polygon[{{1.499894, 0.069387, 0.001486},{1.500225, 0.069280, 0.002935},{
      1.499783, 0.066488, 0.002935},{1.499435, 0.066488, 0.001486}}],
    Polygon[{{1.500225, 0.069280, 0.002935},{1.500767, 0.069103, 0.004312},{
      1.500353, 0.066488, 0.004312},{1.499783, 0.066488, 0.002935}}],
    Polygon[{{1.500767, 0.069103, 0.004312},{1.501508, 0.068863, 0.005583},{
      1.501132, 0.066488, 0.005583},{1.500353, 0.066488, 0.004312}}],
    Polygon[{{1.501508, 0.068863, 0.005583},{1.502429, 0.068564, 0.006716},{
      1.502100, 0.066488, 0.006716},{1.501132, 0.066488, 0.005583}}],
    Polygon[{{1.502429, 0.068564, 0.006716},{1.503507, 0.068213, 0.007684},{
      1.503233, 0.066488, 0.007684},{1.502100, 0.066488, 0.006716}}],
    Polygon[{{1.503507, 0.068213, 0.007684},{1.504715, 0.067821, 0.008463},{
      1.504504, 0.066488, 0.008463},{1.503233, 0.066488, 0.007684}}],
    Polygon[{{1.504715, 0.067821, 0.008463},{1.506025, 0.067395, 0.009033},{
      1.505881, 0.066488, 0.009033},{1.504504, 0.066488, 0.008463}}],
    Polygon[{{1.506025, 0.067395, 0.009033},{1.507403, 0.066947, 0.009381},{
      1.507331, 0.066488, 0.009381},{1.505881, 0.066488, 0.009033}}],
    Polygon[{{1.507331, 0.066488, -0.009381},{1.505881, 0.066488, -0.009033},{
      1.506025, 0.065581, -0.009033},{1.507403, 0.066029, -0.009381}}],
    Polygon[{{1.505881, 0.066488, -0.009033},{1.504504, 0.066488, -0.008463},{
      1.504715, 0.065156, -0.008463},{1.506025, 0.065581, -0.009033}}],
    Polygon[{{1.504504, 0.066488, -0.008463},{1.503233, 0.066488, -0.007684},{
      1.503507, 0.064763, -0.007684},{1.504715, 0.065156, -0.008463}}],
    Polygon[{{1.503233, 0.066488, -0.007684},{1.502100, 0.066488, -0.006716},{
      1.502429, 0.064413, -0.006716},{1.503507, 0.064763, -0.007684}}],
    Polygon[{{1.502100, 0.066488, -0.006716},{1.501132, 0.066488, -0.005583},{
      1.501508, 0.064114, -0.005583},{1.502429, 0.064413, -0.006716}}],
    Polygon[{{1.501132, 0.066488, -0.005583},{1.500353, 0.066488, -0.004312},{
      1.500767, 0.063873, -0.004312},{1.501508, 0.064114, -0.005583}}],
    Polygon[{{1.500353, 0.066488, -0.004312},{1.499783, 0.066488, -0.002935},{
      1.500225, 0.063697, -0.002935},{1.500767, 0.063873, -0.004312}}],
    Polygon[{{1.499783, 0.066488, -0.002935},{1.499435, 0.066488, -0.001486},{
      1.499894, 0.063589, -0.001486},{1.500225, 0.063697, -0.002935}}],
    Polygon[{{1.499435, 0.066488, -0.001486},{1.499318, 0.066488, 0.000000},{
      1.499783, 0.063553, 0.000000},{1.499894, 0.063589, -0.001486}}],
    Polygon[{{1.499318, 0.066488, 0.000000},{1.499435, 0.066488, 0.001486},{
      1.499894, 0.063589, 0.001486},{1.499783, 0.063553, 0.000000}}],
    Polygon[{{1.499435, 0.066488, 0.001486},{1.499783, 0.066488, 0.002935},{
      1.500225, 0.063697, 0.002935},{1.499894, 0.063589, 0.001486}}],
    Polygon[{{1.499783, 0.066488, 0.002935},{1.500353, 0.066488, 0.004312},{
      1.500767, 0.063873, 0.004312},{1.500225, 0.063697, 0.002935}}],
    Polygon[{{1.500353, 0.066488, 0.004312},{1.501132, 0.066488, 0.005583},{
      1.501508, 0.064114, 0.005583},{1.500767, 0.063873, 0.004312}}],
    Polygon[{{1.501132, 0.066488, 0.005583},{1.502100, 0.066488, 0.006716},{
      1.502429, 0.064413, 0.006716},{1.501508, 0.064114, 0.005583}}],
    Polygon[{{1.502100, 0.066488, 0.006716},{1.503233, 0.066488, 0.007684},{
      1.503507, 0.064763, 0.007684},{1.502429, 0.064413, 0.006716}}],
    Polygon[{{1.503233, 0.066488, 0.007684},{1.504504, 0.066488, 0.008463},{
      1.504715, 0.065156, 0.008463},{1.503507, 0.064763, 0.007684}}],
    Polygon[{{1.504504, 0.066488, 0.008463},{1.505881, 0.066488, 0.009033},{
      1.506025, 0.065581, 0.009033},{1.504715, 0.065156, 0.008463}}],
    Polygon[{{1.505881, 0.066488, 0.009033},{1.507331, 0.066488, 0.009381},{
      1.507403, 0.066029, 0.009381},{1.506025, 0.065581, 0.009033}}],
    Polygon[{{1.507403, 0.066029, -0.009381},{1.506025, 0.065581, -0.009033},{
      1.506442, 0.064763, -0.009033},{1.507614, 0.065615, -0.009381}}],
    Polygon[{{1.506025, 0.065581, -0.009033},{1.504715, 0.065156, -0.008463},{
      1.505328, 0.063953, -0.008463},{1.506442, 0.064763, -0.009033}}],
    Polygon[{{1.504715, 0.065156, -0.008463},{1.503507, 0.064763, -0.007684},{
      1.504300, 0.063206, -0.007684},{1.505328, 0.063953, -0.008463}}],
    Polygon[{{1.503507, 0.064763, -0.007684},{1.502429, 0.064413, -0.006716},{
      1.503383, 0.062540, -0.006716},{1.504300, 0.063206, -0.007684}}],
    Polygon[{{1.502429, 0.064413, -0.006716},{1.501508, 0.064114, -0.005583},{
      1.502600, 0.061971, -0.005583},{1.503383, 0.062540, -0.006716}}],
    Polygon[{{1.501508, 0.064114, -0.005583},{1.500767, 0.063873, -0.004312},{
      1.501970, 0.061514, -0.004312},{1.502600, 0.061971, -0.005583}}],
    Polygon[{{1.500767, 0.063873, -0.004312},{1.500225, 0.063697, -0.002935},{
      1.501508, 0.061178, -0.002935},{1.501970, 0.061514, -0.004312}}],
    Polygon[{{1.500225, 0.063697, -0.002935},{1.499894, 0.063589, -0.001486},{
      1.501227, 0.060974, -0.001486},{1.501508, 0.061178, -0.002935}}],
    Polygon[{{1.499894, 0.063589, -0.001486},{1.499783, 0.063553, 0.000000},{
      1.501132, 0.060905, 0.000000},{1.501227, 0.060974, -0.001486}}],
    Polygon[{{1.499783, 0.063553, 0.000000},{1.499894, 0.063589, 0.001486},{
      1.501227, 0.060974, 0.001486},{1.501132, 0.060905, 0.000000}}],
    Polygon[{{1.499894, 0.063589, 0.001486},{1.500225, 0.063697, 0.002935},{
      1.501508, 0.061178, 0.002935},{1.501227, 0.060974, 0.001486}}],
    Polygon[{{1.500225, 0.063697, 0.002935},{1.500767, 0.063873, 0.004312},{
      1.501970, 0.061514, 0.004312},{1.501508, 0.061178, 0.002935}}],
    Polygon[{{1.500767, 0.063873, 0.004312},{1.501508, 0.064114, 0.005583},{
      1.502600, 0.061971, 0.005583},{1.501970, 0.061514, 0.004312}}],
    Polygon[{{1.501508, 0.064114, 0.005583},{1.502429, 0.064413, 0.006716},{
      1.503383, 0.062540, 0.006716},{1.502600, 0.061971, 0.005583}}],
    Polygon[{{1.502429, 0.064413, 0.006716},{1.503507, 0.064763, 0.007684},{
      1.504300, 0.063206, 0.007684},{1.503383, 0.062540, 0.006716}}],
    Polygon[{{1.503507, 0.064763, 0.007684},{1.504715, 0.065156, 0.008463},{
      1.505328, 0.063953, 0.008463},{1.504300, 0.063206, 0.007684}}],
    Polygon[{{1.504715, 0.065156, 0.008463},{1.506025, 0.065581, 0.009033},{
      1.506442, 0.064763, 0.009033},{1.505328, 0.063953, 0.008463}}],
    Polygon[{{1.506025, 0.065581, 0.009033},{1.507403, 0.066029, 0.009381},{
      1.507614, 0.065615, 0.009381},{1.506442, 0.064763, 0.009033}}],
    Polygon[{{1.507614, 0.065615, -0.009381},{1.506442, 0.064763, -0.009033},{
      1.507091, 0.064114, -0.009033},{1.507943, 0.065286, -0.009381}}],
    Polygon[{{1.506442, 0.064763, -0.009033},{1.505328, 0.063953, -0.008463},{
      1.506282, 0.062999, -0.008463},{1.507091, 0.064114, -0.009033}}],
    Polygon[{{1.505328, 0.063953, -0.008463},{1.504300, 0.063206, -0.007684},{
      1.505535, 0.061971, -0.007684},{1.506282, 0.062999, -0.008463}}],
    Polygon[{{1.504300, 0.063206, -0.007684},{1.503383, 0.062540, -0.006716},{
      1.504869, 0.061054, -0.006716},{1.505535, 0.061971, -0.007684}}],
    Polygon[{{1.503383, 0.062540, -0.006716},{1.502600, 0.061971, -0.005583},{
      1.504300, 0.060271, -0.005583},{1.504869, 0.061054, -0.006716}}],
    Polygon[{{1.502600, 0.061971, -0.005583},{1.501970, 0.061514, -0.004312},{
      1.503842, 0.059641, -0.004312},{1.504300, 0.060271, -0.005583}}],
    Polygon[{{1.501970, 0.061514, -0.004312},{1.501508, 0.061178, -0.002935},{
      1.503507, 0.059180, -0.002935},{1.503842, 0.059641, -0.004312}}],
    Polygon[{{1.501508, 0.061178, -0.002935},{1.501227, 0.060974, -0.001486},{
      1.503302, 0.058898, -0.001486},{1.503507, 0.059180, -0.002935}}],
    Polygon[{{1.501227, 0.060974, -0.001486},{1.501132, 0.060905, 0.000000},{
      1.503233, 0.058804, 0.000000},{1.503302, 0.058898, -0.001486}}],
    Polygon[{{1.501132, 0.060905, 0.000000},{1.501227, 0.060974, 0.001486},{
      1.503302, 0.058898, 0.001486},{1.503233, 0.058804, 0.000000}}],
    Polygon[{{1.501227, 0.060974, 0.001486},{1.501508, 0.061178, 0.002935},{
      1.503507, 0.059180, 0.002935},{1.503302, 0.058898, 0.001486}}],
    Polygon[{{1.501508, 0.061178, 0.002935},{1.501970, 0.061514, 0.004312},{
      1.503842, 0.059641, 0.004312},{1.503507, 0.059180, 0.002935}}],
    Polygon[{{1.501970, 0.061514, 0.004312},{1.502600, 0.061971, 0.005583},{
      1.504300, 0.060271, 0.005583},{1.503842, 0.059641, 0.004312}}],
    Polygon[{{1.502600, 0.061971, 0.005583},{1.503383, 0.062540, 0.006716},{
      1.504869, 0.061054, 0.006716},{1.504300, 0.060271, 0.005583}}],
    Polygon[{{1.503383, 0.062540, 0.006716},{1.504300, 0.063206, 0.007684},{
      1.505535, 0.061971, 0.007684},{1.504869, 0.061054, 0.006716}}],
    Polygon[{{1.504300, 0.063206, 0.007684},{1.505328, 0.063953, 0.008463},{
      1.506282, 0.062999, 0.008463},{1.505535, 0.061971, 0.007684}}],
    Polygon[{{1.505328, 0.063953, 0.008463},{1.506442, 0.064763, 0.009033},{
      1.507091, 0.064114, 0.009033},{1.506282, 0.062999, 0.008463}}],
    Polygon[{{1.506442, 0.064763, 0.009033},{1.507614, 0.065615, 0.009381},{
      1.507943, 0.065286, 0.009381},{1.507091, 0.064114, 0.009033}}],
    Polygon[{{1.507943, 0.065286, -0.009381},{1.507091, 0.064114, -0.009033},{
      1.507909, 0.063697, -0.009033},{1.508357, 0.065075, -0.009381}}],
    Polygon[{{1.507091, 0.064114, -0.009033},{1.506282, 0.062999, -0.008463},{
      1.507484, 0.062387, -0.008463},{1.507909, 0.063697, -0.009033}}],
    Polygon[{{1.506282, 0.062999, -0.008463},{1.505535, 0.061971, -0.007684},{
      1.507091, 0.061178, -0.007684},{1.507484, 0.062387, -0.008463}}],
    Polygon[{{1.505535, 0.061971, -0.007684},{1.504869, 0.061054, -0.006716},{
      1.506741, 0.060100, -0.006716},{1.507091, 0.061178, -0.007684}}],
    Polygon[{{1.504869, 0.061054, -0.006716},{1.504300, 0.060271, -0.005583},{
      1.506442, 0.059180, -0.005583},{1.506741, 0.060100, -0.006716}}],
    Polygon[{{1.504300, 0.060271, -0.005583},{1.503842, 0.059641, -0.004312},{
      1.506201, 0.058439, -0.004312},{1.506442, 0.059180, -0.005583}}],
    Polygon[{{1.503842, 0.059641, -0.004312},{1.503507, 0.059180, -0.002935},{
      1.506025, 0.057897, -0.002935},{1.506201, 0.058439, -0.004312}}],
    Polygon[{{1.503507, 0.059180, -0.002935},{1.503302, 0.058898, -0.001486},{
      1.505917, 0.057566, -0.001486},{1.506025, 0.057897, -0.002935}}],
    Polygon[{{1.503302, 0.058898, -0.001486},{1.503233, 0.058804, 0.000000},{
      1.505881, 0.057455, 0.000000},{1.505917, 0.057566, -0.001486}}],
    Polygon[{{1.503233, 0.058804, 0.000000},{1.503302, 0.058898, 0.001486},{
      1.505917, 0.057566, 0.001486},{1.505881, 0.057455, 0.000000}}],
    Polygon[{{1.503302, 0.058898, 0.001486},{1.503507, 0.059180, 0.002935},{
      1.506025, 0.057897, 0.002935},{1.505917, 0.057566, 0.001486}}],
    Polygon[{{1.503507, 0.059180, 0.002935},{1.503842, 0.059641, 0.004312},{
      1.506201, 0.058439, 0.004312},{1.506025, 0.057897, 0.002935}}],
    Polygon[{{1.503842, 0.059641, 0.004312},{1.504300, 0.060271, 0.005583},{
      1.506442, 0.059180, 0.005583},{1.506201, 0.058439, 0.004312}}],
    Polygon[{{1.504300, 0.060271, 0.005583},{1.504869, 0.061054, 0.006716},{
      1.506741, 0.060100, 0.006716},{1.506442, 0.059180, 0.005583}}],
    Polygon[{{1.504869, 0.061054, 0.006716},{1.505535, 0.061971, 0.007684},{
      1.507091, 0.061178, 0.007684},{1.506741, 0.060100, 0.006716}}],
    Polygon[{{1.505535, 0.061971, 0.007684},{1.506282, 0.062999, 0.008463},{
      1.507484, 0.062387, 0.008463},{1.507091, 0.061178, 0.007684}}],
    Polygon[{{1.506282, 0.062999, 0.008463},{1.507091, 0.064114, 0.009033},{
      1.507909, 0.063697, 0.009033},{1.507484, 0.062387, 0.008463}}],
    Polygon[{{1.507091, 0.064114, 0.009033},{1.507943, 0.065286, 0.009381},{
      1.508357, 0.065075, 0.009381},{1.507909, 0.063697, 0.009033}}],
    Polygon[{{1.508357, 0.065075, -0.009381},{1.507909, 0.063697, -0.009033},{
      1.508816, 0.063553, -0.009033},{1.508816, 0.065002, -0.009381}}],
    Polygon[{{1.507909, 0.063697, -0.009033},{1.507484, 0.062387, -0.008463},{
      1.508816, 0.062176, -0.008463},{1.508816, 0.063553, -0.009033}}],
    Polygon[{{1.507484, 0.062387, -0.008463},{1.507091, 0.061178, -0.007684},{
      1.508816, 0.060905, -0.007684},{1.508816, 0.062176, -0.008463}}],
    Polygon[{{1.507091, 0.061178, -0.007684},{1.506741, 0.060100, -0.006716},{
      1.508816, 0.059772, -0.006716},{1.508816, 0.060905, -0.007684}}],
    Polygon[{{1.506741, 0.060100, -0.006716},{1.506442, 0.059180, -0.005583},{
      1.508816, 0.058804, -0.005583},{1.508816, 0.059772, -0.006716}}],
    Polygon[{{1.506442, 0.059180, -0.005583},{1.506201, 0.058439, -0.004312},{
      1.508816, 0.058025, -0.004312},{1.508816, 0.058804, -0.005583}}],
    Polygon[{{1.506201, 0.058439, -0.004312},{1.506025, 0.057897, -0.002935},{
      1.508816, 0.057455, -0.002935},{1.508816, 0.058025, -0.004312}}],
    Polygon[{{1.506025, 0.057897, -0.002935},{1.505917, 0.057566, -0.001486},{
      1.508816, 0.057107, -0.001486},{1.508816, 0.057455, -0.002935}}],
    Polygon[{{1.505917, 0.057566, -0.001486},{1.505881, 0.057455, 0.000000},{
      1.508816, 0.056990, 0.000000},{1.508816, 0.057107, -0.001486}}],
    Polygon[{{1.505881, 0.057455, 0.000000},{1.505917, 0.057566, 0.001486},{
      1.508816, 0.057107, 0.001486},{1.508816, 0.056990, 0.000000}}],
    Polygon[{{1.505917, 0.057566, 0.001486},{1.506025, 0.057897, 0.002935},{
      1.508816, 0.057455, 0.002935},{1.508816, 0.057107, 0.001486}}],
    Polygon[{{1.506025, 0.057897, 0.002935},{1.506201, 0.058439, 0.004312},{
      1.508816, 0.058025, 0.004312},{1.508816, 0.057455, 0.002935}}],
    Polygon[{{1.506201, 0.058439, 0.004312},{1.506442, 0.059180, 0.005583},{
      1.508816, 0.058804, 0.005583},{1.508816, 0.058025, 0.004312}}],
    Polygon[{{1.506442, 0.059180, 0.005583},{1.506741, 0.060100, 0.006716},{
      1.508816, 0.059772, 0.006716},{1.508816, 0.058804, 0.005583}}],
    Polygon[{{1.506741, 0.060100, 0.006716},{1.507091, 0.061178, 0.007684},{
      1.508816, 0.060905, 0.007684},{1.508816, 0.059772, 0.006716}}],
    Polygon[{{1.507091, 0.061178, 0.007684},{1.507484, 0.062387, 0.008463},{
      1.508816, 0.062176, 0.008463},{1.508816, 0.060905, 0.007684}}],
    Polygon[{{1.507484, 0.062387, 0.008463},{1.507909, 0.063697, 0.009033},{
      1.508816, 0.063553, 0.009033},{1.508816, 0.062176, 0.008463}}],
    Polygon[{{1.507909, 0.063697, 0.009033},{1.508357, 0.065075, 0.009381},{
      1.508816, 0.065002, 0.009381},{1.508816, 0.063553, 0.009033}}],
    Polygon[{{1.508816, 0.065002, -0.009381},{1.508816, 0.063553, -0.009033},{
      1.509723, 0.063697, -0.009033},{1.509276, 0.065075, -0.009381}}],
    Polygon[{{1.508816, 0.063553, -0.009033},{1.508816, 0.062176, -0.008463},{
      1.510149, 0.062387, -0.008463},{1.509723, 0.063697, -0.009033}}],
    Polygon[{{1.508816, 0.062176, -0.008463},{1.508816, 0.060905, -0.007684},{
      1.510542, 0.061178, -0.007684},{1.510149, 0.062387, -0.008463}}],
    Polygon[{{1.508816, 0.060905, -0.007684},{1.508816, 0.059772, -0.006716},{
      1.510892, 0.060100, -0.006716},{1.510542, 0.061178, -0.007684}}],
    Polygon[{{1.508816, 0.059772, -0.006716},{1.508816, 0.058804, -0.005583},{
      1.511191, 0.059180, -0.005583},{1.510892, 0.060100, -0.006716}}],
    Polygon[{{1.508816, 0.058804, -0.005583},{1.508816, 0.058025, -0.004312},{
      1.511432, 0.058439, -0.004312},{1.511191, 0.059180, -0.005583}}],
    Polygon[{{1.508816, 0.058025, -0.004312},{1.508816, 0.057455, -0.002935},{
      1.511608, 0.057897, -0.002935},{1.511432, 0.058439, -0.004312}}],
    Polygon[{{1.508816, 0.057455, -0.002935},{1.508816, 0.057107, -0.001486},{
      1.511715, 0.057566, -0.001486},{1.511608, 0.057897, -0.002935}}],
    Polygon[{{1.508816, 0.057107, -0.001486},{1.508816, 0.056990, 0.000000},{
      1.511752, 0.057455, 0.000000},{1.511715, 0.057566, -0.001486}}],
    Polygon[{{1.508816, 0.056990, 0.000000},{1.508816, 0.057107, 0.001486},{
      1.511715, 0.057566, 0.001486},{1.511752, 0.057455, 0.000000}}],
    Polygon[{{1.508816, 0.057107, 0.001486},{1.508816, 0.057455, 0.002935},{
      1.511608, 0.057897, 0.002935},{1.511715, 0.057566, 0.001486}}],
    Polygon[{{1.508816, 0.057455, 0.002935},{1.508816, 0.058025, 0.004312},{
      1.511432, 0.058439, 0.004312},{1.511608, 0.057897, 0.002935}}],
    Polygon[{{1.508816, 0.058025, 0.004312},{1.508816, 0.058804, 0.005583},{
      1.511191, 0.059180, 0.005583},{1.511432, 0.058439, 0.004312}}],
    Polygon[{{1.508816, 0.058804, 0.005583},{1.508816, 0.059772, 0.006716},{
      1.510892, 0.060100, 0.006716},{1.511191, 0.059180, 0.005583}}],
    Polygon[{{1.508816, 0.059772, 0.006716},{1.508816, 0.060905, 0.007684},{
      1.510542, 0.061178, 0.007684},{1.510892, 0.060100, 0.006716}}],
    Polygon[{{1.508816, 0.060905, 0.007684},{1.508816, 0.062176, 0.008463},{
      1.510149, 0.062387, 0.008463},{1.510542, 0.061178, 0.007684}}],
    Polygon[{{1.508816, 0.062176, 0.008463},{1.508816, 0.063553, 0.009033},{
      1.509723, 0.063697, 0.009033},{1.510149, 0.062387, 0.008463}}],
    Polygon[{{1.508816, 0.063553, 0.009033},{1.508816, 0.065002, 0.009381},{
      1.509276, 0.065075, 0.009381},{1.509723, 0.063697, 0.009033}}],
    Polygon[{{1.509276, 0.065075, -0.009381},{1.509723, 0.063697, -0.009033},{
      1.510542, 0.064114, -0.009033},{1.509690, 0.065286, -0.009381}}],
    Polygon[{{1.509723, 0.063697, -0.009033},{1.510149, 0.062387, -0.008463},{
      1.511351, 0.062999, -0.008463},{1.510542, 0.064114, -0.009033}}],
    Polygon[{{1.510149, 0.062387, -0.008463},{1.510542, 0.061178, -0.007684},{
      1.512098, 0.061971, -0.007684},{1.511351, 0.062999, -0.008463}}],
    Polygon[{{1.510542, 0.061178, -0.007684},{1.510892, 0.060100, -0.006716},{
      1.512764, 0.061054, -0.006716},{1.512098, 0.061971, -0.007684}}],
    Polygon[{{1.510892, 0.060100, -0.006716},{1.511191, 0.059180, -0.005583},{
      1.513333, 0.060271, -0.005583},{1.512764, 0.061054, -0.006716}}],
    Polygon[{{1.511191, 0.059180, -0.005583},{1.511432, 0.058439, -0.004312},{
      1.513791, 0.059641, -0.004312},{1.513333, 0.060271, -0.005583}}],
    Polygon[{{1.511432, 0.058439, -0.004312},{1.511608, 0.057897, -0.002935},{
      1.514126, 0.059180, -0.002935},{1.513791, 0.059641, -0.004312}}],
    Polygon[{{1.511608, 0.057897, -0.002935},{1.511715, 0.057566, -0.001486},{
      1.514331, 0.058898, -0.001486},{1.514126, 0.059180, -0.002935}}],
    Polygon[{{1.511715, 0.057566, -0.001486},{1.511752, 0.057455, 0.000000},{
      1.514399, 0.058804, 0.000000},{1.514331, 0.058898, -0.001486}}],
    Polygon[{{1.511752, 0.057455, 0.000000},{1.511715, 0.057566, 0.001486},{
      1.514331, 0.058898, 0.001486},{1.514399, 0.058804, 0.000000}}],
    Polygon[{{1.511715, 0.057566, 0.001486},{1.511608, 0.057897, 0.002935},{
      1.514126, 0.059180, 0.002935},{1.514331, 0.058898, 0.001486}}],
    Polygon[{{1.511608, 0.057897, 0.002935},{1.511432, 0.058439, 0.004312},{
      1.513791, 0.059641, 0.004312},{1.514126, 0.059180, 0.002935}}],
    Polygon[{{1.511432, 0.058439, 0.004312},{1.511191, 0.059180, 0.005583},{
      1.513333, 0.060271, 0.005583},{1.513791, 0.059641, 0.004312}}],
    Polygon[{{1.511191, 0.059180, 0.005583},{1.510892, 0.060100, 0.006716},{
      1.512764, 0.061054, 0.006716},{1.513333, 0.060271, 0.005583}}],
    Polygon[{{1.510892, 0.060100, 0.006716},{1.510542, 0.061178, 0.007684},{
      1.512098, 0.061971, 0.007684},{1.512764, 0.061054, 0.006716}}],
    Polygon[{{1.510542, 0.061178, 0.007684},{1.510149, 0.062387, 0.008463},{
      1.511351, 0.062999, 0.008463},{1.512098, 0.061971, 0.007684}}],
    Polygon[{{1.510149, 0.062387, 0.008463},{1.509723, 0.063697, 0.009033},{
      1.510542, 0.064114, 0.009033},{1.511351, 0.062999, 0.008463}}],
    Polygon[{{1.509723, 0.063697, 0.009033},{1.509276, 0.065075, 0.009381},{
      1.509690, 0.065286, 0.009381},{1.510542, 0.064114, 0.009033}}],
    Polygon[{{1.509690, 0.065286, -0.009381},{1.510542, 0.064114, -0.009033},{
      1.511191, 0.064763, -0.009033},{1.510018, 0.065615, -0.009381}}],
    Polygon[{{1.510542, 0.064114, -0.009033},{1.511351, 0.062999, -0.008463},{
      1.512305, 0.063953, -0.008463},{1.511191, 0.064763, -0.009033}}],
    Polygon[{{1.511351, 0.062999, -0.008463},{1.512098, 0.061971, -0.007684},{
      1.513333, 0.063206, -0.007684},{1.512305, 0.063953, -0.008463}}],
    Polygon[{{1.512098, 0.061971, -0.007684},{1.512764, 0.061054, -0.006716},{
      1.514250, 0.062540, -0.006716},{1.513333, 0.063206, -0.007684}}],
    Polygon[{{1.512764, 0.061054, -0.006716},{1.513333, 0.060271, -0.005583},{
      1.515033, 0.061971, -0.005583},{1.514250, 0.062540, -0.006716}}],
    Polygon[{{1.513333, 0.060271, -0.005583},{1.513791, 0.059641, -0.004312},{
      1.515663, 0.061514, -0.004312},{1.515033, 0.061971, -0.005583}}],
    Polygon[{{1.513791, 0.059641, -0.004312},{1.514126, 0.059180, -0.002935},{
      1.516124, 0.061178, -0.002935},{1.515663, 0.061514, -0.004312}}],
    Polygon[{{1.514126, 0.059180, -0.002935},{1.514331, 0.058898, -0.001486},{
      1.516406, 0.060974, -0.001486},{1.516124, 0.061178, -0.002935}}],
    Polygon[{{1.514331, 0.058898, -0.001486},{1.514399, 0.058804, 0.000000},{
      1.516501, 0.060905, 0.000000},{1.516406, 0.060974, -0.001486}}],
    Polygon[{{1.514399, 0.058804, 0.000000},{1.514331, 0.058898, 0.001486},{
      1.516406, 0.060974, 0.001486},{1.516501, 0.060905, 0.000000}}],
    Polygon[{{1.514331, 0.058898, 0.001486},{1.514126, 0.059180, 0.002935},{
      1.516124, 0.061178, 0.002935},{1.516406, 0.060974, 0.001486}}],
    Polygon[{{1.514126, 0.059180, 0.002935},{1.513791, 0.059641, 0.004312},{
      1.515663, 0.061514, 0.004312},{1.516124, 0.061178, 0.002935}}],
    Polygon[{{1.513791, 0.059641, 0.004312},{1.513333, 0.060271, 0.005583},{
      1.515033, 0.061971, 0.005583},{1.515663, 0.061514, 0.004312}}],
    Polygon[{{1.513333, 0.060271, 0.005583},{1.512764, 0.061054, 0.006716},{
      1.514250, 0.062540, 0.006716},{1.515033, 0.061971, 0.005583}}],
    Polygon[{{1.512764, 0.061054, 0.006716},{1.512098, 0.061971, 0.007684},{
      1.513333, 0.063206, 0.007684},{1.514250, 0.062540, 0.006716}}],
    Polygon[{{1.512098, 0.061971, 0.007684},{1.511351, 0.062999, 0.008463},{
      1.512305, 0.063953, 0.008463},{1.513333, 0.063206, 0.007684}}],
    Polygon[{{1.511351, 0.062999, 0.008463},{1.510542, 0.064114, 0.009033},{
      1.511191, 0.064763, 0.009033},{1.512305, 0.063953, 0.008463}}],
    Polygon[{{1.510542, 0.064114, 0.009033},{1.509690, 0.065286, 0.009381},{
      1.510018, 0.065615, 0.009381},{1.511191, 0.064763, 0.009033}}],
    Polygon[{{1.510018, 0.065615, -0.009381},{1.511191, 0.064763, -0.009033},{
      1.511608, 0.065581, -0.009033},{1.510229, 0.066029, -0.009381}}],
    Polygon[{{1.511191, 0.064763, -0.009033},{1.512305, 0.063953, -0.008463},{
      1.512917, 0.065156, -0.008463},{1.511608, 0.065581, -0.009033}}],
    Polygon[{{1.512305, 0.063953, -0.008463},{1.513333, 0.063206, -0.007684},{
      1.514126, 0.064763, -0.007684},{1.512917, 0.065156, -0.008463}}],
    Polygon[{{1.513333, 0.063206, -0.007684},{1.514250, 0.062540, -0.006716},{
      1.515204, 0.064413, -0.006716},{1.514126, 0.064763, -0.007684}}],
    Polygon[{{1.514250, 0.062540, -0.006716},{1.515033, 0.061971, -0.005583},{
      1.516124, 0.064114, -0.005583},{1.515204, 0.064413, -0.006716}}],
    Polygon[{{1.515033, 0.061971, -0.005583},{1.515663, 0.061514, -0.004312},{
      1.516865, 0.063873, -0.004312},{1.516124, 0.064114, -0.005583}}],
    Polygon[{{1.515663, 0.061514, -0.004312},{1.516124, 0.061178, -0.002935},{
      1.517408, 0.063697, -0.002935},{1.516865, 0.063873, -0.004312}}],
    Polygon[{{1.516124, 0.061178, -0.002935},{1.516406, 0.060974, -0.001486},{
      1.517739, 0.063589, -0.001486},{1.517408, 0.063697, -0.002935}}],
    Polygon[{{1.516406, 0.060974, -0.001486},{1.516501, 0.060905, 0.000000},{
      1.517850, 0.063553, 0.000000},{1.517739, 0.063589, -0.001486}}],
    Polygon[{{1.516501, 0.060905, 0.000000},{1.516406, 0.060974, 0.001486},{
      1.517739, 0.063589, 0.001486},{1.517850, 0.063553, 0.000000}}],
    Polygon[{{1.516406, 0.060974, 0.001486},{1.516124, 0.061178, 0.002935},{
      1.517408, 0.063697, 0.002935},{1.517739, 0.063589, 0.001486}}],
    Polygon[{{1.516124, 0.061178, 0.002935},{1.515663, 0.061514, 0.004312},{
      1.516865, 0.063873, 0.004312},{1.517408, 0.063697, 0.002935}}],
    Polygon[{{1.515663, 0.061514, 0.004312},{1.515033, 0.061971, 0.005583},{
      1.516124, 0.064114, 0.005583},{1.516865, 0.063873, 0.004312}}],
    Polygon[{{1.515033, 0.061971, 0.005583},{1.514250, 0.062540, 0.006716},{
      1.515204, 0.064413, 0.006716},{1.516124, 0.064114, 0.005583}}],
    Polygon[{{1.514250, 0.062540, 0.006716},{1.513333, 0.063206, 0.007684},{
      1.514126, 0.064763, 0.007684},{1.515204, 0.064413, 0.006716}}],
    Polygon[{{1.513333, 0.063206, 0.007684},{1.512305, 0.063953, 0.008463},{
      1.512917, 0.065156, 0.008463},{1.514126, 0.064763, 0.007684}}],
    Polygon[{{1.512305, 0.063953, 0.008463},{1.511191, 0.064763, 0.009033},{
      1.511608, 0.065581, 0.009033},{1.512917, 0.065156, 0.008463}}],
    Polygon[{{1.511191, 0.064763, 0.009033},{1.510018, 0.065615, 0.009381},{
      1.510229, 0.066029, 0.009381},{1.511608, 0.065581, 0.009033}}],
    Polygon[{{1.510229, 0.066029, -0.009381},{1.511608, 0.065581, -0.009033},{
      1.511752, 0.066488, -0.009033},{1.510302, 0.066488, -0.009381}}],
    Polygon[{{1.511608, 0.065581, -0.009033},{1.512917, 0.065156, -0.008463},{
      1.513129, 0.066488, -0.008463},{1.511752, 0.066488, -0.009033}}],
    Polygon[{{1.512917, 0.065156, -0.008463},{1.514126, 0.064763, -0.007684},{
      1.514399, 0.066488, -0.007684},{1.513129, 0.066488, -0.008463}}],
    Polygon[{{1.514126, 0.064763, -0.007684},{1.515204, 0.064413, -0.006716},{
      1.515533, 0.066488, -0.006716},{1.514399, 0.066488, -0.007684}}],
    Polygon[{{1.515204, 0.064413, -0.006716},{1.516124, 0.064114, -0.005583},{
      1.516501, 0.066488, -0.005583},{1.515533, 0.066488, -0.006716}}],
    Polygon[{{1.516124, 0.064114, -0.005583},{1.516865, 0.063873, -0.004312},{
      1.517279, 0.066488, -0.004312},{1.516501, 0.066488, -0.005583}}],
    Polygon[{{1.516865, 0.063873, -0.004312},{1.517408, 0.063697, -0.002935},{
      1.517850, 0.066488, -0.002935},{1.517279, 0.066488, -0.004312}}],
    Polygon[{{1.517408, 0.063697, -0.002935},{1.517739, 0.063589, -0.001486},{
      1.518198, 0.066488, -0.001486},{1.517850, 0.066488, -0.002935}}],
    Polygon[{{1.517739, 0.063589, -0.001486},{1.517850, 0.063553, 0.000000},{
      1.518315, 0.066488, 0.000000},{1.518198, 0.066488, -0.001486}}],
    Polygon[{{1.517850, 0.063553, 0.000000},{1.517739, 0.063589, 0.001486},{
      1.518198, 0.066488, 0.001486},{1.518315, 0.066488, 0.000000}}],
    Polygon[{{1.517739, 0.063589, 0.001486},{1.517408, 0.063697, 0.002935},{
      1.517850, 0.066488, 0.002935},{1.518198, 0.066488, 0.001486}}],
    Polygon[{{1.517408, 0.063697, 0.002935},{1.516865, 0.063873, 0.004312},{
      1.517279, 0.066488, 0.004312},{1.517850, 0.066488, 0.002935}}],
    Polygon[{{1.516865, 0.063873, 0.004312},{1.516124, 0.064114, 0.005583},{
      1.516501, 0.066488, 0.005583},{1.517279, 0.066488, 0.004312}}],
    Polygon[{{1.516124, 0.064114, 0.005583},{1.515204, 0.064413, 0.006716},{
      1.515533, 0.066488, 0.006716},{1.516501, 0.066488, 0.005583}}],
    Polygon[{{1.515204, 0.064413, 0.006716},{1.514126, 0.064763, 0.007684},{
      1.514399, 0.066488, 0.007684},{1.515533, 0.066488, 0.006716}}],
    Polygon[{{1.514126, 0.064763, 0.007684},{1.512917, 0.065156, 0.008463},{
      1.513129, 0.066488, 0.008463},{1.514399, 0.066488, 0.007684}}],
    Polygon[{{1.512917, 0.065156, 0.008463},{1.511608, 0.065581, 0.009033},{
      1.511752, 0.066488, 0.009033},{1.513129, 0.066488, 0.008463}}],
    Polygon[{{1.511608, 0.065581, 0.009033},{1.510229, 0.066029, 0.009381},{
      1.510302, 0.066488, 0.009381},{1.511752, 0.066488, 0.009033}}],
    Polygon[{{1.453578, 0.176266, -0.024871},{1.457420, 0.176266, -0.023948},{
      1.457039, 0.178670, -0.023948},{1.453385, 0.177483, -0.024871}}],
    Polygon[{{1.457420, 0.176266, -0.023948},{1.461070, 0.176266, -0.022436},{
      1.460511, 0.179798, -0.022436},{1.457039, 0.178670, -0.023948}}],
    Polygon[{{1.461070, 0.176266, -0.022436},{1.464439, 0.176266, -0.020372},{
      1.463715, 0.180839, -0.020372},{1.460511, 0.179798, -0.022436}}],
    Polygon[{{1.464439, 0.176266, -0.020372},{1.467444, 0.176266, -0.017806},{
      1.466573, 0.181768, -0.017806},{1.463715, 0.180839, -0.020372}}],
    Polygon[{{1.467444, 0.176266, -0.017806},{1.470010, 0.176266, -0.014801},{
      1.469013, 0.182561, -0.014801},{1.466573, 0.181768, -0.017806}}],
    Polygon[{{1.470010, 0.176266, -0.014801},{1.472075, 0.176266, -0.011432},{
      1.470977, 0.183199, -0.011432},{1.469013, 0.182561, -0.014801}}],
    Polygon[{{1.472075, 0.176266, -0.011432},{1.473587, 0.176266, -0.007781},{
      1.472415, 0.183666, -0.007781},{1.470977, 0.183199, -0.011432}}],
    Polygon[{{1.473587, 0.176266, -0.007781},{1.474509, 0.176266, -0.003939},{
      1.473292, 0.183951, -0.003939},{1.472415, 0.183666, -0.007781}}],
    Polygon[{{1.474509, 0.176266, -0.003939},{1.474819, 0.176266, 0.000000},{
      1.473587, 0.184047, 0.000000},{1.473292, 0.183951, -0.003939}}],
    Polygon[{{1.474819, 0.176266, 0.000000},{1.474509, 0.176266, 0.003939},{
      1.473292, 0.183951, 0.003939},{1.473587, 0.184047, 0.000000}}],
    Polygon[{{1.474509, 0.176266, 0.003939},{1.473587, 0.176266, 0.007781},{
      1.472415, 0.183666, 0.007781},{1.473292, 0.183951, 0.003939}}],
    Polygon[{{1.473587, 0.176266, 0.007781},{1.472075, 0.176266, 0.011432},{
      1.470977, 0.183199, 0.011432},{1.472415, 0.183666, 0.007781}}],
    Polygon[{{1.472075, 0.176266, 0.011432},{1.470010, 0.176266, 0.014801},{
      1.469013, 0.182561, 0.014801},{1.470977, 0.183199, 0.011432}}],
    Polygon[{{1.470010, 0.176266, 0.014801},{1.467444, 0.176266, 0.017806},{
      1.466573, 0.181768, 0.017806},{1.469013, 0.182561, 0.014801}}],
    Polygon[{{1.467444, 0.176266, 0.017806},{1.464439, 0.176266, 0.020372},{
      1.463715, 0.180839, 0.020372},{1.466573, 0.181768, 0.017806}}],
    Polygon[{{1.464439, 0.176266, 0.020372},{1.461070, 0.176266, 0.022436},{
      1.460511, 0.179798, 0.022436},{1.463715, 0.180839, 0.020372}}],
    Polygon[{{1.461070, 0.176266, 0.022436},{1.457420, 0.176266, 0.023948},{
      1.457039, 0.178670, 0.023948},{1.460511, 0.179798, 0.022436}}],
    Polygon[{{1.457420, 0.176266, 0.023948},{1.453578, 0.176266, 0.024871},{
      1.453385, 0.177483, 0.024871},{1.457039, 0.178670, 0.023948}}],
    Polygon[{{1.453385, 0.177483, -0.024871},{1.457039, 0.178670, -0.023948},{
      1.455934, 0.180839, -0.023948},{1.452825, 0.178581, -0.024871}}],
    Polygon[{{1.457039, 0.178670, -0.023948},{1.460511, 0.179798, -0.022436},{
      1.458887, 0.182985, -0.022436},{1.455934, 0.180839, -0.023948}}],
    Polygon[{{1.460511, 0.179798, -0.022436},{1.463715, 0.180839, -0.020372},{
      1.461613, 0.184965, -0.020372},{1.458887, 0.182985, -0.022436}}],
    Polygon[{{1.463715, 0.180839, -0.020372},{1.466573, 0.181768, -0.017806},{
      1.464043, 0.186731, -0.017806},{1.461613, 0.184965, -0.020372}}],
    Polygon[{{1.466573, 0.181768, -0.017806},{1.469013, 0.182561, -0.014801},{
      1.466119, 0.188240, -0.014801},{1.464043, 0.186731, -0.017806}}],
    Polygon[{{1.469013, 0.182561, -0.014801},{1.470977, 0.183199, -0.011432},{
      1.467790, 0.189453, -0.011432},{1.466119, 0.188240, -0.014801}}],
    Polygon[{{1.470977, 0.183199, -0.011432},{1.472415, 0.183666, -0.007781},{
      1.469013, 0.190342, -0.007781},{1.467790, 0.189453, -0.011432}}],
    Polygon[{{1.472415, 0.183666, -0.007781},{1.473292, 0.183951, -0.003939},{
      1.469759, 0.190884, -0.003939},{1.469013, 0.190342, -0.007781}}],
    Polygon[{{1.473292, 0.183951, -0.003939},{1.473587, 0.184047, 0.000000},{
      1.470010, 0.191066, 0.000000},{1.469759, 0.190884, -0.003939}}],
    Polygon[{{1.473587, 0.184047, 0.000000},{1.473292, 0.183951, 0.003939},{
      1.469759, 0.190884, 0.003939},{1.470010, 0.191066, 0.000000}}],
    Polygon[{{1.473292, 0.183951, 0.003939},{1.472415, 0.183666, 0.007781},{
      1.469013, 0.190342, 0.007781},{1.469759, 0.190884, 0.003939}}],
    Polygon[{{1.472415, 0.183666, 0.007781},{1.470977, 0.183199, 0.011432},{
      1.467790, 0.189453, 0.011432},{1.469013, 0.190342, 0.007781}}],
    Polygon[{{1.470977, 0.183199, 0.011432},{1.469013, 0.182561, 0.014801},{
      1.466119, 0.188240, 0.014801},{1.467790, 0.189453, 0.011432}}],
    Polygon[{{1.469013, 0.182561, 0.014801},{1.466573, 0.181768, 0.017806},{
      1.464043, 0.186731, 0.017806},{1.466119, 0.188240, 0.014801}}],
    Polygon[{{1.466573, 0.181768, 0.017806},{1.463715, 0.180839, 0.020372},{
      1.461613, 0.184965, 0.020372},{1.464043, 0.186731, 0.017806}}],
    Polygon[{{1.463715, 0.180839, 0.020372},{1.460511, 0.179798, 0.022436},{
      1.458887, 0.182985, 0.022436},{1.461613, 0.184965, 0.020372}}],
    Polygon[{{1.460511, 0.179798, 0.022436},{1.457039, 0.178670, 0.023948},{
      1.455934, 0.180839, 0.023948},{1.458887, 0.182985, 0.022436}}],
    Polygon[{{1.457039, 0.178670, 0.023948},{1.453385, 0.177483, 0.024871},{
      1.452825, 0.178581, 0.024871},{1.455934, 0.180839, 0.023948}}],
    Polygon[{{1.452825, 0.178581, -0.024871},{1.455934, 0.180839, -0.023948},{
      1.454212, 0.182561, -0.023948},{1.451954, 0.179452, -0.024871}}],
    Polygon[{{1.455934, 0.180839, -0.023948},{1.458887, 0.182985, -0.022436},{
      1.456358, 0.185514, -0.022436},{1.454212, 0.182561, -0.023948}}],
    Polygon[{{1.458887, 0.182985, -0.022436},{1.461613, 0.184965, -0.020372},{
      1.458338, 0.188240, -0.020372},{1.456358, 0.185514, -0.022436}}],
    Polygon[{{1.461613, 0.184965, -0.020372},{1.464043, 0.186731, -0.017806},{
      1.460104, 0.190670, -0.017806},{1.458338, 0.188240, -0.020372}}],
    Polygon[{{1.464043, 0.186731, -0.017806},{1.466119, 0.188240, -0.014801},{
      1.461613, 0.192747, -0.014801},{1.460104, 0.190670, -0.017806}}],
    Polygon[{{1.466119, 0.188240, -0.014801},{1.467790, 0.189453, -0.011432},{
      1.462826, 0.194417, -0.011432},{1.461613, 0.192747, -0.014801}}],
    Polygon[{{1.467790, 0.189453, -0.011432},{1.469013, 0.190342, -0.007781},{
      1.463715, 0.195640, -0.007781},{1.462826, 0.194417, -0.011432}}],
    Polygon[{{1.469013, 0.190342, -0.007781},{1.469759, 0.190884, -0.003939},{
      1.464257, 0.196386, -0.003939},{1.463715, 0.195640, -0.007781}}],
    Polygon[{{1.469759, 0.190884, -0.003939},{1.470010, 0.191066, 0.000000},{
      1.464439, 0.196637, 0.000000},{1.464257, 0.196386, -0.003939}}],
    Polygon[{{1.470010, 0.191066, 0.000000},{1.469759, 0.190884, 0.003939},{
      1.464257, 0.196386, 0.003939},{1.464439, 0.196637, 0.000000}}],
    Polygon[{{1.469759, 0.190884, 0.003939},{1.469013, 0.190342, 0.007781},{
      1.463715, 0.195640, 0.007781},{1.464257, 0.196386, 0.003939}}],
    Polygon[{{1.469013, 0.190342, 0.007781},{1.467790, 0.189453, 0.011432},{
      1.462826, 0.194417, 0.011432},{1.463715, 0.195640, 0.007781}}],
    Polygon[{{1.467790, 0.189453, 0.011432},{1.466119, 0.188240, 0.014801},{
      1.461613, 0.192747, 0.014801},{1.462826, 0.194417, 0.011432}}],
    Polygon[{{1.466119, 0.188240, 0.014801},{1.464043, 0.186731, 0.017806},{
      1.460104, 0.190670, 0.017806},{1.461613, 0.192747, 0.014801}}],
    Polygon[{{1.464043, 0.186731, 0.017806},{1.461613, 0.184965, 0.020372},{
      1.458338, 0.188240, 0.020372},{1.460104, 0.190670, 0.017806}}],
    Polygon[{{1.461613, 0.184965, 0.020372},{1.458887, 0.182985, 0.022436},{
      1.456358, 0.185514, 0.022436},{1.458338, 0.188240, 0.020372}}],
    Polygon[{{1.458887, 0.182985, 0.022436},{1.455934, 0.180839, 0.023948},{
      1.454212, 0.182561, 0.023948},{1.456358, 0.185514, 0.022436}}],
    Polygon[{{1.455934, 0.180839, 0.023948},{1.452825, 0.178581, 0.024871},{
      1.451954, 0.179452, 0.024871},{1.454212, 0.182561, 0.023948}}],
    Polygon[{{1.451954, 0.179452, -0.024871},{1.454212, 0.182561, -0.023948},{
      1.452043, 0.183666, -0.023948},{1.450856, 0.180012, -0.024871}}],
    Polygon[{{1.454212, 0.182561, -0.023948},{1.456358, 0.185514, -0.022436},{
      1.453171, 0.187138, -0.022436},{1.452043, 0.183666, -0.023948}}],
    Polygon[{{1.456358, 0.185514, -0.022436},{1.458338, 0.188240, -0.020372},{
      1.454212, 0.190342, -0.020372},{1.453171, 0.187138, -0.022436}}],
    Polygon[{{1.458338, 0.188240, -0.020372},{1.460104, 0.190670, -0.017806},{
      1.455141, 0.193200, -0.017806},{1.454212, 0.190342, -0.020372}}],
    Polygon[{{1.460104, 0.190670, -0.017806},{1.461613, 0.192747, -0.014801},{
      1.455934, 0.195640, -0.014801},{1.455141, 0.193200, -0.017806}}],
    Polygon[{{1.461613, 0.192747, -0.014801},{1.462826, 0.194417, -0.011432},{
      1.456572, 0.197604, -0.011432},{1.455934, 0.195640, -0.014801}}],
    Polygon[{{1.462826, 0.194417, -0.011432},{1.463715, 0.195640, -0.007781},{
      1.457039, 0.199042, -0.007781},{1.456572, 0.197604, -0.011432}}],
    Polygon[{{1.463715, 0.195640, -0.007781},{1.464257, 0.196386, -0.003939},{
      1.457324, 0.199919, -0.003939},{1.457039, 0.199042, -0.007781}}],
    Polygon[{{1.464257, 0.196386, -0.003939},{1.464439, 0.196637, 0.000000},{
      1.457420, 0.200214, 0.000000},{1.457324, 0.199919, -0.003939}}],
    Polygon[{{1.464439, 0.196637, 0.000000},{1.464257, 0.196386, 0.003939},{
      1.457324, 0.199919, 0.003939},{1.457420, 0.200214, 0.000000}}],
    Polygon[{{1.464257, 0.196386, 0.003939},{1.463715, 0.195640, 0.007781},{
      1.457039, 0.199042, 0.007781},{1.457324, 0.199919, 0.003939}}],
    Polygon[{{1.463715, 0.195640, 0.007781},{1.462826, 0.194417, 0.011432},{
      1.456572, 0.197604, 0.011432},{1.457039, 0.199042, 0.007781}}],
    Polygon[{{1.462826, 0.194417, 0.011432},{1.461613, 0.192747, 0.014801},{
      1.455934, 0.195640, 0.014801},{1.456572, 0.197604, 0.011432}}],
    Polygon[{{1.461613, 0.192747, 0.014801},{1.460104, 0.190670, 0.017806},{
      1.455141, 0.193200, 0.017806},{1.455934, 0.195640, 0.014801}}],
    Polygon[{{1.460104, 0.190670, 0.017806},{1.458338, 0.188240, 0.020372},{
      1.454212, 0.190342, 0.020372},{1.455141, 0.193200, 0.017806}}],
    Polygon[{{1.458338, 0.188240, 0.020372},{1.456358, 0.185514, 0.022436},{
      1.453171, 0.187138, 0.022436},{1.454212, 0.190342, 0.020372}}],
    Polygon[{{1.456358, 0.185514, 0.022436},{1.454212, 0.182561, 0.023948},{
      1.452043, 0.183666, 0.023948},{1.453171, 0.187138, 0.022436}}],
    Polygon[{{1.454212, 0.182561, 0.023948},{1.451954, 0.179452, 0.024871},{
      1.450856, 0.180012, 0.024871},{1.452043, 0.183666, 0.023948}}],
    Polygon[{{1.450856, 0.180012, -0.024871},{1.452043, 0.183666, -0.023948},{
      1.449638, 0.184047, -0.023948},{1.449638, 0.180205, -0.024871}}],
    Polygon[{{1.452043, 0.183666, -0.023948},{1.453171, 0.187138, -0.022436},{
      1.449638, 0.187697, -0.022436},{1.449638, 0.184047, -0.023948}}],
    Polygon[{{1.453171, 0.187138, -0.022436},{1.454212, 0.190342, -0.020372},{
      1.449638, 0.191066, -0.020372},{1.449638, 0.187697, -0.022436}}],
    Polygon[{{1.454212, 0.190342, -0.020372},{1.455141, 0.193200, -0.017806},{
      1.449638, 0.194071, -0.017806},{1.449638, 0.191066, -0.020372}}],
    Polygon[{{1.455141, 0.193200, -0.017806},{1.455934, 0.195640, -0.014801},{
      1.449638, 0.196637, -0.014801},{1.449638, 0.194071, -0.017806}}],
    Polygon[{{1.455934, 0.195640, -0.014801},{1.456572, 0.197604, -0.011432},{
      1.449638, 0.198702, -0.011432},{1.449638, 0.196637, -0.014801}}],
    Polygon[{{1.456572, 0.197604, -0.011432},{1.457039, 0.199042, -0.007781},{
      1.449638, 0.200214, -0.007781},{1.449638, 0.198702, -0.011432}}],
    Polygon[{{1.457039, 0.199042, -0.007781},{1.457324, 0.199919, -0.003939},{
      1.449638, 0.201136, -0.003939},{1.449638, 0.200214, -0.007781}}],
    Polygon[{{1.457324, 0.199919, -0.003939},{1.457420, 0.200214, 0.000000},{
      1.449638, 0.201446, 0.000000},{1.449638, 0.201136, -0.003939}}],
    Polygon[{{1.457420, 0.200214, 0.000000},{1.457324, 0.199919, 0.003939},{
      1.449638, 0.201136, 0.003939},{1.449638, 0.201446, 0.000000}}],
    Polygon[{{1.457324, 0.199919, 0.003939},{1.457039, 0.199042, 0.007781},{
      1.449638, 0.200214, 0.007781},{1.449638, 0.201136, 0.003939}}],
    Polygon[{{1.457039, 0.199042, 0.007781},{1.456572, 0.197604, 0.011432},{
      1.449638, 0.198702, 0.011432},{1.449638, 0.200214, 0.007781}}],
    Polygon[{{1.456572, 0.197604, 0.011432},{1.455934, 0.195640, 0.014801},{
      1.449638, 0.196637, 0.014801},{1.449638, 0.198702, 0.011432}}],
    Polygon[{{1.455934, 0.195640, 0.014801},{1.455141, 0.193200, 0.017806},{
      1.449638, 0.194071, 0.017806},{1.449638, 0.196637, 0.014801}}],
    Polygon[{{1.455141, 0.193200, 0.017806},{1.454212, 0.190342, 0.020372},{
      1.449638, 0.191066, 0.020372},{1.449638, 0.194071, 0.017806}}],
    Polygon[{{1.454212, 0.190342, 0.020372},{1.453171, 0.187138, 0.022436},{
      1.449638, 0.187697, 0.022436},{1.449638, 0.191066, 0.020372}}],
    Polygon[{{1.453171, 0.187138, 0.022436},{1.452043, 0.183666, 0.023948},{
      1.449638, 0.184047, 0.023948},{1.449638, 0.187697, 0.022436}}],
    Polygon[{{1.452043, 0.183666, 0.023948},{1.450856, 0.180012, 0.024871},{
      1.449638, 0.180205, 0.024871},{1.449638, 0.184047, 0.023948}}],
    Polygon[{{1.449638, 0.180205, -0.024871},{1.449638, 0.184047, -0.023948},{
      1.447234, 0.183666, -0.023948},{1.448421, 0.180012, -0.024871}}],
    Polygon[{{1.449638, 0.184047, -0.023948},{1.449638, 0.187697, -0.022436},{
      1.446106, 0.187138, -0.022436},{1.447234, 0.183666, -0.023948}}],
    Polygon[{{1.449638, 0.187697, -0.022436},{1.449638, 0.191066, -0.020372},{
      1.445065, 0.190342, -0.020372},{1.446106, 0.187138, -0.022436}}],
    Polygon[{{1.449638, 0.191066, -0.020372},{1.449638, 0.194071, -0.017806},{
      1.444136, 0.193200, -0.017806},{1.445065, 0.190342, -0.020372}}],
    Polygon[{{1.449638, 0.194071, -0.017806},{1.449638, 0.196637, -0.014801},{
      1.443343, 0.195640, -0.014801},{1.444136, 0.193200, -0.017806}}],
    Polygon[{{1.449638, 0.196637, -0.014801},{1.449638, 0.198702, -0.011432},{
      1.442705, 0.197604, -0.011432},{1.443343, 0.195640, -0.014801}}],
    Polygon[{{1.449638, 0.198702, -0.011432},{1.449638, 0.200214, -0.007781},{
      1.442238, 0.199042, -0.007781},{1.442705, 0.197604, -0.011432}}],
    Polygon[{{1.449638, 0.200214, -0.007781},{1.449638, 0.201136, -0.003939},{
      1.441953, 0.199919, -0.003939},{1.442238, 0.199042, -0.007781}}],
    Polygon[{{1.449638, 0.201136, -0.003939},{1.449638, 0.201446, 0.000000},{
      1.441857, 0.200214, 0.000000},{1.441953, 0.199919, -0.003939}}],
    Polygon[{{1.449638, 0.201446, 0.000000},{1.449638, 0.201136, 0.003939},{
      1.441953, 0.199919, 0.003939},{1.441857, 0.200214, 0.000000}}],
    Polygon[{{1.449638, 0.201136, 0.003939},{1.449638, 0.200214, 0.007781},{
      1.442238, 0.199042, 0.007781},{1.441953, 0.199919, 0.003939}}],
    Polygon[{{1.449638, 0.200214, 0.007781},{1.449638, 0.198702, 0.011432},{
      1.442705, 0.197604, 0.011432},{1.442238, 0.199042, 0.007781}}],
    Polygon[{{1.449638, 0.198702, 0.011432},{1.449638, 0.196637, 0.014801},{
      1.443343, 0.195640, 0.014801},{1.442705, 0.197604, 0.011432}}],
    Polygon[{{1.449638, 0.196637, 0.014801},{1.449638, 0.194071, 0.017806},{
      1.444136, 0.193200, 0.017806},{1.443343, 0.195640, 0.014801}}],
    Polygon[{{1.449638, 0.194071, 0.017806},{1.449638, 0.191066, 0.020372},{
      1.445065, 0.190342, 0.020372},{1.444136, 0.193200, 0.017806}}],
    Polygon[{{1.449638, 0.191066, 0.020372},{1.449638, 0.187697, 0.022436},{
      1.446106, 0.187138, 0.022436},{1.445065, 0.190342, 0.020372}}],
    Polygon[{{1.449638, 0.187697, 0.022436},{1.449638, 0.184047, 0.023948},{
      1.447234, 0.183666, 0.023948},{1.446106, 0.187138, 0.022436}}],
    Polygon[{{1.449638, 0.184047, 0.023948},{1.449638, 0.180205, 0.024871},{
      1.448421, 0.180012, 0.024871},{1.447234, 0.183666, 0.023948}}],
    Polygon[{{1.448421, 0.180012, -0.024871},{1.447234, 0.183666, -0.023948},{
      1.445065, 0.182561, -0.023948},{1.447323, 0.179452, -0.024871}}],
    Polygon[{{1.447234, 0.183666, -0.023948},{1.446106, 0.187138, -0.022436},{
      1.442919, 0.185514, -0.022436},{1.445065, 0.182561, -0.023948}}],
    Polygon[{{1.446106, 0.187138, -0.022436},{1.445065, 0.190342, -0.020372},{
      1.440939, 0.188240, -0.020372},{1.442919, 0.185514, -0.022436}}],
    Polygon[{{1.445065, 0.190342, -0.020372},{1.444136, 0.193200, -0.017806},{
      1.439173, 0.190670, -0.017806},{1.440939, 0.188240, -0.020372}}],
    Polygon[{{1.444136, 0.193200, -0.017806},{1.443343, 0.195640, -0.014801},{
      1.437664, 0.192747, -0.014801},{1.439173, 0.190670, -0.017806}}],
    Polygon[{{1.443343, 0.195640, -0.014801},{1.442705, 0.197604, -0.011432},{
      1.436451, 0.194417, -0.011432},{1.437664, 0.192747, -0.014801}}],
    Polygon[{{1.442705, 0.197604, -0.011432},{1.442238, 0.199042, -0.007781},{
      1.435562, 0.195640, -0.007781},{1.436451, 0.194417, -0.011432}}],
    Polygon[{{1.442238, 0.199042, -0.007781},{1.441953, 0.199919, -0.003939},{
      1.435020, 0.196386, -0.003939},{1.435562, 0.195640, -0.007781}}],
    Polygon[{{1.441953, 0.199919, -0.003939},{1.441857, 0.200214, 0.000000},{
      1.434838, 0.196637, 0.000000},{1.435020, 0.196386, -0.003939}}],
    Polygon[{{1.441857, 0.200214, 0.000000},{1.441953, 0.199919, 0.003939},{
      1.435020, 0.196386, 0.003939},{1.434838, 0.196637, 0.000000}}],
    Polygon[{{1.441953, 0.199919, 0.003939},{1.442238, 0.199042, 0.007781},{
      1.435562, 0.195640, 0.007781},{1.435020, 0.196386, 0.003939}}],
    Polygon[{{1.442238, 0.199042, 0.007781},{1.442705, 0.197604, 0.011432},{
      1.436451, 0.194417, 0.011432},{1.435562, 0.195640, 0.007781}}],
    Polygon[{{1.442705, 0.197604, 0.011432},{1.443343, 0.195640, 0.014801},{
      1.437664, 0.192747, 0.014801},{1.436451, 0.194417, 0.011432}}],
    Polygon[{{1.443343, 0.195640, 0.014801},{1.444136, 0.193200, 0.017806},{
      1.439173, 0.190670, 0.017806},{1.437664, 0.192747, 0.014801}}],
    Polygon[{{1.444136, 0.193200, 0.017806},{1.445065, 0.190342, 0.020372},{
      1.440939, 0.188240, 0.020372},{1.439173, 0.190670, 0.017806}}],
    Polygon[{{1.445065, 0.190342, 0.020372},{1.446106, 0.187138, 0.022436},{
      1.442919, 0.185514, 0.022436},{1.440939, 0.188240, 0.020372}}],
    Polygon[{{1.446106, 0.187138, 0.022436},{1.447234, 0.183666, 0.023948},{
      1.445065, 0.182561, 0.023948},{1.442919, 0.185514, 0.022436}}],
    Polygon[{{1.447234, 0.183666, 0.023948},{1.448421, 0.180012, 0.024871},{
      1.447323, 0.179452, 0.024871},{1.445065, 0.182561, 0.023948}}],
    Polygon[{{1.447323, 0.179452, -0.024871},{1.445065, 0.182561, -0.023948},{
      1.443343, 0.180839, -0.023948},{1.446452, 0.178581, -0.024871}}],
    Polygon[{{1.445065, 0.182561, -0.023948},{1.442919, 0.185514, -0.022436},{
      1.440390, 0.182985, -0.022436},{1.443343, 0.180839, -0.023948}}],
    Polygon[{{1.442919, 0.185514, -0.022436},{1.440939, 0.188240, -0.020372},{
      1.437664, 0.184965, -0.020372},{1.440390, 0.182985, -0.022436}}],
    Polygon[{{1.440939, 0.188240, -0.020372},{1.439173, 0.190670, -0.017806},{
      1.435233, 0.186731, -0.017806},{1.437664, 0.184965, -0.020372}}],
    Polygon[{{1.439173, 0.190670, -0.017806},{1.437664, 0.192747, -0.014801},{
      1.433157, 0.188240, -0.014801},{1.435233, 0.186731, -0.017806}}],
    Polygon[{{1.437664, 0.192747, -0.014801},{1.436451, 0.194417, -0.011432},{
      1.431487, 0.189453, -0.011432},{1.433157, 0.188240, -0.014801}}],
    Polygon[{{1.436451, 0.194417, -0.011432},{1.435562, 0.195640, -0.007781},{
      1.430264, 0.190342, -0.007781},{1.431487, 0.189453, -0.011432}}],
    Polygon[{{1.435562, 0.195640, -0.007781},{1.435020, 0.196386, -0.003939},{
      1.429518, 0.190884, -0.003939},{1.430264, 0.190342, -0.007781}}],
    Polygon[{{1.435020, 0.196386, -0.003939},{1.434838, 0.196637, 0.000000},{
      1.429267, 0.191066, 0.000000},{1.429518, 0.190884, -0.003939}}],
    Polygon[{{1.434838, 0.196637, 0.000000},{1.435020, 0.196386, 0.003939},{
      1.429518, 0.190884, 0.003939},{1.429267, 0.191066, 0.000000}}],
    Polygon[{{1.435020, 0.196386, 0.003939},{1.435562, 0.195640, 0.007781},{
      1.430264, 0.190342, 0.007781},{1.429518, 0.190884, 0.003939}}],
    Polygon[{{1.435562, 0.195640, 0.007781},{1.436451, 0.194417, 0.011432},{
      1.431487, 0.189453, 0.011432},{1.430264, 0.190342, 0.007781}}],
    Polygon[{{1.436451, 0.194417, 0.011432},{1.437664, 0.192747, 0.014801},{
      1.433157, 0.188240, 0.014801},{1.431487, 0.189453, 0.011432}}],
    Polygon[{{1.437664, 0.192747, 0.014801},{1.439173, 0.190670, 0.017806},{
      1.435233, 0.186731, 0.017806},{1.433157, 0.188240, 0.014801}}],
    Polygon[{{1.439173, 0.190670, 0.017806},{1.440939, 0.188240, 0.020372},{
      1.437664, 0.184965, 0.020372},{1.435233, 0.186731, 0.017806}}],
    Polygon[{{1.440939, 0.188240, 0.020372},{1.442919, 0.185514, 0.022436},{
      1.440390, 0.182985, 0.022436},{1.437664, 0.184965, 0.020372}}],
    Polygon[{{1.442919, 0.185514, 0.022436},{1.445065, 0.182561, 0.023948},{
      1.443343, 0.180839, 0.023948},{1.440390, 0.182985, 0.022436}}],
    Polygon[{{1.445065, 0.182561, 0.023948},{1.447323, 0.179452, 0.024871},{
      1.446452, 0.178581, 0.024871},{1.443343, 0.180839, 0.023948}}],
    Polygon[{{1.446452, 0.178581, -0.024871},{1.443343, 0.180839, -0.023948},{
      1.442238, 0.178670, -0.023948},{1.445892, 0.177483, -0.024871}}],
    Polygon[{{1.443343, 0.180839, -0.023948},{1.440390, 0.182985, -0.022436},{
      1.438766, 0.179798, -0.022436},{1.442238, 0.178670, -0.023948}}],
    Polygon[{{1.440390, 0.182985, -0.022436},{1.437664, 0.184965, -0.020372},{
      1.435562, 0.180839, -0.020372},{1.438766, 0.179798, -0.022436}}],
    Polygon[{{1.437664, 0.184965, -0.020372},{1.435233, 0.186731, -0.017806},{
      1.432704, 0.181768, -0.017806},{1.435562, 0.180839, -0.020372}}],
    Polygon[{{1.435233, 0.186731, -0.017806},{1.433157, 0.188240, -0.014801},{
      1.430264, 0.182561, -0.014801},{1.432704, 0.181768, -0.017806}}],
    Polygon[{{1.433157, 0.188240, -0.014801},{1.431487, 0.189453, -0.011432},{
      1.428300, 0.183199, -0.011432},{1.430264, 0.182561, -0.014801}}],
    Polygon[{{1.431487, 0.189453, -0.011432},{1.430264, 0.190342, -0.007781},{
      1.426862, 0.183666, -0.007781},{1.428300, 0.183199, -0.011432}}],
    Polygon[{{1.430264, 0.190342, -0.007781},{1.429518, 0.190884, -0.003939},{
      1.425985, 0.183951, -0.003939},{1.426862, 0.183666, -0.007781}}],
    Polygon[{{1.429518, 0.190884, -0.003939},{1.429267, 0.191066, 0.000000},{
      1.425690, 0.184047, 0.000000},{1.425985, 0.183951, -0.003939}}],
    Polygon[{{1.429267, 0.191066, 0.000000},{1.429518, 0.190884, 0.003939},{
      1.425985, 0.183951, 0.003939},{1.425690, 0.184047, 0.000000}}],
    Polygon[{{1.429518, 0.190884, 0.003939},{1.430264, 0.190342, 0.007781},{
      1.426862, 0.183666, 0.007781},{1.425985, 0.183951, 0.003939}}],
    Polygon[{{1.430264, 0.190342, 0.007781},{1.431487, 0.189453, 0.011432},{
      1.428300, 0.183199, 0.011432},{1.426862, 0.183666, 0.007781}}],
    Polygon[{{1.431487, 0.189453, 0.011432},{1.433157, 0.188240, 0.014801},{
      1.430264, 0.182561, 0.014801},{1.428300, 0.183199, 0.011432}}],
    Polygon[{{1.433157, 0.188240, 0.014801},{1.435233, 0.186731, 0.017806},{
      1.432704, 0.181768, 0.017806},{1.430264, 0.182561, 0.014801}}],
    Polygon[{{1.435233, 0.186731, 0.017806},{1.437664, 0.184965, 0.020372},{
      1.435562, 0.180839, 0.020372},{1.432704, 0.181768, 0.017806}}],
    Polygon[{{1.437664, 0.184965, 0.020372},{1.440390, 0.182985, 0.022436},{
      1.438766, 0.179798, 0.022436},{1.435562, 0.180839, 0.020372}}],
    Polygon[{{1.440390, 0.182985, 0.022436},{1.443343, 0.180839, 0.023948},{
      1.442238, 0.178670, 0.023948},{1.438766, 0.179798, 0.022436}}],
    Polygon[{{1.443343, 0.180839, 0.023948},{1.446452, 0.178581, 0.024871},{
      1.445892, 0.177483, 0.024871},{1.442238, 0.178670, 0.023948}}],
    Polygon[{{1.445892, 0.177483, -0.024871},{1.442238, 0.178670, -0.023948},{
      1.441857, 0.176266, -0.023948},{1.445699, 0.176266, -0.024871}}],
    Polygon[{{1.442238, 0.178670, -0.023948},{1.438766, 0.179798, -0.022436},{
      1.438207, 0.176266, -0.022436},{1.441857, 0.176266, -0.023948}}],
    Polygon[{{1.438766, 0.179798, -0.022436},{1.435562, 0.180839, -0.020372},{
      1.434838, 0.176266, -0.020372},{1.438207, 0.176266, -0.022436}}],
    Polygon[{{1.435562, 0.180839, -0.020372},{1.432704, 0.181768, -0.017806},{
      1.431833, 0.176266, -0.017806},{1.434838, 0.176266, -0.020372}}],
    Polygon[{{1.432704, 0.181768, -0.017806},{1.430264, 0.182561, -0.014801},{
      1.429267, 0.176266, -0.014801},{1.431833, 0.176266, -0.017806}}],
    Polygon[{{1.430264, 0.182561, -0.014801},{1.428300, 0.183199, -0.011432},{
      1.427202, 0.176266, -0.011432},{1.429267, 0.176266, -0.014801}}],
    Polygon[{{1.428300, 0.183199, -0.011432},{1.426862, 0.183666, -0.007781},{
      1.425690, 0.176266, -0.007781},{1.427202, 0.176266, -0.011432}}],
    Polygon[{{1.426862, 0.183666, -0.007781},{1.425985, 0.183951, -0.003939},{
      1.424768, 0.176266, -0.003939},{1.425690, 0.176266, -0.007781}}],
    Polygon[{{1.425985, 0.183951, -0.003939},{1.425690, 0.184047, 0.000000},{
      1.424458, 0.176266, 0.000000},{1.424768, 0.176266, -0.003939}}],
    Polygon[{{1.425690, 0.184047, 0.000000},{1.425985, 0.183951, 0.003939},{
      1.424768, 0.176266, 0.003939},{1.424458, 0.176266, 0.000000}}],
    Polygon[{{1.425985, 0.183951, 0.003939},{1.426862, 0.183666, 0.007781},{
      1.425690, 0.176266, 0.007781},{1.424768, 0.176266, 0.003939}}],
    Polygon[{{1.426862, 0.183666, 0.007781},{1.428300, 0.183199, 0.011432},{
      1.427202, 0.176266, 0.011432},{1.425690, 0.176266, 0.007781}}],
    Polygon[{{1.428300, 0.183199, 0.011432},{1.430264, 0.182561, 0.014801},{
      1.429267, 0.176266, 0.014801},{1.427202, 0.176266, 0.011432}}],
    Polygon[{{1.430264, 0.182561, 0.014801},{1.432704, 0.181768, 0.017806},{
      1.431833, 0.176266, 0.017806},{1.429267, 0.176266, 0.014801}}],
    Polygon[{{1.432704, 0.181768, 0.017806},{1.435562, 0.180839, 0.020372},{
      1.434838, 0.176266, 0.020372},{1.431833, 0.176266, 0.017806}}],
    Polygon[{{1.435562, 0.180839, 0.020372},{1.438766, 0.179798, 0.022436},{
      1.438207, 0.176266, 0.022436},{1.434838, 0.176266, 0.020372}}],
    Polygon[{{1.438766, 0.179798, 0.022436},{1.442238, 0.178670, 0.023948},{
      1.441857, 0.176266, 0.023948},{1.438207, 0.176266, 0.022436}}],
    Polygon[{{1.442238, 0.178670, 0.023948},{1.445892, 0.177483, 0.024871},{
      1.445699, 0.176266, 0.024871},{1.441857, 0.176266, 0.023948}}],
    Polygon[{{1.445699, 0.176266, -0.024871},{1.441857, 0.176266, -0.023948},{
      1.442238, 0.173861, -0.023948},{1.445892, 0.175048, -0.024871}}],
    Polygon[{{1.441857, 0.176266, -0.023948},{1.438207, 0.176266, -0.022436},{
      1.438766, 0.172733, -0.022436},{1.442238, 0.173861, -0.023948}}],
    Polygon[{{1.438207, 0.176266, -0.022436},{1.434838, 0.176266, -0.020372},{
      1.435562, 0.171692, -0.020372},{1.438766, 0.172733, -0.022436}}],
    Polygon[{{1.434838, 0.176266, -0.020372},{1.431833, 0.176266, -0.017806},{
      1.432704, 0.170763, -0.017806},{1.435562, 0.171692, -0.020372}}],
    Polygon[{{1.431833, 0.176266, -0.017806},{1.429267, 0.176266, -0.014801},{
      1.430264, 0.169970, -0.014801},{1.432704, 0.170763, -0.017806}}],
    Polygon[{{1.429267, 0.176266, -0.014801},{1.427202, 0.176266, -0.011432},{
      1.428300, 0.169332, -0.011432},{1.430264, 0.169970, -0.014801}}],
    Polygon[{{1.427202, 0.176266, -0.011432},{1.425690, 0.176266, -0.007781},{
      1.426862, 0.168865, -0.007781},{1.428300, 0.169332, -0.011432}}],
    Polygon[{{1.425690, 0.176266, -0.007781},{1.424768, 0.176266, -0.003939},{
      1.425985, 0.168580, -0.003939},{1.426862, 0.168865, -0.007781}}],
    Polygon[{{1.424768, 0.176266, -0.003939},{1.424458, 0.176266, 0.000000},{
      1.425690, 0.168484, 0.000000},{1.425985, 0.168580, -0.003939}}],
    Polygon[{{1.424458, 0.176266, 0.000000},{1.424768, 0.176266, 0.003939},{
      1.425985, 0.168580, 0.003939},{1.425690, 0.168484, 0.000000}}],
    Polygon[{{1.424768, 0.176266, 0.003939},{1.425690, 0.176266, 0.007781},{
      1.426862, 0.168865, 0.007781},{1.425985, 0.168580, 0.003939}}],
    Polygon[{{1.425690, 0.176266, 0.007781},{1.427202, 0.176266, 0.011432},{
      1.428300, 0.169332, 0.011432},{1.426862, 0.168865, 0.007781}}],
    Polygon[{{1.427202, 0.176266, 0.011432},{1.429267, 0.176266, 0.014801},{
      1.430264, 0.169970, 0.014801},{1.428300, 0.169332, 0.011432}}],
    Polygon[{{1.429267, 0.176266, 0.014801},{1.431833, 0.176266, 0.017806},{
      1.432704, 0.170763, 0.017806},{1.430264, 0.169970, 0.014801}}],
    Polygon[{{1.431833, 0.176266, 0.017806},{1.434838, 0.176266, 0.020372},{
      1.435562, 0.171692, 0.020372},{1.432704, 0.170763, 0.017806}}],
    Polygon[{{1.434838, 0.176266, 0.020372},{1.438207, 0.176266, 0.022436},{
      1.438766, 0.172733, 0.022436},{1.435562, 0.171692, 0.020372}}],
    Polygon[{{1.438207, 0.176266, 0.022436},{1.441857, 0.176266, 0.023948},{
      1.442238, 0.173861, 0.023948},{1.438766, 0.172733, 0.022436}}],
    Polygon[{{1.441857, 0.176266, 0.023948},{1.445699, 0.176266, 0.024871},{
      1.445892, 0.175048, 0.024871},{1.442238, 0.173861, 0.023948}}],
    Polygon[{{1.445892, 0.175048, -0.024871},{1.442238, 0.173861, -0.023948},{
      1.443343, 0.171692, -0.023948},{1.446452, 0.173950, -0.024871}}],
    Polygon[{{1.442238, 0.173861, -0.023948},{1.438766, 0.172733, -0.022436},{
      1.440390, 0.169546, -0.022436},{1.443343, 0.171692, -0.023948}}],
    Polygon[{{1.438766, 0.172733, -0.022436},{1.435562, 0.171692, -0.020372},{
      1.437664, 0.167566, -0.020372},{1.440390, 0.169546, -0.022436}}],
    Polygon[{{1.435562, 0.171692, -0.020372},{1.432704, 0.170763, -0.017806},{
      1.435233, 0.165800, -0.017806},{1.437664, 0.167566, -0.020372}}],
    Polygon[{{1.432704, 0.170763, -0.017806},{1.430264, 0.169970, -0.014801},{
      1.433157, 0.164291, -0.014801},{1.435233, 0.165800, -0.017806}}],
    Polygon[{{1.430264, 0.169970, -0.014801},{1.428300, 0.169332, -0.011432},{
      1.431487, 0.163078, -0.011432},{1.433157, 0.164291, -0.014801}}],
    Polygon[{{1.428300, 0.169332, -0.011432},{1.426862, 0.168865, -0.007781},{
      1.430264, 0.162189, -0.007781},{1.431487, 0.163078, -0.011432}}],
    Polygon[{{1.426862, 0.168865, -0.007781},{1.425985, 0.168580, -0.003939},{
      1.429518, 0.161647, -0.003939},{1.430264, 0.162189, -0.007781}}],
    Polygon[{{1.425985, 0.168580, -0.003939},{1.425690, 0.168484, 0.000000},{
      1.429267, 0.161465, 0.000000},{1.429518, 0.161647, -0.003939}}],
    Polygon[{{1.425690, 0.168484, 0.000000},{1.425985, 0.168580, 0.003939},{
      1.429518, 0.161647, 0.003939},{1.429267, 0.161465, 0.000000}}],
    Polygon[{{1.425985, 0.168580, 0.003939},{1.426862, 0.168865, 0.007781},{
      1.430264, 0.162189, 0.007781},{1.429518, 0.161647, 0.003939}}],
    Polygon[{{1.426862, 0.168865, 0.007781},{1.428300, 0.169332, 0.011432},{
      1.431487, 0.163078, 0.011432},{1.430264, 0.162189, 0.007781}}],
    Polygon[{{1.428300, 0.169332, 0.011432},{1.430264, 0.169970, 0.014801},{
      1.433157, 0.164291, 0.014801},{1.431487, 0.163078, 0.011432}}],
    Polygon[{{1.430264, 0.169970, 0.014801},{1.432704, 0.170763, 0.017806},{
      1.435233, 0.165800, 0.017806},{1.433157, 0.164291, 0.014801}}],
    Polygon[{{1.432704, 0.170763, 0.017806},{1.435562, 0.171692, 0.020372},{
      1.437664, 0.167566, 0.020372},{1.435233, 0.165800, 0.017806}}],
    Polygon[{{1.435562, 0.171692, 0.020372},{1.438766, 0.172733, 0.022436},{
      1.440390, 0.169546, 0.022436},{1.437664, 0.167566, 0.020372}}],
    Polygon[{{1.438766, 0.172733, 0.022436},{1.442238, 0.173861, 0.023948},{
      1.443343, 0.171692, 0.023948},{1.440390, 0.169546, 0.022436}}],
    Polygon[{{1.442238, 0.173861, 0.023948},{1.445892, 0.175048, 0.024871},{
      1.446452, 0.173950, 0.024871},{1.443343, 0.171692, 0.023948}}],
    Polygon[{{1.446452, 0.173950, -0.024871},{1.443343, 0.171692, -0.023948},{
      1.445065, 0.169970, -0.023948},{1.447323, 0.173079, -0.024871}}],
    Polygon[{{1.443343, 0.171692, -0.023948},{1.440390, 0.169546, -0.022436},{
      1.442919, 0.167017, -0.022436},{1.445065, 0.169970, -0.023948}}],
    Polygon[{{1.440390, 0.169546, -0.022436},{1.437664, 0.167566, -0.020372},{
      1.440939, 0.164291, -0.020372},{1.442919, 0.167017, -0.022436}}],
    Polygon[{{1.437664, 0.167566, -0.020372},{1.435233, 0.165800, -0.017806},{
      1.439173, 0.161861, -0.017806},{1.440939, 0.164291, -0.020372}}],
    Polygon[{{1.435233, 0.165800, -0.017806},{1.433157, 0.164291, -0.014801},{
      1.437664, 0.159784, -0.014801},{1.439173, 0.161861, -0.017806}}],
    Polygon[{{1.433157, 0.164291, -0.014801},{1.431487, 0.163078, -0.011432},{
      1.436451, 0.158114, -0.011432},{1.437664, 0.159784, -0.014801}}],
    Polygon[{{1.431487, 0.163078, -0.011432},{1.430264, 0.162189, -0.007781},{
      1.435562, 0.156891, -0.007781},{1.436451, 0.158114, -0.011432}}],
    Polygon[{{1.430264, 0.162189, -0.007781},{1.429518, 0.161647, -0.003939},{
      1.435020, 0.156145, -0.003939},{1.435562, 0.156891, -0.007781}}],
    Polygon[{{1.429518, 0.161647, -0.003939},{1.429267, 0.161465, 0.000000},{
      1.434838, 0.155894, 0.000000},{1.435020, 0.156145, -0.003939}}],
    Polygon[{{1.429267, 0.161465, 0.000000},{1.429518, 0.161647, 0.003939},{
      1.435020, 0.156145, 0.003939},{1.434838, 0.155894, 0.000000}}],
    Polygon[{{1.429518, 0.161647, 0.003939},{1.430264, 0.162189, 0.007781},{
      1.435562, 0.156891, 0.007781},{1.435020, 0.156145, 0.003939}}],
    Polygon[{{1.430264, 0.162189, 0.007781},{1.431487, 0.163078, 0.011432},{
      1.436451, 0.158114, 0.011432},{1.435562, 0.156891, 0.007781}}],
    Polygon[{{1.431487, 0.163078, 0.011432},{1.433157, 0.164291, 0.014801},{
      1.437664, 0.159784, 0.014801},{1.436451, 0.158114, 0.011432}}],
    Polygon[{{1.433157, 0.164291, 0.014801},{1.435233, 0.165800, 0.017806},{
      1.439173, 0.161861, 0.017806},{1.437664, 0.159784, 0.014801}}],
    Polygon[{{1.435233, 0.165800, 0.017806},{1.437664, 0.167566, 0.020372},{
      1.440939, 0.164291, 0.020372},{1.439173, 0.161861, 0.017806}}],
    Polygon[{{1.437664, 0.167566, 0.020372},{1.440390, 0.169546, 0.022436},{
      1.442919, 0.167017, 0.022436},{1.440939, 0.164291, 0.020372}}],
    Polygon[{{1.440390, 0.169546, 0.022436},{1.443343, 0.171692, 0.023948},{
      1.445065, 0.169970, 0.023948},{1.442919, 0.167017, 0.022436}}],
    Polygon[{{1.443343, 0.171692, 0.023948},{1.446452, 0.173950, 0.024871},{
      1.447323, 0.173079, 0.024871},{1.445065, 0.169970, 0.023948}}],
    Polygon[{{1.447323, 0.173079, -0.024871},{1.445065, 0.169970, -0.023948},{
      1.447234, 0.168865, -0.023948},{1.448421, 0.172519, -0.024871}}],
    Polygon[{{1.445065, 0.169970, -0.023948},{1.442919, 0.167017, -0.022436},{
      1.446106, 0.165393, -0.022436},{1.447234, 0.168865, -0.023948}}],
    Polygon[{{1.442919, 0.167017, -0.022436},{1.440939, 0.164291, -0.020372},{
      1.445065, 0.162189, -0.020372},{1.446106, 0.165393, -0.022436}}],
    Polygon[{{1.440939, 0.164291, -0.020372},{1.439173, 0.161861, -0.017806},{
      1.444136, 0.159331, -0.017806},{1.445065, 0.162189, -0.020372}}],
    Polygon[{{1.439173, 0.161861, -0.017806},{1.437664, 0.159784, -0.014801},{
      1.443343, 0.156891, -0.014801},{1.444136, 0.159331, -0.017806}}],
    Polygon[{{1.437664, 0.159784, -0.014801},{1.436451, 0.158114, -0.011432},{
      1.442705, 0.154927, -0.011432},{1.443343, 0.156891, -0.014801}}],
    Polygon[{{1.436451, 0.158114, -0.011432},{1.435562, 0.156891, -0.007781},{
      1.442238, 0.153489, -0.007781},{1.442705, 0.154927, -0.011432}}],
    Polygon[{{1.435562, 0.156891, -0.007781},{1.435020, 0.156145, -0.003939},{
      1.441953, 0.152612, -0.003939},{1.442238, 0.153489, -0.007781}}],
    Polygon[{{1.435020, 0.156145, -0.003939},{1.434838, 0.155894, 0.000000},{
      1.441857, 0.152317, 0.000000},{1.441953, 0.152612, -0.003939}}],
    Polygon[{{1.434838, 0.155894, 0.000000},{1.435020, 0.156145, 0.003939},{
      1.441953, 0.152612, 0.003939},{1.441857, 0.152317, 0.000000}}],
    Polygon[{{1.435020, 0.156145, 0.003939},{1.435562, 0.156891, 0.007781},{
      1.442238, 0.153489, 0.007781},{1.441953, 0.152612, 0.003939}}],
    Polygon[{{1.435562, 0.156891, 0.007781},{1.436451, 0.158114, 0.011432},{
      1.442705, 0.154927, 0.011432},{1.442238, 0.153489, 0.007781}}],
    Polygon[{{1.436451, 0.158114, 0.011432},{1.437664, 0.159784, 0.014801},{
      1.443343, 0.156891, 0.014801},{1.442705, 0.154927, 0.011432}}],
    Polygon[{{1.437664, 0.159784, 0.014801},{1.439173, 0.161861, 0.017806},{
      1.444136, 0.159331, 0.017806},{1.443343, 0.156891, 0.014801}}],
    Polygon[{{1.439173, 0.161861, 0.017806},{1.440939, 0.164291, 0.020372},{
      1.445065, 0.162189, 0.020372},{1.444136, 0.159331, 0.017806}}],
    Polygon[{{1.440939, 0.164291, 0.020372},{1.442919, 0.167017, 0.022436},{
      1.446106, 0.165393, 0.022436},{1.445065, 0.162189, 0.020372}}],
    Polygon[{{1.442919, 0.167017, 0.022436},{1.445065, 0.169970, 0.023948},{
      1.447234, 0.168865, 0.023948},{1.446106, 0.165393, 0.022436}}],
    Polygon[{{1.445065, 0.169970, 0.023948},{1.447323, 0.173079, 0.024871},{
      1.448421, 0.172519, 0.024871},{1.447234, 0.168865, 0.023948}}],
    Polygon[{{1.448421, 0.172519, -0.024871},{1.447234, 0.168865, -0.023948},{
      1.449638, 0.168484, -0.023948},{1.449638, 0.172326, -0.024871}}],
    Polygon[{{1.447234, 0.168865, -0.023948},{1.446106, 0.165393, -0.022436},{
      1.449638, 0.164834, -0.022436},{1.449638, 0.168484, -0.023948}}],
    Polygon[{{1.446106, 0.165393, -0.022436},{1.445065, 0.162189, -0.020372},{
      1.449638, 0.161465, -0.020372},{1.449638, 0.164834, -0.022436}}],
    Polygon[{{1.445065, 0.162189, -0.020372},{1.444136, 0.159331, -0.017806},{
      1.449638, 0.158460, -0.017806},{1.449638, 0.161465, -0.020372}}],
    Polygon[{{1.444136, 0.159331, -0.017806},{1.443343, 0.156891, -0.014801},{
      1.449638, 0.155894, -0.014801},{1.449638, 0.158460, -0.017806}}],
    Polygon[{{1.443343, 0.156891, -0.014801},{1.442705, 0.154927, -0.011432},{
      1.449638, 0.153829, -0.011432},{1.449638, 0.155894, -0.014801}}],
    Polygon[{{1.442705, 0.154927, -0.011432},{1.442238, 0.153489, -0.007781},{
      1.449638, 0.152317, -0.007781},{1.449638, 0.153829, -0.011432}}],
    Polygon[{{1.442238, 0.153489, -0.007781},{1.441953, 0.152612, -0.003939},{
      1.449638, 0.151395, -0.003939},{1.449638, 0.152317, -0.007781}}],
    Polygon[{{1.441953, 0.152612, -0.003939},{1.441857, 0.152317, 0.000000},{
      1.449638, 0.151085, 0.000000},{1.449638, 0.151395, -0.003939}}],
    Polygon[{{1.441857, 0.152317, 0.000000},{1.441953, 0.152612, 0.003939},{
      1.449638, 0.151395, 0.003939},{1.449638, 0.151085, 0.000000}}],
    Polygon[{{1.441953, 0.152612, 0.003939},{1.442238, 0.153489, 0.007781},{
      1.449638, 0.152317, 0.007781},{1.449638, 0.151395, 0.003939}}],
    Polygon[{{1.442238, 0.153489, 0.007781},{1.442705, 0.154927, 0.011432},{
      1.449638, 0.153829, 0.011432},{1.449638, 0.152317, 0.007781}}],
    Polygon[{{1.442705, 0.154927, 0.011432},{1.443343, 0.156891, 0.014801},{
      1.449638, 0.155894, 0.014801},{1.449638, 0.153829, 0.011432}}],
    Polygon[{{1.443343, 0.156891, 0.014801},{1.444136, 0.159331, 0.017806},{
      1.449638, 0.158460, 0.017806},{1.449638, 0.155894, 0.014801}}],
    Polygon[{{1.444136, 0.159331, 0.017806},{1.445065, 0.162189, 0.020372},{
      1.449638, 0.161465, 0.020372},{1.449638, 0.158460, 0.017806}}],
    Polygon[{{1.445065, 0.162189, 0.020372},{1.446106, 0.165393, 0.022436},{
      1.449638, 0.164834, 0.022436},{1.449638, 0.161465, 0.020372}}],
    Polygon[{{1.446106, 0.165393, 0.022436},{1.447234, 0.168865, 0.023948},{
      1.449638, 0.168484, 0.023948},{1.449638, 0.164834, 0.022436}}],
    Polygon[{{1.447234, 0.168865, 0.023948},{1.448421, 0.172519, 0.024871},{
      1.449638, 0.172326, 0.024871},{1.449638, 0.168484, 0.023948}}],
    Polygon[{{1.449638, 0.172326, -0.024871},{1.449638, 0.168484, -0.023948},{
      1.452043, 0.168865, -0.023948},{1.450856, 0.172519, -0.024871}}],
    Polygon[{{1.449638, 0.168484, -0.023948},{1.449638, 0.164834, -0.022436},{
      1.453171, 0.165393, -0.022436},{1.452043, 0.168865, -0.023948}}],
    Polygon[{{1.449638, 0.164834, -0.022436},{1.449638, 0.161465, -0.020372},{
      1.454212, 0.162189, -0.020372},{1.453171, 0.165393, -0.022436}}],
    Polygon[{{1.449638, 0.161465, -0.020372},{1.449638, 0.158460, -0.017806},{
      1.455141, 0.159331, -0.017806},{1.454212, 0.162189, -0.020372}}],
    Polygon[{{1.449638, 0.158460, -0.017806},{1.449638, 0.155894, -0.014801},{
      1.455934, 0.156891, -0.014801},{1.455141, 0.159331, -0.017806}}],
    Polygon[{{1.449638, 0.155894, -0.014801},{1.449638, 0.153829, -0.011432},{
      1.456572, 0.154927, -0.011432},{1.455934, 0.156891, -0.014801}}],
    Polygon[{{1.449638, 0.153829, -0.011432},{1.449638, 0.152317, -0.007781},{
      1.457039, 0.153489, -0.007781},{1.456572, 0.154927, -0.011432}}],
    Polygon[{{1.449638, 0.152317, -0.007781},{1.449638, 0.151395, -0.003939},{
      1.457324, 0.152612, -0.003939},{1.457039, 0.153489, -0.007781}}],
    Polygon[{{1.449638, 0.151395, -0.003939},{1.449638, 0.151085, 0.000000},{
      1.457420, 0.152317, 0.000000},{1.457324, 0.152612, -0.003939}}],
    Polygon[{{1.449638, 0.151085, 0.000000},{1.449638, 0.151395, 0.003939},{
      1.457324, 0.152612, 0.003939},{1.457420, 0.152317, 0.000000}}],
    Polygon[{{1.449638, 0.151395, 0.003939},{1.449638, 0.152317, 0.007781},{
      1.457039, 0.153489, 0.007781},{1.457324, 0.152612, 0.003939}}],
    Polygon[{{1.449638, 0.152317, 0.007781},{1.449638, 0.153829, 0.011432},{
      1.456572, 0.154927, 0.011432},{1.457039, 0.153489, 0.007781}}],
    Polygon[{{1.449638, 0.153829, 0.011432},{1.449638, 0.155894, 0.014801},{
      1.455934, 0.156891, 0.014801},{1.456572, 0.154927, 0.011432}}],
    Polygon[{{1.449638, 0.155894, 0.014801},{1.449638, 0.158460, 0.017806},{
      1.455141, 0.159331, 0.017806},{1.455934, 0.156891, 0.014801}}],
    Polygon[{{1.449638, 0.158460, 0.017806},{1.449638, 0.161465, 0.020372},{
      1.454212, 0.162189, 0.020372},{1.455141, 0.159331, 0.017806}}],
    Polygon[{{1.449638, 0.161465, 0.020372},{1.449638, 0.164834, 0.022436},{
      1.453171, 0.165393, 0.022436},{1.454212, 0.162189, 0.020372}}],
    Polygon[{{1.449638, 0.164834, 0.022436},{1.449638, 0.168484, 0.023948},{
      1.452043, 0.168865, 0.023948},{1.453171, 0.165393, 0.022436}}],
    Polygon[{{1.449638, 0.168484, 0.023948},{1.449638, 0.172326, 0.024871},{
      1.450856, 0.172519, 0.024871},{1.452043, 0.168865, 0.023948}}],
    Polygon[{{1.450856, 0.172519, -0.024871},{1.452043, 0.168865, -0.023948},{
      1.454212, 0.169970, -0.023948},{1.451954, 0.173079, -0.024871}}],
    Polygon[{{1.452043, 0.168865, -0.023948},{1.453171, 0.165393, -0.022436},{
      1.456358, 0.167017, -0.022436},{1.454212, 0.169970, -0.023948}}],
    Polygon[{{1.453171, 0.165393, -0.022436},{1.454212, 0.162189, -0.020372},{
      1.458338, 0.164291, -0.020372},{1.456358, 0.167017, -0.022436}}],
    Polygon[{{1.454212, 0.162189, -0.020372},{1.455141, 0.159331, -0.017806},{
      1.460104, 0.161861, -0.017806},{1.458338, 0.164291, -0.020372}}],
    Polygon[{{1.455141, 0.159331, -0.017806},{1.455934, 0.156891, -0.014801},{
      1.461613, 0.159784, -0.014801},{1.460104, 0.161861, -0.017806}}],
    Polygon[{{1.455934, 0.156891, -0.014801},{1.456572, 0.154927, -0.011432},{
      1.462826, 0.158114, -0.011432},{1.461613, 0.159784, -0.014801}}],
    Polygon[{{1.456572, 0.154927, -0.011432},{1.457039, 0.153489, -0.007781},{
      1.463715, 0.156891, -0.007781},{1.462826, 0.158114, -0.011432}}],
    Polygon[{{1.457039, 0.153489, -0.007781},{1.457324, 0.152612, -0.003939},{
      1.464257, 0.156145, -0.003939},{1.463715, 0.156891, -0.007781}}],
    Polygon[{{1.457324, 0.152612, -0.003939},{1.457420, 0.152317, 0.000000},{
      1.464439, 0.155894, 0.000000},{1.464257, 0.156145, -0.003939}}],
    Polygon[{{1.457420, 0.152317, 0.000000},{1.457324, 0.152612, 0.003939},{
      1.464257, 0.156145, 0.003939},{1.464439, 0.155894, 0.000000}}],
    Polygon[{{1.457324, 0.152612, 0.003939},{1.457039, 0.153489, 0.007781},{
      1.463715, 0.156891, 0.007781},{1.464257, 0.156145, 0.003939}}],
    Polygon[{{1.457039, 0.153489, 0.007781},{1.456572, 0.154927, 0.011432},{
      1.462826, 0.158114, 0.011432},{1.463715, 0.156891, 0.007781}}],
    Polygon[{{1.456572, 0.154927, 0.011432},{1.455934, 0.156891, 0.014801},{
      1.461613, 0.159784, 0.014801},{1.462826, 0.158114, 0.011432}}],
    Polygon[{{1.455934, 0.156891, 0.014801},{1.455141, 0.159331, 0.017806},{
      1.460104, 0.161861, 0.017806},{1.461613, 0.159784, 0.014801}}],
    Polygon[{{1.455141, 0.159331, 0.017806},{1.454212, 0.162189, 0.020372},{
      1.458338, 0.164291, 0.020372},{1.460104, 0.161861, 0.017806}}],
    Polygon[{{1.454212, 0.162189, 0.020372},{1.453171, 0.165393, 0.022436},{
      1.456358, 0.167017, 0.022436},{1.458338, 0.164291, 0.020372}}],
    Polygon[{{1.453171, 0.165393, 0.022436},{1.452043, 0.168865, 0.023948},{
      1.454212, 0.169970, 0.023948},{1.456358, 0.167017, 0.022436}}],
    Polygon[{{1.452043, 0.168865, 0.023948},{1.450856, 0.172519, 0.024871},{
      1.451954, 0.173079, 0.024871},{1.454212, 0.169970, 0.023948}}],
    Polygon[{{1.451954, 0.173079, -0.024871},{1.454212, 0.169970, -0.023948},{
      1.455934, 0.171692, -0.023948},{1.452825, 0.173950, -0.024871}}],
    Polygon[{{1.454212, 0.169970, -0.023948},{1.456358, 0.167017, -0.022436},{
      1.458887, 0.169546, -0.022436},{1.455934, 0.171692, -0.023948}}],
    Polygon[{{1.456358, 0.167017, -0.022436},{1.458338, 0.164291, -0.020372},{
      1.461613, 0.167566, -0.020372},{1.458887, 0.169546, -0.022436}}],
    Polygon[{{1.458338, 0.164291, -0.020372},{1.460104, 0.161861, -0.017806},{
      1.464043, 0.165800, -0.017806},{1.461613, 0.167566, -0.020372}}],
    Polygon[{{1.460104, 0.161861, -0.017806},{1.461613, 0.159784, -0.014801},{
      1.466119, 0.164291, -0.014801},{1.464043, 0.165800, -0.017806}}],
    Polygon[{{1.461613, 0.159784, -0.014801},{1.462826, 0.158114, -0.011432},{
      1.467790, 0.163078, -0.011432},{1.466119, 0.164291, -0.014801}}],
    Polygon[{{1.462826, 0.158114, -0.011432},{1.463715, 0.156891, -0.007781},{
      1.469013, 0.162189, -0.007781},{1.467790, 0.163078, -0.011432}}],
    Polygon[{{1.463715, 0.156891, -0.007781},{1.464257, 0.156145, -0.003939},{
      1.469759, 0.161647, -0.003939},{1.469013, 0.162189, -0.007781}}],
    Polygon[{{1.464257, 0.156145, -0.003939},{1.464439, 0.155894, 0.000000},{
      1.470010, 0.161465, 0.000000},{1.469759, 0.161647, -0.003939}}],
    Polygon[{{1.464439, 0.155894, 0.000000},{1.464257, 0.156145, 0.003939},{
      1.469759, 0.161647, 0.003939},{1.470010, 0.161465, 0.000000}}],
    Polygon[{{1.464257, 0.156145, 0.003939},{1.463715, 0.156891, 0.007781},{
      1.469013, 0.162189, 0.007781},{1.469759, 0.161647, 0.003939}}],
    Polygon[{{1.463715, 0.156891, 0.007781},{1.462826, 0.158114, 0.011432},{
      1.467790, 0.163078, 0.011432},{1.469013, 0.162189, 0.007781}}],
    Polygon[{{1.462826, 0.158114, 0.011432},{1.461613, 0.159784, 0.014801},{
      1.466119, 0.164291, 0.014801},{1.467790, 0.163078, 0.011432}}],
    Polygon[{{1.461613, 0.159784, 0.014801},{1.460104, 0.161861, 0.017806},{
      1.464043, 0.165800, 0.017806},{1.466119, 0.164291, 0.014801}}],
    Polygon[{{1.460104, 0.161861, 0.017806},{1.458338, 0.164291, 0.020372},{
      1.461613, 0.167566, 0.020372},{1.464043, 0.165800, 0.017806}}],
    Polygon[{{1.458338, 0.164291, 0.020372},{1.456358, 0.167017, 0.022436},{
      1.458887, 0.169546, 0.022436},{1.461613, 0.167566, 0.020372}}],
    Polygon[{{1.456358, 0.167017, 0.022436},{1.454212, 0.169970, 0.023948},{
      1.455934, 0.171692, 0.023948},{1.458887, 0.169546, 0.022436}}],
    Polygon[{{1.454212, 0.169970, 0.023948},{1.451954, 0.173079, 0.024871},{
      1.452825, 0.173950, 0.024871},{1.455934, 0.171692, 0.023948}}],
    Polygon[{{1.452825, 0.173950, -0.024871},{1.455934, 0.171692, -0.023948},{
      1.457039, 0.173861, -0.023948},{1.453385, 0.175048, -0.024871}}],
    Polygon[{{1.455934, 0.171692, -0.023948},{1.458887, 0.169546, -0.022436},{
      1.460511, 0.172733, -0.022436},{1.457039, 0.173861, -0.023948}}],
    Polygon[{{1.458887, 0.169546, -0.022436},{1.461613, 0.167566, -0.020372},{
      1.463715, 0.171692, -0.020372},{1.460511, 0.172733, -0.022436}}],
    Polygon[{{1.461613, 0.167566, -0.020372},{1.464043, 0.165800, -0.017806},{
      1.466573, 0.170763, -0.017806},{1.463715, 0.171692, -0.020372}}],
    Polygon[{{1.464043, 0.165800, -0.017806},{1.466119, 0.164291, -0.014801},{
      1.469013, 0.169970, -0.014801},{1.466573, 0.170763, -0.017806}}],
    Polygon[{{1.466119, 0.164291, -0.014801},{1.467790, 0.163078, -0.011432},{
      1.470977, 0.169332, -0.011432},{1.469013, 0.169970, -0.014801}}],
    Polygon[{{1.467790, 0.163078, -0.011432},{1.469013, 0.162189, -0.007781},{
      1.472415, 0.168865, -0.007781},{1.470977, 0.169332, -0.011432}}],
    Polygon[{{1.469013, 0.162189, -0.007781},{1.469759, 0.161647, -0.003939},{
      1.473292, 0.168580, -0.003939},{1.472415, 0.168865, -0.007781}}],
    Polygon[{{1.469759, 0.161647, -0.003939},{1.470010, 0.161465, 0.000000},{
      1.473587, 0.168484, 0.000000},{1.473292, 0.168580, -0.003939}}],
    Polygon[{{1.470010, 0.161465, 0.000000},{1.469759, 0.161647, 0.003939},{
      1.473292, 0.168580, 0.003939},{1.473587, 0.168484, 0.000000}}],
    Polygon[{{1.469759, 0.161647, 0.003939},{1.469013, 0.162189, 0.007781},{
      1.472415, 0.168865, 0.007781},{1.473292, 0.168580, 0.003939}}],
    Polygon[{{1.469013, 0.162189, 0.007781},{1.467790, 0.163078, 0.011432},{
      1.470977, 0.169332, 0.011432},{1.472415, 0.168865, 0.007781}}],
    Polygon[{{1.467790, 0.163078, 0.011432},{1.466119, 0.164291, 0.014801},{
      1.469013, 0.169970, 0.014801},{1.470977, 0.169332, 0.011432}}],
    Polygon[{{1.466119, 0.164291, 0.014801},{1.464043, 0.165800, 0.017806},{
      1.466573, 0.170763, 0.017806},{1.469013, 0.169970, 0.014801}}],
    Polygon[{{1.464043, 0.165800, 0.017806},{1.461613, 0.167566, 0.020372},{
      1.463715, 0.171692, 0.020372},{1.466573, 0.170763, 0.017806}}],
    Polygon[{{1.461613, 0.167566, 0.020372},{1.458887, 0.169546, 0.022436},{
      1.460511, 0.172733, 0.022436},{1.463715, 0.171692, 0.020372}}],
    Polygon[{{1.458887, 0.169546, 0.022436},{1.455934, 0.171692, 0.023948},{
      1.457039, 0.173861, 0.023948},{1.460511, 0.172733, 0.022436}}],
    Polygon[{{1.455934, 0.171692, 0.023948},{1.452825, 0.173950, 0.024871},{
      1.453385, 0.175048, 0.024871},{1.457039, 0.173861, 0.023948}}],
    Polygon[{{1.453385, 0.175048, -0.024871},{1.457039, 0.173861, -0.023948},{
      1.457420, 0.176266, -0.023948},{1.453578, 0.176266, -0.024871}}],
    Polygon[{{1.457039, 0.173861, -0.023948},{1.460511, 0.172733, -0.022436},{
      1.461070, 0.176266, -0.022436},{1.457420, 0.176266, -0.023948}}],
    Polygon[{{1.460511, 0.172733, -0.022436},{1.463715, 0.171692, -0.020372},{
      1.464439, 0.176266, -0.020372},{1.461070, 0.176266, -0.022436}}],
    Polygon[{{1.463715, 0.171692, -0.020372},{1.466573, 0.170763, -0.017806},{
      1.467444, 0.176266, -0.017806},{1.464439, 0.176266, -0.020372}}],
    Polygon[{{1.466573, 0.170763, -0.017806},{1.469013, 0.169970, -0.014801},{
      1.470010, 0.176266, -0.014801},{1.467444, 0.176266, -0.017806}}],
    Polygon[{{1.469013, 0.169970, -0.014801},{1.470977, 0.169332, -0.011432},{
      1.472075, 0.176266, -0.011432},{1.470010, 0.176266, -0.014801}}],
    Polygon[{{1.470977, 0.169332, -0.011432},{1.472415, 0.168865, -0.007781},{
      1.473587, 0.176266, -0.007781},{1.472075, 0.176266, -0.011432}}],
    Polygon[{{1.472415, 0.168865, -0.007781},{1.473292, 0.168580, -0.003939},{
      1.474509, 0.176266, -0.003939},{1.473587, 0.176266, -0.007781}}],
    Polygon[{{1.473292, 0.168580, -0.003939},{1.473587, 0.168484, 0.000000},{
      1.474819, 0.176266, 0.000000},{1.474509, 0.176266, -0.003939}}],
    Polygon[{{1.473587, 0.168484, 0.000000},{1.473292, 0.168580, 0.003939},{
      1.474509, 0.176266, 0.003939},{1.474819, 0.176266, 0.000000}}],
    Polygon[{{1.473292, 0.168580, 0.003939},{1.472415, 0.168865, 0.007781},{
      1.473587, 0.176266, 0.007781},{1.474509, 0.176266, 0.003939}}],
    Polygon[{{1.472415, 0.168865, 0.007781},{1.470977, 0.169332, 0.011432},{
      1.472075, 0.176266, 0.011432},{1.473587, 0.176266, 0.007781}}],
    Polygon[{{1.470977, 0.169332, 0.011432},{1.469013, 0.169970, 0.014801},{
      1.470010, 0.176266, 0.014801},{1.472075, 0.176266, 0.011432}}],
    Polygon[{{1.469013, 0.169970, 0.014801},{1.466573, 0.170763, 0.017806},{
      1.467444, 0.176266, 0.017806},{1.470010, 0.176266, 0.014801}}],
    Polygon[{{1.466573, 0.170763, 0.017806},{1.463715, 0.171692, 0.020372},{
      1.464439, 0.176266, 0.020372},{1.467444, 0.176266, 0.017806}}],
    Polygon[{{1.463715, 0.171692, 0.020372},{1.460511, 0.172733, 0.022436},{
      1.461070, 0.176266, 0.022436},{1.464439, 0.176266, 0.020372}}],
    Polygon[{{1.460511, 0.172733, 0.022436},{1.457039, 0.173861, 0.023948},{
      1.457420, 0.176266, 0.023948},{1.461070, 0.176266, 0.022436}}],
    Polygon[{{1.457039, 0.173861, 0.023948},{1.453385, 0.175048, 0.024871},{
      1.453578, 0.176266, 0.024871},{1.457420, 0.176266, 0.023948}}],
    Polygon[{{1.464612, 0.211564, -0.012292},{1.466511, 0.211564, -0.011836},{
      1.466323, 0.212753, -0.011836},{1.464517, 0.212166, -0.012292}}],
    Polygon[{{1.466511, 0.211564, -0.011836},{1.468315, 0.211564, -0.011089},{
      1.468038, 0.213310, -0.011089},{1.466323, 0.212753, -0.011836}}],
    Polygon[{{1.468315, 0.211564, -0.011089},{1.469980, 0.211564, -0.010068},{
      1.469622, 0.213825, -0.010068},{1.468038, 0.213310, -0.011089}}],
    Polygon[{{1.469980, 0.211564, -0.010068},{1.471465, 0.211564, -0.008800},{
      1.471034, 0.214284, -0.008800},{1.469622, 0.213825, -0.010068}}],
    Polygon[{{1.471465, 0.211564, -0.008800},{1.472733, 0.211564, -0.007315},{
      1.472241, 0.214676, -0.007315},{1.471034, 0.214284, -0.008800}}],
    Polygon[{{1.472733, 0.211564, -0.007315},{1.473754, 0.211564, -0.005650},{
      1.473211, 0.214991, -0.005650},{1.472241, 0.214676, -0.007315}}],
    Polygon[{{1.473754, 0.211564, -0.005650},{1.474501, 0.211564, -0.003846},{
      1.473922, 0.215222, -0.003846},{1.473211, 0.214991, -0.005650}}],
    Polygon[{{1.474501, 0.211564, -0.003846},{1.474957, 0.211564, -0.001947},{
      1.474355, 0.215363, -0.001947},{1.473922, 0.215222, -0.003846}}],
    Polygon[{{1.474957, 0.211564, -0.001947},{1.475110, 0.211564, 0.000000},{
      1.474501, 0.215410, 0.000000},{1.474355, 0.215363, -0.001947}}],
    Polygon[{{1.475110, 0.211564, 0.000000},{1.474957, 0.211564, 0.001947},{
      1.474355, 0.215363, 0.001947},{1.474501, 0.215410, 0.000000}}],
    Polygon[{{1.474957, 0.211564, 0.001947},{1.474501, 0.211564, 0.003846},{
      1.473922, 0.215222, 0.003846},{1.474355, 0.215363, 0.001947}}],
    Polygon[{{1.474501, 0.211564, 0.003846},{1.473754, 0.211564, 0.005650},{
      1.473211, 0.214991, 0.005650},{1.473922, 0.215222, 0.003846}}],
    Polygon[{{1.473754, 0.211564, 0.005650},{1.472733, 0.211564, 0.007315},{
      1.472241, 0.214676, 0.007315},{1.473211, 0.214991, 0.005650}}],
    Polygon[{{1.472733, 0.211564, 0.007315},{1.471465, 0.211564, 0.008800},{
      1.471034, 0.214284, 0.008800},{1.472241, 0.214676, 0.007315}}],
    Polygon[{{1.471465, 0.211564, 0.008800},{1.469980, 0.211564, 0.010068},{
      1.469622, 0.213825, 0.010068},{1.471034, 0.214284, 0.008800}}],
    Polygon[{{1.469980, 0.211564, 0.010068},{1.468315, 0.211564, 0.011089},{
      1.468038, 0.213310, 0.011089},{1.469622, 0.213825, 0.010068}}],
    Polygon[{{1.468315, 0.211564, 0.011089},{1.466511, 0.211564, 0.011836},{
      1.466323, 0.212753, 0.011836},{1.468038, 0.213310, 0.011089}}],
    Polygon[{{1.466511, 0.211564, 0.011836},{1.464612, 0.211564, 0.012292},{
      1.464517, 0.212166, 0.012292},{1.466323, 0.212753, 0.011836}}],
    Polygon[{{1.464517, 0.212166, -0.012292},{1.466323, 0.212753, -0.011836},{
      1.465776, 0.213825, -0.011836},{1.464240, 0.212709, -0.012292}}],
    Polygon[{{1.466323, 0.212753, -0.011836},{1.468038, 0.213310, -0.011089},{
      1.467236, 0.214885, -0.011089},{1.465776, 0.213825, -0.011836}}],
    Polygon[{{1.468038, 0.213310, -0.011089},{1.469622, 0.213825, -0.010068},{
      1.468583, 0.215864, -0.010068},{1.467236, 0.214885, -0.011089}}],
    Polygon[{{1.469622, 0.213825, -0.010068},{1.471034, 0.214284, -0.008800},{
      1.469784, 0.216737, -0.008800},{1.468583, 0.215864, -0.010068}}],
    Polygon[{{1.471034, 0.214284, -0.008800},{1.472241, 0.214676, -0.007315},{
      1.470810, 0.217482, -0.007315},{1.469784, 0.216737, -0.008800}}],
    Polygon[{{1.472241, 0.214676, -0.007315},{1.473211, 0.214991, -0.005650},{
      1.471636, 0.218082, -0.005650},{1.470810, 0.217482, -0.007315}}],
    Polygon[{{1.473211, 0.214991, -0.005650},{1.473922, 0.215222, -0.003846},{
      1.472241, 0.218521, -0.003846},{1.471636, 0.218082, -0.005650}}],
    Polygon[{{1.473922, 0.215222, -0.003846},{1.474355, 0.215363, -0.001947},{
      1.472609, 0.218789, -0.001947},{1.472241, 0.218521, -0.003846}}],
    Polygon[{{1.474355, 0.215363, -0.001947},{1.474501, 0.215410, 0.000000},{
      1.472733, 0.218879, 0.000000},{1.472609, 0.218789, -0.001947}}],
    Polygon[{{1.474501, 0.215410, 0.000000},{1.474355, 0.215363, 0.001947},{
      1.472609, 0.218789, 0.001947},{1.472733, 0.218879, 0.000000}}],
    Polygon[{{1.474355, 0.215363, 0.001947},{1.473922, 0.215222, 0.003846},{
      1.472241, 0.218521, 0.003846},{1.472609, 0.218789, 0.001947}}],
    Polygon[{{1.473922, 0.215222, 0.003846},{1.473211, 0.214991, 0.005650},{
      1.471636, 0.218082, 0.005650},{1.472241, 0.218521, 0.003846}}],
    Polygon[{{1.473211, 0.214991, 0.005650},{1.472241, 0.214676, 0.007315},{
      1.470810, 0.217482, 0.007315},{1.471636, 0.218082, 0.005650}}],
    Polygon[{{1.472241, 0.214676, 0.007315},{1.471034, 0.214284, 0.008800},{
      1.469784, 0.216737, 0.008800},{1.470810, 0.217482, 0.007315}}],
    Polygon[{{1.471034, 0.214284, 0.008800},{1.469622, 0.213825, 0.010068},{
      1.468583, 0.215864, 0.010068},{1.469784, 0.216737, 0.008800}}],
    Polygon[{{1.469622, 0.213825, 0.010068},{1.468038, 0.213310, 0.011089},{
      1.467236, 0.214885, 0.011089},{1.468583, 0.215864, 0.010068}}],
    Polygon[{{1.468038, 0.213310, 0.011089},{1.466323, 0.212753, 0.011836},{
      1.465776, 0.213825, 0.011836},{1.467236, 0.214885, 0.011089}}],
    Polygon[{{1.466323, 0.212753, 0.011836},{1.464517, 0.212166, 0.012292},{
      1.464240, 0.212709, 0.012292},{1.465776, 0.213825, 0.011836}}],
    Polygon[{{1.464240, 0.212709, -0.012292},{1.465776, 0.213825, -0.011836},{
      1.464926, 0.214676, -0.011836},{1.463809, 0.213139, -0.012292}}],
    Polygon[{{1.465776, 0.213825, -0.011836},{1.467236, 0.214885, -0.011089},{
      1.465986, 0.216135, -0.011089},{1.464926, 0.214676, -0.011836}}],
    Polygon[{{1.467236, 0.214885, -0.011089},{1.468583, 0.215864, -0.010068},{
      1.466965, 0.217482, -0.010068},{1.465986, 0.216135, -0.011089}}],
    Polygon[{{1.468583, 0.215864, -0.010068},{1.469784, 0.216737, -0.008800},{
      1.467838, 0.218684, -0.008800},{1.466965, 0.217482, -0.010068}}],
    Polygon[{{1.469784, 0.216737, -0.008800},{1.470810, 0.217482, -0.007315},{
      1.468583, 0.219710, -0.007315},{1.467838, 0.218684, -0.008800}}],
    Polygon[{{1.470810, 0.217482, -0.007315},{1.471636, 0.218082, -0.005650},{
      1.469183, 0.220535, -0.005650},{1.468583, 0.219710, -0.007315}}],
    Polygon[{{1.471636, 0.218082, -0.005650},{1.472241, 0.218521, -0.003846},{
      1.469622, 0.221140, -0.003846},{1.469183, 0.220535, -0.005650}}],
    Polygon[{{1.472241, 0.218521, -0.003846},{1.472609, 0.218789, -0.001947},{
      1.469890, 0.221509, -0.001947},{1.469622, 0.221140, -0.003846}}],
    Polygon[{{1.472609, 0.218789, -0.001947},{1.472733, 0.218879, 0.000000},{
      1.469980, 0.221632, 0.000000},{1.469890, 0.221509, -0.001947}}],
    Polygon[{{1.472733, 0.218879, 0.000000},{1.472609, 0.218789, 0.001947},{
      1.469890, 0.221509, 0.001947},{1.469980, 0.221632, 0.000000}}],
    Polygon[{{1.472609, 0.218789, 0.001947},{1.472241, 0.218521, 0.003846},{
      1.469622, 0.221140, 0.003846},{1.469890, 0.221509, 0.001947}}],
    Polygon[{{1.472241, 0.218521, 0.003846},{1.471636, 0.218082, 0.005650},{
      1.469183, 0.220535, 0.005650},{1.469622, 0.221140, 0.003846}}],
    Polygon[{{1.471636, 0.218082, 0.005650},{1.470810, 0.217482, 0.007315},{
      1.468583, 0.219710, 0.007315},{1.469183, 0.220535, 0.005650}}],
    Polygon[{{1.470810, 0.217482, 0.007315},{1.469784, 0.216737, 0.008800},{
      1.467838, 0.218684, 0.008800},{1.468583, 0.219710, 0.007315}}],
    Polygon[{{1.469784, 0.216737, 0.008800},{1.468583, 0.215864, 0.010068},{
      1.466965, 0.217482, 0.010068},{1.467838, 0.218684, 0.008800}}],
    Polygon[{{1.468583, 0.215864, 0.010068},{1.467236, 0.214885, 0.011089},{
      1.465986, 0.216135, 0.011089},{1.466965, 0.217482, 0.010068}}],
    Polygon[{{1.467236, 0.214885, 0.011089},{1.465776, 0.213825, 0.011836},{
      1.464926, 0.214676, 0.011836},{1.465986, 0.216135, 0.011089}}],
    Polygon[{{1.465776, 0.213825, 0.011836},{1.464240, 0.212709, 0.012292},{
      1.463809, 0.213139, 0.012292},{1.464926, 0.214676, 0.011836}}],
    Polygon[{{1.463809, 0.213139, -0.012292},{1.464926, 0.214676, -0.011836},{
      1.463853, 0.215222, -0.011836},{1.463267, 0.213416, -0.012292}}],
    Polygon[{{1.464926, 0.214676, -0.011836},{1.465986, 0.216135, -0.011089},{
      1.464411, 0.216938, -0.011089},{1.463853, 0.215222, -0.011836}}],
    Polygon[{{1.465986, 0.216135, -0.011089},{1.466965, 0.217482, -0.010068},{
      1.464926, 0.218521, -0.010068},{1.464411, 0.216938, -0.011089}}],
    Polygon[{{1.466965, 0.217482, -0.010068},{1.467838, 0.218684, -0.008800},{
      1.465384, 0.219933, -0.008800},{1.464926, 0.218521, -0.010068}}],
    Polygon[{{1.467838, 0.218684, -0.008800},{1.468583, 0.219710, -0.007315},{
      1.465776, 0.221140, -0.007315},{1.465384, 0.219933, -0.008800}}],
    Polygon[{{1.468583, 0.219710, -0.007315},{1.469183, 0.220535, -0.005650},{
      1.466092, 0.222110, -0.005650},{1.465776, 0.221140, -0.007315}}],
    Polygon[{{1.469183, 0.220535, -0.005650},{1.469622, 0.221140, -0.003846},{
      1.466323, 0.222821, -0.003846},{1.466092, 0.222110, -0.005650}}],
    Polygon[{{1.469622, 0.221140, -0.003846},{1.469890, 0.221509, -0.001947},{
      1.466463, 0.223254, -0.001947},{1.466323, 0.222821, -0.003846}}],
    Polygon[{{1.469890, 0.221509, -0.001947},{1.469980, 0.221632, 0.000000},{
      1.466511, 0.223400, 0.000000},{1.466463, 0.223254, -0.001947}}],
    Polygon[{{1.469980, 0.221632, 0.000000},{1.469890, 0.221509, 0.001947},{
      1.466463, 0.223254, 0.001947},{1.466511, 0.223400, 0.000000}}],
    Polygon[{{1.469890, 0.221509, 0.001947},{1.469622, 0.221140, 0.003846},{
      1.466323, 0.222821, 0.003846},{1.466463, 0.223254, 0.001947}}],
    Polygon[{{1.469622, 0.221140, 0.003846},{1.469183, 0.220535, 0.005650},{
      1.466092, 0.222110, 0.005650},{1.466323, 0.222821, 0.003846}}],
    Polygon[{{1.469183, 0.220535, 0.005650},{1.468583, 0.219710, 0.007315},{
      1.465776, 0.221140, 0.007315},{1.466092, 0.222110, 0.005650}}],
    Polygon[{{1.468583, 0.219710, 0.007315},{1.467838, 0.218684, 0.008800},{
      1.465384, 0.219933, 0.008800},{1.465776, 0.221140, 0.007315}}],
    Polygon[{{1.467838, 0.218684, 0.008800},{1.466965, 0.217482, 0.010068},{
      1.464926, 0.218521, 0.010068},{1.465384, 0.219933, 0.008800}}],
    Polygon[{{1.466965, 0.217482, 0.010068},{1.465986, 0.216135, 0.011089},{
      1.464411, 0.216938, 0.011089},{1.464926, 0.218521, 0.010068}}],
    Polygon[{{1.465986, 0.216135, 0.011089},{1.464926, 0.214676, 0.011836},{
      1.463853, 0.215222, 0.011836},{1.464411, 0.216938, 0.011089}}],
    Polygon[{{1.464926, 0.214676, 0.011836},{1.463809, 0.213139, 0.012292},{
      1.463267, 0.213416, 0.012292},{1.463853, 0.215222, 0.011836}}],
    Polygon[{{1.463267, 0.213416, -0.012292},{1.463853, 0.215222, -0.011836},{
      1.462665, 0.215410, -0.011836},{1.462665, 0.213511, -0.012292}}],
    Polygon[{{1.463853, 0.215222, -0.011836},{1.464411, 0.216938, -0.011089},{
      1.462665, 0.217214, -0.011089},{1.462665, 0.215410, -0.011836}}],
    Polygon[{{1.464411, 0.216938, -0.011089},{1.464926, 0.218521, -0.010068},{
      1.462665, 0.218879, -0.010068},{1.462665, 0.217214, -0.011089}}],
    Polygon[{{1.464926, 0.218521, -0.010068},{1.465384, 0.219933, -0.008800},{
      1.462665, 0.220364, -0.008800},{1.462665, 0.218879, -0.010068}}],
    Polygon[{{1.465384, 0.219933, -0.008800},{1.465776, 0.221140, -0.007315},{
      1.462665, 0.221632, -0.007315},{1.462665, 0.220364, -0.008800}}],
    Polygon[{{1.465776, 0.221140, -0.007315},{1.466092, 0.222110, -0.005650},{
      1.462665, 0.222653, -0.005650},{1.462665, 0.221632, -0.007315}}],
    Polygon[{{1.466092, 0.222110, -0.005650},{1.466323, 0.222821, -0.003846},{
      1.462665, 0.223400, -0.003846},{1.462665, 0.222653, -0.005650}}],
    Polygon[{{1.466323, 0.222821, -0.003846},{1.466463, 0.223254, -0.001947},{
      1.462665, 0.223856, -0.001947},{1.462665, 0.223400, -0.003846}}],
    Polygon[{{1.466463, 0.223254, -0.001947},{1.466511, 0.223400, 0.000000},{
      1.462665, 0.224009, 0.000000},{1.462665, 0.223856, -0.001947}}],
    Polygon[{{1.466511, 0.223400, 0.000000},{1.466463, 0.223254, 0.001947},{
      1.462665, 0.223856, 0.001947},{1.462665, 0.224009, 0.000000}}],
    Polygon[{{1.466463, 0.223254, 0.001947},{1.466323, 0.222821, 0.003846},{
      1.462665, 0.223400, 0.003846},{1.462665, 0.223856, 0.001947}}],
    Polygon[{{1.466323, 0.222821, 0.003846},{1.466092, 0.222110, 0.005650},{
      1.462665, 0.222653, 0.005650},{1.462665, 0.223400, 0.003846}}],
    Polygon[{{1.466092, 0.222110, 0.005650},{1.465776, 0.221140, 0.007315},{
      1.462665, 0.221632, 0.007315},{1.462665, 0.222653, 0.005650}}],
    Polygon[{{1.465776, 0.221140, 0.007315},{1.465384, 0.219933, 0.008800},{
      1.462665, 0.220364, 0.008800},{1.462665, 0.221632, 0.007315}}],
    Polygon[{{1.465384, 0.219933, 0.008800},{1.464926, 0.218521, 0.010068},{
      1.462665, 0.218879, 0.010068},{1.462665, 0.220364, 0.008800}}],
    Polygon[{{1.464926, 0.218521, 0.010068},{1.464411, 0.216938, 0.011089},{
      1.462665, 0.217214, 0.011089},{1.462665, 0.218879, 0.010068}}],
    Polygon[{{1.464411, 0.216938, 0.011089},{1.463853, 0.215222, 0.011836},{
      1.462665, 0.215410, 0.011836},{1.462665, 0.217214, 0.011089}}],
    Polygon[{{1.463853, 0.215222, 0.011836},{1.463267, 0.213416, 0.012292},{
      1.462665, 0.213511, 0.012292},{1.462665, 0.215410, 0.011836}}],
    Polygon[{{1.462665, 0.213511, -0.012292},{1.462665, 0.215410, -0.011836},{
      1.461477, 0.215222, -0.011836},{1.462064, 0.213416, -0.012292}}],
    Polygon[{{1.462665, 0.215410, -0.011836},{1.462665, 0.217214, -0.011089},{
      1.460919, 0.216938, -0.011089},{1.461477, 0.215222, -0.011836}}],
    Polygon[{{1.462665, 0.217214, -0.011089},{1.462665, 0.218879, -0.010068},{
      1.460405, 0.218521, -0.010068},{1.460919, 0.216938, -0.011089}}],
    Polygon[{{1.462665, 0.218879, -0.010068},{1.462665, 0.220364, -0.008800},{
      1.459946, 0.219933, -0.008800},{1.460405, 0.218521, -0.010068}}],
    Polygon[{{1.462665, 0.220364, -0.008800},{1.462665, 0.221632, -0.007315},{
      1.459554, 0.221140, -0.007315},{1.459946, 0.219933, -0.008800}}],
    Polygon[{{1.462665, 0.221632, -0.007315},{1.462665, 0.222653, -0.005650},{
      1.459239, 0.222110, -0.005650},{1.459554, 0.221140, -0.007315}}],
    Polygon[{{1.462665, 0.222653, -0.005650},{1.462665, 0.223400, -0.003846},{
      1.459008, 0.222821, -0.003846},{1.459239, 0.222110, -0.005650}}],
    Polygon[{{1.462665, 0.223400, -0.003846},{1.462665, 0.223856, -0.001947},{
      1.458867, 0.223254, -0.001947},{1.459008, 0.222821, -0.003846}}],
    Polygon[{{1.462665, 0.223856, -0.001947},{1.462665, 0.224009, 0.000000},{
      1.458819, 0.223400, 0.000000},{1.458867, 0.223254, -0.001947}}],
    Polygon[{{1.462665, 0.224009, 0.000000},{1.462665, 0.223856, 0.001947},{
      1.458867, 0.223254, 0.001947},{1.458819, 0.223400, 0.000000}}],
    Polygon[{{1.462665, 0.223856, 0.001947},{1.462665, 0.223400, 0.003846},{
      1.459008, 0.222821, 0.003846},{1.458867, 0.223254, 0.001947}}],
    Polygon[{{1.462665, 0.223400, 0.003846},{1.462665, 0.222653, 0.005650},{
      1.459239, 0.222110, 0.005650},{1.459008, 0.222821, 0.003846}}],
    Polygon[{{1.462665, 0.222653, 0.005650},{1.462665, 0.221632, 0.007315},{
      1.459554, 0.221140, 0.007315},{1.459239, 0.222110, 0.005650}}],
    Polygon[{{1.462665, 0.221632, 0.007315},{1.462665, 0.220364, 0.008800},{
      1.459946, 0.219933, 0.008800},{1.459554, 0.221140, 0.007315}}],
    Polygon[{{1.462665, 0.220364, 0.008800},{1.462665, 0.218879, 0.010068},{
      1.460405, 0.218521, 0.010068},{1.459946, 0.219933, 0.008800}}],
    Polygon[{{1.462665, 0.218879, 0.010068},{1.462665, 0.217214, 0.011089},{
      1.460919, 0.216938, 0.011089},{1.460405, 0.218521, 0.010068}}],
    Polygon[{{1.462665, 0.217214, 0.011089},{1.462665, 0.215410, 0.011836},{
      1.461477, 0.215222, 0.011836},{1.460919, 0.216938, 0.011089}}],
    Polygon[{{1.462665, 0.215410, 0.011836},{1.462665, 0.213511, 0.012292},{
      1.462064, 0.213416, 0.012292},{1.461477, 0.215222, 0.011836}}],
    Polygon[{{1.462064, 0.213416, -0.012292},{1.461477, 0.215222, -0.011836},{
      1.460405, 0.214676, -0.011836},{1.461521, 0.213139, -0.012292}}],
    Polygon[{{1.461477, 0.215222, -0.011836},{1.460919, 0.216938, -0.011089},{
      1.459344, 0.216135, -0.011089},{1.460405, 0.214676, -0.011836}}],
    Polygon[{{1.460919, 0.216938, -0.011089},{1.460405, 0.218521, -0.010068},{
      1.458365, 0.217482, -0.010068},{1.459344, 0.216135, -0.011089}}],
    Polygon[{{1.460405, 0.218521, -0.010068},{1.459946, 0.219933, -0.008800},{
      1.457493, 0.218684, -0.008800},{1.458365, 0.217482, -0.010068}}],
    Polygon[{{1.459946, 0.219933, -0.008800},{1.459554, 0.221140, -0.007315},{
      1.456747, 0.219710, -0.007315},{1.457493, 0.218684, -0.008800}}],
    Polygon[{{1.459554, 0.221140, -0.007315},{1.459239, 0.222110, -0.005650},{
      1.456147, 0.220535, -0.005650},{1.456747, 0.219710, -0.007315}}],
    Polygon[{{1.459239, 0.222110, -0.005650},{1.459008, 0.222821, -0.003846},{
      1.455708, 0.221140, -0.003846},{1.456147, 0.220535, -0.005650}}],
    Polygon[{{1.459008, 0.222821, -0.003846},{1.458867, 0.223254, -0.001947},{
      1.455440, 0.221509, -0.001947},{1.455708, 0.221140, -0.003846}}],
    Polygon[{{1.458867, 0.223254, -0.001947},{1.458819, 0.223400, 0.000000},{
      1.455350, 0.221632, 0.000000},{1.455440, 0.221509, -0.001947}}],
    Polygon[{{1.458819, 0.223400, 0.000000},{1.458867, 0.223254, 0.001947},{
      1.455440, 0.221509, 0.001947},{1.455350, 0.221632, 0.000000}}],
    Polygon[{{1.458867, 0.223254, 0.001947},{1.459008, 0.222821, 0.003846},{
      1.455708, 0.221140, 0.003846},{1.455440, 0.221509, 0.001947}}],
    Polygon[{{1.459008, 0.222821, 0.003846},{1.459239, 0.222110, 0.005650},{
      1.456147, 0.220535, 0.005650},{1.455708, 0.221140, 0.003846}}],
    Polygon[{{1.459239, 0.222110, 0.005650},{1.459554, 0.221140, 0.007315},{
      1.456747, 0.219710, 0.007315},{1.456147, 0.220535, 0.005650}}],
    Polygon[{{1.459554, 0.221140, 0.007315},{1.459946, 0.219933, 0.008800},{
      1.457493, 0.218684, 0.008800},{1.456747, 0.219710, 0.007315}}],
    Polygon[{{1.459946, 0.219933, 0.008800},{1.460405, 0.218521, 0.010068},{
      1.458365, 0.217482, 0.010068},{1.457493, 0.218684, 0.008800}}],
    Polygon[{{1.460405, 0.218521, 0.010068},{1.460919, 0.216938, 0.011089},{
      1.459344, 0.216135, 0.011089},{1.458365, 0.217482, 0.010068}}],
    Polygon[{{1.460919, 0.216938, 0.011089},{1.461477, 0.215222, 0.011836},{
      1.460405, 0.214676, 0.011836},{1.459344, 0.216135, 0.011089}}],
    Polygon[{{1.461477, 0.215222, 0.011836},{1.462064, 0.213416, 0.012292},{
      1.461521, 0.213139, 0.012292},{1.460405, 0.214676, 0.011836}}],
    Polygon[{{1.461521, 0.213139, -0.012292},{1.460405, 0.214676, -0.011836},{
      1.459554, 0.213825, -0.011836},{1.461090, 0.212709, -0.012292}}],
    Polygon[{{1.460405, 0.214676, -0.011836},{1.459344, 0.216135, -0.011089},{
      1.458094, 0.214885, -0.011089},{1.459554, 0.213825, -0.011836}}],
    Polygon[{{1.459344, 0.216135, -0.011089},{1.458365, 0.217482, -0.010068},{
      1.456747, 0.215864, -0.010068},{1.458094, 0.214885, -0.011089}}],
    Polygon[{{1.458365, 0.217482, -0.010068},{1.457493, 0.218684, -0.008800},{
      1.455546, 0.216737, -0.008800},{1.456747, 0.215864, -0.010068}}],
    Polygon[{{1.457493, 0.218684, -0.008800},{1.456747, 0.219710, -0.007315},{
      1.454520, 0.217482, -0.007315},{1.455546, 0.216737, -0.008800}}],
    Polygon[{{1.456747, 0.219710, -0.007315},{1.456147, 0.220535, -0.005650},{
      1.453694, 0.218082, -0.005650},{1.454520, 0.217482, -0.007315}}],
    Polygon[{{1.456147, 0.220535, -0.005650},{1.455708, 0.221140, -0.003846},{
      1.453090, 0.218521, -0.003846},{1.453694, 0.218082, -0.005650}}],
    Polygon[{{1.455708, 0.221140, -0.003846},{1.455440, 0.221509, -0.001947},{
      1.452721, 0.218789, -0.001947},{1.453090, 0.218521, -0.003846}}],
    Polygon[{{1.455440, 0.221509, -0.001947},{1.455350, 0.221632, 0.000000},{
      1.452597, 0.218879, 0.000000},{1.452721, 0.218789, -0.001947}}],
    Polygon[{{1.455350, 0.221632, 0.000000},{1.455440, 0.221509, 0.001947},{
      1.452721, 0.218789, 0.001947},{1.452597, 0.218879, 0.000000}}],
    Polygon[{{1.455440, 0.221509, 0.001947},{1.455708, 0.221140, 0.003846},{
      1.453090, 0.218521, 0.003846},{1.452721, 0.218789, 0.001947}}],
    Polygon[{{1.455708, 0.221140, 0.003846},{1.456147, 0.220535, 0.005650},{
      1.453694, 0.218082, 0.005650},{1.453090, 0.218521, 0.003846}}],
    Polygon[{{1.456147, 0.220535, 0.005650},{1.456747, 0.219710, 0.007315},{
      1.454520, 0.217482, 0.007315},{1.453694, 0.218082, 0.005650}}],
    Polygon[{{1.456747, 0.219710, 0.007315},{1.457493, 0.218684, 0.008800},{
      1.455546, 0.216737, 0.008800},{1.454520, 0.217482, 0.007315}}],
    Polygon[{{1.457493, 0.218684, 0.008800},{1.458365, 0.217482, 0.010068},{
      1.456747, 0.215864, 0.010068},{1.455546, 0.216737, 0.008800}}],
    Polygon[{{1.458365, 0.217482, 0.010068},{1.459344, 0.216135, 0.011089},{
      1.458094, 0.214885, 0.011089},{1.456747, 0.215864, 0.010068}}],
    Polygon[{{1.459344, 0.216135, 0.011089},{1.460405, 0.214676, 0.011836},{
      1.459554, 0.213825, 0.011836},{1.458094, 0.214885, 0.011089}}],
    Polygon[{{1.460405, 0.214676, 0.011836},{1.461521, 0.213139, 0.012292},{
      1.461090, 0.212709, 0.012292},{1.459554, 0.213825, 0.011836}}],
    Polygon[{{1.461090, 0.212709, -0.012292},{1.459554, 0.213825, -0.011836},{
      1.459008, 0.212753, -0.011836},{1.460814, 0.212166, -0.012292}}],
    Polygon[{{1.459554, 0.213825, -0.011836},{1.458094, 0.214885, -0.011089},{
      1.457292, 0.213310, -0.011089},{1.459008, 0.212753, -0.011836}}],
    Polygon[{{1.458094, 0.214885, -0.011089},{1.456747, 0.215864, -0.010068},{
      1.455708, 0.213825, -0.010068},{1.457292, 0.213310, -0.011089}}],
    Polygon[{{1.456747, 0.215864, -0.010068},{1.455546, 0.216737, -0.008800},{
      1.454296, 0.214284, -0.008800},{1.455708, 0.213825, -0.010068}}],
    Polygon[{{1.455546, 0.216737, -0.008800},{1.454520, 0.217482, -0.007315},{
      1.453090, 0.214676, -0.007315},{1.454296, 0.214284, -0.008800}}],
    Polygon[{{1.454520, 0.217482, -0.007315},{1.453694, 0.218082, -0.005650},{
      1.452119, 0.214991, -0.005650},{1.453090, 0.214676, -0.007315}}],
    Polygon[{{1.453694, 0.218082, -0.005650},{1.453090, 0.218521, -0.003846},{
      1.451409, 0.215222, -0.003846},{1.452119, 0.214991, -0.005650}}],
    Polygon[{{1.453090, 0.218521, -0.003846},{1.452721, 0.218789, -0.001947},{
      1.450975, 0.215363, -0.001947},{1.451409, 0.215222, -0.003846}}],
    Polygon[{{1.452721, 0.218789, -0.001947},{1.452597, 0.218879, 0.000000},{
      1.450829, 0.215410, 0.000000},{1.450975, 0.215363, -0.001947}}],
    Polygon[{{1.452597, 0.218879, 0.000000},{1.452721, 0.218789, 0.001947},{
      1.450975, 0.215363, 0.001947},{1.450829, 0.215410, 0.000000}}],
    Polygon[{{1.452721, 0.218789, 0.001947},{1.453090, 0.218521, 0.003846},{
      1.451409, 0.215222, 0.003846},{1.450975, 0.215363, 0.001947}}],
    Polygon[{{1.453090, 0.218521, 0.003846},{1.453694, 0.218082, 0.005650},{
      1.452119, 0.214991, 0.005650},{1.451409, 0.215222, 0.003846}}],
    Polygon[{{1.453694, 0.218082, 0.005650},{1.454520, 0.217482, 0.007315},{
      1.453090, 0.214676, 0.007315},{1.452119, 0.214991, 0.005650}}],
    Polygon[{{1.454520, 0.217482, 0.007315},{1.455546, 0.216737, 0.008800},{
      1.454296, 0.214284, 0.008800},{1.453090, 0.214676, 0.007315}}],
    Polygon[{{1.455546, 0.216737, 0.008800},{1.456747, 0.215864, 0.010068},{
      1.455708, 0.213825, 0.010068},{1.454296, 0.214284, 0.008800}}],
    Polygon[{{1.456747, 0.215864, 0.010068},{1.458094, 0.214885, 0.011089},{
      1.457292, 0.213310, 0.011089},{1.455708, 0.213825, 0.010068}}],
    Polygon[{{1.458094, 0.214885, 0.011089},{1.459554, 0.213825, 0.011836},{
      1.459008, 0.212753, 0.011836},{1.457292, 0.213310, 0.011089}}],
    Polygon[{{1.459554, 0.213825, 0.011836},{1.461090, 0.212709, 0.012292},{
      1.460814, 0.212166, 0.012292},{1.459008, 0.212753, 0.011836}}],
    Polygon[{{1.460814, 0.212166, -0.012292},{1.459008, 0.212753, -0.011836},{
      1.458819, 0.211564, -0.011836},{1.460718, 0.211564, -0.012292}}],
    Polygon[{{1.459008, 0.212753, -0.011836},{1.457292, 0.213310, -0.011089},{
      1.457015, 0.211564, -0.011089},{1.458819, 0.211564, -0.011836}}],
    Polygon[{{1.457292, 0.213310, -0.011089},{1.455708, 0.213825, -0.010068},{
      1.455350, 0.211564, -0.010068},{1.457015, 0.211564, -0.011089}}],
    Polygon[{{1.455708, 0.213825, -0.010068},{1.454296, 0.214284, -0.008800},{
      1.453865, 0.211564, -0.008800},{1.455350, 0.211564, -0.010068}}],
    Polygon[{{1.454296, 0.214284, -0.008800},{1.453090, 0.214676, -0.007315},{
      1.452597, 0.211564, -0.007315},{1.453865, 0.211564, -0.008800}}],
    Polygon[{{1.453090, 0.214676, -0.007315},{1.452119, 0.214991, -0.005650},{
      1.451577, 0.211564, -0.005650},{1.452597, 0.211564, -0.007315}}],
    Polygon[{{1.452119, 0.214991, -0.005650},{1.451409, 0.215222, -0.003846},{
      1.450829, 0.211564, -0.003846},{1.451577, 0.211564, -0.005650}}],
    Polygon[{{1.451409, 0.215222, -0.003846},{1.450975, 0.215363, -0.001947},{
      1.450373, 0.211564, -0.001947},{1.450829, 0.211564, -0.003846}}],
    Polygon[{{1.450975, 0.215363, -0.001947},{1.450829, 0.215410, 0.000000},{
      1.450220, 0.211564, 0.000000},{1.450373, 0.211564, -0.001947}}],
    Polygon[{{1.450829, 0.215410, 0.000000},{1.450975, 0.215363, 0.001947},{
      1.450373, 0.211564, 0.001947},{1.450220, 0.211564, 0.000000}}],
    Polygon[{{1.450975, 0.215363, 0.001947},{1.451409, 0.215222, 0.003846},{
      1.450829, 0.211564, 0.003846},{1.450373, 0.211564, 0.001947}}],
    Polygon[{{1.451409, 0.215222, 0.003846},{1.452119, 0.214991, 0.005650},{
      1.451577, 0.211564, 0.005650},{1.450829, 0.211564, 0.003846}}],
    Polygon[{{1.452119, 0.214991, 0.005650},{1.453090, 0.214676, 0.007315},{
      1.452597, 0.211564, 0.007315},{1.451577, 0.211564, 0.005650}}],
    Polygon[{{1.453090, 0.214676, 0.007315},{1.454296, 0.214284, 0.008800},{
      1.453865, 0.211564, 0.008800},{1.452597, 0.211564, 0.007315}}],
    Polygon[{{1.454296, 0.214284, 0.008800},{1.455708, 0.213825, 0.010068},{
      1.455350, 0.211564, 0.010068},{1.453865, 0.211564, 0.008800}}],
    Polygon[{{1.455708, 0.213825, 0.010068},{1.457292, 0.213310, 0.011089},{
      1.457015, 0.211564, 0.011089},{1.455350, 0.211564, 0.010068}}],
    Polygon[{{1.457292, 0.213310, 0.011089},{1.459008, 0.212753, 0.011836},{
      1.458819, 0.211564, 0.011836},{1.457015, 0.211564, 0.011089}}],
    Polygon[{{1.459008, 0.212753, 0.011836},{1.460814, 0.212166, 0.012292},{
      1.460718, 0.211564, 0.012292},{1.458819, 0.211564, 0.011836}}],
    Polygon[{{1.460718, 0.211564, -0.012292},{1.458819, 0.211564, -0.011836},{
      1.459008, 0.210376, -0.011836},{1.460814, 0.210963, -0.012292}}],
    Polygon[{{1.458819, 0.211564, -0.011836},{1.457015, 0.211564, -0.011089},{
      1.457292, 0.209818, -0.011089},{1.459008, 0.210376, -0.011836}}],
    Polygon[{{1.457015, 0.211564, -0.011089},{1.455350, 0.211564, -0.010068},{
      1.455708, 0.209304, -0.010068},{1.457292, 0.209818, -0.011089}}],
    Polygon[{{1.455350, 0.211564, -0.010068},{1.453865, 0.211564, -0.008800},{
      1.454296, 0.208845, -0.008800},{1.455708, 0.209304, -0.010068}}],
    Polygon[{{1.453865, 0.211564, -0.008800},{1.452597, 0.211564, -0.007315},{
      1.453090, 0.208453, -0.007315},{1.454296, 0.208845, -0.008800}}],
    Polygon[{{1.452597, 0.211564, -0.007315},{1.451577, 0.211564, -0.005650},{
      1.452119, 0.208138, -0.005650},{1.453090, 0.208453, -0.007315}}],
    Polygon[{{1.451577, 0.211564, -0.005650},{1.450829, 0.211564, -0.003846},{
      1.451409, 0.207907, -0.003846},{1.452119, 0.208138, -0.005650}}],
    Polygon[{{1.450829, 0.211564, -0.003846},{1.450373, 0.211564, -0.001947},{
      1.450975, 0.207766, -0.001947},{1.451409, 0.207907, -0.003846}}],
    Polygon[{{1.450373, 0.211564, -0.001947},{1.450220, 0.211564, 0.000000},{
      1.450829, 0.207719, 0.000000},{1.450975, 0.207766, -0.001947}}],
    Polygon[{{1.450220, 0.211564, 0.000000},{1.450373, 0.211564, 0.001947},{
      1.450975, 0.207766, 0.001947},{1.450829, 0.207719, 0.000000}}],
    Polygon[{{1.450373, 0.211564, 0.001947},{1.450829, 0.211564, 0.003846},{
      1.451409, 0.207907, 0.003846},{1.450975, 0.207766, 0.001947}}],
    Polygon[{{1.450829, 0.211564, 0.003846},{1.451577, 0.211564, 0.005650},{
      1.452119, 0.208138, 0.005650},{1.451409, 0.207907, 0.003846}}],
    Polygon[{{1.451577, 0.211564, 0.005650},{1.452597, 0.211564, 0.007315},{
      1.453090, 0.208453, 0.007315},{1.452119, 0.208138, 0.005650}}],
    Polygon[{{1.452597, 0.211564, 0.007315},{1.453865, 0.211564, 0.008800},{
      1.454296, 0.208845, 0.008800},{1.453090, 0.208453, 0.007315}}],
    Polygon[{{1.453865, 0.211564, 0.008800},{1.455350, 0.211564, 0.010068},{
      1.455708, 0.209304, 0.010068},{1.454296, 0.208845, 0.008800}}],
    Polygon[{{1.455350, 0.211564, 0.010068},{1.457015, 0.211564, 0.011089},{
      1.457292, 0.209818, 0.011089},{1.455708, 0.209304, 0.010068}}],
    Polygon[{{1.457015, 0.211564, 0.011089},{1.458819, 0.211564, 0.011836},{
      1.459008, 0.210376, 0.011836},{1.457292, 0.209818, 0.011089}}],
    Polygon[{{1.458819, 0.211564, 0.011836},{1.460718, 0.211564, 0.012292},{
      1.460814, 0.210963, 0.012292},{1.459008, 0.210376, 0.011836}}],
    Polygon[{{1.460814, 0.210963, -0.012292},{1.459008, 0.210376, -0.011836},{
      1.459554, 0.209304, -0.011836},{1.461090, 0.210420, -0.012292}}],
    Polygon[{{1.459008, 0.210376, -0.011836},{1.457292, 0.209818, -0.011089},{
      1.458094, 0.208243, -0.011089},{1.459554, 0.209304, -0.011836}}],
    Polygon[{{1.457292, 0.209818, -0.011089},{1.455708, 0.209304, -0.010068},{
      1.456747, 0.207265, -0.010068},{1.458094, 0.208243, -0.011089}}],
    Polygon[{{1.455708, 0.209304, -0.010068},{1.454296, 0.208845, -0.008800},{
      1.455546, 0.206392, -0.008800},{1.456747, 0.207265, -0.010068}}],
    Polygon[{{1.454296, 0.208845, -0.008800},{1.453090, 0.208453, -0.007315},{
      1.454520, 0.205646, -0.007315},{1.455546, 0.206392, -0.008800}}],
    Polygon[{{1.453090, 0.208453, -0.007315},{1.452119, 0.208138, -0.005650},{
      1.453694, 0.205047, -0.005650},{1.454520, 0.205646, -0.007315}}],
    Polygon[{{1.452119, 0.208138, -0.005650},{1.451409, 0.207907, -0.003846},{
      1.453090, 0.204607, -0.003846},{1.453694, 0.205047, -0.005650}}],
    Polygon[{{1.451409, 0.207907, -0.003846},{1.450975, 0.207766, -0.001947},{
      1.452721, 0.204339, -0.001947},{1.453090, 0.204607, -0.003846}}],
    Polygon[{{1.450975, 0.207766, -0.001947},{1.450829, 0.207719, 0.000000},{
      1.452597, 0.204249, 0.000000},{1.452721, 0.204339, -0.001947}}],
    Polygon[{{1.450829, 0.207719, 0.000000},{1.450975, 0.207766, 0.001947},{
      1.452721, 0.204339, 0.001947},{1.452597, 0.204249, 0.000000}}],
    Polygon[{{1.450975, 0.207766, 0.001947},{1.451409, 0.207907, 0.003846},{
      1.453090, 0.204607, 0.003846},{1.452721, 0.204339, 0.001947}}],
    Polygon[{{1.451409, 0.207907, 0.003846},{1.452119, 0.208138, 0.005650},{
      1.453694, 0.205047, 0.005650},{1.453090, 0.204607, 0.003846}}],
    Polygon[{{1.452119, 0.208138, 0.005650},{1.453090, 0.208453, 0.007315},{
      1.454520, 0.205646, 0.007315},{1.453694, 0.205047, 0.005650}}],
    Polygon[{{1.453090, 0.208453, 0.007315},{1.454296, 0.208845, 0.008800},{
      1.455546, 0.206392, 0.008800},{1.454520, 0.205646, 0.007315}}],
    Polygon[{{1.454296, 0.208845, 0.008800},{1.455708, 0.209304, 0.010068},{
      1.456747, 0.207265, 0.010068},{1.455546, 0.206392, 0.008800}}],
    Polygon[{{1.455708, 0.209304, 0.010068},{1.457292, 0.209818, 0.011089},{
      1.458094, 0.208243, 0.011089},{1.456747, 0.207265, 0.010068}}],
    Polygon[{{1.457292, 0.209818, 0.011089},{1.459008, 0.210376, 0.011836},{
      1.459554, 0.209304, 0.011836},{1.458094, 0.208243, 0.011089}}],
    Polygon[{{1.459008, 0.210376, 0.011836},{1.460814, 0.210963, 0.012292},{
      1.461090, 0.210420, 0.012292},{1.459554, 0.209304, 0.011836}}],
    Polygon[{{1.461090, 0.210420, -0.012292},{1.459554, 0.209304, -0.011836},{
      1.460405, 0.208453, -0.011836},{1.461521, 0.209989, -0.012292}}],
    Polygon[{{1.459554, 0.209304, -0.011836},{1.458094, 0.208243, -0.011089},{
      1.459344, 0.206993, -0.011089},{1.460405, 0.208453, -0.011836}}],
    Polygon[{{1.458094, 0.208243, -0.011089},{1.456747, 0.207265, -0.010068},{
      1.458365, 0.205646, -0.010068},{1.459344, 0.206993, -0.011089}}],
    Polygon[{{1.456747, 0.207265, -0.010068},{1.455546, 0.206392, -0.008800},{
      1.457493, 0.204445, -0.008800},{1.458365, 0.205646, -0.010068}}],
    Polygon[{{1.455546, 0.206392, -0.008800},{1.454520, 0.205646, -0.007315},{
      1.456747, 0.203419, -0.007315},{1.457493, 0.204445, -0.008800}}],
    Polygon[{{1.454520, 0.205646, -0.007315},{1.453694, 0.205047, -0.005650},{
      1.456147, 0.202593, -0.005650},{1.456747, 0.203419, -0.007315}}],
    Polygon[{{1.453694, 0.205047, -0.005650},{1.453090, 0.204607, -0.003846},{
      1.455708, 0.201989, -0.003846},{1.456147, 0.202593, -0.005650}}],
    Polygon[{{1.453090, 0.204607, -0.003846},{1.452721, 0.204339, -0.001947},{
      1.455440, 0.201620, -0.001947},{1.455708, 0.201989, -0.003846}}],
    Polygon[{{1.452721, 0.204339, -0.001947},{1.452597, 0.204249, 0.000000},{
      1.455350, 0.201496, 0.000000},{1.455440, 0.201620, -0.001947}}],
    Polygon[{{1.452597, 0.204249, 0.000000},{1.452721, 0.204339, 0.001947},{
      1.455440, 0.201620, 0.001947},{1.455350, 0.201496, 0.000000}}],
    Polygon[{{1.452721, 0.204339, 0.001947},{1.453090, 0.204607, 0.003846},{
      1.455708, 0.201989, 0.003846},{1.455440, 0.201620, 0.001947}}],
    Polygon[{{1.453090, 0.204607, 0.003846},{1.453694, 0.205047, 0.005650},{
      1.456147, 0.202593, 0.005650},{1.455708, 0.201989, 0.003846}}],
    Polygon[{{1.453694, 0.205047, 0.005650},{1.454520, 0.205646, 0.007315},{
      1.456747, 0.203419, 0.007315},{1.456147, 0.202593, 0.005650}}],
    Polygon[{{1.454520, 0.205646, 0.007315},{1.455546, 0.206392, 0.008800},{
      1.457493, 0.204445, 0.008800},{1.456747, 0.203419, 0.007315}}],
    Polygon[{{1.455546, 0.206392, 0.008800},{1.456747, 0.207265, 0.010068},{
      1.458365, 0.205646, 0.010068},{1.457493, 0.204445, 0.008800}}],
    Polygon[{{1.456747, 0.207265, 0.010068},{1.458094, 0.208243, 0.011089},{
      1.459344, 0.206993, 0.011089},{1.458365, 0.205646, 0.010068}}],
    Polygon[{{1.458094, 0.208243, 0.011089},{1.459554, 0.209304, 0.011836},{
      1.460405, 0.208453, 0.011836},{1.459344, 0.206993, 0.011089}}],
    Polygon[{{1.459554, 0.209304, 0.011836},{1.461090, 0.210420, 0.012292},{
      1.461521, 0.209989, 0.012292},{1.460405, 0.208453, 0.011836}}],
    Polygon[{{1.461521, 0.209989, -0.012292},{1.460405, 0.208453, -0.011836},{
      1.461477, 0.207907, -0.011836},{1.462064, 0.209713, -0.012292}}],
    Polygon[{{1.460405, 0.208453, -0.011836},{1.459344, 0.206993, -0.011089},{
      1.460919, 0.206191, -0.011089},{1.461477, 0.207907, -0.011836}}],
    Polygon[{{1.459344, 0.206993, -0.011089},{1.458365, 0.205646, -0.010068},{
      1.460405, 0.204607, -0.010068},{1.460919, 0.206191, -0.011089}}],
    Polygon[{{1.458365, 0.205646, -0.010068},{1.457493, 0.204445, -0.008800},{
      1.459946, 0.203195, -0.008800},{1.460405, 0.204607, -0.010068}}],
    Polygon[{{1.457493, 0.204445, -0.008800},{1.456747, 0.203419, -0.007315},{
      1.459554, 0.201989, -0.007315},{1.459946, 0.203195, -0.008800}}],
    Polygon[{{1.456747, 0.203419, -0.007315},{1.456147, 0.202593, -0.005650},{
      1.459239, 0.201018, -0.005650},{1.459554, 0.201989, -0.007315}}],
    Polygon[{{1.456147, 0.202593, -0.005650},{1.455708, 0.201989, -0.003846},{
      1.459008, 0.200308, -0.003846},{1.459239, 0.201018, -0.005650}}],
    Polygon[{{1.455708, 0.201989, -0.003846},{1.455440, 0.201620, -0.001947},{
      1.458867, 0.199874, -0.001947},{1.459008, 0.200308, -0.003846}}],
    Polygon[{{1.455440, 0.201620, -0.001947},{1.455350, 0.201496, 0.000000},{
      1.458819, 0.199728, 0.000000},{1.458867, 0.199874, -0.001947}}],
    Polygon[{{1.455350, 0.201496, 0.000000},{1.455440, 0.201620, 0.001947},{
      1.458867, 0.199874, 0.001947},{1.458819, 0.199728, 0.000000}}],
    Polygon[{{1.455440, 0.201620, 0.001947},{1.455708, 0.201989, 0.003846},{
      1.459008, 0.200308, 0.003846},{1.458867, 0.199874, 0.001947}}],
    Polygon[{{1.455708, 0.201989, 0.003846},{1.456147, 0.202593, 0.005650},{
      1.459239, 0.201018, 0.005650},{1.459008, 0.200308, 0.003846}}],
    Polygon[{{1.456147, 0.202593, 0.005650},{1.456747, 0.203419, 0.007315},{
      1.459554, 0.201989, 0.007315},{1.459239, 0.201018, 0.005650}}],
    Polygon[{{1.456747, 0.203419, 0.007315},{1.457493, 0.204445, 0.008800},{
      1.459946, 0.203195, 0.008800},{1.459554, 0.201989, 0.007315}}],
    Polygon[{{1.457493, 0.204445, 0.008800},{1.458365, 0.205646, 0.010068},{
      1.460405, 0.204607, 0.010068},{1.459946, 0.203195, 0.008800}}],
    Polygon[{{1.458365, 0.205646, 0.010068},{1.459344, 0.206993, 0.011089},{
      1.460919, 0.206191, 0.011089},{1.460405, 0.204607, 0.010068}}],
    Polygon[{{1.459344, 0.206993, 0.011089},{1.460405, 0.208453, 0.011836},{
      1.461477, 0.207907, 0.011836},{1.460919, 0.206191, 0.011089}}],
    Polygon[{{1.460405, 0.208453, 0.011836},{1.461521, 0.209989, 0.012292},{
      1.462064, 0.209713, 0.012292},{1.461477, 0.207907, 0.011836}}],
    Polygon[{{1.462064, 0.209713, -0.012292},{1.461477, 0.207907, -0.011836},{
      1.462665, 0.207719, -0.011836},{1.462665, 0.209617, -0.012292}}],
    Polygon[{{1.461477, 0.207907, -0.011836},{1.460919, 0.206191, -0.011089},{
      1.462665, 0.205914, -0.011089},{1.462665, 0.207719, -0.011836}}],
    Polygon[{{1.460919, 0.206191, -0.011089},{1.460405, 0.204607, -0.010068},{
      1.462665, 0.204249, -0.010068},{1.462665, 0.205914, -0.011089}}],
    Polygon[{{1.460405, 0.204607, -0.010068},{1.459946, 0.203195, -0.008800},{
      1.462665, 0.202764, -0.008800},{1.462665, 0.204249, -0.010068}}],
    Polygon[{{1.459946, 0.203195, -0.008800},{1.459554, 0.201989, -0.007315},{
      1.462665, 0.201496, -0.007315},{1.462665, 0.202764, -0.008800}}],
    Polygon[{{1.459554, 0.201989, -0.007315},{1.459239, 0.201018, -0.005650},{
      1.462665, 0.200476, -0.005650},{1.462665, 0.201496, -0.007315}}],
    Polygon[{{1.459239, 0.201018, -0.005650},{1.459008, 0.200308, -0.003846},{
      1.462665, 0.199728, -0.003846},{1.462665, 0.200476, -0.005650}}],
    Polygon[{{1.459008, 0.200308, -0.003846},{1.458867, 0.199874, -0.001947},{
      1.462665, 0.199273, -0.001947},{1.462665, 0.199728, -0.003846}}],
    Polygon[{{1.458867, 0.199874, -0.001947},{1.458819, 0.199728, 0.000000},{
      1.462665, 0.199119, 0.000000},{1.462665, 0.199273, -0.001947}}],
    Polygon[{{1.458819, 0.199728, 0.000000},{1.458867, 0.199874, 0.001947},{
      1.462665, 0.199273, 0.001947},{1.462665, 0.199119, 0.000000}}],
    Polygon[{{1.458867, 0.199874, 0.001947},{1.459008, 0.200308, 0.003846},{
      1.462665, 0.199728, 0.003846},{1.462665, 0.199273, 0.001947}}],
    Polygon[{{1.459008, 0.200308, 0.003846},{1.459239, 0.201018, 0.005650},{
      1.462665, 0.200476, 0.005650},{1.462665, 0.199728, 0.003846}}],
    Polygon[{{1.459239, 0.201018, 0.005650},{1.459554, 0.201989, 0.007315},{
      1.462665, 0.201496, 0.007315},{1.462665, 0.200476, 0.005650}}],
    Polygon[{{1.459554, 0.201989, 0.007315},{1.459946, 0.203195, 0.008800},{
      1.462665, 0.202764, 0.008800},{1.462665, 0.201496, 0.007315}}],
    Polygon[{{1.459946, 0.203195, 0.008800},{1.460405, 0.204607, 0.010068},{
      1.462665, 0.204249, 0.010068},{1.462665, 0.202764, 0.008800}}],
    Polygon[{{1.460405, 0.204607, 0.010068},{1.460919, 0.206191, 0.011089},{
      1.462665, 0.205914, 0.011089},{1.462665, 0.204249, 0.010068}}],
    Polygon[{{1.460919, 0.206191, 0.011089},{1.461477, 0.207907, 0.011836},{
      1.462665, 0.207719, 0.011836},{1.462665, 0.205914, 0.011089}}],
    Polygon[{{1.461477, 0.207907, 0.011836},{1.462064, 0.209713, 0.012292},{
      1.462665, 0.209617, 0.012292},{1.462665, 0.207719, 0.011836}}],
    Polygon[{{1.462665, 0.209617, -0.012292},{1.462665, 0.207719, -0.011836},{
      1.463853, 0.207907, -0.011836},{1.463267, 0.209713, -0.012292}}],
    Polygon[{{1.462665, 0.207719, -0.011836},{1.462665, 0.205914, -0.011089},{
      1.464411, 0.206191, -0.011089},{1.463853, 0.207907, -0.011836}}],
    Polygon[{{1.462665, 0.205914, -0.011089},{1.462665, 0.204249, -0.010068},{
      1.464926, 0.204607, -0.010068},{1.464411, 0.206191, -0.011089}}],
    Polygon[{{1.462665, 0.204249, -0.010068},{1.462665, 0.202764, -0.008800},{
      1.465384, 0.203195, -0.008800},{1.464926, 0.204607, -0.010068}}],
    Polygon[{{1.462665, 0.202764, -0.008800},{1.462665, 0.201496, -0.007315},{
      1.465776, 0.201989, -0.007315},{1.465384, 0.203195, -0.008800}}],
    Polygon[{{1.462665, 0.201496, -0.007315},{1.462665, 0.200476, -0.005650},{
      1.466092, 0.201018, -0.005650},{1.465776, 0.201989, -0.007315}}],
    Polygon[{{1.462665, 0.200476, -0.005650},{1.462665, 0.199728, -0.003846},{
      1.466323, 0.200308, -0.003846},{1.466092, 0.201018, -0.005650}}],
    Polygon[{{1.462665, 0.199728, -0.003846},{1.462665, 0.199273, -0.001947},{
      1.466463, 0.199874, -0.001947},{1.466323, 0.200308, -0.003846}}],
    Polygon[{{1.462665, 0.199273, -0.001947},{1.462665, 0.199119, 0.000000},{
      1.466511, 0.199728, 0.000000},{1.466463, 0.199874, -0.001947}}],
    Polygon[{{1.462665, 0.199119, 0.000000},{1.462665, 0.199273, 0.001947},{
      1.466463, 0.199874, 0.001947},{1.466511, 0.199728, 0.000000}}],
    Polygon[{{1.462665, 0.199273, 0.001947},{1.462665, 0.199728, 0.003846},{
      1.466323, 0.200308, 0.003846},{1.466463, 0.199874, 0.001947}}],
    Polygon[{{1.462665, 0.199728, 0.003846},{1.462665, 0.200476, 0.005650},{
      1.466092, 0.201018, 0.005650},{1.466323, 0.200308, 0.003846}}],
    Polygon[{{1.462665, 0.200476, 0.005650},{1.462665, 0.201496, 0.007315},{
      1.465776, 0.201989, 0.007315},{1.466092, 0.201018, 0.005650}}],
    Polygon[{{1.462665, 0.201496, 0.007315},{1.462665, 0.202764, 0.008800},{
      1.465384, 0.203195, 0.008800},{1.465776, 0.201989, 0.007315}}],
    Polygon[{{1.462665, 0.202764, 0.008800},{1.462665, 0.204249, 0.010068},{
      1.464926, 0.204607, 0.010068},{1.465384, 0.203195, 0.008800}}],
    Polygon[{{1.462665, 0.204249, 0.010068},{1.462665, 0.205914, 0.011089},{
      1.464411, 0.206191, 0.011089},{1.464926, 0.204607, 0.010068}}],
    Polygon[{{1.462665, 0.205914, 0.011089},{1.462665, 0.207719, 0.011836},{
      1.463853, 0.207907, 0.011836},{1.464411, 0.206191, 0.011089}}],
    Polygon[{{1.462665, 0.207719, 0.011836},{1.462665, 0.209617, 0.012292},{
      1.463267, 0.209713, 0.012292},{1.463853, 0.207907, 0.011836}}],
    Polygon[{{1.463267, 0.209713, -0.012292},{1.463853, 0.207907, -0.011836},{
      1.464926, 0.208453, -0.011836},{1.463809, 0.209989, -0.012292}}],
    Polygon[{{1.463853, 0.207907, -0.011836},{1.464411, 0.206191, -0.011089},{
      1.465986, 0.206993, -0.011089},{1.464926, 0.208453, -0.011836}}],
    Polygon[{{1.464411, 0.206191, -0.011089},{1.464926, 0.204607, -0.010068},{
      1.466965, 0.205646, -0.010068},{1.465986, 0.206993, -0.011089}}],
    Polygon[{{1.464926, 0.204607, -0.010068},{1.465384, 0.203195, -0.008800},{
      1.467838, 0.204445, -0.008800},{1.466965, 0.205646, -0.010068}}],
    Polygon[{{1.465384, 0.203195, -0.008800},{1.465776, 0.201989, -0.007315},{
      1.468583, 0.203419, -0.007315},{1.467838, 0.204445, -0.008800}}],
    Polygon[{{1.465776, 0.201989, -0.007315},{1.466092, 0.201018, -0.005650},{
      1.469183, 0.202593, -0.005650},{1.468583, 0.203419, -0.007315}}],
    Polygon[{{1.466092, 0.201018, -0.005650},{1.466323, 0.200308, -0.003846},{
      1.469622, 0.201989, -0.003846},{1.469183, 0.202593, -0.005650}}],
    Polygon[{{1.466323, 0.200308, -0.003846},{1.466463, 0.199874, -0.001947},{
      1.469890, 0.201620, -0.001947},{1.469622, 0.201989, -0.003846}}],
    Polygon[{{1.466463, 0.199874, -0.001947},{1.466511, 0.199728, 0.000000},{
      1.469980, 0.201496, 0.000000},{1.469890, 0.201620, -0.001947}}],
    Polygon[{{1.466511, 0.199728, 0.000000},{1.466463, 0.199874, 0.001947},{
      1.469890, 0.201620, 0.001947},{1.469980, 0.201496, 0.000000}}],
    Polygon[{{1.466463, 0.199874, 0.001947},{1.466323, 0.200308, 0.003846},{
      1.469622, 0.201989, 0.003846},{1.469890, 0.201620, 0.001947}}],
    Polygon[{{1.466323, 0.200308, 0.003846},{1.466092, 0.201018, 0.005650},{
      1.469183, 0.202593, 0.005650},{1.469622, 0.201989, 0.003846}}],
    Polygon[{{1.466092, 0.201018, 0.005650},{1.465776, 0.201989, 0.007315},{
      1.468583, 0.203419, 0.007315},{1.469183, 0.202593, 0.005650}}],
    Polygon[{{1.465776, 0.201989, 0.007315},{1.465384, 0.203195, 0.008800},{
      1.467838, 0.204445, 0.008800},{1.468583, 0.203419, 0.007315}}],
    Polygon[{{1.465384, 0.203195, 0.008800},{1.464926, 0.204607, 0.010068},{
      1.466965, 0.205646, 0.010068},{1.467838, 0.204445, 0.008800}}],
    Polygon[{{1.464926, 0.204607, 0.010068},{1.464411, 0.206191, 0.011089},{
      1.465986, 0.206993, 0.011089},{1.466965, 0.205646, 0.010068}}],
    Polygon[{{1.464411, 0.206191, 0.011089},{1.463853, 0.207907, 0.011836},{
      1.464926, 0.208453, 0.011836},{1.465986, 0.206993, 0.011089}}],
    Polygon[{{1.463853, 0.207907, 0.011836},{1.463267, 0.209713, 0.012292},{
      1.463809, 0.209989, 0.012292},{1.464926, 0.208453, 0.011836}}],
    Polygon[{{1.463809, 0.209989, -0.012292},{1.464926, 0.208453, -0.011836},{
      1.465776, 0.209304, -0.011836},{1.464240, 0.210420, -0.012292}}],
    Polygon[{{1.464926, 0.208453, -0.011836},{1.465986, 0.206993, -0.011089},{
      1.467236, 0.208243, -0.011089},{1.465776, 0.209304, -0.011836}}],
    Polygon[{{1.465986, 0.206993, -0.011089},{1.466965, 0.205646, -0.010068},{
      1.468583, 0.207265, -0.010068},{1.467236, 0.208243, -0.011089}}],
    Polygon[{{1.466965, 0.205646, -0.010068},{1.467838, 0.204445, -0.008800},{
      1.469784, 0.206392, -0.008800},{1.468583, 0.207265, -0.010068}}],
    Polygon[{{1.467838, 0.204445, -0.008800},{1.468583, 0.203419, -0.007315},{
      1.470810, 0.205646, -0.007315},{1.469784, 0.206392, -0.008800}}],
    Polygon[{{1.468583, 0.203419, -0.007315},{1.469183, 0.202593, -0.005650},{
      1.471636, 0.205047, -0.005650},{1.470810, 0.205646, -0.007315}}],
    Polygon[{{1.469183, 0.202593, -0.005650},{1.469622, 0.201989, -0.003846},{
      1.472241, 0.204607, -0.003846},{1.471636, 0.205047, -0.005650}}],
    Polygon[{{1.469622, 0.201989, -0.003846},{1.469890, 0.201620, -0.001947},{
      1.472609, 0.204339, -0.001947},{1.472241, 0.204607, -0.003846}}],
    Polygon[{{1.469890, 0.201620, -0.001947},{1.469980, 0.201496, 0.000000},{
      1.472733, 0.204249, 0.000000},{1.472609, 0.204339, -0.001947}}],
    Polygon[{{1.469980, 0.201496, 0.000000},{1.469890, 0.201620, 0.001947},{
      1.472609, 0.204339, 0.001947},{1.472733, 0.204249, 0.000000}}],
    Polygon[{{1.469890, 0.201620, 0.001947},{1.469622, 0.201989, 0.003846},{
      1.472241, 0.204607, 0.003846},{1.472609, 0.204339, 0.001947}}],
    Polygon[{{1.469622, 0.201989, 0.003846},{1.469183, 0.202593, 0.005650},{
      1.471636, 0.205047, 0.005650},{1.472241, 0.204607, 0.003846}}],
    Polygon[{{1.469183, 0.202593, 0.005650},{1.468583, 0.203419, 0.007315},{
      1.470810, 0.205646, 0.007315},{1.471636, 0.205047, 0.005650}}],
    Polygon[{{1.468583, 0.203419, 0.007315},{1.467838, 0.204445, 0.008800},{
      1.469784, 0.206392, 0.008800},{1.470810, 0.205646, 0.007315}}],
    Polygon[{{1.467838, 0.204445, 0.008800},{1.466965, 0.205646, 0.010068},{
      1.468583, 0.207265, 0.010068},{1.469784, 0.206392, 0.008800}}],
    Polygon[{{1.466965, 0.205646, 0.010068},{1.465986, 0.206993, 0.011089},{
      1.467236, 0.208243, 0.011089},{1.468583, 0.207265, 0.010068}}],
    Polygon[{{1.465986, 0.206993, 0.011089},{1.464926, 0.208453, 0.011836},{
      1.465776, 0.209304, 0.011836},{1.467236, 0.208243, 0.011089}}],
    Polygon[{{1.464926, 0.208453, 0.011836},{1.463809, 0.209989, 0.012292},{
      1.464240, 0.210420, 0.012292},{1.465776, 0.209304, 0.011836}}],
    Polygon[{{1.464240, 0.210420, -0.012292},{1.465776, 0.209304, -0.011836},{
      1.466323, 0.210376, -0.011836},{1.464517, 0.210963, -0.012292}}],
    Polygon[{{1.465776, 0.209304, -0.011836},{1.467236, 0.208243, -0.011089},{
      1.468038, 0.209818, -0.011089},{1.466323, 0.210376, -0.011836}}],
    Polygon[{{1.467236, 0.208243, -0.011089},{1.468583, 0.207265, -0.010068},{
      1.469622, 0.209304, -0.010068},{1.468038, 0.209818, -0.011089}}],
    Polygon[{{1.468583, 0.207265, -0.010068},{1.469784, 0.206392, -0.008800},{
      1.471034, 0.208845, -0.008800},{1.469622, 0.209304, -0.010068}}],
    Polygon[{{1.469784, 0.206392, -0.008800},{1.470810, 0.205646, -0.007315},{
      1.472241, 0.208453, -0.007315},{1.471034, 0.208845, -0.008800}}],
    Polygon[{{1.470810, 0.205646, -0.007315},{1.471636, 0.205047, -0.005650},{
      1.473211, 0.208138, -0.005650},{1.472241, 0.208453, -0.007315}}],
    Polygon[{{1.471636, 0.205047, -0.005650},{1.472241, 0.204607, -0.003846},{
      1.473922, 0.207907, -0.003846},{1.473211, 0.208138, -0.005650}}],
    Polygon[{{1.472241, 0.204607, -0.003846},{1.472609, 0.204339, -0.001947},{
      1.474355, 0.207766, -0.001947},{1.473922, 0.207907, -0.003846}}],
    Polygon[{{1.472609, 0.204339, -0.001947},{1.472733, 0.204249, 0.000000},{
      1.474501, 0.207719, 0.000000},{1.474355, 0.207766, -0.001947}}],
    Polygon[{{1.472733, 0.204249, 0.000000},{1.472609, 0.204339, 0.001947},{
      1.474355, 0.207766, 0.001947},{1.474501, 0.207719, 0.000000}}],
    Polygon[{{1.472609, 0.204339, 0.001947},{1.472241, 0.204607, 0.003846},{
      1.473922, 0.207907, 0.003846},{1.474355, 0.207766, 0.001947}}],
    Polygon[{{1.472241, 0.204607, 0.003846},{1.471636, 0.205047, 0.005650},{
      1.473211, 0.208138, 0.005650},{1.473922, 0.207907, 0.003846}}],
    Polygon[{{1.471636, 0.205047, 0.005650},{1.470810, 0.205646, 0.007315},{
      1.472241, 0.208453, 0.007315},{1.473211, 0.208138, 0.005650}}],
    Polygon[{{1.470810, 0.205646, 0.007315},{1.469784, 0.206392, 0.008800},{
      1.471034, 0.208845, 0.008800},{1.472241, 0.208453, 0.007315}}],
    Polygon[{{1.469784, 0.206392, 0.008800},{1.468583, 0.207265, 0.010068},{
      1.469622, 0.209304, 0.010068},{1.471034, 0.208845, 0.008800}}],
    Polygon[{{1.468583, 0.207265, 0.010068},{1.467236, 0.208243, 0.011089},{
      1.468038, 0.209818, 0.011089},{1.469622, 0.209304, 0.010068}}],
    Polygon[{{1.467236, 0.208243, 0.011089},{1.465776, 0.209304, 0.011836},{
      1.466323, 0.210376, 0.011836},{1.468038, 0.209818, 0.011089}}],
    Polygon[{{1.465776, 0.209304, 0.011836},{1.464240, 0.210420, 0.012292},{
      1.464517, 0.210963, 0.012292},{1.466323, 0.210376, 0.011836}}],
    Polygon[{{1.464517, 0.210963, -0.012292},{1.466323, 0.210376, -0.011836},{
      1.466511, 0.211564, -0.011836},{1.464612, 0.211564, -0.012292}}],
    Polygon[{{1.466323, 0.210376, -0.011836},{1.468038, 0.209818, -0.011089},{
      1.468315, 0.211564, -0.011089},{1.466511, 0.211564, -0.011836}}],
    Polygon[{{1.468038, 0.209818, -0.011089},{1.469622, 0.209304, -0.010068},{
      1.469980, 0.211564, -0.010068},{1.468315, 0.211564, -0.011089}}],
    Polygon[{{1.469622, 0.209304, -0.010068},{1.471034, 0.208845, -0.008800},{
      1.471465, 0.211564, -0.008800},{1.469980, 0.211564, -0.010068}}],
    Polygon[{{1.471034, 0.208845, -0.008800},{1.472241, 0.208453, -0.007315},{
      1.472733, 0.211564, -0.007315},{1.471465, 0.211564, -0.008800}}],
    Polygon[{{1.472241, 0.208453, -0.007315},{1.473211, 0.208138, -0.005650},{
      1.473754, 0.211564, -0.005650},{1.472733, 0.211564, -0.007315}}],
    Polygon[{{1.473211, 0.208138, -0.005650},{1.473922, 0.207907, -0.003846},{
      1.474501, 0.211564, -0.003846},{1.473754, 0.211564, -0.005650}}],
    Polygon[{{1.473922, 0.207907, -0.003846},{1.474355, 0.207766, -0.001947},{
      1.474957, 0.211564, -0.001947},{1.474501, 0.211564, -0.003846}}],
    Polygon[{{1.474355, 0.207766, -0.001947},{1.474501, 0.207719, 0.000000},{
      1.475110, 0.211564, 0.000000},{1.474957, 0.211564, -0.001947}}],
    Polygon[{{1.474501, 0.207719, 0.000000},{1.474355, 0.207766, 0.001947},{
      1.474957, 0.211564, 0.001947},{1.475110, 0.211564, 0.000000}}],
    Polygon[{{1.474355, 0.207766, 0.001947},{1.473922, 0.207907, 0.003846},{
      1.474501, 0.211564, 0.003846},{1.474957, 0.211564, 0.001947}}],
    Polygon[{{1.473922, 0.207907, 0.003846},{1.473211, 0.208138, 0.005650},{
      1.473754, 0.211564, 0.005650},{1.474501, 0.211564, 0.003846}}],
    Polygon[{{1.473211, 0.208138, 0.005650},{1.472241, 0.208453, 0.007315},{
      1.472733, 0.211564, 0.007315},{1.473754, 0.211564, 0.005650}}],
    Polygon[{{1.472241, 0.208453, 0.007315},{1.471034, 0.208845, 0.008800},{
      1.471465, 0.211564, 0.008800},{1.472733, 0.211564, 0.007315}}],
    Polygon[{{1.471034, 0.208845, 0.008800},{1.469622, 0.209304, 0.010068},{
      1.469980, 0.211564, 0.010068},{1.471465, 0.211564, 0.008800}}],
    Polygon[{{1.469622, 0.209304, 0.010068},{1.468038, 0.209818, 0.011089},{
      1.468315, 0.211564, 0.011089},{1.469980, 0.211564, 0.010068}}],
    Polygon[{{1.468038, 0.209818, 0.011089},{1.466323, 0.210376, 0.011836},{
      1.466511, 0.211564, 0.011836},{1.468315, 0.211564, 0.011089}}],
    Polygon[{{1.466323, 0.210376, 0.011836},{1.464517, 0.210963, 0.012292},{
      1.464612, 0.211564, 0.012292},{1.466511, 0.211564, 0.011836}}],
    Polygon[{{1.418478, 0.164172, -0.009538},{1.419951, 0.164172, -0.009185},{
      1.419805, 0.165094, -0.009185},{1.418404, 0.164639, -0.009538}}],
    Polygon[{{1.419951, 0.164172, -0.009185},{1.421351, 0.164172, -0.008605},{
      1.421137, 0.165527, -0.008605},{1.419805, 0.165094, -0.009185}}],
    Polygon[{{1.421351, 0.164172, -0.008605},{1.422643, 0.164172, -0.007813},{
      1.422365, 0.165926, -0.007813},{1.421137, 0.165527, -0.008605}}],
    Polygon[{{1.422643, 0.164172, -0.007813},{1.423796, 0.164172, -0.006829},{
      1.423461, 0.166282, -0.006829},{1.422365, 0.165926, -0.007813}}],
    Polygon[{{1.423796, 0.164172, -0.006829},{1.424780, 0.164172, -0.005676},{
      1.424397, 0.166586, -0.005676},{1.423461, 0.166282, -0.006829}}],
    Polygon[{{1.424780, 0.164172, -0.005676},{1.425571, 0.164172, -0.004384},{
      1.425150, 0.166831, -0.004384},{1.424397, 0.166586, -0.005676}}],
    Polygon[{{1.425571, 0.164172, -0.004384},{1.426151, 0.164172, -0.002984},{
      1.425702, 0.167010, -0.002984},{1.425150, 0.166831, -0.004384}}],
    Polygon[{{1.426151, 0.164172, -0.002984},{1.426505, 0.164172, -0.001511},{
      1.426038, 0.167119, -0.001511},{1.425702, 0.167010, -0.002984}}],
    Polygon[{{1.426505, 0.164172, -0.001511},{1.426624, 0.164172, 0.000000},{
      1.426151, 0.167156, 0.000000},{1.426038, 0.167119, -0.001511}}],
    Polygon[{{1.426624, 0.164172, 0.000000},{1.426505, 0.164172, 0.001511},{
      1.426038, 0.167119, 0.001511},{1.426151, 0.167156, 0.000000}}],
    Polygon[{{1.426505, 0.164172, 0.001511},{1.426151, 0.164172, 0.002984},{
      1.425702, 0.167010, 0.002984},{1.426038, 0.167119, 0.001511}}],
    Polygon[{{1.426151, 0.164172, 0.002984},{1.425571, 0.164172, 0.004384},{
      1.425150, 0.166831, 0.004384},{1.425702, 0.167010, 0.002984}}],
    Polygon[{{1.425571, 0.164172, 0.004384},{1.424780, 0.164172, 0.005676},{
      1.424397, 0.166586, 0.005676},{1.425150, 0.166831, 0.004384}}],
    Polygon[{{1.424780, 0.164172, 0.005676},{1.423796, 0.164172, 0.006829},{
      1.423461, 0.166282, 0.006829},{1.424397, 0.166586, 0.005676}}],
    Polygon[{{1.423796, 0.164172, 0.006829},{1.422643, 0.164172, 0.007813},{
      1.422365, 0.165926, 0.007813},{1.423461, 0.166282, 0.006829}}],
    Polygon[{{1.422643, 0.164172, 0.007813},{1.421351, 0.164172, 0.008605},{
      1.421137, 0.165527, 0.008605},{1.422365, 0.165926, 0.007813}}],
    Polygon[{{1.421351, 0.164172, 0.008605},{1.419951, 0.164172, 0.009185},{
      1.419805, 0.165094, 0.009185},{1.421137, 0.165527, 0.008605}}],
    Polygon[{{1.419951, 0.164172, 0.009185},{1.418478, 0.164172, 0.009538},{
      1.418404, 0.164639, 0.009538},{1.419805, 0.165094, 0.009185}}],
    Polygon[{{1.418404, 0.164639, -0.009538},{1.419805, 0.165094, -0.009185},{
      1.419381, 0.165926, -0.009185},{1.418189, 0.165060, -0.009538}}],
    Polygon[{{1.419805, 0.165094, -0.009185},{1.421137, 0.165527, -0.008605},{
      1.420514, 0.166749, -0.008605},{1.419381, 0.165926, -0.009185}}],
    Polygon[{{1.421137, 0.165527, -0.008605},{1.422365, 0.165926, -0.007813},{
      1.421559, 0.167508, -0.007813},{1.420514, 0.166749, -0.008605}}],
    Polygon[{{1.422365, 0.165926, -0.007813},{1.423461, 0.166282, -0.006829},{
      1.422491, 0.168186, -0.006829},{1.421559, 0.167508, -0.007813}}],
    Polygon[{{1.423461, 0.166282, -0.006829},{1.424397, 0.166586, -0.005676},{
      1.423288, 0.168764, -0.005676},{1.422491, 0.168186, -0.006829}}],
    Polygon[{{1.424397, 0.166586, -0.005676},{1.425150, 0.166831, -0.004384},{
      1.423928, 0.169230, -0.004384},{1.423288, 0.168764, -0.005676}}],
    Polygon[{{1.425150, 0.166831, -0.004384},{1.425702, 0.167010, -0.002984},{
      1.424397, 0.169570, -0.002984},{1.423928, 0.169230, -0.004384}}],
    Polygon[{{1.425702, 0.167010, -0.002984},{1.426038, 0.167119, -0.001511},{
      1.424684, 0.169778, -0.001511},{1.424397, 0.169570, -0.002984}}],
    Polygon[{{1.426038, 0.167119, -0.001511},{1.426151, 0.167156, 0.000000},{
      1.424780, 0.169848, 0.000000},{1.424684, 0.169778, -0.001511}}],
    Polygon[{{1.426151, 0.167156, 0.000000},{1.426038, 0.167119, 0.001511},{
      1.424684, 0.169778, 0.001511},{1.424780, 0.169848, 0.000000}}],
    Polygon[{{1.426038, 0.167119, 0.001511},{1.425702, 0.167010, 0.002984},{
      1.424397, 0.169570, 0.002984},{1.424684, 0.169778, 0.001511}}],
    Polygon[{{1.425702, 0.167010, 0.002984},{1.425150, 0.166831, 0.004384},{
      1.423928, 0.169230, 0.004384},{1.424397, 0.169570, 0.002984}}],
    Polygon[{{1.425150, 0.166831, 0.004384},{1.424397, 0.166586, 0.005676},{
      1.423288, 0.168764, 0.005676},{1.423928, 0.169230, 0.004384}}],
    Polygon[{{1.424397, 0.166586, 0.005676},{1.423461, 0.166282, 0.006829},{
      1.422491, 0.168186, 0.006829},{1.423288, 0.168764, 0.005676}}],
    Polygon[{{1.423461, 0.166282, 0.006829},{1.422365, 0.165926, 0.007813},{
      1.421559, 0.167508, 0.007813},{1.422491, 0.168186, 0.006829}}],
    Polygon[{{1.422365, 0.165926, 0.007813},{1.421137, 0.165527, 0.008605},{
      1.420514, 0.166749, 0.008605},{1.421559, 0.167508, 0.007813}}],
    Polygon[{{1.421137, 0.165527, 0.008605},{1.419805, 0.165094, 0.009185},{
      1.419381, 0.165926, 0.009185},{1.420514, 0.166749, 0.008605}}],
    Polygon[{{1.419805, 0.165094, 0.009185},{1.418404, 0.164639, 0.009538},{
      1.418189, 0.165060, 0.009538},{1.419381, 0.165926, 0.009185}}],
    Polygon[{{1.418189, 0.165060, -0.009538},{1.419381, 0.165926, -0.009185},{
      1.418721, 0.166586, -0.009185},{1.417855, 0.165394, -0.009538}}],
    Polygon[{{1.419381, 0.165926, -0.009185},{1.420514, 0.166749, -0.008605},{
      1.419544, 0.167719, -0.008605},{1.418721, 0.166586, -0.009185}}],
    Polygon[{{1.420514, 0.166749, -0.008605},{1.421559, 0.167508, -0.007813},{
      1.420303, 0.168764, -0.007813},{1.419544, 0.167719, -0.008605}}],
    Polygon[{{1.421559, 0.167508, -0.007813},{1.422491, 0.168186, -0.006829},{
      1.420981, 0.169696, -0.006829},{1.420303, 0.168764, -0.007813}}],
    Polygon[{{1.422491, 0.168186, -0.006829},{1.423288, 0.168764, -0.005676},{
      1.421559, 0.170493, -0.005676},{1.420981, 0.169696, -0.006829}}],
    Polygon[{{1.423288, 0.168764, -0.005676},{1.423928, 0.169230, -0.004384},{
      1.422025, 0.171133, -0.004384},{1.421559, 0.170493, -0.005676}}],
    Polygon[{{1.423928, 0.169230, -0.004384},{1.424397, 0.169570, -0.002984},{
      1.422365, 0.171602, -0.002984},{1.422025, 0.171133, -0.004384}}],
    Polygon[{{1.424397, 0.169570, -0.002984},{1.424684, 0.169778, -0.001511},{
      1.422573, 0.171889, -0.001511},{1.422365, 0.171602, -0.002984}}],
    Polygon[{{1.424684, 0.169778, -0.001511},{1.424780, 0.169848, 0.000000},{
      1.422643, 0.171985, 0.000000},{1.422573, 0.171889, -0.001511}}],
    Polygon[{{1.424780, 0.169848, 0.000000},{1.424684, 0.169778, 0.001511},{
      1.422573, 0.171889, 0.001511},{1.422643, 0.171985, 0.000000}}],
    Polygon[{{1.424684, 0.169778, 0.001511},{1.424397, 0.169570, 0.002984},{
      1.422365, 0.171602, 0.002984},{1.422573, 0.171889, 0.001511}}],
    Polygon[{{1.424397, 0.169570, 0.002984},{1.423928, 0.169230, 0.004384},{
      1.422025, 0.171133, 0.004384},{1.422365, 0.171602, 0.002984}}],
    Polygon[{{1.423928, 0.169230, 0.004384},{1.423288, 0.168764, 0.005676},{
      1.421559, 0.170493, 0.005676},{1.422025, 0.171133, 0.004384}}],
    Polygon[{{1.423288, 0.168764, 0.005676},{1.422491, 0.168186, 0.006829},{
      1.420981, 0.169696, 0.006829},{1.421559, 0.170493, 0.005676}}],
    Polygon[{{1.422491, 0.168186, 0.006829},{1.421559, 0.167508, 0.007813},{
      1.420303, 0.168764, 0.007813},{1.420981, 0.169696, 0.006829}}],
    Polygon[{{1.421559, 0.167508, 0.007813},{1.420514, 0.166749, 0.008605},{
      1.419544, 0.167719, 0.008605},{1.420303, 0.168764, 0.007813}}],
    Polygon[{{1.420514, 0.166749, 0.008605},{1.419381, 0.165926, 0.009185},{
      1.418721, 0.166586, 0.009185},{1.419544, 0.167719, 0.008605}}],
    Polygon[{{1.419381, 0.165926, 0.009185},{1.418189, 0.165060, 0.009538},{
      1.417855, 0.165394, 0.009538},{1.418721, 0.166586, 0.009185}}],
    Polygon[{{1.417855, 0.165394, -0.009538},{1.418721, 0.166586, -0.009185},{
      1.417889, 0.167010, -0.009185},{1.417434, 0.165609, -0.009538}}],
    Polygon[{{1.418721, 0.166586, -0.009185},{1.419544, 0.167719, -0.008605},{
      1.418322, 0.168342, -0.008605},{1.417889, 0.167010, -0.009185}}],
    Polygon[{{1.419544, 0.167719, -0.008605},{1.420303, 0.168764, -0.007813},{
      1.418721, 0.169570, -0.007813},{1.418322, 0.168342, -0.008605}}],
    Polygon[{{1.420303, 0.168764, -0.007813},{1.420981, 0.169696, -0.006829},{
      1.419077, 0.170666, -0.006829},{1.418721, 0.169570, -0.007813}}],
    Polygon[{{1.420981, 0.169696, -0.006829},{1.421559, 0.170493, -0.005676},{
      1.419381, 0.171602, -0.005676},{1.419077, 0.170666, -0.006829}}],
    Polygon[{{1.421559, 0.170493, -0.005676},{1.422025, 0.171133, -0.004384},{
      1.419626, 0.172355, -0.004384},{1.419381, 0.171602, -0.005676}}],
    Polygon[{{1.422025, 0.171133, -0.004384},{1.422365, 0.171602, -0.002984},{
      1.419805, 0.172907, -0.002984},{1.419626, 0.172355, -0.004384}}],
    Polygon[{{1.422365, 0.171602, -0.002984},{1.422573, 0.171889, -0.001511},{
      1.419914, 0.173243, -0.001511},{1.419805, 0.172907, -0.002984}}],
    Polygon[{{1.422573, 0.171889, -0.001511},{1.422643, 0.171985, 0.000000},{
      1.419951, 0.173356, 0.000000},{1.419914, 0.173243, -0.001511}}],
    Polygon[{{1.422643, 0.171985, 0.000000},{1.422573, 0.171889, 0.001511},{
      1.419914, 0.173243, 0.001511},{1.419951, 0.173356, 0.000000}}],
    Polygon[{{1.422573, 0.171889, 0.001511},{1.422365, 0.171602, 0.002984},{
      1.419805, 0.172907, 0.002984},{1.419914, 0.173243, 0.001511}}],
    Polygon[{{1.422365, 0.171602, 0.002984},{1.422025, 0.171133, 0.004384},{
      1.419626, 0.172355, 0.004384},{1.419805, 0.172907, 0.002984}}],
    Polygon[{{1.422025, 0.171133, 0.004384},{1.421559, 0.170493, 0.005676},{
      1.419381, 0.171602, 0.005676},{1.419626, 0.172355, 0.004384}}],
    Polygon[{{1.421559, 0.170493, 0.005676},{1.420981, 0.169696, 0.006829},{
      1.419077, 0.170666, 0.006829},{1.419381, 0.171602, 0.005676}}],
    Polygon[{{1.420981, 0.169696, 0.006829},{1.420303, 0.168764, 0.007813},{
      1.418721, 0.169570, 0.007813},{1.419077, 0.170666, 0.006829}}],
    Polygon[{{1.420303, 0.168764, 0.007813},{1.419544, 0.167719, 0.008605},{
      1.418322, 0.168342, 0.008605},{1.418721, 0.169570, 0.007813}}],
    Polygon[{{1.419544, 0.167719, 0.008605},{1.418721, 0.166586, 0.009185},{
      1.417889, 0.167010, 0.009185},{1.418322, 0.168342, 0.008605}}],
    Polygon[{{1.418721, 0.166586, 0.009185},{1.417855, 0.165394, 0.009538},{
      1.417434, 0.165609, 0.009538},{1.417889, 0.167010, 0.009185}}],
    Polygon[{{1.417434, 0.165609, -0.009538},{1.417889, 0.167010, -0.009185},{
      1.416967, 0.167156, -0.009185},{1.416967, 0.165683, -0.009538}}],
    Polygon[{{1.417889, 0.167010, -0.009185},{1.418322, 0.168342, -0.008605},{
      1.416967, 0.168556, -0.008605},{1.416967, 0.167156, -0.009185}}],
    Polygon[{{1.418322, 0.168342, -0.008605},{1.418721, 0.169570, -0.007813},{
      1.416967, 0.169848, -0.007813},{1.416967, 0.168556, -0.008605}}],
    Polygon[{{1.418721, 0.169570, -0.007813},{1.419077, 0.170666, -0.006829},{
      1.416967, 0.171001, -0.006829},{1.416967, 0.169848, -0.007813}}],
    Polygon[{{1.419077, 0.170666, -0.006829},{1.419381, 0.171602, -0.005676},{
      1.416967, 0.171985, -0.005676},{1.416967, 0.171001, -0.006829}}],
    Polygon[{{1.419381, 0.171602, -0.005676},{1.419626, 0.172355, -0.004384},{
      1.416967, 0.172777, -0.004384},{1.416967, 0.171985, -0.005676}}],
    Polygon[{{1.419626, 0.172355, -0.004384},{1.419805, 0.172907, -0.002984},{
      1.416967, 0.173356, -0.002984},{1.416967, 0.172777, -0.004384}}],
    Polygon[{{1.419805, 0.172907, -0.002984},{1.419914, 0.173243, -0.001511},{
      1.416967, 0.173710, -0.001511},{1.416967, 0.173356, -0.002984}}],
    Polygon[{{1.419914, 0.173243, -0.001511},{1.419951, 0.173356, 0.000000},{
      1.416967, 0.173829, 0.000000},{1.416967, 0.173710, -0.001511}}],
    Polygon[{{1.419951, 0.173356, 0.000000},{1.419914, 0.173243, 0.001511},{
      1.416967, 0.173710, 0.001511},{1.416967, 0.173829, 0.000000}}],
    Polygon[{{1.419914, 0.173243, 0.001511},{1.419805, 0.172907, 0.002984},{
      1.416967, 0.173356, 0.002984},{1.416967, 0.173710, 0.001511}}],
    Polygon[{{1.419805, 0.172907, 0.002984},{1.419626, 0.172355, 0.004384},{
      1.416967, 0.172777, 0.004384},{1.416967, 0.173356, 0.002984}}],
    Polygon[{{1.419626, 0.172355, 0.004384},{1.419381, 0.171602, 0.005676},{
      1.416967, 0.171985, 0.005676},{1.416967, 0.172777, 0.004384}}],
    Polygon[{{1.419381, 0.171602, 0.005676},{1.419077, 0.170666, 0.006829},{
      1.416967, 0.171001, 0.006829},{1.416967, 0.171985, 0.005676}}],
    Polygon[{{1.419077, 0.170666, 0.006829},{1.418721, 0.169570, 0.007813},{
      1.416967, 0.169848, 0.007813},{1.416967, 0.171001, 0.006829}}],
    Polygon[{{1.418721, 0.169570, 0.007813},{1.418322, 0.168342, 0.008605},{
      1.416967, 0.168556, 0.008605},{1.416967, 0.169848, 0.007813}}],
    Polygon[{{1.418322, 0.168342, 0.008605},{1.417889, 0.167010, 0.009185},{
      1.416967, 0.167156, 0.009185},{1.416967, 0.168556, 0.008605}}],
    Polygon[{{1.417889, 0.167010, 0.009185},{1.417434, 0.165609, 0.009538},{
      1.416967, 0.165683, 0.009538},{1.416967, 0.167156, 0.009185}}],
    Polygon[{{1.416967, 0.165683, -0.009538},{1.416967, 0.167156, -0.009185},{
      1.416045, 0.167010, -0.009185},{1.416500, 0.165609, -0.009538}}],
    Polygon[{{1.416967, 0.167156, -0.009185},{1.416967, 0.168556, -0.008605},{
      1.415612, 0.168342, -0.008605},{1.416045, 0.167010, -0.009185}}],
    Polygon[{{1.416967, 0.168556, -0.008605},{1.416967, 0.169848, -0.007813},{
      1.415213, 0.169570, -0.007813},{1.415612, 0.168342, -0.008605}}],
    Polygon[{{1.416967, 0.169848, -0.007813},{1.416967, 0.171001, -0.006829},{
      1.414857, 0.170666, -0.006829},{1.415213, 0.169570, -0.007813}}],
    Polygon[{{1.416967, 0.171001, -0.006829},{1.416967, 0.171985, -0.005676},{
      1.414553, 0.171602, -0.005676},{1.414857, 0.170666, -0.006829}}],
    Polygon[{{1.416967, 0.171985, -0.005676},{1.416967, 0.172777, -0.004384},{
      1.414308, 0.172355, -0.004384},{1.414553, 0.171602, -0.005676}}],
    Polygon[{{1.416967, 0.172777, -0.004384},{1.416967, 0.173356, -0.002984},{
      1.414129, 0.172907, -0.002984},{1.414308, 0.172355, -0.004384}}],
    Polygon[{{1.416967, 0.173356, -0.002984},{1.416967, 0.173710, -0.001511},{
      1.414019, 0.173243, -0.001511},{1.414129, 0.172907, -0.002984}}],
    Polygon[{{1.416967, 0.173710, -0.001511},{1.416967, 0.173829, 0.000000},{
      1.413983, 0.173356, 0.000000},{1.414019, 0.173243, -0.001511}}],
    Polygon[{{1.416967, 0.173829, 0.000000},{1.416967, 0.173710, 0.001511},{
      1.414019, 0.173243, 0.001511},{1.413983, 0.173356, 0.000000}}],
    Polygon[{{1.416967, 0.173710, 0.001511},{1.416967, 0.173356, 0.002984},{
      1.414129, 0.172907, 0.002984},{1.414019, 0.173243, 0.001511}}],
    Polygon[{{1.416967, 0.173356, 0.002984},{1.416967, 0.172777, 0.004384},{
      1.414308, 0.172355, 0.004384},{1.414129, 0.172907, 0.002984}}],
    Polygon[{{1.416967, 0.172777, 0.004384},{1.416967, 0.171985, 0.005676},{
      1.414553, 0.171602, 0.005676},{1.414308, 0.172355, 0.004384}}],
    Polygon[{{1.416967, 0.171985, 0.005676},{1.416967, 0.171001, 0.006829},{
      1.414857, 0.170666, 0.006829},{1.414553, 0.171602, 0.005676}}],
    Polygon[{{1.416967, 0.171001, 0.006829},{1.416967, 0.169848, 0.007813},{
      1.415213, 0.169570, 0.007813},{1.414857, 0.170666, 0.006829}}],
    Polygon[{{1.416967, 0.169848, 0.007813},{1.416967, 0.168556, 0.008605},{
      1.415612, 0.168342, 0.008605},{1.415213, 0.169570, 0.007813}}],
    Polygon[{{1.416967, 0.168556, 0.008605},{1.416967, 0.167156, 0.009185},{
      1.416045, 0.167010, 0.009185},{1.415612, 0.168342, 0.008605}}],
    Polygon[{{1.416967, 0.167156, 0.009185},{1.416967, 0.165683, 0.009538},{
      1.416500, 0.165609, 0.009538},{1.416045, 0.167010, 0.009185}}],
    Polygon[{{1.416500, 0.165609, -0.009538},{1.416045, 0.167010, -0.009185},{
      1.415213, 0.166586, -0.009185},{1.416079, 0.165394, -0.009538}}],
    Polygon[{{1.416045, 0.167010, -0.009185},{1.415612, 0.168342, -0.008605},{
      1.414390, 0.167719, -0.008605},{1.415213, 0.166586, -0.009185}}],
    Polygon[{{1.415612, 0.168342, -0.008605},{1.415213, 0.169570, -0.007813},{
      1.413630, 0.168764, -0.007813},{1.414390, 0.167719, -0.008605}}],
    Polygon[{{1.415213, 0.169570, -0.007813},{1.414857, 0.170666, -0.006829},{
      1.412953, 0.169696, -0.006829},{1.413630, 0.168764, -0.007813}}],
    Polygon[{{1.414857, 0.170666, -0.006829},{1.414553, 0.171602, -0.005676},{
      1.412375, 0.170493, -0.005676},{1.412953, 0.169696, -0.006829}}],
    Polygon[{{1.414553, 0.171602, -0.005676},{1.414308, 0.172355, -0.004384},{
      1.411909, 0.171133, -0.004384},{1.412375, 0.170493, -0.005676}}],
    Polygon[{{1.414308, 0.172355, -0.004384},{1.414129, 0.172907, -0.002984},{
      1.411568, 0.171602, -0.002984},{1.411909, 0.171133, -0.004384}}],
    Polygon[{{1.414129, 0.172907, -0.002984},{1.414019, 0.173243, -0.001511},{
      1.411360, 0.171889, -0.001511},{1.411568, 0.171602, -0.002984}}],
    Polygon[{{1.414019, 0.173243, -0.001511},{1.413983, 0.173356, 0.000000},{
      1.411291, 0.171985, 0.000000},{1.411360, 0.171889, -0.001511}}],
    Polygon[{{1.413983, 0.173356, 0.000000},{1.414019, 0.173243, 0.001511},{
      1.411360, 0.171889, 0.001511},{1.411291, 0.171985, 0.000000}}],
    Polygon[{{1.414019, 0.173243, 0.001511},{1.414129, 0.172907, 0.002984},{
      1.411568, 0.171602, 0.002984},{1.411360, 0.171889, 0.001511}}],
    Polygon[{{1.414129, 0.172907, 0.002984},{1.414308, 0.172355, 0.004384},{
      1.411909, 0.171133, 0.004384},{1.411568, 0.171602, 0.002984}}],
    Polygon[{{1.414308, 0.172355, 0.004384},{1.414553, 0.171602, 0.005676},{
      1.412375, 0.170493, 0.005676},{1.411909, 0.171133, 0.004384}}],
    Polygon[{{1.414553, 0.171602, 0.005676},{1.414857, 0.170666, 0.006829},{
      1.412953, 0.169696, 0.006829},{1.412375, 0.170493, 0.005676}}],
    Polygon[{{1.414857, 0.170666, 0.006829},{1.415213, 0.169570, 0.007813},{
      1.413630, 0.168764, 0.007813},{1.412953, 0.169696, 0.006829}}],
    Polygon[{{1.415213, 0.169570, 0.007813},{1.415612, 0.168342, 0.008605},{
      1.414390, 0.167719, 0.008605},{1.413630, 0.168764, 0.007813}}],
    Polygon[{{1.415612, 0.168342, 0.008605},{1.416045, 0.167010, 0.009185},{
      1.415213, 0.166586, 0.009185},{1.414390, 0.167719, 0.008605}}],
    Polygon[{{1.416045, 0.167010, 0.009185},{1.416500, 0.165609, 0.009538},{
      1.416079, 0.165394, 0.009538},{1.415213, 0.166586, 0.009185}}],
    Polygon[{{1.416079, 0.165394, -0.009538},{1.415213, 0.166586, -0.009185},{
      1.414553, 0.165926, -0.009185},{1.415745, 0.165060, -0.009538}}],
    Polygon[{{1.415213, 0.166586, -0.009185},{1.414390, 0.167719, -0.008605},{
      1.413420, 0.166749, -0.008605},{1.414553, 0.165926, -0.009185}}],
    Polygon[{{1.414390, 0.167719, -0.008605},{1.413630, 0.168764, -0.007813},{
      1.412375, 0.167508, -0.007813},{1.413420, 0.166749, -0.008605}}],
    Polygon[{{1.413630, 0.168764, -0.007813},{1.412953, 0.169696, -0.006829},{
      1.411442, 0.168186, -0.006829},{1.412375, 0.167508, -0.007813}}],
    Polygon[{{1.412953, 0.169696, -0.006829},{1.412375, 0.170493, -0.005676},{
      1.410646, 0.168764, -0.005676},{1.411442, 0.168186, -0.006829}}],
    Polygon[{{1.412375, 0.170493, -0.005676},{1.411909, 0.171133, -0.004384},{
      1.410006, 0.169230, -0.004384},{1.410646, 0.168764, -0.005676}}],
    Polygon[{{1.411909, 0.171133, -0.004384},{1.411568, 0.171602, -0.002984},{
      1.409536, 0.169570, -0.002984},{1.410006, 0.169230, -0.004384}}],
    Polygon[{{1.411568, 0.171602, -0.002984},{1.411360, 0.171889, -0.001511},{
      1.409250, 0.169778, -0.001511},{1.409536, 0.169570, -0.002984}}],
    Polygon[{{1.411360, 0.171889, -0.001511},{1.411291, 0.171985, 0.000000},{
      1.409154, 0.169848, 0.000000},{1.409250, 0.169778, -0.001511}}],
    Polygon[{{1.411291, 0.171985, 0.000000},{1.411360, 0.171889, 0.001511},{
      1.409250, 0.169778, 0.001511},{1.409154, 0.169848, 0.000000}}],
    Polygon[{{1.411360, 0.171889, 0.001511},{1.411568, 0.171602, 0.002984},{
      1.409536, 0.169570, 0.002984},{1.409250, 0.169778, 0.001511}}],
    Polygon[{{1.411568, 0.171602, 0.002984},{1.411909, 0.171133, 0.004384},{
      1.410006, 0.169230, 0.004384},{1.409536, 0.169570, 0.002984}}],
    Polygon[{{1.411909, 0.171133, 0.004384},{1.412375, 0.170493, 0.005676},{
      1.410646, 0.168764, 0.005676},{1.410006, 0.169230, 0.004384}}],
    Polygon[{{1.412375, 0.170493, 0.005676},{1.412953, 0.169696, 0.006829},{
      1.411442, 0.168186, 0.006829},{1.410646, 0.168764, 0.005676}}],
    Polygon[{{1.412953, 0.169696, 0.006829},{1.413630, 0.168764, 0.007813},{
      1.412375, 0.167508, 0.007813},{1.411442, 0.168186, 0.006829}}],
    Polygon[{{1.413630, 0.168764, 0.007813},{1.414390, 0.167719, 0.008605},{
      1.413420, 0.166749, 0.008605},{1.412375, 0.167508, 0.007813}}],
    Polygon[{{1.414390, 0.167719, 0.008605},{1.415213, 0.166586, 0.009185},{
      1.414553, 0.165926, 0.009185},{1.413420, 0.166749, 0.008605}}],
    Polygon[{{1.415213, 0.166586, 0.009185},{1.416079, 0.165394, 0.009538},{
      1.415745, 0.165060, 0.009538},{1.414553, 0.165926, 0.009185}}],
    Polygon[{{1.415745, 0.165060, -0.009538},{1.414553, 0.165926, -0.009185},{
      1.414129, 0.165094, -0.009185},{1.415530, 0.164639, -0.009538}}],
    Polygon[{{1.414553, 0.165926, -0.009185},{1.413420, 0.166749, -0.008605},{
      1.412797, 0.165527, -0.008605},{1.414129, 0.165094, -0.009185}}],
    Polygon[{{1.413420, 0.166749, -0.008605},{1.412375, 0.167508, -0.007813},{
      1.411568, 0.165926, -0.007813},{1.412797, 0.165527, -0.008605}}],
    Polygon[{{1.412375, 0.167508, -0.007813},{1.411442, 0.168186, -0.006829},{
      1.410473, 0.166282, -0.006829},{1.411568, 0.165926, -0.007813}}],
    Polygon[{{1.411442, 0.168186, -0.006829},{1.410646, 0.168764, -0.005676},{
      1.409536, 0.166586, -0.005676},{1.410473, 0.166282, -0.006829}}],
    Polygon[{{1.410646, 0.168764, -0.005676},{1.410006, 0.169230, -0.004384},{
      1.408783, 0.166831, -0.004384},{1.409536, 0.166586, -0.005676}}],
    Polygon[{{1.410006, 0.169230, -0.004384},{1.409536, 0.169570, -0.002984},{
      1.408232, 0.167010, -0.002984},{1.408783, 0.166831, -0.004384}}],
    Polygon[{{1.409536, 0.169570, -0.002984},{1.409250, 0.169778, -0.001511},{
      1.407895, 0.167119, -0.001511},{1.408232, 0.167010, -0.002984}}],
    Polygon[{{1.409250, 0.169778, -0.001511},{1.409154, 0.169848, 0.000000},{
      1.407782, 0.167156, 0.000000},{1.407895, 0.167119, -0.001511}}],
    Polygon[{{1.409154, 0.169848, 0.000000},{1.409250, 0.169778, 0.001511},{
      1.407895, 0.167119, 0.001511},{1.407782, 0.167156, 0.000000}}],
    Polygon[{{1.409250, 0.169778, 0.001511},{1.409536, 0.169570, 0.002984},{
      1.408232, 0.167010, 0.002984},{1.407895, 0.167119, 0.001511}}],
    Polygon[{{1.409536, 0.169570, 0.002984},{1.410006, 0.169230, 0.004384},{
      1.408783, 0.166831, 0.004384},{1.408232, 0.167010, 0.002984}}],
    Polygon[{{1.410006, 0.169230, 0.004384},{1.410646, 0.168764, 0.005676},{
      1.409536, 0.166586, 0.005676},{1.408783, 0.166831, 0.004384}}],
    Polygon[{{1.410646, 0.168764, 0.005676},{1.411442, 0.168186, 0.006829},{
      1.410473, 0.166282, 0.006829},{1.409536, 0.166586, 0.005676}}],
    Polygon[{{1.411442, 0.168186, 0.006829},{1.412375, 0.167508, 0.007813},{
      1.411568, 0.165926, 0.007813},{1.410473, 0.166282, 0.006829}}],
    Polygon[{{1.412375, 0.167508, 0.007813},{1.413420, 0.166749, 0.008605},{
      1.412797, 0.165527, 0.008605},{1.411568, 0.165926, 0.007813}}],
    Polygon[{{1.413420, 0.166749, 0.008605},{1.414553, 0.165926, 0.009185},{
      1.414129, 0.165094, 0.009185},{1.412797, 0.165527, 0.008605}}],
    Polygon[{{1.414553, 0.165926, 0.009185},{1.415745, 0.165060, 0.009538},{
      1.415530, 0.164639, 0.009538},{1.414129, 0.165094, 0.009185}}],
    Polygon[{{1.415530, 0.164639, -0.009538},{1.414129, 0.165094, -0.009185},{
      1.413983, 0.164172, -0.009185},{1.415456, 0.164172, -0.009538}}],
    Polygon[{{1.414129, 0.165094, -0.009185},{1.412797, 0.165527, -0.008605},{
      1.412583, 0.164172, -0.008605},{1.413983, 0.164172, -0.009185}}],
    Polygon[{{1.412797, 0.165527, -0.008605},{1.411568, 0.165926, -0.007813},{
      1.411291, 0.164172, -0.007813},{1.412583, 0.164172, -0.008605}}],
    Polygon[{{1.411568, 0.165926, -0.007813},{1.410473, 0.166282, -0.006829},{
      1.410138, 0.164172, -0.006829},{1.411291, 0.164172, -0.007813}}],
    Polygon[{{1.410473, 0.166282, -0.006829},{1.409536, 0.166586, -0.005676},{
      1.409154, 0.164172, -0.005676},{1.410138, 0.164172, -0.006829}}],
    Polygon[{{1.409536, 0.166586, -0.005676},{1.408783, 0.166831, -0.004384},{
      1.408362, 0.164172, -0.004384},{1.409154, 0.164172, -0.005676}}],
    Polygon[{{1.408783, 0.166831, -0.004384},{1.408232, 0.167010, -0.002984},{
      1.407782, 0.164172, -0.002984},{1.408362, 0.164172, -0.004384}}],
    Polygon[{{1.408232, 0.167010, -0.002984},{1.407895, 0.167119, -0.001511},{
      1.407429, 0.164172, -0.001511},{1.407782, 0.164172, -0.002984}}],
    Polygon[{{1.407895, 0.167119, -0.001511},{1.407782, 0.167156, 0.000000},{
      1.407310, 0.164172, 0.000000},{1.407429, 0.164172, -0.001511}}],
    Polygon[{{1.407782, 0.167156, 0.000000},{1.407895, 0.167119, 0.001511},{
      1.407429, 0.164172, 0.001511},{1.407310, 0.164172, 0.000000}}],
    Polygon[{{1.407895, 0.167119, 0.001511},{1.408232, 0.167010, 0.002984},{
      1.407782, 0.164172, 0.002984},{1.407429, 0.164172, 0.001511}}],
    Polygon[{{1.408232, 0.167010, 0.002984},{1.408783, 0.166831, 0.004384},{
      1.408362, 0.164172, 0.004384},{1.407782, 0.164172, 0.002984}}],
    Polygon[{{1.408783, 0.166831, 0.004384},{1.409536, 0.166586, 0.005676},{
      1.409154, 0.164172, 0.005676},{1.408362, 0.164172, 0.004384}}],
    Polygon[{{1.409536, 0.166586, 0.005676},{1.410473, 0.166282, 0.006829},{
      1.410138, 0.164172, 0.006829},{1.409154, 0.164172, 0.005676}}],
    Polygon[{{1.410473, 0.166282, 0.006829},{1.411568, 0.165926, 0.007813},{
      1.411291, 0.164172, 0.007813},{1.410138, 0.164172, 0.006829}}],
    Polygon[{{1.411568, 0.165926, 0.007813},{1.412797, 0.165527, 0.008605},{
      1.412583, 0.164172, 0.008605},{1.411291, 0.164172, 0.007813}}],
    Polygon[{{1.412797, 0.165527, 0.008605},{1.414129, 0.165094, 0.009185},{
      1.413983, 0.164172, 0.009185},{1.412583, 0.164172, 0.008605}}],
    Polygon[{{1.414129, 0.165094, 0.009185},{1.415530, 0.164639, 0.009538},{
      1.415456, 0.164172, 0.009538},{1.413983, 0.164172, 0.009185}}],
    Polygon[{{1.415456, 0.164172, -0.009538},{1.413983, 0.164172, -0.009185},{
      1.414129, 0.163250, -0.009185},{1.415530, 0.163705, -0.009538}}],
    Polygon[{{1.413983, 0.164172, -0.009185},{1.412583, 0.164172, -0.008605},{
      1.412797, 0.162817, -0.008605},{1.414129, 0.163250, -0.009185}}],
    Polygon[{{1.412583, 0.164172, -0.008605},{1.411291, 0.164172, -0.007813},{
      1.411568, 0.162418, -0.007813},{1.412797, 0.162817, -0.008605}}],
    Polygon[{{1.411291, 0.164172, -0.007813},{1.410138, 0.164172, -0.006829},{
      1.410473, 0.162062, -0.006829},{1.411568, 0.162418, -0.007813}}],
    Polygon[{{1.410138, 0.164172, -0.006829},{1.409154, 0.164172, -0.005676},{
      1.409536, 0.161758, -0.005676},{1.410473, 0.162062, -0.006829}}],
    Polygon[{{1.409154, 0.164172, -0.005676},{1.408362, 0.164172, -0.004384},{
      1.408783, 0.161513, -0.004384},{1.409536, 0.161758, -0.005676}}],
    Polygon[{{1.408362, 0.164172, -0.004384},{1.407782, 0.164172, -0.002984},{
      1.408232, 0.161334, -0.002984},{1.408783, 0.161513, -0.004384}}],
    Polygon[{{1.407782, 0.164172, -0.002984},{1.407429, 0.164172, -0.001511},{
      1.407895, 0.161224, -0.001511},{1.408232, 0.161334, -0.002984}}],
    Polygon[{{1.407429, 0.164172, -0.001511},{1.407310, 0.164172, 0.000000},{
      1.407782, 0.161188, 0.000000},{1.407895, 0.161224, -0.001511}}],
    Polygon[{{1.407310, 0.164172, 0.000000},{1.407429, 0.164172, 0.001511},{
      1.407895, 0.161224, 0.001511},{1.407782, 0.161188, 0.000000}}],
    Polygon[{{1.407429, 0.164172, 0.001511},{1.407782, 0.164172, 0.002984},{
      1.408232, 0.161334, 0.002984},{1.407895, 0.161224, 0.001511}}],
    Polygon[{{1.407782, 0.164172, 0.002984},{1.408362, 0.164172, 0.004384},{
      1.408783, 0.161513, 0.004384},{1.408232, 0.161334, 0.002984}}],
    Polygon[{{1.408362, 0.164172, 0.004384},{1.409154, 0.164172, 0.005676},{
      1.409536, 0.161758, 0.005676},{1.408783, 0.161513, 0.004384}}],
    Polygon[{{1.409154, 0.164172, 0.005676},{1.410138, 0.164172, 0.006829},{
      1.410473, 0.162062, 0.006829},{1.409536, 0.161758, 0.005676}}],
    Polygon[{{1.410138, 0.164172, 0.006829},{1.411291, 0.164172, 0.007813},{
      1.411568, 0.162418, 0.007813},{1.410473, 0.162062, 0.006829}}],
    Polygon[{{1.411291, 0.164172, 0.007813},{1.412583, 0.164172, 0.008605},{
      1.412797, 0.162817, 0.008605},{1.411568, 0.162418, 0.007813}}],
    Polygon[{{1.412583, 0.164172, 0.008605},{1.413983, 0.164172, 0.009185},{
      1.414129, 0.163250, 0.009185},{1.412797, 0.162817, 0.008605}}],
    Polygon[{{1.413983, 0.164172, 0.009185},{1.415456, 0.164172, 0.009538},{
      1.415530, 0.163705, 0.009538},{1.414129, 0.163250, 0.009185}}],
    Polygon[{{1.415530, 0.163705, -0.009538},{1.414129, 0.163250, -0.009185},{
      1.414553, 0.162418, -0.009185},{1.415745, 0.163284, -0.009538}}],
    Polygon[{{1.414129, 0.163250, -0.009185},{1.412797, 0.162817, -0.008605},{
      1.413420, 0.161595, -0.008605},{1.414553, 0.162418, -0.009185}}],
    Polygon[{{1.412797, 0.162817, -0.008605},{1.411568, 0.162418, -0.007813},{
      1.412375, 0.160835, -0.007813},{1.413420, 0.161595, -0.008605}}],
    Polygon[{{1.411568, 0.162418, -0.007813},{1.410473, 0.162062, -0.006829},{
      1.411442, 0.160158, -0.006829},{1.412375, 0.160835, -0.007813}}],
    Polygon[{{1.410473, 0.162062, -0.006829},{1.409536, 0.161758, -0.005676},{
      1.410646, 0.159580, -0.005676},{1.411442, 0.160158, -0.006829}}],
    Polygon[{{1.409536, 0.161758, -0.005676},{1.408783, 0.161513, -0.004384},{
      1.410006, 0.159114, -0.004384},{1.410646, 0.159580, -0.005676}}],
    Polygon[{{1.408783, 0.161513, -0.004384},{1.408232, 0.161334, -0.002984},{
      1.409536, 0.158773, -0.002984},{1.410006, 0.159114, -0.004384}}],
    Polygon[{{1.408232, 0.161334, -0.002984},{1.407895, 0.161224, -0.001511},{
      1.409250, 0.158565, -0.001511},{1.409536, 0.158773, -0.002984}}],
    Polygon[{{1.407895, 0.161224, -0.001511},{1.407782, 0.161188, 0.000000},{
      1.409154, 0.158496, 0.000000},{1.409250, 0.158565, -0.001511}}],
    Polygon[{{1.407782, 0.161188, 0.000000},{1.407895, 0.161224, 0.001511},{
      1.409250, 0.158565, 0.001511},{1.409154, 0.158496, 0.000000}}],
    Polygon[{{1.407895, 0.161224, 0.001511},{1.408232, 0.161334, 0.002984},{
      1.409536, 0.158773, 0.002984},{1.409250, 0.158565, 0.001511}}],
    Polygon[{{1.408232, 0.161334, 0.002984},{1.408783, 0.161513, 0.004384},{
      1.410006, 0.159114, 0.004384},{1.409536, 0.158773, 0.002984}}],
    Polygon[{{1.408783, 0.161513, 0.004384},{1.409536, 0.161758, 0.005676},{
      1.410646, 0.159580, 0.005676},{1.410006, 0.159114, 0.004384}}],
    Polygon[{{1.409536, 0.161758, 0.005676},{1.410473, 0.162062, 0.006829},{
      1.411442, 0.160158, 0.006829},{1.410646, 0.159580, 0.005676}}],
    Polygon[{{1.410473, 0.162062, 0.006829},{1.411568, 0.162418, 0.007813},{
      1.412375, 0.160835, 0.007813},{1.411442, 0.160158, 0.006829}}],
    Polygon[{{1.411568, 0.162418, 0.007813},{1.412797, 0.162817, 0.008605},{
      1.413420, 0.161595, 0.008605},{1.412375, 0.160835, 0.007813}}],
    Polygon[{{1.412797, 0.162817, 0.008605},{1.414129, 0.163250, 0.009185},{
      1.414553, 0.162418, 0.009185},{1.413420, 0.161595, 0.008605}}],
    Polygon[{{1.414129, 0.163250, 0.009185},{1.415530, 0.163705, 0.009538},{
      1.415745, 0.163284, 0.009538},{1.414553, 0.162418, 0.009185}}],
    Polygon[{{1.415745, 0.163284, -0.009538},{1.414553, 0.162418, -0.009185},{
      1.415213, 0.161758, -0.009185},{1.416079, 0.162950, -0.009538}}],
    Polygon[{{1.414553, 0.162418, -0.009185},{1.413420, 0.161595, -0.008605},{
      1.414390, 0.160625, -0.008605},{1.415213, 0.161758, -0.009185}}],
    Polygon[{{1.413420, 0.161595, -0.008605},{1.412375, 0.160835, -0.007813},{
      1.413630, 0.159580, -0.007813},{1.414390, 0.160625, -0.008605}}],
    Polygon[{{1.412375, 0.160835, -0.007813},{1.411442, 0.160158, -0.006829},{
      1.412953, 0.158647, -0.006829},{1.413630, 0.159580, -0.007813}}],
    Polygon[{{1.411442, 0.160158, -0.006829},{1.410646, 0.159580, -0.005676},{
      1.412375, 0.157851, -0.005676},{1.412953, 0.158647, -0.006829}}],
    Polygon[{{1.410646, 0.159580, -0.005676},{1.410006, 0.159114, -0.004384},{
      1.411909, 0.157211, -0.004384},{1.412375, 0.157851, -0.005676}}],
    Polygon[{{1.410006, 0.159114, -0.004384},{1.409536, 0.158773, -0.002984},{
      1.411568, 0.156741, -0.002984},{1.411909, 0.157211, -0.004384}}],
    Polygon[{{1.409536, 0.158773, -0.002984},{1.409250, 0.158565, -0.001511},{
      1.411360, 0.156455, -0.001511},{1.411568, 0.156741, -0.002984}}],
    Polygon[{{1.409250, 0.158565, -0.001511},{1.409154, 0.158496, 0.000000},{
      1.411291, 0.156359, 0.000000},{1.411360, 0.156455, -0.001511}}],
    Polygon[{{1.409154, 0.158496, 0.000000},{1.409250, 0.158565, 0.001511},{
      1.411360, 0.156455, 0.001511},{1.411291, 0.156359, 0.000000}}],
    Polygon[{{1.409250, 0.158565, 0.001511},{1.409536, 0.158773, 0.002984},{
      1.411568, 0.156741, 0.002984},{1.411360, 0.156455, 0.001511}}],
    Polygon[{{1.409536, 0.158773, 0.002984},{1.410006, 0.159114, 0.004384},{
      1.411909, 0.157211, 0.004384},{1.411568, 0.156741, 0.002984}}],
    Polygon[{{1.410006, 0.159114, 0.004384},{1.410646, 0.159580, 0.005676},{
      1.412375, 0.157851, 0.005676},{1.411909, 0.157211, 0.004384}}],
    Polygon[{{1.410646, 0.159580, 0.005676},{1.411442, 0.160158, 0.006829},{
      1.412953, 0.158647, 0.006829},{1.412375, 0.157851, 0.005676}}],
    Polygon[{{1.411442, 0.160158, 0.006829},{1.412375, 0.160835, 0.007813},{
      1.413630, 0.159580, 0.007813},{1.412953, 0.158647, 0.006829}}],
    Polygon[{{1.412375, 0.160835, 0.007813},{1.413420, 0.161595, 0.008605},{
      1.414390, 0.160625, 0.008605},{1.413630, 0.159580, 0.007813}}],
    Polygon[{{1.413420, 0.161595, 0.008605},{1.414553, 0.162418, 0.009185},{
      1.415213, 0.161758, 0.009185},{1.414390, 0.160625, 0.008605}}],
    Polygon[{{1.414553, 0.162418, 0.009185},{1.415745, 0.163284, 0.009538},{
      1.416079, 0.162950, 0.009538},{1.415213, 0.161758, 0.009185}}],
    Polygon[{{1.416079, 0.162950, -0.009538},{1.415213, 0.161758, -0.009185},{
      1.416045, 0.161334, -0.009185},{1.416500, 0.162735, -0.009538}}],
    Polygon[{{1.415213, 0.161758, -0.009185},{1.414390, 0.160625, -0.008605},{
      1.415612, 0.160002, -0.008605},{1.416045, 0.161334, -0.009185}}],
    Polygon[{{1.414390, 0.160625, -0.008605},{1.413630, 0.159580, -0.007813},{
      1.415213, 0.158773, -0.007813},{1.415612, 0.160002, -0.008605}}],
    Polygon[{{1.413630, 0.159580, -0.007813},{1.412953, 0.158647, -0.006829},{
      1.414857, 0.157677, -0.006829},{1.415213, 0.158773, -0.007813}}],
    Polygon[{{1.412953, 0.158647, -0.006829},{1.412375, 0.157851, -0.005676},{
      1.414553, 0.156741, -0.005676},{1.414857, 0.157677, -0.006829}}],
    Polygon[{{1.412375, 0.157851, -0.005676},{1.411909, 0.157211, -0.004384},{
      1.414308, 0.155988, -0.004384},{1.414553, 0.156741, -0.005676}}],
    Polygon[{{1.411909, 0.157211, -0.004384},{1.411568, 0.156741, -0.002984},{
      1.414129, 0.155437, -0.002984},{1.414308, 0.155988, -0.004384}}],
    Polygon[{{1.411568, 0.156741, -0.002984},{1.411360, 0.156455, -0.001511},{
      1.414019, 0.155100, -0.001511},{1.414129, 0.155437, -0.002984}}],
    Polygon[{{1.411360, 0.156455, -0.001511},{1.411291, 0.156359, 0.000000},{
      1.413983, 0.154987, 0.000000},{1.414019, 0.155100, -0.001511}}],
    Polygon[{{1.411291, 0.156359, 0.000000},{1.411360, 0.156455, 0.001511},{
      1.414019, 0.155100, 0.001511},{1.413983, 0.154987, 0.000000}}],
    Polygon[{{1.411360, 0.156455, 0.001511},{1.411568, 0.156741, 0.002984},{
      1.414129, 0.155437, 0.002984},{1.414019, 0.155100, 0.001511}}],
    Polygon[{{1.411568, 0.156741, 0.002984},{1.411909, 0.157211, 0.004384},{
      1.414308, 0.155988, 0.004384},{1.414129, 0.155437, 0.002984}}],
    Polygon[{{1.411909, 0.157211, 0.004384},{1.412375, 0.157851, 0.005676},{
      1.414553, 0.156741, 0.005676},{1.414308, 0.155988, 0.004384}}],
    Polygon[{{1.412375, 0.157851, 0.005676},{1.412953, 0.158647, 0.006829},{
      1.414857, 0.157677, 0.006829},{1.414553, 0.156741, 0.005676}}],
    Polygon[{{1.412953, 0.158647, 0.006829},{1.413630, 0.159580, 0.007813},{
      1.415213, 0.158773, 0.007813},{1.414857, 0.157677, 0.006829}}],
    Polygon[{{1.413630, 0.159580, 0.007813},{1.414390, 0.160625, 0.008605},{
      1.415612, 0.160002, 0.008605},{1.415213, 0.158773, 0.007813}}],
    Polygon[{{1.414390, 0.160625, 0.008605},{1.415213, 0.161758, 0.009185},{
      1.416045, 0.161334, 0.009185},{1.415612, 0.160002, 0.008605}}],
    Polygon[{{1.415213, 0.161758, 0.009185},{1.416079, 0.162950, 0.009538},{
      1.416500, 0.162735, 0.009538},{1.416045, 0.161334, 0.009185}}],
    Polygon[{{1.416500, 0.162735, -0.009538},{1.416045, 0.161334, -0.009185},{
      1.416967, 0.161188, -0.009185},{1.416967, 0.162661, -0.009538}}],
    Polygon[{{1.416045, 0.161334, -0.009185},{1.415612, 0.160002, -0.008605},{
      1.416967, 0.159788, -0.008605},{1.416967, 0.161188, -0.009185}}],
    Polygon[{{1.415612, 0.160002, -0.008605},{1.415213, 0.158773, -0.007813},{
      1.416967, 0.158496, -0.007813},{1.416967, 0.159788, -0.008605}}],
    Polygon[{{1.415213, 0.158773, -0.007813},{1.414857, 0.157677, -0.006829},{
      1.416967, 0.157343, -0.006829},{1.416967, 0.158496, -0.007813}}],
    Polygon[{{1.414857, 0.157677, -0.006829},{1.414553, 0.156741, -0.005676},{
      1.416967, 0.156359, -0.005676},{1.416967, 0.157343, -0.006829}}],
    Polygon[{{1.414553, 0.156741, -0.005676},{1.414308, 0.155988, -0.004384},{
      1.416967, 0.155567, -0.004384},{1.416967, 0.156359, -0.005676}}],
    Polygon[{{1.414308, 0.155988, -0.004384},{1.414129, 0.155437, -0.002984},{
      1.416967, 0.154987, -0.002984},{1.416967, 0.155567, -0.004384}}],
    Polygon[{{1.414129, 0.155437, -0.002984},{1.414019, 0.155100, -0.001511},{
      1.416967, 0.154634, -0.001511},{1.416967, 0.154987, -0.002984}}],
    Polygon[{{1.414019, 0.155100, -0.001511},{1.413983, 0.154987, 0.000000},{
      1.416967, 0.154515, 0.000000},{1.416967, 0.154634, -0.001511}}],
    Polygon[{{1.413983, 0.154987, 0.000000},{1.414019, 0.155100, 0.001511},{
      1.416967, 0.154634, 0.001511},{1.416967, 0.154515, 0.000000}}],
    Polygon[{{1.414019, 0.155100, 0.001511},{1.414129, 0.155437, 0.002984},{
      1.416967, 0.154987, 0.002984},{1.416967, 0.154634, 0.001511}}],
    Polygon[{{1.414129, 0.155437, 0.002984},{1.414308, 0.155988, 0.004384},{
      1.416967, 0.155567, 0.004384},{1.416967, 0.154987, 0.002984}}],
    Polygon[{{1.414308, 0.155988, 0.004384},{1.414553, 0.156741, 0.005676},{
      1.416967, 0.156359, 0.005676},{1.416967, 0.155567, 0.004384}}],
    Polygon[{{1.414553, 0.156741, 0.005676},{1.414857, 0.157677, 0.006829},{
      1.416967, 0.157343, 0.006829},{1.416967, 0.156359, 0.005676}}],
    Polygon[{{1.414857, 0.157677, 0.006829},{1.415213, 0.158773, 0.007813},{
      1.416967, 0.158496, 0.007813},{1.416967, 0.157343, 0.006829}}],
    Polygon[{{1.415213, 0.158773, 0.007813},{1.415612, 0.160002, 0.008605},{
      1.416967, 0.159788, 0.008605},{1.416967, 0.158496, 0.007813}}],
    Polygon[{{1.415612, 0.160002, 0.008605},{1.416045, 0.161334, 0.009185},{
      1.416967, 0.161188, 0.009185},{1.416967, 0.159788, 0.008605}}],
    Polygon[{{1.416045, 0.161334, 0.009185},{1.416500, 0.162735, 0.009538},{
      1.416967, 0.162661, 0.009538},{1.416967, 0.161188, 0.009185}}],
    Polygon[{{1.416967, 0.162661, -0.009538},{1.416967, 0.161188, -0.009185},{
      1.417889, 0.161334, -0.009185},{1.417434, 0.162735, -0.009538}}],
    Polygon[{{1.416967, 0.161188, -0.009185},{1.416967, 0.159788, -0.008605},{
      1.418322, 0.160002, -0.008605},{1.417889, 0.161334, -0.009185}}],
    Polygon[{{1.416967, 0.159788, -0.008605},{1.416967, 0.158496, -0.007813},{
      1.418721, 0.158773, -0.007813},{1.418322, 0.160002, -0.008605}}],
    Polygon[{{1.416967, 0.158496, -0.007813},{1.416967, 0.157343, -0.006829},{
      1.419077, 0.157677, -0.006829},{1.418721, 0.158773, -0.007813}}],
    Polygon[{{1.416967, 0.157343, -0.006829},{1.416967, 0.156359, -0.005676},{
      1.419381, 0.156741, -0.005676},{1.419077, 0.157677, -0.006829}}],
    Polygon[{{1.416967, 0.156359, -0.005676},{1.416967, 0.155567, -0.004384},{
      1.419626, 0.155988, -0.004384},{1.419381, 0.156741, -0.005676}}],
    Polygon[{{1.416967, 0.155567, -0.004384},{1.416967, 0.154987, -0.002984},{
      1.419805, 0.155437, -0.002984},{1.419626, 0.155988, -0.004384}}],
    Polygon[{{1.416967, 0.154987, -0.002984},{1.416967, 0.154634, -0.001511},{
      1.419914, 0.155100, -0.001511},{1.419805, 0.155437, -0.002984}}],
    Polygon[{{1.416967, 0.154634, -0.001511},{1.416967, 0.154515, 0.000000},{
      1.419951, 0.154987, 0.000000},{1.419914, 0.155100, -0.001511}}],
    Polygon[{{1.416967, 0.154515, 0.000000},{1.416967, 0.154634, 0.001511},{
      1.419914, 0.155100, 0.001511},{1.419951, 0.154987, 0.000000}}],
    Polygon[{{1.416967, 0.154634, 0.001511},{1.416967, 0.154987, 0.002984},{
      1.419805, 0.155437, 0.002984},{1.419914, 0.155100, 0.001511}}],
    Polygon[{{1.416967, 0.154987, 0.002984},{1.416967, 0.155567, 0.004384},{
      1.419626, 0.155988, 0.004384},{1.419805, 0.155437, 0.002984}}],
    Polygon[{{1.416967, 0.155567, 0.004384},{1.416967, 0.156359, 0.005676},{
      1.419381, 0.156741, 0.005676},{1.419626, 0.155988, 0.004384}}],
    Polygon[{{1.416967, 0.156359, 0.005676},{1.416967, 0.157343, 0.006829},{
      1.419077, 0.157677, 0.006829},{1.419381, 0.156741, 0.005676}}],
    Polygon[{{1.416967, 0.157343, 0.006829},{1.416967, 0.158496, 0.007813},{
      1.418721, 0.158773, 0.007813},{1.419077, 0.157677, 0.006829}}],
    Polygon[{{1.416967, 0.158496, 0.007813},{1.416967, 0.159788, 0.008605},{
      1.418322, 0.160002, 0.008605},{1.418721, 0.158773, 0.007813}}],
    Polygon[{{1.416967, 0.159788, 0.008605},{1.416967, 0.161188, 0.009185},{
      1.417889, 0.161334, 0.009185},{1.418322, 0.160002, 0.008605}}],
    Polygon[{{1.416967, 0.161188, 0.009185},{1.416967, 0.162661, 0.009538},{
      1.417434, 0.162735, 0.009538},{1.417889, 0.161334, 0.009185}}],
    Polygon[{{1.417434, 0.162735, -0.009538},{1.417889, 0.161334, -0.009185},{
      1.418721, 0.161758, -0.009185},{1.417855, 0.162950, -0.009538}}],
    Polygon[{{1.417889, 0.161334, -0.009185},{1.418322, 0.160002, -0.008605},{
      1.419544, 0.160625, -0.008605},{1.418721, 0.161758, -0.009185}}],
    Polygon[{{1.418322, 0.160002, -0.008605},{1.418721, 0.158773, -0.007813},{
      1.420303, 0.159580, -0.007813},{1.419544, 0.160625, -0.008605}}],
    Polygon[{{1.418721, 0.158773, -0.007813},{1.419077, 0.157677, -0.006829},{
      1.420981, 0.158647, -0.006829},{1.420303, 0.159580, -0.007813}}],
    Polygon[{{1.419077, 0.157677, -0.006829},{1.419381, 0.156741, -0.005676},{
      1.421559, 0.157851, -0.005676},{1.420981, 0.158647, -0.006829}}],
    Polygon[{{1.419381, 0.156741, -0.005676},{1.419626, 0.155988, -0.004384},{
      1.422025, 0.157211, -0.004384},{1.421559, 0.157851, -0.005676}}],
    Polygon[{{1.419626, 0.155988, -0.004384},{1.419805, 0.155437, -0.002984},{
      1.422365, 0.156741, -0.002984},{1.422025, 0.157211, -0.004384}}],
    Polygon[{{1.419805, 0.155437, -0.002984},{1.419914, 0.155100, -0.001511},{
      1.422573, 0.156455, -0.001511},{1.422365, 0.156741, -0.002984}}],
    Polygon[{{1.419914, 0.155100, -0.001511},{1.419951, 0.154987, 0.000000},{
      1.422643, 0.156359, 0.000000},{1.422573, 0.156455, -0.001511}}],
    Polygon[{{1.419951, 0.154987, 0.000000},{1.419914, 0.155100, 0.001511},{
      1.422573, 0.156455, 0.001511},{1.422643, 0.156359, 0.000000}}],
    Polygon[{{1.419914, 0.155100, 0.001511},{1.419805, 0.155437, 0.002984},{
      1.422365, 0.156741, 0.002984},{1.422573, 0.156455, 0.001511}}],
    Polygon[{{1.419805, 0.155437, 0.002984},{1.419626, 0.155988, 0.004384},{
      1.422025, 0.157211, 0.004384},{1.422365, 0.156741, 0.002984}}],
    Polygon[{{1.419626, 0.155988, 0.004384},{1.419381, 0.156741, 0.005676},{
      1.421559, 0.157851, 0.005676},{1.422025, 0.157211, 0.004384}}],
    Polygon[{{1.419381, 0.156741, 0.005676},{1.419077, 0.157677, 0.006829},{
      1.420981, 0.158647, 0.006829},{1.421559, 0.157851, 0.005676}}],
    Polygon[{{1.419077, 0.157677, 0.006829},{1.418721, 0.158773, 0.007813},{
      1.420303, 0.159580, 0.007813},{1.420981, 0.158647, 0.006829}}],
    Polygon[{{1.418721, 0.158773, 0.007813},{1.418322, 0.160002, 0.008605},{
      1.419544, 0.160625, 0.008605},{1.420303, 0.159580, 0.007813}}],
    Polygon[{{1.418322, 0.160002, 0.008605},{1.417889, 0.161334, 0.009185},{
      1.418721, 0.161758, 0.009185},{1.419544, 0.160625, 0.008605}}],
    Polygon[{{1.417889, 0.161334, 0.009185},{1.417434, 0.162735, 0.009538},{
      1.417855, 0.162950, 0.009538},{1.418721, 0.161758, 0.009185}}],
    Polygon[{{1.417855, 0.162950, -0.009538},{1.418721, 0.161758, -0.009185},{
      1.419381, 0.162418, -0.009185},{1.418189, 0.163284, -0.009538}}],
    Polygon[{{1.418721, 0.161758, -0.009185},{1.419544, 0.160625, -0.008605},{
      1.420514, 0.161595, -0.008605},{1.419381, 0.162418, -0.009185}}],
    Polygon[{{1.419544, 0.160625, -0.008605},{1.420303, 0.159580, -0.007813},{
      1.421559, 0.160835, -0.007813},{1.420514, 0.161595, -0.008605}}],
    Polygon[{{1.420303, 0.159580, -0.007813},{1.420981, 0.158647, -0.006829},{
      1.422491, 0.160158, -0.006829},{1.421559, 0.160835, -0.007813}}],
    Polygon[{{1.420981, 0.158647, -0.006829},{1.421559, 0.157851, -0.005676},{
      1.423288, 0.159580, -0.005676},{1.422491, 0.160158, -0.006829}}],
    Polygon[{{1.421559, 0.157851, -0.005676},{1.422025, 0.157211, -0.004384},{
      1.423928, 0.159114, -0.004384},{1.423288, 0.159580, -0.005676}}],
    Polygon[{{1.422025, 0.157211, -0.004384},{1.422365, 0.156741, -0.002984},{
      1.424397, 0.158773, -0.002984},{1.423928, 0.159114, -0.004384}}],
    Polygon[{{1.422365, 0.156741, -0.002984},{1.422573, 0.156455, -0.001511},{
      1.424684, 0.158565, -0.001511},{1.424397, 0.158773, -0.002984}}],
    Polygon[{{1.422573, 0.156455, -0.001511},{1.422643, 0.156359, 0.000000},{
      1.424780, 0.158496, 0.000000},{1.424684, 0.158565, -0.001511}}],
    Polygon[{{1.422643, 0.156359, 0.000000},{1.422573, 0.156455, 0.001511},{
      1.424684, 0.158565, 0.001511},{1.424780, 0.158496, 0.000000}}],
    Polygon[{{1.422573, 0.156455, 0.001511},{1.422365, 0.156741, 0.002984},{
      1.424397, 0.158773, 0.002984},{1.424684, 0.158565, 0.001511}}],
    Polygon[{{1.422365, 0.156741, 0.002984},{1.422025, 0.157211, 0.004384},{
      1.423928, 0.159114, 0.004384},{1.424397, 0.158773, 0.002984}}],
    Polygon[{{1.422025, 0.157211, 0.004384},{1.421559, 0.157851, 0.005676},{
      1.423288, 0.159580, 0.005676},{1.423928, 0.159114, 0.004384}}],
    Polygon[{{1.421559, 0.157851, 0.005676},{1.420981, 0.158647, 0.006829},{
      1.422491, 0.160158, 0.006829},{1.423288, 0.159580, 0.005676}}],
    Polygon[{{1.420981, 0.158647, 0.006829},{1.420303, 0.159580, 0.007813},{
      1.421559, 0.160835, 0.007813},{1.422491, 0.160158, 0.006829}}],
    Polygon[{{1.420303, 0.159580, 0.007813},{1.419544, 0.160625, 0.008605},{
      1.420514, 0.161595, 0.008605},{1.421559, 0.160835, 0.007813}}],
    Polygon[{{1.419544, 0.160625, 0.008605},{1.418721, 0.161758, 0.009185},{
      1.419381, 0.162418, 0.009185},{1.420514, 0.161595, 0.008605}}],
    Polygon[{{1.418721, 0.161758, 0.009185},{1.417855, 0.162950, 0.009538},{
      1.418189, 0.163284, 0.009538},{1.419381, 0.162418, 0.009185}}],
    Polygon[{{1.418189, 0.163284, -0.009538},{1.419381, 0.162418, -0.009185},{
      1.419805, 0.163250, -0.009185},{1.418404, 0.163705, -0.009538}}],
    Polygon[{{1.419381, 0.162418, -0.009185},{1.420514, 0.161595, -0.008605},{
      1.421137, 0.162817, -0.008605},{1.419805, 0.163250, -0.009185}}],
    Polygon[{{1.420514, 0.161595, -0.008605},{1.421559, 0.160835, -0.007813},{
      1.422365, 0.162418, -0.007813},{1.421137, 0.162817, -0.008605}}],
    Polygon[{{1.421559, 0.160835, -0.007813},{1.422491, 0.160158, -0.006829},{
      1.423461, 0.162062, -0.006829},{1.422365, 0.162418, -0.007813}}],
    Polygon[{{1.422491, 0.160158, -0.006829},{1.423288, 0.159580, -0.005676},{
      1.424397, 0.161758, -0.005676},{1.423461, 0.162062, -0.006829}}],
    Polygon[{{1.423288, 0.159580, -0.005676},{1.423928, 0.159114, -0.004384},{
      1.425150, 0.161513, -0.004384},{1.424397, 0.161758, -0.005676}}],
    Polygon[{{1.423928, 0.159114, -0.004384},{1.424397, 0.158773, -0.002984},{
      1.425702, 0.161334, -0.002984},{1.425150, 0.161513, -0.004384}}],
    Polygon[{{1.424397, 0.158773, -0.002984},{1.424684, 0.158565, -0.001511},{
      1.426038, 0.161224, -0.001511},{1.425702, 0.161334, -0.002984}}],
    Polygon[{{1.424684, 0.158565, -0.001511},{1.424780, 0.158496, 0.000000},{
      1.426151, 0.161188, 0.000000},{1.426038, 0.161224, -0.001511}}],
    Polygon[{{1.424780, 0.158496, 0.000000},{1.424684, 0.158565, 0.001511},{
      1.426038, 0.161224, 0.001511},{1.426151, 0.161188, 0.000000}}],
    Polygon[{{1.424684, 0.158565, 0.001511},{1.424397, 0.158773, 0.002984},{
      1.425702, 0.161334, 0.002984},{1.426038, 0.161224, 0.001511}}],
    Polygon[{{1.424397, 0.158773, 0.002984},{1.423928, 0.159114, 0.004384},{
      1.425150, 0.161513, 0.004384},{1.425702, 0.161334, 0.002984}}],
    Polygon[{{1.423928, 0.159114, 0.004384},{1.423288, 0.159580, 0.005676},{
      1.424397, 0.161758, 0.005676},{1.425150, 0.161513, 0.004384}}],
    Polygon[{{1.423288, 0.159580, 0.005676},{1.422491, 0.160158, 0.006829},{
      1.423461, 0.162062, 0.006829},{1.424397, 0.161758, 0.005676}}],
    Polygon[{{1.422491, 0.160158, 0.006829},{1.421559, 0.160835, 0.007813},{
      1.422365, 0.162418, 0.007813},{1.423461, 0.162062, 0.006829}}],
    Polygon[{{1.421559, 0.160835, 0.007813},{1.420514, 0.161595, 0.008605},{
      1.421137, 0.162817, 0.008605},{1.422365, 0.162418, 0.007813}}],
    Polygon[{{1.420514, 0.161595, 0.008605},{1.419381, 0.162418, 0.009185},{
      1.419805, 0.163250, 0.009185},{1.421137, 0.162817, 0.008605}}],
    Polygon[{{1.419381, 0.162418, 0.009185},{1.418189, 0.163284, 0.009538},{
      1.418404, 0.163705, 0.009538},{1.419805, 0.163250, 0.009185}}],
    Polygon[{{1.418404, 0.163705, -0.009538},{1.419805, 0.163250, -0.009185},{
      1.419951, 0.164172, -0.009185},{1.418478, 0.164172, -0.009538}}],
    Polygon[{{1.419805, 0.163250, -0.009185},{1.421137, 0.162817, -0.008605},{
      1.421351, 0.164172, -0.008605},{1.419951, 0.164172, -0.009185}}],
    Polygon[{{1.421137, 0.162817, -0.008605},{1.422365, 0.162418, -0.007813},{
      1.422643, 0.164172, -0.007813},{1.421351, 0.164172, -0.008605}}],
    Polygon[{{1.422365, 0.162418, -0.007813},{1.423461, 0.162062, -0.006829},{
      1.423796, 0.164172, -0.006829},{1.422643, 0.164172, -0.007813}}],
    Polygon[{{1.423461, 0.162062, -0.006829},{1.424397, 0.161758, -0.005676},{
      1.424780, 0.164172, -0.005676},{1.423796, 0.164172, -0.006829}}],
    Polygon[{{1.424397, 0.161758, -0.005676},{1.425150, 0.161513, -0.004384},{
      1.425571, 0.164172, -0.004384},{1.424780, 0.164172, -0.005676}}],
    Polygon[{{1.425150, 0.161513, -0.004384},{1.425702, 0.161334, -0.002984},{
      1.426151, 0.164172, -0.002984},{1.425571, 0.164172, -0.004384}}],
    Polygon[{{1.425702, 0.161334, -0.002984},{1.426038, 0.161224, -0.001511},{
      1.426505, 0.164172, -0.001511},{1.426151, 0.164172, -0.002984}}],
    Polygon[{{1.426038, 0.161224, -0.001511},{1.426151, 0.161188, 0.000000},{
      1.426624, 0.164172, 0.000000},{1.426505, 0.164172, -0.001511}}],
    Polygon[{{1.426151, 0.161188, 0.000000},{1.426038, 0.161224, 0.001511},{
      1.426505, 0.164172, 0.001511},{1.426624, 0.164172, 0.000000}}],
    Polygon[{{1.426038, 0.161224, 0.001511},{1.425702, 0.161334, 0.002984},{
      1.426151, 0.164172, 0.002984},{1.426505, 0.164172, 0.001511}}],
    Polygon[{{1.425702, 0.161334, 0.002984},{1.425150, 0.161513, 0.004384},{
      1.425571, 0.164172, 0.004384},{1.426151, 0.164172, 0.002984}}],
    Polygon[{{1.425150, 0.161513, 0.004384},{1.424397, 0.161758, 0.005676},{
      1.424780, 0.164172, 0.005676},{1.425571, 0.164172, 0.004384}}],
    Polygon[{{1.424397, 0.161758, 0.005676},{1.423461, 0.162062, 0.006829},{
      1.423796, 0.164172, 0.006829},{1.424780, 0.164172, 0.005676}}],
    Polygon[{{1.423461, 0.162062, 0.006829},{1.422365, 0.162418, 0.007813},{
      1.422643, 0.164172, 0.007813},{1.423796, 0.164172, 0.006829}}],
    Polygon[{{1.422365, 0.162418, 0.007813},{1.421137, 0.162817, 0.008605},{
      1.421351, 0.164172, 0.008605},{1.422643, 0.164172, 0.007813}}],
    Polygon[{{1.421137, 0.162817, 0.008605},{1.419805, 0.163250, 0.009185},{
      1.419951, 0.164172, 0.009185},{1.421351, 0.164172, 0.008605}}],
    Polygon[{{1.419805, 0.163250, 0.009185},{1.418404, 0.163705, 0.009538},{
      1.418478, 0.164172, 0.009538},{1.419951, 0.164172, 0.009185}}],
    Polygon[{{1.471516, 0.149198, -0.008668},{1.472855, 0.149198, -0.008347},{
      1.472723, 0.150036, -0.008347},{1.471449, 0.149623, -0.008668}}],
    Polygon[{{1.472855, 0.149198, -0.008347},{1.474128, 0.149198, -0.007820},{
      1.473933, 0.150430, -0.007820},{1.472723, 0.150036, -0.008347}}],
    Polygon[{{1.474128, 0.149198, -0.007820},{1.475302, 0.149198, -0.007100},{
      1.475050, 0.150792, -0.007100},{1.473933, 0.150430, -0.007820}}],
    Polygon[{{1.475302, 0.149198, -0.007100},{1.476349, 0.149198, -0.006206},{
      1.476045, 0.151116, -0.006206},{1.475050, 0.150792, -0.007100}}],
    Polygon[{{1.476349, 0.149198, -0.006206},{1.477244, 0.149198, -0.005159},{
      1.476896, 0.151392, -0.005159},{1.476045, 0.151116, -0.006206}}],
    Polygon[{{1.477244, 0.149198, -0.005159},{1.477963, 0.149198, -0.003984},{
      1.477581, 0.151615, -0.003984},{1.476896, 0.151392, -0.005159}}],
    Polygon[{{1.477963, 0.149198, -0.003984},{1.478490, 0.149198, -0.002712},{
      1.478082, 0.151778, -0.002712},{1.477581, 0.151615, -0.003984}}],
    Polygon[{{1.478490, 0.149198, -0.002712},{1.478812, 0.149198, -0.001373},{
      1.478387, 0.151877, -0.001373},{1.478082, 0.151778, -0.002712}}],
    Polygon[{{1.478812, 0.149198, -0.001373},{1.478920, 0.149198, 0.000000},{
      1.478490, 0.151910, 0.000000},{1.478387, 0.151877, -0.001373}}],
    Polygon[{{1.478920, 0.149198, 0.000000},{1.478812, 0.149198, 0.001373},{
      1.478387, 0.151877, 0.001373},{1.478490, 0.151910, 0.000000}}],
    Polygon[{{1.478812, 0.149198, 0.001373},{1.478490, 0.149198, 0.002712},{
      1.478082, 0.151778, 0.002712},{1.478387, 0.151877, 0.001373}}],
    Polygon[{{1.478490, 0.149198, 0.002712},{1.477963, 0.149198, 0.003984},{
      1.477581, 0.151615, 0.003984},{1.478082, 0.151778, 0.002712}}],
    Polygon[{{1.477963, 0.149198, 0.003984},{1.477244, 0.149198, 0.005159},{
      1.476896, 0.151392, 0.005159},{1.477581, 0.151615, 0.003984}}],
    Polygon[{{1.477244, 0.149198, 0.005159},{1.476349, 0.149198, 0.006206},{
      1.476045, 0.151116, 0.006206},{1.476896, 0.151392, 0.005159}}],
    Polygon[{{1.476349, 0.149198, 0.006206},{1.475302, 0.149198, 0.007100},{
      1.475050, 0.150792, 0.007100},{1.476045, 0.151116, 0.006206}}],
    Polygon[{{1.475302, 0.149198, 0.007100},{1.474128, 0.149198, 0.007820},{
      1.473933, 0.150430, 0.007820},{1.475050, 0.150792, 0.007100}}],
    Polygon[{{1.474128, 0.149198, 0.007820},{1.472855, 0.149198, 0.008347},{
      1.472723, 0.150036, 0.008347},{1.473933, 0.150430, 0.007820}}],
    Polygon[{{1.472855, 0.149198, 0.008347},{1.471516, 0.149198, 0.008668},{
      1.471449, 0.149623, 0.008668},{1.472723, 0.150036, 0.008347}}],
    Polygon[{{1.471449, 0.149623, -0.008668},{1.472723, 0.150036, -0.008347},{
      1.472337, 0.150792, -0.008347},{1.471254, 0.150005, -0.008668}}],
    Polygon[{{1.472723, 0.150036, -0.008347},{1.473933, 0.150430, -0.007820},{
      1.473367, 0.151540, -0.007820},{1.472337, 0.150792, -0.008347}}],
    Polygon[{{1.473933, 0.150430, -0.007820},{1.475050, 0.150792, -0.007100},{
      1.474317, 0.152231, -0.007100},{1.473367, 0.151540, -0.007820}}],
    Polygon[{{1.475050, 0.150792, -0.007100},{1.476045, 0.151116, -0.006206},{
      1.475164, 0.152846, -0.006206},{1.474317, 0.152231, -0.007100}}],
    Polygon[{{1.476045, 0.151116, -0.006206},{1.476896, 0.151392, -0.005159},{
      1.475888, 0.153372, -0.005159},{1.475164, 0.152846, -0.006206}}],
    Polygon[{{1.476896, 0.151392, -0.005159},{1.477581, 0.151615, -0.003984},{
      1.476470, 0.153795, -0.003984},{1.475888, 0.153372, -0.005159}}],
    Polygon[{{1.477581, 0.151615, -0.003984},{1.478082, 0.151778, -0.002712},{
      1.476896, 0.154104, -0.002712},{1.476470, 0.153795, -0.003984}}],
    Polygon[{{1.478082, 0.151778, -0.002712},{1.478387, 0.151877, -0.001373},{
      1.477156, 0.154293, -0.001373},{1.476896, 0.154104, -0.002712}}],
    Polygon[{{1.478387, 0.151877, -0.001373},{1.478490, 0.151910, 0.000000},{
      1.477244, 0.154357, 0.000000},{1.477156, 0.154293, -0.001373}}],
    Polygon[{{1.478490, 0.151910, 0.000000},{1.478387, 0.151877, 0.001373},{
      1.477156, 0.154293, 0.001373},{1.477244, 0.154357, 0.000000}}],
    Polygon[{{1.478387, 0.151877, 0.001373},{1.478082, 0.151778, 0.002712},{
      1.476896, 0.154104, 0.002712},{1.477156, 0.154293, 0.001373}}],
    Polygon[{{1.478082, 0.151778, 0.002712},{1.477581, 0.151615, 0.003984},{
      1.476470, 0.153795, 0.003984},{1.476896, 0.154104, 0.002712}}],
    Polygon[{{1.477581, 0.151615, 0.003984},{1.476896, 0.151392, 0.005159},{
      1.475888, 0.153372, 0.005159},{1.476470, 0.153795, 0.003984}}],
    Polygon[{{1.476896, 0.151392, 0.005159},{1.476045, 0.151116, 0.006206},{
      1.475164, 0.152846, 0.006206},{1.475888, 0.153372, 0.005159}}],
    Polygon[{{1.476045, 0.151116, 0.006206},{1.475050, 0.150792, 0.007100},{
      1.474317, 0.152231, 0.007100},{1.475164, 0.152846, 0.006206}}],
    Polygon[{{1.475050, 0.150792, 0.007100},{1.473933, 0.150430, 0.007820},{
      1.473367, 0.151540, 0.007820},{1.474317, 0.152231, 0.007100}}],
    Polygon[{{1.473933, 0.150430, 0.007820},{1.472723, 0.150036, 0.008347},{
      1.472337, 0.150792, 0.008347},{1.473367, 0.151540, 0.007820}}],
    Polygon[{{1.472723, 0.150036, 0.008347},{1.471449, 0.149623, 0.008668},{
      1.471254, 0.150005, 0.008668},{1.472337, 0.150792, 0.008347}}],
    Polygon[{{1.471254, 0.150005, -0.008668},{1.472337, 0.150792, -0.008347},{
      1.471738, 0.151392, -0.008347},{1.470950, 0.150309, -0.008668}}],
    Polygon[{{1.472337, 0.150792, -0.008347},{1.473367, 0.151540, -0.007820},{
      1.472485, 0.152422, -0.007820},{1.471738, 0.151392, -0.008347}}],
    Polygon[{{1.473367, 0.151540, -0.007820},{1.474317, 0.152231, -0.007100},{
      1.473176, 0.153372, -0.007100},{1.472485, 0.152422, -0.007820}}],
    Polygon[{{1.474317, 0.152231, -0.007100},{1.475164, 0.152846, -0.006206},{
      1.473791, 0.154219, -0.006206},{1.473176, 0.153372, -0.007100}}],
    Polygon[{{1.475164, 0.152846, -0.006206},{1.475888, 0.153372, -0.005159},{
      1.474317, 0.154943, -0.005159},{1.473791, 0.154219, -0.006206}}],
    Polygon[{{1.475888, 0.153372, -0.005159},{1.476470, 0.153795, -0.003984},{
      1.474740, 0.155525, -0.003984},{1.474317, 0.154943, -0.005159}}],
    Polygon[{{1.476470, 0.153795, -0.003984},{1.476896, 0.154104, -0.002712},{
      1.475050, 0.155951, -0.002712},{1.474740, 0.155525, -0.003984}}],
    Polygon[{{1.476896, 0.154104, -0.002712},{1.477156, 0.154293, -0.001373},{
      1.475239, 0.156211, -0.001373},{1.475050, 0.155951, -0.002712}}],
    Polygon[{{1.477156, 0.154293, -0.001373},{1.477244, 0.154357, 0.000000},{
      1.475302, 0.156299, 0.000000},{1.475239, 0.156211, -0.001373}}],
    Polygon[{{1.477244, 0.154357, 0.000000},{1.477156, 0.154293, 0.001373},{
      1.475239, 0.156211, 0.001373},{1.475302, 0.156299, 0.000000}}],
    Polygon[{{1.477156, 0.154293, 0.001373},{1.476896, 0.154104, 0.002712},{
      1.475050, 0.155951, 0.002712},{1.475239, 0.156211, 0.001373}}],
    Polygon[{{1.476896, 0.154104, 0.002712},{1.476470, 0.153795, 0.003984},{
      1.474740, 0.155525, 0.003984},{1.475050, 0.155951, 0.002712}}],
    Polygon[{{1.476470, 0.153795, 0.003984},{1.475888, 0.153372, 0.005159},{
      1.474317, 0.154943, 0.005159},{1.474740, 0.155525, 0.003984}}],
    Polygon[{{1.475888, 0.153372, 0.005159},{1.475164, 0.152846, 0.006206},{
      1.473791, 0.154219, 0.006206},{1.474317, 0.154943, 0.005159}}],
    Polygon[{{1.475164, 0.152846, 0.006206},{1.474317, 0.152231, 0.007100},{
      1.473176, 0.153372, 0.007100},{1.473791, 0.154219, 0.006206}}],
    Polygon[{{1.474317, 0.152231, 0.007100},{1.473367, 0.151540, 0.007820},{
      1.472485, 0.152422, 0.007820},{1.473176, 0.153372, 0.007100}}],
    Polygon[{{1.473367, 0.151540, 0.007820},{1.472337, 0.150792, 0.008347},{
      1.471738, 0.151392, 0.008347},{1.472485, 0.152422, 0.007820}}],
    Polygon[{{1.472337, 0.150792, 0.008347},{1.471254, 0.150005, 0.008668},{
      1.470950, 0.150309, 0.008668},{1.471738, 0.151392, 0.008347}}],
    Polygon[{{1.470950, 0.150309, -0.008668},{1.471738, 0.151392, -0.008347},{
      1.470981, 0.151778, -0.008347},{1.470568, 0.150504, -0.008668}}],
    Polygon[{{1.471738, 0.151392, -0.008347},{1.472485, 0.152422, -0.007820},{
      1.471375, 0.152988, -0.007820},{1.470981, 0.151778, -0.008347}}],
    Polygon[{{1.472485, 0.152422, -0.007820},{1.473176, 0.153372, -0.007100},{
      1.471738, 0.154104, -0.007100},{1.471375, 0.152988, -0.007820}}],
    Polygon[{{1.473176, 0.153372, -0.007100},{1.473791, 0.154219, -0.006206},{
      1.472061, 0.155100, -0.006206},{1.471738, 0.154104, -0.007100}}],
    Polygon[{{1.473791, 0.154219, -0.006206},{1.474317, 0.154943, -0.005159},{
      1.472337, 0.155951, -0.005159},{1.472061, 0.155100, -0.006206}}],
    Polygon[{{1.474317, 0.154943, -0.005159},{1.474740, 0.155525, -0.003984},{
      1.472560, 0.156635, -0.003984},{1.472337, 0.155951, -0.005159}}],
    Polygon[{{1.474740, 0.155525, -0.003984},{1.475050, 0.155951, -0.002712},{
      1.472723, 0.157137, -0.002712},{1.472560, 0.156635, -0.003984}}],
    Polygon[{{1.475050, 0.155951, -0.002712},{1.475239, 0.156211, -0.001373},{
      1.472822, 0.157442, -0.001373},{1.472723, 0.157137, -0.002712}}],
    Polygon[{{1.475239, 0.156211, -0.001373},{1.475302, 0.156299, 0.000000},{
      1.472855, 0.157545, 0.000000},{1.472822, 0.157442, -0.001373}}],
    Polygon[{{1.475302, 0.156299, 0.000000},{1.475239, 0.156211, 0.001373},{
      1.472822, 0.157442, 0.001373},{1.472855, 0.157545, 0.000000}}],
    Polygon[{{1.475239, 0.156211, 0.001373},{1.475050, 0.155951, 0.002712},{
      1.472723, 0.157137, 0.002712},{1.472822, 0.157442, 0.001373}}],
    Polygon[{{1.475050, 0.155951, 0.002712},{1.474740, 0.155525, 0.003984},{
      1.472560, 0.156635, 0.003984},{1.472723, 0.157137, 0.002712}}],
    Polygon[{{1.474740, 0.155525, 0.003984},{1.474317, 0.154943, 0.005159},{
      1.472337, 0.155951, 0.005159},{1.472560, 0.156635, 0.003984}}],
    Polygon[{{1.474317, 0.154943, 0.005159},{1.473791, 0.154219, 0.006206},{
      1.472061, 0.155100, 0.006206},{1.472337, 0.155951, 0.005159}}],
    Polygon[{{1.473791, 0.154219, 0.006206},{1.473176, 0.153372, 0.007100},{
      1.471738, 0.154104, 0.007100},{1.472061, 0.155100, 0.006206}}],
    Polygon[{{1.473176, 0.153372, 0.007100},{1.472485, 0.152422, 0.007820},{
      1.471375, 0.152988, 0.007820},{1.471738, 0.154104, 0.007100}}],
    Polygon[{{1.472485, 0.152422, 0.007820},{1.471738, 0.151392, 0.008347},{
      1.470981, 0.151778, 0.008347},{1.471375, 0.152988, 0.007820}}],
    Polygon[{{1.471738, 0.151392, 0.008347},{1.470950, 0.150309, 0.008668},{
      1.470568, 0.150504, 0.008668},{1.470981, 0.151778, 0.008347}}],
    Polygon[{{1.470568, 0.150504, -0.008668},{1.470981, 0.151778, -0.008347},{
      1.470143, 0.151910, -0.008347},{1.470143, 0.150571, -0.008668}}],
    Polygon[{{1.470981, 0.151778, -0.008347},{1.471375, 0.152988, -0.007820},{
      1.470143, 0.153183, -0.007820},{1.470143, 0.151910, -0.008347}}],
    Polygon[{{1.471375, 0.152988, -0.007820},{1.471738, 0.154104, -0.007100},{
      1.470143, 0.154357, -0.007100},{1.470143, 0.153183, -0.007820}}],
    Polygon[{{1.471738, 0.154104, -0.007100},{1.472061, 0.155100, -0.006206},{
      1.470143, 0.155404, -0.006206},{1.470143, 0.154357, -0.007100}}],
    Polygon[{{1.472061, 0.155100, -0.006206},{1.472337, 0.155951, -0.005159},{
      1.470143, 0.156299, -0.005159},{1.470143, 0.155404, -0.006206}}],
    Polygon[{{1.472337, 0.155951, -0.005159},{1.472560, 0.156635, -0.003984},{
      1.470143, 0.157018, -0.003984},{1.470143, 0.156299, -0.005159}}],
    Polygon[{{1.472560, 0.156635, -0.003984},{1.472723, 0.157137, -0.002712},{
      1.470143, 0.157545, -0.002712},{1.470143, 0.157018, -0.003984}}],
    Polygon[{{1.472723, 0.157137, -0.002712},{1.472822, 0.157442, -0.001373},{
      1.470143, 0.157867, -0.001373},{1.470143, 0.157545, -0.002712}}],
    Polygon[{{1.472822, 0.157442, -0.001373},{1.472855, 0.157545, 0.000000},{
      1.470143, 0.157975, 0.000000},{1.470143, 0.157867, -0.001373}}],
    Polygon[{{1.472855, 0.157545, 0.000000},{1.472822, 0.157442, 0.001373},{
      1.470143, 0.157867, 0.001373},{1.470143, 0.157975, 0.000000}}],
    Polygon[{{1.472822, 0.157442, 0.001373},{1.472723, 0.157137, 0.002712},{
      1.470143, 0.157545, 0.002712},{1.470143, 0.157867, 0.001373}}],
    Polygon[{{1.472723, 0.157137, 0.002712},{1.472560, 0.156635, 0.003984},{
      1.470143, 0.157018, 0.003984},{1.470143, 0.157545, 0.002712}}],
    Polygon[{{1.472560, 0.156635, 0.003984},{1.472337, 0.155951, 0.005159},{
      1.470143, 0.156299, 0.005159},{1.470143, 0.157018, 0.003984}}],
    Polygon[{{1.472337, 0.155951, 0.005159},{1.472061, 0.155100, 0.006206},{
      1.470143, 0.155404, 0.006206},{1.470143, 0.156299, 0.005159}}],
    Polygon[{{1.472061, 0.155100, 0.006206},{1.471738, 0.154104, 0.007100},{
      1.470143, 0.154357, 0.007100},{1.470143, 0.155404, 0.006206}}],
    Polygon[{{1.471738, 0.154104, 0.007100},{1.471375, 0.152988, 0.007820},{
      1.470143, 0.153183, 0.007820},{1.470143, 0.154357, 0.007100}}],
    Polygon[{{1.471375, 0.152988, 0.007820},{1.470981, 0.151778, 0.008347},{
      1.470143, 0.151910, 0.008347},{1.470143, 0.153183, 0.007820}}],
    Polygon[{{1.470981, 0.151778, 0.008347},{1.470568, 0.150504, 0.008668},{
      1.470143, 0.150571, 0.008668},{1.470143, 0.151910, 0.008347}}],
    Polygon[{{1.470143, 0.150571, -0.008668},{1.470143, 0.151910, -0.008347},{
      1.469305, 0.151778, -0.008347},{1.469719, 0.150504, -0.008668}}],
    Polygon[{{1.470143, 0.151910, -0.008347},{1.470143, 0.153183, -0.007820},{
      1.468912, 0.152988, -0.007820},{1.469305, 0.151778, -0.008347}}],
    Polygon[{{1.470143, 0.153183, -0.007820},{1.470143, 0.154357, -0.007100},{
      1.468549, 0.154104, -0.007100},{1.468912, 0.152988, -0.007820}}],
    Polygon[{{1.470143, 0.154357, -0.007100},{1.470143, 0.155404, -0.006206},{
      1.468226, 0.155100, -0.006206},{1.468549, 0.154104, -0.007100}}],
    Polygon[{{1.470143, 0.155404, -0.006206},{1.470143, 0.156299, -0.005159},{
      1.467949, 0.155951, -0.005159},{1.468226, 0.155100, -0.006206}}],
    Polygon[{{1.470143, 0.156299, -0.005159},{1.470143, 0.157018, -0.003984},{
      1.467727, 0.156635, -0.003984},{1.467949, 0.155951, -0.005159}}],
    Polygon[{{1.470143, 0.157018, -0.003984},{1.470143, 0.157545, -0.002712},{
      1.467564, 0.157137, -0.002712},{1.467727, 0.156635, -0.003984}}],
    Polygon[{{1.470143, 0.157545, -0.002712},{1.470143, 0.157867, -0.001373},{
      1.467465, 0.157442, -0.001373},{1.467564, 0.157137, -0.002712}}],
    Polygon[{{1.470143, 0.157867, -0.001373},{1.470143, 0.157975, 0.000000},{
      1.467431, 0.157545, 0.000000},{1.467465, 0.157442, -0.001373}}],
    Polygon[{{1.470143, 0.157975, 0.000000},{1.470143, 0.157867, 0.001373},{
      1.467465, 0.157442, 0.001373},{1.467431, 0.157545, 0.000000}}],
    Polygon[{{1.470143, 0.157867, 0.001373},{1.470143, 0.157545, 0.002712},{
      1.467564, 0.157137, 0.002712},{1.467465, 0.157442, 0.001373}}],
    Polygon[{{1.470143, 0.157545, 0.002712},{1.470143, 0.157018, 0.003984},{
      1.467727, 0.156635, 0.003984},{1.467564, 0.157137, 0.002712}}],
    Polygon[{{1.470143, 0.157018, 0.003984},{1.470143, 0.156299, 0.005159},{
      1.467949, 0.155951, 0.005159},{1.467727, 0.156635, 0.003984}}],
    Polygon[{{1.470143, 0.156299, 0.005159},{1.470143, 0.155404, 0.006206},{
      1.468226, 0.155100, 0.006206},{1.467949, 0.155951, 0.005159}}],
    Polygon[{{1.470143, 0.155404, 0.006206},{1.470143, 0.154357, 0.007100},{
      1.468549, 0.154104, 0.007100},{1.468226, 0.155100, 0.006206}}],
    Polygon[{{1.470143, 0.154357, 0.007100},{1.470143, 0.153183, 0.007820},{
      1.468912, 0.152988, 0.007820},{1.468549, 0.154104, 0.007100}}],
    Polygon[{{1.470143, 0.153183, 0.007820},{1.470143, 0.151910, 0.008347},{
      1.469305, 0.151778, 0.008347},{1.468912, 0.152988, 0.007820}}],
    Polygon[{{1.470143, 0.151910, 0.008347},{1.470143, 0.150571, 0.008668},{
      1.469719, 0.150504, 0.008668},{1.469305, 0.151778, 0.008347}}],
    Polygon[{{1.469719, 0.150504, -0.008668},{1.469305, 0.151778, -0.008347},{
      1.468549, 0.151392, -0.008347},{1.469337, 0.150309, -0.008668}}],
    Polygon[{{1.469305, 0.151778, -0.008347},{1.468912, 0.152988, -0.007820},{
      1.467801, 0.152422, -0.007820},{1.468549, 0.151392, -0.008347}}],
    Polygon[{{1.468912, 0.152988, -0.007820},{1.468549, 0.154104, -0.007100},{
      1.467111, 0.153372, -0.007100},{1.467801, 0.152422, -0.007820}}],
    Polygon[{{1.468549, 0.154104, -0.007100},{1.468226, 0.155100, -0.006206},{
      1.466496, 0.154219, -0.006206},{1.467111, 0.153372, -0.007100}}],
    Polygon[{{1.468226, 0.155100, -0.006206},{1.467949, 0.155951, -0.005159},{
      1.465970, 0.154943, -0.005159},{1.466496, 0.154219, -0.006206}}],
    Polygon[{{1.467949, 0.155951, -0.005159},{1.467727, 0.156635, -0.003984},{
      1.465547, 0.155525, -0.003984},{1.465970, 0.154943, -0.005159}}],
    Polygon[{{1.467727, 0.156635, -0.003984},{1.467564, 0.157137, -0.002712},{
      1.465237, 0.155951, -0.002712},{1.465547, 0.155525, -0.003984}}],
    Polygon[{{1.467564, 0.157137, -0.002712},{1.467465, 0.157442, -0.001373},{
      1.465048, 0.156211, -0.001373},{1.465237, 0.155951, -0.002712}}],
    Polygon[{{1.467465, 0.157442, -0.001373},{1.467431, 0.157545, 0.000000},{
      1.464985, 0.156299, 0.000000},{1.465048, 0.156211, -0.001373}}],
    Polygon[{{1.467431, 0.157545, 0.000000},{1.467465, 0.157442, 0.001373},{
      1.465048, 0.156211, 0.001373},{1.464985, 0.156299, 0.000000}}],
    Polygon[{{1.467465, 0.157442, 0.001373},{1.467564, 0.157137, 0.002712},{
      1.465237, 0.155951, 0.002712},{1.465048, 0.156211, 0.001373}}],
    Polygon[{{1.467564, 0.157137, 0.002712},{1.467727, 0.156635, 0.003984},{
      1.465547, 0.155525, 0.003984},{1.465237, 0.155951, 0.002712}}],
    Polygon[{{1.467727, 0.156635, 0.003984},{1.467949, 0.155951, 0.005159},{
      1.465970, 0.154943, 0.005159},{1.465547, 0.155525, 0.003984}}],
    Polygon[{{1.467949, 0.155951, 0.005159},{1.468226, 0.155100, 0.006206},{
      1.466496, 0.154219, 0.006206},{1.465970, 0.154943, 0.005159}}],
    Polygon[{{1.468226, 0.155100, 0.006206},{1.468549, 0.154104, 0.007100},{
      1.467111, 0.153372, 0.007100},{1.466496, 0.154219, 0.006206}}],
    Polygon[{{1.468549, 0.154104, 0.007100},{1.468912, 0.152988, 0.007820},{
      1.467801, 0.152422, 0.007820},{1.467111, 0.153372, 0.007100}}],
    Polygon[{{1.468912, 0.152988, 0.007820},{1.469305, 0.151778, 0.008347},{
      1.468549, 0.151392, 0.008347},{1.467801, 0.152422, 0.007820}}],
    Polygon[{{1.469305, 0.151778, 0.008347},{1.469719, 0.150504, 0.008668},{
      1.469337, 0.150309, 0.008668},{1.468549, 0.151392, 0.008347}}],
    Polygon[{{1.469337, 0.150309, -0.008668},{1.468549, 0.151392, -0.008347},{
      1.467949, 0.150792, -0.008347},{1.469033, 0.150005, -0.008668}}],
    Polygon[{{1.468549, 0.151392, -0.008347},{1.467801, 0.152422, -0.007820},{
      1.466920, 0.151540, -0.007820},{1.467949, 0.150792, -0.008347}}],
    Polygon[{{1.467801, 0.152422, -0.007820},{1.467111, 0.153372, -0.007100},{
      1.465970, 0.152231, -0.007100},{1.466920, 0.151540, -0.007820}}],
    Polygon[{{1.467111, 0.153372, -0.007100},{1.466496, 0.154219, -0.006206},{
      1.465123, 0.152846, -0.006206},{1.465970, 0.152231, -0.007100}}],
    Polygon[{{1.466496, 0.154219, -0.006206},{1.465970, 0.154943, -0.005159},{
      1.464399, 0.153372, -0.005159},{1.465123, 0.152846, -0.006206}}],
    Polygon[{{1.465970, 0.154943, -0.005159},{1.465547, 0.155525, -0.003984},{
      1.463817, 0.153795, -0.003984},{1.464399, 0.153372, -0.005159}}],
    Polygon[{{1.465547, 0.155525, -0.003984},{1.465237, 0.155951, -0.002712},{
      1.463391, 0.154104, -0.002712},{1.463817, 0.153795, -0.003984}}],
    Polygon[{{1.465237, 0.155951, -0.002712},{1.465048, 0.156211, -0.001373},{
      1.463131, 0.154293, -0.001373},{1.463391, 0.154104, -0.002712}}],
    Polygon[{{1.465048, 0.156211, -0.001373},{1.464985, 0.156299, 0.000000},{
      1.463043, 0.154357, 0.000000},{1.463131, 0.154293, -0.001373}}],
    Polygon[{{1.464985, 0.156299, 0.000000},{1.465048, 0.156211, 0.001373},{
      1.463131, 0.154293, 0.001373},{1.463043, 0.154357, 0.000000}}],
    Polygon[{{1.465048, 0.156211, 0.001373},{1.465237, 0.155951, 0.002712},{
      1.463391, 0.154104, 0.002712},{1.463131, 0.154293, 0.001373}}],
    Polygon[{{1.465237, 0.155951, 0.002712},{1.465547, 0.155525, 0.003984},{
      1.463817, 0.153795, 0.003984},{1.463391, 0.154104, 0.002712}}],
    Polygon[{{1.465547, 0.155525, 0.003984},{1.465970, 0.154943, 0.005159},{
      1.464399, 0.153372, 0.005159},{1.463817, 0.153795, 0.003984}}],
    Polygon[{{1.465970, 0.154943, 0.005159},{1.466496, 0.154219, 0.006206},{
      1.465123, 0.152846, 0.006206},{1.464399, 0.153372, 0.005159}}],
    Polygon[{{1.466496, 0.154219, 0.006206},{1.467111, 0.153372, 0.007100},{
      1.465970, 0.152231, 0.007100},{1.465123, 0.152846, 0.006206}}],
    Polygon[{{1.467111, 0.153372, 0.007100},{1.467801, 0.152422, 0.007820},{
      1.466920, 0.151540, 0.007820},{1.465970, 0.152231, 0.007100}}],
    Polygon[{{1.467801, 0.152422, 0.007820},{1.468549, 0.151392, 0.008347},{
      1.467949, 0.150792, 0.008347},{1.466920, 0.151540, 0.007820}}],
    Polygon[{{1.468549, 0.151392, 0.008347},{1.469337, 0.150309, 0.008668},{
      1.469033, 0.150005, 0.008668},{1.467949, 0.150792, 0.008347}}],
    Polygon[{{1.469033, 0.150005, -0.008668},{1.467949, 0.150792, -0.008347},{
      1.467564, 0.150036, -0.008347},{1.468838, 0.149623, -0.008668}}],
    Polygon[{{1.467949, 0.150792, -0.008347},{1.466920, 0.151540, -0.007820},{
      1.466354, 0.150430, -0.007820},{1.467564, 0.150036, -0.008347}}],
    Polygon[{{1.466920, 0.151540, -0.007820},{1.465970, 0.152231, -0.007100},{
      1.465237, 0.150792, -0.007100},{1.466354, 0.150430, -0.007820}}],
    Polygon[{{1.465970, 0.152231, -0.007100},{1.465123, 0.152846, -0.006206},{
      1.464241, 0.151116, -0.006206},{1.465237, 0.150792, -0.007100}}],
    Polygon[{{1.465123, 0.152846, -0.006206},{1.464399, 0.153372, -0.005159},{
      1.463391, 0.151392, -0.005159},{1.464241, 0.151116, -0.006206}}],
    Polygon[{{1.464399, 0.153372, -0.005159},{1.463817, 0.153795, -0.003984},{
      1.462706, 0.151615, -0.003984},{1.463391, 0.151392, -0.005159}}],
    Polygon[{{1.463817, 0.153795, -0.003984},{1.463391, 0.154104, -0.002712},{
      1.462205, 0.151778, -0.002712},{1.462706, 0.151615, -0.003984}}],
    Polygon[{{1.463391, 0.154104, -0.002712},{1.463131, 0.154293, -0.001373},{
      1.461899, 0.151877, -0.001373},{1.462205, 0.151778, -0.002712}}],
    Polygon[{{1.463131, 0.154293, -0.001373},{1.463043, 0.154357, 0.000000},{
      1.461797, 0.151910, 0.000000},{1.461899, 0.151877, -0.001373}}],
    Polygon[{{1.463043, 0.154357, 0.000000},{1.463131, 0.154293, 0.001373},{
      1.461899, 0.151877, 0.001373},{1.461797, 0.151910, 0.000000}}],
    Polygon[{{1.463131, 0.154293, 0.001373},{1.463391, 0.154104, 0.002712},{
      1.462205, 0.151778, 0.002712},{1.461899, 0.151877, 0.001373}}],
    Polygon[{{1.463391, 0.154104, 0.002712},{1.463817, 0.153795, 0.003984},{
      1.462706, 0.151615, 0.003984},{1.462205, 0.151778, 0.002712}}],
    Polygon[{{1.463817, 0.153795, 0.003984},{1.464399, 0.153372, 0.005159},{
      1.463391, 0.151392, 0.005159},{1.462706, 0.151615, 0.003984}}],
    Polygon[{{1.464399, 0.153372, 0.005159},{1.465123, 0.152846, 0.006206},{
      1.464241, 0.151116, 0.006206},{1.463391, 0.151392, 0.005159}}],
    Polygon[{{1.465123, 0.152846, 0.006206},{1.465970, 0.152231, 0.007100},{
      1.465237, 0.150792, 0.007100},{1.464241, 0.151116, 0.006206}}],
    Polygon[{{1.465970, 0.152231, 0.007100},{1.466920, 0.151540, 0.007820},{
      1.466354, 0.150430, 0.007820},{1.465237, 0.150792, 0.007100}}],
    Polygon[{{1.466920, 0.151540, 0.007820},{1.467949, 0.150792, 0.008347},{
      1.467564, 0.150036, 0.008347},{1.466354, 0.150430, 0.007820}}],
    Polygon[{{1.467949, 0.150792, 0.008347},{1.469033, 0.150005, 0.008668},{
      1.468838, 0.149623, 0.008668},{1.467564, 0.150036, 0.008347}}],
    Polygon[{{1.468838, 0.149623, -0.008668},{1.467564, 0.150036, -0.008347},{
      1.467431, 0.149198, -0.008347},{1.468771, 0.149198, -0.008668}}],
    Polygon[{{1.467564, 0.150036, -0.008347},{1.466354, 0.150430, -0.007820},{
      1.466159, 0.149198, -0.007820},{1.467431, 0.149198, -0.008347}}],
    Polygon[{{1.466354, 0.150430, -0.007820},{1.465237, 0.150792, -0.007100},{
      1.464985, 0.149198, -0.007100},{1.466159, 0.149198, -0.007820}}],
    Polygon[{{1.465237, 0.150792, -0.007100},{1.464241, 0.151116, -0.006206},{
      1.463938, 0.149198, -0.006206},{1.464985, 0.149198, -0.007100}}],
    Polygon[{{1.464241, 0.151116, -0.006206},{1.463391, 0.151392, -0.005159},{
      1.463043, 0.149198, -0.005159},{1.463938, 0.149198, -0.006206}}],
    Polygon[{{1.463391, 0.151392, -0.005159},{1.462706, 0.151615, -0.003984},{
      1.462324, 0.149198, -0.003984},{1.463043, 0.149198, -0.005159}}],
    Polygon[{{1.462706, 0.151615, -0.003984},{1.462205, 0.151778, -0.002712},{
      1.461797, 0.149198, -0.002712},{1.462324, 0.149198, -0.003984}}],
    Polygon[{{1.462205, 0.151778, -0.002712},{1.461899, 0.151877, -0.001373},{
      1.461475, 0.149198, -0.001373},{1.461797, 0.149198, -0.002712}}],
    Polygon[{{1.461899, 0.151877, -0.001373},{1.461797, 0.151910, 0.000000},{
      1.461367, 0.149198, 0.000000},{1.461475, 0.149198, -0.001373}}],
    Polygon[{{1.461797, 0.151910, 0.000000},{1.461899, 0.151877, 0.001373},{
      1.461475, 0.149198, 0.001373},{1.461367, 0.149198, 0.000000}}],
    Polygon[{{1.461899, 0.151877, 0.001373},{1.462205, 0.151778, 0.002712},{
      1.461797, 0.149198, 0.002712},{1.461475, 0.149198, 0.001373}}],
    Polygon[{{1.462205, 0.151778, 0.002712},{1.462706, 0.151615, 0.003984},{
      1.462324, 0.149198, 0.003984},{1.461797, 0.149198, 0.002712}}],
    Polygon[{{1.462706, 0.151615, 0.003984},{1.463391, 0.151392, 0.005159},{
      1.463043, 0.149198, 0.005159},{1.462324, 0.149198, 0.003984}}],
    Polygon[{{1.463391, 0.151392, 0.005159},{1.464241, 0.151116, 0.006206},{
      1.463938, 0.149198, 0.006206},{1.463043, 0.149198, 0.005159}}],
    Polygon[{{1.464241, 0.151116, 0.006206},{1.465237, 0.150792, 0.007100},{
      1.464985, 0.149198, 0.007100},{1.463938, 0.149198, 0.006206}}],
    Polygon[{{1.465237, 0.150792, 0.007100},{1.466354, 0.150430, 0.007820},{
      1.466159, 0.149198, 0.007820},{1.464985, 0.149198, 0.007100}}],
    Polygon[{{1.466354, 0.150430, 0.007820},{1.467564, 0.150036, 0.008347},{
      1.467431, 0.149198, 0.008347},{1.466159, 0.149198, 0.007820}}],
    Polygon[{{1.467564, 0.150036, 0.008347},{1.468838, 0.149623, 0.008668},{
      1.468771, 0.149198, 0.008668},{1.467431, 0.149198, 0.008347}}],
    Polygon[{{1.468771, 0.149198, -0.008668},{1.467431, 0.149198, -0.008347},{
      1.467564, 0.148360, -0.008347},{1.468838, 0.148774, -0.008668}}],
    Polygon[{{1.467431, 0.149198, -0.008347},{1.466159, 0.149198, -0.007820},{
      1.466354, 0.147967, -0.007820},{1.467564, 0.148360, -0.008347}}],
    Polygon[{{1.466159, 0.149198, -0.007820},{1.464985, 0.149198, -0.007100},{
      1.465237, 0.147604, -0.007100},{1.466354, 0.147967, -0.007820}}],
    Polygon[{{1.464985, 0.149198, -0.007100},{1.463938, 0.149198, -0.006206},{
      1.464241, 0.147281, -0.006206},{1.465237, 0.147604, -0.007100}}],
    Polygon[{{1.463938, 0.149198, -0.006206},{1.463043, 0.149198, -0.005159},{
      1.463391, 0.147004, -0.005159},{1.464241, 0.147281, -0.006206}}],
    Polygon[{{1.463043, 0.149198, -0.005159},{1.462324, 0.149198, -0.003984},{
      1.462706, 0.146782, -0.003984},{1.463391, 0.147004, -0.005159}}],
    Polygon[{{1.462324, 0.149198, -0.003984},{1.461797, 0.149198, -0.002712},{
      1.462205, 0.146619, -0.002712},{1.462706, 0.146782, -0.003984}}],
    Polygon[{{1.461797, 0.149198, -0.002712},{1.461475, 0.149198, -0.001373},{
      1.461899, 0.146520, -0.001373},{1.462205, 0.146619, -0.002712}}],
    Polygon[{{1.461475, 0.149198, -0.001373},{1.461367, 0.149198, 0.000000},{
      1.461797, 0.146486, 0.000000},{1.461899, 0.146520, -0.001373}}],
    Polygon[{{1.461367, 0.149198, 0.000000},{1.461475, 0.149198, 0.001373},{
      1.461899, 0.146520, 0.001373},{1.461797, 0.146486, 0.000000}}],
    Polygon[{{1.461475, 0.149198, 0.001373},{1.461797, 0.149198, 0.002712},{
      1.462205, 0.146619, 0.002712},{1.461899, 0.146520, 0.001373}}],
    Polygon[{{1.461797, 0.149198, 0.002712},{1.462324, 0.149198, 0.003984},{
      1.462706, 0.146782, 0.003984},{1.462205, 0.146619, 0.002712}}],
    Polygon[{{1.462324, 0.149198, 0.003984},{1.463043, 0.149198, 0.005159},{
      1.463391, 0.147004, 0.005159},{1.462706, 0.146782, 0.003984}}],
    Polygon[{{1.463043, 0.149198, 0.005159},{1.463938, 0.149198, 0.006206},{
      1.464241, 0.147281, 0.006206},{1.463391, 0.147004, 0.005159}}],
    Polygon[{{1.463938, 0.149198, 0.006206},{1.464985, 0.149198, 0.007100},{
      1.465237, 0.147604, 0.007100},{1.464241, 0.147281, 0.006206}}],
    Polygon[{{1.464985, 0.149198, 0.007100},{1.466159, 0.149198, 0.007820},{
      1.466354, 0.147967, 0.007820},{1.465237, 0.147604, 0.007100}}],
    Polygon[{{1.466159, 0.149198, 0.007820},{1.467431, 0.149198, 0.008347},{
      1.467564, 0.148360, 0.008347},{1.466354, 0.147967, 0.007820}}],
    Polygon[{{1.467431, 0.149198, 0.008347},{1.468771, 0.149198, 0.008668},{
      1.468838, 0.148774, 0.008668},{1.467564, 0.148360, 0.008347}}],
    Polygon[{{1.468838, 0.148774, -0.008668},{1.467564, 0.148360, -0.008347},{
      1.467949, 0.147604, -0.008347},{1.469033, 0.148391, -0.008668}}],
    Polygon[{{1.467564, 0.148360, -0.008347},{1.466354, 0.147967, -0.007820},{
      1.466920, 0.146856, -0.007820},{1.467949, 0.147604, -0.008347}}],
    Polygon[{{1.466354, 0.147967, -0.007820},{1.465237, 0.147604, -0.007100},{
      1.465970, 0.146166, -0.007100},{1.466920, 0.146856, -0.007820}}],
    Polygon[{{1.465237, 0.147604, -0.007100},{1.464241, 0.147281, -0.006206},{
      1.465123, 0.145551, -0.006206},{1.465970, 0.146166, -0.007100}}],
    Polygon[{{1.464241, 0.147281, -0.006206},{1.463391, 0.147004, -0.005159},{
      1.464399, 0.145025, -0.005159},{1.465123, 0.145551, -0.006206}}],
    Polygon[{{1.463391, 0.147004, -0.005159},{1.462706, 0.146782, -0.003984},{
      1.463817, 0.144602, -0.003984},{1.464399, 0.145025, -0.005159}}],
    Polygon[{{1.462706, 0.146782, -0.003984},{1.462205, 0.146619, -0.002712},{
      1.463391, 0.144292, -0.002712},{1.463817, 0.144602, -0.003984}}],
    Polygon[{{1.462205, 0.146619, -0.002712},{1.461899, 0.146520, -0.001373},{
      1.463131, 0.144103, -0.001373},{1.463391, 0.144292, -0.002712}}],
    Polygon[{{1.461899, 0.146520, -0.001373},{1.461797, 0.146486, 0.000000},{
      1.463043, 0.144040, 0.000000},{1.463131, 0.144103, -0.001373}}],
    Polygon[{{1.461797, 0.146486, 0.000000},{1.461899, 0.146520, 0.001373},{
      1.463131, 0.144103, 0.001373},{1.463043, 0.144040, 0.000000}}],
    Polygon[{{1.461899, 0.146520, 0.001373},{1.462205, 0.146619, 0.002712},{
      1.463391, 0.144292, 0.002712},{1.463131, 0.144103, 0.001373}}],
    Polygon[{{1.462205, 0.146619, 0.002712},{1.462706, 0.146782, 0.003984},{
      1.463817, 0.144602, 0.003984},{1.463391, 0.144292, 0.002712}}],
    Polygon[{{1.462706, 0.146782, 0.003984},{1.463391, 0.147004, 0.005159},{
      1.464399, 0.145025, 0.005159},{1.463817, 0.144602, 0.003984}}],
    Polygon[{{1.463391, 0.147004, 0.005159},{1.464241, 0.147281, 0.006206},{
      1.465123, 0.145551, 0.006206},{1.464399, 0.145025, 0.005159}}],
    Polygon[{{1.464241, 0.147281, 0.006206},{1.465237, 0.147604, 0.007100},{
      1.465970, 0.146166, 0.007100},{1.465123, 0.145551, 0.006206}}],
    Polygon[{{1.465237, 0.147604, 0.007100},{1.466354, 0.147967, 0.007820},{
      1.466920, 0.146856, 0.007820},{1.465970, 0.146166, 0.007100}}],
    Polygon[{{1.466354, 0.147967, 0.007820},{1.467564, 0.148360, 0.008347},{
      1.467949, 0.147604, 0.008347},{1.466920, 0.146856, 0.007820}}],
    Polygon[{{1.467564, 0.148360, 0.008347},{1.468838, 0.148774, 0.008668},{
      1.469033, 0.148391, 0.008668},{1.467949, 0.147604, 0.008347}}],
    Polygon[{{1.469033, 0.148391, -0.008668},{1.467949, 0.147604, -0.008347},{
      1.468549, 0.147004, -0.008347},{1.469337, 0.148088, -0.008668}}],
    Polygon[{{1.467949, 0.147604, -0.008347},{1.466920, 0.146856, -0.007820},{
      1.467801, 0.145975, -0.007820},{1.468549, 0.147004, -0.008347}}],
    Polygon[{{1.466920, 0.146856, -0.007820},{1.465970, 0.146166, -0.007100},{
      1.467111, 0.145025, -0.007100},{1.467801, 0.145975, -0.007820}}],
    Polygon[{{1.465970, 0.146166, -0.007100},{1.465123, 0.145551, -0.006206},{
      1.466496, 0.144178, -0.006206},{1.467111, 0.145025, -0.007100}}],
    Polygon[{{1.465123, 0.145551, -0.006206},{1.464399, 0.145025, -0.005159},{
      1.465970, 0.143454, -0.005159},{1.466496, 0.144178, -0.006206}}],
    Polygon[{{1.464399, 0.145025, -0.005159},{1.463817, 0.144602, -0.003984},{
      1.465547, 0.142872, -0.003984},{1.465970, 0.143454, -0.005159}}],
    Polygon[{{1.463817, 0.144602, -0.003984},{1.463391, 0.144292, -0.002712},{
      1.465237, 0.142446, -0.002712},{1.465547, 0.142872, -0.003984}}],
    Polygon[{{1.463391, 0.144292, -0.002712},{1.463131, 0.144103, -0.001373},{
      1.465048, 0.142186, -0.001373},{1.465237, 0.142446, -0.002712}}],
    Polygon[{{1.463131, 0.144103, -0.001373},{1.463043, 0.144040, 0.000000},{
      1.464985, 0.142098, 0.000000},{1.465048, 0.142186, -0.001373}}],
    Polygon[{{1.463043, 0.144040, 0.000000},{1.463131, 0.144103, 0.001373},{
      1.465048, 0.142186, 0.001373},{1.464985, 0.142098, 0.000000}}],
    Polygon[{{1.463131, 0.144103, 0.001373},{1.463391, 0.144292, 0.002712},{
      1.465237, 0.142446, 0.002712},{1.465048, 0.142186, 0.001373}}],
    Polygon[{{1.463391, 0.144292, 0.002712},{1.463817, 0.144602, 0.003984},{
      1.465547, 0.142872, 0.003984},{1.465237, 0.142446, 0.002712}}],
    Polygon[{{1.463817, 0.144602, 0.003984},{1.464399, 0.145025, 0.005159},{
      1.465970, 0.143454, 0.005159},{1.465547, 0.142872, 0.003984}}],
    Polygon[{{1.464399, 0.145025, 0.005159},{1.465123, 0.145551, 0.006206},{
      1.466496, 0.144178, 0.006206},{1.465970, 0.143454, 0.005159}}],
    Polygon[{{1.465123, 0.145551, 0.006206},{1.465970, 0.146166, 0.007100},{
      1.467111, 0.145025, 0.007100},{1.466496, 0.144178, 0.006206}}],
    Polygon[{{1.465970, 0.146166, 0.007100},{1.466920, 0.146856, 0.007820},{
      1.467801, 0.145975, 0.007820},{1.467111, 0.145025, 0.007100}}],
    Polygon[{{1.466920, 0.146856, 0.007820},{1.467949, 0.147604, 0.008347},{
      1.468549, 0.147004, 0.008347},{1.467801, 0.145975, 0.007820}}],
    Polygon[{{1.467949, 0.147604, 0.008347},{1.469033, 0.148391, 0.008668},{
      1.469337, 0.148088, 0.008668},{1.468549, 0.147004, 0.008347}}],
    Polygon[{{1.469337, 0.148088, -0.008668},{1.468549, 0.147004, -0.008347},{
      1.469305, 0.146619, -0.008347},{1.469719, 0.147893, -0.008668}}],
    Polygon[{{1.468549, 0.147004, -0.008347},{1.467801, 0.145975, -0.007820},{
      1.468912, 0.145409, -0.007820},{1.469305, 0.146619, -0.008347}}],
    Polygon[{{1.467801, 0.145975, -0.007820},{1.467111, 0.145025, -0.007100},{
      1.468549, 0.144292, -0.007100},{1.468912, 0.145409, -0.007820}}],
    Polygon[{{1.467111, 0.145025, -0.007100},{1.466496, 0.144178, -0.006206},{
      1.468226, 0.143296, -0.006206},{1.468549, 0.144292, -0.007100}}],
    Polygon[{{1.466496, 0.144178, -0.006206},{1.465970, 0.143454, -0.005159},{
      1.467949, 0.142446, -0.005159},{1.468226, 0.143296, -0.006206}}],
    Polygon[{{1.465970, 0.143454, -0.005159},{1.465547, 0.142872, -0.003984},{
      1.467727, 0.141761, -0.003984},{1.467949, 0.142446, -0.005159}}],
    Polygon[{{1.465547, 0.142872, -0.003984},{1.465237, 0.142446, -0.002712},{
      1.467564, 0.141260, -0.002712},{1.467727, 0.141761, -0.003984}}],
    Polygon[{{1.465237, 0.142446, -0.002712},{1.465048, 0.142186, -0.001373},{
      1.467465, 0.140954, -0.001373},{1.467564, 0.141260, -0.002712}}],
    Polygon[{{1.465048, 0.142186, -0.001373},{1.464985, 0.142098, 0.000000},{
      1.467431, 0.140852, 0.000000},{1.467465, 0.140954, -0.001373}}],
    Polygon[{{1.464985, 0.142098, 0.000000},{1.465048, 0.142186, 0.001373},{
      1.467465, 0.140954, 0.001373},{1.467431, 0.140852, 0.000000}}],
    Polygon[{{1.465048, 0.142186, 0.001373},{1.465237, 0.142446, 0.002712},{
      1.467564, 0.141260, 0.002712},{1.467465, 0.140954, 0.001373}}],
    Polygon[{{1.465237, 0.142446, 0.002712},{1.465547, 0.142872, 0.003984},{
      1.467727, 0.141761, 0.003984},{1.467564, 0.141260, 0.002712}}],
    Polygon[{{1.465547, 0.142872, 0.003984},{1.465970, 0.143454, 0.005159},{
      1.467949, 0.142446, 0.005159},{1.467727, 0.141761, 0.003984}}],
    Polygon[{{1.465970, 0.143454, 0.005159},{1.466496, 0.144178, 0.006206},{
      1.468226, 0.143296, 0.006206},{1.467949, 0.142446, 0.005159}}],
    Polygon[{{1.466496, 0.144178, 0.006206},{1.467111, 0.145025, 0.007100},{
      1.468549, 0.144292, 0.007100},{1.468226, 0.143296, 0.006206}}],
    Polygon[{{1.467111, 0.145025, 0.007100},{1.467801, 0.145975, 0.007820},{
      1.468912, 0.145409, 0.007820},{1.468549, 0.144292, 0.007100}}],
    Polygon[{{1.467801, 0.145975, 0.007820},{1.468549, 0.147004, 0.008347},{
      1.469305, 0.146619, 0.008347},{1.468912, 0.145409, 0.007820}}],
    Polygon[{{1.468549, 0.147004, 0.008347},{1.469337, 0.148088, 0.008668},{
      1.469719, 0.147893, 0.008668},{1.469305, 0.146619, 0.008347}}],
    Polygon[{{1.469719, 0.147893, -0.008668},{1.469305, 0.146619, -0.008347},{
      1.470143, 0.146486, -0.008347},{1.470143, 0.147825, -0.008668}}],
    Polygon[{{1.469305, 0.146619, -0.008347},{1.468912, 0.145409, -0.007820},{
      1.470143, 0.145214, -0.007820},{1.470143, 0.146486, -0.008347}}],
    Polygon[{{1.468912, 0.145409, -0.007820},{1.468549, 0.144292, -0.007100},{
      1.470143, 0.144040, -0.007100},{1.470143, 0.145214, -0.007820}}],
    Polygon[{{1.468549, 0.144292, -0.007100},{1.468226, 0.143296, -0.006206},{
      1.470143, 0.142993, -0.006206},{1.470143, 0.144040, -0.007100}}],
    Polygon[{{1.468226, 0.143296, -0.006206},{1.467949, 0.142446, -0.005159},{
      1.470143, 0.142098, -0.005159},{1.470143, 0.142993, -0.006206}}],
    Polygon[{{1.467949, 0.142446, -0.005159},{1.467727, 0.141761, -0.003984},{
      1.470143, 0.141379, -0.003984},{1.470143, 0.142098, -0.005159}}],
    Polygon[{{1.467727, 0.141761, -0.003984},{1.467564, 0.141260, -0.002712},{
      1.470143, 0.140852, -0.002712},{1.470143, 0.141379, -0.003984}}],
    Polygon[{{1.467564, 0.141260, -0.002712},{1.467465, 0.140954, -0.001373},{
      1.470143, 0.140530, -0.001373},{1.470143, 0.140852, -0.002712}}],
    Polygon[{{1.467465, 0.140954, -0.001373},{1.467431, 0.140852, 0.000000},{
      1.470143, 0.140422, 0.000000},{1.470143, 0.140530, -0.001373}}],
    Polygon[{{1.467431, 0.140852, 0.000000},{1.467465, 0.140954, 0.001373},{
      1.470143, 0.140530, 0.001373},{1.470143, 0.140422, 0.000000}}],
    Polygon[{{1.467465, 0.140954, 0.001373},{1.467564, 0.141260, 0.002712},{
      1.470143, 0.140852, 0.002712},{1.470143, 0.140530, 0.001373}}],
    Polygon[{{1.467564, 0.141260, 0.002712},{1.467727, 0.141761, 0.003984},{
      1.470143, 0.141379, 0.003984},{1.470143, 0.140852, 0.002712}}],
    Polygon[{{1.467727, 0.141761, 0.003984},{1.467949, 0.142446, 0.005159},{
      1.470143, 0.142098, 0.005159},{1.470143, 0.141379, 0.003984}}],
    Polygon[{{1.467949, 0.142446, 0.005159},{1.468226, 0.143296, 0.006206},{
      1.470143, 0.142993, 0.006206},{1.470143, 0.142098, 0.005159}}],
    Polygon[{{1.468226, 0.143296, 0.006206},{1.468549, 0.144292, 0.007100},{
      1.470143, 0.144040, 0.007100},{1.470143, 0.142993, 0.006206}}],
    Polygon[{{1.468549, 0.144292, 0.007100},{1.468912, 0.145409, 0.007820},{
      1.470143, 0.145214, 0.007820},{1.470143, 0.144040, 0.007100}}],
    Polygon[{{1.468912, 0.145409, 0.007820},{1.469305, 0.146619, 0.008347},{
      1.470143, 0.146486, 0.008347},{1.470143, 0.145214, 0.007820}}],
    Polygon[{{1.469305, 0.146619, 0.008347},{1.469719, 0.147893, 0.008668},{
      1.470143, 0.147825, 0.008668},{1.470143, 0.146486, 0.008347}}],
    Polygon[{{1.470143, 0.147825, -0.008668},{1.470143, 0.146486, -0.008347},{
      1.470981, 0.146619, -0.008347},{1.470568, 0.147893, -0.008668}}],
    Polygon[{{1.470143, 0.146486, -0.008347},{1.470143, 0.145214, -0.007820},{
      1.471375, 0.145409, -0.007820},{1.470981, 0.146619, -0.008347}}],
    Polygon[{{1.470143, 0.145214, -0.007820},{1.470143, 0.144040, -0.007100},{
      1.471738, 0.144292, -0.007100},{1.471375, 0.145409, -0.007820}}],
    Polygon[{{1.470143, 0.144040, -0.007100},{1.470143, 0.142993, -0.006206},{
      1.472061, 0.143296, -0.006206},{1.471738, 0.144292, -0.007100}}],
    Polygon[{{1.470143, 0.142993, -0.006206},{1.470143, 0.142098, -0.005159},{
      1.472337, 0.142446, -0.005159},{1.472061, 0.143296, -0.006206}}],
    Polygon[{{1.470143, 0.142098, -0.005159},{1.470143, 0.141379, -0.003984},{
      1.472560, 0.141761, -0.003984},{1.472337, 0.142446, -0.005159}}],
    Polygon[{{1.470143, 0.141379, -0.003984},{1.470143, 0.140852, -0.002712},{
      1.472723, 0.141260, -0.002712},{1.472560, 0.141761, -0.003984}}],
    Polygon[{{1.470143, 0.140852, -0.002712},{1.470143, 0.140530, -0.001373},{
      1.472822, 0.140954, -0.001373},{1.472723, 0.141260, -0.002712}}],
    Polygon[{{1.470143, 0.140530, -0.001373},{1.470143, 0.140422, 0.000000},{
      1.472855, 0.140852, 0.000000},{1.472822, 0.140954, -0.001373}}],
    Polygon[{{1.470143, 0.140422, 0.000000},{1.470143, 0.140530, 0.001373},{
      1.472822, 0.140954, 0.001373},{1.472855, 0.140852, 0.000000}}],
    Polygon[{{1.470143, 0.140530, 0.001373},{1.470143, 0.140852, 0.002712},{
      1.472723, 0.141260, 0.002712},{1.472822, 0.140954, 0.001373}}],
    Polygon[{{1.470143, 0.140852, 0.002712},{1.470143, 0.141379, 0.003984},{
      1.472560, 0.141761, 0.003984},{1.472723, 0.141260, 0.002712}}],
    Polygon[{{1.470143, 0.141379, 0.003984},{1.470143, 0.142098, 0.005159},{
      1.472337, 0.142446, 0.005159},{1.472560, 0.141761, 0.003984}}],
    Polygon[{{1.470143, 0.142098, 0.005159},{1.470143, 0.142993, 0.006206},{
      1.472061, 0.143296, 0.006206},{1.472337, 0.142446, 0.005159}}],
    Polygon[{{1.470143, 0.142993, 0.006206},{1.470143, 0.144040, 0.007100},{
      1.471738, 0.144292, 0.007100},{1.472061, 0.143296, 0.006206}}],
    Polygon[{{1.470143, 0.144040, 0.007100},{1.470143, 0.145214, 0.007820},{
      1.471375, 0.145409, 0.007820},{1.471738, 0.144292, 0.007100}}],
    Polygon[{{1.470143, 0.145214, 0.007820},{1.470143, 0.146486, 0.008347},{
      1.470981, 0.146619, 0.008347},{1.471375, 0.145409, 0.007820}}],
    Polygon[{{1.470143, 0.146486, 0.008347},{1.470143, 0.147825, 0.008668},{
      1.470568, 0.147893, 0.008668},{1.470981, 0.146619, 0.008347}}],
    Polygon[{{1.470568, 0.147893, -0.008668},{1.470981, 0.146619, -0.008347},{
      1.471738, 0.147004, -0.008347},{1.470950, 0.148088, -0.008668}}],
    Polygon[{{1.470981, 0.146619, -0.008347},{1.471375, 0.145409, -0.007820},{
      1.472485, 0.145975, -0.007820},{1.471738, 0.147004, -0.008347}}],
    Polygon[{{1.471375, 0.145409, -0.007820},{1.471738, 0.144292, -0.007100},{
      1.473176, 0.145025, -0.007100},{1.472485, 0.145975, -0.007820}}],
    Polygon[{{1.471738, 0.144292, -0.007100},{1.472061, 0.143296, -0.006206},{
      1.473791, 0.144178, -0.006206},{1.473176, 0.145025, -0.007100}}],
    Polygon[{{1.472061, 0.143296, -0.006206},{1.472337, 0.142446, -0.005159},{
      1.474317, 0.143454, -0.005159},{1.473791, 0.144178, -0.006206}}],
    Polygon[{{1.472337, 0.142446, -0.005159},{1.472560, 0.141761, -0.003984},{
      1.474740, 0.142872, -0.003984},{1.474317, 0.143454, -0.005159}}],
    Polygon[{{1.472560, 0.141761, -0.003984},{1.472723, 0.141260, -0.002712},{
      1.475050, 0.142446, -0.002712},{1.474740, 0.142872, -0.003984}}],
    Polygon[{{1.472723, 0.141260, -0.002712},{1.472822, 0.140954, -0.001373},{
      1.475239, 0.142186, -0.001373},{1.475050, 0.142446, -0.002712}}],
    Polygon[{{1.472822, 0.140954, -0.001373},{1.472855, 0.140852, 0.000000},{
      1.475302, 0.142098, 0.000000},{1.475239, 0.142186, -0.001373}}],
    Polygon[{{1.472855, 0.140852, 0.000000},{1.472822, 0.140954, 0.001373},{
      1.475239, 0.142186, 0.001373},{1.475302, 0.142098, 0.000000}}],
    Polygon[{{1.472822, 0.140954, 0.001373},{1.472723, 0.141260, 0.002712},{
      1.475050, 0.142446, 0.002712},{1.475239, 0.142186, 0.001373}}],
    Polygon[{{1.472723, 0.141260, 0.002712},{1.472560, 0.141761, 0.003984},{
      1.474740, 0.142872, 0.003984},{1.475050, 0.142446, 0.002712}}],
    Polygon[{{1.472560, 0.141761, 0.003984},{1.472337, 0.142446, 0.005159},{
      1.474317, 0.143454, 0.005159},{1.474740, 0.142872, 0.003984}}],
    Polygon[{{1.472337, 0.142446, 0.005159},{1.472061, 0.143296, 0.006206},{
      1.473791, 0.144178, 0.006206},{1.474317, 0.143454, 0.005159}}],
    Polygon[{{1.472061, 0.143296, 0.006206},{1.471738, 0.144292, 0.007100},{
      1.473176, 0.145025, 0.007100},{1.473791, 0.144178, 0.006206}}],
    Polygon[{{1.471738, 0.144292, 0.007100},{1.471375, 0.145409, 0.007820},{
      1.472485, 0.145975, 0.007820},{1.473176, 0.145025, 0.007100}}],
    Polygon[{{1.471375, 0.145409, 0.007820},{1.470981, 0.146619, 0.008347},{
      1.471738, 0.147004, 0.008347},{1.472485, 0.145975, 0.007820}}],
    Polygon[{{1.470981, 0.146619, 0.008347},{1.470568, 0.147893, 0.008668},{
      1.470950, 0.148088, 0.008668},{1.471738, 0.147004, 0.008347}}],
    Polygon[{{1.470950, 0.148088, -0.008668},{1.471738, 0.147004, -0.008347},{
      1.472337, 0.147604, -0.008347},{1.471254, 0.148391, -0.008668}}],
    Polygon[{{1.471738, 0.147004, -0.008347},{1.472485, 0.145975, -0.007820},{
      1.473367, 0.146856, -0.007820},{1.472337, 0.147604, -0.008347}}],
    Polygon[{{1.472485, 0.145975, -0.007820},{1.473176, 0.145025, -0.007100},{
      1.474317, 0.146166, -0.007100},{1.473367, 0.146856, -0.007820}}],
    Polygon[{{1.473176, 0.145025, -0.007100},{1.473791, 0.144178, -0.006206},{
      1.475164, 0.145551, -0.006206},{1.474317, 0.146166, -0.007100}}],
    Polygon[{{1.473791, 0.144178, -0.006206},{1.474317, 0.143454, -0.005159},{
      1.475888, 0.145025, -0.005159},{1.475164, 0.145551, -0.006206}}],
    Polygon[{{1.474317, 0.143454, -0.005159},{1.474740, 0.142872, -0.003984},{
      1.476470, 0.144602, -0.003984},{1.475888, 0.145025, -0.005159}}],
    Polygon[{{1.474740, 0.142872, -0.003984},{1.475050, 0.142446, -0.002712},{
      1.476896, 0.144292, -0.002712},{1.476470, 0.144602, -0.003984}}],
    Polygon[{{1.475050, 0.142446, -0.002712},{1.475239, 0.142186, -0.001373},{
      1.477156, 0.144103, -0.001373},{1.476896, 0.144292, -0.002712}}],
    Polygon[{{1.475239, 0.142186, -0.001373},{1.475302, 0.142098, 0.000000},{
      1.477244, 0.144040, 0.000000},{1.477156, 0.144103, -0.001373}}],
    Polygon[{{1.475302, 0.142098, 0.000000},{1.475239, 0.142186, 0.001373},{
      1.477156, 0.144103, 0.001373},{1.477244, 0.144040, 0.000000}}],
    Polygon[{{1.475239, 0.142186, 0.001373},{1.475050, 0.142446, 0.002712},{
      1.476896, 0.144292, 0.002712},{1.477156, 0.144103, 0.001373}}],
    Polygon[{{1.475050, 0.142446, 0.002712},{1.474740, 0.142872, 0.003984},{
      1.476470, 0.144602, 0.003984},{1.476896, 0.144292, 0.002712}}],
    Polygon[{{1.474740, 0.142872, 0.003984},{1.474317, 0.143454, 0.005159},{
      1.475888, 0.145025, 0.005159},{1.476470, 0.144602, 0.003984}}],
    Polygon[{{1.474317, 0.143454, 0.005159},{1.473791, 0.144178, 0.006206},{
      1.475164, 0.145551, 0.006206},{1.475888, 0.145025, 0.005159}}],
    Polygon[{{1.473791, 0.144178, 0.006206},{1.473176, 0.145025, 0.007100},{
      1.474317, 0.146166, 0.007100},{1.475164, 0.145551, 0.006206}}],
    Polygon[{{1.473176, 0.145025, 0.007100},{1.472485, 0.145975, 0.007820},{
      1.473367, 0.146856, 0.007820},{1.474317, 0.146166, 0.007100}}],
    Polygon[{{1.472485, 0.145975, 0.007820},{1.471738, 0.147004, 0.008347},{
      1.472337, 0.147604, 0.008347},{1.473367, 0.146856, 0.007820}}],
    Polygon[{{1.471738, 0.147004, 0.008347},{1.470950, 0.148088, 0.008668},{
      1.471254, 0.148391, 0.008668},{1.472337, 0.147604, 0.008347}}],
    Polygon[{{1.471254, 0.148391, -0.008668},{1.472337, 0.147604, -0.008347},{
      1.472723, 0.148360, -0.008347},{1.471449, 0.148774, -0.008668}}],
    Polygon[{{1.472337, 0.147604, -0.008347},{1.473367, 0.146856, -0.007820},{
      1.473933, 0.147967, -0.007820},{1.472723, 0.148360, -0.008347}}],
    Polygon[{{1.473367, 0.146856, -0.007820},{1.474317, 0.146166, -0.007100},{
      1.475050, 0.147604, -0.007100},{1.473933, 0.147967, -0.007820}}],
    Polygon[{{1.474317, 0.146166, -0.007100},{1.475164, 0.145551, -0.006206},{
      1.476045, 0.147281, -0.006206},{1.475050, 0.147604, -0.007100}}],
    Polygon[{{1.475164, 0.145551, -0.006206},{1.475888, 0.145025, -0.005159},{
      1.476896, 0.147004, -0.005159},{1.476045, 0.147281, -0.006206}}],
    Polygon[{{1.475888, 0.145025, -0.005159},{1.476470, 0.144602, -0.003984},{
      1.477581, 0.146782, -0.003984},{1.476896, 0.147004, -0.005159}}],
    Polygon[{{1.476470, 0.144602, -0.003984},{1.476896, 0.144292, -0.002712},{
      1.478082, 0.146619, -0.002712},{1.477581, 0.146782, -0.003984}}],
    Polygon[{{1.476896, 0.144292, -0.002712},{1.477156, 0.144103, -0.001373},{
      1.478387, 0.146520, -0.001373},{1.478082, 0.146619, -0.002712}}],
    Polygon[{{1.477156, 0.144103, -0.001373},{1.477244, 0.144040, 0.000000},{
      1.478490, 0.146486, 0.000000},{1.478387, 0.146520, -0.001373}}],
    Polygon[{{1.477244, 0.144040, 0.000000},{1.477156, 0.144103, 0.001373},{
      1.478387, 0.146520, 0.001373},{1.478490, 0.146486, 0.000000}}],
    Polygon[{{1.477156, 0.144103, 0.001373},{1.476896, 0.144292, 0.002712},{
      1.478082, 0.146619, 0.002712},{1.478387, 0.146520, 0.001373}}],
    Polygon[{{1.476896, 0.144292, 0.002712},{1.476470, 0.144602, 0.003984},{
      1.477581, 0.146782, 0.003984},{1.478082, 0.146619, 0.002712}}],
    Polygon[{{1.476470, 0.144602, 0.003984},{1.475888, 0.145025, 0.005159},{
      1.476896, 0.147004, 0.005159},{1.477581, 0.146782, 0.003984}}],
    Polygon[{{1.475888, 0.145025, 0.005159},{1.475164, 0.145551, 0.006206},{
      1.476045, 0.147281, 0.006206},{1.476896, 0.147004, 0.005159}}],
    Polygon[{{1.475164, 0.145551, 0.006206},{1.474317, 0.146166, 0.007100},{
      1.475050, 0.147604, 0.007100},{1.476045, 0.147281, 0.006206}}],
    Polygon[{{1.474317, 0.146166, 0.007100},{1.473367, 0.146856, 0.007820},{
      1.473933, 0.147967, 0.007820},{1.475050, 0.147604, 0.007100}}],
    Polygon[{{1.473367, 0.146856, 0.007820},{1.472337, 0.147604, 0.008347},{
      1.472723, 0.148360, 0.008347},{1.473933, 0.147967, 0.007820}}],
    Polygon[{{1.472337, 0.147604, 0.008347},{1.471254, 0.148391, 0.008668},{
      1.471449, 0.148774, 0.008668},{1.472723, 0.148360, 0.008347}}],
    Polygon[{{1.471449, 0.148774, -0.008668},{1.472723, 0.148360, -0.008347},{
      1.472855, 0.149198, -0.008347},{1.471516, 0.149198, -0.008668}}],
    Polygon[{{1.472723, 0.148360, -0.008347},{1.473933, 0.147967, -0.007820},{
      1.474128, 0.149198, -0.007820},{1.472855, 0.149198, -0.008347}}],
    Polygon[{{1.473933, 0.147967, -0.007820},{1.475050, 0.147604, -0.007100},{
      1.475302, 0.149198, -0.007100},{1.474128, 0.149198, -0.007820}}],
    Polygon[{{1.475050, 0.147604, -0.007100},{1.476045, 0.147281, -0.006206},{
      1.476349, 0.149198, -0.006206},{1.475302, 0.149198, -0.007100}}],
    Polygon[{{1.476045, 0.147281, -0.006206},{1.476896, 0.147004, -0.005159},{
      1.477244, 0.149198, -0.005159},{1.476349, 0.149198, -0.006206}}],
    Polygon[{{1.476896, 0.147004, -0.005159},{1.477581, 0.146782, -0.003984},{
      1.477963, 0.149198, -0.003984},{1.477244, 0.149198, -0.005159}}],
    Polygon[{{1.477581, 0.146782, -0.003984},{1.478082, 0.146619, -0.002712},{
      1.478490, 0.149198, -0.002712},{1.477963, 0.149198, -0.003984}}],
    Polygon[{{1.478082, 0.146619, -0.002712},{1.478387, 0.146520, -0.001373},{
      1.478812, 0.149198, -0.001373},{1.478490, 0.149198, -0.002712}}],
    Polygon[{{1.478387, 0.146520, -0.001373},{1.478490, 0.146486, 0.000000},{
      1.478920, 0.149198, 0.000000},{1.478812, 0.149198, -0.001373}}],
    Polygon[{{1.478490, 0.146486, 0.000000},{1.478387, 0.146520, 0.001373},{
      1.478812, 0.149198, 0.001373},{1.478920, 0.149198, 0.000000}}],
    Polygon[{{1.478387, 0.146520, 0.001373},{1.478082, 0.146619, 0.002712},{
      1.478490, 0.149198, 0.002712},{1.478812, 0.149198, 0.001373}}],
    Polygon[{{1.478082, 0.146619, 0.002712},{1.477581, 0.146782, 0.003984},{
      1.477963, 0.149198, 0.003984},{1.478490, 0.149198, 0.002712}}],
    Polygon[{{1.477581, 0.146782, 0.003984},{1.476896, 0.147004, 0.005159},{
      1.477244, 0.149198, 0.005159},{1.477963, 0.149198, 0.003984}}],
    Polygon[{{1.476896, 0.147004, 0.005159},{1.476045, 0.147281, 0.006206},{
      1.476349, 0.149198, 0.006206},{1.477244, 0.149198, 0.005159}}],
    Polygon[{{1.476045, 0.147281, 0.006206},{1.475050, 0.147604, 0.007100},{
      1.475302, 0.149198, 0.007100},{1.476349, 0.149198, 0.006206}}],
    Polygon[{{1.475050, 0.147604, 0.007100},{1.473933, 0.147967, 0.007820},{
      1.474128, 0.149198, 0.007820},{1.475302, 0.149198, 0.007100}}],
    Polygon[{{1.473933, 0.147967, 0.007820},{1.472723, 0.148360, 0.008347},{
      1.472855, 0.149198, 0.008347},{1.474128, 0.149198, 0.007820}}],
    Polygon[{{1.472723, 0.148360, 0.008347},{1.471449, 0.148774, 0.008668},{
      1.471516, 0.149198, 0.008668},{1.472855, 0.149198, 0.008347}}],
    Polygon[{{1.656438, 0.461325, -0.076398},{1.668240, 0.461325, -0.073564},{
      1.667070, 0.468711, -0.073564},{1.655846, 0.465064, -0.076398}}],
    Polygon[{{1.668240, 0.461325, -0.073564},{1.679454, 0.461325, -0.068920},{
      1.677735, 0.472176, -0.068920},{1.667070, 0.468711, -0.073564}}],
    Polygon[{{1.679454, 0.461325, -0.068920},{1.689803, 0.461325, -0.062578},{
      1.687578, 0.475374, -0.062578},{1.677735, 0.472176, -0.068920}}],
    Polygon[{{1.689803, 0.461325, -0.062578},{1.699032, 0.461325, -0.054695},{
      1.696355, 0.478227, -0.054695},{1.687578, 0.475374, -0.062578}}],
    Polygon[{{1.699032, 0.461325, -0.054695},{1.706915, 0.461325, -0.045465},{
      1.703853, 0.480662, -0.045465},{1.696355, 0.478227, -0.054695}}],
    Polygon[{{1.706915, 0.461325, -0.045465},{1.713257, 0.461325, -0.035116},{
      1.709884, 0.482622, -0.035116},{1.703853, 0.480662, -0.045465}}],
    Polygon[{{1.713257, 0.461325, -0.035116},{1.717902, 0.461325, -0.023903},{
      1.714302, 0.484058, -0.023903},{1.709884, 0.482622, -0.035116}}],
    Polygon[{{1.717902, 0.461325, -0.023903},{1.720736, 0.461325, -0.012100},{
      1.716996, 0.484933, -0.012100},{1.714302, 0.484058, -0.023903}}],
    Polygon[{{1.720736, 0.461325, -0.012100},{1.721688, 0.461325, 0.000000},{
      1.717902, 0.485227, 0.000000},{1.716996, 0.484933, -0.012100}}],
    Polygon[{{1.721688, 0.461325, 0.000000},{1.720736, 0.461325, 0.012100},{
      1.716996, 0.484933, 0.012100},{1.717902, 0.485227, 0.000000}}],
    Polygon[{{1.720736, 0.461325, 0.012100},{1.717902, 0.461325, 0.023903},{
      1.714302, 0.484058, 0.023903},{1.716996, 0.484933, 0.012100}}],
    Polygon[{{1.717902, 0.461325, 0.023903},{1.713257, 0.461325, 0.035116},{
      1.709884, 0.482622, 0.035116},{1.714302, 0.484058, 0.023903}}],
    Polygon[{{1.713257, 0.461325, 0.035116},{1.706915, 0.461325, 0.045465},{
      1.703853, 0.480662, 0.045465},{1.709884, 0.482622, 0.035116}}],
    Polygon[{{1.706915, 0.461325, 0.045465},{1.699032, 0.461325, 0.054695},{
      1.696355, 0.478227, 0.054695},{1.703853, 0.480662, 0.045465}}],
    Polygon[{{1.699032, 0.461325, 0.054695},{1.689803, 0.461325, 0.062578},{
      1.687578, 0.475374, 0.062578},{1.696355, 0.478227, 0.054695}}],
    Polygon[{{1.689803, 0.461325, 0.062578},{1.679454, 0.461325, 0.068920},{
      1.677735, 0.472176, 0.068920},{1.687578, 0.475374, 0.062578}}],
    Polygon[{{1.679454, 0.461325, 0.068920},{1.668240, 0.461325, 0.073564},{
      1.667070, 0.468711, 0.073564},{1.677735, 0.472176, 0.068920}}],
    Polygon[{{1.668240, 0.461325, 0.073564},{1.656438, 0.461325, 0.076398},{
      1.655846, 0.465064, 0.076398},{1.667070, 0.468711, 0.073564}}],
    Polygon[{{1.655846, 0.465064, -0.076398},{1.667070, 0.468711, -0.073564},{
      1.663675, 0.475374, -0.073564},{1.654127, 0.468437, -0.076398}}],
    Polygon[{{1.667070, 0.468711, -0.073564},{1.677735, 0.472176, -0.068920},{
      1.672747, 0.481966, -0.068920},{1.663675, 0.475374, -0.073564}}],
    Polygon[{{1.677735, 0.472176, -0.068920},{1.687578, 0.475374, -0.062578},{
      1.681120, 0.488049, -0.062578},{1.672747, 0.481966, -0.068920}}],
    Polygon[{{1.687578, 0.475374, -0.062578},{1.696355, 0.478227, -0.054695},{
      1.688587, 0.493474, -0.054695},{1.681120, 0.488049, -0.062578}}],
    Polygon[{{1.696355, 0.478227, -0.054695},{1.703853, 0.480662, -0.045465},{
      1.694964, 0.498107, -0.045465},{1.688587, 0.493474, -0.054695}}],
    Polygon[{{1.703853, 0.480662, -0.045465},{1.709884, 0.482622, -0.035116},{
      1.700095, 0.501835, -0.035116},{1.694964, 0.498107, -0.045465}}],
    Polygon[{{1.709884, 0.482622, -0.035116},{1.714302, 0.484058, -0.023903},{
      1.703853, 0.504565, -0.023903},{1.700095, 0.501835, -0.035116}}],
    Polygon[{{1.714302, 0.484058, -0.023903},{1.716996, 0.484933, -0.012100},{
      1.706145, 0.506230, -0.012100},{1.703853, 0.504565, -0.023903}}],
    Polygon[{{1.716996, 0.484933, -0.012100},{1.717902, 0.485227, 0.000000},{
      1.706915, 0.506790, 0.000000},{1.706145, 0.506230, -0.012100}}],
    Polygon[{{1.717902, 0.485227, 0.000000},{1.716996, 0.484933, 0.012100},{
      1.706145, 0.506230, 0.012100},{1.706915, 0.506790, 0.000000}}],
    Polygon[{{1.716996, 0.484933, 0.012100},{1.714302, 0.484058, 0.023903},{
      1.703853, 0.504565, 0.023903},{1.706145, 0.506230, 0.012100}}],
    Polygon[{{1.714302, 0.484058, 0.023903},{1.709884, 0.482622, 0.035116},{
      1.700095, 0.501835, 0.035116},{1.703853, 0.504565, 0.023903}}],
    Polygon[{{1.709884, 0.482622, 0.035116},{1.703853, 0.480662, 0.045465},{
      1.694964, 0.498107, 0.045465},{1.700095, 0.501835, 0.035116}}],
    Polygon[{{1.703853, 0.480662, 0.045465},{1.696355, 0.478227, 0.054695},{
      1.688587, 0.493474, 0.054695},{1.694964, 0.498107, 0.045465}}],
    Polygon[{{1.696355, 0.478227, 0.054695},{1.687578, 0.475374, 0.062578},{
      1.681120, 0.488049, 0.062578},{1.688587, 0.493474, 0.054695}}],
    Polygon[{{1.687578, 0.475374, 0.062578},{1.677735, 0.472176, 0.068920},{
      1.672747, 0.481966, 0.068920},{1.681120, 0.488049, 0.062578}}],
    Polygon[{{1.677735, 0.472176, 0.068920},{1.667070, 0.468711, 0.073564},{
      1.663675, 0.475374, 0.073564},{1.672747, 0.481966, 0.068920}}],
    Polygon[{{1.667070, 0.468711, 0.073564},{1.655846, 0.465064, 0.076398},{
      1.654127, 0.468437, 0.076398},{1.663675, 0.475374, 0.073564}}],
    Polygon[{{1.654127, 0.468437, -0.076398},{1.663675, 0.475374, -0.073564},{
      1.658387, 0.480662, -0.073564},{1.651450, 0.471114, -0.076398}}],
    Polygon[{{1.663675, 0.475374, -0.073564},{1.672747, 0.481966, -0.068920},{
      1.664978, 0.489735, -0.068920},{1.658387, 0.480662, -0.073564}}],
    Polygon[{{1.672747, 0.481966, -0.068920},{1.681120, 0.488049, -0.062578},{
      1.671061, 0.498107, -0.062578},{1.664978, 0.489735, -0.068920}}],
    Polygon[{{1.681120, 0.488049, -0.062578},{1.688587, 0.493474, -0.054695},{
      1.676486, 0.505574, -0.054695},{1.671061, 0.498107, -0.062578}}],
    Polygon[{{1.688587, 0.493474, -0.054695},{1.694964, 0.498107, -0.045465},{
      1.681120, 0.511951, -0.045465},{1.676486, 0.505574, -0.054695}}],
    Polygon[{{1.694964, 0.498107, -0.045465},{1.700095, 0.501835, -0.035116},{
      1.684847, 0.517082, -0.035116},{1.681120, 0.511951, -0.045465}}],
    Polygon[{{1.700095, 0.501835, -0.035116},{1.703853, 0.504565, -0.023903},{
      1.687578, 0.520840, -0.023903},{1.684847, 0.517082, -0.035116}}],
    Polygon[{{1.703853, 0.504565, -0.023903},{1.706145, 0.506230, -0.012100},{
      1.689243, 0.523132, -0.012100},{1.687578, 0.520840, -0.023903}}],
    Polygon[{{1.706145, 0.506230, -0.012100},{1.706915, 0.506790, 0.000000},{
      1.689803, 0.523903, 0.000000},{1.689243, 0.523132, -0.012100}}],
    Polygon[{{1.706915, 0.506790, 0.000000},{1.706145, 0.506230, 0.012100},{
      1.689243, 0.523132, 0.012100},{1.689803, 0.523903, 0.000000}}],
    Polygon[{{1.706145, 0.506230, 0.012100},{1.703853, 0.504565, 0.023903},{
      1.687578, 0.520840, 0.023903},{1.689243, 0.523132, 0.012100}}],
    Polygon[{{1.703853, 0.504565, 0.023903},{1.700095, 0.501835, 0.035116},{
      1.684847, 0.517082, 0.035116},{1.687578, 0.520840, 0.023903}}],
    Polygon[{{1.700095, 0.501835, 0.035116},{1.694964, 0.498107, 0.045465},{
      1.681120, 0.511951, 0.045465},{1.684847, 0.517082, 0.035116}}],
    Polygon[{{1.694964, 0.498107, 0.045465},{1.688587, 0.493474, 0.054695},{
      1.676486, 0.505574, 0.054695},{1.681120, 0.511951, 0.045465}}],
    Polygon[{{1.688587, 0.493474, 0.054695},{1.681120, 0.488049, 0.062578},{
      1.671061, 0.498107, 0.062578},{1.676486, 0.505574, 0.054695}}],
    Polygon[{{1.681120, 0.488049, 0.062578},{1.672747, 0.481966, 0.068920},{
      1.664978, 0.489735, 0.068920},{1.671061, 0.498107, 0.062578}}],
    Polygon[{{1.672747, 0.481966, 0.068920},{1.663675, 0.475374, 0.073564},{
      1.658387, 0.480662, 0.073564},{1.664978, 0.489735, 0.068920}}],
    Polygon[{{1.663675, 0.475374, 0.073564},{1.654127, 0.468437, 0.076398},{
      1.651450, 0.471114, 0.076398},{1.658387, 0.480662, 0.073564}}],
    Polygon[{{1.651450, 0.471114, -0.076398},{1.658387, 0.480662, -0.073564},{
      1.651724, 0.484058, -0.073564},{1.648077, 0.472833, -0.076398}}],
    Polygon[{{1.658387, 0.480662, -0.073564},{1.664978, 0.489735, -0.068920},{
      1.655189, 0.494722, -0.068920},{1.651724, 0.484058, -0.073564}}],
    Polygon[{{1.664978, 0.489735, -0.068920},{1.671061, 0.498107, -0.062578},{
      1.658387, 0.504565, -0.062578},{1.655189, 0.494722, -0.068920}}],
    Polygon[{{1.671061, 0.498107, -0.062578},{1.676486, 0.505574, -0.054695},{
      1.661239, 0.513343, -0.054695},{1.658387, 0.504565, -0.062578}}],
    Polygon[{{1.676486, 0.505574, -0.054695},{1.681120, 0.511951, -0.045465},{
      1.663675, 0.520840, -0.045465},{1.661239, 0.513343, -0.054695}}],
    Polygon[{{1.681120, 0.511951, -0.045465},{1.684847, 0.517082, -0.035116},{
      1.665635, 0.526871, -0.035116},{1.663675, 0.520840, -0.045465}}],
    Polygon[{{1.684847, 0.517082, -0.035116},{1.687578, 0.520840, -0.023903},{
      1.667070, 0.531289, -0.023903},{1.665635, 0.526871, -0.035116}}],
    Polygon[{{1.687578, 0.520840, -0.023903},{1.689243, 0.523132, -0.012100},{
      1.667946, 0.533984, -0.012100},{1.667070, 0.531289, -0.023903}}],
    Polygon[{{1.689243, 0.523132, -0.012100},{1.689803, 0.523903, 0.000000},{
      1.668240, 0.534889, 0.000000},{1.667946, 0.533984, -0.012100}}],
    Polygon[{{1.689803, 0.523903, 0.000000},{1.689243, 0.523132, 0.012100},{
      1.667946, 0.533984, 0.012100},{1.668240, 0.534889, 0.000000}}],
    Polygon[{{1.689243, 0.523132, 0.012100},{1.687578, 0.520840, 0.023903},{
      1.667070, 0.531289, 0.023903},{1.667946, 0.533984, 0.012100}}],
    Polygon[{{1.687578, 0.520840, 0.023903},{1.684847, 0.517082, 0.035116},{
      1.665635, 0.526871, 0.035116},{1.667070, 0.531289, 0.023903}}],
    Polygon[{{1.684847, 0.517082, 0.035116},{1.681120, 0.511951, 0.045465},{
      1.663675, 0.520840, 0.045465},{1.665635, 0.526871, 0.035116}}],
    Polygon[{{1.681120, 0.511951, 0.045465},{1.676486, 0.505574, 0.054695},{
      1.661239, 0.513343, 0.054695},{1.663675, 0.520840, 0.045465}}],
    Polygon[{{1.676486, 0.505574, 0.054695},{1.671061, 0.498107, 0.062578},{
      1.658387, 0.504565, 0.062578},{1.661239, 0.513343, 0.054695}}],
    Polygon[{{1.671061, 0.498107, 0.062578},{1.664978, 0.489735, 0.068920},{
      1.655189, 0.494722, 0.068920},{1.658387, 0.504565, 0.062578}}],
    Polygon[{{1.664978, 0.489735, 0.068920},{1.658387, 0.480662, 0.073564},{
      1.651724, 0.484058, 0.073564},{1.655189, 0.494722, 0.068920}}],
    Polygon[{{1.658387, 0.480662, 0.073564},{1.651450, 0.471114, 0.076398},{
      1.648077, 0.472833, 0.076398},{1.651724, 0.484058, 0.073564}}],
    Polygon[{{1.648077, 0.472833, -0.076398},{1.651724, 0.484058, -0.073564},{
      1.644338, 0.485227, -0.073564},{1.644338, 0.473425, -0.076398}}],
    Polygon[{{1.651724, 0.484058, -0.073564},{1.655189, 0.494722, -0.068920},{
      1.644338, 0.496441, -0.068920},{1.644338, 0.485227, -0.073564}}],
    Polygon[{{1.655189, 0.494722, -0.068920},{1.658387, 0.504565, -0.062578},{
      1.644338, 0.506790, -0.062578},{1.644338, 0.496441, -0.068920}}],
    Polygon[{{1.658387, 0.504565, -0.062578},{1.661239, 0.513343, -0.054695},{
      1.644338, 0.516020, -0.054695},{1.644338, 0.506790, -0.062578}}],
    Polygon[{{1.661239, 0.513343, -0.054695},{1.663675, 0.520840, -0.045465},{
      1.644338, 0.523903, -0.045465},{1.644338, 0.516020, -0.054695}}],
    Polygon[{{1.663675, 0.520840, -0.045465},{1.665635, 0.526871, -0.035116},{
      1.644338, 0.530244, -0.035116},{1.644338, 0.523903, -0.045465}}],
    Polygon[{{1.665635, 0.526871, -0.035116},{1.667070, 0.531289, -0.023903},{
      1.644338, 0.534889, -0.023903},{1.644338, 0.530244, -0.035116}}],
    Polygon[{{1.667070, 0.531289, -0.023903},{1.667946, 0.533984, -0.012100},{
      1.644338, 0.537723, -0.012100},{1.644338, 0.534889, -0.023903}}],
    Polygon[{{1.667946, 0.533984, -0.012100},{1.668240, 0.534889, 0.000000},{
      1.644338, 0.538675, 0.000000},{1.644338, 0.537723, -0.012100}}],
    Polygon[{{1.668240, 0.534889, 0.000000},{1.667946, 0.533984, 0.012100},{
      1.644338, 0.537723, 0.012100},{1.644338, 0.538675, 0.000000}}],
    Polygon[{{1.667946, 0.533984, 0.012100},{1.667070, 0.531289, 0.023903},{
      1.644338, 0.534889, 0.023903},{1.644338, 0.537723, 0.012100}}],
    Polygon[{{1.667070, 0.531289, 0.023903},{1.665635, 0.526871, 0.035116},{
      1.644338, 0.530244, 0.035116},{1.644338, 0.534889, 0.023903}}],
    Polygon[{{1.665635, 0.526871, 0.035116},{1.663675, 0.520840, 0.045465},{
      1.644338, 0.523903, 0.045465},{1.644338, 0.530244, 0.035116}}],
    Polygon[{{1.663675, 0.520840, 0.045465},{1.661239, 0.513343, 0.054695},{
      1.644338, 0.516020, 0.054695},{1.644338, 0.523903, 0.045465}}],
    Polygon[{{1.661239, 0.513343, 0.054695},{1.658387, 0.504565, 0.062578},{
      1.644338, 0.506790, 0.062578},{1.644338, 0.516020, 0.054695}}],
    Polygon[{{1.658387, 0.504565, 0.062578},{1.655189, 0.494722, 0.068920},{
      1.644338, 0.496441, 0.068920},{1.644338, 0.506790, 0.062578}}],
    Polygon[{{1.655189, 0.494722, 0.068920},{1.651724, 0.484058, 0.073564},{
      1.644338, 0.485227, 0.073564},{1.644338, 0.496441, 0.068920}}],
    Polygon[{{1.651724, 0.484058, 0.073564},{1.648077, 0.472833, 0.076398},{
      1.644338, 0.473425, 0.076398},{1.644338, 0.485227, 0.073564}}],
    Polygon[{{1.644338, 0.473425, -0.076398},{1.644338, 0.485227, -0.073564},{
      1.636951, 0.484058, -0.073564},{1.640598, 0.472833, -0.076398}}],
    Polygon[{{1.644338, 0.485227, -0.073564},{1.644338, 0.496441, -0.068920},{
      1.633486, 0.494722, -0.068920},{1.636951, 0.484058, -0.073564}}],
    Polygon[{{1.644338, 0.496441, -0.068920},{1.644338, 0.506790, -0.062578},{
      1.630288, 0.504565, -0.062578},{1.633486, 0.494722, -0.068920}}],
    Polygon[{{1.644338, 0.506790, -0.062578},{1.644338, 0.516020, -0.054695},{
      1.627436, 0.513343, -0.054695},{1.630288, 0.504565, -0.062578}}],
    Polygon[{{1.644338, 0.516020, -0.054695},{1.644338, 0.523903, -0.045465},{
      1.625000, 0.520840, -0.045465},{1.627436, 0.513343, -0.054695}}],
    Polygon[{{1.644338, 0.523903, -0.045465},{1.644338, 0.530244, -0.035116},{
      1.623040, 0.526871, -0.035116},{1.625000, 0.520840, -0.045465}}],
    Polygon[{{1.644338, 0.530244, -0.035116},{1.644338, 0.534889, -0.023903},{
      1.621605, 0.531289, -0.023903},{1.623040, 0.526871, -0.035116}}],
    Polygon[{{1.644338, 0.534889, -0.023903},{1.644338, 0.537723, -0.012100},{
      1.620729, 0.533984, -0.012100},{1.621605, 0.531289, -0.023903}}],
    Polygon[{{1.644338, 0.537723, -0.012100},{1.644338, 0.538675, 0.000000},{
      1.620435, 0.534889, 0.000000},{1.620729, 0.533984, -0.012100}}],
    Polygon[{{1.644338, 0.538675, 0.000000},{1.644338, 0.537723, 0.012100},{
      1.620729, 0.533984, 0.012100},{1.620435, 0.534889, 0.000000}}],
    Polygon[{{1.644338, 0.537723, 0.012100},{1.644338, 0.534889, 0.023903},{
      1.621605, 0.531289, 0.023903},{1.620729, 0.533984, 0.012100}}],
    Polygon[{{1.644338, 0.534889, 0.023903},{1.644338, 0.530244, 0.035116},{
      1.623040, 0.526871, 0.035116},{1.621605, 0.531289, 0.023903}}],
    Polygon[{{1.644338, 0.530244, 0.035116},{1.644338, 0.523903, 0.045465},{
      1.625000, 0.520840, 0.045465},{1.623040, 0.526871, 0.035116}}],
    Polygon[{{1.644338, 0.523903, 0.045465},{1.644338, 0.516020, 0.054695},{
      1.627436, 0.513343, 0.054695},{1.625000, 0.520840, 0.045465}}],
    Polygon[{{1.644338, 0.516020, 0.054695},{1.644338, 0.506790, 0.062578},{
      1.630288, 0.504565, 0.062578},{1.627436, 0.513343, 0.054695}}],
    Polygon[{{1.644338, 0.506790, 0.062578},{1.644338, 0.496441, 0.068920},{
      1.633486, 0.494722, 0.068920},{1.630288, 0.504565, 0.062578}}],
    Polygon[{{1.644338, 0.496441, 0.068920},{1.644338, 0.485227, 0.073564},{
      1.636951, 0.484058, 0.073564},{1.633486, 0.494722, 0.068920}}],
    Polygon[{{1.644338, 0.485227, 0.073564},{1.644338, 0.473425, 0.076398},{
      1.640598, 0.472833, 0.076398},{1.636951, 0.484058, 0.073564}}],
    Polygon[{{1.640598, 0.472833, -0.076398},{1.636951, 0.484058, -0.073564},{
      1.630288, 0.480662, -0.073564},{1.637225, 0.471114, -0.076398}}],
    Polygon[{{1.636951, 0.484058, -0.073564},{1.633486, 0.494722, -0.068920},{
      1.623697, 0.489735, -0.068920},{1.630288, 0.480662, -0.073564}}],
    Polygon[{{1.633486, 0.494722, -0.068920},{1.630288, 0.504565, -0.062578},{
      1.617614, 0.498107, -0.062578},{1.623697, 0.489735, -0.068920}}],
    Polygon[{{1.630288, 0.504565, -0.062578},{1.627436, 0.513343, -0.054695},{
      1.612189, 0.505574, -0.054695},{1.617614, 0.498107, -0.062578}}],
    Polygon[{{1.627436, 0.513343, -0.054695},{1.625000, 0.520840, -0.045465},{
      1.607555, 0.511951, -0.045465},{1.612189, 0.505574, -0.054695}}],
    Polygon[{{1.625000, 0.520840, -0.045465},{1.623040, 0.526871, -0.035116},{
      1.603828, 0.517082, -0.035116},{1.607555, 0.511951, -0.045465}}],
    Polygon[{{1.623040, 0.526871, -0.035116},{1.621605, 0.531289, -0.023903},{
      1.601097, 0.520840, -0.023903},{1.603828, 0.517082, -0.035116}}],
    Polygon[{{1.621605, 0.531289, -0.023903},{1.620729, 0.533984, -0.012100},{
      1.599432, 0.523132, -0.012100},{1.601097, 0.520840, -0.023903}}],
    Polygon[{{1.620729, 0.533984, -0.012100},{1.620435, 0.534889, 0.000000},{
      1.598872, 0.523903, 0.000000},{1.599432, 0.523132, -0.012100}}],
    Polygon[{{1.620435, 0.534889, 0.000000},{1.620729, 0.533984, 0.012100},{
      1.599432, 0.523132, 0.012100},{1.598872, 0.523903, 0.000000}}],
    Polygon[{{1.620729, 0.533984, 0.012100},{1.621605, 0.531289, 0.023903},{
      1.601097, 0.520840, 0.023903},{1.599432, 0.523132, 0.012100}}],
    Polygon[{{1.621605, 0.531289, 0.023903},{1.623040, 0.526871, 0.035116},{
      1.603828, 0.517082, 0.035116},{1.601097, 0.520840, 0.023903}}],
    Polygon[{{1.623040, 0.526871, 0.035116},{1.625000, 0.520840, 0.045465},{
      1.607555, 0.511951, 0.045465},{1.603828, 0.517082, 0.035116}}],
    Polygon[{{1.625000, 0.520840, 0.045465},{1.627436, 0.513343, 0.054695},{
      1.612189, 0.505574, 0.054695},{1.607555, 0.511951, 0.045465}}],
    Polygon[{{1.627436, 0.513343, 0.054695},{1.630288, 0.504565, 0.062578},{
      1.617614, 0.498107, 0.062578},{1.612189, 0.505574, 0.054695}}],
    Polygon[{{1.630288, 0.504565, 0.062578},{1.633486, 0.494722, 0.068920},{
      1.623697, 0.489735, 0.068920},{1.617614, 0.498107, 0.062578}}],
    Polygon[{{1.633486, 0.494722, 0.068920},{1.636951, 0.484058, 0.073564},{
      1.630288, 0.480662, 0.073564},{1.623697, 0.489735, 0.068920}}],
    Polygon[{{1.636951, 0.484058, 0.073564},{1.640598, 0.472833, 0.076398},{
      1.637225, 0.471114, 0.076398},{1.630288, 0.480662, 0.073564}}],
    Polygon[{{1.637225, 0.471114, -0.076398},{1.630288, 0.480662, -0.073564},{
      1.625000, 0.475374, -0.073564},{1.634548, 0.468437, -0.076398}}],
    Polygon[{{1.630288, 0.480662, -0.073564},{1.623697, 0.489735, -0.068920},{
      1.615928, 0.481966, -0.068920},{1.625000, 0.475374, -0.073564}}],
    Polygon[{{1.623697, 0.489735, -0.068920},{1.617614, 0.498107, -0.062578},{
      1.607555, 0.488049, -0.062578},{1.615928, 0.481966, -0.068920}}],
    Polygon[{{1.617614, 0.498107, -0.062578},{1.612189, 0.505574, -0.054695},{
      1.600088, 0.493474, -0.054695},{1.607555, 0.488049, -0.062578}}],
    Polygon[{{1.612189, 0.505574, -0.054695},{1.607555, 0.511951, -0.045465},{
      1.593711, 0.498107, -0.045465},{1.600088, 0.493474, -0.054695}}],
    Polygon[{{1.607555, 0.511951, -0.045465},{1.603828, 0.517082, -0.035116},{
      1.588580, 0.501835, -0.035116},{1.593711, 0.498107, -0.045465}}],
    Polygon[{{1.603828, 0.517082, -0.035116},{1.601097, 0.520840, -0.023903},{
      1.584823, 0.504565, -0.023903},{1.588580, 0.501835, -0.035116}}],
    Polygon[{{1.601097, 0.520840, -0.023903},{1.599432, 0.523132, -0.012100},{
      1.582530, 0.506230, -0.012100},{1.584823, 0.504565, -0.023903}}],
    Polygon[{{1.599432, 0.523132, -0.012100},{1.598872, 0.523903, 0.000000},{
      1.581760, 0.506790, 0.000000},{1.582530, 0.506230, -0.012100}}],
    Polygon[{{1.598872, 0.523903, 0.000000},{1.599432, 0.523132, 0.012100},{
      1.582530, 0.506230, 0.012100},{1.581760, 0.506790, 0.000000}}],
    Polygon[{{1.599432, 0.523132, 0.012100},{1.601097, 0.520840, 0.023903},{
      1.584823, 0.504565, 0.023903},{1.582530, 0.506230, 0.012100}}],
    Polygon[{{1.601097, 0.520840, 0.023903},{1.603828, 0.517082, 0.035116},{
      1.588580, 0.501835, 0.035116},{1.584823, 0.504565, 0.023903}}],
    Polygon[{{1.603828, 0.517082, 0.035116},{1.607555, 0.511951, 0.045465},{
      1.593711, 0.498107, 0.045465},{1.588580, 0.501835, 0.035116}}],
    Polygon[{{1.607555, 0.511951, 0.045465},{1.612189, 0.505574, 0.054695},{
      1.600088, 0.493474, 0.054695},{1.593711, 0.498107, 0.045465}}],
    Polygon[{{1.612189, 0.505574, 0.054695},{1.617614, 0.498107, 0.062578},{
      1.607555, 0.488049, 0.062578},{1.600088, 0.493474, 0.054695}}],
    Polygon[{{1.617614, 0.498107, 0.062578},{1.623697, 0.489735, 0.068920},{
      1.615928, 0.481966, 0.068920},{1.607555, 0.488049, 0.062578}}],
    Polygon[{{1.623697, 0.489735, 0.068920},{1.630288, 0.480662, 0.073564},{
      1.625000, 0.475374, 0.073564},{1.615928, 0.481966, 0.068920}}],
    Polygon[{{1.630288, 0.480662, 0.073564},{1.637225, 0.471114, 0.076398},{
      1.634548, 0.468437, 0.076398},{1.625000, 0.475374, 0.073564}}],
    Polygon[{{1.634548, 0.468437, -0.076398},{1.625000, 0.475374, -0.073564},{
      1.621605, 0.468711, -0.073564},{1.632830, 0.465064, -0.076398}}],
    Polygon[{{1.625000, 0.475374, -0.073564},{1.615928, 0.481966, -0.068920},{
      1.610940, 0.472176, -0.068920},{1.621605, 0.468711, -0.073564}}],
    Polygon[{{1.615928, 0.481966, -0.068920},{1.607555, 0.488049, -0.062578},{
      1.601097, 0.475374, -0.062578},{1.610940, 0.472176, -0.068920}}],
    Polygon[{{1.607555, 0.488049, -0.062578},{1.600088, 0.493474, -0.054695},{
      1.592320, 0.478227, -0.054695},{1.601097, 0.475374, -0.062578}}],
    Polygon[{{1.600088, 0.493474, -0.054695},{1.593711, 0.498107, -0.045465},{
      1.584823, 0.480662, -0.045465},{1.592320, 0.478227, -0.054695}}],
    Polygon[{{1.593711, 0.498107, -0.045465},{1.588580, 0.501835, -0.035116},{
      1.578791, 0.482622, -0.035116},{1.584823, 0.480662, -0.045465}}],
    Polygon[{{1.588580, 0.501835, -0.035116},{1.584823, 0.504565, -0.023903},{
      1.574374, 0.484058, -0.023903},{1.578791, 0.482622, -0.035116}}],
    Polygon[{{1.584823, 0.504565, -0.023903},{1.582530, 0.506230, -0.012100},{
      1.571679, 0.484933, -0.012100},{1.574374, 0.484058, -0.023903}}],
    Polygon[{{1.582530, 0.506230, -0.012100},{1.581760, 0.506790, 0.000000},{
      1.570773, 0.485227, 0.000000},{1.571679, 0.484933, -0.012100}}],
    Polygon[{{1.581760, 0.506790, 0.000000},{1.582530, 0.506230, 0.012100},{
      1.571679, 0.484933, 0.012100},{1.570773, 0.485227, 0.000000}}],
    Polygon[{{1.582530, 0.506230, 0.012100},{1.584823, 0.504565, 0.023903},{
      1.574374, 0.484058, 0.023903},{1.571679, 0.484933, 0.012100}}],
    Polygon[{{1.584823, 0.504565, 0.023903},{1.588580, 0.501835, 0.035116},{
      1.578791, 0.482622, 0.035116},{1.574374, 0.484058, 0.023903}}],
    Polygon[{{1.588580, 0.501835, 0.035116},{1.593711, 0.498107, 0.045465},{
      1.584823, 0.480662, 0.045465},{1.578791, 0.482622, 0.035116}}],
    Polygon[{{1.593711, 0.498107, 0.045465},{1.600088, 0.493474, 0.054695},{
      1.592320, 0.478227, 0.054695},{1.584823, 0.480662, 0.045465}}],
    Polygon[{{1.600088, 0.493474, 0.054695},{1.607555, 0.488049, 0.062578},{
      1.601097, 0.475374, 0.062578},{1.592320, 0.478227, 0.054695}}],
    Polygon[{{1.607555, 0.488049, 0.062578},{1.615928, 0.481966, 0.068920},{
      1.610940, 0.472176, 0.068920},{1.601097, 0.475374, 0.062578}}],
    Polygon[{{1.615928, 0.481966, 0.068920},{1.625000, 0.475374, 0.073564},{
      1.621605, 0.468711, 0.073564},{1.610940, 0.472176, 0.068920}}],
    Polygon[{{1.625000, 0.475374, 0.073564},{1.634548, 0.468437, 0.076398},{
      1.632830, 0.465064, 0.076398},{1.621605, 0.468711, 0.073564}}],
    Polygon[{{1.632830, 0.465064, -0.076398},{1.621605, 0.468711, -0.073564},{
      1.620435, 0.461325, -0.073564},{1.632237, 0.461325, -0.076398}}],
    Polygon[{{1.621605, 0.468711, -0.073564},{1.610940, 0.472176, -0.068920},{
      1.609221, 0.461325, -0.068920},{1.620435, 0.461325, -0.073564}}],
    Polygon[{{1.610940, 0.472176, -0.068920},{1.601097, 0.475374, -0.062578},{
      1.598872, 0.461325, -0.062578},{1.609221, 0.461325, -0.068920}}],
    Polygon[{{1.601097, 0.475374, -0.062578},{1.592320, 0.478227, -0.054695},{
      1.589643, 0.461325, -0.054695},{1.598872, 0.461325, -0.062578}}],
    Polygon[{{1.592320, 0.478227, -0.054695},{1.584823, 0.480662, -0.045465},{
      1.581760, 0.461325, -0.045465},{1.589643, 0.461325, -0.054695}}],
    Polygon[{{1.584823, 0.480662, -0.045465},{1.578791, 0.482622, -0.035116},{
      1.575418, 0.461325, -0.035116},{1.581760, 0.461325, -0.045465}}],
    Polygon[{{1.578791, 0.482622, -0.035116},{1.574374, 0.484058, -0.023903},{
      1.570773, 0.461325, -0.023903},{1.575418, 0.461325, -0.035116}}],
    Polygon[{{1.574374, 0.484058, -0.023903},{1.571679, 0.484933, -0.012100},{
      1.567940, 0.461325, -0.012100},{1.570773, 0.461325, -0.023903}}],
    Polygon[{{1.571679, 0.484933, -0.012100},{1.570773, 0.485227, 0.000000},{
      1.566987, 0.461325, 0.000000},{1.567940, 0.461325, -0.012100}}],
    Polygon[{{1.570773, 0.485227, 0.000000},{1.571679, 0.484933, 0.012100},{
      1.567940, 0.461325, 0.012100},{1.566987, 0.461325, 0.000000}}],
    Polygon[{{1.571679, 0.484933, 0.012100},{1.574374, 0.484058, 0.023903},{
      1.570773, 0.461325, 0.023903},{1.567940, 0.461325, 0.012100}}],
    Polygon[{{1.574374, 0.484058, 0.023903},{1.578791, 0.482622, 0.035116},{
      1.575418, 0.461325, 0.035116},{1.570773, 0.461325, 0.023903}}],
    Polygon[{{1.578791, 0.482622, 0.035116},{1.584823, 0.480662, 0.045465},{
      1.581760, 0.461325, 0.045465},{1.575418, 0.461325, 0.035116}}],
    Polygon[{{1.584823, 0.480662, 0.045465},{1.592320, 0.478227, 0.054695},{
      1.589643, 0.461325, 0.054695},{1.581760, 0.461325, 0.045465}}],
    Polygon[{{1.592320, 0.478227, 0.054695},{1.601097, 0.475374, 0.062578},{
      1.598872, 0.461325, 0.062578},{1.589643, 0.461325, 0.054695}}],
    Polygon[{{1.601097, 0.475374, 0.062578},{1.610940, 0.472176, 0.068920},{
      1.609221, 0.461325, 0.068920},{1.598872, 0.461325, 0.062578}}],
    Polygon[{{1.610940, 0.472176, 0.068920},{1.621605, 0.468711, 0.073564},{
      1.620435, 0.461325, 0.073564},{1.609221, 0.461325, 0.068920}}],
    Polygon[{{1.621605, 0.468711, 0.073564},{1.632830, 0.465064, 0.076398},{
      1.632237, 0.461325, 0.076398},{1.620435, 0.461325, 0.073564}}],
    Polygon[{{1.632237, 0.461325, -0.076398},{1.620435, 0.461325, -0.073564},{
      1.621605, 0.453939, -0.073564},{1.632830, 0.457586, -0.076398}}],
    Polygon[{{1.620435, 0.461325, -0.073564},{1.609221, 0.461325, -0.068920},{
      1.610940, 0.450473, -0.068920},{1.621605, 0.453939, -0.073564}}],
    Polygon[{{1.609221, 0.461325, -0.068920},{1.598872, 0.461325, -0.062578},{
      1.601097, 0.447275, -0.062578},{1.610940, 0.450473, -0.068920}}],
    Polygon[{{1.598872, 0.461325, -0.062578},{1.589643, 0.461325, -0.054695},{
      1.592320, 0.444423, -0.054695},{1.601097, 0.447275, -0.062578}}],
    Polygon[{{1.589643, 0.461325, -0.054695},{1.581760, 0.461325, -0.045465},{
      1.584823, 0.441987, -0.045465},{1.592320, 0.444423, -0.054695}}],
    Polygon[{{1.581760, 0.461325, -0.045465},{1.575418, 0.461325, -0.035116},{
      1.578791, 0.440028, -0.035116},{1.584823, 0.441987, -0.045465}}],
    Polygon[{{1.575418, 0.461325, -0.035116},{1.570773, 0.461325, -0.023903},{
      1.574374, 0.438592, -0.023903},{1.578791, 0.440028, -0.035116}}],
    Polygon[{{1.570773, 0.461325, -0.023903},{1.567940, 0.461325, -0.012100},{
      1.571679, 0.437717, -0.012100},{1.574374, 0.438592, -0.023903}}],
    Polygon[{{1.567940, 0.461325, -0.012100},{1.566987, 0.461325, 0.000000},{
      1.570773, 0.437422, 0.000000},{1.571679, 0.437717, -0.012100}}],
    Polygon[{{1.566987, 0.461325, 0.000000},{1.567940, 0.461325, 0.012100},{
      1.571679, 0.437717, 0.012100},{1.570773, 0.437422, 0.000000}}],
    Polygon[{{1.567940, 0.461325, 0.012100},{1.570773, 0.461325, 0.023903},{
      1.574374, 0.438592, 0.023903},{1.571679, 0.437717, 0.012100}}],
    Polygon[{{1.570773, 0.461325, 0.023903},{1.575418, 0.461325, 0.035116},{
      1.578791, 0.440028, 0.035116},{1.574374, 0.438592, 0.023903}}],
    Polygon[{{1.575418, 0.461325, 0.035116},{1.581760, 0.461325, 0.045465},{
      1.584823, 0.441987, 0.045465},{1.578791, 0.440028, 0.035116}}],
    Polygon[{{1.581760, 0.461325, 0.045465},{1.589643, 0.461325, 0.054695},{
      1.592320, 0.444423, 0.054695},{1.584823, 0.441987, 0.045465}}],
    Polygon[{{1.589643, 0.461325, 0.054695},{1.598872, 0.461325, 0.062578},{
      1.601097, 0.447275, 0.062578},{1.592320, 0.444423, 0.054695}}],
    Polygon[{{1.598872, 0.461325, 0.062578},{1.609221, 0.461325, 0.068920},{
      1.610940, 0.450473, 0.068920},{1.601097, 0.447275, 0.062578}}],
    Polygon[{{1.609221, 0.461325, 0.068920},{1.620435, 0.461325, 0.073564},{
      1.621605, 0.453939, 0.073564},{1.610940, 0.450473, 0.068920}}],
    Polygon[{{1.620435, 0.461325, 0.073564},{1.632237, 0.461325, 0.076398},{
      1.632830, 0.457586, 0.076398},{1.621605, 0.453939, 0.073564}}],
    Polygon[{{1.632830, 0.457586, -0.076398},{1.621605, 0.453939, -0.073564},{
      1.625000, 0.447275, -0.073564},{1.634548, 0.454213, -0.076398}}],
    Polygon[{{1.621605, 0.453939, -0.073564},{1.610940, 0.450473, -0.068920},{
      1.615928, 0.440684, -0.068920},{1.625000, 0.447275, -0.073564}}],
    Polygon[{{1.610940, 0.450473, -0.068920},{1.601097, 0.447275, -0.062578},{
      1.607555, 0.434601, -0.062578},{1.615928, 0.440684, -0.068920}}],
    Polygon[{{1.601097, 0.447275, -0.062578},{1.592320, 0.444423, -0.054695},{
      1.600088, 0.429176, -0.054695},{1.607555, 0.434601, -0.062578}}],
    Polygon[{{1.592320, 0.444423, -0.054695},{1.584823, 0.441987, -0.045465},{
      1.593711, 0.424543, -0.045465},{1.600088, 0.429176, -0.054695}}],
    Polygon[{{1.584823, 0.441987, -0.045465},{1.578791, 0.440028, -0.035116},{
      1.588580, 0.420815, -0.035116},{1.593711, 0.424543, -0.045465}}],
    Polygon[{{1.578791, 0.440028, -0.035116},{1.574374, 0.438592, -0.023903},{
      1.584823, 0.418085, -0.023903},{1.588580, 0.420815, -0.035116}}],
    Polygon[{{1.574374, 0.438592, -0.023903},{1.571679, 0.437717, -0.012100},{
      1.582530, 0.416419, -0.012100},{1.584823, 0.418085, -0.023903}}],
    Polygon[{{1.571679, 0.437717, -0.012100},{1.570773, 0.437422, 0.000000},{
      1.581760, 0.415860, 0.000000},{1.582530, 0.416419, -0.012100}}],
    Polygon[{{1.570773, 0.437422, 0.000000},{1.571679, 0.437717, 0.012100},{
      1.582530, 0.416419, 0.012100},{1.581760, 0.415860, 0.000000}}],
    Polygon[{{1.571679, 0.437717, 0.012100},{1.574374, 0.438592, 0.023903},{
      1.584823, 0.418085, 0.023903},{1.582530, 0.416419, 0.012100}}],
    Polygon[{{1.574374, 0.438592, 0.023903},{1.578791, 0.440028, 0.035116},{
      1.588580, 0.420815, 0.035116},{1.584823, 0.418085, 0.023903}}],
    Polygon[{{1.578791, 0.440028, 0.035116},{1.584823, 0.441987, 0.045465},{
      1.593711, 0.424543, 0.045465},{1.588580, 0.420815, 0.035116}}],
    Polygon[{{1.584823, 0.441987, 0.045465},{1.592320, 0.444423, 0.054695},{
      1.600088, 0.429176, 0.054695},{1.593711, 0.424543, 0.045465}}],
    Polygon[{{1.592320, 0.444423, 0.054695},{1.601097, 0.447275, 0.062578},{
      1.607555, 0.434601, 0.062578},{1.600088, 0.429176, 0.054695}}],
    Polygon[{{1.601097, 0.447275, 0.062578},{1.610940, 0.450473, 0.068920},{
      1.615928, 0.440684, 0.068920},{1.607555, 0.434601, 0.062578}}],
    Polygon[{{1.610940, 0.450473, 0.068920},{1.621605, 0.453939, 0.073564},{
      1.625000, 0.447275, 0.073564},{1.615928, 0.440684, 0.068920}}],
    Polygon[{{1.621605, 0.453939, 0.073564},{1.632830, 0.457586, 0.076398},{
      1.634548, 0.454213, 0.076398},{1.625000, 0.447275, 0.073564}}],
    Polygon[{{1.634548, 0.454213, -0.076398},{1.625000, 0.447275, -0.073564},{
      1.630288, 0.441987, -0.073564},{1.637225, 0.451536, -0.076398}}],
    Polygon[{{1.625000, 0.447275, -0.073564},{1.615928, 0.440684, -0.068920},{
      1.623697, 0.432915, -0.068920},{1.630288, 0.441987, -0.073564}}],
    Polygon[{{1.615928, 0.440684, -0.068920},{1.607555, 0.434601, -0.062578},{
      1.617614, 0.424543, -0.062578},{1.623697, 0.432915, -0.068920}}],
    Polygon[{{1.607555, 0.434601, -0.062578},{1.600088, 0.429176, -0.054695},{
      1.612189, 0.417076, -0.054695},{1.617614, 0.424543, -0.062578}}],
    Polygon[{{1.600088, 0.429176, -0.054695},{1.593711, 0.424543, -0.045465},{
      1.607555, 0.410698, -0.045465},{1.612189, 0.417076, -0.054695}}],
    Polygon[{{1.593711, 0.424543, -0.045465},{1.588580, 0.420815, -0.035116},{
      1.603828, 0.405568, -0.035116},{1.607555, 0.410698, -0.045465}}],
    Polygon[{{1.588580, 0.420815, -0.035116},{1.584823, 0.418085, -0.023903},{
      1.601097, 0.401810, -0.023903},{1.603828, 0.405568, -0.035116}}],
    Polygon[{{1.584823, 0.418085, -0.023903},{1.582530, 0.416419, -0.012100},{
      1.599432, 0.399518, -0.012100},{1.601097, 0.401810, -0.023903}}],
    Polygon[{{1.582530, 0.416419, -0.012100},{1.581760, 0.415860, 0.000000},{
      1.598872, 0.398747, 0.000000},{1.599432, 0.399518, -0.012100}}],
    Polygon[{{1.581760, 0.415860, 0.000000},{1.582530, 0.416419, 0.012100},{
      1.599432, 0.399518, 0.012100},{1.598872, 0.398747, 0.000000}}],
    Polygon[{{1.582530, 0.416419, 0.012100},{1.584823, 0.418085, 0.023903},{
      1.601097, 0.401810, 0.023903},{1.599432, 0.399518, 0.012100}}],
    Polygon[{{1.584823, 0.418085, 0.023903},{1.588580, 0.420815, 0.035116},{
      1.603828, 0.405568, 0.035116},{1.601097, 0.401810, 0.023903}}],
    Polygon[{{1.588580, 0.420815, 0.035116},{1.593711, 0.424543, 0.045465},{
      1.607555, 0.410698, 0.045465},{1.603828, 0.405568, 0.035116}}],
    Polygon[{{1.593711, 0.424543, 0.045465},{1.600088, 0.429176, 0.054695},{
      1.612189, 0.417076, 0.054695},{1.607555, 0.410698, 0.045465}}],
    Polygon[{{1.600088, 0.429176, 0.054695},{1.607555, 0.434601, 0.062578},{
      1.617614, 0.424543, 0.062578},{1.612189, 0.417076, 0.054695}}],
    Polygon[{{1.607555, 0.434601, 0.062578},{1.615928, 0.440684, 0.068920},{
      1.623697, 0.432915, 0.068920},{1.617614, 0.424543, 0.062578}}],
    Polygon[{{1.615928, 0.440684, 0.068920},{1.625000, 0.447275, 0.073564},{
      1.630288, 0.441987, 0.073564},{1.623697, 0.432915, 0.068920}}],
    Polygon[{{1.625000, 0.447275, 0.073564},{1.634548, 0.454213, 0.076398},{
      1.637225, 0.451536, 0.076398},{1.630288, 0.441987, 0.073564}}],
    Polygon[{{1.637225, 0.451536, -0.076398},{1.630288, 0.441987, -0.073564},{
      1.636951, 0.438592, -0.073564},{1.640598, 0.449817, -0.076398}}],
    Polygon[{{1.630288, 0.441987, -0.073564},{1.623697, 0.432915, -0.068920},{
      1.633486, 0.427927, -0.068920},{1.636951, 0.438592, -0.073564}}],
    Polygon[{{1.623697, 0.432915, -0.068920},{1.617614, 0.424543, -0.062578},{
      1.630288, 0.418085, -0.062578},{1.633486, 0.427927, -0.068920}}],
    Polygon[{{1.617614, 0.424543, -0.062578},{1.612189, 0.417076, -0.054695},{
      1.627436, 0.409307, -0.054695},{1.630288, 0.418085, -0.062578}}],
    Polygon[{{1.612189, 0.417076, -0.054695},{1.607555, 0.410698, -0.045465},{
      1.625000, 0.401810, -0.045465},{1.627436, 0.409307, -0.054695}}],
    Polygon[{{1.607555, 0.410698, -0.045465},{1.603828, 0.405568, -0.035116},{
      1.623040, 0.395778, -0.035116},{1.625000, 0.401810, -0.045465}}],
    Polygon[{{1.603828, 0.405568, -0.035116},{1.601097, 0.401810, -0.023903},{
      1.621605, 0.391361, -0.023903},{1.623040, 0.395778, -0.035116}}],
    Polygon[{{1.601097, 0.401810, -0.023903},{1.599432, 0.399518, -0.012100},{
      1.620729, 0.388666, -0.012100},{1.621605, 0.391361, -0.023903}}],
    Polygon[{{1.599432, 0.399518, -0.012100},{1.598872, 0.398747, 0.000000},{
      1.620435, 0.387760, 0.000000},{1.620729, 0.388666, -0.012100}}],
    Polygon[{{1.598872, 0.398747, 0.000000},{1.599432, 0.399518, 0.012100},{
      1.620729, 0.388666, 0.012100},{1.620435, 0.387760, 0.000000}}],
    Polygon[{{1.599432, 0.399518, 0.012100},{1.601097, 0.401810, 0.023903},{
      1.621605, 0.391361, 0.023903},{1.620729, 0.388666, 0.012100}}],
    Polygon[{{1.601097, 0.401810, 0.023903},{1.603828, 0.405568, 0.035116},{
      1.623040, 0.395778, 0.035116},{1.621605, 0.391361, 0.023903}}],
    Polygon[{{1.603828, 0.405568, 0.035116},{1.607555, 0.410698, 0.045465},{
      1.625000, 0.401810, 0.045465},{1.623040, 0.395778, 0.035116}}],
    Polygon[{{1.607555, 0.410698, 0.045465},{1.612189, 0.417076, 0.054695},{
      1.627436, 0.409307, 0.054695},{1.625000, 0.401810, 0.045465}}],
    Polygon[{{1.612189, 0.417076, 0.054695},{1.617614, 0.424543, 0.062578},{
      1.630288, 0.418085, 0.062578},{1.627436, 0.409307, 0.054695}}],
    Polygon[{{1.617614, 0.424543, 0.062578},{1.623697, 0.432915, 0.068920},{
      1.633486, 0.427927, 0.068920},{1.630288, 0.418085, 0.062578}}],
    Polygon[{{1.623697, 0.432915, 0.068920},{1.630288, 0.441987, 0.073564},{
      1.636951, 0.438592, 0.073564},{1.633486, 0.427927, 0.068920}}],
    Polygon[{{1.630288, 0.441987, 0.073564},{1.637225, 0.451536, 0.076398},{
      1.640598, 0.449817, 0.076398},{1.636951, 0.438592, 0.073564}}],
    Polygon[{{1.640598, 0.449817, -0.076398},{1.636951, 0.438592, -0.073564},{
      1.644338, 0.437422, -0.073564},{1.644338, 0.449225, -0.076398}}],
    Polygon[{{1.636951, 0.438592, -0.073564},{1.633486, 0.427927, -0.068920},{
      1.644338, 0.426209, -0.068920},{1.644338, 0.437422, -0.073564}}],
    Polygon[{{1.633486, 0.427927, -0.068920},{1.630288, 0.418085, -0.062578},{
      1.644338, 0.415860, -0.062578},{1.644338, 0.426209, -0.068920}}],
    Polygon[{{1.630288, 0.418085, -0.062578},{1.627436, 0.409307, -0.054695},{
      1.644338, 0.406630, -0.054695},{1.644338, 0.415860, -0.062578}}],
    Polygon[{{1.627436, 0.409307, -0.054695},{1.625000, 0.401810, -0.045465},{
      1.644338, 0.398747, -0.045465},{1.644338, 0.406630, -0.054695}}],
    Polygon[{{1.625000, 0.401810, -0.045465},{1.623040, 0.395778, -0.035116},{
      1.644338, 0.392405, -0.035116},{1.644338, 0.398747, -0.045465}}],
    Polygon[{{1.623040, 0.395778, -0.035116},{1.621605, 0.391361, -0.023903},{
      1.644338, 0.387760, -0.023903},{1.644338, 0.392405, -0.035116}}],
    Polygon[{{1.621605, 0.391361, -0.023903},{1.620729, 0.388666, -0.012100},{
      1.644338, 0.384927, -0.012100},{1.644338, 0.387760, -0.023903}}],
    Polygon[{{1.620729, 0.388666, -0.012100},{1.620435, 0.387760, 0.000000},{
      1.644338, 0.383975, 0.000000},{1.644338, 0.384927, -0.012100}}],
    Polygon[{{1.620435, 0.387760, 0.000000},{1.620729, 0.388666, 0.012100},{
      1.644338, 0.384927, 0.012100},{1.644338, 0.383975, 0.000000}}],
    Polygon[{{1.620729, 0.388666, 0.012100},{1.621605, 0.391361, 0.023903},{
      1.644338, 0.387760, 0.023903},{1.644338, 0.384927, 0.012100}}],
    Polygon[{{1.621605, 0.391361, 0.023903},{1.623040, 0.395778, 0.035116},{
      1.644338, 0.392405, 0.035116},{1.644338, 0.387760, 0.023903}}],
    Polygon[{{1.623040, 0.395778, 0.035116},{1.625000, 0.401810, 0.045465},{
      1.644338, 0.398747, 0.045465},{1.644338, 0.392405, 0.035116}}],
    Polygon[{{1.625000, 0.401810, 0.045465},{1.627436, 0.409307, 0.054695},{
      1.644338, 0.406630, 0.054695},{1.644338, 0.398747, 0.045465}}],
    Polygon[{{1.627436, 0.409307, 0.054695},{1.630288, 0.418085, 0.062578},{
      1.644338, 0.415860, 0.062578},{1.644338, 0.406630, 0.054695}}],
    Polygon[{{1.630288, 0.418085, 0.062578},{1.633486, 0.427927, 0.068920},{
      1.644338, 0.426209, 0.068920},{1.644338, 0.415860, 0.062578}}],
    Polygon[{{1.633486, 0.427927, 0.068920},{1.636951, 0.438592, 0.073564},{
      1.644338, 0.437422, 0.073564},{1.644338, 0.426209, 0.068920}}],
    Polygon[{{1.636951, 0.438592, 0.073564},{1.640598, 0.449817, 0.076398},{
      1.644338, 0.449225, 0.076398},{1.644338, 0.437422, 0.073564}}],
    Polygon[{{1.644338, 0.449225, -0.076398},{1.644338, 0.437422, -0.073564},{
      1.651724, 0.438592, -0.073564},{1.648077, 0.449817, -0.076398}}],
    Polygon[{{1.644338, 0.437422, -0.073564},{1.644338, 0.426209, -0.068920},{
      1.655189, 0.427927, -0.068920},{1.651724, 0.438592, -0.073564}}],
    Polygon[{{1.644338, 0.426209, -0.068920},{1.644338, 0.415860, -0.062578},{
      1.658387, 0.418085, -0.062578},{1.655189, 0.427927, -0.068920}}],
    Polygon[{{1.644338, 0.415860, -0.062578},{1.644338, 0.406630, -0.054695},{
      1.661239, 0.409307, -0.054695},{1.658387, 0.418085, -0.062578}}],
    Polygon[{{1.644338, 0.406630, -0.054695},{1.644338, 0.398747, -0.045465},{
      1.663675, 0.401810, -0.045465},{1.661239, 0.409307, -0.054695}}],
    Polygon[{{1.644338, 0.398747, -0.045465},{1.644338, 0.392405, -0.035116},{
      1.665635, 0.395778, -0.035116},{1.663675, 0.401810, -0.045465}}],
    Polygon[{{1.644338, 0.392405, -0.035116},{1.644338, 0.387760, -0.023903},{
      1.667070, 0.391361, -0.023903},{1.665635, 0.395778, -0.035116}}],
    Polygon[{{1.644338, 0.387760, -0.023903},{1.644338, 0.384927, -0.012100},{
      1.667946, 0.388666, -0.012100},{1.667070, 0.391361, -0.023903}}],
    Polygon[{{1.644338, 0.384927, -0.012100},{1.644338, 0.383975, 0.000000},{
      1.668240, 0.387760, 0.000000},{1.667946, 0.388666, -0.012100}}],
    Polygon[{{1.644338, 0.383975, 0.000000},{1.644338, 0.384927, 0.012100},{
      1.667946, 0.388666, 0.012100},{1.668240, 0.387760, 0.000000}}],
    Polygon[{{1.644338, 0.384927, 0.012100},{1.644338, 0.387760, 0.023903},{
      1.667070, 0.391361, 0.023903},{1.667946, 0.388666, 0.012100}}],
    Polygon[{{1.644338, 0.387760, 0.023903},{1.644338, 0.392405, 0.035116},{
      1.665635, 0.395778, 0.035116},{1.667070, 0.391361, 0.023903}}],
    Polygon[{{1.644338, 0.392405, 0.035116},{1.644338, 0.398747, 0.045465},{
      1.663675, 0.401810, 0.045465},{1.665635, 0.395778, 0.035116}}],
    Polygon[{{1.644338, 0.398747, 0.045465},{1.644338, 0.406630, 0.054695},{
      1.661239, 0.409307, 0.054695},{1.663675, 0.401810, 0.045465}}],
    Polygon[{{1.644338, 0.406630, 0.054695},{1.644338, 0.415860, 0.062578},{
      1.658387, 0.418085, 0.062578},{1.661239, 0.409307, 0.054695}}],
    Polygon[{{1.644338, 0.415860, 0.062578},{1.644338, 0.426209, 0.068920},{
      1.655189, 0.427927, 0.068920},{1.658387, 0.418085, 0.062578}}],
    Polygon[{{1.644338, 0.426209, 0.068920},{1.644338, 0.437422, 0.073564},{
      1.651724, 0.438592, 0.073564},{1.655189, 0.427927, 0.068920}}],
    Polygon[{{1.644338, 0.437422, 0.073564},{1.644338, 0.449225, 0.076398},{
      1.648077, 0.449817, 0.076398},{1.651724, 0.438592, 0.073564}}],
    Polygon[{{1.648077, 0.449817, -0.076398},{1.651724, 0.438592, -0.073564},{
      1.658387, 0.441987, -0.073564},{1.651450, 0.451536, -0.076398}}],
    Polygon[{{1.651724, 0.438592, -0.073564},{1.655189, 0.427927, -0.068920},{
      1.664978, 0.432915, -0.068920},{1.658387, 0.441987, -0.073564}}],
    Polygon[{{1.655189, 0.427927, -0.068920},{1.658387, 0.418085, -0.062578},{
      1.671061, 0.424543, -0.062578},{1.664978, 0.432915, -0.068920}}],
    Polygon[{{1.658387, 0.418085, -0.062578},{1.661239, 0.409307, -0.054695},{
      1.676486, 0.417076, -0.054695},{1.671061, 0.424543, -0.062578}}],
    Polygon[{{1.661239, 0.409307, -0.054695},{1.663675, 0.401810, -0.045465},{
      1.681120, 0.410698, -0.045465},{1.676486, 0.417076, -0.054695}}],
    Polygon[{{1.663675, 0.401810, -0.045465},{1.665635, 0.395778, -0.035116},{
      1.684847, 0.405568, -0.035116},{1.681120, 0.410698, -0.045465}}],
    Polygon[{{1.665635, 0.395778, -0.035116},{1.667070, 0.391361, -0.023903},{
      1.687578, 0.401810, -0.023903},{1.684847, 0.405568, -0.035116}}],
    Polygon[{{1.667070, 0.391361, -0.023903},{1.667946, 0.388666, -0.012100},{
      1.689243, 0.399518, -0.012100},{1.687578, 0.401810, -0.023903}}],
    Polygon[{{1.667946, 0.388666, -0.012100},{1.668240, 0.387760, 0.000000},{
      1.689803, 0.398747, 0.000000},{1.689243, 0.399518, -0.012100}}],
    Polygon[{{1.668240, 0.387760, 0.000000},{1.667946, 0.388666, 0.012100},{
      1.689243, 0.399518, 0.012100},{1.689803, 0.398747, 0.000000}}],
    Polygon[{{1.667946, 0.388666, 0.012100},{1.667070, 0.391361, 0.023903},{
      1.687578, 0.401810, 0.023903},{1.689243, 0.399518, 0.012100}}],
    Polygon[{{1.667070, 0.391361, 0.023903},{1.665635, 0.395778, 0.035116},{
      1.684847, 0.405568, 0.035116},{1.687578, 0.401810, 0.023903}}],
    Polygon[{{1.665635, 0.395778, 0.035116},{1.663675, 0.401810, 0.045465},{
      1.681120, 0.410698, 0.045465},{1.684847, 0.405568, 0.035116}}],
    Polygon[{{1.663675, 0.401810, 0.045465},{1.661239, 0.409307, 0.054695},{
      1.676486, 0.417076, 0.054695},{1.681120, 0.410698, 0.045465}}],
    Polygon[{{1.661239, 0.409307, 0.054695},{1.658387, 0.418085, 0.062578},{
      1.671061, 0.424543, 0.062578},{1.676486, 0.417076, 0.054695}}],
    Polygon[{{1.658387, 0.418085, 0.062578},{1.655189, 0.427927, 0.068920},{
      1.664978, 0.432915, 0.068920},{1.671061, 0.424543, 0.062578}}],
    Polygon[{{1.655189, 0.427927, 0.068920},{1.651724, 0.438592, 0.073564},{
      1.658387, 0.441987, 0.073564},{1.664978, 0.432915, 0.068920}}],
    Polygon[{{1.651724, 0.438592, 0.073564},{1.648077, 0.449817, 0.076398},{
      1.651450, 0.451536, 0.076398},{1.658387, 0.441987, 0.073564}}],
    Polygon[{{1.651450, 0.451536, -0.076398},{1.658387, 0.441987, -0.073564},{
      1.663675, 0.447275, -0.073564},{1.654127, 0.454213, -0.076398}}],
    Polygon[{{1.658387, 0.441987, -0.073564},{1.664978, 0.432915, -0.068920},{
      1.672747, 0.440684, -0.068920},{1.663675, 0.447275, -0.073564}}],
    Polygon[{{1.664978, 0.432915, -0.068920},{1.671061, 0.424543, -0.062578},{
      1.681120, 0.434601, -0.062578},{1.672747, 0.440684, -0.068920}}],
    Polygon[{{1.671061, 0.424543, -0.062578},{1.676486, 0.417076, -0.054695},{
      1.688587, 0.429176, -0.054695},{1.681120, 0.434601, -0.062578}}],
    Polygon[{{1.676486, 0.417076, -0.054695},{1.681120, 0.410698, -0.045465},{
      1.694964, 0.424543, -0.045465},{1.688587, 0.429176, -0.054695}}],
    Polygon[{{1.681120, 0.410698, -0.045465},{1.684847, 0.405568, -0.035116},{
      1.700095, 0.420815, -0.035116},{1.694964, 0.424543, -0.045465}}],
    Polygon[{{1.684847, 0.405568, -0.035116},{1.687578, 0.401810, -0.023903},{
      1.703853, 0.418085, -0.023903},{1.700095, 0.420815, -0.035116}}],
    Polygon[{{1.687578, 0.401810, -0.023903},{1.689243, 0.399518, -0.012100},{
      1.706145, 0.416419, -0.012100},{1.703853, 0.418085, -0.023903}}],
    Polygon[{{1.689243, 0.399518, -0.012100},{1.689803, 0.398747, 0.000000},{
      1.706915, 0.415860, 0.000000},{1.706145, 0.416419, -0.012100}}],
    Polygon[{{1.689803, 0.398747, 0.000000},{1.689243, 0.399518, 0.012100},{
      1.706145, 0.416419, 0.012100},{1.706915, 0.415860, 0.000000}}],
    Polygon[{{1.689243, 0.399518, 0.012100},{1.687578, 0.401810, 0.023903},{
      1.703853, 0.418085, 0.023903},{1.706145, 0.416419, 0.012100}}],
    Polygon[{{1.687578, 0.401810, 0.023903},{1.684847, 0.405568, 0.035116},{
      1.700095, 0.420815, 0.035116},{1.703853, 0.418085, 0.023903}}],
    Polygon[{{1.684847, 0.405568, 0.035116},{1.681120, 0.410698, 0.045465},{
      1.694964, 0.424543, 0.045465},{1.700095, 0.420815, 0.035116}}],
    Polygon[{{1.681120, 0.410698, 0.045465},{1.676486, 0.417076, 0.054695},{
      1.688587, 0.429176, 0.054695},{1.694964, 0.424543, 0.045465}}],
    Polygon[{{1.676486, 0.417076, 0.054695},{1.671061, 0.424543, 0.062578},{
      1.681120, 0.434601, 0.062578},{1.688587, 0.429176, 0.054695}}],
    Polygon[{{1.671061, 0.424543, 0.062578},{1.664978, 0.432915, 0.068920},{
      1.672747, 0.440684, 0.068920},{1.681120, 0.434601, 0.062578}}],
    Polygon[{{1.664978, 0.432915, 0.068920},{1.658387, 0.441987, 0.073564},{
      1.663675, 0.447275, 0.073564},{1.672747, 0.440684, 0.068920}}],
    Polygon[{{1.658387, 0.441987, 0.073564},{1.651450, 0.451536, 0.076398},{
      1.654127, 0.454213, 0.076398},{1.663675, 0.447275, 0.073564}}],
    Polygon[{{1.654127, 0.454213, -0.076398},{1.663675, 0.447275, -0.073564},{
      1.667070, 0.453939, -0.073564},{1.655846, 0.457586, -0.076398}}],
    Polygon[{{1.663675, 0.447275, -0.073564},{1.672747, 0.440684, -0.068920},{
      1.677735, 0.450473, -0.068920},{1.667070, 0.453939, -0.073564}}],
    Polygon[{{1.672747, 0.440684, -0.068920},{1.681120, 0.434601, -0.062578},{
      1.687578, 0.447275, -0.062578},{1.677735, 0.450473, -0.068920}}],
    Polygon[{{1.681120, 0.434601, -0.062578},{1.688587, 0.429176, -0.054695},{
      1.696355, 0.444423, -0.054695},{1.687578, 0.447275, -0.062578}}],
    Polygon[{{1.688587, 0.429176, -0.054695},{1.694964, 0.424543, -0.045465},{
      1.703853, 0.441987, -0.045465},{1.696355, 0.444423, -0.054695}}],
    Polygon[{{1.694964, 0.424543, -0.045465},{1.700095, 0.420815, -0.035116},{
      1.709884, 0.440028, -0.035116},{1.703853, 0.441987, -0.045465}}],
    Polygon[{{1.700095, 0.420815, -0.035116},{1.703853, 0.418085, -0.023903},{
      1.714302, 0.438592, -0.023903},{1.709884, 0.440028, -0.035116}}],
    Polygon[{{1.703853, 0.418085, -0.023903},{1.706145, 0.416419, -0.012100},{
      1.716996, 0.437717, -0.012100},{1.714302, 0.438592, -0.023903}}],
    Polygon[{{1.706145, 0.416419, -0.012100},{1.706915, 0.415860, 0.000000},{
      1.717902, 0.437422, 0.000000},{1.716996, 0.437717, -0.012100}}],
    Polygon[{{1.706915, 0.415860, 0.000000},{1.706145, 0.416419, 0.012100},{
      1.716996, 0.437717, 0.012100},{1.717902, 0.437422, 0.000000}}],
    Polygon[{{1.706145, 0.416419, 0.012100},{1.703853, 0.418085, 0.023903},{
      1.714302, 0.438592, 0.023903},{1.716996, 0.437717, 0.012100}}],
    Polygon[{{1.703853, 0.418085, 0.023903},{1.700095, 0.420815, 0.035116},{
      1.709884, 0.440028, 0.035116},{1.714302, 0.438592, 0.023903}}],
    Polygon[{{1.700095, 0.420815, 0.035116},{1.694964, 0.424543, 0.045465},{
      1.703853, 0.441987, 0.045465},{1.709884, 0.440028, 0.035116}}],
    Polygon[{{1.694964, 0.424543, 0.045465},{1.688587, 0.429176, 0.054695},{
      1.696355, 0.444423, 0.054695},{1.703853, 0.441987, 0.045465}}],
    Polygon[{{1.688587, 0.429176, 0.054695},{1.681120, 0.434601, 0.062578},{
      1.687578, 0.447275, 0.062578},{1.696355, 0.444423, 0.054695}}],
    Polygon[{{1.681120, 0.434601, 0.062578},{1.672747, 0.440684, 0.068920},{
      1.677735, 0.450473, 0.068920},{1.687578, 0.447275, 0.062578}}],
    Polygon[{{1.672747, 0.440684, 0.068920},{1.663675, 0.447275, 0.073564},{
      1.667070, 0.453939, 0.073564},{1.677735, 0.450473, 0.068920}}],
    Polygon[{{1.663675, 0.447275, 0.073564},{1.654127, 0.454213, 0.076398},{
      1.655846, 0.457586, 0.076398},{1.667070, 0.453939, 0.073564}}],
    Polygon[{{1.655846, 0.457586, -0.076398},{1.667070, 0.453939, -0.073564},{
      1.668240, 0.461325, -0.073564},{1.656438, 0.461325, -0.076398}}],
    Polygon[{{1.667070, 0.453939, -0.073564},{1.677735, 0.450473, -0.068920},{
      1.679454, 0.461325, -0.068920},{1.668240, 0.461325, -0.073564}}],
    Polygon[{{1.677735, 0.450473, -0.068920},{1.687578, 0.447275, -0.062578},{
      1.689803, 0.461325, -0.062578},{1.679454, 0.461325, -0.068920}}],
    Polygon[{{1.687578, 0.447275, -0.062578},{1.696355, 0.444423, -0.054695},{
      1.699032, 0.461325, -0.054695},{1.689803, 0.461325, -0.062578}}],
    Polygon[{{1.696355, 0.444423, -0.054695},{1.703853, 0.441987, -0.045465},{
      1.706915, 0.461325, -0.045465},{1.699032, 0.461325, -0.054695}}],
    Polygon[{{1.703853, 0.441987, -0.045465},{1.709884, 0.440028, -0.035116},{
      1.713257, 0.461325, -0.035116},{1.706915, 0.461325, -0.045465}}],
    Polygon[{{1.709884, 0.440028, -0.035116},{1.714302, 0.438592, -0.023903},{
      1.717902, 0.461325, -0.023903},{1.713257, 0.461325, -0.035116}}],
    Polygon[{{1.714302, 0.438592, -0.023903},{1.716996, 0.437717, -0.012100},{
      1.720736, 0.461325, -0.012100},{1.717902, 0.461325, -0.023903}}],
    Polygon[{{1.716996, 0.437717, -0.012100},{1.717902, 0.437422, 0.000000},{
      1.721688, 0.461325, 0.000000},{1.720736, 0.461325, -0.012100}}],
    Polygon[{{1.717902, 0.437422, 0.000000},{1.716996, 0.437717, 0.012100},{
      1.720736, 0.461325, 0.012100},{1.721688, 0.461325, 0.000000}}],
    Polygon[{{1.716996, 0.437717, 0.012100},{1.714302, 0.438592, 0.023903},{
      1.717902, 0.461325, 0.023903},{1.720736, 0.461325, 0.012100}}],
    Polygon[{{1.714302, 0.438592, 0.023903},{1.709884, 0.440028, 0.035116},{
      1.713257, 0.461325, 0.035116},{1.717902, 0.461325, 0.023903}}],
    Polygon[{{1.709884, 0.440028, 0.035116},{1.703853, 0.441987, 0.045465},{
      1.706915, 0.461325, 0.045465},{1.713257, 0.461325, 0.035116}}],
    Polygon[{{1.703853, 0.441987, 0.045465},{1.696355, 0.444423, 0.054695},{
      1.699032, 0.461325, 0.054695},{1.706915, 0.461325, 0.045465}}],
    Polygon[{{1.696355, 0.444423, 0.054695},{1.687578, 0.447275, 0.062578},{
      1.689803, 0.461325, 0.062578},{1.699032, 0.461325, 0.054695}}],
    Polygon[{{1.687578, 0.447275, 0.062578},{1.677735, 0.450473, 0.068920},{
      1.679454, 0.461325, 0.068920},{1.689803, 0.461325, 0.062578}}],
    Polygon[{{1.677735, 0.450473, 0.068920},{1.667070, 0.453939, 0.073564},{
      1.668240, 0.461325, 0.073564},{1.679454, 0.461325, 0.068920}}],
    Polygon[{{1.667070, 0.453939, 0.073564},{1.655846, 0.457586, 0.076398},{
      1.656438, 0.461325, 0.076398},{1.668240, 0.461325, 0.073564}}],
    Polygon[{{1.625287, 0.577350, -0.040942},{1.631611, 0.577350, -0.039423},{
      1.630985, 0.581309, -0.039423},{1.624969, 0.579354, -0.040942}}],
    Polygon[{{1.631611, 0.577350, -0.039423},{1.637621, 0.577350, -0.036934},{
      1.636700, 0.583166, -0.036934},{1.630985, 0.581309, -0.039423}}],
    Polygon[{{1.637621, 0.577350, -0.036934},{1.643167, 0.577350, -0.033535},{
      1.641974, 0.584879, -0.033535},{1.636700, 0.583166, -0.036934}}],
    Polygon[{{1.643167, 0.577350, -0.033535},{1.648113, 0.577350, -0.029311},{
      1.646678, 0.586408, -0.029311},{1.641974, 0.584879, -0.033535}}],
    Polygon[{{1.648113, 0.577350, -0.029311},{1.652337, 0.577350, -0.024365},{
      1.650696, 0.587713, -0.024365},{1.646678, 0.586408, -0.029311}}],
    Polygon[{{1.652337, 0.577350, -0.024365},{1.655736, 0.577350, -0.018819},{
      1.653928, 0.588763, -0.018819},{1.650696, 0.587713, -0.024365}}],
    Polygon[{{1.655736, 0.577350, -0.018819},{1.658225, 0.577350, -0.012809},{
      1.656296, 0.589533, -0.012809},{1.653928, 0.588763, -0.018819}}],
    Polygon[{{1.658225, 0.577350, -0.012809},{1.659744, 0.577350, -0.006485},{
      1.657740, 0.590002, -0.006485},{1.656296, 0.589533, -0.012809}}],
    Polygon[{{1.659744, 0.577350, -0.006485},{1.660254, 0.577350, 0.000000},{
      1.658225, 0.590160, 0.000000},{1.657740, 0.590002, -0.006485}}],
    Polygon[{{1.660254, 0.577350, 0.000000},{1.659744, 0.577350, 0.006485},{
      1.657740, 0.590002, 0.006485},{1.658225, 0.590160, 0.000000}}],
    Polygon[{{1.659744, 0.577350, 0.006485},{1.658225, 0.577350, 0.012809},{
      1.656296, 0.589533, 0.012809},{1.657740, 0.590002, 0.006485}}],
    Polygon[{{1.658225, 0.577350, 0.012809},{1.655736, 0.577350, 0.018819},{
      1.653928, 0.588763, 0.018819},{1.656296, 0.589533, 0.012809}}],
    Polygon[{{1.655736, 0.577350, 0.018819},{1.652337, 0.577350, 0.024365},{
      1.650696, 0.587713, 0.024365},{1.653928, 0.588763, 0.018819}}],
    Polygon[{{1.652337, 0.577350, 0.024365},{1.648113, 0.577350, 0.029311},{
      1.646678, 0.586408, 0.029311},{1.650696, 0.587713, 0.024365}}],
    Polygon[{{1.648113, 0.577350, 0.029311},{1.643167, 0.577350, 0.033535},{
      1.641974, 0.584879, 0.033535},{1.646678, 0.586408, 0.029311}}],
    Polygon[{{1.643167, 0.577350, 0.033535},{1.637621, 0.577350, 0.036934},{
      1.636700, 0.583166, 0.036934},{1.641974, 0.584879, 0.033535}}],
    Polygon[{{1.637621, 0.577350, 0.036934},{1.631611, 0.577350, 0.039423},{
      1.630985, 0.581309, 0.039423},{1.636700, 0.583166, 0.036934}}],
    Polygon[{{1.631611, 0.577350, 0.039423},{1.625287, 0.577350, 0.040942},{
      1.624969, 0.579354, 0.040942},{1.630985, 0.581309, 0.039423}}],
    Polygon[{{1.624969, 0.579354, -0.040942},{1.630985, 0.581309, -0.039423},{
      1.629165, 0.584879, -0.039423},{1.624048, 0.581162, -0.040942}}],
    Polygon[{{1.630985, 0.581309, -0.039423},{1.636700, 0.583166, -0.036934},{
      1.634027, 0.588412, -0.036934},{1.629165, 0.584879, -0.039423}}],
    Polygon[{{1.636700, 0.583166, -0.036934},{1.641974, 0.584879, -0.033535},{
      1.638514, 0.591672, -0.033535},{1.634027, 0.588412, -0.036934}}],
    Polygon[{{1.641974, 0.584879, -0.033535},{1.646678, 0.586408, -0.029311},{
      1.642515, 0.594579, -0.029311},{1.638514, 0.591672, -0.033535}}],
    Polygon[{{1.646678, 0.586408, -0.029311},{1.650696, 0.587713, -0.024365},{
      1.645933, 0.597062, -0.024365},{1.642515, 0.594579, -0.029311}}],
    Polygon[{{1.650696, 0.587713, -0.024365},{1.653928, 0.588763, -0.018819},{
      1.648682, 0.599059, -0.018819},{1.645933, 0.597062, -0.024365}}],
    Polygon[{{1.653928, 0.588763, -0.018819},{1.656296, 0.589533, -0.012809},{
      1.650696, 0.600523, -0.012809},{1.648682, 0.599059, -0.018819}}],
    Polygon[{{1.656296, 0.589533, -0.012809},{1.657740, 0.590002, -0.006485},{
      1.651925, 0.601415, -0.006485},{1.650696, 0.600523, -0.012809}}],
    Polygon[{{1.657740, 0.590002, -0.006485},{1.658225, 0.590160, 0.000000},{
      1.652337, 0.601715, 0.000000},{1.651925, 0.601415, -0.006485}}],
    Polygon[{{1.658225, 0.590160, 0.000000},{1.657740, 0.590002, 0.006485},{
      1.651925, 0.601415, 0.006485},{1.652337, 0.601715, 0.000000}}],
    Polygon[{{1.657740, 0.590002, 0.006485},{1.656296, 0.589533, 0.012809},{
      1.650696, 0.600523, 0.012809},{1.651925, 0.601415, 0.006485}}],
    Polygon[{{1.656296, 0.589533, 0.012809},{1.653928, 0.588763, 0.018819},{
      1.648682, 0.599059, 0.018819},{1.650696, 0.600523, 0.012809}}],
    Polygon[{{1.653928, 0.588763, 0.018819},{1.650696, 0.587713, 0.024365},{
      1.645933, 0.597062, 0.024365},{1.648682, 0.599059, 0.018819}}],
    Polygon[{{1.650696, 0.587713, 0.024365},{1.646678, 0.586408, 0.029311},{
      1.642515, 0.594579, 0.029311},{1.645933, 0.597062, 0.024365}}],
    Polygon[{{1.646678, 0.586408, 0.029311},{1.641974, 0.584879, 0.033535},{
      1.638514, 0.591672, 0.033535},{1.642515, 0.594579, 0.029311}}],
    Polygon[{{1.641974, 0.584879, 0.033535},{1.636700, 0.583166, 0.036934},{
      1.634027, 0.588412, 0.036934},{1.638514, 0.591672, 0.033535}}],
    Polygon[{{1.636700, 0.583166, 0.036934},{1.630985, 0.581309, 0.039423},{
      1.629165, 0.584879, 0.039423},{1.634027, 0.588412, 0.036934}}],
    Polygon[{{1.630985, 0.581309, 0.039423},{1.624969, 0.579354, 0.040942},{
      1.624048, 0.581162, 0.040942},{1.629165, 0.584879, 0.039423}}],
    Polygon[{{1.624048, 0.581162, -0.040942},{1.629165, 0.584879, -0.039423},{
      1.626331, 0.587713, -0.039423},{1.622614, 0.582596, -0.040942}}],
    Polygon[{{1.629165, 0.584879, -0.039423},{1.634027, 0.588412, -0.036934},{
      1.629864, 0.592575, -0.036934},{1.626331, 0.587713, -0.039423}}],
    Polygon[{{1.634027, 0.588412, -0.036934},{1.638514, 0.591672, -0.033535},{
      1.633123, 0.597062, -0.033535},{1.629864, 0.592575, -0.036934}}],
    Polygon[{{1.638514, 0.591672, -0.033535},{1.642515, 0.594579, -0.029311},{
      1.636031, 0.601063, -0.029311},{1.633123, 0.597062, -0.033535}}],
    Polygon[{{1.642515, 0.594579, -0.029311},{1.645933, 0.597062, -0.024365},{
      1.638514, 0.604481, -0.024365},{1.636031, 0.601063, -0.029311}}],
    Polygon[{{1.645933, 0.597062, -0.024365},{1.648682, 0.599059, -0.018819},{
      1.640511, 0.607230, -0.018819},{1.638514, 0.604481, -0.024365}}],
    Polygon[{{1.648682, 0.599059, -0.018819},{1.650696, 0.600523, -0.012809},{
      1.641974, 0.609244, -0.012809},{1.640511, 0.607230, -0.018819}}],
    Polygon[{{1.650696, 0.600523, -0.012809},{1.651925, 0.601415, -0.006485},{
      1.642867, 0.610473, -0.006485},{1.641974, 0.609244, -0.012809}}],
    Polygon[{{1.651925, 0.601415, -0.006485},{1.652337, 0.601715, 0.000000},{
      1.643167, 0.610886, 0.000000},{1.642867, 0.610473, -0.006485}}],
    Polygon[{{1.652337, 0.601715, 0.000000},{1.651925, 0.601415, 0.006485},{
      1.642867, 0.610473, 0.006485},{1.643167, 0.610886, 0.000000}}],
    Polygon[{{1.651925, 0.601415, 0.006485},{1.650696, 0.600523, 0.012809},{
      1.641974, 0.609244, 0.012809},{1.642867, 0.610473, 0.006485}}],
    Polygon[{{1.650696, 0.600523, 0.012809},{1.648682, 0.599059, 0.018819},{
      1.640511, 0.607230, 0.018819},{1.641974, 0.609244, 0.012809}}],
    Polygon[{{1.648682, 0.599059, 0.018819},{1.645933, 0.597062, 0.024365},{
      1.638514, 0.604481, 0.024365},{1.640511, 0.607230, 0.018819}}],
    Polygon[{{1.645933, 0.597062, 0.024365},{1.642515, 0.594579, 0.029311},{
      1.636031, 0.601063, 0.029311},{1.638514, 0.604481, 0.024365}}],
    Polygon[{{1.642515, 0.594579, 0.029311},{1.638514, 0.591672, 0.033535},{
      1.633123, 0.597062, 0.033535},{1.636031, 0.601063, 0.029311}}],
    Polygon[{{1.638514, 0.591672, 0.033535},{1.634027, 0.588412, 0.036934},{
      1.629864, 0.592575, 0.036934},{1.633123, 0.597062, 0.033535}}],
    Polygon[{{1.634027, 0.588412, 0.036934},{1.629165, 0.584879, 0.039423},{
      1.626331, 0.587713, 0.039423},{1.629864, 0.592575, 0.036934}}],
    Polygon[{{1.629165, 0.584879, 0.039423},{1.624048, 0.581162, 0.040942},{
      1.622614, 0.582596, 0.040942},{1.626331, 0.587713, 0.039423}}],
    Polygon[{{1.622614, 0.582596, -0.040942},{1.626331, 0.587713, -0.039423},{
      1.622760, 0.589533, -0.039423},{1.620806, 0.583517, -0.040942}}],
    Polygon[{{1.626331, 0.587713, -0.039423},{1.629864, 0.592575, -0.036934},{
      1.624617, 0.595248, -0.036934},{1.622760, 0.589533, -0.039423}}],
    Polygon[{{1.629864, 0.592575, -0.036934},{1.633123, 0.597062, -0.033535},{
      1.626331, 0.600523, -0.033535},{1.624617, 0.595248, -0.036934}}],
    Polygon[{{1.633123, 0.597062, -0.033535},{1.636031, 0.601063, -0.029311},{
      1.627860, 0.605227, -0.029311},{1.626331, 0.600523, -0.033535}}],
    Polygon[{{1.636031, 0.601063, -0.029311},{1.638514, 0.604481, -0.024365},{
      1.629165, 0.609244, -0.024365},{1.627860, 0.605227, -0.029311}}],
    Polygon[{{1.638514, 0.604481, -0.024365},{1.640511, 0.607230, -0.018819},{
      1.630215, 0.612476, -0.018819},{1.629165, 0.609244, -0.024365}}],
    Polygon[{{1.640511, 0.607230, -0.018819},{1.641974, 0.609244, -0.012809},{
      1.630985, 0.614844, -0.012809},{1.630215, 0.612476, -0.018819}}],
    Polygon[{{1.641974, 0.609244, -0.012809},{1.642867, 0.610473, -0.006485},{
      1.631454, 0.616288, -0.006485},{1.630985, 0.614844, -0.012809}}],
    Polygon[{{1.642867, 0.610473, -0.006485},{1.643167, 0.610886, 0.000000},{
      1.631611, 0.616773, 0.000000},{1.631454, 0.616288, -0.006485}}],
    Polygon[{{1.643167, 0.610886, 0.000000},{1.642867, 0.610473, 0.006485},{
      1.631454, 0.616288, 0.006485},{1.631611, 0.616773, 0.000000}}],
    Polygon[{{1.642867, 0.610473, 0.006485},{1.641974, 0.609244, 0.012809},{
      1.630985, 0.614844, 0.012809},{1.631454, 0.616288, 0.006485}}],
    Polygon[{{1.641974, 0.609244, 0.012809},{1.640511, 0.607230, 0.018819},{
      1.630215, 0.612476, 0.018819},{1.630985, 0.614844, 0.012809}}],
    Polygon[{{1.640511, 0.607230, 0.018819},{1.638514, 0.604481, 0.024365},{
      1.629165, 0.609244, 0.024365},{1.630215, 0.612476, 0.018819}}],
    Polygon[{{1.638514, 0.604481, 0.024365},{1.636031, 0.601063, 0.029311},{
      1.627860, 0.605227, 0.029311},{1.629165, 0.609244, 0.024365}}],
    Polygon[{{1.636031, 0.601063, 0.029311},{1.633123, 0.597062, 0.033535},{
      1.626331, 0.600523, 0.033535},{1.627860, 0.605227, 0.029311}}],
    Polygon[{{1.633123, 0.597062, 0.033535},{1.629864, 0.592575, 0.036934},{
      1.624617, 0.595248, 0.036934},{1.626331, 0.600523, 0.033535}}],
    Polygon[{{1.629864, 0.592575, 0.036934},{1.626331, 0.587713, 0.039423},{
      1.622760, 0.589533, 0.039423},{1.624617, 0.595248, 0.036934}}],
    Polygon[{{1.626331, 0.587713, 0.039423},{1.622614, 0.582596, 0.040942},{
      1.620806, 0.583517, 0.040942},{1.622760, 0.589533, 0.039423}}],
    Polygon[{{1.620806, 0.583517, -0.040942},{1.622760, 0.589533, -0.039423},{
      1.618802, 0.590160, -0.039423},{1.618802, 0.583835, -0.040942}}],
    Polygon[{{1.622760, 0.589533, -0.039423},{1.624617, 0.595248, -0.036934},{
      1.618802, 0.596169, -0.036934},{1.618802, 0.590160, -0.039423}}],
    Polygon[{{1.624617, 0.595248, -0.036934},{1.626331, 0.600523, -0.033535},{
      1.618802, 0.601715, -0.033535},{1.618802, 0.596169, -0.036934}}],
    Polygon[{{1.626331, 0.600523, -0.033535},{1.627860, 0.605227, -0.029311},{
      1.618802, 0.606661, -0.029311},{1.618802, 0.601715, -0.033535}}],
    Polygon[{{1.627860, 0.605227, -0.029311},{1.629165, 0.609244, -0.024365},{
      1.618802, 0.610886, -0.024365},{1.618802, 0.606661, -0.029311}}],
    Polygon[{{1.629165, 0.609244, -0.024365},{1.630215, 0.612476, -0.018819},{
      1.618802, 0.614284, -0.018819},{1.618802, 0.610886, -0.024365}}],
    Polygon[{{1.630215, 0.612476, -0.018819},{1.630985, 0.614844, -0.012809},{
      1.618802, 0.616773, -0.012809},{1.618802, 0.614284, -0.018819}}],
    Polygon[{{1.630985, 0.614844, -0.012809},{1.631454, 0.616288, -0.006485},{
      1.618802, 0.618292, -0.006485},{1.618802, 0.616773, -0.012809}}],
    Polygon[{{1.631454, 0.616288, -0.006485},{1.631611, 0.616773, 0.000000},{
      1.618802, 0.618802, 0.000000},{1.618802, 0.618292, -0.006485}}],
    Polygon[{{1.631611, 0.616773, 0.000000},{1.631454, 0.616288, 0.006485},{
      1.618802, 0.618292, 0.006485},{1.618802, 0.618802, 0.000000}}],
    Polygon[{{1.631454, 0.616288, 0.006485},{1.630985, 0.614844, 0.012809},{
      1.618802, 0.616773, 0.012809},{1.618802, 0.618292, 0.006485}}],
    Polygon[{{1.630985, 0.614844, 0.012809},{1.630215, 0.612476, 0.018819},{
      1.618802, 0.614284, 0.018819},{1.618802, 0.616773, 0.012809}}],
    Polygon[{{1.630215, 0.612476, 0.018819},{1.629165, 0.609244, 0.024365},{
      1.618802, 0.610886, 0.024365},{1.618802, 0.614284, 0.018819}}],
    Polygon[{{1.629165, 0.609244, 0.024365},{1.627860, 0.605227, 0.029311},{
      1.618802, 0.606661, 0.029311},{1.618802, 0.610886, 0.024365}}],
    Polygon[{{1.627860, 0.605227, 0.029311},{1.626331, 0.600523, 0.033535},{
      1.618802, 0.601715, 0.033535},{1.618802, 0.606661, 0.029311}}],
    Polygon[{{1.626331, 0.600523, 0.033535},{1.624617, 0.595248, 0.036934},{
      1.618802, 0.596169, 0.036934},{1.618802, 0.601715, 0.033535}}],
    Polygon[{{1.624617, 0.595248, 0.036934},{1.622760, 0.589533, 0.039423},{
      1.618802, 0.590160, 0.039423},{1.618802, 0.596169, 0.036934}}],
    Polygon[{{1.622760, 0.589533, 0.039423},{1.620806, 0.583517, 0.040942},{
      1.618802, 0.583835, 0.040942},{1.618802, 0.590160, 0.039423}}],
    Polygon[{{1.618802, 0.583835, -0.040942},{1.618802, 0.590160, -0.039423},{
      1.614844, 0.589533, -0.039423},{1.616798, 0.583517, -0.040942}}],
    Polygon[{{1.618802, 0.590160, -0.039423},{1.618802, 0.596169, -0.036934},{
      1.612987, 0.595248, -0.036934},{1.614844, 0.589533, -0.039423}}],
    Polygon[{{1.618802, 0.596169, -0.036934},{1.618802, 0.601715, -0.033535},{
      1.611273, 0.600523, -0.033535},{1.612987, 0.595248, -0.036934}}],
    Polygon[{{1.618802, 0.601715, -0.033535},{1.618802, 0.606661, -0.029311},{
      1.609745, 0.605227, -0.029311},{1.611273, 0.600523, -0.033535}}],
    Polygon[{{1.618802, 0.606661, -0.029311},{1.618802, 0.610886, -0.024365},{
      1.608439, 0.609244, -0.024365},{1.609745, 0.605227, -0.029311}}],
    Polygon[{{1.618802, 0.610886, -0.024365},{1.618802, 0.614284, -0.018819},{
      1.607389, 0.612476, -0.018819},{1.608439, 0.609244, -0.024365}}],
    Polygon[{{1.618802, 0.614284, -0.018819},{1.618802, 0.616773, -0.012809},{
      1.606620, 0.614844, -0.012809},{1.607389, 0.612476, -0.018819}}],
    Polygon[{{1.618802, 0.616773, -0.012809},{1.618802, 0.618292, -0.006485},{
      1.606151, 0.616288, -0.006485},{1.606620, 0.614844, -0.012809}}],
    Polygon[{{1.618802, 0.618292, -0.006485},{1.618802, 0.618802, 0.000000},{
      1.605993, 0.616773, 0.000000},{1.606151, 0.616288, -0.006485}}],
    Polygon[{{1.618802, 0.618802, 0.000000},{1.618802, 0.618292, 0.006485},{
      1.606151, 0.616288, 0.006485},{1.605993, 0.616773, 0.000000}}],
    Polygon[{{1.618802, 0.618292, 0.006485},{1.618802, 0.616773, 0.012809},{
      1.606620, 0.614844, 0.012809},{1.606151, 0.616288, 0.006485}}],
    Polygon[{{1.618802, 0.616773, 0.012809},{1.618802, 0.614284, 0.018819},{
      1.607389, 0.612476, 0.018819},{1.606620, 0.614844, 0.012809}}],
    Polygon[{{1.618802, 0.614284, 0.018819},{1.618802, 0.610886, 0.024365},{
      1.608439, 0.609244, 0.024365},{1.607389, 0.612476, 0.018819}}],
    Polygon[{{1.618802, 0.610886, 0.024365},{1.618802, 0.606661, 0.029311},{
      1.609745, 0.605227, 0.029311},{1.608439, 0.609244, 0.024365}}],
    Polygon[{{1.618802, 0.606661, 0.029311},{1.618802, 0.601715, 0.033535},{
      1.611273, 0.600523, 0.033535},{1.609745, 0.605227, 0.029311}}],
    Polygon[{{1.618802, 0.601715, 0.033535},{1.618802, 0.596169, 0.036934},{
      1.612987, 0.595248, 0.036934},{1.611273, 0.600523, 0.033535}}],
    Polygon[{{1.618802, 0.596169, 0.036934},{1.618802, 0.590160, 0.039423},{
      1.614844, 0.589533, 0.039423},{1.612987, 0.595248, 0.036934}}],
    Polygon[{{1.618802, 0.590160, 0.039423},{1.618802, 0.583835, 0.040942},{
      1.616798, 0.583517, 0.040942},{1.614844, 0.589533, 0.039423}}],
    Polygon[{{1.616798, 0.583517, -0.040942},{1.614844, 0.589533, -0.039423},{
      1.611273, 0.587713, -0.039423},{1.614991, 0.582596, -0.040942}}],
    Polygon[{{1.614844, 0.589533, -0.039423},{1.612987, 0.595248, -0.036934},{
      1.607741, 0.592575, -0.036934},{1.611273, 0.587713, -0.039423}}],
    Polygon[{{1.612987, 0.595248, -0.036934},{1.611273, 0.600523, -0.033535},{
      1.604481, 0.597062, -0.033535},{1.607741, 0.592575, -0.036934}}],
    Polygon[{{1.611273, 0.600523, -0.033535},{1.609745, 0.605227, -0.029311},{
      1.601574, 0.601063, -0.029311},{1.604481, 0.597062, -0.033535}}],
    Polygon[{{1.609745, 0.605227, -0.029311},{1.608439, 0.609244, -0.024365},{
      1.599091, 0.604481, -0.024365},{1.601574, 0.601063, -0.029311}}],
    Polygon[{{1.608439, 0.609244, -0.024365},{1.607389, 0.612476, -0.018819},{
      1.597093, 0.607230, -0.018819},{1.599091, 0.604481, -0.024365}}],
    Polygon[{{1.607389, 0.612476, -0.018819},{1.606620, 0.614844, -0.012809},{
      1.595630, 0.609244, -0.012809},{1.597093, 0.607230, -0.018819}}],
    Polygon[{{1.606620, 0.614844, -0.012809},{1.606151, 0.616288, -0.006485},{
      1.594737, 0.610473, -0.006485},{1.595630, 0.609244, -0.012809}}],
    Polygon[{{1.606151, 0.616288, -0.006485},{1.605993, 0.616773, 0.000000},{
      1.594437, 0.610886, 0.000000},{1.594737, 0.610473, -0.006485}}],
    Polygon[{{1.605993, 0.616773, 0.000000},{1.606151, 0.616288, 0.006485},{
      1.594737, 0.610473, 0.006485},{1.594437, 0.610886, 0.000000}}],
    Polygon[{{1.606151, 0.616288, 0.006485},{1.606620, 0.614844, 0.012809},{
      1.595630, 0.609244, 0.012809},{1.594737, 0.610473, 0.006485}}],
    Polygon[{{1.606620, 0.614844, 0.012809},{1.607389, 0.612476, 0.018819},{
      1.597093, 0.607230, 0.018819},{1.595630, 0.609244, 0.012809}}],
    Polygon[{{1.607389, 0.612476, 0.018819},{1.608439, 0.609244, 0.024365},{
      1.599091, 0.604481, 0.024365},{1.597093, 0.607230, 0.018819}}],
    Polygon[{{1.608439, 0.609244, 0.024365},{1.609745, 0.605227, 0.029311},{
      1.601574, 0.601063, 0.029311},{1.599091, 0.604481, 0.024365}}],
    Polygon[{{1.609745, 0.605227, 0.029311},{1.611273, 0.600523, 0.033535},{
      1.604481, 0.597062, 0.033535},{1.601574, 0.601063, 0.029311}}],
    Polygon[{{1.611273, 0.600523, 0.033535},{1.612987, 0.595248, 0.036934},{
      1.607741, 0.592575, 0.036934},{1.604481, 0.597062, 0.033535}}],
    Polygon[{{1.612987, 0.595248, 0.036934},{1.614844, 0.589533, 0.039423},{
      1.611273, 0.587713, 0.039423},{1.607741, 0.592575, 0.036934}}],
    Polygon[{{1.614844, 0.589533, 0.039423},{1.616798, 0.583517, 0.040942},{
      1.614991, 0.582596, 0.040942},{1.611273, 0.587713, 0.039423}}],
    Polygon[{{1.614991, 0.582596, -0.040942},{1.611273, 0.587713, -0.039423},{
      1.608439, 0.584879, -0.039423},{1.613556, 0.581162, -0.040942}}],
    Polygon[{{1.611273, 0.587713, -0.039423},{1.607741, 0.592575, -0.036934},{
      1.603577, 0.588412, -0.036934},{1.608439, 0.584879, -0.039423}}],
    Polygon[{{1.607741, 0.592575, -0.036934},{1.604481, 0.597062, -0.033535},{
      1.599091, 0.591672, -0.033535},{1.603577, 0.588412, -0.036934}}],
    Polygon[{{1.604481, 0.597062, -0.033535},{1.601574, 0.601063, -0.029311},{
      1.595089, 0.594579, -0.029311},{1.599091, 0.591672, -0.033535}}],
    Polygon[{{1.601574, 0.601063, -0.029311},{1.599091, 0.604481, -0.024365},{
      1.591672, 0.597062, -0.024365},{1.595089, 0.594579, -0.029311}}],
    Polygon[{{1.599091, 0.604481, -0.024365},{1.597093, 0.607230, -0.018819},{
      1.588922, 0.599059, -0.018819},{1.591672, 0.597062, -0.024365}}],
    Polygon[{{1.597093, 0.607230, -0.018819},{1.595630, 0.609244, -0.012809},{
      1.586908, 0.600523, -0.012809},{1.588922, 0.599059, -0.018819}}],
    Polygon[{{1.595630, 0.609244, -0.012809},{1.594737, 0.610473, -0.006485},{
      1.585680, 0.601415, -0.006485},{1.586908, 0.600523, -0.012809}}],
    Polygon[{{1.594737, 0.610473, -0.006485},{1.594437, 0.610886, 0.000000},{
      1.585267, 0.601715, 0.000000},{1.585680, 0.601415, -0.006485}}],
    Polygon[{{1.594437, 0.610886, 0.000000},{1.594737, 0.610473, 0.006485},{
      1.585680, 0.601415, 0.006485},{1.585267, 0.601715, 0.000000}}],
    Polygon[{{1.594737, 0.610473, 0.006485},{1.595630, 0.609244, 0.012809},{
      1.586908, 0.600523, 0.012809},{1.585680, 0.601415, 0.006485}}],
    Polygon[{{1.595630, 0.609244, 0.012809},{1.597093, 0.607230, 0.018819},{
      1.588922, 0.599059, 0.018819},{1.586908, 0.600523, 0.012809}}],
    Polygon[{{1.597093, 0.607230, 0.018819},{1.599091, 0.604481, 0.024365},{
      1.591672, 0.597062, 0.024365},{1.588922, 0.599059, 0.018819}}],
    Polygon[{{1.599091, 0.604481, 0.024365},{1.601574, 0.601063, 0.029311},{
      1.595089, 0.594579, 0.029311},{1.591672, 0.597062, 0.024365}}],
    Polygon[{{1.601574, 0.601063, 0.029311},{1.604481, 0.597062, 0.033535},{
      1.599091, 0.591672, 0.033535},{1.595089, 0.594579, 0.029311}}],
    Polygon[{{1.604481, 0.597062, 0.033535},{1.607741, 0.592575, 0.036934},{
      1.603577, 0.588412, 0.036934},{1.599091, 0.591672, 0.033535}}],
    Polygon[{{1.607741, 0.592575, 0.036934},{1.611273, 0.587713, 0.039423},{
      1.608439, 0.584879, 0.039423},{1.603577, 0.588412, 0.036934}}],
    Polygon[{{1.611273, 0.587713, 0.039423},{1.614991, 0.582596, 0.040942},{
      1.613556, 0.581162, 0.040942},{1.608439, 0.584879, 0.039423}}],
    Polygon[{{1.613556, 0.581162, -0.040942},{1.608439, 0.584879, -0.039423},{
      1.606620, 0.581309, -0.039423},{1.612635, 0.579354, -0.040942}}],
    Polygon[{{1.608439, 0.584879, -0.039423},{1.603577, 0.588412, -0.036934},{
      1.600904, 0.583166, -0.036934},{1.606620, 0.581309, -0.039423}}],
    Polygon[{{1.603577, 0.588412, -0.036934},{1.599091, 0.591672, -0.033535},{
      1.595630, 0.584879, -0.033535},{1.600904, 0.583166, -0.036934}}],
    Polygon[{{1.599091, 0.591672, -0.033535},{1.595089, 0.594579, -0.029311},{
      1.590926, 0.586408, -0.029311},{1.595630, 0.584879, -0.033535}}],
    Polygon[{{1.595089, 0.594579, -0.029311},{1.591672, 0.597062, -0.024365},{
      1.586908, 0.587713, -0.024365},{1.590926, 0.586408, -0.029311}}],
    Polygon[{{1.591672, 0.597062, -0.024365},{1.588922, 0.599059, -0.018819},{
      1.583676, 0.588763, -0.018819},{1.586908, 0.587713, -0.024365}}],
    Polygon[{{1.588922, 0.599059, -0.018819},{1.586908, 0.600523, -0.012809},{
      1.581309, 0.589533, -0.012809},{1.583676, 0.588763, -0.018819}}],
    Polygon[{{1.586908, 0.600523, -0.012809},{1.585680, 0.601415, -0.006485},{
      1.579864, 0.590002, -0.006485},{1.581309, 0.589533, -0.012809}}],
    Polygon[{{1.585680, 0.601415, -0.006485},{1.585267, 0.601715, 0.000000},{
      1.579379, 0.590160, 0.000000},{1.579864, 0.590002, -0.006485}}],
    Polygon[{{1.585267, 0.601715, 0.000000},{1.585680, 0.601415, 0.006485},{
      1.579864, 0.590002, 0.006485},{1.579379, 0.590160, 0.000000}}],
    Polygon[{{1.585680, 0.601415, 0.006485},{1.586908, 0.600523, 0.012809},{
      1.581309, 0.589533, 0.012809},{1.579864, 0.590002, 0.006485}}],
    Polygon[{{1.586908, 0.600523, 0.012809},{1.588922, 0.599059, 0.018819},{
      1.583676, 0.588763, 0.018819},{1.581309, 0.589533, 0.012809}}],
    Polygon[{{1.588922, 0.599059, 0.018819},{1.591672, 0.597062, 0.024365},{
      1.586908, 0.587713, 0.024365},{1.583676, 0.588763, 0.018819}}],
    Polygon[{{1.591672, 0.597062, 0.024365},{1.595089, 0.594579, 0.029311},{
      1.590926, 0.586408, 0.029311},{1.586908, 0.587713, 0.024365}}],
    Polygon[{{1.595089, 0.594579, 0.029311},{1.599091, 0.591672, 0.033535},{
      1.595630, 0.584879, 0.033535},{1.590926, 0.586408, 0.029311}}],
    Polygon[{{1.599091, 0.591672, 0.033535},{1.603577, 0.588412, 0.036934},{
      1.600904, 0.583166, 0.036934},{1.595630, 0.584879, 0.033535}}],
    Polygon[{{1.603577, 0.588412, 0.036934},{1.608439, 0.584879, 0.039423},{
      1.606620, 0.581309, 0.039423},{1.600904, 0.583166, 0.036934}}],
    Polygon[{{1.608439, 0.584879, 0.039423},{1.613556, 0.581162, 0.040942},{
      1.612635, 0.579354, 0.040942},{1.606620, 0.581309, 0.039423}}],
    Polygon[{{1.612635, 0.579354, -0.040942},{1.606620, 0.581309, -0.039423},{
      1.605993, 0.577350, -0.039423},{1.612318, 0.577350, -0.040942}}],
    Polygon[{{1.606620, 0.581309, -0.039423},{1.600904, 0.583166, -0.036934},{
      1.599983, 0.577350, -0.036934},{1.605993, 0.577350, -0.039423}}],
    Polygon[{{1.600904, 0.583166, -0.036934},{1.595630, 0.584879, -0.033535},{
      1.594437, 0.577350, -0.033535},{1.599983, 0.577350, -0.036934}}],
    Polygon[{{1.595630, 0.584879, -0.033535},{1.590926, 0.586408, -0.029311},{
      1.589491, 0.577350, -0.029311},{1.594437, 0.577350, -0.033535}}],
    Polygon[{{1.590926, 0.586408, -0.029311},{1.586908, 0.587713, -0.024365},{
      1.585267, 0.577350, -0.024365},{1.589491, 0.577350, -0.029311}}],
    Polygon[{{1.586908, 0.587713, -0.024365},{1.583676, 0.588763, -0.018819},{
      1.581868, 0.577350, -0.018819},{1.585267, 0.577350, -0.024365}}],
    Polygon[{{1.583676, 0.588763, -0.018819},{1.581309, 0.589533, -0.012809},{
      1.579379, 0.577350, -0.012809},{1.581868, 0.577350, -0.018819}}],
    Polygon[{{1.581309, 0.589533, -0.012809},{1.579864, 0.590002, -0.006485},{
      1.577861, 0.577350, -0.006485},{1.579379, 0.577350, -0.012809}}],
    Polygon[{{1.579864, 0.590002, -0.006485},{1.579379, 0.590160, 0.000000},{
      1.577350, 0.577350, 0.000000},{1.577861, 0.577350, -0.006485}}],
    Polygon[{{1.579379, 0.590160, 0.000000},{1.579864, 0.590002, 0.006485},{
      1.577861, 0.577350, 0.006485},{1.577350, 0.577350, 0.000000}}],
    Polygon[{{1.579864, 0.590002, 0.006485},{1.581309, 0.589533, 0.012809},{
      1.579379, 0.577350, 0.012809},{1.577861, 0.577350, 0.006485}}],
    Polygon[{{1.581309, 0.589533, 0.012809},{1.583676, 0.588763, 0.018819},{
      1.581868, 0.577350, 0.018819},{1.579379, 0.577350, 0.012809}}],
    Polygon[{{1.583676, 0.588763, 0.018819},{1.586908, 0.587713, 0.024365},{
      1.585267, 0.577350, 0.024365},{1.581868, 0.577350, 0.018819}}],
    Polygon[{{1.586908, 0.587713, 0.024365},{1.590926, 0.586408, 0.029311},{
      1.589491, 0.577350, 0.029311},{1.585267, 0.577350, 0.024365}}],
    Polygon[{{1.590926, 0.586408, 0.029311},{1.595630, 0.584879, 0.033535},{
      1.594437, 0.577350, 0.033535},{1.589491, 0.577350, 0.029311}}],
    Polygon[{{1.595630, 0.584879, 0.033535},{1.600904, 0.583166, 0.036934},{
      1.599983, 0.577350, 0.036934},{1.594437, 0.577350, 0.033535}}],
    Polygon[{{1.600904, 0.583166, 0.036934},{1.606620, 0.581309, 0.039423},{
      1.605993, 0.577350, 0.039423},{1.599983, 0.577350, 0.036934}}],
    Polygon[{{1.606620, 0.581309, 0.039423},{1.612635, 0.579354, 0.040942},{
      1.612318, 0.577350, 0.040942},{1.605993, 0.577350, 0.039423}}],
    Polygon[{{1.612318, 0.577350, -0.040942},{1.605993, 0.577350, -0.039423},{
      1.606620, 0.573392, -0.039423},{1.612635, 0.575346, -0.040942}}],
    Polygon[{{1.605993, 0.577350, -0.039423},{1.599983, 0.577350, -0.036934},{
      1.600904, 0.571535, -0.036934},{1.606620, 0.573392, -0.039423}}],
    Polygon[{{1.599983, 0.577350, -0.036934},{1.594437, 0.577350, -0.033535},{
      1.595630, 0.569821, -0.033535},{1.600904, 0.571535, -0.036934}}],
    Polygon[{{1.594437, 0.577350, -0.033535},{1.589491, 0.577350, -0.029311},{
      1.590926, 0.568293, -0.029311},{1.595630, 0.569821, -0.033535}}],
    Polygon[{{1.589491, 0.577350, -0.029311},{1.585267, 0.577350, -0.024365},{
      1.586908, 0.566987, -0.024365},{1.590926, 0.568293, -0.029311}}],
    Polygon[{{1.585267, 0.577350, -0.024365},{1.581868, 0.577350, -0.018819},{
      1.583676, 0.565937, -0.018819},{1.586908, 0.566987, -0.024365}}],
    Polygon[{{1.581868, 0.577350, -0.018819},{1.579379, 0.577350, -0.012809},{
      1.581309, 0.565168, -0.012809},{1.583676, 0.565937, -0.018819}}],
    Polygon[{{1.579379, 0.577350, -0.012809},{1.577861, 0.577350, -0.006485},{
      1.579864, 0.564699, -0.006485},{1.581309, 0.565168, -0.012809}}],
    Polygon[{{1.577861, 0.577350, -0.006485},{1.577350, 0.577350, 0.000000},{
      1.579379, 0.564541, 0.000000},{1.579864, 0.564699, -0.006485}}],
    Polygon[{{1.577350, 0.577350, 0.000000},{1.577861, 0.577350, 0.006485},{
      1.579864, 0.564699, 0.006485},{1.579379, 0.564541, 0.000000}}],
    Polygon[{{1.577861, 0.577350, 0.006485},{1.579379, 0.577350, 0.012809},{
      1.581309, 0.565168, 0.012809},{1.579864, 0.564699, 0.006485}}],
    Polygon[{{1.579379, 0.577350, 0.012809},{1.581868, 0.577350, 0.018819},{
      1.583676, 0.565937, 0.018819},{1.581309, 0.565168, 0.012809}}],
    Polygon[{{1.581868, 0.577350, 0.018819},{1.585267, 0.577350, 0.024365},{
      1.586908, 0.566987, 0.024365},{1.583676, 0.565937, 0.018819}}],
    Polygon[{{1.585267, 0.577350, 0.024365},{1.589491, 0.577350, 0.029311},{
      1.590926, 0.568293, 0.029311},{1.586908, 0.566987, 0.024365}}],
    Polygon[{{1.589491, 0.577350, 0.029311},{1.594437, 0.577350, 0.033535},{
      1.595630, 0.569821, 0.033535},{1.590926, 0.568293, 0.029311}}],
    Polygon[{{1.594437, 0.577350, 0.033535},{1.599983, 0.577350, 0.036934},{
      1.600904, 0.571535, 0.036934},{1.595630, 0.569821, 0.033535}}],
    Polygon[{{1.599983, 0.577350, 0.036934},{1.605993, 0.577350, 0.039423},{
      1.606620, 0.573392, 0.039423},{1.600904, 0.571535, 0.036934}}],
    Polygon[{{1.605993, 0.577350, 0.039423},{1.612318, 0.577350, 0.040942},{
      1.612635, 0.575346, 0.040942},{1.606620, 0.573392, 0.039423}}],
    Polygon[{{1.612635, 0.575346, -0.040942},{1.606620, 0.573392, -0.039423},{
      1.608439, 0.569821, -0.039423},{1.613556, 0.573539, -0.040942}}],
    Polygon[{{1.606620, 0.573392, -0.039423},{1.600904, 0.571535, -0.036934},{
      1.603577, 0.566289, -0.036934},{1.608439, 0.569821, -0.039423}}],
    Polygon[{{1.600904, 0.571535, -0.036934},{1.595630, 0.569821, -0.033535},{
      1.599091, 0.563029, -0.033535},{1.603577, 0.566289, -0.036934}}],
    Polygon[{{1.595630, 0.569821, -0.033535},{1.590926, 0.568293, -0.029311},{
      1.595089, 0.560122, -0.029311},{1.599091, 0.563029, -0.033535}}],
    Polygon[{{1.590926, 0.568293, -0.029311},{1.586908, 0.566987, -0.024365},{
      1.591672, 0.557639, -0.024365},{1.595089, 0.560122, -0.029311}}],
    Polygon[{{1.586908, 0.566987, -0.024365},{1.583676, 0.565937, -0.018819},{
      1.588922, 0.555641, -0.018819},{1.591672, 0.557639, -0.024365}}],
    Polygon[{{1.583676, 0.565937, -0.018819},{1.581309, 0.565168, -0.012809},{
      1.586908, 0.554178, -0.012809},{1.588922, 0.555641, -0.018819}}],
    Polygon[{{1.581309, 0.565168, -0.012809},{1.579864, 0.564699, -0.006485},{
      1.585680, 0.553285, -0.006485},{1.586908, 0.554178, -0.012809}}],
    Polygon[{{1.579864, 0.564699, -0.006485},{1.579379, 0.564541, 0.000000},{
      1.585267, 0.552985, 0.000000},{1.585680, 0.553285, -0.006485}}],
    Polygon[{{1.579379, 0.564541, 0.000000},{1.579864, 0.564699, 0.006485},{
      1.585680, 0.553285, 0.006485},{1.585267, 0.552985, 0.000000}}],
    Polygon[{{1.579864, 0.564699, 0.006485},{1.581309, 0.565168, 0.012809},{
      1.586908, 0.554178, 0.012809},{1.585680, 0.553285, 0.006485}}],
    Polygon[{{1.581309, 0.565168, 0.012809},{1.583676, 0.565937, 0.018819},{
      1.588922, 0.555641, 0.018819},{1.586908, 0.554178, 0.012809}}],
    Polygon[{{1.583676, 0.565937, 0.018819},{1.586908, 0.566987, 0.024365},{
      1.591672, 0.557639, 0.024365},{1.588922, 0.555641, 0.018819}}],
    Polygon[{{1.586908, 0.566987, 0.024365},{1.590926, 0.568293, 0.029311},{
      1.595089, 0.560122, 0.029311},{1.591672, 0.557639, 0.024365}}],
    Polygon[{{1.590926, 0.568293, 0.029311},{1.595630, 0.569821, 0.033535},{
      1.599091, 0.563029, 0.033535},{1.595089, 0.560122, 0.029311}}],
    Polygon[{{1.595630, 0.569821, 0.033535},{1.600904, 0.571535, 0.036934},{
      1.603577, 0.566289, 0.036934},{1.599091, 0.563029, 0.033535}}],
    Polygon[{{1.600904, 0.571535, 0.036934},{1.606620, 0.573392, 0.039423},{
      1.608439, 0.569821, 0.039423},{1.603577, 0.566289, 0.036934}}],
    Polygon[{{1.606620, 0.573392, 0.039423},{1.612635, 0.575346, 0.040942},{
      1.613556, 0.573539, 0.040942},{1.608439, 0.569821, 0.039423}}],
    Polygon[{{1.613556, 0.573539, -0.040942},{1.608439, 0.569821, -0.039423},{
      1.611273, 0.566987, -0.039423},{1.614991, 0.572104, -0.040942}}],
    Polygon[{{1.608439, 0.569821, -0.039423},{1.603577, 0.566289, -0.036934},{
      1.607741, 0.562126, -0.036934},{1.611273, 0.566987, -0.039423}}],
    Polygon[{{1.603577, 0.566289, -0.036934},{1.599091, 0.563029, -0.033535},{
      1.604481, 0.557639, -0.033535},{1.607741, 0.562126, -0.036934}}],
    Polygon[{{1.599091, 0.563029, -0.033535},{1.595089, 0.560122, -0.029311},{
      1.601574, 0.553637, -0.029311},{1.604481, 0.557639, -0.033535}}],
    Polygon[{{1.595089, 0.560122, -0.029311},{1.591672, 0.557639, -0.024365},{
      1.599091, 0.550220, -0.024365},{1.601574, 0.553637, -0.029311}}],
    Polygon[{{1.591672, 0.557639, -0.024365},{1.588922, 0.555641, -0.018819},{
      1.597093, 0.547470, -0.018819},{1.599091, 0.550220, -0.024365}}],
    Polygon[{{1.588922, 0.555641, -0.018819},{1.586908, 0.554178, -0.012809},{
      1.595630, 0.545456, -0.012809},{1.597093, 0.547470, -0.018819}}],
    Polygon[{{1.586908, 0.554178, -0.012809},{1.585680, 0.553285, -0.006485},{
      1.594737, 0.544228, -0.006485},{1.595630, 0.545456, -0.012809}}],
    Polygon[{{1.585680, 0.553285, -0.006485},{1.585267, 0.552985, 0.000000},{
      1.594437, 0.543815, 0.000000},{1.594737, 0.544228, -0.006485}}],
    Polygon[{{1.585267, 0.552985, 0.000000},{1.585680, 0.553285, 0.006485},{
      1.594737, 0.544228, 0.006485},{1.594437, 0.543815, 0.000000}}],
    Polygon[{{1.585680, 0.553285, 0.006485},{1.586908, 0.554178, 0.012809},{
      1.595630, 0.545456, 0.012809},{1.594737, 0.544228, 0.006485}}],
    Polygon[{{1.586908, 0.554178, 0.012809},{1.588922, 0.555641, 0.018819},{
      1.597093, 0.547470, 0.018819},{1.595630, 0.545456, 0.012809}}],
    Polygon[{{1.588922, 0.555641, 0.018819},{1.591672, 0.557639, 0.024365},{
      1.599091, 0.550220, 0.024365},{1.597093, 0.547470, 0.018819}}],
    Polygon[{{1.591672, 0.557639, 0.024365},{1.595089, 0.560122, 0.029311},{
      1.601574, 0.553637, 0.029311},{1.599091, 0.550220, 0.024365}}],
    Polygon[{{1.595089, 0.560122, 0.029311},{1.599091, 0.563029, 0.033535},{
      1.604481, 0.557639, 0.033535},{1.601574, 0.553637, 0.029311}}],
    Polygon[{{1.599091, 0.563029, 0.033535},{1.603577, 0.566289, 0.036934},{
      1.607741, 0.562126, 0.036934},{1.604481, 0.557639, 0.033535}}],
    Polygon[{{1.603577, 0.566289, 0.036934},{1.608439, 0.569821, 0.039423},{
      1.611273, 0.566987, 0.039423},{1.607741, 0.562126, 0.036934}}],
    Polygon[{{1.608439, 0.569821, 0.039423},{1.613556, 0.573539, 0.040942},{
      1.614991, 0.572104, 0.040942},{1.611273, 0.566987, 0.039423}}],
    Polygon[{{1.614991, 0.572104, -0.040942},{1.611273, 0.566987, -0.039423},{
      1.614844, 0.565168, -0.039423},{1.616798, 0.571183, -0.040942}}],
    Polygon[{{1.611273, 0.566987, -0.039423},{1.607741, 0.562126, -0.036934},{
      1.612987, 0.559453, -0.036934},{1.614844, 0.565168, -0.039423}}],
    Polygon[{{1.607741, 0.562126, -0.036934},{1.604481, 0.557639, -0.033535},{
      1.611273, 0.554178, -0.033535},{1.612987, 0.559453, -0.036934}}],
    Polygon[{{1.604481, 0.557639, -0.033535},{1.601574, 0.553637, -0.029311},{
      1.609745, 0.549474, -0.029311},{1.611273, 0.554178, -0.033535}}],
    Polygon[{{1.601574, 0.553637, -0.029311},{1.599091, 0.550220, -0.024365},{
      1.608439, 0.545456, -0.024365},{1.609745, 0.549474, -0.029311}}],
    Polygon[{{1.599091, 0.550220, -0.024365},{1.597093, 0.547470, -0.018819},{
      1.607389, 0.542224, -0.018819},{1.608439, 0.545456, -0.024365}}],
    Polygon[{{1.597093, 0.547470, -0.018819},{1.595630, 0.545456, -0.012809},{
      1.606620, 0.539857, -0.012809},{1.607389, 0.542224, -0.018819}}],
    Polygon[{{1.595630, 0.545456, -0.012809},{1.594737, 0.544228, -0.006485},{
      1.606151, 0.538413, -0.006485},{1.606620, 0.539857, -0.012809}}],
    Polygon[{{1.594737, 0.544228, -0.006485},{1.594437, 0.543815, 0.000000},{
      1.605993, 0.537927, 0.000000},{1.606151, 0.538413, -0.006485}}],
    Polygon[{{1.594437, 0.543815, 0.000000},{1.594737, 0.544228, 0.006485},{
      1.606151, 0.538413, 0.006485},{1.605993, 0.537927, 0.000000}}],
    Polygon[{{1.594737, 0.544228, 0.006485},{1.595630, 0.545456, 0.012809},{
      1.606620, 0.539857, 0.012809},{1.606151, 0.538413, 0.006485}}],
    Polygon[{{1.595630, 0.545456, 0.012809},{1.597093, 0.547470, 0.018819},{
      1.607389, 0.542224, 0.018819},{1.606620, 0.539857, 0.012809}}],
    Polygon[{{1.597093, 0.547470, 0.018819},{1.599091, 0.550220, 0.024365},{
      1.608439, 0.545456, 0.024365},{1.607389, 0.542224, 0.018819}}],
    Polygon[{{1.599091, 0.550220, 0.024365},{1.601574, 0.553637, 0.029311},{
      1.609745, 0.549474, 0.029311},{1.608439, 0.545456, 0.024365}}],
    Polygon[{{1.601574, 0.553637, 0.029311},{1.604481, 0.557639, 0.033535},{
      1.611273, 0.554178, 0.033535},{1.609745, 0.549474, 0.029311}}],
    Polygon[{{1.604481, 0.557639, 0.033535},{1.607741, 0.562126, 0.036934},{
      1.612987, 0.559453, 0.036934},{1.611273, 0.554178, 0.033535}}],
    Polygon[{{1.607741, 0.562126, 0.036934},{1.611273, 0.566987, 0.039423},{
      1.614844, 0.565168, 0.039423},{1.612987, 0.559453, 0.036934}}],
    Polygon[{{1.611273, 0.566987, 0.039423},{1.614991, 0.572104, 0.040942},{
      1.616798, 0.571183, 0.040942},{1.614844, 0.565168, 0.039423}}],
    Polygon[{{1.616798, 0.571183, -0.040942},{1.614844, 0.565168, -0.039423},{
      1.618802, 0.564541, -0.039423},{1.618802, 0.570866, -0.040942}}],
    Polygon[{{1.614844, 0.565168, -0.039423},{1.612987, 0.559453, -0.036934},{
      1.618802, 0.558532, -0.036934},{1.618802, 0.564541, -0.039423}}],
    Polygon[{{1.612987, 0.559453, -0.036934},{1.611273, 0.554178, -0.033535},{
      1.618802, 0.552985, -0.033535},{1.618802, 0.558532, -0.036934}}],
    Polygon[{{1.611273, 0.554178, -0.033535},{1.609745, 0.549474, -0.029311},{
      1.618802, 0.548039, -0.029311},{1.618802, 0.552985, -0.033535}}],
    Polygon[{{1.609745, 0.549474, -0.029311},{1.608439, 0.545456, -0.024365},{
      1.618802, 0.543815, -0.024365},{1.618802, 0.548039, -0.029311}}],
    Polygon[{{1.608439, 0.545456, -0.024365},{1.607389, 0.542224, -0.018819},{
      1.618802, 0.540416, -0.018819},{1.618802, 0.543815, -0.024365}}],
    Polygon[{{1.607389, 0.542224, -0.018819},{1.606620, 0.539857, -0.012809},{
      1.618802, 0.537927, -0.012809},{1.618802, 0.540416, -0.018819}}],
    Polygon[{{1.606620, 0.539857, -0.012809},{1.606151, 0.538413, -0.006485},{
      1.618802, 0.536409, -0.006485},{1.618802, 0.537927, -0.012809}}],
    Polygon[{{1.606151, 0.538413, -0.006485},{1.605993, 0.537927, 0.000000},{
      1.618802, 0.535898, 0.000000},{1.618802, 0.536409, -0.006485}}],
    Polygon[{{1.605993, 0.537927, 0.000000},{1.606151, 0.538413, 0.006485},{
      1.618802, 0.536409, 0.006485},{1.618802, 0.535898, 0.000000}}],
    Polygon[{{1.606151, 0.538413, 0.006485},{1.606620, 0.539857, 0.012809},{
      1.618802, 0.537927, 0.012809},{1.618802, 0.536409, 0.006485}}],
    Polygon[{{1.606620, 0.539857, 0.012809},{1.607389, 0.542224, 0.018819},{
      1.618802, 0.540416, 0.018819},{1.618802, 0.537927, 0.012809}}],
    Polygon[{{1.607389, 0.542224, 0.018819},{1.608439, 0.545456, 0.024365},{
      1.618802, 0.543815, 0.024365},{1.618802, 0.540416, 0.018819}}],
    Polygon[{{1.608439, 0.545456, 0.024365},{1.609745, 0.549474, 0.029311},{
      1.618802, 0.548039, 0.029311},{1.618802, 0.543815, 0.024365}}],
    Polygon[{{1.609745, 0.549474, 0.029311},{1.611273, 0.554178, 0.033535},{
      1.618802, 0.552985, 0.033535},{1.618802, 0.548039, 0.029311}}],
    Polygon[{{1.611273, 0.554178, 0.033535},{1.612987, 0.559453, 0.036934},{
      1.618802, 0.558532, 0.036934},{1.618802, 0.552985, 0.033535}}],
    Polygon[{{1.612987, 0.559453, 0.036934},{1.614844, 0.565168, 0.039423},{
      1.618802, 0.564541, 0.039423},{1.618802, 0.558532, 0.036934}}],
    Polygon[{{1.614844, 0.565168, 0.039423},{1.616798, 0.571183, 0.040942},{
      1.618802, 0.570866, 0.040942},{1.618802, 0.564541, 0.039423}}],
    Polygon[{{1.618802, 0.570866, -0.040942},{1.618802, 0.564541, -0.039423},{
      1.622760, 0.565168, -0.039423},{1.620806, 0.571183, -0.040942}}],
    Polygon[{{1.618802, 0.564541, -0.039423},{1.618802, 0.558532, -0.036934},{
      1.624617, 0.559453, -0.036934},{1.622760, 0.565168, -0.039423}}],
    Polygon[{{1.618802, 0.558532, -0.036934},{1.618802, 0.552985, -0.033535},{
      1.626331, 0.554178, -0.033535},{1.624617, 0.559453, -0.036934}}],
    Polygon[{{1.618802, 0.552985, -0.033535},{1.618802, 0.548039, -0.029311},{
      1.627860, 0.549474, -0.029311},{1.626331, 0.554178, -0.033535}}],
    Polygon[{{1.618802, 0.548039, -0.029311},{1.618802, 0.543815, -0.024365},{
      1.629165, 0.545456, -0.024365},{1.627860, 0.549474, -0.029311}}],
    Polygon[{{1.618802, 0.543815, -0.024365},{1.618802, 0.540416, -0.018819},{
      1.630215, 0.542224, -0.018819},{1.629165, 0.545456, -0.024365}}],
    Polygon[{{1.618802, 0.540416, -0.018819},{1.618802, 0.537927, -0.012809},{
      1.630985, 0.539857, -0.012809},{1.630215, 0.542224, -0.018819}}],
    Polygon[{{1.618802, 0.537927, -0.012809},{1.618802, 0.536409, -0.006485},{
      1.631454, 0.538413, -0.006485},{1.630985, 0.539857, -0.012809}}],
    Polygon[{{1.618802, 0.536409, -0.006485},{1.618802, 0.535898, 0.000000},{
      1.631611, 0.537927, 0.000000},{1.631454, 0.538413, -0.006485}}],
    Polygon[{{1.618802, 0.535898, 0.000000},{1.618802, 0.536409, 0.006485},{
      1.631454, 0.538413, 0.006485},{1.631611, 0.537927, 0.000000}}],
    Polygon[{{1.618802, 0.536409, 0.006485},{1.618802, 0.537927, 0.012809},{
      1.630985, 0.539857, 0.012809},{1.631454, 0.538413, 0.006485}}],
    Polygon[{{1.618802, 0.537927, 0.012809},{1.618802, 0.540416, 0.018819},{
      1.630215, 0.542224, 0.018819},{1.630985, 0.539857, 0.012809}}],
    Polygon[{{1.618802, 0.540416, 0.018819},{1.618802, 0.543815, 0.024365},{
      1.629165, 0.545456, 0.024365},{1.630215, 0.542224, 0.018819}}],
    Polygon[{{1.618802, 0.543815, 0.024365},{1.618802, 0.548039, 0.029311},{
      1.627860, 0.549474, 0.029311},{1.629165, 0.545456, 0.024365}}],
    Polygon[{{1.618802, 0.548039, 0.029311},{1.618802, 0.552985, 0.033535},{
      1.626331, 0.554178, 0.033535},{1.627860, 0.549474, 0.029311}}],
    Polygon[{{1.618802, 0.552985, 0.033535},{1.618802, 0.558532, 0.036934},{
      1.624617, 0.559453, 0.036934},{1.626331, 0.554178, 0.033535}}],
    Polygon[{{1.618802, 0.558532, 0.036934},{1.618802, 0.564541, 0.039423},{
      1.622760, 0.565168, 0.039423},{1.624617, 0.559453, 0.036934}}],
    Polygon[{{1.618802, 0.564541, 0.039423},{1.618802, 0.570866, 0.040942},{
      1.620806, 0.571183, 0.040942},{1.622760, 0.565168, 0.039423}}],
    Polygon[{{1.620806, 0.571183, -0.040942},{1.622760, 0.565168, -0.039423},{
      1.626331, 0.566987, -0.039423},{1.622614, 0.572104, -0.040942}}],
    Polygon[{{1.622760, 0.565168, -0.039423},{1.624617, 0.559453, -0.036934},{
      1.629864, 0.562126, -0.036934},{1.626331, 0.566987, -0.039423}}],
    Polygon[{{1.624617, 0.559453, -0.036934},{1.626331, 0.554178, -0.033535},{
      1.633123, 0.557639, -0.033535},{1.629864, 0.562126, -0.036934}}],
    Polygon[{{1.626331, 0.554178, -0.033535},{1.627860, 0.549474, -0.029311},{
      1.636031, 0.553637, -0.029311},{1.633123, 0.557639, -0.033535}}],
    Polygon[{{1.627860, 0.549474, -0.029311},{1.629165, 0.545456, -0.024365},{
      1.638514, 0.550220, -0.024365},{1.636031, 0.553637, -0.029311}}],
    Polygon[{{1.629165, 0.545456, -0.024365},{1.630215, 0.542224, -0.018819},{
      1.640511, 0.547470, -0.018819},{1.638514, 0.550220, -0.024365}}],
    Polygon[{{1.630215, 0.542224, -0.018819},{1.630985, 0.539857, -0.012809},{
      1.641974, 0.545456, -0.012809},{1.640511, 0.547470, -0.018819}}],
    Polygon[{{1.630985, 0.539857, -0.012809},{1.631454, 0.538413, -0.006485},{
      1.642867, 0.544228, -0.006485},{1.641974, 0.545456, -0.012809}}],
    Polygon[{{1.631454, 0.538413, -0.006485},{1.631611, 0.537927, 0.000000},{
      1.643167, 0.543815, 0.000000},{1.642867, 0.544228, -0.006485}}],
    Polygon[{{1.631611, 0.537927, 0.000000},{1.631454, 0.538413, 0.006485},{
      1.642867, 0.544228, 0.006485},{1.643167, 0.543815, 0.000000}}],
    Polygon[{{1.631454, 0.538413, 0.006485},{1.630985, 0.539857, 0.012809},{
      1.641974, 0.545456, 0.012809},{1.642867, 0.544228, 0.006485}}],
    Polygon[{{1.630985, 0.539857, 0.012809},{1.630215, 0.542224, 0.018819},{
      1.640511, 0.547470, 0.018819},{1.641974, 0.545456, 0.012809}}],
    Polygon[{{1.630215, 0.542224, 0.018819},{1.629165, 0.545456, 0.024365},{
      1.638514, 0.550220, 0.024365},{1.640511, 0.547470, 0.018819}}],
    Polygon[{{1.629165, 0.545456, 0.024365},{1.627860, 0.549474, 0.029311},{
      1.636031, 0.553637, 0.029311},{1.638514, 0.550220, 0.024365}}],
    Polygon[{{1.627860, 0.549474, 0.029311},{1.626331, 0.554178, 0.033535},{
      1.633123, 0.557639, 0.033535},{1.636031, 0.553637, 0.029311}}],
    Polygon[{{1.626331, 0.554178, 0.033535},{1.624617, 0.559453, 0.036934},{
      1.629864, 0.562126, 0.036934},{1.633123, 0.557639, 0.033535}}],
    Polygon[{{1.624617, 0.559453, 0.036934},{1.622760, 0.565168, 0.039423},{
      1.626331, 0.566987, 0.039423},{1.629864, 0.562126, 0.036934}}],
    Polygon[{{1.622760, 0.565168, 0.039423},{1.620806, 0.571183, 0.040942},{
      1.622614, 0.572104, 0.040942},{1.626331, 0.566987, 0.039423}}],
    Polygon[{{1.622614, 0.572104, -0.040942},{1.626331, 0.566987, -0.039423},{
      1.629165, 0.569821, -0.039423},{1.624048, 0.573539, -0.040942}}],
    Polygon[{{1.626331, 0.566987, -0.039423},{1.629864, 0.562126, -0.036934},{
      1.634027, 0.566289, -0.036934},{1.629165, 0.569821, -0.039423}}],
    Polygon[{{1.629864, 0.562126, -0.036934},{1.633123, 0.557639, -0.033535},{
      1.638514, 0.563029, -0.033535},{1.634027, 0.566289, -0.036934}}],
    Polygon[{{1.633123, 0.557639, -0.033535},{1.636031, 0.553637, -0.029311},{
      1.642515, 0.560122, -0.029311},{1.638514, 0.563029, -0.033535}}],
    Polygon[{{1.636031, 0.553637, -0.029311},{1.638514, 0.550220, -0.024365},{
      1.645933, 0.557639, -0.024365},{1.642515, 0.560122, -0.029311}}],
    Polygon[{{1.638514, 0.550220, -0.024365},{1.640511, 0.547470, -0.018819},{
      1.648682, 0.555641, -0.018819},{1.645933, 0.557639, -0.024365}}],
    Polygon[{{1.640511, 0.547470, -0.018819},{1.641974, 0.545456, -0.012809},{
      1.650696, 0.554178, -0.012809},{1.648682, 0.555641, -0.018819}}],
    Polygon[{{1.641974, 0.545456, -0.012809},{1.642867, 0.544228, -0.006485},{
      1.651925, 0.553285, -0.006485},{1.650696, 0.554178, -0.012809}}],
    Polygon[{{1.642867, 0.544228, -0.006485},{1.643167, 0.543815, 0.000000},{
      1.652337, 0.552985, 0.000000},{1.651925, 0.553285, -0.006485}}],
    Polygon[{{1.643167, 0.543815, 0.000000},{1.642867, 0.544228, 0.006485},{
      1.651925, 0.553285, 0.006485},{1.652337, 0.552985, 0.000000}}],
    Polygon[{{1.642867, 0.544228, 0.006485},{1.641974, 0.545456, 0.012809},{
      1.650696, 0.554178, 0.012809},{1.651925, 0.553285, 0.006485}}],
    Polygon[{{1.641974, 0.545456, 0.012809},{1.640511, 0.547470, 0.018819},{
      1.648682, 0.555641, 0.018819},{1.650696, 0.554178, 0.012809}}],
    Polygon[{{1.640511, 0.547470, 0.018819},{1.638514, 0.550220, 0.024365},{
      1.645933, 0.557639, 0.024365},{1.648682, 0.555641, 0.018819}}],
    Polygon[{{1.638514, 0.550220, 0.024365},{1.636031, 0.553637, 0.029311},{
      1.642515, 0.560122, 0.029311},{1.645933, 0.557639, 0.024365}}],
    Polygon[{{1.636031, 0.553637, 0.029311},{1.633123, 0.557639, 0.033535},{
      1.638514, 0.563029, 0.033535},{1.642515, 0.560122, 0.029311}}],
    Polygon[{{1.633123, 0.557639, 0.033535},{1.629864, 0.562126, 0.036934},{
      1.634027, 0.566289, 0.036934},{1.638514, 0.563029, 0.033535}}],
    Polygon[{{1.629864, 0.562126, 0.036934},{1.626331, 0.566987, 0.039423},{
      1.629165, 0.569821, 0.039423},{1.634027, 0.566289, 0.036934}}],
    Polygon[{{1.626331, 0.566987, 0.039423},{1.622614, 0.572104, 0.040942},{
      1.624048, 0.573539, 0.040942},{1.629165, 0.569821, 0.039423}}],
    Polygon[{{1.624048, 0.573539, -0.040942},{1.629165, 0.569821, -0.039423},{
      1.630985, 0.573392, -0.039423},{1.624969, 0.575346, -0.040942}}],
    Polygon[{{1.629165, 0.569821, -0.039423},{1.634027, 0.566289, -0.036934},{
      1.636700, 0.571535, -0.036934},{1.630985, 0.573392, -0.039423}}],
    Polygon[{{1.634027, 0.566289, -0.036934},{1.638514, 0.563029, -0.033535},{
      1.641974, 0.569821, -0.033535},{1.636700, 0.571535, -0.036934}}],
    Polygon[{{1.638514, 0.563029, -0.033535},{1.642515, 0.560122, -0.029311},{
      1.646678, 0.568293, -0.029311},{1.641974, 0.569821, -0.033535}}],
    Polygon[{{1.642515, 0.560122, -0.029311},{1.645933, 0.557639, -0.024365},{
      1.650696, 0.566987, -0.024365},{1.646678, 0.568293, -0.029311}}],
    Polygon[{{1.645933, 0.557639, -0.024365},{1.648682, 0.555641, -0.018819},{
      1.653928, 0.565937, -0.018819},{1.650696, 0.566987, -0.024365}}],
    Polygon[{{1.648682, 0.555641, -0.018819},{1.650696, 0.554178, -0.012809},{
      1.656296, 0.565168, -0.012809},{1.653928, 0.565937, -0.018819}}],
    Polygon[{{1.650696, 0.554178, -0.012809},{1.651925, 0.553285, -0.006485},{
      1.657740, 0.564699, -0.006485},{1.656296, 0.565168, -0.012809}}],
    Polygon[{{1.651925, 0.553285, -0.006485},{1.652337, 0.552985, 0.000000},{
      1.658225, 0.564541, 0.000000},{1.657740, 0.564699, -0.006485}}],
    Polygon[{{1.652337, 0.552985, 0.000000},{1.651925, 0.553285, 0.006485},{
      1.657740, 0.564699, 0.006485},{1.658225, 0.564541, 0.000000}}],
    Polygon[{{1.651925, 0.553285, 0.006485},{1.650696, 0.554178, 0.012809},{
      1.656296, 0.565168, 0.012809},{1.657740, 0.564699, 0.006485}}],
    Polygon[{{1.650696, 0.554178, 0.012809},{1.648682, 0.555641, 0.018819},{
      1.653928, 0.565937, 0.018819},{1.656296, 0.565168, 0.012809}}],
    Polygon[{{1.648682, 0.555641, 0.018819},{1.645933, 0.557639, 0.024365},{
      1.650696, 0.566987, 0.024365},{1.653928, 0.565937, 0.018819}}],
    Polygon[{{1.645933, 0.557639, 0.024365},{1.642515, 0.560122, 0.029311},{
      1.646678, 0.568293, 0.029311},{1.650696, 0.566987, 0.024365}}],
    Polygon[{{1.642515, 0.560122, 0.029311},{1.638514, 0.563029, 0.033535},{
      1.641974, 0.569821, 0.033535},{1.646678, 0.568293, 0.029311}}],
    Polygon[{{1.638514, 0.563029, 0.033535},{1.634027, 0.566289, 0.036934},{
      1.636700, 0.571535, 0.036934},{1.641974, 0.569821, 0.033535}}],
    Polygon[{{1.634027, 0.566289, 0.036934},{1.629165, 0.569821, 0.039423},{
      1.630985, 0.573392, 0.039423},{1.636700, 0.571535, 0.036934}}],
    Polygon[{{1.629165, 0.569821, 0.039423},{1.624048, 0.573539, 0.040942},{
      1.624969, 0.575346, 0.040942},{1.630985, 0.573392, 0.039423}}],
    Polygon[{{1.624969, 0.575346, -0.040942},{1.630985, 0.573392, -0.039423},{
      1.631611, 0.577350, -0.039423},{1.625287, 0.577350, -0.040942}}],
    Polygon[{{1.630985, 0.573392, -0.039423},{1.636700, 0.571535, -0.036934},{
      1.637621, 0.577350, -0.036934},{1.631611, 0.577350, -0.039423}}],
    Polygon[{{1.636700, 0.571535, -0.036934},{1.641974, 0.569821, -0.033535},{
      1.643167, 0.577350, -0.033535},{1.637621, 0.577350, -0.036934}}],
    Polygon[{{1.641974, 0.569821, -0.033535},{1.646678, 0.568293, -0.029311},{
      1.648113, 0.577350, -0.029311},{1.643167, 0.577350, -0.033535}}],
    Polygon[{{1.646678, 0.568293, -0.029311},{1.650696, 0.566987, -0.024365},{
      1.652337, 0.577350, -0.024365},{1.648113, 0.577350, -0.029311}}],
    Polygon[{{1.650696, 0.566987, -0.024365},{1.653928, 0.565937, -0.018819},{
      1.655736, 0.577350, -0.018819},{1.652337, 0.577350, -0.024365}}],
    Polygon[{{1.653928, 0.565937, -0.018819},{1.656296, 0.565168, -0.012809},{
      1.658225, 0.577350, -0.012809},{1.655736, 0.577350, -0.018819}}],
    Polygon[{{1.656296, 0.565168, -0.012809},{1.657740, 0.564699, -0.006485},{
      1.659744, 0.577350, -0.006485},{1.658225, 0.577350, -0.012809}}],
    Polygon[{{1.657740, 0.564699, -0.006485},{1.658225, 0.564541, 0.000000},{
      1.660254, 0.577350, 0.000000},{1.659744, 0.577350, -0.006485}}],
    Polygon[{{1.658225, 0.564541, 0.000000},{1.657740, 0.564699, 0.006485},{
      1.659744, 0.577350, 0.006485},{1.660254, 0.577350, 0.000000}}],
    Polygon[{{1.657740, 0.564699, 0.006485},{1.656296, 0.565168, 0.012809},{
      1.658225, 0.577350, 0.012809},{1.659744, 0.577350, 0.006485}}],
    Polygon[{{1.656296, 0.565168, 0.012809},{1.653928, 0.565937, 0.018819},{
      1.655736, 0.577350, 0.018819},{1.658225, 0.577350, 0.012809}}],
    Polygon[{{1.653928, 0.565937, 0.018819},{1.650696, 0.566987, 0.024365},{
      1.652337, 0.577350, 0.024365},{1.655736, 0.577350, 0.018819}}],
    Polygon[{{1.650696, 0.566987, 0.024365},{1.646678, 0.568293, 0.029311},{
      1.648113, 0.577350, 0.029311},{1.652337, 0.577350, 0.024365}}],
    Polygon[{{1.646678, 0.568293, 0.029311},{1.641974, 0.569821, 0.033535},{
      1.643167, 0.577350, 0.033535},{1.648113, 0.577350, 0.029311}}],
    Polygon[{{1.641974, 0.569821, 0.033535},{1.636700, 0.571535, 0.036934},{
      1.637621, 0.577350, 0.036934},{1.643167, 0.577350, 0.033535}}],
    Polygon[{{1.636700, 0.571535, 0.036934},{1.630985, 0.573392, 0.039423},{
      1.631611, 0.577350, 0.039423},{1.637621, 0.577350, 0.036934}}],
    Polygon[{{1.630985, 0.573392, 0.039423},{1.624969, 0.575346, 0.040942},{
      1.625287, 0.577350, 0.040942},{1.631611, 0.577350, 0.039423}}],
    Polygon[{{1.603713, 0.641809, -0.025466},{1.607647, 0.641809, -0.024521},{
      1.607257, 0.644271, -0.024521},{1.603515, 0.643055, -0.025466}}],
    Polygon[{{1.607647, 0.641809, -0.024521},{1.611385, 0.641809, -0.022973},{
      1.610812, 0.645426, -0.022973},{1.607257, 0.644271, -0.024521}}],
    Polygon[{{1.611385, 0.641809, -0.022973},{1.614834, 0.641809, -0.020859},{
      1.614093, 0.646492, -0.020859},{1.610812, 0.645426, -0.022973}}],
    Polygon[{{1.614834, 0.641809, -0.020859},{1.617911, 0.641809, -0.018232},{
      1.617019, 0.647443, -0.018232},{1.614093, 0.646492, -0.020859}}],
    Polygon[{{1.617911, 0.641809, -0.018232},{1.620539, 0.641809, -0.015155},{
      1.619518, 0.648255, -0.015155},{1.617019, 0.647443, -0.018232}}],
    Polygon[{{1.620539, 0.641809, -0.015155},{1.622653, 0.641809, -0.011705},{
      1.621528, 0.648908, -0.011705},{1.619518, 0.648255, -0.015155}}],
    Polygon[{{1.622653, 0.641809, -0.011705},{1.624201, 0.641809, -0.007968},{
      1.623001, 0.649386, -0.007968},{1.621528, 0.648908, -0.011705}}],
    Polygon[{{1.624201, 0.641809, -0.007968},{1.625145, 0.641809, -0.004033},{
      1.623899, 0.649678, -0.004033},{1.623001, 0.649386, -0.007968}}],
    Polygon[{{1.625145, 0.641809, -0.004033},{1.625463, 0.641809, 0.000000},{
      1.624201, 0.649776, 0.000000},{1.623899, 0.649678, -0.004033}}],
    Polygon[{{1.625463, 0.641809, 0.000000},{1.625145, 0.641809, 0.004033},{
      1.623899, 0.649678, 0.004033},{1.624201, 0.649776, 0.000000}}],
    Polygon[{{1.625145, 0.641809, 0.004033},{1.624201, 0.641809, 0.007968},{
      1.623001, 0.649386, 0.007968},{1.623899, 0.649678, 0.004033}}],
    Polygon[{{1.624201, 0.641809, 0.007968},{1.622653, 0.641809, 0.011705},{
      1.621528, 0.648908, 0.011705},{1.623001, 0.649386, 0.007968}}],
    Polygon[{{1.622653, 0.641809, 0.011705},{1.620539, 0.641809, 0.015155},{
      1.619518, 0.648255, 0.015155},{1.621528, 0.648908, 0.011705}}],
    Polygon[{{1.620539, 0.641809, 0.015155},{1.617911, 0.641809, 0.018232},{
      1.617019, 0.647443, 0.018232},{1.619518, 0.648255, 0.015155}}],
    Polygon[{{1.617911, 0.641809, 0.018232},{1.614834, 0.641809, 0.020859},{
      1.614093, 0.646492, 0.020859},{1.617019, 0.647443, 0.018232}}],
    Polygon[{{1.614834, 0.641809, 0.020859},{1.611385, 0.641809, 0.022973},{
      1.610812, 0.645426, 0.022973},{1.614093, 0.646492, 0.020859}}],
    Polygon[{{1.611385, 0.641809, 0.022973},{1.607647, 0.641809, 0.024521},{
      1.607257, 0.644271, 0.024521},{1.610812, 0.645426, 0.022973}}],
    Polygon[{{1.607647, 0.641809, 0.024521},{1.603713, 0.641809, 0.025466},{
      1.603515, 0.643055, 0.025466},{1.607257, 0.644271, 0.024521}}],
    Polygon[{{1.603515, 0.643055, -0.025466},{1.607257, 0.644271, -0.024521},{
      1.606125, 0.646492, -0.024521},{1.602942, 0.644180, -0.025466}}],
    Polygon[{{1.607257, 0.644271, -0.024521},{1.610812, 0.645426, -0.022973},{
      1.609149, 0.648689, -0.022973},{1.606125, 0.646492, -0.024521}}],
    Polygon[{{1.610812, 0.645426, -0.022973},{1.614093, 0.646492, -0.020859},{
      1.611940, 0.650717, -0.020859},{1.609149, 0.648689, -0.022973}}],
    Polygon[{{1.614093, 0.646492, -0.020859},{1.617019, 0.647443, -0.018232},{
      1.614429, 0.652525, -0.018232},{1.611940, 0.650717, -0.020859}}],
    Polygon[{{1.617019, 0.647443, -0.018232},{1.619518, 0.648255, -0.015155},{
      1.616555, 0.654070, -0.015155},{1.614429, 0.652525, -0.018232}}],
    Polygon[{{1.619518, 0.648255, -0.015155},{1.621528, 0.648908, -0.011705},{
      1.618265, 0.655312, -0.011705},{1.616555, 0.654070, -0.015155}}],
    Polygon[{{1.621528, 0.648908, -0.011705},{1.623001, 0.649386, -0.007968},{
      1.619518, 0.656222, -0.007968},{1.618265, 0.655312, -0.011705}}],
    Polygon[{{1.623001, 0.649386, -0.007968},{1.623899, 0.649678, -0.004033},{
      1.620282, 0.656777, -0.004033},{1.619518, 0.656222, -0.007968}}],
    Polygon[{{1.623899, 0.649678, -0.004033},{1.624201, 0.649776, 0.000000},{
      1.620539, 0.656964, 0.000000},{1.620282, 0.656777, -0.004033}}],
    Polygon[{{1.624201, 0.649776, 0.000000},{1.623899, 0.649678, 0.004033},{
      1.620282, 0.656777, 0.004033},{1.620539, 0.656964, 0.000000}}],
    Polygon[{{1.623899, 0.649678, 0.004033},{1.623001, 0.649386, 0.007968},{
      1.619518, 0.656222, 0.007968},{1.620282, 0.656777, 0.004033}}],
    Polygon[{{1.623001, 0.649386, 0.007968},{1.621528, 0.648908, 0.011705},{
      1.618265, 0.655312, 0.011705},{1.619518, 0.656222, 0.007968}}],
    Polygon[{{1.621528, 0.648908, 0.011705},{1.619518, 0.648255, 0.015155},{
      1.616555, 0.654070, 0.015155},{1.618265, 0.655312, 0.011705}}],
    Polygon[{{1.619518, 0.648255, 0.015155},{1.617019, 0.647443, 0.018232},{
      1.614429, 0.652525, 0.018232},{1.616555, 0.654070, 0.015155}}],
    Polygon[{{1.617019, 0.647443, 0.018232},{1.614093, 0.646492, 0.020859},{
      1.611940, 0.650717, 0.020859},{1.614429, 0.652525, 0.018232}}],
    Polygon[{{1.614093, 0.646492, 0.020859},{1.610812, 0.645426, 0.022973},{
      1.609149, 0.648689, 0.022973},{1.611940, 0.650717, 0.020859}}],
    Polygon[{{1.610812, 0.645426, 0.022973},{1.607257, 0.644271, 0.024521},{
      1.606125, 0.646492, 0.024521},{1.609149, 0.648689, 0.022973}}],
    Polygon[{{1.607257, 0.644271, 0.024521},{1.603515, 0.643055, 0.025466},{
      1.602942, 0.644180, 0.025466},{1.606125, 0.646492, 0.024521}}],
    Polygon[{{1.602942, 0.644180, -0.025466},{1.606125, 0.646492, -0.024521},{
      1.604363, 0.648255, -0.024521},{1.602050, 0.645072, -0.025466}}],
    Polygon[{{1.606125, 0.646492, -0.024521},{1.609149, 0.648689, -0.022973},{
      1.606560, 0.651279, -0.022973},{1.604363, 0.648255, -0.024521}}],
    Polygon[{{1.609149, 0.648689, -0.022973},{1.611940, 0.650717, -0.020859},{
      1.608587, 0.654070, -0.020859},{1.606560, 0.651279, -0.022973}}],
    Polygon[{{1.611940, 0.650717, -0.020859},{1.614429, 0.652525, -0.018232},{
      1.610396, 0.656559, -0.018232},{1.608587, 0.654070, -0.020859}}],
    Polygon[{{1.614429, 0.652525, -0.018232},{1.616555, 0.654070, -0.015155},{
      1.611940, 0.658684, -0.015155},{1.610396, 0.656559, -0.018232}}],
    Polygon[{{1.616555, 0.654070, -0.015155},{1.618265, 0.655312, -0.011705},{
      1.613183, 0.660395, -0.011705},{1.611940, 0.658684, -0.015155}}],
    Polygon[{{1.618265, 0.655312, -0.011705},{1.619518, 0.656222, -0.007968},{
      1.614093, 0.661647, -0.007968},{1.613183, 0.660395, -0.011705}}],
    Polygon[{{1.619518, 0.656222, -0.007968},{1.620282, 0.656777, -0.004033},{
      1.614648, 0.662411, -0.004033},{1.614093, 0.661647, -0.007968}}],
    Polygon[{{1.620282, 0.656777, -0.004033},{1.620539, 0.656964, 0.000000},{
      1.614834, 0.662668, 0.000000},{1.614648, 0.662411, -0.004033}}],
    Polygon[{{1.620539, 0.656964, 0.000000},{1.620282, 0.656777, 0.004033},{
      1.614648, 0.662411, 0.004033},{1.614834, 0.662668, 0.000000}}],
    Polygon[{{1.620282, 0.656777, 0.004033},{1.619518, 0.656222, 0.007968},{
      1.614093, 0.661647, 0.007968},{1.614648, 0.662411, 0.004033}}],
    Polygon[{{1.619518, 0.656222, 0.007968},{1.618265, 0.655312, 0.011705},{
      1.613183, 0.660395, 0.011705},{1.614093, 0.661647, 0.007968}}],
    Polygon[{{1.618265, 0.655312, 0.011705},{1.616555, 0.654070, 0.015155},{
      1.611940, 0.658684, 0.015155},{1.613183, 0.660395, 0.011705}}],
    Polygon[{{1.616555, 0.654070, 0.015155},{1.614429, 0.652525, 0.018232},{
      1.610396, 0.656559, 0.018232},{1.611940, 0.658684, 0.015155}}],
    Polygon[{{1.614429, 0.652525, 0.018232},{1.611940, 0.650717, 0.020859},{
      1.608587, 0.654070, 0.020859},{1.610396, 0.656559, 0.018232}}],
    Polygon[{{1.611940, 0.650717, 0.020859},{1.609149, 0.648689, 0.022973},{
      1.606560, 0.651279, 0.022973},{1.608587, 0.654070, 0.020859}}],
    Polygon[{{1.609149, 0.648689, 0.022973},{1.606125, 0.646492, 0.024521},{
      1.604363, 0.648255, 0.024521},{1.606560, 0.651279, 0.022973}}],
    Polygon[{{1.606125, 0.646492, 0.024521},{1.602942, 0.644180, 0.025466},{
      1.602050, 0.645072, 0.025466},{1.604363, 0.648255, 0.024521}}],
    Polygon[{{1.602050, 0.645072, -0.025466},{1.604363, 0.648255, -0.024521},{
      1.602141, 0.649386, -0.024521},{1.600926, 0.645645, -0.025466}}],
    Polygon[{{1.604363, 0.648255, -0.024521},{1.606560, 0.651279, -0.022973},{
      1.603297, 0.652941, -0.022973},{1.602141, 0.649386, -0.024521}}],
    Polygon[{{1.606560, 0.651279, -0.022973},{1.608587, 0.654070, -0.020859},{
      1.604363, 0.656222, -0.020859},{1.603297, 0.652941, -0.022973}}],
    Polygon[{{1.608587, 0.654070, -0.020859},{1.610396, 0.656559, -0.018232},{
      1.605313, 0.659148, -0.018232},{1.604363, 0.656222, -0.020859}}],
    Polygon[{{1.610396, 0.656559, -0.018232},{1.611940, 0.658684, -0.015155},{
      1.606125, 0.661647, -0.015155},{1.605313, 0.659148, -0.018232}}],
    Polygon[{{1.611940, 0.658684, -0.015155},{1.613183, 0.660395, -0.011705},{
      1.606779, 0.663658, -0.011705},{1.606125, 0.661647, -0.015155}}],
    Polygon[{{1.613183, 0.660395, -0.011705},{1.614093, 0.661647, -0.007968},{
      1.607257, 0.665130, -0.007968},{1.606779, 0.663658, -0.011705}}],
    Polygon[{{1.614093, 0.661647, -0.007968},{1.614648, 0.662411, -0.004033},{
      1.607549, 0.666028, -0.004033},{1.607257, 0.665130, -0.007968}}],
    Polygon[{{1.614648, 0.662411, -0.004033},{1.614834, 0.662668, 0.000000},{
      1.607647, 0.666330, 0.000000},{1.607549, 0.666028, -0.004033}}],
    Polygon[{{1.614834, 0.662668, 0.000000},{1.614648, 0.662411, 0.004033},{
      1.607549, 0.666028, 0.004033},{1.607647, 0.666330, 0.000000}}],
    Polygon[{{1.614648, 0.662411, 0.004033},{1.614093, 0.661647, 0.007968},{
      1.607257, 0.665130, 0.007968},{1.607549, 0.666028, 0.004033}}],
    Polygon[{{1.614093, 0.661647, 0.007968},{1.613183, 0.660395, 0.011705},{
      1.606779, 0.663658, 0.011705},{1.607257, 0.665130, 0.007968}}],
    Polygon[{{1.613183, 0.660395, 0.011705},{1.611940, 0.658684, 0.015155},{
      1.606125, 0.661647, 0.015155},{1.606779, 0.663658, 0.011705}}],
    Polygon[{{1.611940, 0.658684, 0.015155},{1.610396, 0.656559, 0.018232},{
      1.605313, 0.659148, 0.018232},{1.606125, 0.661647, 0.015155}}],
    Polygon[{{1.610396, 0.656559, 0.018232},{1.608587, 0.654070, 0.020859},{
      1.604363, 0.656222, 0.020859},{1.605313, 0.659148, 0.018232}}],
    Polygon[{{1.608587, 0.654070, 0.020859},{1.606560, 0.651279, 0.022973},{
      1.603297, 0.652941, 0.022973},{1.604363, 0.656222, 0.020859}}],
    Polygon[{{1.606560, 0.651279, 0.022973},{1.604363, 0.648255, 0.024521},{
      1.602141, 0.649386, 0.024521},{1.603297, 0.652941, 0.022973}}],
    Polygon[{{1.604363, 0.648255, 0.024521},{1.602050, 0.645072, 0.025466},{
      1.600926, 0.645645, 0.025466},{1.602141, 0.649386, 0.024521}}],
    Polygon[{{1.600926, 0.645645, -0.025466},{1.602141, 0.649386, -0.024521},{
      1.599679, 0.649776, -0.024521},{1.599679, 0.645842, -0.025466}}],
    Polygon[{{1.602141, 0.649386, -0.024521},{1.603297, 0.652941, -0.022973},{
      1.599679, 0.653514, -0.022973},{1.599679, 0.649776, -0.024521}}],
    Polygon[{{1.603297, 0.652941, -0.022973},{1.604363, 0.656222, -0.020859},{
      1.599679, 0.656964, -0.020859},{1.599679, 0.653514, -0.022973}}],
    Polygon[{{1.604363, 0.656222, -0.020859},{1.605313, 0.659148, -0.018232},{
      1.599679, 0.660040, -0.018232},{1.599679, 0.656964, -0.020859}}],
    Polygon[{{1.605313, 0.659148, -0.018232},{1.606125, 0.661647, -0.015155},{
      1.599679, 0.662668, -0.015155},{1.599679, 0.660040, -0.018232}}],
    Polygon[{{1.606125, 0.661647, -0.015155},{1.606779, 0.663658, -0.011705},{
      1.599679, 0.664782, -0.011705},{1.599679, 0.662668, -0.015155}}],
    Polygon[{{1.606779, 0.663658, -0.011705},{1.607257, 0.665130, -0.007968},{
      1.599679, 0.666330, -0.007968},{1.599679, 0.664782, -0.011705}}],
    Polygon[{{1.607257, 0.665130, -0.007968},{1.607549, 0.666028, -0.004033},{
      1.599679, 0.667275, -0.004033},{1.599679, 0.666330, -0.007968}}],
    Polygon[{{1.607549, 0.666028, -0.004033},{1.607647, 0.666330, 0.000000},{
      1.599679, 0.667592, 0.000000},{1.599679, 0.667275, -0.004033}}],
    Polygon[{{1.607647, 0.666330, 0.000000},{1.607549, 0.666028, 0.004033},{
      1.599679, 0.667275, 0.004033},{1.599679, 0.667592, 0.000000}}],
    Polygon[{{1.607549, 0.666028, 0.004033},{1.607257, 0.665130, 0.007968},{
      1.599679, 0.666330, 0.007968},{1.599679, 0.667275, 0.004033}}],
    Polygon[{{1.607257, 0.665130, 0.007968},{1.606779, 0.663658, 0.011705},{
      1.599679, 0.664782, 0.011705},{1.599679, 0.666330, 0.007968}}],
    Polygon[{{1.606779, 0.663658, 0.011705},{1.606125, 0.661647, 0.015155},{
      1.599679, 0.662668, 0.015155},{1.599679, 0.664782, 0.011705}}],
    Polygon[{{1.606125, 0.661647, 0.015155},{1.605313, 0.659148, 0.018232},{
      1.599679, 0.660040, 0.018232},{1.599679, 0.662668, 0.015155}}],
    Polygon[{{1.605313, 0.659148, 0.018232},{1.604363, 0.656222, 0.020859},{
      1.599679, 0.656964, 0.020859},{1.599679, 0.660040, 0.018232}}],
    Polygon[{{1.604363, 0.656222, 0.020859},{1.603297, 0.652941, 0.022973},{
      1.599679, 0.653514, 0.022973},{1.599679, 0.656964, 0.020859}}],
    Polygon[{{1.603297, 0.652941, 0.022973},{1.602141, 0.649386, 0.024521},{
      1.599679, 0.649776, 0.024521},{1.599679, 0.653514, 0.022973}}],
    Polygon[{{1.602141, 0.649386, 0.024521},{1.600926, 0.645645, 0.025466},{
      1.599679, 0.645842, 0.025466},{1.599679, 0.649776, 0.024521}}],
    Polygon[{{1.599679, 0.645842, -0.025466},{1.599679, 0.649776, -0.024521},{
      1.597217, 0.649386, -0.024521},{1.598433, 0.645645, -0.025466}}],
    Polygon[{{1.599679, 0.649776, -0.024521},{1.599679, 0.653514, -0.022973},{
      1.596062, 0.652941, -0.022973},{1.597217, 0.649386, -0.024521}}],
    Polygon[{{1.599679, 0.653514, -0.022973},{1.599679, 0.656964, -0.020859},{
      1.594996, 0.656222, -0.020859},{1.596062, 0.652941, -0.022973}}],
    Polygon[{{1.599679, 0.656964, -0.020859},{1.599679, 0.660040, -0.018232},{
      1.594046, 0.659148, -0.018232},{1.594996, 0.656222, -0.020859}}],
    Polygon[{{1.599679, 0.660040, -0.018232},{1.599679, 0.662668, -0.015155},{
      1.593233, 0.661647, -0.015155},{1.594046, 0.659148, -0.018232}}],
    Polygon[{{1.599679, 0.662668, -0.015155},{1.599679, 0.664782, -0.011705},{
      1.592580, 0.663658, -0.011705},{1.593233, 0.661647, -0.015155}}],
    Polygon[{{1.599679, 0.664782, -0.011705},{1.599679, 0.666330, -0.007968},{
      1.592102, 0.665130, -0.007968},{1.592580, 0.663658, -0.011705}}],
    Polygon[{{1.599679, 0.666330, -0.007968},{1.599679, 0.667275, -0.004033},{
      1.591810, 0.666028, -0.004033},{1.592102, 0.665130, -0.007968}}],
    Polygon[{{1.599679, 0.667275, -0.004033},{1.599679, 0.667592, 0.000000},{
      1.591712, 0.666330, 0.000000},{1.591810, 0.666028, -0.004033}}],
    Polygon[{{1.599679, 0.667592, 0.000000},{1.599679, 0.667275, 0.004033},{
      1.591810, 0.666028, 0.004033},{1.591712, 0.666330, 0.000000}}],
    Polygon[{{1.599679, 0.667275, 0.004033},{1.599679, 0.666330, 0.007968},{
      1.592102, 0.665130, 0.007968},{1.591810, 0.666028, 0.004033}}],
    Polygon[{{1.599679, 0.666330, 0.007968},{1.599679, 0.664782, 0.011705},{
      1.592580, 0.663658, 0.011705},{1.592102, 0.665130, 0.007968}}],
    Polygon[{{1.599679, 0.664782, 0.011705},{1.599679, 0.662668, 0.015155},{
      1.593233, 0.661647, 0.015155},{1.592580, 0.663658, 0.011705}}],
    Polygon[{{1.599679, 0.662668, 0.015155},{1.599679, 0.660040, 0.018232},{
      1.594046, 0.659148, 0.018232},{1.593233, 0.661647, 0.015155}}],
    Polygon[{{1.599679, 0.660040, 0.018232},{1.599679, 0.656964, 0.020859},{
      1.594996, 0.656222, 0.020859},{1.594046, 0.659148, 0.018232}}],
    Polygon[{{1.599679, 0.656964, 0.020859},{1.599679, 0.653514, 0.022973},{
      1.596062, 0.652941, 0.022973},{1.594996, 0.656222, 0.020859}}],
    Polygon[{{1.599679, 0.653514, 0.022973},{1.599679, 0.649776, 0.024521},{
      1.597217, 0.649386, 0.024521},{1.596062, 0.652941, 0.022973}}],
    Polygon[{{1.599679, 0.649776, 0.024521},{1.599679, 0.645842, 0.025466},{
      1.598433, 0.645645, 0.025466},{1.597217, 0.649386, 0.024521}}],
    Polygon[{{1.598433, 0.645645, -0.025466},{1.597217, 0.649386, -0.024521},{
      1.594996, 0.648255, -0.024521},{1.597309, 0.645072, -0.025466}}],
    Polygon[{{1.597217, 0.649386, -0.024521},{1.596062, 0.652941, -0.022973},{
      1.592799, 0.651279, -0.022973},{1.594996, 0.648255, -0.024521}}],
    Polygon[{{1.596062, 0.652941, -0.022973},{1.594996, 0.656222, -0.020859},{
      1.590771, 0.654070, -0.020859},{1.592799, 0.651279, -0.022973}}],
    Polygon[{{1.594996, 0.656222, -0.020859},{1.594046, 0.659148, -0.018232},{
      1.588963, 0.656559, -0.018232},{1.590771, 0.654070, -0.020859}}],
    Polygon[{{1.594046, 0.659148, -0.018232},{1.593233, 0.661647, -0.015155},{
      1.587419, 0.658684, -0.015155},{1.588963, 0.656559, -0.018232}}],
    Polygon[{{1.593233, 0.661647, -0.015155},{1.592580, 0.663658, -0.011705},{
      1.586176, 0.660395, -0.011705},{1.587419, 0.658684, -0.015155}}],
    Polygon[{{1.592580, 0.663658, -0.011705},{1.592102, 0.665130, -0.007968},{
      1.585266, 0.661647, -0.007968},{1.586176, 0.660395, -0.011705}}],
    Polygon[{{1.592102, 0.665130, -0.007968},{1.591810, 0.666028, -0.004033},{
      1.584711, 0.662411, -0.004033},{1.585266, 0.661647, -0.007968}}],
    Polygon[{{1.591810, 0.666028, -0.004033},{1.591712, 0.666330, 0.000000},{
      1.584524, 0.662668, 0.000000},{1.584711, 0.662411, -0.004033}}],
    Polygon[{{1.591712, 0.666330, 0.000000},{1.591810, 0.666028, 0.004033},{
      1.584711, 0.662411, 0.004033},{1.584524, 0.662668, 0.000000}}],
    Polygon[{{1.591810, 0.666028, 0.004033},{1.592102, 0.665130, 0.007968},{
      1.585266, 0.661647, 0.007968},{1.584711, 0.662411, 0.004033}}],
    Polygon[{{1.592102, 0.665130, 0.007968},{1.592580, 0.663658, 0.011705},{
      1.586176, 0.660395, 0.011705},{1.585266, 0.661647, 0.007968}}],
    Polygon[{{1.592580, 0.663658, 0.011705},{1.593233, 0.661647, 0.015155},{
      1.587419, 0.658684, 0.015155},{1.586176, 0.660395, 0.011705}}],
    Polygon[{{1.593233, 0.661647, 0.015155},{1.594046, 0.659148, 0.018232},{
      1.588963, 0.656559, 0.018232},{1.587419, 0.658684, 0.015155}}],
    Polygon[{{1.594046, 0.659148, 0.018232},{1.594996, 0.656222, 0.020859},{
      1.590771, 0.654070, 0.020859},{1.588963, 0.656559, 0.018232}}],
    Polygon[{{1.594996, 0.656222, 0.020859},{1.596062, 0.652941, 0.022973},{
      1.592799, 0.651279, 0.022973},{1.590771, 0.654070, 0.020859}}],
    Polygon[{{1.596062, 0.652941, 0.022973},{1.597217, 0.649386, 0.024521},{
      1.594996, 0.648255, 0.024521},{1.592799, 0.651279, 0.022973}}],
    Polygon[{{1.597217, 0.649386, 0.024521},{1.598433, 0.645645, 0.025466},{
      1.597309, 0.645072, 0.025466},{1.594996, 0.648255, 0.024521}}],
    Polygon[{{1.597309, 0.645072, -0.025466},{1.594996, 0.648255, -0.024521},{
      1.593233, 0.646492, -0.024521},{1.596416, 0.644180, -0.025466}}],
    Polygon[{{1.594996, 0.648255, -0.024521},{1.592799, 0.651279, -0.022973},{
      1.590209, 0.648689, -0.022973},{1.593233, 0.646492, -0.024521}}],
    Polygon[{{1.592799, 0.651279, -0.022973},{1.590771, 0.654070, -0.020859},{
      1.587419, 0.650717, -0.020859},{1.590209, 0.648689, -0.022973}}],
    Polygon[{{1.590771, 0.654070, -0.020859},{1.588963, 0.656559, -0.018232},{
      1.584930, 0.652525, -0.018232},{1.587419, 0.650717, -0.020859}}],
    Polygon[{{1.588963, 0.656559, -0.018232},{1.587419, 0.658684, -0.015155},{
      1.582804, 0.654070, -0.015155},{1.584930, 0.652525, -0.018232}}],
    Polygon[{{1.587419, 0.658684, -0.015155},{1.586176, 0.660395, -0.011705},{
      1.581094, 0.655312, -0.011705},{1.582804, 0.654070, -0.015155}}],
    Polygon[{{1.586176, 0.660395, -0.011705},{1.585266, 0.661647, -0.007968},{
      1.579841, 0.656222, -0.007968},{1.581094, 0.655312, -0.011705}}],
    Polygon[{{1.585266, 0.661647, -0.007968},{1.584711, 0.662411, -0.004033},{
      1.579077, 0.656777, -0.004033},{1.579841, 0.656222, -0.007968}}],
    Polygon[{{1.584711, 0.662411, -0.004033},{1.584524, 0.662668, 0.000000},{
      1.578820, 0.656964, 0.000000},{1.579077, 0.656777, -0.004033}}],
    Polygon[{{1.584524, 0.662668, 0.000000},{1.584711, 0.662411, 0.004033},{
      1.579077, 0.656777, 0.004033},{1.578820, 0.656964, 0.000000}}],
    Polygon[{{1.584711, 0.662411, 0.004033},{1.585266, 0.661647, 0.007968},{
      1.579841, 0.656222, 0.007968},{1.579077, 0.656777, 0.004033}}],
    Polygon[{{1.585266, 0.661647, 0.007968},{1.586176, 0.660395, 0.011705},{
      1.581094, 0.655312, 0.011705},{1.579841, 0.656222, 0.007968}}],
    Polygon[{{1.586176, 0.660395, 0.011705},{1.587419, 0.658684, 0.015155},{
      1.582804, 0.654070, 0.015155},{1.581094, 0.655312, 0.011705}}],
    Polygon[{{1.587419, 0.658684, 0.015155},{1.588963, 0.656559, 0.018232},{
      1.584930, 0.652525, 0.018232},{1.582804, 0.654070, 0.015155}}],
    Polygon[{{1.588963, 0.656559, 0.018232},{1.590771, 0.654070, 0.020859},{
      1.587419, 0.650717, 0.020859},{1.584930, 0.652525, 0.018232}}],
    Polygon[{{1.590771, 0.654070, 0.020859},{1.592799, 0.651279, 0.022973},{
      1.590209, 0.648689, 0.022973},{1.587419, 0.650717, 0.020859}}],
    Polygon[{{1.592799, 0.651279, 0.022973},{1.594996, 0.648255, 0.024521},{
      1.593233, 0.646492, 0.024521},{1.590209, 0.648689, 0.022973}}],
    Polygon[{{1.594996, 0.648255, 0.024521},{1.597309, 0.645072, 0.025466},{
      1.596416, 0.644180, 0.025466},{1.593233, 0.646492, 0.024521}}],
    Polygon[{{1.596416, 0.644180, -0.025466},{1.593233, 0.646492, -0.024521},{
      1.592102, 0.644271, -0.024521},{1.595843, 0.643055, -0.025466}}],
    Polygon[{{1.593233, 0.646492, -0.024521},{1.590209, 0.648689, -0.022973},{
      1.588547, 0.645426, -0.022973},{1.592102, 0.644271, -0.024521}}],
    Polygon[{{1.590209, 0.648689, -0.022973},{1.587419, 0.650717, -0.020859},{
      1.585266, 0.646492, -0.020859},{1.588547, 0.645426, -0.022973}}],
    Polygon[{{1.587419, 0.650717, -0.020859},{1.584930, 0.652525, -0.018232},{
      1.582340, 0.647443, -0.018232},{1.585266, 0.646492, -0.020859}}],
    Polygon[{{1.584930, 0.652525, -0.018232},{1.582804, 0.654070, -0.015155},{
      1.579841, 0.648255, -0.015155},{1.582340, 0.647443, -0.018232}}],
    Polygon[{{1.582804, 0.654070, -0.015155},{1.581094, 0.655312, -0.011705},{
      1.577831, 0.648908, -0.011705},{1.579841, 0.648255, -0.015155}}],
    Polygon[{{1.581094, 0.655312, -0.011705},{1.579841, 0.656222, -0.007968},{
      1.576358, 0.649386, -0.007968},{1.577831, 0.648908, -0.011705}}],
    Polygon[{{1.579841, 0.656222, -0.007968},{1.579077, 0.656777, -0.004033},{
      1.575460, 0.649678, -0.004033},{1.576358, 0.649386, -0.007968}}],
    Polygon[{{1.579077, 0.656777, -0.004033},{1.578820, 0.656964, 0.000000},{
      1.575158, 0.649776, 0.000000},{1.575460, 0.649678, -0.004033}}],
    Polygon[{{1.578820, 0.656964, 0.000000},{1.579077, 0.656777, 0.004033},{
      1.575460, 0.649678, 0.004033},{1.575158, 0.649776, 0.000000}}],
    Polygon[{{1.579077, 0.656777, 0.004033},{1.579841, 0.656222, 0.007968},{
      1.576358, 0.649386, 0.007968},{1.575460, 0.649678, 0.004033}}],
    Polygon[{{1.579841, 0.656222, 0.007968},{1.581094, 0.655312, 0.011705},{
      1.577831, 0.648908, 0.011705},{1.576358, 0.649386, 0.007968}}],
    Polygon[{{1.581094, 0.655312, 0.011705},{1.582804, 0.654070, 0.015155},{
      1.579841, 0.648255, 0.015155},{1.577831, 0.648908, 0.011705}}],
    Polygon[{{1.582804, 0.654070, 0.015155},{1.584930, 0.652525, 0.018232},{
      1.582340, 0.647443, 0.018232},{1.579841, 0.648255, 0.015155}}],
    Polygon[{{1.584930, 0.652525, 0.018232},{1.587419, 0.650717, 0.020859},{
      1.585266, 0.646492, 0.020859},{1.582340, 0.647443, 0.018232}}],
    Polygon[{{1.587419, 0.650717, 0.020859},{1.590209, 0.648689, 0.022973},{
      1.588547, 0.645426, 0.022973},{1.585266, 0.646492, 0.020859}}],
    Polygon[{{1.590209, 0.648689, 0.022973},{1.593233, 0.646492, 0.024521},{
      1.592102, 0.644271, 0.024521},{1.588547, 0.645426, 0.022973}}],
    Polygon[{{1.593233, 0.646492, 0.024521},{1.596416, 0.644180, 0.025466},{
      1.595843, 0.643055, 0.025466},{1.592102, 0.644271, 0.024521}}],
    Polygon[{{1.595843, 0.643055, -0.025466},{1.592102, 0.644271, -0.024521},{
      1.591712, 0.641809, -0.024521},{1.595646, 0.641809, -0.025466}}],
    Polygon[{{1.592102, 0.644271, -0.024521},{1.588547, 0.645426, -0.022973},{
      1.587974, 0.641809, -0.022973},{1.591712, 0.641809, -0.024521}}],
    Polygon[{{1.588547, 0.645426, -0.022973},{1.585266, 0.646492, -0.020859},{
      1.584524, 0.641809, -0.020859},{1.587974, 0.641809, -0.022973}}],
    Polygon[{{1.585266, 0.646492, -0.020859},{1.582340, 0.647443, -0.018232},{
      1.581448, 0.641809, -0.018232},{1.584524, 0.641809, -0.020859}}],
    Polygon[{{1.582340, 0.647443, -0.018232},{1.579841, 0.648255, -0.015155},{
      1.578820, 0.641809, -0.015155},{1.581448, 0.641809, -0.018232}}],
    Polygon[{{1.579841, 0.648255, -0.015155},{1.577831, 0.648908, -0.011705},{
      1.576706, 0.641809, -0.011705},{1.578820, 0.641809, -0.015155}}],
    Polygon[{{1.577831, 0.648908, -0.011705},{1.576358, 0.649386, -0.007968},{
      1.575158, 0.641809, -0.007968},{1.576706, 0.641809, -0.011705}}],
    Polygon[{{1.576358, 0.649386, -0.007968},{1.575460, 0.649678, -0.004033},{
      1.574213, 0.641809, -0.004033},{1.575158, 0.641809, -0.007968}}],
    Polygon[{{1.575460, 0.649678, -0.004033},{1.575158, 0.649776, 0.000000},{
      1.573896, 0.641809, 0.000000},{1.574213, 0.641809, -0.004033}}],
    Polygon[{{1.575158, 0.649776, 0.000000},{1.575460, 0.649678, 0.004033},{
      1.574213, 0.641809, 0.004033},{1.573896, 0.641809, 0.000000}}],
    Polygon[{{1.575460, 0.649678, 0.004033},{1.576358, 0.649386, 0.007968},{
      1.575158, 0.641809, 0.007968},{1.574213, 0.641809, 0.004033}}],
    Polygon[{{1.576358, 0.649386, 0.007968},{1.577831, 0.648908, 0.011705},{
      1.576706, 0.641809, 0.011705},{1.575158, 0.641809, 0.007968}}],
    Polygon[{{1.577831, 0.648908, 0.011705},{1.579841, 0.648255, 0.015155},{
      1.578820, 0.641809, 0.015155},{1.576706, 0.641809, 0.011705}}],
    Polygon[{{1.579841, 0.648255, 0.015155},{1.582340, 0.647443, 0.018232},{
      1.581448, 0.641809, 0.018232},{1.578820, 0.641809, 0.015155}}],
    Polygon[{{1.582340, 0.647443, 0.018232},{1.585266, 0.646492, 0.020859},{
      1.584524, 0.641809, 0.020859},{1.581448, 0.641809, 0.018232}}],
    Polygon[{{1.585266, 0.646492, 0.020859},{1.588547, 0.645426, 0.022973},{
      1.587974, 0.641809, 0.022973},{1.584524, 0.641809, 0.020859}}],
    Polygon[{{1.588547, 0.645426, 0.022973},{1.592102, 0.644271, 0.024521},{
      1.591712, 0.641809, 0.024521},{1.587974, 0.641809, 0.022973}}],
    Polygon[{{1.592102, 0.644271, 0.024521},{1.595843, 0.643055, 0.025466},{
      1.595646, 0.641809, 0.025466},{1.591712, 0.641809, 0.024521}}],
    Polygon[{{1.595646, 0.641809, -0.025466},{1.591712, 0.641809, -0.024521},{
      1.592102, 0.639347, -0.024521},{1.595843, 0.640562, -0.025466}}],
    Polygon[{{1.591712, 0.641809, -0.024521},{1.587974, 0.641809, -0.022973},{
      1.588547, 0.638192, -0.022973},{1.592102, 0.639347, -0.024521}}],
    Polygon[{{1.587974, 0.641809, -0.022973},{1.584524, 0.641809, -0.020859},{
      1.585266, 0.637126, -0.020859},{1.588547, 0.638192, -0.022973}}],
    Polygon[{{1.584524, 0.641809, -0.020859},{1.581448, 0.641809, -0.018232},{
      1.582340, 0.636175, -0.018232},{1.585266, 0.637126, -0.020859}}],
    Polygon[{{1.581448, 0.641809, -0.018232},{1.578820, 0.641809, -0.015155},{
      1.579841, 0.635363, -0.015155},{1.582340, 0.636175, -0.018232}}],
    Polygon[{{1.578820, 0.641809, -0.015155},{1.576706, 0.641809, -0.011705},{
      1.577831, 0.634710, -0.011705},{1.579841, 0.635363, -0.015155}}],
    Polygon[{{1.576706, 0.641809, -0.011705},{1.575158, 0.641809, -0.007968},{
      1.576358, 0.634231, -0.007968},{1.577831, 0.634710, -0.011705}}],
    Polygon[{{1.575158, 0.641809, -0.007968},{1.574213, 0.641809, -0.004033},{
      1.575460, 0.633939, -0.004033},{1.576358, 0.634231, -0.007968}}],
    Polygon[{{1.574213, 0.641809, -0.004033},{1.573896, 0.641809, 0.000000},{
      1.575158, 0.633841, 0.000000},{1.575460, 0.633939, -0.004033}}],
    Polygon[{{1.573896, 0.641809, 0.000000},{1.574213, 0.641809, 0.004033},{
      1.575460, 0.633939, 0.004033},{1.575158, 0.633841, 0.000000}}],
    Polygon[{{1.574213, 0.641809, 0.004033},{1.575158, 0.641809, 0.007968},{
      1.576358, 0.634231, 0.007968},{1.575460, 0.633939, 0.004033}}],
    Polygon[{{1.575158, 0.641809, 0.007968},{1.576706, 0.641809, 0.011705},{
      1.577831, 0.634710, 0.011705},{1.576358, 0.634231, 0.007968}}],
    Polygon[{{1.576706, 0.641809, 0.011705},{1.578820, 0.641809, 0.015155},{
      1.579841, 0.635363, 0.015155},{1.577831, 0.634710, 0.011705}}],
    Polygon[{{1.578820, 0.641809, 0.015155},{1.581448, 0.641809, 0.018232},{
      1.582340, 0.636175, 0.018232},{1.579841, 0.635363, 0.015155}}],
    Polygon[{{1.581448, 0.641809, 0.018232},{1.584524, 0.641809, 0.020859},{
      1.585266, 0.637126, 0.020859},{1.582340, 0.636175, 0.018232}}],
    Polygon[{{1.584524, 0.641809, 0.020859},{1.587974, 0.641809, 0.022973},{
      1.588547, 0.638192, 0.022973},{1.585266, 0.637126, 0.020859}}],
    Polygon[{{1.587974, 0.641809, 0.022973},{1.591712, 0.641809, 0.024521},{
      1.592102, 0.639347, 0.024521},{1.588547, 0.638192, 0.022973}}],
    Polygon[{{1.591712, 0.641809, 0.024521},{1.595646, 0.641809, 0.025466},{
      1.595843, 0.640562, 0.025466},{1.592102, 0.639347, 0.024521}}],
    Polygon[{{1.595843, 0.640562, -0.025466},{1.592102, 0.639347, -0.024521},{
      1.593233, 0.637126, -0.024521},{1.596416, 0.639438, -0.025466}}],
    Polygon[{{1.592102, 0.639347, -0.024521},{1.588547, 0.638192, -0.022973},{
      1.590209, 0.634929, -0.022973},{1.593233, 0.637126, -0.024521}}],
    Polygon[{{1.588547, 0.638192, -0.022973},{1.585266, 0.637126, -0.020859},{
      1.587419, 0.632901, -0.020859},{1.590209, 0.634929, -0.022973}}],
    Polygon[{{1.585266, 0.637126, -0.020859},{1.582340, 0.636175, -0.018232},{
      1.584930, 0.631093, -0.018232},{1.587419, 0.632901, -0.020859}}],
    Polygon[{{1.582340, 0.636175, -0.018232},{1.579841, 0.635363, -0.015155},{
      1.582804, 0.629548, -0.015155},{1.584930, 0.631093, -0.018232}}],
    Polygon[{{1.579841, 0.635363, -0.015155},{1.577831, 0.634710, -0.011705},{
      1.581094, 0.628305, -0.011705},{1.582804, 0.629548, -0.015155}}],
    Polygon[{{1.577831, 0.634710, -0.011705},{1.576358, 0.634231, -0.007968},{
      1.579841, 0.627395, -0.007968},{1.581094, 0.628305, -0.011705}}],
    Polygon[{{1.576358, 0.634231, -0.007968},{1.575460, 0.633939, -0.004033},{
      1.579077, 0.626840, -0.004033},{1.579841, 0.627395, -0.007968}}],
    Polygon[{{1.575460, 0.633939, -0.004033},{1.575158, 0.633841, 0.000000},{
      1.578820, 0.626654, 0.000000},{1.579077, 0.626840, -0.004033}}],
    Polygon[{{1.575158, 0.633841, 0.000000},{1.575460, 0.633939, 0.004033},{
      1.579077, 0.626840, 0.004033},{1.578820, 0.626654, 0.000000}}],
    Polygon[{{1.575460, 0.633939, 0.004033},{1.576358, 0.634231, 0.007968},{
      1.579841, 0.627395, 0.007968},{1.579077, 0.626840, 0.004033}}],
    Polygon[{{1.576358, 0.634231, 0.007968},{1.577831, 0.634710, 0.011705},{
      1.581094, 0.628305, 0.011705},{1.579841, 0.627395, 0.007968}}],
    Polygon[{{1.577831, 0.634710, 0.011705},{1.579841, 0.635363, 0.015155},{
      1.582804, 0.629548, 0.015155},{1.581094, 0.628305, 0.011705}}],
    Polygon[{{1.579841, 0.635363, 0.015155},{1.582340, 0.636175, 0.018232},{
      1.584930, 0.631093, 0.018232},{1.582804, 0.629548, 0.015155}}],
    Polygon[{{1.582340, 0.636175, 0.018232},{1.585266, 0.637126, 0.020859},{
      1.587419, 0.632901, 0.020859},{1.584930, 0.631093, 0.018232}}],
    Polygon[{{1.585266, 0.637126, 0.020859},{1.588547, 0.638192, 0.022973},{
      1.590209, 0.634929, 0.022973},{1.587419, 0.632901, 0.020859}}],
    Polygon[{{1.588547, 0.638192, 0.022973},{1.592102, 0.639347, 0.024521},{
      1.593233, 0.637126, 0.024521},{1.590209, 0.634929, 0.022973}}],
    Polygon[{{1.592102, 0.639347, 0.024521},{1.595843, 0.640562, 0.025466},{
      1.596416, 0.639438, 0.025466},{1.593233, 0.637126, 0.024521}}],
    Polygon[{{1.596416, 0.639438, -0.025466},{1.593233, 0.637126, -0.024521},{
      1.594996, 0.635363, -0.024521},{1.597309, 0.638546, -0.025466}}],
    Polygon[{{1.593233, 0.637126, -0.024521},{1.590209, 0.634929, -0.022973},{
      1.592799, 0.632339, -0.022973},{1.594996, 0.635363, -0.024521}}],
    Polygon[{{1.590209, 0.634929, -0.022973},{1.587419, 0.632901, -0.020859},{
      1.590771, 0.629548, -0.020859},{1.592799, 0.632339, -0.022973}}],
    Polygon[{{1.587419, 0.632901, -0.020859},{1.584930, 0.631093, -0.018232},{
      1.588963, 0.627059, -0.018232},{1.590771, 0.629548, -0.020859}}],
    Polygon[{{1.584930, 0.631093, -0.018232},{1.582804, 0.629548, -0.015155},{
      1.587419, 0.624933, -0.015155},{1.588963, 0.627059, -0.018232}}],
    Polygon[{{1.582804, 0.629548, -0.015155},{1.581094, 0.628305, -0.011705},{
      1.586176, 0.623223, -0.011705},{1.587419, 0.624933, -0.015155}}],
    Polygon[{{1.581094, 0.628305, -0.011705},{1.579841, 0.627395, -0.007968},{
      1.585266, 0.621971, -0.007968},{1.586176, 0.623223, -0.011705}}],
    Polygon[{{1.579841, 0.627395, -0.007968},{1.579077, 0.626840, -0.004033},{
      1.584711, 0.621206, -0.004033},{1.585266, 0.621971, -0.007968}}],
    Polygon[{{1.579077, 0.626840, -0.004033},{1.578820, 0.626654, 0.000000},{
      1.584524, 0.620950, 0.000000},{1.584711, 0.621206, -0.004033}}],
    Polygon[{{1.578820, 0.626654, 0.000000},{1.579077, 0.626840, 0.004033},{
      1.584711, 0.621206, 0.004033},{1.584524, 0.620950, 0.000000}}],
    Polygon[{{1.579077, 0.626840, 0.004033},{1.579841, 0.627395, 0.007968},{
      1.585266, 0.621971, 0.007968},{1.584711, 0.621206, 0.004033}}],
    Polygon[{{1.579841, 0.627395, 0.007968},{1.581094, 0.628305, 0.011705},{
      1.586176, 0.623223, 0.011705},{1.585266, 0.621971, 0.007968}}],
    Polygon[{{1.581094, 0.628305, 0.011705},{1.582804, 0.629548, 0.015155},{
      1.587419, 0.624933, 0.015155},{1.586176, 0.623223, 0.011705}}],
    Polygon[{{1.582804, 0.629548, 0.015155},{1.584930, 0.631093, 0.018232},{
      1.588963, 0.627059, 0.018232},{1.587419, 0.624933, 0.015155}}],
    Polygon[{{1.584930, 0.631093, 0.018232},{1.587419, 0.632901, 0.020859},{
      1.590771, 0.629548, 0.020859},{1.588963, 0.627059, 0.018232}}],
    Polygon[{{1.587419, 0.632901, 0.020859},{1.590209, 0.634929, 0.022973},{
      1.592799, 0.632339, 0.022973},{1.590771, 0.629548, 0.020859}}],
    Polygon[{{1.590209, 0.634929, 0.022973},{1.593233, 0.637126, 0.024521},{
      1.594996, 0.635363, 0.024521},{1.592799, 0.632339, 0.022973}}],
    Polygon[{{1.593233, 0.637126, 0.024521},{1.596416, 0.639438, 0.025466},{
      1.597309, 0.638546, 0.025466},{1.594996, 0.635363, 0.024521}}],
    Polygon[{{1.597309, 0.638546, -0.025466},{1.594996, 0.635363, -0.024521},{
      1.597217, 0.634231, -0.024521},{1.598433, 0.637973, -0.025466}}],
    Polygon[{{1.594996, 0.635363, -0.024521},{1.592799, 0.632339, -0.022973},{
      1.596062, 0.630676, -0.022973},{1.597217, 0.634231, -0.024521}}],
    Polygon[{{1.592799, 0.632339, -0.022973},{1.590771, 0.629548, -0.020859},{
      1.594996, 0.627395, -0.020859},{1.596062, 0.630676, -0.022973}}],
    Polygon[{{1.590771, 0.629548, -0.020859},{1.588963, 0.627059, -0.018232},{
      1.594046, 0.624470, -0.018232},{1.594996, 0.627395, -0.020859}}],
    Polygon[{{1.588963, 0.627059, -0.018232},{1.587419, 0.624933, -0.015155},{
      1.593233, 0.621971, -0.015155},{1.594046, 0.624470, -0.018232}}],
    Polygon[{{1.587419, 0.624933, -0.015155},{1.586176, 0.623223, -0.011705},{
      1.592580, 0.619960, -0.011705},{1.593233, 0.621971, -0.015155}}],
    Polygon[{{1.586176, 0.623223, -0.011705},{1.585266, 0.621971, -0.007968},{
      1.592102, 0.618487, -0.007968},{1.592580, 0.619960, -0.011705}}],
    Polygon[{{1.585266, 0.621971, -0.007968},{1.584711, 0.621206, -0.004033},{
      1.591810, 0.617589, -0.004033},{1.592102, 0.618487, -0.007968}}],
    Polygon[{{1.584711, 0.621206, -0.004033},{1.584524, 0.620950, 0.000000},{
      1.591712, 0.617287, 0.000000},{1.591810, 0.617589, -0.004033}}],
    Polygon[{{1.584524, 0.620950, 0.000000},{1.584711, 0.621206, 0.004033},{
      1.591810, 0.617589, 0.004033},{1.591712, 0.617287, 0.000000}}],
    Polygon[{{1.584711, 0.621206, 0.004033},{1.585266, 0.621971, 0.007968},{
      1.592102, 0.618487, 0.007968},{1.591810, 0.617589, 0.004033}}],
    Polygon[{{1.585266, 0.621971, 0.007968},{1.586176, 0.623223, 0.011705},{
      1.592580, 0.619960, 0.011705},{1.592102, 0.618487, 0.007968}}],
    Polygon[{{1.586176, 0.623223, 0.011705},{1.587419, 0.624933, 0.015155},{
      1.593233, 0.621971, 0.015155},{1.592580, 0.619960, 0.011705}}],
    Polygon[{{1.587419, 0.624933, 0.015155},{1.588963, 0.627059, 0.018232},{
      1.594046, 0.624470, 0.018232},{1.593233, 0.621971, 0.015155}}],
    Polygon[{{1.588963, 0.627059, 0.018232},{1.590771, 0.629548, 0.020859},{
      1.594996, 0.627395, 0.020859},{1.594046, 0.624470, 0.018232}}],
    Polygon[{{1.590771, 0.629548, 0.020859},{1.592799, 0.632339, 0.022973},{
      1.596062, 0.630676, 0.022973},{1.594996, 0.627395, 0.020859}}],
    Polygon[{{1.592799, 0.632339, 0.022973},{1.594996, 0.635363, 0.024521},{
      1.597217, 0.634231, 0.024521},{1.596062, 0.630676, 0.022973}}],
    Polygon[{{1.594996, 0.635363, 0.024521},{1.597309, 0.638546, 0.025466},{
      1.598433, 0.637973, 0.025466},{1.597217, 0.634231, 0.024521}}],
    Polygon[{{1.598433, 0.637973, -0.025466},{1.597217, 0.634231, -0.024521},{
      1.599679, 0.633841, -0.024521},{1.599679, 0.637775, -0.025466}}],
    Polygon[{{1.597217, 0.634231, -0.024521},{1.596062, 0.630676, -0.022973},{
      1.599679, 0.630103, -0.022973},{1.599679, 0.633841, -0.024521}}],
    Polygon[{{1.596062, 0.630676, -0.022973},{1.594996, 0.627395, -0.020859},{
      1.599679, 0.626654, -0.020859},{1.599679, 0.630103, -0.022973}}],
    Polygon[{{1.594996, 0.627395, -0.020859},{1.594046, 0.624470, -0.018232},{
      1.599679, 0.623577, -0.018232},{1.599679, 0.626654, -0.020859}}],
    Polygon[{{1.594046, 0.624470, -0.018232},{1.593233, 0.621971, -0.015155},{
      1.599679, 0.620950, -0.015155},{1.599679, 0.623577, -0.018232}}],
    Polygon[{{1.593233, 0.621971, -0.015155},{1.592580, 0.619960, -0.011705},{
      1.599679, 0.618836, -0.011705},{1.599679, 0.620950, -0.015155}}],
    Polygon[{{1.592580, 0.619960, -0.011705},{1.592102, 0.618487, -0.007968},{
      1.599679, 0.617287, -0.007968},{1.599679, 0.618836, -0.011705}}],
    Polygon[{{1.592102, 0.618487, -0.007968},{1.591810, 0.617589, -0.004033},{
      1.599679, 0.616343, -0.004033},{1.599679, 0.617287, -0.007968}}],
    Polygon[{{1.591810, 0.617589, -0.004033},{1.591712, 0.617287, 0.000000},{
      1.599679, 0.616025, 0.000000},{1.599679, 0.616343, -0.004033}}],
    Polygon[{{1.591712, 0.617287, 0.000000},{1.591810, 0.617589, 0.004033},{
      1.599679, 0.616343, 0.004033},{1.599679, 0.616025, 0.000000}}],
    Polygon[{{1.591810, 0.617589, 0.004033},{1.592102, 0.618487, 0.007968},{
      1.599679, 0.617287, 0.007968},{1.599679, 0.616343, 0.004033}}],
    Polygon[{{1.592102, 0.618487, 0.007968},{1.592580, 0.619960, 0.011705},{
      1.599679, 0.618836, 0.011705},{1.599679, 0.617287, 0.007968}}],
    Polygon[{{1.592580, 0.619960, 0.011705},{1.593233, 0.621971, 0.015155},{
      1.599679, 0.620950, 0.015155},{1.599679, 0.618836, 0.011705}}],
    Polygon[{{1.593233, 0.621971, 0.015155},{1.594046, 0.624470, 0.018232},{
      1.599679, 0.623577, 0.018232},{1.599679, 0.620950, 0.015155}}],
    Polygon[{{1.594046, 0.624470, 0.018232},{1.594996, 0.627395, 0.020859},{
      1.599679, 0.626654, 0.020859},{1.599679, 0.623577, 0.018232}}],
    Polygon[{{1.594996, 0.627395, 0.020859},{1.596062, 0.630676, 0.022973},{
      1.599679, 0.630103, 0.022973},{1.599679, 0.626654, 0.020859}}],
    Polygon[{{1.596062, 0.630676, 0.022973},{1.597217, 0.634231, 0.024521},{
      1.599679, 0.633841, 0.024521},{1.599679, 0.630103, 0.022973}}],
    Polygon[{{1.597217, 0.634231, 0.024521},{1.598433, 0.637973, 0.025466},{
      1.599679, 0.637775, 0.025466},{1.599679, 0.633841, 0.024521}}],
    Polygon[{{1.599679, 0.637775, -0.025466},{1.599679, 0.633841, -0.024521},{
      1.602141, 0.634231, -0.024521},{1.600926, 0.637973, -0.025466}}],
    Polygon[{{1.599679, 0.633841, -0.024521},{1.599679, 0.630103, -0.022973},{
      1.603297, 0.630676, -0.022973},{1.602141, 0.634231, -0.024521}}],
    Polygon[{{1.599679, 0.630103, -0.022973},{1.599679, 0.626654, -0.020859},{
      1.604363, 0.627395, -0.020859},{1.603297, 0.630676, -0.022973}}],
    Polygon[{{1.599679, 0.626654, -0.020859},{1.599679, 0.623577, -0.018232},{
      1.605313, 0.624470, -0.018232},{1.604363, 0.627395, -0.020859}}],
    Polygon[{{1.599679, 0.623577, -0.018232},{1.599679, 0.620950, -0.015155},{
      1.606125, 0.621971, -0.015155},{1.605313, 0.624470, -0.018232}}],
    Polygon[{{1.599679, 0.620950, -0.015155},{1.599679, 0.618836, -0.011705},{
      1.606779, 0.619960, -0.011705},{1.606125, 0.621971, -0.015155}}],
    Polygon[{{1.599679, 0.618836, -0.011705},{1.599679, 0.617287, -0.007968},{
      1.607257, 0.618487, -0.007968},{1.606779, 0.619960, -0.011705}}],
    Polygon[{{1.599679, 0.617287, -0.007968},{1.599679, 0.616343, -0.004033},{
      1.607549, 0.617589, -0.004033},{1.607257, 0.618487, -0.007968}}],
    Polygon[{{1.599679, 0.616343, -0.004033},{1.599679, 0.616025, 0.000000},{
      1.607647, 0.617287, 0.000000},{1.607549, 0.617589, -0.004033}}],
    Polygon[{{1.599679, 0.616025, 0.000000},{1.599679, 0.616343, 0.004033},{
      1.607549, 0.617589, 0.004033},{1.607647, 0.617287, 0.000000}}],
    Polygon[{{1.599679, 0.616343, 0.004033},{1.599679, 0.617287, 0.007968},{
      1.607257, 0.618487, 0.007968},{1.607549, 0.617589, 0.004033}}],
    Polygon[{{1.599679, 0.617287, 0.007968},{1.599679, 0.618836, 0.011705},{
      1.606779, 0.619960, 0.011705},{1.607257, 0.618487, 0.007968}}],
    Polygon[{{1.599679, 0.618836, 0.011705},{1.599679, 0.620950, 0.015155},{
      1.606125, 0.621971, 0.015155},{1.606779, 0.619960, 0.011705}}],
    Polygon[{{1.599679, 0.620950, 0.015155},{1.599679, 0.623577, 0.018232},{
      1.605313, 0.624470, 0.018232},{1.606125, 0.621971, 0.015155}}],
    Polygon[{{1.599679, 0.623577, 0.018232},{1.599679, 0.626654, 0.020859},{
      1.604363, 0.627395, 0.020859},{1.605313, 0.624470, 0.018232}}],
    Polygon[{{1.599679, 0.626654, 0.020859},{1.599679, 0.630103, 0.022973},{
      1.603297, 0.630676, 0.022973},{1.604363, 0.627395, 0.020859}}],
    Polygon[{{1.599679, 0.630103, 0.022973},{1.599679, 0.633841, 0.024521},{
      1.602141, 0.634231, 0.024521},{1.603297, 0.630676, 0.022973}}],
    Polygon[{{1.599679, 0.633841, 0.024521},{1.599679, 0.637775, 0.025466},{
      1.600926, 0.637973, 0.025466},{1.602141, 0.634231, 0.024521}}],
    Polygon[{{1.600926, 0.637973, -0.025466},{1.602141, 0.634231, -0.024521},{
      1.604363, 0.635363, -0.024521},{1.602050, 0.638546, -0.025466}}],
    Polygon[{{1.602141, 0.634231, -0.024521},{1.603297, 0.630676, -0.022973},{
      1.606560, 0.632339, -0.022973},{1.604363, 0.635363, -0.024521}}],
    Polygon[{{1.603297, 0.630676, -0.022973},{1.604363, 0.627395, -0.020859},{
      1.608587, 0.629548, -0.020859},{1.606560, 0.632339, -0.022973}}],
    Polygon[{{1.604363, 0.627395, -0.020859},{1.605313, 0.624470, -0.018232},{
      1.610396, 0.627059, -0.018232},{1.608587, 0.629548, -0.020859}}],
    Polygon[{{1.605313, 0.624470, -0.018232},{1.606125, 0.621971, -0.015155},{
      1.611940, 0.624933, -0.015155},{1.610396, 0.627059, -0.018232}}],
    Polygon[{{1.606125, 0.621971, -0.015155},{1.606779, 0.619960, -0.011705},{
      1.613183, 0.623223, -0.011705},{1.611940, 0.624933, -0.015155}}],
    Polygon[{{1.606779, 0.619960, -0.011705},{1.607257, 0.618487, -0.007968},{
      1.614093, 0.621971, -0.007968},{1.613183, 0.623223, -0.011705}}],
    Polygon[{{1.607257, 0.618487, -0.007968},{1.607549, 0.617589, -0.004033},{
      1.614648, 0.621206, -0.004033},{1.614093, 0.621971, -0.007968}}],
    Polygon[{{1.607549, 0.617589, -0.004033},{1.607647, 0.617287, 0.000000},{
      1.614834, 0.620950, 0.000000},{1.614648, 0.621206, -0.004033}}],
    Polygon[{{1.607647, 0.617287, 0.000000},{1.607549, 0.617589, 0.004033},{
      1.614648, 0.621206, 0.004033},{1.614834, 0.620950, 0.000000}}],
    Polygon[{{1.607549, 0.617589, 0.004033},{1.607257, 0.618487, 0.007968},{
      1.614093, 0.621971, 0.007968},{1.614648, 0.621206, 0.004033}}],
    Polygon[{{1.607257, 0.618487, 0.007968},{1.606779, 0.619960, 0.011705},{
      1.613183, 0.623223, 0.011705},{1.614093, 0.621971, 0.007968}}],
    Polygon[{{1.606779, 0.619960, 0.011705},{1.606125, 0.621971, 0.015155},{
      1.611940, 0.624933, 0.015155},{1.613183, 0.623223, 0.011705}}],
    Polygon[{{1.606125, 0.621971, 0.015155},{1.605313, 0.624470, 0.018232},{
      1.610396, 0.627059, 0.018232},{1.611940, 0.624933, 0.015155}}],
    Polygon[{{1.605313, 0.624470, 0.018232},{1.604363, 0.627395, 0.020859},{
      1.608587, 0.629548, 0.020859},{1.610396, 0.627059, 0.018232}}],
    Polygon[{{1.604363, 0.627395, 0.020859},{1.603297, 0.630676, 0.022973},{
      1.606560, 0.632339, 0.022973},{1.608587, 0.629548, 0.020859}}],
    Polygon[{{1.603297, 0.630676, 0.022973},{1.602141, 0.634231, 0.024521},{
      1.604363, 0.635363, 0.024521},{1.606560, 0.632339, 0.022973}}],
    Polygon[{{1.602141, 0.634231, 0.024521},{1.600926, 0.637973, 0.025466},{
      1.602050, 0.638546, 0.025466},{1.604363, 0.635363, 0.024521}}],
    Polygon[{{1.602050, 0.638546, -0.025466},{1.604363, 0.635363, -0.024521},{
      1.606125, 0.637126, -0.024521},{1.602942, 0.639438, -0.025466}}],
    Polygon[{{1.604363, 0.635363, -0.024521},{1.606560, 0.632339, -0.022973},{
      1.609149, 0.634929, -0.022973},{1.606125, 0.637126, -0.024521}}],
    Polygon[{{1.606560, 0.632339, -0.022973},{1.608587, 0.629548, -0.020859},{
      1.611940, 0.632901, -0.020859},{1.609149, 0.634929, -0.022973}}],
    Polygon[{{1.608587, 0.629548, -0.020859},{1.610396, 0.627059, -0.018232},{
      1.614429, 0.631093, -0.018232},{1.611940, 0.632901, -0.020859}}],
    Polygon[{{1.610396, 0.627059, -0.018232},{1.611940, 0.624933, -0.015155},{
      1.616555, 0.629548, -0.015155},{1.614429, 0.631093, -0.018232}}],
    Polygon[{{1.611940, 0.624933, -0.015155},{1.613183, 0.623223, -0.011705},{
      1.618265, 0.628305, -0.011705},{1.616555, 0.629548, -0.015155}}],
    Polygon[{{1.613183, 0.623223, -0.011705},{1.614093, 0.621971, -0.007968},{
      1.619518, 0.627395, -0.007968},{1.618265, 0.628305, -0.011705}}],
    Polygon[{{1.614093, 0.621971, -0.007968},{1.614648, 0.621206, -0.004033},{
      1.620282, 0.626840, -0.004033},{1.619518, 0.627395, -0.007968}}],
    Polygon[{{1.614648, 0.621206, -0.004033},{1.614834, 0.620950, 0.000000},{
      1.620539, 0.626654, 0.000000},{1.620282, 0.626840, -0.004033}}],
    Polygon[{{1.614834, 0.620950, 0.000000},{1.614648, 0.621206, 0.004033},{
      1.620282, 0.626840, 0.004033},{1.620539, 0.626654, 0.000000}}],
    Polygon[{{1.614648, 0.621206, 0.004033},{1.614093, 0.621971, 0.007968},{
      1.619518, 0.627395, 0.007968},{1.620282, 0.626840, 0.004033}}],
    Polygon[{{1.614093, 0.621971, 0.007968},{1.613183, 0.623223, 0.011705},{
      1.618265, 0.628305, 0.011705},{1.619518, 0.627395, 0.007968}}],
    Polygon[{{1.613183, 0.623223, 0.011705},{1.611940, 0.624933, 0.015155},{
      1.616555, 0.629548, 0.015155},{1.618265, 0.628305, 0.011705}}],
    Polygon[{{1.611940, 0.624933, 0.015155},{1.610396, 0.627059, 0.018232},{
      1.614429, 0.631093, 0.018232},{1.616555, 0.629548, 0.015155}}],
    Polygon[{{1.610396, 0.627059, 0.018232},{1.608587, 0.629548, 0.020859},{
      1.611940, 0.632901, 0.020859},{1.614429, 0.631093, 0.018232}}],
    Polygon[{{1.608587, 0.629548, 0.020859},{1.606560, 0.632339, 0.022973},{
      1.609149, 0.634929, 0.022973},{1.611940, 0.632901, 0.020859}}],
    Polygon[{{1.606560, 0.632339, 0.022973},{1.604363, 0.635363, 0.024521},{
      1.606125, 0.637126, 0.024521},{1.609149, 0.634929, 0.022973}}],
    Polygon[{{1.604363, 0.635363, 0.024521},{1.602050, 0.638546, 0.025466},{
      1.602942, 0.639438, 0.025466},{1.606125, 0.637126, 0.024521}}],
    Polygon[{{1.602942, 0.639438, -0.025466},{1.606125, 0.637126, -0.024521},{
      1.607257, 0.639347, -0.024521},{1.603515, 0.640562, -0.025466}}],
    Polygon[{{1.606125, 0.637126, -0.024521},{1.609149, 0.634929, -0.022973},{
      1.610812, 0.638192, -0.022973},{1.607257, 0.639347, -0.024521}}],
    Polygon[{{1.609149, 0.634929, -0.022973},{1.611940, 0.632901, -0.020859},{
      1.614093, 0.637126, -0.020859},{1.610812, 0.638192, -0.022973}}],
    Polygon[{{1.611940, 0.632901, -0.020859},{1.614429, 0.631093, -0.018232},{
      1.617019, 0.636175, -0.018232},{1.614093, 0.637126, -0.020859}}],
    Polygon[{{1.614429, 0.631093, -0.018232},{1.616555, 0.629548, -0.015155},{
      1.619518, 0.635363, -0.015155},{1.617019, 0.636175, -0.018232}}],
    Polygon[{{1.616555, 0.629548, -0.015155},{1.618265, 0.628305, -0.011705},{
      1.621528, 0.634710, -0.011705},{1.619518, 0.635363, -0.015155}}],
    Polygon[{{1.618265, 0.628305, -0.011705},{1.619518, 0.627395, -0.007968},{
      1.623001, 0.634231, -0.007968},{1.621528, 0.634710, -0.011705}}],
    Polygon[{{1.619518, 0.627395, -0.007968},{1.620282, 0.626840, -0.004033},{
      1.623899, 0.633939, -0.004033},{1.623001, 0.634231, -0.007968}}],
    Polygon[{{1.620282, 0.626840, -0.004033},{1.620539, 0.626654, 0.000000},{
      1.624201, 0.633841, 0.000000},{1.623899, 0.633939, -0.004033}}],
    Polygon[{{1.620539, 0.626654, 0.000000},{1.620282, 0.626840, 0.004033},{
      1.623899, 0.633939, 0.004033},{1.624201, 0.633841, 0.000000}}],
    Polygon[{{1.620282, 0.626840, 0.004033},{1.619518, 0.627395, 0.007968},{
      1.623001, 0.634231, 0.007968},{1.623899, 0.633939, 0.004033}}],
    Polygon[{{1.619518, 0.627395, 0.007968},{1.618265, 0.628305, 0.011705},{
      1.621528, 0.634710, 0.011705},{1.623001, 0.634231, 0.007968}}],
    Polygon[{{1.618265, 0.628305, 0.011705},{1.616555, 0.629548, 0.015155},{
      1.619518, 0.635363, 0.015155},{1.621528, 0.634710, 0.011705}}],
    Polygon[{{1.616555, 0.629548, 0.015155},{1.614429, 0.631093, 0.018232},{
      1.617019, 0.636175, 0.018232},{1.619518, 0.635363, 0.015155}}],
    Polygon[{{1.614429, 0.631093, 0.018232},{1.611940, 0.632901, 0.020859},{
      1.614093, 0.637126, 0.020859},{1.617019, 0.636175, 0.018232}}],
    Polygon[{{1.611940, 0.632901, 0.020859},{1.609149, 0.634929, 0.022973},{
      1.610812, 0.638192, 0.022973},{1.614093, 0.637126, 0.020859}}],
    Polygon[{{1.609149, 0.634929, 0.022973},{1.606125, 0.637126, 0.024521},{
      1.607257, 0.639347, 0.024521},{1.610812, 0.638192, 0.022973}}],
    Polygon[{{1.606125, 0.637126, 0.024521},{1.602942, 0.639438, 0.025466},{
      1.603515, 0.640562, 0.025466},{1.607257, 0.639347, 0.024521}}],
    Polygon[{{1.603515, 0.640562, -0.025466},{1.607257, 0.639347, -0.024521},{
      1.607647, 0.641809, -0.024521},{1.603713, 0.641809, -0.025466}}],
    Polygon[{{1.607257, 0.639347, -0.024521},{1.610812, 0.638192, -0.022973},{
      1.611385, 0.641809, -0.022973},{1.607647, 0.641809, -0.024521}}],
    Polygon[{{1.610812, 0.638192, -0.022973},{1.614093, 0.637126, -0.020859},{
      1.614834, 0.641809, -0.020859},{1.611385, 0.641809, -0.022973}}],
    Polygon[{{1.614093, 0.637126, -0.020859},{1.617019, 0.636175, -0.018232},{
      1.617911, 0.641809, -0.018232},{1.614834, 0.641809, -0.020859}}],
    Polygon[{{1.617019, 0.636175, -0.018232},{1.619518, 0.635363, -0.015155},{
      1.620539, 0.641809, -0.015155},{1.617911, 0.641809, -0.018232}}],
    Polygon[{{1.619518, 0.635363, -0.015155},{1.621528, 0.634710, -0.011705},{
      1.622653, 0.641809, -0.011705},{1.620539, 0.641809, -0.015155}}],
    Polygon[{{1.621528, 0.634710, -0.011705},{1.623001, 0.634231, -0.007968},{
      1.624201, 0.641809, -0.007968},{1.622653, 0.641809, -0.011705}}],
    Polygon[{{1.623001, 0.634231, -0.007968},{1.623899, 0.633939, -0.004033},{
      1.625145, 0.641809, -0.004033},{1.624201, 0.641809, -0.007968}}],
    Polygon[{{1.623899, 0.633939, -0.004033},{1.624201, 0.633841, 0.000000},{
      1.625463, 0.641809, 0.000000},{1.625145, 0.641809, -0.004033}}],
    Polygon[{{1.624201, 0.633841, 0.000000},{1.623899, 0.633939, 0.004033},{
      1.625145, 0.641809, 0.004033},{1.625463, 0.641809, 0.000000}}],
    Polygon[{{1.623899, 0.633939, 0.004033},{1.623001, 0.634231, 0.007968},{
      1.624201, 0.641809, 0.007968},{1.625145, 0.641809, 0.004033}}],
    Polygon[{{1.623001, 0.634231, 0.007968},{1.621528, 0.634710, 0.011705},{
      1.622653, 0.641809, 0.011705},{1.624201, 0.641809, 0.007968}}],
    Polygon[{{1.621528, 0.634710, 0.011705},{1.619518, 0.635363, 0.015155},{
      1.620539, 0.641809, 0.015155},{1.622653, 0.641809, 0.011705}}],
    Polygon[{{1.619518, 0.635363, 0.015155},{1.617019, 0.636175, 0.018232},{
      1.617911, 0.641809, 0.018232},{1.620539, 0.641809, 0.015155}}],
    Polygon[{{1.617019, 0.636175, 0.018232},{1.614093, 0.637126, 0.020859},{
      1.614834, 0.641809, 0.020859},{1.617911, 0.641809, 0.018232}}],
    Polygon[{{1.614093, 0.637126, 0.020859},{1.610812, 0.638192, 0.022973},{
      1.611385, 0.641809, 0.022973},{1.614834, 0.641809, 0.020859}}],
    Polygon[{{1.610812, 0.638192, 0.022973},{1.607257, 0.639347, 0.024521},{
      1.607647, 0.641809, 0.024521},{1.611385, 0.641809, 0.022973}}],
    Polygon[{{1.607257, 0.639347, 0.024521},{1.603515, 0.640562, 0.025466},{
      1.603713, 0.641809, 0.025466},{1.607647, 0.641809, 0.024521}}],
    Polygon[{{1.668828, 0.549716, -0.013647},{1.670936, 0.549716, -0.013141},{
      1.670727, 0.551035, -0.013141},{1.668722, 0.550384, -0.013647}}],
    Polygon[{{1.670936, 0.549716, -0.013141},{1.672940, 0.549716, -0.012311},{
      1.672633, 0.551654, -0.012311},{1.670727, 0.551035, -0.013141}}],
    Polygon[{{1.672940, 0.549716, -0.012311},{1.674788, 0.549716, -0.011178},{
      1.674391, 0.552225, -0.011178},{1.672633, 0.551654, -0.012311}}],
    Polygon[{{1.674788, 0.549716, -0.011178},{1.676437, 0.549716, -0.009770},{
      1.675959, 0.552735, -0.009770},{1.674391, 0.552225, -0.011178}}],
    Polygon[{{1.676437, 0.549716, -0.009770},{1.677845, 0.549716, -0.008122},{
      1.677298, 0.553170, -0.008122},{1.675959, 0.552735, -0.009770}}],
    Polygon[{{1.677845, 0.549716, -0.008122},{1.678978, 0.549716, -0.006273},{
      1.678375, 0.553520, -0.006273},{1.677298, 0.553170, -0.008122}}],
    Polygon[{{1.678978, 0.549716, -0.006273},{1.679808, 0.549716, -0.004270},{
      1.679165, 0.553777, -0.004270},{1.678375, 0.553520, -0.006273}}],
    Polygon[{{1.679808, 0.549716, -0.004270},{1.680314, 0.549716, -0.002162},{
      1.679646, 0.553933, -0.002162},{1.679165, 0.553777, -0.004270}}],
    Polygon[{{1.680314, 0.549716, -0.002162},{1.680484, 0.549716, 0.000000},{
      1.679808, 0.553985, 0.000000},{1.679646, 0.553933, -0.002162}}],
    Polygon[{{1.680484, 0.549716, 0.000000},{1.680314, 0.549716, 0.002162},{
      1.679646, 0.553933, 0.002162},{1.679808, 0.553985, 0.000000}}],
    Polygon[{{1.680314, 0.549716, 0.002162},{1.679808, 0.549716, 0.004270},{
      1.679165, 0.553777, 0.004270},{1.679646, 0.553933, 0.002162}}],
    Polygon[{{1.679808, 0.549716, 0.004270},{1.678978, 0.549716, 0.006273},{
      1.678375, 0.553520, 0.006273},{1.679165, 0.553777, 0.004270}}],
    Polygon[{{1.678978, 0.549716, 0.006273},{1.677845, 0.549716, 0.008122},{
      1.677298, 0.553170, 0.008122},{1.678375, 0.553520, 0.006273}}],
    Polygon[{{1.677845, 0.549716, 0.008122},{1.676437, 0.549716, 0.009770},{
      1.675959, 0.552735, 0.009770},{1.677298, 0.553170, 0.008122}}],
    Polygon[{{1.676437, 0.549716, 0.009770},{1.674788, 0.549716, 0.011178},{
      1.674391, 0.552225, 0.011178},{1.675959, 0.552735, 0.009770}}],
    Polygon[{{1.674788, 0.549716, 0.011178},{1.672940, 0.549716, 0.012311},{
      1.672633, 0.551654, 0.012311},{1.674391, 0.552225, 0.011178}}],
    Polygon[{{1.672940, 0.549716, 0.012311},{1.670936, 0.549716, 0.013141},{
      1.670727, 0.551035, 0.013141},{1.672633, 0.551654, 0.012311}}],
    Polygon[{{1.670936, 0.549716, 0.013141},{1.668828, 0.549716, 0.013647},{
      1.668722, 0.550384, 0.013647},{1.670727, 0.551035, 0.013141}}],
    Polygon[{{1.668722, 0.550384, -0.013647},{1.670727, 0.551035, -0.013141},{
      1.670121, 0.552225, -0.013141},{1.668415, 0.550986, -0.013647}}],
    Polygon[{{1.670727, 0.551035, -0.013141},{1.672633, 0.551654, -0.012311},{
      1.671742, 0.553403, -0.012311},{1.670121, 0.552225, -0.013141}}],
    Polygon[{{1.672633, 0.551654, -0.012311},{1.674391, 0.552225, -0.011178},{
      1.673237, 0.554489, -0.011178},{1.671742, 0.553403, -0.012311}}],
    Polygon[{{1.674391, 0.552225, -0.011178},{1.675959, 0.552735, -0.009770},{
      1.674571, 0.555459, -0.009770},{1.673237, 0.554489, -0.011178}}],
    Polygon[{{1.675959, 0.552735, -0.009770},{1.677298, 0.553170, -0.008122},{
      1.675710, 0.556286, -0.008122},{1.674571, 0.555459, -0.009770}}],
    Polygon[{{1.677298, 0.553170, -0.008122},{1.678375, 0.553520, -0.006273},{
      1.676627, 0.556952, -0.006273},{1.675710, 0.556286, -0.008122}}],
    Polygon[{{1.678375, 0.553520, -0.006273},{1.679165, 0.553777, -0.004270},{
      1.677298, 0.557440, -0.004270},{1.676627, 0.556952, -0.006273}}],
    Polygon[{{1.679165, 0.553777, -0.004270},{1.679646, 0.553933, -0.002162},{
      1.677707, 0.557737, -0.002162},{1.677298, 0.557440, -0.004270}}],
    Polygon[{{1.679646, 0.553933, -0.002162},{1.679808, 0.553985, 0.000000},{
      1.677845, 0.557837, 0.000000},{1.677707, 0.557737, -0.002162}}],
    Polygon[{{1.679808, 0.553985, 0.000000},{1.679646, 0.553933, 0.002162},{
      1.677707, 0.557737, 0.002162},{1.677845, 0.557837, 0.000000}}],
    Polygon[{{1.679646, 0.553933, 0.002162},{1.679165, 0.553777, 0.004270},{
      1.677298, 0.557440, 0.004270},{1.677707, 0.557737, 0.002162}}],
    Polygon[{{1.679165, 0.553777, 0.004270},{1.678375, 0.553520, 0.006273},{
      1.676627, 0.556952, 0.006273},{1.677298, 0.557440, 0.004270}}],
    Polygon[{{1.678375, 0.553520, 0.006273},{1.677298, 0.553170, 0.008122},{
      1.675710, 0.556286, 0.008122},{1.676627, 0.556952, 0.006273}}],
    Polygon[{{1.677298, 0.553170, 0.008122},{1.675959, 0.552735, 0.009770},{
      1.674571, 0.555459, 0.009770},{1.675710, 0.556286, 0.008122}}],
    Polygon[{{1.675959, 0.552735, 0.009770},{1.674391, 0.552225, 0.011178},{
      1.673237, 0.554489, 0.011178},{1.674571, 0.555459, 0.009770}}],
    Polygon[{{1.674391, 0.552225, 0.011178},{1.672633, 0.551654, 0.012311},{
      1.671742, 0.553403, 0.012311},{1.673237, 0.554489, 0.011178}}],
    Polygon[{{1.672633, 0.551654, 0.012311},{1.670727, 0.551035, 0.013141},{
      1.670121, 0.552225, 0.013141},{1.671742, 0.553403, 0.012311}}],
    Polygon[{{1.670727, 0.551035, 0.013141},{1.668722, 0.550384, 0.013647},{
      1.668415, 0.550986, 0.013647},{1.670121, 0.552225, 0.013141}}],
    Polygon[{{1.668415, 0.550986, -0.013647},{1.670121, 0.552225, -0.013141},{
      1.669176, 0.553170, -0.013141},{1.667937, 0.551464, -0.013647}}],
    Polygon[{{1.670121, 0.552225, -0.013141},{1.671742, 0.553403, -0.012311},{
      1.670354, 0.554791, -0.012311},{1.669176, 0.553170, -0.013141}}],
    Polygon[{{1.671742, 0.553403, -0.012311},{1.673237, 0.554489, -0.011178},{
      1.671440, 0.556286, -0.011178},{1.670354, 0.554791, -0.012311}}],
    Polygon[{{1.673237, 0.554489, -0.011178},{1.674571, 0.555459, -0.009770},{
      1.672410, 0.557620, -0.009770},{1.671440, 0.556286, -0.011178}}],
    Polygon[{{1.674571, 0.555459, -0.009770},{1.675710, 0.556286, -0.008122},{
      1.673237, 0.558759, -0.008122},{1.672410, 0.557620, -0.009770}}],
    Polygon[{{1.675710, 0.556286, -0.008122},{1.676627, 0.556952, -0.006273},{
      1.673903, 0.559676, -0.006273},{1.673237, 0.558759, -0.008122}}],
    Polygon[{{1.676627, 0.556952, -0.006273},{1.677298, 0.557440, -0.004270},{
      1.674391, 0.560347, -0.004270},{1.673903, 0.559676, -0.006273}}],
    Polygon[{{1.677298, 0.557440, -0.004270},{1.677707, 0.557737, -0.002162},{
      1.674688, 0.560757, -0.002162},{1.674391, 0.560347, -0.004270}}],
    Polygon[{{1.677707, 0.557737, -0.002162},{1.677845, 0.557837, 0.000000},{
      1.674788, 0.560894, 0.000000},{1.674688, 0.560757, -0.002162}}],
    Polygon[{{1.677845, 0.557837, 0.000000},{1.677707, 0.557737, 0.002162},{
      1.674688, 0.560757, 0.002162},{1.674788, 0.560894, 0.000000}}],
    Polygon[{{1.677707, 0.557737, 0.002162},{1.677298, 0.557440, 0.004270},{
      1.674391, 0.560347, 0.004270},{1.674688, 0.560757, 0.002162}}],
    Polygon[{{1.677298, 0.557440, 0.004270},{1.676627, 0.556952, 0.006273},{
      1.673903, 0.559676, 0.006273},{1.674391, 0.560347, 0.004270}}],
    Polygon[{{1.676627, 0.556952, 0.006273},{1.675710, 0.556286, 0.008122},{
      1.673237, 0.558759, 0.008122},{1.673903, 0.559676, 0.006273}}],
    Polygon[{{1.675710, 0.556286, 0.008122},{1.674571, 0.555459, 0.009770},{
      1.672410, 0.557620, 0.009770},{1.673237, 0.558759, 0.008122}}],
    Polygon[{{1.674571, 0.555459, 0.009770},{1.673237, 0.554489, 0.011178},{
      1.671440, 0.556286, 0.011178},{1.672410, 0.557620, 0.009770}}],
    Polygon[{{1.673237, 0.554489, 0.011178},{1.671742, 0.553403, 0.012311},{
      1.670354, 0.554791, 0.012311},{1.671440, 0.556286, 0.011178}}],
    Polygon[{{1.671742, 0.553403, 0.012311},{1.670121, 0.552225, 0.013141},{
      1.669176, 0.553170, 0.013141},{1.670354, 0.554791, 0.012311}}],
    Polygon[{{1.670121, 0.552225, 0.013141},{1.668415, 0.550986, 0.013647},{
      1.667937, 0.551464, 0.013647},{1.669176, 0.553170, 0.013141}}],
    Polygon[{{1.667937, 0.551464, -0.013647},{1.669176, 0.553170, -0.013141},{
      1.667986, 0.553777, -0.013141},{1.667335, 0.551771, -0.013647}}],
    Polygon[{{1.669176, 0.553170, -0.013141},{1.670354, 0.554791, -0.012311},{
      1.668605, 0.555682, -0.012311},{1.667986, 0.553777, -0.013141}}],
    Polygon[{{1.670354, 0.554791, -0.012311},{1.671440, 0.556286, -0.011178},{
      1.669176, 0.557440, -0.011178},{1.668605, 0.555682, -0.012311}}],
    Polygon[{{1.671440, 0.556286, -0.011178},{1.672410, 0.557620, -0.009770},{
      1.669686, 0.559008, -0.009770},{1.669176, 0.557440, -0.011178}}],
    Polygon[{{1.672410, 0.557620, -0.009770},{1.673237, 0.558759, -0.008122},{
      1.670121, 0.560347, -0.008122},{1.669686, 0.559008, -0.009770}}],
    Polygon[{{1.673237, 0.558759, -0.008122},{1.673903, 0.559676, -0.006273},{
      1.670471, 0.561424, -0.006273},{1.670121, 0.560347, -0.008122}}],
    Polygon[{{1.673903, 0.559676, -0.006273},{1.674391, 0.560347, -0.004270},{
      1.670727, 0.562214, -0.004270},{1.670471, 0.561424, -0.006273}}],
    Polygon[{{1.674391, 0.560347, -0.004270},{1.674688, 0.560757, -0.002162},{
      1.670884, 0.562695, -0.002162},{1.670727, 0.562214, -0.004270}}],
    Polygon[{{1.674688, 0.560757, -0.002162},{1.674788, 0.560894, 0.000000},{
      1.670936, 0.562857, 0.000000},{1.670884, 0.562695, -0.002162}}],
    Polygon[{{1.674788, 0.560894, 0.000000},{1.674688, 0.560757, 0.002162},{
      1.670884, 0.562695, 0.002162},{1.670936, 0.562857, 0.000000}}],
    Polygon[{{1.674688, 0.560757, 0.002162},{1.674391, 0.560347, 0.004270},{
      1.670727, 0.562214, 0.004270},{1.670884, 0.562695, 0.002162}}],
    Polygon[{{1.674391, 0.560347, 0.004270},{1.673903, 0.559676, 0.006273},{
      1.670471, 0.561424, 0.006273},{1.670727, 0.562214, 0.004270}}],
    Polygon[{{1.673903, 0.559676, 0.006273},{1.673237, 0.558759, 0.008122},{
      1.670121, 0.560347, 0.008122},{1.670471, 0.561424, 0.006273}}],
    Polygon[{{1.673237, 0.558759, 0.008122},{1.672410, 0.557620, 0.009770},{
      1.669686, 0.559008, 0.009770},{1.670121, 0.560347, 0.008122}}],
    Polygon[{{1.672410, 0.557620, 0.009770},{1.671440, 0.556286, 0.011178},{
      1.669176, 0.557440, 0.011178},{1.669686, 0.559008, 0.009770}}],
    Polygon[{{1.671440, 0.556286, 0.011178},{1.670354, 0.554791, 0.012311},{
      1.668605, 0.555682, 0.012311},{1.669176, 0.557440, 0.011178}}],
    Polygon[{{1.670354, 0.554791, 0.012311},{1.669176, 0.553170, 0.013141},{
      1.667986, 0.553777, 0.013141},{1.668605, 0.555682, 0.012311}}],
    Polygon[{{1.669176, 0.553170, 0.013141},{1.667937, 0.551464, 0.013647},{
      1.667335, 0.551771, 0.013647},{1.667986, 0.553777, 0.013141}}],
    Polygon[{{1.667335, 0.551771, -0.013647},{1.667986, 0.553777, -0.013141},{
      1.666667, 0.553985, -0.013141},{1.666667, 0.551877, -0.013647}}],
    Polygon[{{1.667986, 0.553777, -0.013141},{1.668605, 0.555682, -0.012311},{
      1.666667, 0.555989, -0.012311},{1.666667, 0.553985, -0.013141}}],
    Polygon[{{1.668605, 0.555682, -0.012311},{1.669176, 0.557440, -0.011178},{
      1.666667, 0.557837, -0.011178},{1.666667, 0.555989, -0.012311}}],
    Polygon[{{1.669176, 0.557440, -0.011178},{1.669686, 0.559008, -0.009770},{
      1.666667, 0.559486, -0.009770},{1.666667, 0.557837, -0.011178}}],
    Polygon[{{1.669686, 0.559008, -0.009770},{1.670121, 0.560347, -0.008122},{
      1.666667, 0.560894, -0.008122},{1.666667, 0.559486, -0.009770}}],
    Polygon[{{1.670121, 0.560347, -0.008122},{1.670471, 0.561424, -0.006273},{
      1.666667, 0.562027, -0.006273},{1.666667, 0.560894, -0.008122}}],
    Polygon[{{1.670471, 0.561424, -0.006273},{1.670727, 0.562214, -0.004270},{
      1.666667, 0.562857, -0.004270},{1.666667, 0.562027, -0.006273}}],
    Polygon[{{1.670727, 0.562214, -0.004270},{1.670884, 0.562695, -0.002162},{
      1.666667, 0.563363, -0.002162},{1.666667, 0.562857, -0.004270}}],
    Polygon[{{1.670884, 0.562695, -0.002162},{1.670936, 0.562857, 0.000000},{
      1.666667, 0.563533, 0.000000},{1.666667, 0.563363, -0.002162}}],
    Polygon[{{1.670936, 0.562857, 0.000000},{1.670884, 0.562695, 0.002162},{
      1.666667, 0.563363, 0.002162},{1.666667, 0.563533, 0.000000}}],
    Polygon[{{1.670884, 0.562695, 0.002162},{1.670727, 0.562214, 0.004270},{
      1.666667, 0.562857, 0.004270},{1.666667, 0.563363, 0.002162}}],
    Polygon[{{1.670727, 0.562214, 0.004270},{1.670471, 0.561424, 0.006273},{
      1.666667, 0.562027, 0.006273},{1.666667, 0.562857, 0.004270}}],
    Polygon[{{1.670471, 0.561424, 0.006273},{1.670121, 0.560347, 0.008122},{
      1.666667, 0.560894, 0.008122},{1.666667, 0.562027, 0.006273}}],
    Polygon[{{1.670121, 0.560347, 0.008122},{1.669686, 0.559008, 0.009770},{
      1.666667, 0.559486, 0.009770},{1.666667, 0.560894, 0.008122}}],
    Polygon[{{1.669686, 0.559008, 0.009770},{1.669176, 0.557440, 0.011178},{
      1.666667, 0.557837, 0.011178},{1.666667, 0.559486, 0.009770}}],
    Polygon[{{1.669176, 0.557440, 0.011178},{1.668605, 0.555682, 0.012311},{
      1.666667, 0.555989, 0.012311},{1.666667, 0.557837, 0.011178}}],
    Polygon[{{1.668605, 0.555682, 0.012311},{1.667986, 0.553777, 0.013141},{
      1.666667, 0.553985, 0.013141},{1.666667, 0.555989, 0.012311}}],
    Polygon[{{1.667986, 0.553777, 0.013141},{1.667335, 0.551771, 0.013647},{
      1.666667, 0.551877, 0.013647},{1.666667, 0.553985, 0.013141}}],
    Polygon[{{1.666667, 0.551877, -0.013647},{1.666667, 0.553985, -0.013141},{
      1.665347, 0.553777, -0.013141},{1.665999, 0.551771, -0.013647}}],
    Polygon[{{1.666667, 0.553985, -0.013141},{1.666667, 0.555989, -0.012311},{
      1.664728, 0.555682, -0.012311},{1.665347, 0.553777, -0.013141}}],
    Polygon[{{1.666667, 0.555989, -0.012311},{1.666667, 0.557837, -0.011178},{
      1.664157, 0.557440, -0.011178},{1.664728, 0.555682, -0.012311}}],
    Polygon[{{1.666667, 0.557837, -0.011178},{1.666667, 0.559486, -0.009770},{
      1.663648, 0.559008, -0.009770},{1.664157, 0.557440, -0.011178}}],
    Polygon[{{1.666667, 0.559486, -0.009770},{1.666667, 0.560894, -0.008122},{
      1.663212, 0.560347, -0.008122},{1.663648, 0.559008, -0.009770}}],
    Polygon[{{1.666667, 0.560894, -0.008122},{1.666667, 0.562027, -0.006273},{
      1.662862, 0.561424, -0.006273},{1.663212, 0.560347, -0.008122}}],
    Polygon[{{1.666667, 0.562027, -0.006273},{1.666667, 0.562857, -0.004270},{
      1.662606, 0.562214, -0.004270},{1.662862, 0.561424, -0.006273}}],
    Polygon[{{1.666667, 0.562857, -0.004270},{1.666667, 0.563363, -0.002162},{
      1.662449, 0.562695, -0.002162},{1.662606, 0.562214, -0.004270}}],
    Polygon[{{1.666667, 0.563363, -0.002162},{1.666667, 0.563533, 0.000000},{
      1.662397, 0.562857, 0.000000},{1.662449, 0.562695, -0.002162}}],
    Polygon[{{1.666667, 0.563533, 0.000000},{1.666667, 0.563363, 0.002162},{
      1.662449, 0.562695, 0.002162},{1.662397, 0.562857, 0.000000}}],
    Polygon[{{1.666667, 0.563363, 0.002162},{1.666667, 0.562857, 0.004270},{
      1.662606, 0.562214, 0.004270},{1.662449, 0.562695, 0.002162}}],
    Polygon[{{1.666667, 0.562857, 0.004270},{1.666667, 0.562027, 0.006273},{
      1.662862, 0.561424, 0.006273},{1.662606, 0.562214, 0.004270}}],
    Polygon[{{1.666667, 0.562027, 0.006273},{1.666667, 0.560894, 0.008122},{
      1.663212, 0.560347, 0.008122},{1.662862, 0.561424, 0.006273}}],
    Polygon[{{1.666667, 0.560894, 0.008122},{1.666667, 0.559486, 0.009770},{
      1.663648, 0.559008, 0.009770},{1.663212, 0.560347, 0.008122}}],
    Polygon[{{1.666667, 0.559486, 0.009770},{1.666667, 0.557837, 0.011178},{
      1.664157, 0.557440, 0.011178},{1.663648, 0.559008, 0.009770}}],
    Polygon[{{1.666667, 0.557837, 0.011178},{1.666667, 0.555989, 0.012311},{
      1.664728, 0.555682, 0.012311},{1.664157, 0.557440, 0.011178}}],
    Polygon[{{1.666667, 0.555989, 0.012311},{1.666667, 0.553985, 0.013141},{
      1.665347, 0.553777, 0.013141},{1.664728, 0.555682, 0.012311}}],
    Polygon[{{1.666667, 0.553985, 0.013141},{1.666667, 0.551877, 0.013647},{
      1.665999, 0.551771, 0.013647},{1.665347, 0.553777, 0.013141}}],
    Polygon[{{1.665999, 0.551771, -0.013647},{1.665347, 0.553777, -0.013141},{
      1.664157, 0.553170, -0.013141},{1.665396, 0.551464, -0.013647}}],
    Polygon[{{1.665347, 0.553777, -0.013141},{1.664728, 0.555682, -0.012311},{
      1.662979, 0.554791, -0.012311},{1.664157, 0.553170, -0.013141}}],
    Polygon[{{1.664728, 0.555682, -0.012311},{1.664157, 0.557440, -0.011178},{
      1.661893, 0.556286, -0.011178},{1.662979, 0.554791, -0.012311}}],
    Polygon[{{1.664157, 0.557440, -0.011178},{1.663648, 0.559008, -0.009770},{
      1.660924, 0.557620, -0.009770},{1.661893, 0.556286, -0.011178}}],
    Polygon[{{1.663648, 0.559008, -0.009770},{1.663212, 0.560347, -0.008122},{
      1.660096, 0.558759, -0.008122},{1.660924, 0.557620, -0.009770}}],
    Polygon[{{1.663212, 0.560347, -0.008122},{1.662862, 0.561424, -0.006273},{
      1.659430, 0.559676, -0.006273},{1.660096, 0.558759, -0.008122}}],
    Polygon[{{1.662862, 0.561424, -0.006273},{1.662606, 0.562214, -0.004270},{
      1.658943, 0.560347, -0.004270},{1.659430, 0.559676, -0.006273}}],
    Polygon[{{1.662606, 0.562214, -0.004270},{1.662449, 0.562695, -0.002162},{
      1.658645, 0.560757, -0.002162},{1.658943, 0.560347, -0.004270}}],
    Polygon[{{1.662449, 0.562695, -0.002162},{1.662397, 0.562857, 0.000000},{
      1.658545, 0.560894, 0.000000},{1.658645, 0.560757, -0.002162}}],
    Polygon[{{1.662397, 0.562857, 0.000000},{1.662449, 0.562695, 0.002162},{
      1.658645, 0.560757, 0.002162},{1.658545, 0.560894, 0.000000}}],
    Polygon[{{1.662449, 0.562695, 0.002162},{1.662606, 0.562214, 0.004270},{
      1.658943, 0.560347, 0.004270},{1.658645, 0.560757, 0.002162}}],
    Polygon[{{1.662606, 0.562214, 0.004270},{1.662862, 0.561424, 0.006273},{
      1.659430, 0.559676, 0.006273},{1.658943, 0.560347, 0.004270}}],
    Polygon[{{1.662862, 0.561424, 0.006273},{1.663212, 0.560347, 0.008122},{
      1.660096, 0.558759, 0.008122},{1.659430, 0.559676, 0.006273}}],
    Polygon[{{1.663212, 0.560347, 0.008122},{1.663648, 0.559008, 0.009770},{
      1.660924, 0.557620, 0.009770},{1.660096, 0.558759, 0.008122}}],
    Polygon[{{1.663648, 0.559008, 0.009770},{1.664157, 0.557440, 0.011178},{
      1.661893, 0.556286, 0.011178},{1.660924, 0.557620, 0.009770}}],
    Polygon[{{1.664157, 0.557440, 0.011178},{1.664728, 0.555682, 0.012311},{
      1.662979, 0.554791, 0.012311},{1.661893, 0.556286, 0.011178}}],
    Polygon[{{1.664728, 0.555682, 0.012311},{1.665347, 0.553777, 0.013141},{
      1.664157, 0.553170, 0.013141},{1.662979, 0.554791, 0.012311}}],
    Polygon[{{1.665347, 0.553777, 0.013141},{1.665999, 0.551771, 0.013647},{
      1.665396, 0.551464, 0.013647},{1.664157, 0.553170, 0.013141}}],
    Polygon[{{1.665396, 0.551464, -0.013647},{1.664157, 0.553170, -0.013141},{
      1.663212, 0.552225, -0.013141},{1.664918, 0.550986, -0.013647}}],
    Polygon[{{1.664157, 0.553170, -0.013141},{1.662979, 0.554791, -0.012311},{
      1.661592, 0.553403, -0.012311},{1.663212, 0.552225, -0.013141}}],
    Polygon[{{1.662979, 0.554791, -0.012311},{1.661893, 0.556286, -0.011178},{
      1.660096, 0.554489, -0.011178},{1.661592, 0.553403, -0.012311}}],
    Polygon[{{1.661893, 0.556286, -0.011178},{1.660924, 0.557620, -0.009770},{
      1.658762, 0.555459, -0.009770},{1.660096, 0.554489, -0.011178}}],
    Polygon[{{1.660924, 0.557620, -0.009770},{1.660096, 0.558759, -0.008122},{
      1.657623, 0.556286, -0.008122},{1.658762, 0.555459, -0.009770}}],
    Polygon[{{1.660096, 0.558759, -0.008122},{1.659430, 0.559676, -0.006273},{
      1.656707, 0.556952, -0.006273},{1.657623, 0.556286, -0.008122}}],
    Polygon[{{1.659430, 0.559676, -0.006273},{1.658943, 0.560347, -0.004270},{
      1.656035, 0.557440, -0.004270},{1.656707, 0.556952, -0.006273}}],
    Polygon[{{1.658943, 0.560347, -0.004270},{1.658645, 0.560757, -0.002162},{
      1.655626, 0.557737, -0.002162},{1.656035, 0.557440, -0.004270}}],
    Polygon[{{1.658645, 0.560757, -0.002162},{1.658545, 0.560894, 0.000000},{
      1.655488, 0.557837, 0.000000},{1.655626, 0.557737, -0.002162}}],
    Polygon[{{1.658545, 0.560894, 0.000000},{1.658645, 0.560757, 0.002162},{
      1.655626, 0.557737, 0.002162},{1.655488, 0.557837, 0.000000}}],
    Polygon[{{1.658645, 0.560757, 0.002162},{1.658943, 0.560347, 0.004270},{
      1.656035, 0.557440, 0.004270},{1.655626, 0.557737, 0.002162}}],
    Polygon[{{1.658943, 0.560347, 0.004270},{1.659430, 0.559676, 0.006273},{
      1.656707, 0.556952, 0.006273},{1.656035, 0.557440, 0.004270}}],
    Polygon[{{1.659430, 0.559676, 0.006273},{1.660096, 0.558759, 0.008122},{
      1.657623, 0.556286, 0.008122},{1.656707, 0.556952, 0.006273}}],
    Polygon[{{1.660096, 0.558759, 0.008122},{1.660924, 0.557620, 0.009770},{
      1.658762, 0.555459, 0.009770},{1.657623, 0.556286, 0.008122}}],
    Polygon[{{1.660924, 0.557620, 0.009770},{1.661893, 0.556286, 0.011178},{
      1.660096, 0.554489, 0.011178},{1.658762, 0.555459, 0.009770}}],
    Polygon[{{1.661893, 0.556286, 0.011178},{1.662979, 0.554791, 0.012311},{
      1.661592, 0.553403, 0.012311},{1.660096, 0.554489, 0.011178}}],
    Polygon[{{1.662979, 0.554791, 0.012311},{1.664157, 0.553170, 0.013141},{
      1.663212, 0.552225, 0.013141},{1.661592, 0.553403, 0.012311}}],
    Polygon[{{1.664157, 0.553170, 0.013141},{1.665396, 0.551464, 0.013647},{
      1.664918, 0.550986, 0.013647},{1.663212, 0.552225, 0.013141}}],
    Polygon[{{1.664918, 0.550986, -0.013647},{1.663212, 0.552225, -0.013141},{
      1.662606, 0.551035, -0.013141},{1.664611, 0.550384, -0.013647}}],
    Polygon[{{1.663212, 0.552225, -0.013141},{1.661592, 0.553403, -0.012311},{
      1.660701, 0.551654, -0.012311},{1.662606, 0.551035, -0.013141}}],
    Polygon[{{1.661592, 0.553403, -0.012311},{1.660096, 0.554489, -0.011178},{
      1.658943, 0.552225, -0.011178},{1.660701, 0.551654, -0.012311}}],
    Polygon[{{1.660096, 0.554489, -0.011178},{1.658762, 0.555459, -0.009770},{
      1.657375, 0.552735, -0.009770},{1.658943, 0.552225, -0.011178}}],
    Polygon[{{1.658762, 0.555459, -0.009770},{1.657623, 0.556286, -0.008122},{
      1.656035, 0.553170, -0.008122},{1.657375, 0.552735, -0.009770}}],
    Polygon[{{1.657623, 0.556286, -0.008122},{1.656707, 0.556952, -0.006273},{
      1.654958, 0.553520, -0.006273},{1.656035, 0.553170, -0.008122}}],
    Polygon[{{1.656707, 0.556952, -0.006273},{1.656035, 0.557440, -0.004270},{
      1.654169, 0.553777, -0.004270},{1.654958, 0.553520, -0.006273}}],
    Polygon[{{1.656035, 0.557440, -0.004270},{1.655626, 0.557737, -0.002162},{
      1.653687, 0.553933, -0.002162},{1.654169, 0.553777, -0.004270}}],
    Polygon[{{1.655626, 0.557737, -0.002162},{1.655488, 0.557837, 0.000000},{
      1.653526, 0.553985, 0.000000},{1.653687, 0.553933, -0.002162}}],
    Polygon[{{1.655488, 0.557837, 0.000000},{1.655626, 0.557737, 0.002162},{
      1.653687, 0.553933, 0.002162},{1.653526, 0.553985, 0.000000}}],
    Polygon[{{1.655626, 0.557737, 0.002162},{1.656035, 0.557440, 0.004270},{
      1.654169, 0.553777, 0.004270},{1.653687, 0.553933, 0.002162}}],
    Polygon[{{1.656035, 0.557440, 0.004270},{1.656707, 0.556952, 0.006273},{
      1.654958, 0.553520, 0.006273},{1.654169, 0.553777, 0.004270}}],
    Polygon[{{1.656707, 0.556952, 0.006273},{1.657623, 0.556286, 0.008122},{
      1.656035, 0.553170, 0.008122},{1.654958, 0.553520, 0.006273}}],
    Polygon[{{1.657623, 0.556286, 0.008122},{1.658762, 0.555459, 0.009770},{
      1.657375, 0.552735, 0.009770},{1.656035, 0.553170, 0.008122}}],
    Polygon[{{1.658762, 0.555459, 0.009770},{1.660096, 0.554489, 0.011178},{
      1.658943, 0.552225, 0.011178},{1.657375, 0.552735, 0.009770}}],
    Polygon[{{1.660096, 0.554489, 0.011178},{1.661592, 0.553403, 0.012311},{
      1.660701, 0.551654, 0.012311},{1.658943, 0.552225, 0.011178}}],
    Polygon[{{1.661592, 0.553403, 0.012311},{1.663212, 0.552225, 0.013141},{
      1.662606, 0.551035, 0.013141},{1.660701, 0.551654, 0.012311}}],
    Polygon[{{1.663212, 0.552225, 0.013141},{1.664918, 0.550986, 0.013647},{
      1.664611, 0.550384, 0.013647},{1.662606, 0.551035, 0.013141}}],
    Polygon[{{1.664611, 0.550384, -0.013647},{1.662606, 0.551035, -0.013141},{
      1.662397, 0.549716, -0.013141},{1.664505, 0.549716, -0.013647}}],
    Polygon[{{1.662606, 0.551035, -0.013141},{1.660701, 0.551654, -0.012311},{
      1.660394, 0.549716, -0.012311},{1.662397, 0.549716, -0.013141}}],
    Polygon[{{1.660701, 0.551654, -0.012311},{1.658943, 0.552225, -0.011178},{
      1.658545, 0.549716, -0.011178},{1.660394, 0.549716, -0.012311}}],
    Polygon[{{1.658943, 0.552225, -0.011178},{1.657375, 0.552735, -0.009770},{
      1.656896, 0.549716, -0.009770},{1.658545, 0.549716, -0.011178}}],
    Polygon[{{1.657375, 0.552735, -0.009770},{1.656035, 0.553170, -0.008122},{
      1.655488, 0.549716, -0.008122},{1.656896, 0.549716, -0.009770}}],
    Polygon[{{1.656035, 0.553170, -0.008122},{1.654958, 0.553520, -0.006273},{
      1.654355, 0.549716, -0.006273},{1.655488, 0.549716, -0.008122}}],
    Polygon[{{1.654958, 0.553520, -0.006273},{1.654169, 0.553777, -0.004270},{
      1.653526, 0.549716, -0.004270},{1.654355, 0.549716, -0.006273}}],
    Polygon[{{1.654169, 0.553777, -0.004270},{1.653687, 0.553933, -0.002162},{
      1.653019, 0.549716, -0.002162},{1.653526, 0.549716, -0.004270}}],
    Polygon[{{1.653687, 0.553933, -0.002162},{1.653526, 0.553985, 0.000000},{
      1.652849, 0.549716, 0.000000},{1.653019, 0.549716, -0.002162}}],
    Polygon[{{1.653526, 0.553985, 0.000000},{1.653687, 0.553933, 0.002162},{
      1.653019, 0.549716, 0.002162},{1.652849, 0.549716, 0.000000}}],
    Polygon[{{1.653687, 0.553933, 0.002162},{1.654169, 0.553777, 0.004270},{
      1.653526, 0.549716, 0.004270},{1.653019, 0.549716, 0.002162}}],
    Polygon[{{1.654169, 0.553777, 0.004270},{1.654958, 0.553520, 0.006273},{
      1.654355, 0.549716, 0.006273},{1.653526, 0.549716, 0.004270}}],
    Polygon[{{1.654958, 0.553520, 0.006273},{1.656035, 0.553170, 0.008122},{
      1.655488, 0.549716, 0.008122},{1.654355, 0.549716, 0.006273}}],
    Polygon[{{1.656035, 0.553170, 0.008122},{1.657375, 0.552735, 0.009770},{
      1.656896, 0.549716, 0.009770},{1.655488, 0.549716, 0.008122}}],
    Polygon[{{1.657375, 0.552735, 0.009770},{1.658943, 0.552225, 0.011178},{
      1.658545, 0.549716, 0.011178},{1.656896, 0.549716, 0.009770}}],
    Polygon[{{1.658943, 0.552225, 0.011178},{1.660701, 0.551654, 0.012311},{
      1.660394, 0.549716, 0.012311},{1.658545, 0.549716, 0.011178}}],
    Polygon[{{1.660701, 0.551654, 0.012311},{1.662606, 0.551035, 0.013141},{
      1.662397, 0.549716, 0.013141},{1.660394, 0.549716, 0.012311}}],
    Polygon[{{1.662606, 0.551035, 0.013141},{1.664611, 0.550384, 0.013647},{
      1.664505, 0.549716, 0.013647},{1.662397, 0.549716, 0.013141}}],
    Polygon[{{1.664505, 0.549716, -0.013647},{1.662397, 0.549716, -0.013141},{
      1.662606, 0.548396, -0.013141},{1.664611, 0.549048, -0.013647}}],
    Polygon[{{1.662397, 0.549716, -0.013141},{1.660394, 0.549716, -0.012311},{
      1.660701, 0.547777, -0.012311},{1.662606, 0.548396, -0.013141}}],
    Polygon[{{1.660394, 0.549716, -0.012311},{1.658545, 0.549716, -0.011178},{
      1.658943, 0.547206, -0.011178},{1.660701, 0.547777, -0.012311}}],
    Polygon[{{1.658545, 0.549716, -0.011178},{1.656896, 0.549716, -0.009770},{
      1.657375, 0.546696, -0.009770},{1.658943, 0.547206, -0.011178}}],
    Polygon[{{1.656896, 0.549716, -0.009770},{1.655488, 0.549716, -0.008122},{
      1.656035, 0.546261, -0.008122},{1.657375, 0.546696, -0.009770}}],
    Polygon[{{1.655488, 0.549716, -0.008122},{1.654355, 0.549716, -0.006273},{
      1.654958, 0.545911, -0.006273},{1.656035, 0.546261, -0.008122}}],
    Polygon[{{1.654355, 0.549716, -0.006273},{1.653526, 0.549716, -0.004270},{
      1.654169, 0.545655, -0.004270},{1.654958, 0.545911, -0.006273}}],
    Polygon[{{1.653526, 0.549716, -0.004270},{1.653019, 0.549716, -0.002162},{
      1.653687, 0.545498, -0.002162},{1.654169, 0.545655, -0.004270}}],
    Polygon[{{1.653019, 0.549716, -0.002162},{1.652849, 0.549716, 0.000000},{
      1.653526, 0.545446, 0.000000},{1.653687, 0.545498, -0.002162}}],
    Polygon[{{1.652849, 0.549716, 0.000000},{1.653019, 0.549716, 0.002162},{
      1.653687, 0.545498, 0.002162},{1.653526, 0.545446, 0.000000}}],
    Polygon[{{1.653019, 0.549716, 0.002162},{1.653526, 0.549716, 0.004270},{
      1.654169, 0.545655, 0.004270},{1.653687, 0.545498, 0.002162}}],
    Polygon[{{1.653526, 0.549716, 0.004270},{1.654355, 0.549716, 0.006273},{
      1.654958, 0.545911, 0.006273},{1.654169, 0.545655, 0.004270}}],
    Polygon[{{1.654355, 0.549716, 0.006273},{1.655488, 0.549716, 0.008122},{
      1.656035, 0.546261, 0.008122},{1.654958, 0.545911, 0.006273}}],
    Polygon[{{1.655488, 0.549716, 0.008122},{1.656896, 0.549716, 0.009770},{
      1.657375, 0.546696, 0.009770},{1.656035, 0.546261, 0.008122}}],
    Polygon[{{1.656896, 0.549716, 0.009770},{1.658545, 0.549716, 0.011178},{
      1.658943, 0.547206, 0.011178},{1.657375, 0.546696, 0.009770}}],
    Polygon[{{1.658545, 0.549716, 0.011178},{1.660394, 0.549716, 0.012311},{
      1.660701, 0.547777, 0.012311},{1.658943, 0.547206, 0.011178}}],
    Polygon[{{1.660394, 0.549716, 0.012311},{1.662397, 0.549716, 0.013141},{
      1.662606, 0.548396, 0.013141},{1.660701, 0.547777, 0.012311}}],
    Polygon[{{1.662397, 0.549716, 0.013141},{1.664505, 0.549716, 0.013647},{
      1.664611, 0.549048, 0.013647},{1.662606, 0.548396, 0.013141}}],
    Polygon[{{1.664611, 0.549048, -0.013647},{1.662606, 0.548396, -0.013141},{
      1.663212, 0.547206, -0.013141},{1.664918, 0.548445, -0.013647}}],
    Polygon[{{1.662606, 0.548396, -0.013141},{1.660701, 0.547777, -0.012311},{
      1.661592, 0.546029, -0.012311},{1.663212, 0.547206, -0.013141}}],
    Polygon[{{1.660701, 0.547777, -0.012311},{1.658943, 0.547206, -0.011178},{
      1.660096, 0.544942, -0.011178},{1.661592, 0.546029, -0.012311}}],
    Polygon[{{1.658943, 0.547206, -0.011178},{1.657375, 0.546696, -0.009770},{
      1.658762, 0.543973, -0.009770},{1.660096, 0.544942, -0.011178}}],
    Polygon[{{1.657375, 0.546696, -0.009770},{1.656035, 0.546261, -0.008122},{
      1.657623, 0.543145, -0.008122},{1.658762, 0.543973, -0.009770}}],
    Polygon[{{1.656035, 0.546261, -0.008122},{1.654958, 0.545911, -0.006273},{
      1.656707, 0.542479, -0.006273},{1.657623, 0.543145, -0.008122}}],
    Polygon[{{1.654958, 0.545911, -0.006273},{1.654169, 0.545655, -0.004270},{
      1.656035, 0.541992, -0.004270},{1.656707, 0.542479, -0.006273}}],
    Polygon[{{1.654169, 0.545655, -0.004270},{1.653687, 0.545498, -0.002162},{
      1.655626, 0.541694, -0.002162},{1.656035, 0.541992, -0.004270}}],
    Polygon[{{1.653687, 0.545498, -0.002162},{1.653526, 0.545446, 0.000000},{
      1.655488, 0.541594, 0.000000},{1.655626, 0.541694, -0.002162}}],
    Polygon[{{1.653526, 0.545446, 0.000000},{1.653687, 0.545498, 0.002162},{
      1.655626, 0.541694, 0.002162},{1.655488, 0.541594, 0.000000}}],
    Polygon[{{1.653687, 0.545498, 0.002162},{1.654169, 0.545655, 0.004270},{
      1.656035, 0.541992, 0.004270},{1.655626, 0.541694, 0.002162}}],
    Polygon[{{1.654169, 0.545655, 0.004270},{1.654958, 0.545911, 0.006273},{
      1.656707, 0.542479, 0.006273},{1.656035, 0.541992, 0.004270}}],
    Polygon[{{1.654958, 0.545911, 0.006273},{1.656035, 0.546261, 0.008122},{
      1.657623, 0.543145, 0.008122},{1.656707, 0.542479, 0.006273}}],
    Polygon[{{1.656035, 0.546261, 0.008122},{1.657375, 0.546696, 0.009770},{
      1.658762, 0.543973, 0.009770},{1.657623, 0.543145, 0.008122}}],
    Polygon[{{1.657375, 0.546696, 0.009770},{1.658943, 0.547206, 0.011178},{
      1.660096, 0.544942, 0.011178},{1.658762, 0.543973, 0.009770}}],
    Polygon[{{1.658943, 0.547206, 0.011178},{1.660701, 0.547777, 0.012311},{
      1.661592, 0.546029, 0.012311},{1.660096, 0.544942, 0.011178}}],
    Polygon[{{1.660701, 0.547777, 0.012311},{1.662606, 0.548396, 0.013141},{
      1.663212, 0.547206, 0.013141},{1.661592, 0.546029, 0.012311}}],
    Polygon[{{1.662606, 0.548396, 0.013141},{1.664611, 0.549048, 0.013647},{
      1.664918, 0.548445, 0.013647},{1.663212, 0.547206, 0.013141}}],
    Polygon[{{1.664918, 0.548445, -0.013647},{1.663212, 0.547206, -0.013141},{
      1.664157, 0.546261, -0.013141},{1.665396, 0.547967, -0.013647}}],
    Polygon[{{1.663212, 0.547206, -0.013141},{1.661592, 0.546029, -0.012311},{
      1.662979, 0.544641, -0.012311},{1.664157, 0.546261, -0.013141}}],
    Polygon[{{1.661592, 0.546029, -0.012311},{1.660096, 0.544942, -0.011178},{
      1.661893, 0.543145, -0.011178},{1.662979, 0.544641, -0.012311}}],
    Polygon[{{1.660096, 0.544942, -0.011178},{1.658762, 0.543973, -0.009770},{
      1.660924, 0.541811, -0.009770},{1.661893, 0.543145, -0.011178}}],
    Polygon[{{1.658762, 0.543973, -0.009770},{1.657623, 0.543145, -0.008122},{
      1.660096, 0.540672, -0.008122},{1.660924, 0.541811, -0.009770}}],
    Polygon[{{1.657623, 0.543145, -0.008122},{1.656707, 0.542479, -0.006273},{
      1.659430, 0.539756, -0.006273},{1.660096, 0.540672, -0.008122}}],
    Polygon[{{1.656707, 0.542479, -0.006273},{1.656035, 0.541992, -0.004270},{
      1.658943, 0.539084, -0.004270},{1.659430, 0.539756, -0.006273}}],
    Polygon[{{1.656035, 0.541992, -0.004270},{1.655626, 0.541694, -0.002162},{
      1.658645, 0.538675, -0.002162},{1.658943, 0.539084, -0.004270}}],
    Polygon[{{1.655626, 0.541694, -0.002162},{1.655488, 0.541594, 0.000000},{
      1.658545, 0.538537, 0.000000},{1.658645, 0.538675, -0.002162}}],
    Polygon[{{1.655488, 0.541594, 0.000000},{1.655626, 0.541694, 0.002162},{
      1.658645, 0.538675, 0.002162},{1.658545, 0.538537, 0.000000}}],
    Polygon[{{1.655626, 0.541694, 0.002162},{1.656035, 0.541992, 0.004270},{
      1.658943, 0.539084, 0.004270},{1.658645, 0.538675, 0.002162}}],
    Polygon[{{1.656035, 0.541992, 0.004270},{1.656707, 0.542479, 0.006273},{
      1.659430, 0.539756, 0.006273},{1.658943, 0.539084, 0.004270}}],
    Polygon[{{1.656707, 0.542479, 0.006273},{1.657623, 0.543145, 0.008122},{
      1.660096, 0.540672, 0.008122},{1.659430, 0.539756, 0.006273}}],
    Polygon[{{1.657623, 0.543145, 0.008122},{1.658762, 0.543973, 0.009770},{
      1.660924, 0.541811, 0.009770},{1.660096, 0.540672, 0.008122}}],
    Polygon[{{1.658762, 0.543973, 0.009770},{1.660096, 0.544942, 0.011178},{
      1.661893, 0.543145, 0.011178},{1.660924, 0.541811, 0.009770}}],
    Polygon[{{1.660096, 0.544942, 0.011178},{1.661592, 0.546029, 0.012311},{
      1.662979, 0.544641, 0.012311},{1.661893, 0.543145, 0.011178}}],
    Polygon[{{1.661592, 0.546029, 0.012311},{1.663212, 0.547206, 0.013141},{
      1.664157, 0.546261, 0.013141},{1.662979, 0.544641, 0.012311}}],
    Polygon[{{1.663212, 0.547206, 0.013141},{1.664918, 0.548445, 0.013647},{
      1.665396, 0.547967, 0.013647},{1.664157, 0.546261, 0.013141}}],
    Polygon[{{1.665396, 0.547967, -0.013647},{1.664157, 0.546261, -0.013141},{
      1.665347, 0.545655, -0.013141},{1.665999, 0.547660, -0.013647}}],
    Polygon[{{1.664157, 0.546261, -0.013141},{1.662979, 0.544641, -0.012311},{
      1.664728, 0.543750, -0.012311},{1.665347, 0.545655, -0.013141}}],
    Polygon[{{1.662979, 0.544641, -0.012311},{1.661893, 0.543145, -0.011178},{
      1.664157, 0.541992, -0.011178},{1.664728, 0.543750, -0.012311}}],
    Polygon[{{1.661893, 0.543145, -0.011178},{1.660924, 0.541811, -0.009770},{
      1.663648, 0.540424, -0.009770},{1.664157, 0.541992, -0.011178}}],
    Polygon[{{1.660924, 0.541811, -0.009770},{1.660096, 0.540672, -0.008122},{
      1.663212, 0.539084, -0.008122},{1.663648, 0.540424, -0.009770}}],
    Polygon[{{1.660096, 0.540672, -0.008122},{1.659430, 0.539756, -0.006273},{
      1.662862, 0.538007, -0.006273},{1.663212, 0.539084, -0.008122}}],
    Polygon[{{1.659430, 0.539756, -0.006273},{1.658943, 0.539084, -0.004270},{
      1.662606, 0.537218, -0.004270},{1.662862, 0.538007, -0.006273}}],
    Polygon[{{1.658943, 0.539084, -0.004270},{1.658645, 0.538675, -0.002162},{
      1.662449, 0.536736, -0.002162},{1.662606, 0.537218, -0.004270}}],
    Polygon[{{1.658645, 0.538675, -0.002162},{1.658545, 0.538537, 0.000000},{
      1.662397, 0.536575, 0.000000},{1.662449, 0.536736, -0.002162}}],
    Polygon[{{1.658545, 0.538537, 0.000000},{1.658645, 0.538675, 0.002162},{
      1.662449, 0.536736, 0.002162},{1.662397, 0.536575, 0.000000}}],
    Polygon[{{1.658645, 0.538675, 0.002162},{1.658943, 0.539084, 0.004270},{
      1.662606, 0.537218, 0.004270},{1.662449, 0.536736, 0.002162}}],
    Polygon[{{1.658943, 0.539084, 0.004270},{1.659430, 0.539756, 0.006273},{
      1.662862, 0.538007, 0.006273},{1.662606, 0.537218, 0.004270}}],
    Polygon[{{1.659430, 0.539756, 0.006273},{1.660096, 0.540672, 0.008122},{
      1.663212, 0.539084, 0.008122},{1.662862, 0.538007, 0.006273}}],
    Polygon[{{1.660096, 0.540672, 0.008122},{1.660924, 0.541811, 0.009770},{
      1.663648, 0.540424, 0.009770},{1.663212, 0.539084, 0.008122}}],
    Polygon[{{1.660924, 0.541811, 0.009770},{1.661893, 0.543145, 0.011178},{
      1.664157, 0.541992, 0.011178},{1.663648, 0.540424, 0.009770}}],
    Polygon[{{1.661893, 0.543145, 0.011178},{1.662979, 0.544641, 0.012311},{
      1.664728, 0.543750, 0.012311},{1.664157, 0.541992, 0.011178}}],
    Polygon[{{1.662979, 0.544641, 0.012311},{1.664157, 0.546261, 0.013141},{
      1.665347, 0.545655, 0.013141},{1.664728, 0.543750, 0.012311}}],
    Polygon[{{1.664157, 0.546261, 0.013141},{1.665396, 0.547967, 0.013647},{
      1.665999, 0.547660, 0.013647},{1.665347, 0.545655, 0.013141}}],
    Polygon[{{1.665999, 0.547660, -0.013647},{1.665347, 0.545655, -0.013141},{
      1.666667, 0.545446, -0.013141},{1.666667, 0.547554, -0.013647}}],
    Polygon[{{1.665347, 0.545655, -0.013141},{1.664728, 0.543750, -0.012311},{
      1.666667, 0.543443, -0.012311},{1.666667, 0.545446, -0.013141}}],
    Polygon[{{1.664728, 0.543750, -0.012311},{1.664157, 0.541992, -0.011178},{
      1.666667, 0.541594, -0.011178},{1.666667, 0.543443, -0.012311}}],
    Polygon[{{1.664157, 0.541992, -0.011178},{1.663648, 0.540424, -0.009770},{
      1.666667, 0.539945, -0.009770},{1.666667, 0.541594, -0.011178}}],
    Polygon[{{1.663648, 0.540424, -0.009770},{1.663212, 0.539084, -0.008122},{
      1.666667, 0.538537, -0.008122},{1.666667, 0.539945, -0.009770}}],
    Polygon[{{1.663212, 0.539084, -0.008122},{1.662862, 0.538007, -0.006273},{
      1.666667, 0.537404, -0.006273},{1.666667, 0.538537, -0.008122}}],
    Polygon[{{1.662862, 0.538007, -0.006273},{1.662606, 0.537218, -0.004270},{
      1.666667, 0.536575, -0.004270},{1.666667, 0.537404, -0.006273}}],
    Polygon[{{1.662606, 0.537218, -0.004270},{1.662449, 0.536736, -0.002162},{
      1.666667, 0.536068, -0.002162},{1.666667, 0.536575, -0.004270}}],
    Polygon[{{1.662449, 0.536736, -0.002162},{1.662397, 0.536575, 0.000000},{
      1.666667, 0.535898, 0.000000},{1.666667, 0.536068, -0.002162}}],
    Polygon[{{1.662397, 0.536575, 0.000000},{1.662449, 0.536736, 0.002162},{
      1.666667, 0.536068, 0.002162},{1.666667, 0.535898, 0.000000}}],
    Polygon[{{1.662449, 0.536736, 0.002162},{1.662606, 0.537218, 0.004270},{
      1.666667, 0.536575, 0.004270},{1.666667, 0.536068, 0.002162}}],
    Polygon[{{1.662606, 0.537218, 0.004270},{1.662862, 0.538007, 0.006273},{
      1.666667, 0.537404, 0.006273},{1.666667, 0.536575, 0.004270}}],
    Polygon[{{1.662862, 0.538007, 0.006273},{1.663212, 0.539084, 0.008122},{
      1.666667, 0.538537, 0.008122},{1.666667, 0.537404, 0.006273}}],
    Polygon[{{1.663212, 0.539084, 0.008122},{1.663648, 0.540424, 0.009770},{
      1.666667, 0.539945, 0.009770},{1.666667, 0.538537, 0.008122}}],
    Polygon[{{1.663648, 0.540424, 0.009770},{1.664157, 0.541992, 0.011178},{
      1.666667, 0.541594, 0.011178},{1.666667, 0.539945, 0.009770}}],
    Polygon[{{1.664157, 0.541992, 0.011178},{1.664728, 0.543750, 0.012311},{
      1.666667, 0.543443, 0.012311},{1.666667, 0.541594, 0.011178}}],
    Polygon[{{1.664728, 0.543750, 0.012311},{1.665347, 0.545655, 0.013141},{
      1.666667, 0.545446, 0.013141},{1.666667, 0.543443, 0.012311}}],
    Polygon[{{1.665347, 0.545655, 0.013141},{1.665999, 0.547660, 0.013647},{
      1.666667, 0.547554, 0.013647},{1.666667, 0.545446, 0.013141}}],
    Polygon[{{1.666667, 0.547554, -0.013647},{1.666667, 0.545446, -0.013141},{
      1.667986, 0.545655, -0.013141},{1.667335, 0.547660, -0.013647}}],
    Polygon[{{1.666667, 0.545446, -0.013141},{1.666667, 0.543443, -0.012311},{
      1.668605, 0.543750, -0.012311},{1.667986, 0.545655, -0.013141}}],
    Polygon[{{1.666667, 0.543443, -0.012311},{1.666667, 0.541594, -0.011178},{
      1.669176, 0.541992, -0.011178},{1.668605, 0.543750, -0.012311}}],
    Polygon[{{1.666667, 0.541594, -0.011178},{1.666667, 0.539945, -0.009770},{
      1.669686, 0.540424, -0.009770},{1.669176, 0.541992, -0.011178}}],
    Polygon[{{1.666667, 0.539945, -0.009770},{1.666667, 0.538537, -0.008122},{
      1.670121, 0.539084, -0.008122},{1.669686, 0.540424, -0.009770}}],
    Polygon[{{1.666667, 0.538537, -0.008122},{1.666667, 0.537404, -0.006273},{
      1.670471, 0.538007, -0.006273},{1.670121, 0.539084, -0.008122}}],
    Polygon[{{1.666667, 0.537404, -0.006273},{1.666667, 0.536575, -0.004270},{
      1.670727, 0.537218, -0.004270},{1.670471, 0.538007, -0.006273}}],
    Polygon[{{1.666667, 0.536575, -0.004270},{1.666667, 0.536068, -0.002162},{
      1.670884, 0.536736, -0.002162},{1.670727, 0.537218, -0.004270}}],
    Polygon[{{1.666667, 0.536068, -0.002162},{1.666667, 0.535898, 0.000000},{
      1.670936, 0.536575, 0.000000},{1.670884, 0.536736, -0.002162}}],
    Polygon[{{1.666667, 0.535898, 0.000000},{1.666667, 0.536068, 0.002162},{
      1.670884, 0.536736, 0.002162},{1.670936, 0.536575, 0.000000}}],
    Polygon[{{1.666667, 0.536068, 0.002162},{1.666667, 0.536575, 0.004270},{
      1.670727, 0.537218, 0.004270},{1.670884, 0.536736, 0.002162}}],
    Polygon[{{1.666667, 0.536575, 0.004270},{1.666667, 0.537404, 0.006273},{
      1.670471, 0.538007, 0.006273},{1.670727, 0.537218, 0.004270}}],
    Polygon[{{1.666667, 0.537404, 0.006273},{1.666667, 0.538537, 0.008122},{
      1.670121, 0.539084, 0.008122},{1.670471, 0.538007, 0.006273}}],
    Polygon[{{1.666667, 0.538537, 0.008122},{1.666667, 0.539945, 0.009770},{
      1.669686, 0.540424, 0.009770},{1.670121, 0.539084, 0.008122}}],
    Polygon[{{1.666667, 0.539945, 0.009770},{1.666667, 0.541594, 0.011178},{
      1.669176, 0.541992, 0.011178},{1.669686, 0.540424, 0.009770}}],
    Polygon[{{1.666667, 0.541594, 0.011178},{1.666667, 0.543443, 0.012311},{
      1.668605, 0.543750, 0.012311},{1.669176, 0.541992, 0.011178}}],
    Polygon[{{1.666667, 0.543443, 0.012311},{1.666667, 0.545446, 0.013141},{
      1.667986, 0.545655, 0.013141},{1.668605, 0.543750, 0.012311}}],
    Polygon[{{1.666667, 0.545446, 0.013141},{1.666667, 0.547554, 0.013647},{
      1.667335, 0.547660, 0.013647},{1.667986, 0.545655, 0.013141}}],
    Polygon[{{1.667335, 0.547660, -0.013647},{1.667986, 0.545655, -0.013141},{
      1.669176, 0.546261, -0.013141},{1.667937, 0.547967, -0.013647}}],
    Polygon[{{1.667986, 0.545655, -0.013141},{1.668605, 0.543750, -0.012311},{
      1.670354, 0.544641, -0.012311},{1.669176, 0.546261, -0.013141}}],
    Polygon[{{1.668605, 0.543750, -0.012311},{1.669176, 0.541992, -0.011178},{
      1.671440, 0.543145, -0.011178},{1.670354, 0.544641, -0.012311}}],
    Polygon[{{1.669176, 0.541992, -0.011178},{1.669686, 0.540424, -0.009770},{
      1.672410, 0.541811, -0.009770},{1.671440, 0.543145, -0.011178}}],
    Polygon[{{1.669686, 0.540424, -0.009770},{1.670121, 0.539084, -0.008122},{
      1.673237, 0.540672, -0.008122},{1.672410, 0.541811, -0.009770}}],
    Polygon[{{1.670121, 0.539084, -0.008122},{1.670471, 0.538007, -0.006273},{
      1.673903, 0.539756, -0.006273},{1.673237, 0.540672, -0.008122}}],
    Polygon[{{1.670471, 0.538007, -0.006273},{1.670727, 0.537218, -0.004270},{
      1.674391, 0.539084, -0.004270},{1.673903, 0.539756, -0.006273}}],
    Polygon[{{1.670727, 0.537218, -0.004270},{1.670884, 0.536736, -0.002162},{
      1.674688, 0.538675, -0.002162},{1.674391, 0.539084, -0.004270}}],
    Polygon[{{1.670884, 0.536736, -0.002162},{1.670936, 0.536575, 0.000000},{
      1.674788, 0.538537, 0.000000},{1.674688, 0.538675, -0.002162}}],
    Polygon[{{1.670936, 0.536575, 0.000000},{1.670884, 0.536736, 0.002162},{
      1.674688, 0.538675, 0.002162},{1.674788, 0.538537, 0.000000}}],
    Polygon[{{1.670884, 0.536736, 0.002162},{1.670727, 0.537218, 0.004270},{
      1.674391, 0.539084, 0.004270},{1.674688, 0.538675, 0.002162}}],
    Polygon[{{1.670727, 0.537218, 0.004270},{1.670471, 0.538007, 0.006273},{
      1.673903, 0.539756, 0.006273},{1.674391, 0.539084, 0.004270}}],
    Polygon[{{1.670471, 0.538007, 0.006273},{1.670121, 0.539084, 0.008122},{
      1.673237, 0.540672, 0.008122},{1.673903, 0.539756, 0.006273}}],
    Polygon[{{1.670121, 0.539084, 0.008122},{1.669686, 0.540424, 0.009770},{
      1.672410, 0.541811, 0.009770},{1.673237, 0.540672, 0.008122}}],
    Polygon[{{1.669686, 0.540424, 0.009770},{1.669176, 0.541992, 0.011178},{
      1.671440, 0.543145, 0.011178},{1.672410, 0.541811, 0.009770}}],
    Polygon[{{1.669176, 0.541992, 0.011178},{1.668605, 0.543750, 0.012311},{
      1.670354, 0.544641, 0.012311},{1.671440, 0.543145, 0.011178}}],
    Polygon[{{1.668605, 0.543750, 0.012311},{1.667986, 0.545655, 0.013141},{
      1.669176, 0.546261, 0.013141},{1.670354, 0.544641, 0.012311}}],
    Polygon[{{1.667986, 0.545655, 0.013141},{1.667335, 0.547660, 0.013647},{
      1.667937, 0.547967, 0.013647},{1.669176, 0.546261, 0.013141}}],
    Polygon[{{1.667937, 0.547967, -0.013647},{1.669176, 0.546261, -0.013141},{
      1.670121, 0.547206, -0.013141},{1.668415, 0.548445, -0.013647}}],
    Polygon[{{1.669176, 0.546261, -0.013141},{1.670354, 0.544641, -0.012311},{
      1.671742, 0.546029, -0.012311},{1.670121, 0.547206, -0.013141}}],
    Polygon[{{1.670354, 0.544641, -0.012311},{1.671440, 0.543145, -0.011178},{
      1.673237, 0.544942, -0.011178},{1.671742, 0.546029, -0.012311}}],
    Polygon[{{1.671440, 0.543145, -0.011178},{1.672410, 0.541811, -0.009770},{
      1.674571, 0.543973, -0.009770},{1.673237, 0.544942, -0.011178}}],
    Polygon[{{1.672410, 0.541811, -0.009770},{1.673237, 0.540672, -0.008122},{
      1.675710, 0.543145, -0.008122},{1.674571, 0.543973, -0.009770}}],
    Polygon[{{1.673237, 0.540672, -0.008122},{1.673903, 0.539756, -0.006273},{
      1.676627, 0.542479, -0.006273},{1.675710, 0.543145, -0.008122}}],
    Polygon[{{1.673903, 0.539756, -0.006273},{1.674391, 0.539084, -0.004270},{
      1.677298, 0.541992, -0.004270},{1.676627, 0.542479, -0.006273}}],
    Polygon[{{1.674391, 0.539084, -0.004270},{1.674688, 0.538675, -0.002162},{
      1.677707, 0.541694, -0.002162},{1.677298, 0.541992, -0.004270}}],
    Polygon[{{1.674688, 0.538675, -0.002162},{1.674788, 0.538537, 0.000000},{
      1.677845, 0.541594, 0.000000},{1.677707, 0.541694, -0.002162}}],
    Polygon[{{1.674788, 0.538537, 0.000000},{1.674688, 0.538675, 0.002162},{
      1.677707, 0.541694, 0.002162},{1.677845, 0.541594, 0.000000}}],
    Polygon[{{1.674688, 0.538675, 0.002162},{1.674391, 0.539084, 0.004270},{
      1.677298, 0.541992, 0.004270},{1.677707, 0.541694, 0.002162}}],
    Polygon[{{1.674391, 0.539084, 0.004270},{1.673903, 0.539756, 0.006273},{
      1.676627, 0.542479, 0.006273},{1.677298, 0.541992, 0.004270}}],
    Polygon[{{1.673903, 0.539756, 0.006273},{1.673237, 0.540672, 0.008122},{
      1.675710, 0.543145, 0.008122},{1.676627, 0.542479, 0.006273}}],
    Polygon[{{1.673237, 0.540672, 0.008122},{1.672410, 0.541811, 0.009770},{
      1.674571, 0.543973, 0.009770},{1.675710, 0.543145, 0.008122}}],
    Polygon[{{1.672410, 0.541811, 0.009770},{1.671440, 0.543145, 0.011178},{
      1.673237, 0.544942, 0.011178},{1.674571, 0.543973, 0.009770}}],
    Polygon[{{1.671440, 0.543145, 0.011178},{1.670354, 0.544641, 0.012311},{
      1.671742, 0.546029, 0.012311},{1.673237, 0.544942, 0.011178}}],
    Polygon[{{1.670354, 0.544641, 0.012311},{1.669176, 0.546261, 0.013141},{
      1.670121, 0.547206, 0.013141},{1.671742, 0.546029, 0.012311}}],
    Polygon[{{1.669176, 0.546261, 0.013141},{1.667937, 0.547967, 0.013647},{
      1.668415, 0.548445, 0.013647},{1.670121, 0.547206, 0.013141}}],
    Polygon[{{1.668415, 0.548445, -0.013647},{1.670121, 0.547206, -0.013141},{
      1.670727, 0.548396, -0.013141},{1.668722, 0.549048, -0.013647}}],
    Polygon[{{1.670121, 0.547206, -0.013141},{1.671742, 0.546029, -0.012311},{
      1.672633, 0.547777, -0.012311},{1.670727, 0.548396, -0.013141}}],
    Polygon[{{1.671742, 0.546029, -0.012311},{1.673237, 0.544942, -0.011178},{
      1.674391, 0.547206, -0.011178},{1.672633, 0.547777, -0.012311}}],
    Polygon[{{1.673237, 0.544942, -0.011178},{1.674571, 0.543973, -0.009770},{
      1.675959, 0.546696, -0.009770},{1.674391, 0.547206, -0.011178}}],
    Polygon[{{1.674571, 0.543973, -0.009770},{1.675710, 0.543145, -0.008122},{
      1.677298, 0.546261, -0.008122},{1.675959, 0.546696, -0.009770}}],
    Polygon[{{1.675710, 0.543145, -0.008122},{1.676627, 0.542479, -0.006273},{
      1.678375, 0.545911, -0.006273},{1.677298, 0.546261, -0.008122}}],
    Polygon[{{1.676627, 0.542479, -0.006273},{1.677298, 0.541992, -0.004270},{
      1.679165, 0.545655, -0.004270},{1.678375, 0.545911, -0.006273}}],
    Polygon[{{1.677298, 0.541992, -0.004270},{1.677707, 0.541694, -0.002162},{
      1.679646, 0.545498, -0.002162},{1.679165, 0.545655, -0.004270}}],
    Polygon[{{1.677707, 0.541694, -0.002162},{1.677845, 0.541594, 0.000000},{
      1.679808, 0.545446, 0.000000},{1.679646, 0.545498, -0.002162}}],
    Polygon[{{1.677845, 0.541594, 0.000000},{1.677707, 0.541694, 0.002162},{
      1.679646, 0.545498, 0.002162},{1.679808, 0.545446, 0.000000}}],
    Polygon[{{1.677707, 0.541694, 0.002162},{1.677298, 0.541992, 0.004270},{
      1.679165, 0.545655, 0.004270},{1.679646, 0.545498, 0.002162}}],
    Polygon[{{1.677298, 0.541992, 0.004270},{1.676627, 0.542479, 0.006273},{
      1.678375, 0.545911, 0.006273},{1.679165, 0.545655, 0.004270}}],
    Polygon[{{1.676627, 0.542479, 0.006273},{1.675710, 0.543145, 0.008122},{
      1.677298, 0.546261, 0.008122},{1.678375, 0.545911, 0.006273}}],
    Polygon[{{1.675710, 0.543145, 0.008122},{1.674571, 0.543973, 0.009770},{
      1.675959, 0.546696, 0.009770},{1.677298, 0.546261, 0.008122}}],
    Polygon[{{1.674571, 0.543973, 0.009770},{1.673237, 0.544942, 0.011178},{
      1.674391, 0.547206, 0.011178},{1.675959, 0.546696, 0.009770}}],
    Polygon[{{1.673237, 0.544942, 0.011178},{1.671742, 0.546029, 0.012311},{
      1.672633, 0.547777, 0.012311},{1.674391, 0.547206, 0.011178}}],
    Polygon[{{1.671742, 0.546029, 0.012311},{1.670121, 0.547206, 0.013141},{
      1.670727, 0.548396, 0.013141},{1.672633, 0.547777, 0.012311}}],
    Polygon[{{1.670121, 0.547206, 0.013141},{1.668415, 0.548445, 0.013647},{
      1.668722, 0.549048, 0.013647},{1.670727, 0.548396, 0.013141}}],
    Polygon[{{1.668722, 0.549048, -0.013647},{1.670727, 0.548396, -0.013141},{
      1.670936, 0.549716, -0.013141},{1.668828, 0.549716, -0.013647}}],
    Polygon[{{1.670727, 0.548396, -0.013141},{1.672633, 0.547777, -0.012311},{
      1.672940, 0.549716, -0.012311},{1.670936, 0.549716, -0.013141}}],
    Polygon[{{1.672633, 0.547777, -0.012311},{1.674391, 0.547206, -0.011178},{
      1.674788, 0.549716, -0.011178},{1.672940, 0.549716, -0.012311}}],
    Polygon[{{1.674391, 0.547206, -0.011178},{1.675959, 0.546696, -0.009770},{
      1.676437, 0.549716, -0.009770},{1.674788, 0.549716, -0.011178}}],
    Polygon[{{1.675959, 0.546696, -0.009770},{1.677298, 0.546261, -0.008122},{
      1.677845, 0.549716, -0.008122},{1.676437, 0.549716, -0.009770}}],
    Polygon[{{1.677298, 0.546261, -0.008122},{1.678375, 0.545911, -0.006273},{
      1.678978, 0.549716, -0.006273},{1.677845, 0.549716, -0.008122}}],
    Polygon[{{1.678375, 0.545911, -0.006273},{1.679165, 0.545655, -0.004270},{
      1.679808, 0.549716, -0.004270},{1.678978, 0.549716, -0.006273}}],
    Polygon[{{1.679165, 0.545655, -0.004270},{1.679646, 0.545498, -0.002162},{
      1.680314, 0.549716, -0.002162},{1.679808, 0.549716, -0.004270}}],
    Polygon[{{1.679646, 0.545498, -0.002162},{1.679808, 0.545446, 0.000000},{
      1.680484, 0.549716, 0.000000},{1.680314, 0.549716, -0.002162}}],
    Polygon[{{1.679808, 0.545446, 0.000000},{1.679646, 0.545498, 0.002162},{
      1.680314, 0.549716, 0.002162},{1.680484, 0.549716, 0.000000}}],
    Polygon[{{1.679646, 0.545498, 0.002162},{1.679165, 0.545655, 0.004270},{
      1.679808, 0.549716, 0.004270},{1.680314, 0.549716, 0.002162}}],
    Polygon[{{1.679165, 0.545655, 0.004270},{1.678375, 0.545911, 0.006273},{
      1.678978, 0.549716, 0.006273},{1.679808, 0.549716, 0.004270}}],
    Polygon[{{1.678375, 0.545911, 0.006273},{1.677298, 0.546261, 0.008122},{
      1.677845, 0.549716, 0.008122},{1.678978, 0.549716, 0.006273}}],
    Polygon[{{1.677298, 0.546261, 0.008122},{1.675959, 0.546696, 0.009770},{
      1.676437, 0.549716, 0.009770},{1.677845, 0.549716, 0.008122}}],
    Polygon[{{1.675959, 0.546696, 0.009770},{1.674391, 0.547206, 0.011178},{
      1.674788, 0.549716, 0.011178},{1.676437, 0.549716, 0.009770}}],
    Polygon[{{1.674391, 0.547206, 0.011178},{1.672633, 0.547777, 0.012311},{
      1.672940, 0.549716, 0.012311},{1.674788, 0.549716, 0.011178}}],
    Polygon[{{1.672633, 0.547777, 0.012311},{1.670727, 0.548396, 0.013141},{
      1.670936, 0.549716, 0.013141},{1.672940, 0.549716, 0.012311}}],
    Polygon[{{1.670727, 0.548396, 0.013141},{1.668722, 0.549048, 0.013647},{
      1.668828, 0.549716, 0.013647},{1.670936, 0.549716, 0.013141}}],
    Polygon[{{1.590531, 0.532229, -0.012733},{1.592499, 0.532229, -0.012261},{
      1.592304, 0.533460, -0.012261},{1.590433, 0.532852, -0.012733}}],
    Polygon[{{1.592499, 0.532229, -0.012261},{1.594368, 0.532229, -0.011487},{
      1.594081, 0.534038, -0.011487},{1.592304, 0.533460, -0.012261}}],
    Polygon[{{1.594368, 0.532229, -0.011487},{1.596092, 0.532229, -0.010430},{
      1.595721, 0.534571, -0.010430},{1.594081, 0.534038, -0.011487}}],
    Polygon[{{1.596092, 0.532229, -0.010430},{1.597631, 0.532229, -0.009116},{
      1.597184, 0.535046, -0.009116},{1.595721, 0.534571, -0.010430}}],
    Polygon[{{1.597631, 0.532229, -0.009116},{1.598944, 0.532229, -0.007578},{
      1.598434, 0.535452, -0.007578},{1.597184, 0.535046, -0.009116}}],
    Polygon[{{1.598944, 0.532229, -0.007578},{1.600001, 0.532229, -0.005853},{
      1.599439, 0.535779, -0.005853},{1.598434, 0.535452, -0.007578}}],
    Polygon[{{1.600001, 0.532229, -0.005853},{1.600776, 0.532229, -0.003984},{
      1.600175, 0.536018, -0.003984},{1.599439, 0.535779, -0.005853}}],
    Polygon[{{1.600776, 0.532229, -0.003984},{1.601248, 0.532229, -0.002017},{
      1.600625, 0.536164, -0.002017},{1.600175, 0.536018, -0.003984}}],
    Polygon[{{1.601248, 0.532229, -0.002017},{1.601407, 0.532229, 0.000000},{
      1.600776, 0.536213, 0.000000},{1.600625, 0.536164, -0.002017}}],
    Polygon[{{1.601407, 0.532229, 0.000000},{1.601248, 0.532229, 0.002017},{
      1.600625, 0.536164, 0.002017},{1.600776, 0.536213, 0.000000}}],
    Polygon[{{1.601248, 0.532229, 0.002017},{1.600776, 0.532229, 0.003984},{
      1.600175, 0.536018, 0.003984},{1.600625, 0.536164, 0.002017}}],
    Polygon[{{1.600776, 0.532229, 0.003984},{1.600001, 0.532229, 0.005853},{
      1.599439, 0.535779, 0.005853},{1.600175, 0.536018, 0.003984}}],
    Polygon[{{1.600001, 0.532229, 0.005853},{1.598944, 0.532229, 0.007578},{
      1.598434, 0.535452, 0.007578},{1.599439, 0.535779, 0.005853}}],
    Polygon[{{1.598944, 0.532229, 0.007578},{1.597631, 0.532229, 0.009116},{
      1.597184, 0.535046, 0.009116},{1.598434, 0.535452, 0.007578}}],
    Polygon[{{1.597631, 0.532229, 0.009116},{1.596092, 0.532229, 0.010430},{
      1.595721, 0.534571, 0.010430},{1.597184, 0.535046, 0.009116}}],
    Polygon[{{1.596092, 0.532229, 0.010430},{1.594368, 0.532229, 0.011487},{
      1.594081, 0.534038, 0.011487},{1.595721, 0.534571, 0.010430}}],
    Polygon[{{1.594368, 0.532229, 0.011487},{1.592499, 0.532229, 0.012261},{
      1.592304, 0.533460, 0.012261},{1.594081, 0.534038, 0.011487}}],
    Polygon[{{1.592499, 0.532229, 0.012261},{1.590531, 0.532229, 0.012733},{
      1.590433, 0.532852, 0.012733},{1.592304, 0.533460, 0.012261}}],
    Polygon[{{1.590433, 0.532852, -0.012733},{1.592304, 0.533460, -0.012261},{
      1.591738, 0.534571, -0.012261},{1.590146, 0.533415, -0.012733}}],
    Polygon[{{1.592304, 0.533460, -0.012261},{1.594081, 0.534038, -0.011487},{
      1.593250, 0.535669, -0.011487},{1.591738, 0.534571, -0.012261}}],
    Polygon[{{1.594081, 0.534038, -0.011487},{1.595721, 0.534571, -0.010430},{
      1.594645, 0.536683, -0.010430},{1.593250, 0.535669, -0.011487}}],
    Polygon[{{1.595721, 0.534571, -0.010430},{1.597184, 0.535046, -0.009116},{
      1.595890, 0.537587, -0.009116},{1.594645, 0.536683, -0.010430}}],
    Polygon[{{1.597184, 0.535046, -0.009116},{1.598434, 0.535452, -0.007578},{
      1.596953, 0.538360, -0.007578},{1.595890, 0.537587, -0.009116}}],
    Polygon[{{1.598434, 0.535452, -0.007578},{1.599439, 0.535779, -0.005853},{
      1.597808, 0.538981, -0.005853},{1.596953, 0.538360, -0.007578}}],
    Polygon[{{1.599439, 0.535779, -0.005853},{1.600175, 0.536018, -0.003984},{
      1.598434, 0.539436, -0.003984},{1.597808, 0.538981, -0.005853}}],
    Polygon[{{1.600175, 0.536018, -0.003984},{1.600625, 0.536164, -0.002017},{
      1.598816, 0.539714, -0.002017},{1.598434, 0.539436, -0.003984}}],
    Polygon[{{1.600625, 0.536164, -0.002017},{1.600776, 0.536213, 0.000000},{
      1.598944, 0.539807, 0.000000},{1.598816, 0.539714, -0.002017}}],
    Polygon[{{1.600776, 0.536213, 0.000000},{1.600625, 0.536164, 0.002017},{
      1.598816, 0.539714, 0.002017},{1.598944, 0.539807, 0.000000}}],
    Polygon[{{1.600625, 0.536164, 0.002017},{1.600175, 0.536018, 0.003984},{
      1.598434, 0.539436, 0.003984},{1.598816, 0.539714, 0.002017}}],
    Polygon[{{1.600175, 0.536018, 0.003984},{1.599439, 0.535779, 0.005853},{
      1.597808, 0.538981, 0.005853},{1.598434, 0.539436, 0.003984}}],
    Polygon[{{1.599439, 0.535779, 0.005853},{1.598434, 0.535452, 0.007578},{
      1.596953, 0.538360, 0.007578},{1.597808, 0.538981, 0.005853}}],
    Polygon[{{1.598434, 0.535452, 0.007578},{1.597184, 0.535046, 0.009116},{
      1.595890, 0.537587, 0.009116},{1.596953, 0.538360, 0.007578}}],
    Polygon[{{1.597184, 0.535046, 0.009116},{1.595721, 0.534571, 0.010430},{
      1.594645, 0.536683, 0.010430},{1.595890, 0.537587, 0.009116}}],
    Polygon[{{1.595721, 0.534571, 0.010430},{1.594081, 0.534038, 0.011487},{
      1.593250, 0.535669, 0.011487},{1.594645, 0.536683, 0.010430}}],
    Polygon[{{1.594081, 0.534038, 0.011487},{1.592304, 0.533460, 0.012261},{
      1.591738, 0.534571, 0.012261},{1.593250, 0.535669, 0.011487}}],
    Polygon[{{1.592304, 0.533460, 0.012261},{1.590433, 0.532852, 0.012733},{
      1.590146, 0.533415, 0.012733},{1.591738, 0.534571, 0.012261}}],
    Polygon[{{1.590146, 0.533415, -0.012733},{1.591738, 0.534571, -0.012261},{
      1.590856, 0.535452, -0.012261},{1.589700, 0.533861, -0.012733}}],
    Polygon[{{1.591738, 0.534571, -0.012261},{1.593250, 0.535669, -0.011487},{
      1.591955, 0.536964, -0.011487},{1.590856, 0.535452, -0.012261}}],
    Polygon[{{1.593250, 0.535669, -0.011487},{1.594645, 0.536683, -0.010430},{
      1.592969, 0.538360, -0.010430},{1.591955, 0.536964, -0.011487}}],
    Polygon[{{1.594645, 0.536683, -0.010430},{1.595890, 0.537587, -0.009116},{
      1.593873, 0.539604, -0.009116},{1.592969, 0.538360, -0.010430}}],
    Polygon[{{1.595890, 0.537587, -0.009116},{1.596953, 0.538360, -0.007578},{
      1.594645, 0.540667, -0.007578},{1.593873, 0.539604, -0.009116}}],
    Polygon[{{1.596953, 0.538360, -0.007578},{1.597808, 0.538981, -0.005853},{
      1.595266, 0.541522, -0.005853},{1.594645, 0.540667, -0.007578}}],
    Polygon[{{1.597808, 0.538981, -0.005853},{1.598434, 0.539436, -0.003984},{
      1.595721, 0.542148, -0.003984},{1.595266, 0.541522, -0.005853}}],
    Polygon[{{1.598434, 0.539436, -0.003984},{1.598816, 0.539714, -0.002017},{
      1.595999, 0.542530, -0.002017},{1.595721, 0.542148, -0.003984}}],
    Polygon[{{1.598816, 0.539714, -0.002017},{1.598944, 0.539807, 0.000000},{
      1.596092, 0.542659, 0.000000},{1.595999, 0.542530, -0.002017}}],
    Polygon[{{1.598944, 0.539807, 0.000000},{1.598816, 0.539714, 0.002017},{
      1.595999, 0.542530, 0.002017},{1.596092, 0.542659, 0.000000}}],
    Polygon[{{1.598816, 0.539714, 0.002017},{1.598434, 0.539436, 0.003984},{
      1.595721, 0.542148, 0.003984},{1.595999, 0.542530, 0.002017}}],
    Polygon[{{1.598434, 0.539436, 0.003984},{1.597808, 0.538981, 0.005853},{
      1.595266, 0.541522, 0.005853},{1.595721, 0.542148, 0.003984}}],
    Polygon[{{1.597808, 0.538981, 0.005853},{1.596953, 0.538360, 0.007578},{
      1.594645, 0.540667, 0.007578},{1.595266, 0.541522, 0.005853}}],
    Polygon[{{1.596953, 0.538360, 0.007578},{1.595890, 0.537587, 0.009116},{
      1.593873, 0.539604, 0.009116},{1.594645, 0.540667, 0.007578}}],
    Polygon[{{1.595890, 0.537587, 0.009116},{1.594645, 0.536683, 0.010430},{
      1.592969, 0.538360, 0.010430},{1.593873, 0.539604, 0.009116}}],
    Polygon[{{1.594645, 0.536683, 0.010430},{1.593250, 0.535669, 0.011487},{
      1.591955, 0.536964, 0.011487},{1.592969, 0.538360, 0.010430}}],
    Polygon[{{1.593250, 0.535669, 0.011487},{1.591738, 0.534571, 0.012261},{
      1.590856, 0.535452, 0.012261},{1.591955, 0.536964, 0.011487}}],
    Polygon[{{1.591738, 0.534571, 0.012261},{1.590146, 0.533415, 0.012733},{
      1.589700, 0.533861, 0.012733},{1.590856, 0.535452, 0.012261}}],
    Polygon[{{1.589700, 0.533861, -0.012733},{1.590856, 0.535452, -0.012261},{
      1.589746, 0.536018, -0.012261},{1.589138, 0.534147, -0.012733}}],
    Polygon[{{1.590856, 0.535452, -0.012261},{1.591955, 0.536964, -0.011487},{
      1.590323, 0.537796, -0.011487},{1.589746, 0.536018, -0.012261}}],
    Polygon[{{1.591955, 0.536964, -0.011487},{1.592969, 0.538360, -0.010430},{
      1.590856, 0.539436, -0.010430},{1.590323, 0.537796, -0.011487}}],
    Polygon[{{1.592969, 0.538360, -0.010430},{1.593873, 0.539604, -0.009116},{
      1.591332, 0.540899, -0.009116},{1.590856, 0.539436, -0.010430}}],
    Polygon[{{1.593873, 0.539604, -0.009116},{1.594645, 0.540667, -0.007578},{
      1.591738, 0.542148, -0.007578},{1.591332, 0.540899, -0.009116}}],
    Polygon[{{1.594645, 0.540667, -0.007578},{1.595266, 0.541522, -0.005853},{
      1.592064, 0.543154, -0.005853},{1.591738, 0.542148, -0.007578}}],
    Polygon[{{1.595266, 0.541522, -0.005853},{1.595721, 0.542148, -0.003984},{
      1.592304, 0.543890, -0.003984},{1.592064, 0.543154, -0.005853}}],
    Polygon[{{1.595721, 0.542148, -0.003984},{1.595999, 0.542530, -0.002017},{
      1.592450, 0.544339, -0.002017},{1.592304, 0.543890, -0.003984}}],
    Polygon[{{1.595999, 0.542530, -0.002017},{1.596092, 0.542659, 0.000000},{
      1.592499, 0.544490, 0.000000},{1.592450, 0.544339, -0.002017}}],
    Polygon[{{1.596092, 0.542659, 0.000000},{1.595999, 0.542530, 0.002017},{
      1.592450, 0.544339, 0.002017},{1.592499, 0.544490, 0.000000}}],
    Polygon[{{1.595999, 0.542530, 0.002017},{1.595721, 0.542148, 0.003984},{
      1.592304, 0.543890, 0.003984},{1.592450, 0.544339, 0.002017}}],
    Polygon[{{1.595721, 0.542148, 0.003984},{1.595266, 0.541522, 0.005853},{
      1.592064, 0.543154, 0.005853},{1.592304, 0.543890, 0.003984}}],
    Polygon[{{1.595266, 0.541522, 0.005853},{1.594645, 0.540667, 0.007578},{
      1.591738, 0.542148, 0.007578},{1.592064, 0.543154, 0.005853}}],
    Polygon[{{1.594645, 0.540667, 0.007578},{1.593873, 0.539604, 0.009116},{
      1.591332, 0.540899, 0.009116},{1.591738, 0.542148, 0.007578}}],
    Polygon[{{1.593873, 0.539604, 0.009116},{1.592969, 0.538360, 0.010430},{
      1.590856, 0.539436, 0.010430},{1.591332, 0.540899, 0.009116}}],
    Polygon[{{1.592969, 0.538360, 0.010430},{1.591955, 0.536964, 0.011487},{
      1.590323, 0.537796, 0.011487},{1.590856, 0.539436, 0.010430}}],
    Polygon[{{1.591955, 0.536964, 0.011487},{1.590856, 0.535452, 0.012261},{
      1.589746, 0.536018, 0.012261},{1.590323, 0.537796, 0.011487}}],
    Polygon[{{1.590856, 0.535452, 0.012261},{1.589700, 0.533861, 0.012733},{
      1.589138, 0.534147, 0.012733},{1.589746, 0.536018, 0.012261}}],
    Polygon[{{1.589138, 0.534147, -0.012733},{1.589746, 0.536018, -0.012261},{
      1.588515, 0.536213, -0.012261},{1.588515, 0.534246, -0.012733}}],
    Polygon[{{1.589746, 0.536018, -0.012261},{1.590323, 0.537796, -0.011487},{
      1.588515, 0.538082, -0.011487},{1.588515, 0.536213, -0.012261}}],
    Polygon[{{1.590323, 0.537796, -0.011487},{1.590856, 0.539436, -0.010430},{
      1.588515, 0.539807, -0.010430},{1.588515, 0.538082, -0.011487}}],
    Polygon[{{1.590856, 0.539436, -0.010430},{1.591332, 0.540899, -0.009116},{
      1.588515, 0.541345, -0.009116},{1.588515, 0.539807, -0.010430}}],
    Polygon[{{1.591332, 0.540899, -0.009116},{1.591738, 0.542148, -0.007578},{
      1.588515, 0.542659, -0.007578},{1.588515, 0.541345, -0.009116}}],
    Polygon[{{1.591738, 0.542148, -0.007578},{1.592064, 0.543154, -0.005853},{
      1.588515, 0.543716, -0.005853},{1.588515, 0.542659, -0.007578}}],
    Polygon[{{1.592064, 0.543154, -0.005853},{1.592304, 0.543890, -0.003984},{
      1.588515, 0.544490, -0.003984},{1.588515, 0.543716, -0.005853}}],
    Polygon[{{1.592304, 0.543890, -0.003984},{1.592450, 0.544339, -0.002017},{
      1.588515, 0.544962, -0.002017},{1.588515, 0.544490, -0.003984}}],
    Polygon[{{1.592450, 0.544339, -0.002017},{1.592499, 0.544490, 0.000000},{
      1.588515, 0.545121, 0.000000},{1.588515, 0.544962, -0.002017}}],
    Polygon[{{1.592499, 0.544490, 0.000000},{1.592450, 0.544339, 0.002017},{
      1.588515, 0.544962, 0.002017},{1.588515, 0.545121, 0.000000}}],
    Polygon[{{1.592450, 0.544339, 0.002017},{1.592304, 0.543890, 0.003984},{
      1.588515, 0.544490, 0.003984},{1.588515, 0.544962, 0.002017}}],
    Polygon[{{1.592304, 0.543890, 0.003984},{1.592064, 0.543154, 0.005853},{
      1.588515, 0.543716, 0.005853},{1.588515, 0.544490, 0.003984}}],
    Polygon[{{1.592064, 0.543154, 0.005853},{1.591738, 0.542148, 0.007578},{
      1.588515, 0.542659, 0.007578},{1.588515, 0.543716, 0.005853}}],
    Polygon[{{1.591738, 0.542148, 0.007578},{1.591332, 0.540899, 0.009116},{
      1.588515, 0.541345, 0.009116},{1.588515, 0.542659, 0.007578}}],
    Polygon[{{1.591332, 0.540899, 0.009116},{1.590856, 0.539436, 0.010430},{
      1.588515, 0.539807, 0.010430},{1.588515, 0.541345, 0.009116}}],
    Polygon[{{1.590856, 0.539436, 0.010430},{1.590323, 0.537796, 0.011487},{
      1.588515, 0.538082, 0.011487},{1.588515, 0.539807, 0.010430}}],
    Polygon[{{1.590323, 0.537796, 0.011487},{1.589746, 0.536018, 0.012261},{
      1.588515, 0.536213, 0.012261},{1.588515, 0.538082, 0.011487}}],
    Polygon[{{1.589746, 0.536018, 0.012261},{1.589138, 0.534147, 0.012733},{
      1.588515, 0.534246, 0.012733},{1.588515, 0.536213, 0.012261}}],
    Polygon[{{1.588515, 0.534246, -0.012733},{1.588515, 0.536213, -0.012261},{
      1.587284, 0.536018, -0.012261},{1.587892, 0.534147, -0.012733}}],
    Polygon[{{1.588515, 0.536213, -0.012261},{1.588515, 0.538082, -0.011487},{
      1.586706, 0.537796, -0.011487},{1.587284, 0.536018, -0.012261}}],
    Polygon[{{1.588515, 0.538082, -0.011487},{1.588515, 0.539807, -0.010430},{
      1.586173, 0.539436, -0.010430},{1.586706, 0.537796, -0.011487}}],
    Polygon[{{1.588515, 0.539807, -0.010430},{1.588515, 0.541345, -0.009116},{
      1.585698, 0.540899, -0.009116},{1.586173, 0.539436, -0.010430}}],
    Polygon[{{1.588515, 0.541345, -0.009116},{1.588515, 0.542659, -0.007578},{
      1.585292, 0.542148, -0.007578},{1.585698, 0.540899, -0.009116}}],
    Polygon[{{1.588515, 0.542659, -0.007578},{1.588515, 0.543716, -0.005853},{
      1.584965, 0.543154, -0.005853},{1.585292, 0.542148, -0.007578}}],
    Polygon[{{1.588515, 0.543716, -0.005853},{1.588515, 0.544490, -0.003984},{
      1.584726, 0.543890, -0.003984},{1.584965, 0.543154, -0.005853}}],
    Polygon[{{1.588515, 0.544490, -0.003984},{1.588515, 0.544962, -0.002017},{
      1.584580, 0.544339, -0.002017},{1.584726, 0.543890, -0.003984}}],
    Polygon[{{1.588515, 0.544962, -0.002017},{1.588515, 0.545121, 0.000000},{
      1.584531, 0.544490, 0.000000},{1.584580, 0.544339, -0.002017}}],
    Polygon[{{1.588515, 0.545121, 0.000000},{1.588515, 0.544962, 0.002017},{
      1.584580, 0.544339, 0.002017},{1.584531, 0.544490, 0.000000}}],
    Polygon[{{1.588515, 0.544962, 0.002017},{1.588515, 0.544490, 0.003984},{
      1.584726, 0.543890, 0.003984},{1.584580, 0.544339, 0.002017}}],
    Polygon[{{1.588515, 0.544490, 0.003984},{1.588515, 0.543716, 0.005853},{
      1.584965, 0.543154, 0.005853},{1.584726, 0.543890, 0.003984}}],
    Polygon[{{1.588515, 0.543716, 0.005853},{1.588515, 0.542659, 0.007578},{
      1.585292, 0.542148, 0.007578},{1.584965, 0.543154, 0.005853}}],
    Polygon[{{1.588515, 0.542659, 0.007578},{1.588515, 0.541345, 0.009116},{
      1.585698, 0.540899, 0.009116},{1.585292, 0.542148, 0.007578}}],
    Polygon[{{1.588515, 0.541345, 0.009116},{1.588515, 0.539807, 0.010430},{
      1.586173, 0.539436, 0.010430},{1.585698, 0.540899, 0.009116}}],
    Polygon[{{1.588515, 0.539807, 0.010430},{1.588515, 0.538082, 0.011487},{
      1.586706, 0.537796, 0.011487},{1.586173, 0.539436, 0.010430}}],
    Polygon[{{1.588515, 0.538082, 0.011487},{1.588515, 0.536213, 0.012261},{
      1.587284, 0.536018, 0.012261},{1.586706, 0.537796, 0.011487}}],
    Polygon[{{1.588515, 0.536213, 0.012261},{1.588515, 0.534246, 0.012733},{
      1.587892, 0.534147, 0.012733},{1.587284, 0.536018, 0.012261}}],
    Polygon[{{1.587892, 0.534147, -0.012733},{1.587284, 0.536018, -0.012261},{
      1.586173, 0.535452, -0.012261},{1.587329, 0.533861, -0.012733}}],
    Polygon[{{1.587284, 0.536018, -0.012261},{1.586706, 0.537796, -0.011487},{
      1.585075, 0.536964, -0.011487},{1.586173, 0.535452, -0.012261}}],
    Polygon[{{1.586706, 0.537796, -0.011487},{1.586173, 0.539436, -0.010430},{
      1.584061, 0.538360, -0.010430},{1.585075, 0.536964, -0.011487}}],
    Polygon[{{1.586173, 0.539436, -0.010430},{1.585698, 0.540899, -0.009116},{
      1.583157, 0.539604, -0.009116},{1.584061, 0.538360, -0.010430}}],
    Polygon[{{1.585698, 0.540899, -0.009116},{1.585292, 0.542148, -0.007578},{
      1.582384, 0.540667, -0.007578},{1.583157, 0.539604, -0.009116}}],
    Polygon[{{1.585292, 0.542148, -0.007578},{1.584965, 0.543154, -0.005853},{
      1.581763, 0.541522, -0.005853},{1.582384, 0.540667, -0.007578}}],
    Polygon[{{1.584965, 0.543154, -0.005853},{1.584726, 0.543890, -0.003984},{
      1.581308, 0.542148, -0.003984},{1.581763, 0.541522, -0.005853}}],
    Polygon[{{1.584726, 0.543890, -0.003984},{1.584580, 0.544339, -0.002017},{
      1.581031, 0.542530, -0.002017},{1.581308, 0.542148, -0.003984}}],
    Polygon[{{1.584580, 0.544339, -0.002017},{1.584531, 0.544490, 0.000000},{
      1.580937, 0.542659, 0.000000},{1.581031, 0.542530, -0.002017}}],
    Polygon[{{1.584531, 0.544490, 0.000000},{1.584580, 0.544339, 0.002017},{
      1.581031, 0.542530, 0.002017},{1.580937, 0.542659, 0.000000}}],
    Polygon[{{1.584580, 0.544339, 0.002017},{1.584726, 0.543890, 0.003984},{
      1.581308, 0.542148, 0.003984},{1.581031, 0.542530, 0.002017}}],
    Polygon[{{1.584726, 0.543890, 0.003984},{1.584965, 0.543154, 0.005853},{
      1.581763, 0.541522, 0.005853},{1.581308, 0.542148, 0.003984}}],
    Polygon[{{1.584965, 0.543154, 0.005853},{1.585292, 0.542148, 0.007578},{
      1.582384, 0.540667, 0.007578},{1.581763, 0.541522, 0.005853}}],
    Polygon[{{1.585292, 0.542148, 0.007578},{1.585698, 0.540899, 0.009116},{
      1.583157, 0.539604, 0.009116},{1.582384, 0.540667, 0.007578}}],
    Polygon[{{1.585698, 0.540899, 0.009116},{1.586173, 0.539436, 0.010430},{
      1.584061, 0.538360, 0.010430},{1.583157, 0.539604, 0.009116}}],
    Polygon[{{1.586173, 0.539436, 0.010430},{1.586706, 0.537796, 0.011487},{
      1.585075, 0.536964, 0.011487},{1.584061, 0.538360, 0.010430}}],
    Polygon[{{1.586706, 0.537796, 0.011487},{1.587284, 0.536018, 0.012261},{
      1.586173, 0.535452, 0.012261},{1.585075, 0.536964, 0.011487}}],
    Polygon[{{1.587284, 0.536018, 0.012261},{1.587892, 0.534147, 0.012733},{
      1.587329, 0.533861, 0.012733},{1.586173, 0.535452, 0.012261}}],
    Polygon[{{1.587329, 0.533861, -0.012733},{1.586173, 0.535452, -0.012261},{
      1.585292, 0.534571, -0.012261},{1.586883, 0.533415, -0.012733}}],
    Polygon[{{1.586173, 0.535452, -0.012261},{1.585075, 0.536964, -0.011487},{
      1.583780, 0.535669, -0.011487},{1.585292, 0.534571, -0.012261}}],
    Polygon[{{1.585075, 0.536964, -0.011487},{1.584061, 0.538360, -0.010430},{
      1.582384, 0.536683, -0.010430},{1.583780, 0.535669, -0.011487}}],
    Polygon[{{1.584061, 0.538360, -0.010430},{1.583157, 0.539604, -0.009116},{
      1.581140, 0.537587, -0.009116},{1.582384, 0.536683, -0.010430}}],
    Polygon[{{1.583157, 0.539604, -0.009116},{1.582384, 0.540667, -0.007578},{
      1.580077, 0.538360, -0.007578},{1.581140, 0.537587, -0.009116}}],
    Polygon[{{1.582384, 0.540667, -0.007578},{1.581763, 0.541522, -0.005853},{
      1.579222, 0.538981, -0.005853},{1.580077, 0.538360, -0.007578}}],
    Polygon[{{1.581763, 0.541522, -0.005853},{1.581308, 0.542148, -0.003984},{
      1.578596, 0.539436, -0.003984},{1.579222, 0.538981, -0.005853}}],
    Polygon[{{1.581308, 0.542148, -0.003984},{1.581031, 0.542530, -0.002017},{
      1.578214, 0.539714, -0.002017},{1.578596, 0.539436, -0.003984}}],
    Polygon[{{1.581031, 0.542530, -0.002017},{1.580937, 0.542659, 0.000000},{
      1.578085, 0.539807, 0.000000},{1.578214, 0.539714, -0.002017}}],
    Polygon[{{1.580937, 0.542659, 0.000000},{1.581031, 0.542530, 0.002017},{
      1.578214, 0.539714, 0.002017},{1.578085, 0.539807, 0.000000}}],
    Polygon[{{1.581031, 0.542530, 0.002017},{1.581308, 0.542148, 0.003984},{
      1.578596, 0.539436, 0.003984},{1.578214, 0.539714, 0.002017}}],
    Polygon[{{1.581308, 0.542148, 0.003984},{1.581763, 0.541522, 0.005853},{
      1.579222, 0.538981, 0.005853},{1.578596, 0.539436, 0.003984}}],
    Polygon[{{1.581763, 0.541522, 0.005853},{1.582384, 0.540667, 0.007578},{
      1.580077, 0.538360, 0.007578},{1.579222, 0.538981, 0.005853}}],
    Polygon[{{1.582384, 0.540667, 0.007578},{1.583157, 0.539604, 0.009116},{
      1.581140, 0.537587, 0.009116},{1.580077, 0.538360, 0.007578}}],
    Polygon[{{1.583157, 0.539604, 0.009116},{1.584061, 0.538360, 0.010430},{
      1.582384, 0.536683, 0.010430},{1.581140, 0.537587, 0.009116}}],
    Polygon[{{1.584061, 0.538360, 0.010430},{1.585075, 0.536964, 0.011487},{
      1.583780, 0.535669, 0.011487},{1.582384, 0.536683, 0.010430}}],
    Polygon[{{1.585075, 0.536964, 0.011487},{1.586173, 0.535452, 0.012261},{
      1.585292, 0.534571, 0.012261},{1.583780, 0.535669, 0.011487}}],
    Polygon[{{1.586173, 0.535452, 0.012261},{1.587329, 0.533861, 0.012733},{
      1.586883, 0.533415, 0.012733},{1.585292, 0.534571, 0.012261}}],
    Polygon[{{1.586883, 0.533415, -0.012733},{1.585292, 0.534571, -0.012261},{
      1.584726, 0.533460, -0.012261},{1.586597, 0.532852, -0.012733}}],
    Polygon[{{1.585292, 0.534571, -0.012261},{1.583780, 0.535669, -0.011487},{
      1.582949, 0.534038, -0.011487},{1.584726, 0.533460, -0.012261}}],
    Polygon[{{1.583780, 0.535669, -0.011487},{1.582384, 0.536683, -0.010430},{
      1.581308, 0.534571, -0.010430},{1.582949, 0.534038, -0.011487}}],
    Polygon[{{1.582384, 0.536683, -0.010430},{1.581140, 0.537587, -0.009116},{
      1.579845, 0.535046, -0.009116},{1.581308, 0.534571, -0.010430}}],
    Polygon[{{1.581140, 0.537587, -0.009116},{1.580077, 0.538360, -0.007578},{
      1.578596, 0.535452, -0.007578},{1.579845, 0.535046, -0.009116}}],
    Polygon[{{1.580077, 0.538360, -0.007578},{1.579222, 0.538981, -0.005853},{
      1.577590, 0.535779, -0.005853},{1.578596, 0.535452, -0.007578}}],
    Polygon[{{1.579222, 0.538981, -0.005853},{1.578596, 0.539436, -0.003984},{
      1.576854, 0.536018, -0.003984},{1.577590, 0.535779, -0.005853}}],
    Polygon[{{1.578596, 0.539436, -0.003984},{1.578214, 0.539714, -0.002017},{
      1.576405, 0.536164, -0.002017},{1.576854, 0.536018, -0.003984}}],
    Polygon[{{1.578214, 0.539714, -0.002017},{1.578085, 0.539807, 0.000000},{
      1.576254, 0.536213, 0.000000},{1.576405, 0.536164, -0.002017}}],
    Polygon[{{1.578085, 0.539807, 0.000000},{1.578214, 0.539714, 0.002017},{
      1.576405, 0.536164, 0.002017},{1.576254, 0.536213, 0.000000}}],
    Polygon[{{1.578214, 0.539714, 0.002017},{1.578596, 0.539436, 0.003984},{
      1.576854, 0.536018, 0.003984},{1.576405, 0.536164, 0.002017}}],
    Polygon[{{1.578596, 0.539436, 0.003984},{1.579222, 0.538981, 0.005853},{
      1.577590, 0.535779, 0.005853},{1.576854, 0.536018, 0.003984}}],
    Polygon[{{1.579222, 0.538981, 0.005853},{1.580077, 0.538360, 0.007578},{
      1.578596, 0.535452, 0.007578},{1.577590, 0.535779, 0.005853}}],
    Polygon[{{1.580077, 0.538360, 0.007578},{1.581140, 0.537587, 0.009116},{
      1.579845, 0.535046, 0.009116},{1.578596, 0.535452, 0.007578}}],
    Polygon[{{1.581140, 0.537587, 0.009116},{1.582384, 0.536683, 0.010430},{
      1.581308, 0.534571, 0.010430},{1.579845, 0.535046, 0.009116}}],
    Polygon[{{1.582384, 0.536683, 0.010430},{1.583780, 0.535669, 0.011487},{
      1.582949, 0.534038, 0.011487},{1.581308, 0.534571, 0.010430}}],
    Polygon[{{1.583780, 0.535669, 0.011487},{1.585292, 0.534571, 0.012261},{
      1.584726, 0.533460, 0.012261},{1.582949, 0.534038, 0.011487}}],
    Polygon[{{1.585292, 0.534571, 0.012261},{1.586883, 0.533415, 0.012733},{
      1.586597, 0.532852, 0.012733},{1.584726, 0.533460, 0.012261}}],
    Polygon[{{1.586597, 0.532852, -0.012733},{1.584726, 0.533460, -0.012261},{
      1.584531, 0.532229, -0.012261},{1.586498, 0.532229, -0.012733}}],
    Polygon[{{1.584726, 0.533460, -0.012261},{1.582949, 0.534038, -0.011487},{
      1.582662, 0.532229, -0.011487},{1.584531, 0.532229, -0.012261}}],
    Polygon[{{1.582949, 0.534038, -0.011487},{1.581308, 0.534571, -0.010430},{
      1.580937, 0.532229, -0.010430},{1.582662, 0.532229, -0.011487}}],
    Polygon[{{1.581308, 0.534571, -0.010430},{1.579845, 0.535046, -0.009116},{
      1.579399, 0.532229, -0.009116},{1.580937, 0.532229, -0.010430}}],
    Polygon[{{1.579845, 0.535046, -0.009116},{1.578596, 0.535452, -0.007578},{
      1.578085, 0.532229, -0.007578},{1.579399, 0.532229, -0.009116}}],
    Polygon[{{1.578596, 0.535452, -0.007578},{1.577590, 0.535779, -0.005853},{
      1.577028, 0.532229, -0.005853},{1.578085, 0.532229, -0.007578}}],
    Polygon[{{1.577590, 0.535779, -0.005853},{1.576854, 0.536018, -0.003984},{
      1.576254, 0.532229, -0.003984},{1.577028, 0.532229, -0.005853}}],
    Polygon[{{1.576854, 0.536018, -0.003984},{1.576405, 0.536164, -0.002017},{
      1.575782, 0.532229, -0.002017},{1.576254, 0.532229, -0.003984}}],
    Polygon[{{1.576405, 0.536164, -0.002017},{1.576254, 0.536213, 0.000000},{
      1.575623, 0.532229, 0.000000},{1.575782, 0.532229, -0.002017}}],
    Polygon[{{1.576254, 0.536213, 0.000000},{1.576405, 0.536164, 0.002017},{
      1.575782, 0.532229, 0.002017},{1.575623, 0.532229, 0.000000}}],
    Polygon[{{1.576405, 0.536164, 0.002017},{1.576854, 0.536018, 0.003984},{
      1.576254, 0.532229, 0.003984},{1.575782, 0.532229, 0.002017}}],
    Polygon[{{1.576854, 0.536018, 0.003984},{1.577590, 0.535779, 0.005853},{
      1.577028, 0.532229, 0.005853},{1.576254, 0.532229, 0.003984}}],
    Polygon[{{1.577590, 0.535779, 0.005853},{1.578596, 0.535452, 0.007578},{
      1.578085, 0.532229, 0.007578},{1.577028, 0.532229, 0.005853}}],
    Polygon[{{1.578596, 0.535452, 0.007578},{1.579845, 0.535046, 0.009116},{
      1.579399, 0.532229, 0.009116},{1.578085, 0.532229, 0.007578}}],
    Polygon[{{1.579845, 0.535046, 0.009116},{1.581308, 0.534571, 0.010430},{
      1.580937, 0.532229, 0.010430},{1.579399, 0.532229, 0.009116}}],
    Polygon[{{1.581308, 0.534571, 0.010430},{1.582949, 0.534038, 0.011487},{
      1.582662, 0.532229, 0.011487},{1.580937, 0.532229, 0.010430}}],
    Polygon[{{1.582949, 0.534038, 0.011487},{1.584726, 0.533460, 0.012261},{
      1.584531, 0.532229, 0.012261},{1.582662, 0.532229, 0.011487}}],
    Polygon[{{1.584726, 0.533460, 0.012261},{1.586597, 0.532852, 0.012733},{
      1.586498, 0.532229, 0.012733},{1.584531, 0.532229, 0.012261}}],
    Polygon[{{1.586498, 0.532229, -0.012733},{1.584531, 0.532229, -0.012261},{
      1.584726, 0.530998, -0.012261},{1.586597, 0.531606, -0.012733}}],
    Polygon[{{1.584531, 0.532229, -0.012261},{1.582662, 0.532229, -0.011487},{
      1.582949, 0.530421, -0.011487},{1.584726, 0.530998, -0.012261}}],
    Polygon[{{1.582662, 0.532229, -0.011487},{1.580937, 0.532229, -0.010430},{
      1.581308, 0.529888, -0.010430},{1.582949, 0.530421, -0.011487}}],
    Polygon[{{1.580937, 0.532229, -0.010430},{1.579399, 0.532229, -0.009116},{
      1.579845, 0.529412, -0.009116},{1.581308, 0.529888, -0.010430}}],
    Polygon[{{1.579399, 0.532229, -0.009116},{1.578085, 0.532229, -0.007578},{
      1.578596, 0.529006, -0.007578},{1.579845, 0.529412, -0.009116}}],
    Polygon[{{1.578085, 0.532229, -0.007578},{1.577028, 0.532229, -0.005853},{
      1.577590, 0.528680, -0.005853},{1.578596, 0.529006, -0.007578}}],
    Polygon[{{1.577028, 0.532229, -0.005853},{1.576254, 0.532229, -0.003984},{
      1.576854, 0.528440, -0.003984},{1.577590, 0.528680, -0.005853}}],
    Polygon[{{1.576254, 0.532229, -0.003984},{1.575782, 0.532229, -0.002017},{
      1.576405, 0.528295, -0.002017},{1.576854, 0.528440, -0.003984}}],
    Polygon[{{1.575782, 0.532229, -0.002017},{1.575623, 0.532229, 0.000000},{
      1.576254, 0.528246, 0.000000},{1.576405, 0.528295, -0.002017}}],
    Polygon[{{1.575623, 0.532229, 0.000000},{1.575782, 0.532229, 0.002017},{
      1.576405, 0.528295, 0.002017},{1.576254, 0.528246, 0.000000}}],
    Polygon[{{1.575782, 0.532229, 0.002017},{1.576254, 0.532229, 0.003984},{
      1.576854, 0.528440, 0.003984},{1.576405, 0.528295, 0.002017}}],
    Polygon[{{1.576254, 0.532229, 0.003984},{1.577028, 0.532229, 0.005853},{
      1.577590, 0.528680, 0.005853},{1.576854, 0.528440, 0.003984}}],
    Polygon[{{1.577028, 0.532229, 0.005853},{1.578085, 0.532229, 0.007578},{
      1.578596, 0.529006, 0.007578},{1.577590, 0.528680, 0.005853}}],
    Polygon[{{1.578085, 0.532229, 0.007578},{1.579399, 0.532229, 0.009116},{
      1.579845, 0.529412, 0.009116},{1.578596, 0.529006, 0.007578}}],
    Polygon[{{1.579399, 0.532229, 0.009116},{1.580937, 0.532229, 0.010430},{
      1.581308, 0.529888, 0.010430},{1.579845, 0.529412, 0.009116}}],
    Polygon[{{1.580937, 0.532229, 0.010430},{1.582662, 0.532229, 0.011487},{
      1.582949, 0.530421, 0.011487},{1.581308, 0.529888, 0.010430}}],
    Polygon[{{1.582662, 0.532229, 0.011487},{1.584531, 0.532229, 0.012261},{
      1.584726, 0.530998, 0.012261},{1.582949, 0.530421, 0.011487}}],
    Polygon[{{1.584531, 0.532229, 0.012261},{1.586498, 0.532229, 0.012733},{
      1.586597, 0.531606, 0.012733},{1.584726, 0.530998, 0.012261}}],
    Polygon[{{1.586597, 0.531606, -0.012733},{1.584726, 0.530998, -0.012261},{
      1.585292, 0.529888, -0.012261},{1.586883, 0.531044, -0.012733}}],
    Polygon[{{1.584726, 0.530998, -0.012261},{1.582949, 0.530421, -0.011487},{
      1.583780, 0.528789, -0.011487},{1.585292, 0.529888, -0.012261}}],
    Polygon[{{1.582949, 0.530421, -0.011487},{1.581308, 0.529888, -0.010430},{
      1.582384, 0.527775, -0.010430},{1.583780, 0.528789, -0.011487}}],
    Polygon[{{1.581308, 0.529888, -0.010430},{1.579845, 0.529412, -0.009116},{
      1.581140, 0.526871, -0.009116},{1.582384, 0.527775, -0.010430}}],
    Polygon[{{1.579845, 0.529412, -0.009116},{1.578596, 0.529006, -0.007578},{
      1.580077, 0.526099, -0.007578},{1.581140, 0.526871, -0.009116}}],
    Polygon[{{1.578596, 0.529006, -0.007578},{1.577590, 0.528680, -0.005853},{
      1.579222, 0.525478, -0.005853},{1.580077, 0.526099, -0.007578}}],
    Polygon[{{1.577590, 0.528680, -0.005853},{1.576854, 0.528440, -0.003984},{
      1.578596, 0.525023, -0.003984},{1.579222, 0.525478, -0.005853}}],
    Polygon[{{1.576854, 0.528440, -0.003984},{1.576405, 0.528295, -0.002017},{
      1.578214, 0.524745, -0.002017},{1.578596, 0.525023, -0.003984}}],
    Polygon[{{1.576405, 0.528295, -0.002017},{1.576254, 0.528246, 0.000000},{
      1.578085, 0.524652, 0.000000},{1.578214, 0.524745, -0.002017}}],
    Polygon[{{1.576254, 0.528246, 0.000000},{1.576405, 0.528295, 0.002017},{
      1.578214, 0.524745, 0.002017},{1.578085, 0.524652, 0.000000}}],
    Polygon[{{1.576405, 0.528295, 0.002017},{1.576854, 0.528440, 0.003984},{
      1.578596, 0.525023, 0.003984},{1.578214, 0.524745, 0.002017}}],
    Polygon[{{1.576854, 0.528440, 0.003984},{1.577590, 0.528680, 0.005853},{
      1.579222, 0.525478, 0.005853},{1.578596, 0.525023, 0.003984}}],
    Polygon[{{1.577590, 0.528680, 0.005853},{1.578596, 0.529006, 0.007578},{
      1.580077, 0.526099, 0.007578},{1.579222, 0.525478, 0.005853}}],
    Polygon[{{1.578596, 0.529006, 0.007578},{1.579845, 0.529412, 0.009116},{
      1.581140, 0.526871, 0.009116},{1.580077, 0.526099, 0.007578}}],
    Polygon[{{1.579845, 0.529412, 0.009116},{1.581308, 0.529888, 0.010430},{
      1.582384, 0.527775, 0.010430},{1.581140, 0.526871, 0.009116}}],
    Polygon[{{1.581308, 0.529888, 0.010430},{1.582949, 0.530421, 0.011487},{
      1.583780, 0.528789, 0.011487},{1.582384, 0.527775, 0.010430}}],
    Polygon[{{1.582949, 0.530421, 0.011487},{1.584726, 0.530998, 0.012261},{
      1.585292, 0.529888, 0.012261},{1.583780, 0.528789, 0.011487}}],
    Polygon[{{1.584726, 0.530998, 0.012261},{1.586597, 0.531606, 0.012733},{
      1.586883, 0.531044, 0.012733},{1.585292, 0.529888, 0.012261}}],
    Polygon[{{1.586883, 0.531044, -0.012733},{1.585292, 0.529888, -0.012261},{
      1.586173, 0.529006, -0.012261},{1.587329, 0.530598, -0.012733}}],
    Polygon[{{1.585292, 0.529888, -0.012261},{1.583780, 0.528789, -0.011487},{
      1.585075, 0.527494, -0.011487},{1.586173, 0.529006, -0.012261}}],
    Polygon[{{1.583780, 0.528789, -0.011487},{1.582384, 0.527775, -0.010430},{
      1.584061, 0.526099, -0.010430},{1.585075, 0.527494, -0.011487}}],
    Polygon[{{1.582384, 0.527775, -0.010430},{1.581140, 0.526871, -0.009116},{
      1.583157, 0.524854, -0.009116},{1.584061, 0.526099, -0.010430}}],
    Polygon[{{1.581140, 0.526871, -0.009116},{1.580077, 0.526099, -0.007578},{
      1.582384, 0.523792, -0.007578},{1.583157, 0.524854, -0.009116}}],
    Polygon[{{1.580077, 0.526099, -0.007578},{1.579222, 0.525478, -0.005853},{
      1.581763, 0.522936, -0.005853},{1.582384, 0.523792, -0.007578}}],
    Polygon[{{1.579222, 0.525478, -0.005853},{1.578596, 0.525023, -0.003984},{
      1.581308, 0.522310, -0.003984},{1.581763, 0.522936, -0.005853}}],
    Polygon[{{1.578596, 0.525023, -0.003984},{1.578214, 0.524745, -0.002017},{
      1.581031, 0.521928, -0.002017},{1.581308, 0.522310, -0.003984}}],
    Polygon[{{1.578214, 0.524745, -0.002017},{1.578085, 0.524652, 0.000000},{
      1.580937, 0.521800, 0.000000},{1.581031, 0.521928, -0.002017}}],
    Polygon[{{1.578085, 0.524652, 0.000000},{1.578214, 0.524745, 0.002017},{
      1.581031, 0.521928, 0.002017},{1.580937, 0.521800, 0.000000}}],
    Polygon[{{1.578214, 0.524745, 0.002017},{1.578596, 0.525023, 0.003984},{
      1.581308, 0.522310, 0.003984},{1.581031, 0.521928, 0.002017}}],
    Polygon[{{1.578596, 0.525023, 0.003984},{1.579222, 0.525478, 0.005853},{
      1.581763, 0.522936, 0.005853},{1.581308, 0.522310, 0.003984}}],
    Polygon[{{1.579222, 0.525478, 0.005853},{1.580077, 0.526099, 0.007578},{
      1.582384, 0.523792, 0.007578},{1.581763, 0.522936, 0.005853}}],
    Polygon[{{1.580077, 0.526099, 0.007578},{1.581140, 0.526871, 0.009116},{
      1.583157, 0.524854, 0.009116},{1.582384, 0.523792, 0.007578}}],
    Polygon[{{1.581140, 0.526871, 0.009116},{1.582384, 0.527775, 0.010430},{
      1.584061, 0.526099, 0.010430},{1.583157, 0.524854, 0.009116}}],
    Polygon[{{1.582384, 0.527775, 0.010430},{1.583780, 0.528789, 0.011487},{
      1.585075, 0.527494, 0.011487},{1.584061, 0.526099, 0.010430}}],
    Polygon[{{1.583780, 0.528789, 0.011487},{1.585292, 0.529888, 0.012261},{
      1.586173, 0.529006, 0.012261},{1.585075, 0.527494, 0.011487}}],
    Polygon[{{1.585292, 0.529888, 0.012261},{1.586883, 0.531044, 0.012733},{
      1.587329, 0.530598, 0.012733},{1.586173, 0.529006, 0.012261}}],
    Polygon[{{1.587329, 0.530598, -0.012733},{1.586173, 0.529006, -0.012261},{
      1.587284, 0.528440, -0.012261},{1.587892, 0.530311, -0.012733}}],
    Polygon[{{1.586173, 0.529006, -0.012261},{1.585075, 0.527494, -0.011487},{
      1.586706, 0.526663, -0.011487},{1.587284, 0.528440, -0.012261}}],
    Polygon[{{1.585075, 0.527494, -0.011487},{1.584061, 0.526099, -0.010430},{
      1.586173, 0.525023, -0.010430},{1.586706, 0.526663, -0.011487}}],
    Polygon[{{1.584061, 0.526099, -0.010430},{1.583157, 0.524854, -0.009116},{
      1.585698, 0.523560, -0.009116},{1.586173, 0.525023, -0.010430}}],
    Polygon[{{1.583157, 0.524854, -0.009116},{1.582384, 0.523792, -0.007578},{
      1.585292, 0.522310, -0.007578},{1.585698, 0.523560, -0.009116}}],
    Polygon[{{1.582384, 0.523792, -0.007578},{1.581763, 0.522936, -0.005853},{
      1.584965, 0.521305, -0.005853},{1.585292, 0.522310, -0.007578}}],
    Polygon[{{1.581763, 0.522936, -0.005853},{1.581308, 0.522310, -0.003984},{
      1.584726, 0.520569, -0.003984},{1.584965, 0.521305, -0.005853}}],
    Polygon[{{1.581308, 0.522310, -0.003984},{1.581031, 0.521928, -0.002017},{
      1.584580, 0.520119, -0.002017},{1.584726, 0.520569, -0.003984}}],
    Polygon[{{1.581031, 0.521928, -0.002017},{1.580937, 0.521800, 0.000000},{
      1.584531, 0.519969, 0.000000},{1.584580, 0.520119, -0.002017}}],
    Polygon[{{1.580937, 0.521800, 0.000000},{1.581031, 0.521928, 0.002017},{
      1.584580, 0.520119, 0.002017},{1.584531, 0.519969, 0.000000}}],
    Polygon[{{1.581031, 0.521928, 0.002017},{1.581308, 0.522310, 0.003984},{
      1.584726, 0.520569, 0.003984},{1.584580, 0.520119, 0.002017}}],
    Polygon[{{1.581308, 0.522310, 0.003984},{1.581763, 0.522936, 0.005853},{
      1.584965, 0.521305, 0.005853},{1.584726, 0.520569, 0.003984}}],
    Polygon[{{1.581763, 0.522936, 0.005853},{1.582384, 0.523792, 0.007578},{
      1.585292, 0.522310, 0.007578},{1.584965, 0.521305, 0.005853}}],
    Polygon[{{1.582384, 0.523792, 0.007578},{1.583157, 0.524854, 0.009116},{
      1.585698, 0.523560, 0.009116},{1.585292, 0.522310, 0.007578}}],
    Polygon[{{1.583157, 0.524854, 0.009116},{1.584061, 0.526099, 0.010430},{
      1.586173, 0.525023, 0.010430},{1.585698, 0.523560, 0.009116}}],
    Polygon[{{1.584061, 0.526099, 0.010430},{1.585075, 0.527494, 0.011487},{
      1.586706, 0.526663, 0.011487},{1.586173, 0.525023, 0.010430}}],
    Polygon[{{1.585075, 0.527494, 0.011487},{1.586173, 0.529006, 0.012261},{
      1.587284, 0.528440, 0.012261},{1.586706, 0.526663, 0.011487}}],
    Polygon[{{1.586173, 0.529006, 0.012261},{1.587329, 0.530598, 0.012733},{
      1.587892, 0.530311, 0.012733},{1.587284, 0.528440, 0.012261}}],
    Polygon[{{1.587892, 0.530311, -0.012733},{1.587284, 0.528440, -0.012261},{
      1.588515, 0.528246, -0.012261},{1.588515, 0.530213, -0.012733}}],
    Polygon[{{1.587284, 0.528440, -0.012261},{1.586706, 0.526663, -0.011487},{
      1.588515, 0.526377, -0.011487},{1.588515, 0.528246, -0.012261}}],
    Polygon[{{1.586706, 0.526663, -0.011487},{1.586173, 0.525023, -0.010430},{
      1.588515, 0.524652, -0.010430},{1.588515, 0.526377, -0.011487}}],
    Polygon[{{1.586173, 0.525023, -0.010430},{1.585698, 0.523560, -0.009116},{
      1.588515, 0.523113, -0.009116},{1.588515, 0.524652, -0.010430}}],
    Polygon[{{1.585698, 0.523560, -0.009116},{1.585292, 0.522310, -0.007578},{
      1.588515, 0.521800, -0.007578},{1.588515, 0.523113, -0.009116}}],
    Polygon[{{1.585292, 0.522310, -0.007578},{1.584965, 0.521305, -0.005853},{
      1.588515, 0.520743, -0.005853},{1.588515, 0.521800, -0.007578}}],
    Polygon[{{1.584965, 0.521305, -0.005853},{1.584726, 0.520569, -0.003984},{
      1.588515, 0.519969, -0.003984},{1.588515, 0.520743, -0.005853}}],
    Polygon[{{1.584726, 0.520569, -0.003984},{1.584580, 0.520119, -0.002017},{
      1.588515, 0.519496, -0.002017},{1.588515, 0.519969, -0.003984}}],
    Polygon[{{1.584580, 0.520119, -0.002017},{1.584531, 0.519969, 0.000000},{
      1.588515, 0.519338, 0.000000},{1.588515, 0.519496, -0.002017}}],
    Polygon[{{1.584531, 0.519969, 0.000000},{1.584580, 0.520119, 0.002017},{
      1.588515, 0.519496, 0.002017},{1.588515, 0.519338, 0.000000}}],
    Polygon[{{1.584580, 0.520119, 0.002017},{1.584726, 0.520569, 0.003984},{
      1.588515, 0.519969, 0.003984},{1.588515, 0.519496, 0.002017}}],
    Polygon[{{1.584726, 0.520569, 0.003984},{1.584965, 0.521305, 0.005853},{
      1.588515, 0.520743, 0.005853},{1.588515, 0.519969, 0.003984}}],
    Polygon[{{1.584965, 0.521305, 0.005853},{1.585292, 0.522310, 0.007578},{
      1.588515, 0.521800, 0.007578},{1.588515, 0.520743, 0.005853}}],
    Polygon[{{1.585292, 0.522310, 0.007578},{1.585698, 0.523560, 0.009116},{
      1.588515, 0.523113, 0.009116},{1.588515, 0.521800, 0.007578}}],
    Polygon[{{1.585698, 0.523560, 0.009116},{1.586173, 0.525023, 0.010430},{
      1.588515, 0.524652, 0.010430},{1.588515, 0.523113, 0.009116}}],
    Polygon[{{1.586173, 0.525023, 0.010430},{1.586706, 0.526663, 0.011487},{
      1.588515, 0.526377, 0.011487},{1.588515, 0.524652, 0.010430}}],
    Polygon[{{1.586706, 0.526663, 0.011487},{1.587284, 0.528440, 0.012261},{
      1.588515, 0.528246, 0.012261},{1.588515, 0.526377, 0.011487}}],
    Polygon[{{1.587284, 0.528440, 0.012261},{1.587892, 0.530311, 0.012733},{
      1.588515, 0.530213, 0.012733},{1.588515, 0.528246, 0.012261}}],
    Polygon[{{1.588515, 0.530213, -0.012733},{1.588515, 0.528246, -0.012261},{
      1.589746, 0.528440, -0.012261},{1.589138, 0.530311, -0.012733}}],
    Polygon[{{1.588515, 0.528246, -0.012261},{1.588515, 0.526377, -0.011487},{
      1.590323, 0.526663, -0.011487},{1.589746, 0.528440, -0.012261}}],
    Polygon[{{1.588515, 0.526377, -0.011487},{1.588515, 0.524652, -0.010430},{
      1.590856, 0.525023, -0.010430},{1.590323, 0.526663, -0.011487}}],
    Polygon[{{1.588515, 0.524652, -0.010430},{1.588515, 0.523113, -0.009116},{
      1.591332, 0.523560, -0.009116},{1.590856, 0.525023, -0.010430}}],
    Polygon[{{1.588515, 0.523113, -0.009116},{1.588515, 0.521800, -0.007578},{
      1.591738, 0.522310, -0.007578},{1.591332, 0.523560, -0.009116}}],
    Polygon[{{1.588515, 0.521800, -0.007578},{1.588515, 0.520743, -0.005853},{
      1.592064, 0.521305, -0.005853},{1.591738, 0.522310, -0.007578}}],
    Polygon[{{1.588515, 0.520743, -0.005853},{1.588515, 0.519969, -0.003984},{
      1.592304, 0.520569, -0.003984},{1.592064, 0.521305, -0.005853}}],
    Polygon[{{1.588515, 0.519969, -0.003984},{1.588515, 0.519496, -0.002017},{
      1.592450, 0.520119, -0.002017},{1.592304, 0.520569, -0.003984}}],
    Polygon[{{1.588515, 0.519496, -0.002017},{1.588515, 0.519338, 0.000000},{
      1.592499, 0.519969, 0.000000},{1.592450, 0.520119, -0.002017}}],
    Polygon[{{1.588515, 0.519338, 0.000000},{1.588515, 0.519496, 0.002017},{
      1.592450, 0.520119, 0.002017},{1.592499, 0.519969, 0.000000}}],
    Polygon[{{1.588515, 0.519496, 0.002017},{1.588515, 0.519969, 0.003984},{
      1.592304, 0.520569, 0.003984},{1.592450, 0.520119, 0.002017}}],
    Polygon[{{1.588515, 0.519969, 0.003984},{1.588515, 0.520743, 0.005853},{
      1.592064, 0.521305, 0.005853},{1.592304, 0.520569, 0.003984}}],
    Polygon[{{1.588515, 0.520743, 0.005853},{1.588515, 0.521800, 0.007578},{
      1.591738, 0.522310, 0.007578},{1.592064, 0.521305, 0.005853}}],
    Polygon[{{1.588515, 0.521800, 0.007578},{1.588515, 0.523113, 0.009116},{
      1.591332, 0.523560, 0.009116},{1.591738, 0.522310, 0.007578}}],
    Polygon[{{1.588515, 0.523113, 0.009116},{1.588515, 0.524652, 0.010430},{
      1.590856, 0.525023, 0.010430},{1.591332, 0.523560, 0.009116}}],
    Polygon[{{1.588515, 0.524652, 0.010430},{1.588515, 0.526377, 0.011487},{
      1.590323, 0.526663, 0.011487},{1.590856, 0.525023, 0.010430}}],
    Polygon[{{1.588515, 0.526377, 0.011487},{1.588515, 0.528246, 0.012261},{
      1.589746, 0.528440, 0.012261},{1.590323, 0.526663, 0.011487}}],
    Polygon[{{1.588515, 0.528246, 0.012261},{1.588515, 0.530213, 0.012733},{
      1.589138, 0.530311, 0.012733},{1.589746, 0.528440, 0.012261}}],
    Polygon[{{1.589138, 0.530311, -0.012733},{1.589746, 0.528440, -0.012261},{
      1.590856, 0.529006, -0.012261},{1.589700, 0.530598, -0.012733}}],
    Polygon[{{1.589746, 0.528440, -0.012261},{1.590323, 0.526663, -0.011487},{
      1.591955, 0.527494, -0.011487},{1.590856, 0.529006, -0.012261}}],
    Polygon[{{1.590323, 0.526663, -0.011487},{1.590856, 0.525023, -0.010430},{
      1.592969, 0.526099, -0.010430},{1.591955, 0.527494, -0.011487}}],
    Polygon[{{1.590856, 0.525023, -0.010430},{1.591332, 0.523560, -0.009116},{
      1.593873, 0.524854, -0.009116},{1.592969, 0.526099, -0.010430}}],
    Polygon[{{1.591332, 0.523560, -0.009116},{1.591738, 0.522310, -0.007578},{
      1.594645, 0.523792, -0.007578},{1.593873, 0.524854, -0.009116}}],
    Polygon[{{1.591738, 0.522310, -0.007578},{1.592064, 0.521305, -0.005853},{
      1.595266, 0.522936, -0.005853},{1.594645, 0.523792, -0.007578}}],
    Polygon[{{1.592064, 0.521305, -0.005853},{1.592304, 0.520569, -0.003984},{
      1.595721, 0.522310, -0.003984},{1.595266, 0.522936, -0.005853}}],
    Polygon[{{1.592304, 0.520569, -0.003984},{1.592450, 0.520119, -0.002017},{
      1.595999, 0.521928, -0.002017},{1.595721, 0.522310, -0.003984}}],
    Polygon[{{1.592450, 0.520119, -0.002017},{1.592499, 0.519969, 0.000000},{
      1.596092, 0.521800, 0.000000},{1.595999, 0.521928, -0.002017}}],
    Polygon[{{1.592499, 0.519969, 0.000000},{1.592450, 0.520119, 0.002017},{
      1.595999, 0.521928, 0.002017},{1.596092, 0.521800, 0.000000}}],
    Polygon[{{1.592450, 0.520119, 0.002017},{1.592304, 0.520569, 0.003984},{
      1.595721, 0.522310, 0.003984},{1.595999, 0.521928, 0.002017}}],
    Polygon[{{1.592304, 0.520569, 0.003984},{1.592064, 0.521305, 0.005853},{
      1.595266, 0.522936, 0.005853},{1.595721, 0.522310, 0.003984}}],
    Polygon[{{1.592064, 0.521305, 0.005853},{1.591738, 0.522310, 0.007578},{
      1.594645, 0.523792, 0.007578},{1.595266, 0.522936, 0.005853}}],
    Polygon[{{1.591738, 0.522310, 0.007578},{1.591332, 0.523560, 0.009116},{
      1.593873, 0.524854, 0.009116},{1.594645, 0.523792, 0.007578}}],
    Polygon[{{1.591332, 0.523560, 0.009116},{1.590856, 0.525023, 0.010430},{
      1.592969, 0.526099, 0.010430},{1.593873, 0.524854, 0.009116}}],
    Polygon[{{1.590856, 0.525023, 0.010430},{1.590323, 0.526663, 0.011487},{
      1.591955, 0.527494, 0.011487},{1.592969, 0.526099, 0.010430}}],
    Polygon[{{1.590323, 0.526663, 0.011487},{1.589746, 0.528440, 0.012261},{
      1.590856, 0.529006, 0.012261},{1.591955, 0.527494, 0.011487}}],
    Polygon[{{1.589746, 0.528440, 0.012261},{1.589138, 0.530311, 0.012733},{
      1.589700, 0.530598, 0.012733},{1.590856, 0.529006, 0.012261}}],
    Polygon[{{1.589700, 0.530598, -0.012733},{1.590856, 0.529006, -0.012261},{
      1.591738, 0.529888, -0.012261},{1.590146, 0.531044, -0.012733}}],
    Polygon[{{1.590856, 0.529006, -0.012261},{1.591955, 0.527494, -0.011487},{
      1.593250, 0.528789, -0.011487},{1.591738, 0.529888, -0.012261}}],
    Polygon[{{1.591955, 0.527494, -0.011487},{1.592969, 0.526099, -0.010430},{
      1.594645, 0.527775, -0.010430},{1.593250, 0.528789, -0.011487}}],
    Polygon[{{1.592969, 0.526099, -0.010430},{1.593873, 0.524854, -0.009116},{
      1.595890, 0.526871, -0.009116},{1.594645, 0.527775, -0.010430}}],
    Polygon[{{1.593873, 0.524854, -0.009116},{1.594645, 0.523792, -0.007578},{
      1.596953, 0.526099, -0.007578},{1.595890, 0.526871, -0.009116}}],
    Polygon[{{1.594645, 0.523792, -0.007578},{1.595266, 0.522936, -0.005853},{
      1.597808, 0.525478, -0.005853},{1.596953, 0.526099, -0.007578}}],
    Polygon[{{1.595266, 0.522936, -0.005853},{1.595721, 0.522310, -0.003984},{
      1.598434, 0.525023, -0.003984},{1.597808, 0.525478, -0.005853}}],
    Polygon[{{1.595721, 0.522310, -0.003984},{1.595999, 0.521928, -0.002017},{
      1.598816, 0.524745, -0.002017},{1.598434, 0.525023, -0.003984}}],
    Polygon[{{1.595999, 0.521928, -0.002017},{1.596092, 0.521800, 0.000000},{
      1.598944, 0.524652, 0.000000},{1.598816, 0.524745, -0.002017}}],
    Polygon[{{1.596092, 0.521800, 0.000000},{1.595999, 0.521928, 0.002017},{
      1.598816, 0.524745, 0.002017},{1.598944, 0.524652, 0.000000}}],
    Polygon[{{1.595999, 0.521928, 0.002017},{1.595721, 0.522310, 0.003984},{
      1.598434, 0.525023, 0.003984},{1.598816, 0.524745, 0.002017}}],
    Polygon[{{1.595721, 0.522310, 0.003984},{1.595266, 0.522936, 0.005853},{
      1.597808, 0.525478, 0.005853},{1.598434, 0.525023, 0.003984}}],
    Polygon[{{1.595266, 0.522936, 0.005853},{1.594645, 0.523792, 0.007578},{
      1.596953, 0.526099, 0.007578},{1.597808, 0.525478, 0.005853}}],
    Polygon[{{1.594645, 0.523792, 0.007578},{1.593873, 0.524854, 0.009116},{
      1.595890, 0.526871, 0.009116},{1.596953, 0.526099, 0.007578}}],
    Polygon[{{1.593873, 0.524854, 0.009116},{1.592969, 0.526099, 0.010430},{
      1.594645, 0.527775, 0.010430},{1.595890, 0.526871, 0.009116}}],
    Polygon[{{1.592969, 0.526099, 0.010430},{1.591955, 0.527494, 0.011487},{
      1.593250, 0.528789, 0.011487},{1.594645, 0.527775, 0.010430}}],
    Polygon[{{1.591955, 0.527494, 0.011487},{1.590856, 0.529006, 0.012261},{
      1.591738, 0.529888, 0.012261},{1.593250, 0.528789, 0.011487}}],
    Polygon[{{1.590856, 0.529006, 0.012261},{1.589700, 0.530598, 0.012733},{
      1.590146, 0.531044, 0.012733},{1.591738, 0.529888, 0.012261}}],
    Polygon[{{1.590146, 0.531044, -0.012733},{1.591738, 0.529888, -0.012261},{
      1.592304, 0.530998, -0.012261},{1.590433, 0.531606, -0.012733}}],
    Polygon[{{1.591738, 0.529888, -0.012261},{1.593250, 0.528789, -0.011487},{
      1.594081, 0.530421, -0.011487},{1.592304, 0.530998, -0.012261}}],
    Polygon[{{1.593250, 0.528789, -0.011487},{1.594645, 0.527775, -0.010430},{
      1.595721, 0.529888, -0.010430},{1.594081, 0.530421, -0.011487}}],
    Polygon[{{1.594645, 0.527775, -0.010430},{1.595890, 0.526871, -0.009116},{
      1.597184, 0.529412, -0.009116},{1.595721, 0.529888, -0.010430}}],
    Polygon[{{1.595890, 0.526871, -0.009116},{1.596953, 0.526099, -0.007578},{
      1.598434, 0.529006, -0.007578},{1.597184, 0.529412, -0.009116}}],
    Polygon[{{1.596953, 0.526099, -0.007578},{1.597808, 0.525478, -0.005853},{
      1.599439, 0.528680, -0.005853},{1.598434, 0.529006, -0.007578}}],
    Polygon[{{1.597808, 0.525478, -0.005853},{1.598434, 0.525023, -0.003984},{
      1.600175, 0.528440, -0.003984},{1.599439, 0.528680, -0.005853}}],
    Polygon[{{1.598434, 0.525023, -0.003984},{1.598816, 0.524745, -0.002017},{
      1.600625, 0.528295, -0.002017},{1.600175, 0.528440, -0.003984}}],
    Polygon[{{1.598816, 0.524745, -0.002017},{1.598944, 0.524652, 0.000000},{
      1.600776, 0.528246, 0.000000},{1.600625, 0.528295, -0.002017}}],
    Polygon[{{1.598944, 0.524652, 0.000000},{1.598816, 0.524745, 0.002017},{
      1.600625, 0.528295, 0.002017},{1.600776, 0.528246, 0.000000}}],
    Polygon[{{1.598816, 0.524745, 0.002017},{1.598434, 0.525023, 0.003984},{
      1.600175, 0.528440, 0.003984},{1.600625, 0.528295, 0.002017}}],
    Polygon[{{1.598434, 0.525023, 0.003984},{1.597808, 0.525478, 0.005853},{
      1.599439, 0.528680, 0.005853},{1.600175, 0.528440, 0.003984}}],
    Polygon[{{1.597808, 0.525478, 0.005853},{1.596953, 0.526099, 0.007578},{
      1.598434, 0.529006, 0.007578},{1.599439, 0.528680, 0.005853}}],
    Polygon[{{1.596953, 0.526099, 0.007578},{1.595890, 0.526871, 0.009116},{
      1.597184, 0.529412, 0.009116},{1.598434, 0.529006, 0.007578}}],
    Polygon[{{1.595890, 0.526871, 0.009116},{1.594645, 0.527775, 0.010430},{
      1.595721, 0.529888, 0.010430},{1.597184, 0.529412, 0.009116}}],
    Polygon[{{1.594645, 0.527775, 0.010430},{1.593250, 0.528789, 0.011487},{
      1.594081, 0.530421, 0.011487},{1.595721, 0.529888, 0.010430}}],
    Polygon[{{1.593250, 0.528789, 0.011487},{1.591738, 0.529888, 0.012261},{
      1.592304, 0.530998, 0.012261},{1.594081, 0.530421, 0.011487}}],
    Polygon[{{1.591738, 0.529888, 0.012261},{1.590146, 0.531044, 0.012733},{
      1.590433, 0.531606, 0.012733},{1.592304, 0.530998, 0.012261}}],
    Polygon[{{1.590433, 0.531606, -0.012733},{1.592304, 0.530998, -0.012261},{
      1.592499, 0.532229, -0.012261},{1.590531, 0.532229, -0.012733}}],
    Polygon[{{1.592304, 0.530998, -0.012261},{1.594081, 0.530421, -0.011487},{
      1.594368, 0.532229, -0.011487},{1.592499, 0.532229, -0.012261}}],
    Polygon[{{1.594081, 0.530421, -0.011487},{1.595721, 0.529888, -0.010430},{
      1.596092, 0.532229, -0.010430},{1.594368, 0.532229, -0.011487}}],
    Polygon[{{1.595721, 0.529888, -0.010430},{1.597184, 0.529412, -0.009116},{
      1.597631, 0.532229, -0.009116},{1.596092, 0.532229, -0.010430}}],
    Polygon[{{1.597184, 0.529412, -0.009116},{1.598434, 0.529006, -0.007578},{
      1.598944, 0.532229, -0.007578},{1.597631, 0.532229, -0.009116}}],
    Polygon[{{1.598434, 0.529006, -0.007578},{1.599439, 0.528680, -0.005853},{
      1.600001, 0.532229, -0.005853},{1.598944, 0.532229, -0.007578}}],
    Polygon[{{1.599439, 0.528680, -0.005853},{1.600175, 0.528440, -0.003984},{
      1.600776, 0.532229, -0.003984},{1.600001, 0.532229, -0.005853}}],
    Polygon[{{1.600175, 0.528440, -0.003984},{1.600625, 0.528295, -0.002017},{
      1.601248, 0.532229, -0.002017},{1.600776, 0.532229, -0.003984}}],
    Polygon[{{1.600625, 0.528295, -0.002017},{1.600776, 0.528246, 0.000000},{
      1.601407, 0.532229, 0.000000},{1.601248, 0.532229, -0.002017}}],
    Polygon[{{1.600776, 0.528246, 0.000000},{1.600625, 0.528295, 0.002017},{
      1.601248, 0.532229, 0.002017},{1.601407, 0.532229, 0.000000}}],
    Polygon[{{1.600625, 0.528295, 0.002017},{1.600175, 0.528440, 0.003984},{
      1.600776, 0.532229, 0.003984},{1.601248, 0.532229, 0.002017}}],
    Polygon[{{1.600175, 0.528440, 0.003984},{1.599439, 0.528680, 0.005853},{
      1.600001, 0.532229, 0.005853},{1.600776, 0.532229, 0.003984}}],
    Polygon[{{1.599439, 0.528680, 0.005853},{1.598434, 0.529006, 0.007578},{
      1.598944, 0.532229, 0.007578},{1.600001, 0.532229, 0.005853}}],
    Polygon[{{1.598434, 0.529006, 0.007578},{1.597184, 0.529412, 0.009116},{
      1.597631, 0.532229, 0.009116},{1.598944, 0.532229, 0.007578}}],
    Polygon[{{1.597184, 0.529412, 0.009116},{1.595721, 0.529888, 0.010430},{
      1.596092, 0.532229, 0.010430},{1.597631, 0.532229, 0.009116}}],
    Polygon[{{1.595721, 0.529888, 0.010430},{1.594081, 0.530421, 0.011487},{
      1.594368, 0.532229, 0.011487},{1.596092, 0.532229, 0.010430}}],
    Polygon[{{1.594081, 0.530421, 0.011487},{1.592304, 0.530998, 0.012261},{
      1.592499, 0.532229, 0.012261},{1.594368, 0.532229, 0.011487}}],
    Polygon[{{1.592304, 0.530998, 0.012261},{1.590433, 0.531606, 0.012733},{
      1.590531, 0.532229, 0.012733},{1.592499, 0.532229, 0.012261}}],
    Polygon[{{1.738106, 0.403521, -0.028615},{1.742526, 0.403521, -0.027554},{
      1.742088, 0.406288, -0.027554},{1.737884, 0.404922, -0.028615}}],
    Polygon[{{1.742526, 0.403521, -0.027554},{1.746726, 0.403521, -0.025814},{
      1.746083, 0.407586, -0.025814},{1.742088, 0.406288, -0.027554}}],
    Polygon[{{1.746726, 0.403521, -0.025814},{1.750603, 0.403521, -0.023438},{
      1.749769, 0.408783, -0.023438},{1.746083, 0.407586, -0.025814}}],
    Polygon[{{1.750603, 0.403521, -0.023438},{1.754059, 0.403521, -0.020486},{
      1.753057, 0.409852, -0.020486},{1.749769, 0.408783, -0.023438}}],
    Polygon[{{1.754059, 0.403521, -0.020486},{1.757012, 0.403521, -0.017029},{
      1.755865, 0.410764, -0.017029},{1.753057, 0.409852, -0.020486}}],
    Polygon[{{1.757012, 0.403521, -0.017029},{1.759387, 0.403521, -0.013153},{
      1.758124, 0.411498, -0.013153},{1.755865, 0.410764, -0.017029}}],
    Polygon[{{1.759387, 0.403521, -0.013153},{1.761127, 0.403521, -0.008953},{
      1.759778, 0.412036, -0.008953},{1.758124, 0.411498, -0.013153}}],
    Polygon[{{1.761127, 0.403521, -0.008953},{1.762188, 0.403521, -0.004532},{
      1.760788, 0.412364, -0.004532},{1.759778, 0.412036, -0.008953}}],
    Polygon[{{1.762188, 0.403521, -0.004532},{1.762545, 0.403521, 0.000000},{
      1.761127, 0.412474, 0.000000},{1.760788, 0.412364, -0.004532}}],
    Polygon[{{1.762545, 0.403521, 0.000000},{1.762188, 0.403521, 0.004532},{
      1.760788, 0.412364, 0.004532},{1.761127, 0.412474, 0.000000}}],
    Polygon[{{1.762188, 0.403521, 0.004532},{1.761127, 0.403521, 0.008953},{
      1.759778, 0.412036, 0.008953},{1.760788, 0.412364, 0.004532}}],
    Polygon[{{1.761127, 0.403521, 0.008953},{1.759387, 0.403521, 0.013153},{
      1.758124, 0.411498, 0.013153},{1.759778, 0.412036, 0.008953}}],
    Polygon[{{1.759387, 0.403521, 0.013153},{1.757012, 0.403521, 0.017029},{
      1.755865, 0.410764, 0.017029},{1.758124, 0.411498, 0.013153}}],
    Polygon[{{1.757012, 0.403521, 0.017029},{1.754059, 0.403521, 0.020486},{
      1.753057, 0.409852, 0.020486},{1.755865, 0.410764, 0.017029}}],
    Polygon[{{1.754059, 0.403521, 0.020486},{1.750603, 0.403521, 0.023438},{
      1.749769, 0.408783, 0.023438},{1.753057, 0.409852, 0.020486}}],
    Polygon[{{1.750603, 0.403521, 0.023438},{1.746726, 0.403521, 0.025814},{
      1.746083, 0.407586, 0.025814},{1.749769, 0.408783, 0.023438}}],
    Polygon[{{1.746726, 0.403521, 0.025814},{1.742526, 0.403521, 0.027554},{
      1.742088, 0.406288, 0.027554},{1.746083, 0.407586, 0.025814}}],
    Polygon[{{1.742526, 0.403521, 0.027554},{1.738106, 0.403521, 0.028615},{
      1.737884, 0.404922, 0.028615},{1.742088, 0.406288, 0.027554}}],
    Polygon[{{1.737884, 0.404922, -0.028615},{1.742088, 0.406288, -0.027554},{
      1.740816, 0.408783, -0.027554},{1.737240, 0.406185, -0.028615}}],
    Polygon[{{1.742088, 0.406288, -0.027554},{1.746083, 0.407586, -0.025814},{
      1.744214, 0.411252, -0.025814},{1.740816, 0.408783, -0.027554}}],
    Polygon[{{1.746083, 0.407586, -0.025814},{1.749769, 0.408783, -0.023438},{
      1.747350, 0.413531, -0.023438},{1.744214, 0.411252, -0.025814}}],
    Polygon[{{1.749769, 0.408783, -0.023438},{1.753057, 0.409852, -0.020486},{
      1.750147, 0.415563, -0.020486},{1.747350, 0.413531, -0.023438}}],
    Polygon[{{1.753057, 0.409852, -0.020486},{1.755865, 0.410764, -0.017029},{
      1.752536, 0.417298, -0.017029},{1.750147, 0.415563, -0.020486}}],
    Polygon[{{1.755865, 0.410764, -0.017029},{1.758124, 0.411498, -0.013153},{
      1.754457, 0.418694, -0.013153},{1.752536, 0.417298, -0.017029}}],
    Polygon[{{1.758124, 0.411498, -0.013153},{1.759778, 0.412036, -0.008953},{
      1.755865, 0.419717, -0.008953},{1.754457, 0.418694, -0.013153}}],
    Polygon[{{1.759778, 0.412036, -0.008953},{1.760788, 0.412364, -0.004532},{
      1.756723, 0.420341, -0.004532},{1.755865, 0.419717, -0.008953}}],
    Polygon[{{1.760788, 0.412364, -0.004532},{1.761127, 0.412474, 0.000000},{
      1.757012, 0.420550, 0.000000},{1.756723, 0.420341, -0.004532}}],
    Polygon[{{1.761127, 0.412474, 0.000000},{1.760788, 0.412364, 0.004532},{
      1.756723, 0.420341, 0.004532},{1.757012, 0.420550, 0.000000}}],
    Polygon[{{1.760788, 0.412364, 0.004532},{1.759778, 0.412036, 0.008953},{
      1.755865, 0.419717, 0.008953},{1.756723, 0.420341, 0.004532}}],
    Polygon[{{1.759778, 0.412036, 0.008953},{1.758124, 0.411498, 0.013153},{
      1.754457, 0.418694, 0.013153},{1.755865, 0.419717, 0.008953}}],
    Polygon[{{1.758124, 0.411498, 0.013153},{1.755865, 0.410764, 0.017029},{
      1.752536, 0.417298, 0.017029},{1.754457, 0.418694, 0.013153}}],
    Polygon[{{1.755865, 0.410764, 0.017029},{1.753057, 0.409852, 0.020486},{
      1.750147, 0.415563, 0.020486},{1.752536, 0.417298, 0.017029}}],
    Polygon[{{1.753057, 0.409852, 0.020486},{1.749769, 0.408783, 0.023438},{
      1.747350, 0.413531, 0.023438},{1.750147, 0.415563, 0.020486}}],
    Polygon[{{1.749769, 0.408783, 0.023438},{1.746083, 0.407586, 0.025814},{
      1.744214, 0.411252, 0.025814},{1.747350, 0.413531, 0.023438}}],
    Polygon[{{1.746083, 0.407586, 0.025814},{1.742088, 0.406288, 0.027554},{
      1.740816, 0.408783, 0.027554},{1.744214, 0.411252, 0.025814}}],
    Polygon[{{1.742088, 0.406288, 0.027554},{1.737884, 0.404922, 0.028615},{
      1.737240, 0.406185, 0.028615},{1.740816, 0.408783, 0.027554}}],
    Polygon[{{1.737240, 0.406185, -0.028615},{1.740816, 0.408783, -0.027554},{
      1.738836, 0.410764, -0.027554},{1.736237, 0.407188, -0.028615}}],
    Polygon[{{1.740816, 0.408783, -0.027554},{1.744214, 0.411252, -0.025814},{
      1.741305, 0.414162, -0.025814},{1.738836, 0.410764, -0.027554}}],
    Polygon[{{1.744214, 0.411252, -0.025814},{1.747350, 0.413531, -0.023438},{
      1.743583, 0.417298, -0.023438},{1.741305, 0.414162, -0.025814}}],
    Polygon[{{1.747350, 0.413531, -0.023438},{1.750147, 0.415563, -0.020486},{
      1.745615, 0.420095, -0.020486},{1.743583, 0.417298, -0.023438}}],
    Polygon[{{1.750147, 0.415563, -0.020486},{1.752536, 0.417298, -0.017029},{
      1.747350, 0.422483, -0.017029},{1.745615, 0.420095, -0.020486}}],
    Polygon[{{1.752536, 0.417298, -0.017029},{1.754457, 0.418694, -0.013153},{
      1.748747, 0.424405, -0.013153},{1.747350, 0.422483, -0.017029}}],
    Polygon[{{1.754457, 0.418694, -0.013153},{1.755865, 0.419717, -0.008953},{
      1.749769, 0.425812, -0.008953},{1.748747, 0.424405, -0.013153}}],
    Polygon[{{1.755865, 0.419717, -0.008953},{1.756723, 0.420341, -0.004532},{
      1.750393, 0.426671, -0.004532},{1.749769, 0.425812, -0.008953}}],
    Polygon[{{1.756723, 0.420341, -0.004532},{1.757012, 0.420550, 0.000000},{
      1.750603, 0.426960, 0.000000},{1.750393, 0.426671, -0.004532}}],
    Polygon[{{1.757012, 0.420550, 0.000000},{1.756723, 0.420341, 0.004532},{
      1.750393, 0.426671, 0.004532},{1.750603, 0.426960, 0.000000}}],
    Polygon[{{1.756723, 0.420341, 0.004532},{1.755865, 0.419717, 0.008953},{
      1.749769, 0.425812, 0.008953},{1.750393, 0.426671, 0.004532}}],
    Polygon[{{1.755865, 0.419717, 0.008953},{1.754457, 0.418694, 0.013153},{
      1.748747, 0.424405, 0.013153},{1.749769, 0.425812, 0.008953}}],
    Polygon[{{1.754457, 0.418694, 0.013153},{1.752536, 0.417298, 0.017029},{
      1.747350, 0.422483, 0.017029},{1.748747, 0.424405, 0.013153}}],
    Polygon[{{1.752536, 0.417298, 0.017029},{1.750147, 0.415563, 0.020486},{
      1.745615, 0.420095, 0.020486},{1.747350, 0.422483, 0.017029}}],
    Polygon[{{1.750147, 0.415563, 0.020486},{1.747350, 0.413531, 0.023438},{
      1.743583, 0.417298, 0.023438},{1.745615, 0.420095, 0.020486}}],
    Polygon[{{1.747350, 0.413531, 0.023438},{1.744214, 0.411252, 0.025814},{
      1.741305, 0.414162, 0.025814},{1.743583, 0.417298, 0.023438}}],
    Polygon[{{1.744214, 0.411252, 0.025814},{1.740816, 0.408783, 0.027554},{
      1.738836, 0.410764, 0.027554},{1.741305, 0.414162, 0.025814}}],
    Polygon[{{1.740816, 0.408783, 0.027554},{1.737240, 0.406185, 0.028615},{
      1.736237, 0.407188, 0.028615},{1.738836, 0.410764, 0.027554}}],
    Polygon[{{1.736237, 0.407188, -0.028615},{1.738836, 0.410764, -0.027554},{
      1.736340, 0.412036, -0.027554},{1.734974, 0.407831, -0.028615}}],
    Polygon[{{1.738836, 0.410764, -0.027554},{1.741305, 0.414162, -0.025814},{
      1.737638, 0.416030, -0.025814},{1.736340, 0.412036, -0.027554}}],
    Polygon[{{1.741305, 0.414162, -0.025814},{1.743583, 0.417298, -0.023438},{
      1.738836, 0.419717, -0.023438},{1.737638, 0.416030, -0.025814}}],
    Polygon[{{1.743583, 0.417298, -0.023438},{1.745615, 0.420095, -0.020486},{
      1.739904, 0.423004, -0.020486},{1.738836, 0.419717, -0.023438}}],
    Polygon[{{1.745615, 0.420095, -0.020486},{1.747350, 0.422483, -0.017029},{
      1.740816, 0.425812, -0.017029},{1.739904, 0.423004, -0.020486}}],
    Polygon[{{1.747350, 0.422483, -0.017029},{1.748747, 0.424405, -0.013153},{
      1.741550, 0.428072, -0.013153},{1.740816, 0.425812, -0.017029}}],
    Polygon[{{1.748747, 0.424405, -0.013153},{1.749769, 0.425812, -0.008953},{
      1.742088, 0.429726, -0.008953},{1.741550, 0.428072, -0.013153}}],
    Polygon[{{1.749769, 0.425812, -0.008953},{1.750393, 0.426671, -0.004532},{
      1.742416, 0.430735, -0.004532},{1.742088, 0.429726, -0.008953}}],
    Polygon[{{1.750393, 0.426671, -0.004532},{1.750603, 0.426960, 0.000000},{
      1.742526, 0.431075, 0.000000},{1.742416, 0.430735, -0.004532}}],
    Polygon[{{1.750603, 0.426960, 0.000000},{1.750393, 0.426671, 0.004532},{
      1.742416, 0.430735, 0.004532},{1.742526, 0.431075, 0.000000}}],
    Polygon[{{1.750393, 0.426671, 0.004532},{1.749769, 0.425812, 0.008953},{
      1.742088, 0.429726, 0.008953},{1.742416, 0.430735, 0.004532}}],
    Polygon[{{1.749769, 0.425812, 0.008953},{1.748747, 0.424405, 0.013153},{
      1.741550, 0.428072, 0.013153},{1.742088, 0.429726, 0.008953}}],
    Polygon[{{1.748747, 0.424405, 0.013153},{1.747350, 0.422483, 0.017029},{
      1.740816, 0.425812, 0.017029},{1.741550, 0.428072, 0.013153}}],
    Polygon[{{1.747350, 0.422483, 0.017029},{1.745615, 0.420095, 0.020486},{
      1.739904, 0.423004, 0.020486},{1.740816, 0.425812, 0.017029}}],
    Polygon[{{1.745615, 0.420095, 0.020486},{1.743583, 0.417298, 0.023438},{
      1.738836, 0.419717, 0.023438},{1.739904, 0.423004, 0.020486}}],
    Polygon[{{1.743583, 0.417298, 0.023438},{1.741305, 0.414162, 0.025814},{
      1.737638, 0.416030, 0.025814},{1.738836, 0.419717, 0.023438}}],
    Polygon[{{1.741305, 0.414162, 0.025814},{1.738836, 0.410764, 0.027554},{
      1.736340, 0.412036, 0.027554},{1.737638, 0.416030, 0.025814}}],
    Polygon[{{1.738836, 0.410764, 0.027554},{1.736237, 0.407188, 0.028615},{
      1.734974, 0.407831, 0.028615},{1.736340, 0.412036, 0.027554}}],
    Polygon[{{1.734974, 0.407831, -0.028615},{1.736340, 0.412036, -0.027554},{
      1.733574, 0.412474, -0.027554},{1.733574, 0.408053, -0.028615}}],
    Polygon[{{1.736340, 0.412036, -0.027554},{1.737638, 0.416030, -0.025814},{
      1.733574, 0.416674, -0.025814},{1.733574, 0.412474, -0.027554}}],
    Polygon[{{1.737638, 0.416030, -0.025814},{1.738836, 0.419717, -0.023438},{
      1.733574, 0.420550, -0.023438},{1.733574, 0.416674, -0.025814}}],
    Polygon[{{1.738836, 0.419717, -0.023438},{1.739904, 0.423004, -0.020486},{
      1.733574, 0.424007, -0.020486},{1.733574, 0.420550, -0.023438}}],
    Polygon[{{1.739904, 0.423004, -0.020486},{1.740816, 0.425812, -0.017029},{
      1.733574, 0.426960, -0.017029},{1.733574, 0.424007, -0.020486}}],
    Polygon[{{1.740816, 0.425812, -0.017029},{1.741550, 0.428072, -0.013153},{
      1.733574, 0.429335, -0.013153},{1.733574, 0.426960, -0.017029}}],
    Polygon[{{1.741550, 0.428072, -0.013153},{1.742088, 0.429726, -0.008953},{
      1.733574, 0.431075, -0.008953},{1.733574, 0.429335, -0.013153}}],
    Polygon[{{1.742088, 0.429726, -0.008953},{1.742416, 0.430735, -0.004532},{
      1.733574, 0.432136, -0.004532},{1.733574, 0.431075, -0.008953}}],
    Polygon[{{1.742416, 0.430735, -0.004532},{1.742526, 0.431075, 0.000000},{
      1.733574, 0.432493, 0.000000},{1.733574, 0.432136, -0.004532}}],
    Polygon[{{1.742526, 0.431075, 0.000000},{1.742416, 0.430735, 0.004532},{
      1.733574, 0.432136, 0.004532},{1.733574, 0.432493, 0.000000}}],
    Polygon[{{1.742416, 0.430735, 0.004532},{1.742088, 0.429726, 0.008953},{
      1.733574, 0.431075, 0.008953},{1.733574, 0.432136, 0.004532}}],
    Polygon[{{1.742088, 0.429726, 0.008953},{1.741550, 0.428072, 0.013153},{
      1.733574, 0.429335, 0.013153},{1.733574, 0.431075, 0.008953}}],
    Polygon[{{1.741550, 0.428072, 0.013153},{1.740816, 0.425812, 0.017029},{
      1.733574, 0.426960, 0.017029},{1.733574, 0.429335, 0.013153}}],
    Polygon[{{1.740816, 0.425812, 0.017029},{1.739904, 0.423004, 0.020486},{
      1.733574, 0.424007, 0.020486},{1.733574, 0.426960, 0.017029}}],
    Polygon[{{1.739904, 0.423004, 0.020486},{1.738836, 0.419717, 0.023438},{
      1.733574, 0.420550, 0.023438},{1.733574, 0.424007, 0.020486}}],
    Polygon[{{1.738836, 0.419717, 0.023438},{1.737638, 0.416030, 0.025814},{
      1.733574, 0.416674, 0.025814},{1.733574, 0.420550, 0.023438}}],
    Polygon[{{1.737638, 0.416030, 0.025814},{1.736340, 0.412036, 0.027554},{
      1.733574, 0.412474, 0.027554},{1.733574, 0.416674, 0.025814}}],
    Polygon[{{1.736340, 0.412036, 0.027554},{1.734974, 0.407831, 0.028615},{
      1.733574, 0.408053, 0.028615},{1.733574, 0.412474, 0.027554}}],
    Polygon[{{1.733574, 0.408053, -0.028615},{1.733574, 0.412474, -0.027554},{
      1.730807, 0.412036, -0.027554},{1.732173, 0.407831, -0.028615}}],
    Polygon[{{1.733574, 0.412474, -0.027554},{1.733574, 0.416674, -0.025814},{
      1.729509, 0.416030, -0.025814},{1.730807, 0.412036, -0.027554}}],
    Polygon[{{1.733574, 0.416674, -0.025814},{1.733574, 0.420550, -0.023438},{
      1.728311, 0.419717, -0.023438},{1.729509, 0.416030, -0.025814}}],
    Polygon[{{1.733574, 0.420550, -0.023438},{1.733574, 0.424007, -0.020486},{
      1.727243, 0.423004, -0.020486},{1.728311, 0.419717, -0.023438}}],
    Polygon[{{1.733574, 0.424007, -0.020486},{1.733574, 0.426960, -0.017029},{
      1.726331, 0.425812, -0.017029},{1.727243, 0.423004, -0.020486}}],
    Polygon[{{1.733574, 0.426960, -0.017029},{1.733574, 0.429335, -0.013153},{
      1.725597, 0.428072, -0.013153},{1.726331, 0.425812, -0.017029}}],
    Polygon[{{1.733574, 0.429335, -0.013153},{1.733574, 0.431075, -0.008953},{
      1.725059, 0.429726, -0.008953},{1.725597, 0.428072, -0.013153}}],
    Polygon[{{1.733574, 0.431075, -0.008953},{1.733574, 0.432136, -0.004532},{
      1.724731, 0.430735, -0.004532},{1.725059, 0.429726, -0.008953}}],
    Polygon[{{1.733574, 0.432136, -0.004532},{1.733574, 0.432493, 0.000000},{
      1.724621, 0.431075, 0.000000},{1.724731, 0.430735, -0.004532}}],
    Polygon[{{1.733574, 0.432493, 0.000000},{1.733574, 0.432136, 0.004532},{
      1.724731, 0.430735, 0.004532},{1.724621, 0.431075, 0.000000}}],
    Polygon[{{1.733574, 0.432136, 0.004532},{1.733574, 0.431075, 0.008953},{
      1.725059, 0.429726, 0.008953},{1.724731, 0.430735, 0.004532}}],
    Polygon[{{1.733574, 0.431075, 0.008953},{1.733574, 0.429335, 0.013153},{
      1.725597, 0.428072, 0.013153},{1.725059, 0.429726, 0.008953}}],
    Polygon[{{1.733574, 0.429335, 0.013153},{1.733574, 0.426960, 0.017029},{
      1.726331, 0.425812, 0.017029},{1.725597, 0.428072, 0.013153}}],
    Polygon[{{1.733574, 0.426960, 0.017029},{1.733574, 0.424007, 0.020486},{
      1.727243, 0.423004, 0.020486},{1.726331, 0.425812, 0.017029}}],
    Polygon[{{1.733574, 0.424007, 0.020486},{1.733574, 0.420550, 0.023438},{
      1.728311, 0.419717, 0.023438},{1.727243, 0.423004, 0.020486}}],
    Polygon[{{1.733574, 0.420550, 0.023438},{1.733574, 0.416674, 0.025814},{
      1.729509, 0.416030, 0.025814},{1.728311, 0.419717, 0.023438}}],
    Polygon[{{1.733574, 0.416674, 0.025814},{1.733574, 0.412474, 0.027554},{
      1.730807, 0.412036, 0.027554},{1.729509, 0.416030, 0.025814}}],
    Polygon[{{1.733574, 0.412474, 0.027554},{1.733574, 0.408053, 0.028615},{
      1.732173, 0.407831, 0.028615},{1.730807, 0.412036, 0.027554}}],
    Polygon[{{1.732173, 0.407831, -0.028615},{1.730807, 0.412036, -0.027554},{
      1.728311, 0.410764, -0.027554},{1.730910, 0.407188, -0.028615}}],
    Polygon[{{1.730807, 0.412036, -0.027554},{1.729509, 0.416030, -0.025814},{
      1.725842, 0.414162, -0.025814},{1.728311, 0.410764, -0.027554}}],
    Polygon[{{1.729509, 0.416030, -0.025814},{1.728311, 0.419717, -0.023438},{
      1.723564, 0.417298, -0.023438},{1.725842, 0.414162, -0.025814}}],
    Polygon[{{1.728311, 0.419717, -0.023438},{1.727243, 0.423004, -0.020486},{
      1.721532, 0.420095, -0.020486},{1.723564, 0.417298, -0.023438}}],
    Polygon[{{1.727243, 0.423004, -0.020486},{1.726331, 0.425812, -0.017029},{
      1.719797, 0.422483, -0.017029},{1.721532, 0.420095, -0.020486}}],
    Polygon[{{1.726331, 0.425812, -0.017029},{1.725597, 0.428072, -0.013153},{
      1.718401, 0.424405, -0.013153},{1.719797, 0.422483, -0.017029}}],
    Polygon[{{1.725597, 0.428072, -0.013153},{1.725059, 0.429726, -0.008953},{
      1.717378, 0.425812, -0.008953},{1.718401, 0.424405, -0.013153}}],
    Polygon[{{1.725059, 0.429726, -0.008953},{1.724731, 0.430735, -0.004532},{
      1.716754, 0.426671, -0.004532},{1.717378, 0.425812, -0.008953}}],
    Polygon[{{1.724731, 0.430735, -0.004532},{1.724621, 0.431075, 0.000000},{
      1.716545, 0.426960, 0.000000},{1.716754, 0.426671, -0.004532}}],
    Polygon[{{1.724621, 0.431075, 0.000000},{1.724731, 0.430735, 0.004532},{
      1.716754, 0.426671, 0.004532},{1.716545, 0.426960, 0.000000}}],
    Polygon[{{1.724731, 0.430735, 0.004532},{1.725059, 0.429726, 0.008953},{
      1.717378, 0.425812, 0.008953},{1.716754, 0.426671, 0.004532}}],
    Polygon[{{1.725059, 0.429726, 0.008953},{1.725597, 0.428072, 0.013153},{
      1.718401, 0.424405, 0.013153},{1.717378, 0.425812, 0.008953}}],
    Polygon[{{1.725597, 0.428072, 0.013153},{1.726331, 0.425812, 0.017029},{
      1.719797, 0.422483, 0.017029},{1.718401, 0.424405, 0.013153}}],
    Polygon[{{1.726331, 0.425812, 0.017029},{1.727243, 0.423004, 0.020486},{
      1.721532, 0.420095, 0.020486},{1.719797, 0.422483, 0.017029}}],
    Polygon[{{1.727243, 0.423004, 0.020486},{1.728311, 0.419717, 0.023438},{
      1.723564, 0.417298, 0.023438},{1.721532, 0.420095, 0.020486}}],
    Polygon[{{1.728311, 0.419717, 0.023438},{1.729509, 0.416030, 0.025814},{
      1.725842, 0.414162, 0.025814},{1.723564, 0.417298, 0.023438}}],
    Polygon[{{1.729509, 0.416030, 0.025814},{1.730807, 0.412036, 0.027554},{
      1.728311, 0.410764, 0.027554},{1.725842, 0.414162, 0.025814}}],
    Polygon[{{1.730807, 0.412036, 0.027554},{1.732173, 0.407831, 0.028615},{
      1.730910, 0.407188, 0.028615},{1.728311, 0.410764, 0.027554}}],
    Polygon[{{1.730910, 0.407188, -0.028615},{1.728311, 0.410764, -0.027554},{
      1.726331, 0.408783, -0.027554},{1.729907, 0.406185, -0.028615}}],
    Polygon[{{1.728311, 0.410764, -0.027554},{1.725842, 0.414162, -0.025814},{
      1.722933, 0.411252, -0.025814},{1.726331, 0.408783, -0.027554}}],
    Polygon[{{1.725842, 0.414162, -0.025814},{1.723564, 0.417298, -0.023438},{
      1.719797, 0.413531, -0.023438},{1.722933, 0.411252, -0.025814}}],
    Polygon[{{1.723564, 0.417298, -0.023438},{1.721532, 0.420095, -0.020486},{
      1.717000, 0.415563, -0.020486},{1.719797, 0.413531, -0.023438}}],
    Polygon[{{1.721532, 0.420095, -0.020486},{1.719797, 0.422483, -0.017029},{
      1.714611, 0.417298, -0.017029},{1.717000, 0.415563, -0.020486}}],
    Polygon[{{1.719797, 0.422483, -0.017029},{1.718401, 0.424405, -0.013153},{
      1.712690, 0.418694, -0.013153},{1.714611, 0.417298, -0.017029}}],
    Polygon[{{1.718401, 0.424405, -0.013153},{1.717378, 0.425812, -0.008953},{
      1.711282, 0.419717, -0.008953},{1.712690, 0.418694, -0.013153}}],
    Polygon[{{1.717378, 0.425812, -0.008953},{1.716754, 0.426671, -0.004532},{
      1.710424, 0.420341, -0.004532},{1.711282, 0.419717, -0.008953}}],
    Polygon[{{1.716754, 0.426671, -0.004532},{1.716545, 0.426960, 0.000000},{
      1.710135, 0.420550, 0.000000},{1.710424, 0.420341, -0.004532}}],
    Polygon[{{1.716545, 0.426960, 0.000000},{1.716754, 0.426671, 0.004532},{
      1.710424, 0.420341, 0.004532},{1.710135, 0.420550, 0.000000}}],
    Polygon[{{1.716754, 0.426671, 0.004532},{1.717378, 0.425812, 0.008953},{
      1.711282, 0.419717, 0.008953},{1.710424, 0.420341, 0.004532}}],
    Polygon[{{1.717378, 0.425812, 0.008953},{1.718401, 0.424405, 0.013153},{
      1.712690, 0.418694, 0.013153},{1.711282, 0.419717, 0.008953}}],
    Polygon[{{1.718401, 0.424405, 0.013153},{1.719797, 0.422483, 0.017029},{
      1.714611, 0.417298, 0.017029},{1.712690, 0.418694, 0.013153}}],
    Polygon[{{1.719797, 0.422483, 0.017029},{1.721532, 0.420095, 0.020486},{
      1.717000, 0.415563, 0.020486},{1.714611, 0.417298, 0.017029}}],
    Polygon[{{1.721532, 0.420095, 0.020486},{1.723564, 0.417298, 0.023438},{
      1.719797, 0.413531, 0.023438},{1.717000, 0.415563, 0.020486}}],
    Polygon[{{1.723564, 0.417298, 0.023438},{1.725842, 0.414162, 0.025814},{
      1.722933, 0.411252, 0.025814},{1.719797, 0.413531, 0.023438}}],
    Polygon[{{1.725842, 0.414162, 0.025814},{1.728311, 0.410764, 0.027554},{
      1.726331, 0.408783, 0.027554},{1.722933, 0.411252, 0.025814}}],
    Polygon[{{1.728311, 0.410764, 0.027554},{1.730910, 0.407188, 0.028615},{
      1.729907, 0.406185, 0.028615},{1.726331, 0.408783, 0.027554}}],
    Polygon[{{1.729907, 0.406185, -0.028615},{1.726331, 0.408783, -0.027554},{
      1.725059, 0.406288, -0.027554},{1.729263, 0.404922, -0.028615}}],
    Polygon[{{1.726331, 0.408783, -0.027554},{1.722933, 0.411252, -0.025814},{
      1.721064, 0.407586, -0.025814},{1.725059, 0.406288, -0.027554}}],
    Polygon[{{1.722933, 0.411252, -0.025814},{1.719797, 0.413531, -0.023438},{
      1.717378, 0.408783, -0.023438},{1.721064, 0.407586, -0.025814}}],
    Polygon[{{1.719797, 0.413531, -0.023438},{1.717000, 0.415563, -0.020486},{
      1.714090, 0.409852, -0.020486},{1.717378, 0.408783, -0.023438}}],
    Polygon[{{1.717000, 0.415563, -0.020486},{1.714611, 0.417298, -0.017029},{
      1.711282, 0.410764, -0.017029},{1.714090, 0.409852, -0.020486}}],
    Polygon[{{1.714611, 0.417298, -0.017029},{1.712690, 0.418694, -0.013153},{
      1.709023, 0.411498, -0.013153},{1.711282, 0.410764, -0.017029}}],
    Polygon[{{1.712690, 0.418694, -0.013153},{1.711282, 0.419717, -0.008953},{
      1.707368, 0.412036, -0.008953},{1.709023, 0.411498, -0.013153}}],
    Polygon[{{1.711282, 0.419717, -0.008953},{1.710424, 0.420341, -0.004532},{
      1.706359, 0.412364, -0.004532},{1.707368, 0.412036, -0.008953}}],
    Polygon[{{1.710424, 0.420341, -0.004532},{1.710135, 0.420550, 0.000000},{
      1.706020, 0.412474, 0.000000},{1.706359, 0.412364, -0.004532}}],
    Polygon[{{1.710135, 0.420550, 0.000000},{1.710424, 0.420341, 0.004532},{
      1.706359, 0.412364, 0.004532},{1.706020, 0.412474, 0.000000}}],
    Polygon[{{1.710424, 0.420341, 0.004532},{1.711282, 0.419717, 0.008953},{
      1.707368, 0.412036, 0.008953},{1.706359, 0.412364, 0.004532}}],
    Polygon[{{1.711282, 0.419717, 0.008953},{1.712690, 0.418694, 0.013153},{
      1.709023, 0.411498, 0.013153},{1.707368, 0.412036, 0.008953}}],
    Polygon[{{1.712690, 0.418694, 0.013153},{1.714611, 0.417298, 0.017029},{
      1.711282, 0.410764, 0.017029},{1.709023, 0.411498, 0.013153}}],
    Polygon[{{1.714611, 0.417298, 0.017029},{1.717000, 0.415563, 0.020486},{
      1.714090, 0.409852, 0.020486},{1.711282, 0.410764, 0.017029}}],
    Polygon[{{1.717000, 0.415563, 0.020486},{1.719797, 0.413531, 0.023438},{
      1.717378, 0.408783, 0.023438},{1.714090, 0.409852, 0.020486}}],
    Polygon[{{1.719797, 0.413531, 0.023438},{1.722933, 0.411252, 0.025814},{
      1.721064, 0.407586, 0.025814},{1.717378, 0.408783, 0.023438}}],
    Polygon[{{1.722933, 0.411252, 0.025814},{1.726331, 0.408783, 0.027554},{
      1.725059, 0.406288, 0.027554},{1.721064, 0.407586, 0.025814}}],
    Polygon[{{1.726331, 0.408783, 0.027554},{1.729907, 0.406185, 0.028615},{
      1.729263, 0.404922, 0.028615},{1.725059, 0.406288, 0.027554}}],
    Polygon[{{1.729263, 0.404922, -0.028615},{1.725059, 0.406288, -0.027554},{
      1.724621, 0.403521, -0.027554},{1.729041, 0.403521, -0.028615}}],
    Polygon[{{1.725059, 0.406288, -0.027554},{1.721064, 0.407586, -0.025814},{
      1.720421, 0.403521, -0.025814},{1.724621, 0.403521, -0.027554}}],
    Polygon[{{1.721064, 0.407586, -0.025814},{1.717378, 0.408783, -0.023438},{
      1.716545, 0.403521, -0.023438},{1.720421, 0.403521, -0.025814}}],
    Polygon[{{1.717378, 0.408783, -0.023438},{1.714090, 0.409852, -0.020486},{
      1.713088, 0.403521, -0.020486},{1.716545, 0.403521, -0.023438}}],
    Polygon[{{1.714090, 0.409852, -0.020486},{1.711282, 0.410764, -0.017029},{
      1.710135, 0.403521, -0.017029},{1.713088, 0.403521, -0.020486}}],
    Polygon[{{1.711282, 0.410764, -0.017029},{1.709023, 0.411498, -0.013153},{
      1.707760, 0.403521, -0.013153},{1.710135, 0.403521, -0.017029}}],
    Polygon[{{1.709023, 0.411498, -0.013153},{1.707368, 0.412036, -0.008953},{
      1.706020, 0.403521, -0.008953},{1.707760, 0.403521, -0.013153}}],
    Polygon[{{1.707368, 0.412036, -0.008953},{1.706359, 0.412364, -0.004532},{
      1.704959, 0.403521, -0.004532},{1.706020, 0.403521, -0.008953}}],
    Polygon[{{1.706359, 0.412364, -0.004532},{1.706020, 0.412474, 0.000000},{
      1.704602, 0.403521, 0.000000},{1.704959, 0.403521, -0.004532}}],
    Polygon[{{1.706020, 0.412474, 0.000000},{1.706359, 0.412364, 0.004532},{
      1.704959, 0.403521, 0.004532},{1.704602, 0.403521, 0.000000}}],
    Polygon[{{1.706359, 0.412364, 0.004532},{1.707368, 0.412036, 0.008953},{
      1.706020, 0.403521, 0.008953},{1.704959, 0.403521, 0.004532}}],
    Polygon[{{1.707368, 0.412036, 0.008953},{1.709023, 0.411498, 0.013153},{
      1.707760, 0.403521, 0.013153},{1.706020, 0.403521, 0.008953}}],
    Polygon[{{1.709023, 0.411498, 0.013153},{1.711282, 0.410764, 0.017029},{
      1.710135, 0.403521, 0.017029},{1.707760, 0.403521, 0.013153}}],
    Polygon[{{1.711282, 0.410764, 0.017029},{1.714090, 0.409852, 0.020486},{
      1.713088, 0.403521, 0.020486},{1.710135, 0.403521, 0.017029}}],
    Polygon[{{1.714090, 0.409852, 0.020486},{1.717378, 0.408783, 0.023438},{
      1.716545, 0.403521, 0.023438},{1.713088, 0.403521, 0.020486}}],
    Polygon[{{1.717378, 0.408783, 0.023438},{1.721064, 0.407586, 0.025814},{
      1.720421, 0.403521, 0.025814},{1.716545, 0.403521, 0.023438}}],
    Polygon[{{1.721064, 0.407586, 0.025814},{1.725059, 0.406288, 0.027554},{
      1.724621, 0.403521, 0.027554},{1.720421, 0.403521, 0.025814}}],
    Polygon[{{1.725059, 0.406288, 0.027554},{1.729263, 0.404922, 0.028615},{
      1.729041, 0.403521, 0.028615},{1.724621, 0.403521, 0.027554}}],
    Polygon[{{1.729041, 0.403521, -0.028615},{1.724621, 0.403521, -0.027554},{
      1.725059, 0.400755, -0.027554},{1.729263, 0.402121, -0.028615}}],
    Polygon[{{1.724621, 0.403521, -0.027554},{1.720421, 0.403521, -0.025814},{
      1.721064, 0.399457, -0.025814},{1.725059, 0.400755, -0.027554}}],
    Polygon[{{1.720421, 0.403521, -0.025814},{1.716545, 0.403521, -0.023438},{
      1.717378, 0.398259, -0.023438},{1.721064, 0.399457, -0.025814}}],
    Polygon[{{1.716545, 0.403521, -0.023438},{1.713088, 0.403521, -0.020486},{
      1.714090, 0.397191, -0.020486},{1.717378, 0.398259, -0.023438}}],
    Polygon[{{1.713088, 0.403521, -0.020486},{1.710135, 0.403521, -0.017029},{
      1.711282, 0.396278, -0.017029},{1.714090, 0.397191, -0.020486}}],
    Polygon[{{1.710135, 0.403521, -0.017029},{1.707760, 0.403521, -0.013153},{
      1.709023, 0.395544, -0.013153},{1.711282, 0.396278, -0.017029}}],
    Polygon[{{1.707760, 0.403521, -0.013153},{1.706020, 0.403521, -0.008953},{
      1.707368, 0.395007, -0.008953},{1.709023, 0.395544, -0.013153}}],
    Polygon[{{1.706020, 0.403521, -0.008953},{1.704959, 0.403521, -0.004532},{
      1.706359, 0.394679, -0.004532},{1.707368, 0.395007, -0.008953}}],
    Polygon[{{1.704959, 0.403521, -0.004532},{1.704602, 0.403521, 0.000000},{
      1.706020, 0.394568, 0.000000},{1.706359, 0.394679, -0.004532}}],
    Polygon[{{1.704602, 0.403521, 0.000000},{1.704959, 0.403521, 0.004532},{
      1.706359, 0.394679, 0.004532},{1.706020, 0.394568, 0.000000}}],
    Polygon[{{1.704959, 0.403521, 0.004532},{1.706020, 0.403521, 0.008953},{
      1.707368, 0.395007, 0.008953},{1.706359, 0.394679, 0.004532}}],
    Polygon[{{1.706020, 0.403521, 0.008953},{1.707760, 0.403521, 0.013153},{
      1.709023, 0.395544, 0.013153},{1.707368, 0.395007, 0.008953}}],
    Polygon[{{1.707760, 0.403521, 0.013153},{1.710135, 0.403521, 0.017029},{
      1.711282, 0.396278, 0.017029},{1.709023, 0.395544, 0.013153}}],
    Polygon[{{1.710135, 0.403521, 0.017029},{1.713088, 0.403521, 0.020486},{
      1.714090, 0.397191, 0.020486},{1.711282, 0.396278, 0.017029}}],
    Polygon[{{1.713088, 0.403521, 0.020486},{1.716545, 0.403521, 0.023438},{
      1.717378, 0.398259, 0.023438},{1.714090, 0.397191, 0.020486}}],
    Polygon[{{1.716545, 0.403521, 0.023438},{1.720421, 0.403521, 0.025814},{
      1.721064, 0.399457, 0.025814},{1.717378, 0.398259, 0.023438}}],
    Polygon[{{1.720421, 0.403521, 0.025814},{1.724621, 0.403521, 0.027554},{
      1.725059, 0.400755, 0.027554},{1.721064, 0.399457, 0.025814}}],
    Polygon[{{1.724621, 0.403521, 0.027554},{1.729041, 0.403521, 0.028615},{
      1.729263, 0.402121, 0.028615},{1.725059, 0.400755, 0.027554}}],
    Polygon[{{1.729263, 0.402121, -0.028615},{1.725059, 0.400755, -0.027554},{
      1.726331, 0.398259, -0.027554},{1.729907, 0.400857, -0.028615}}],
    Polygon[{{1.725059, 0.400755, -0.027554},{1.721064, 0.399457, -0.025814},{
      1.722933, 0.395790, -0.025814},{1.726331, 0.398259, -0.027554}}],
    Polygon[{{1.721064, 0.399457, -0.025814},{1.717378, 0.398259, -0.023438},{
      1.719797, 0.393512, -0.023438},{1.722933, 0.395790, -0.025814}}],
    Polygon[{{1.717378, 0.398259, -0.023438},{1.714090, 0.397191, -0.020486},{
      1.717000, 0.391480, -0.020486},{1.719797, 0.393512, -0.023438}}],
    Polygon[{{1.714090, 0.397191, -0.020486},{1.711282, 0.396278, -0.017029},{
      1.714611, 0.389744, -0.017029},{1.717000, 0.391480, -0.020486}}],
    Polygon[{{1.711282, 0.396278, -0.017029},{1.709023, 0.395544, -0.013153},{
      1.712690, 0.388348, -0.013153},{1.714611, 0.389744, -0.017029}}],
    Polygon[{{1.709023, 0.395544, -0.013153},{1.707368, 0.395007, -0.008953},{
      1.711282, 0.387326, -0.008953},{1.712690, 0.388348, -0.013153}}],
    Polygon[{{1.707368, 0.395007, -0.008953},{1.706359, 0.394679, -0.004532},{
      1.710424, 0.386702, -0.004532},{1.711282, 0.387326, -0.008953}}],
    Polygon[{{1.706359, 0.394679, -0.004532},{1.706020, 0.394568, 0.000000},{
      1.710135, 0.386492, 0.000000},{1.710424, 0.386702, -0.004532}}],
    Polygon[{{1.706020, 0.394568, 0.000000},{1.706359, 0.394679, 0.004532},{
      1.710424, 0.386702, 0.004532},{1.710135, 0.386492, 0.000000}}],
    Polygon[{{1.706359, 0.394679, 0.004532},{1.707368, 0.395007, 0.008953},{
      1.711282, 0.387326, 0.008953},{1.710424, 0.386702, 0.004532}}],
    Polygon[{{1.707368, 0.395007, 0.008953},{1.709023, 0.395544, 0.013153},{
      1.712690, 0.388348, 0.013153},{1.711282, 0.387326, 0.008953}}],
    Polygon[{{1.709023, 0.395544, 0.013153},{1.711282, 0.396278, 0.017029},{
      1.714611, 0.389744, 0.017029},{1.712690, 0.388348, 0.013153}}],
    Polygon[{{1.711282, 0.396278, 0.017029},{1.714090, 0.397191, 0.020486},{
      1.717000, 0.391480, 0.020486},{1.714611, 0.389744, 0.017029}}],
    Polygon[{{1.714090, 0.397191, 0.020486},{1.717378, 0.398259, 0.023438},{
      1.719797, 0.393512, 0.023438},{1.717000, 0.391480, 0.020486}}],
    Polygon[{{1.717378, 0.398259, 0.023438},{1.721064, 0.399457, 0.025814},{
      1.722933, 0.395790, 0.025814},{1.719797, 0.393512, 0.023438}}],
    Polygon[{{1.721064, 0.399457, 0.025814},{1.725059, 0.400755, 0.027554},{
      1.726331, 0.398259, 0.027554},{1.722933, 0.395790, 0.025814}}],
    Polygon[{{1.725059, 0.400755, 0.027554},{1.729263, 0.402121, 0.028615},{
      1.729907, 0.400857, 0.028615},{1.726331, 0.398259, 0.027554}}],
    Polygon[{{1.729907, 0.400857, -0.028615},{1.726331, 0.398259, -0.027554},{
      1.728311, 0.396278, -0.027554},{1.730910, 0.399855, -0.028615}}],
    Polygon[{{1.726331, 0.398259, -0.027554},{1.722933, 0.395790, -0.025814},{
      1.725842, 0.392880, -0.025814},{1.728311, 0.396278, -0.027554}}],
    Polygon[{{1.722933, 0.395790, -0.025814},{1.719797, 0.393512, -0.023438},{
      1.723564, 0.389744, -0.023438},{1.725842, 0.392880, -0.025814}}],
    Polygon[{{1.719797, 0.393512, -0.023438},{1.717000, 0.391480, -0.020486},{
      1.721532, 0.386948, -0.020486},{1.723564, 0.389744, -0.023438}}],
    Polygon[{{1.717000, 0.391480, -0.020486},{1.714611, 0.389744, -0.017029},{
      1.719797, 0.384559, -0.017029},{1.721532, 0.386948, -0.020486}}],
    Polygon[{{1.714611, 0.389744, -0.017029},{1.712690, 0.388348, -0.013153},{
      1.718401, 0.382637, -0.013153},{1.719797, 0.384559, -0.017029}}],
    Polygon[{{1.712690, 0.388348, -0.013153},{1.711282, 0.387326, -0.008953},{
      1.717378, 0.381230, -0.008953},{1.718401, 0.382637, -0.013153}}],
    Polygon[{{1.711282, 0.387326, -0.008953},{1.710424, 0.386702, -0.004532},{
      1.716754, 0.380371, -0.004532},{1.717378, 0.381230, -0.008953}}],
    Polygon[{{1.710424, 0.386702, -0.004532},{1.710135, 0.386492, 0.000000},{
      1.716545, 0.380083, 0.000000},{1.716754, 0.380371, -0.004532}}],
    Polygon[{{1.710135, 0.386492, 0.000000},{1.710424, 0.386702, 0.004532},{
      1.716754, 0.380371, 0.004532},{1.716545, 0.380083, 0.000000}}],
    Polygon[{{1.710424, 0.386702, 0.004532},{1.711282, 0.387326, 0.008953},{
      1.717378, 0.381230, 0.008953},{1.716754, 0.380371, 0.004532}}],
    Polygon[{{1.711282, 0.387326, 0.008953},{1.712690, 0.388348, 0.013153},{
      1.718401, 0.382637, 0.013153},{1.717378, 0.381230, 0.008953}}],
    Polygon[{{1.712690, 0.388348, 0.013153},{1.714611, 0.389744, 0.017029},{
      1.719797, 0.384559, 0.017029},{1.718401, 0.382637, 0.013153}}],
    Polygon[{{1.714611, 0.389744, 0.017029},{1.717000, 0.391480, 0.020486},{
      1.721532, 0.386948, 0.020486},{1.719797, 0.384559, 0.017029}}],
    Polygon[{{1.717000, 0.391480, 0.020486},{1.719797, 0.393512, 0.023438},{
      1.723564, 0.389744, 0.023438},{1.721532, 0.386948, 0.020486}}],
    Polygon[{{1.719797, 0.393512, 0.023438},{1.722933, 0.395790, 0.025814},{
      1.725842, 0.392880, 0.025814},{1.723564, 0.389744, 0.023438}}],
    Polygon[{{1.722933, 0.395790, 0.025814},{1.726331, 0.398259, 0.027554},{
      1.728311, 0.396278, 0.027554},{1.725842, 0.392880, 0.025814}}],
    Polygon[{{1.726331, 0.398259, 0.027554},{1.729907, 0.400857, 0.028615},{
      1.730910, 0.399855, 0.028615},{1.728311, 0.396278, 0.027554}}],
    Polygon[{{1.730910, 0.399855, -0.028615},{1.728311, 0.396278, -0.027554},{
      1.730807, 0.395007, -0.027554},{1.732173, 0.399211, -0.028615}}],
    Polygon[{{1.728311, 0.396278, -0.027554},{1.725842, 0.392880, -0.025814},{
      1.729509, 0.391012, -0.025814},{1.730807, 0.395007, -0.027554}}],
    Polygon[{{1.725842, 0.392880, -0.025814},{1.723564, 0.389744, -0.023438},{
      1.728311, 0.387326, -0.023438},{1.729509, 0.391012, -0.025814}}],
    Polygon[{{1.723564, 0.389744, -0.023438},{1.721532, 0.386948, -0.020486},{
      1.727243, 0.384038, -0.020486},{1.728311, 0.387326, -0.023438}}],
    Polygon[{{1.721532, 0.386948, -0.020486},{1.719797, 0.384559, -0.017029},{
      1.726331, 0.381230, -0.017029},{1.727243, 0.384038, -0.020486}}],
    Polygon[{{1.719797, 0.384559, -0.017029},{1.718401, 0.382637, -0.013153},{
      1.725597, 0.378971, -0.013153},{1.726331, 0.381230, -0.017029}}],
    Polygon[{{1.718401, 0.382637, -0.013153},{1.717378, 0.381230, -0.008953},{
      1.725059, 0.377316, -0.008953},{1.725597, 0.378971, -0.013153}}],
    Polygon[{{1.717378, 0.381230, -0.008953},{1.716754, 0.380371, -0.004532},{
      1.724731, 0.376307, -0.004532},{1.725059, 0.377316, -0.008953}}],
    Polygon[{{1.716754, 0.380371, -0.004532},{1.716545, 0.380083, 0.000000},{
      1.724621, 0.375968, 0.000000},{1.724731, 0.376307, -0.004532}}],
    Polygon[{{1.716545, 0.380083, 0.000000},{1.716754, 0.380371, 0.004532},{
      1.724731, 0.376307, 0.004532},{1.724621, 0.375968, 0.000000}}],
    Polygon[{{1.716754, 0.380371, 0.004532},{1.717378, 0.381230, 0.008953},{
      1.725059, 0.377316, 0.008953},{1.724731, 0.376307, 0.004532}}],
    Polygon[{{1.717378, 0.381230, 0.008953},{1.718401, 0.382637, 0.013153},{
      1.725597, 0.378971, 0.013153},{1.725059, 0.377316, 0.008953}}],
    Polygon[{{1.718401, 0.382637, 0.013153},{1.719797, 0.384559, 0.017029},{
      1.726331, 0.381230, 0.017029},{1.725597, 0.378971, 0.013153}}],
    Polygon[{{1.719797, 0.384559, 0.017029},{1.721532, 0.386948, 0.020486},{
      1.727243, 0.384038, 0.020486},{1.726331, 0.381230, 0.017029}}],
    Polygon[{{1.721532, 0.386948, 0.020486},{1.723564, 0.389744, 0.023438},{
      1.728311, 0.387326, 0.023438},{1.727243, 0.384038, 0.020486}}],
    Polygon[{{1.723564, 0.389744, 0.023438},{1.725842, 0.392880, 0.025814},{
      1.729509, 0.391012, 0.025814},{1.728311, 0.387326, 0.023438}}],
    Polygon[{{1.725842, 0.392880, 0.025814},{1.728311, 0.396278, 0.027554},{
      1.730807, 0.395007, 0.027554},{1.729509, 0.391012, 0.025814}}],
    Polygon[{{1.728311, 0.396278, 0.027554},{1.730910, 0.399855, 0.028615},{
      1.732173, 0.399211, 0.028615},{1.730807, 0.395007, 0.027554}}],
    Polygon[{{1.732173, 0.399211, -0.028615},{1.730807, 0.395007, -0.027554},{
      1.733574, 0.394568, -0.027554},{1.733574, 0.398989, -0.028615}}],
    Polygon[{{1.730807, 0.395007, -0.027554},{1.729509, 0.391012, -0.025814},{
      1.733574, 0.390368, -0.025814},{1.733574, 0.394568, -0.027554}}],
    Polygon[{{1.729509, 0.391012, -0.025814},{1.728311, 0.387326, -0.023438},{
      1.733574, 0.386492, -0.023438},{1.733574, 0.390368, -0.025814}}],
    Polygon[{{1.728311, 0.387326, -0.023438},{1.727243, 0.384038, -0.020486},{
      1.733574, 0.383035, -0.020486},{1.733574, 0.386492, -0.023438}}],
    Polygon[{{1.727243, 0.384038, -0.020486},{1.726331, 0.381230, -0.017029},{
      1.733574, 0.380083, -0.017029},{1.733574, 0.383035, -0.020486}}],
    Polygon[{{1.726331, 0.381230, -0.017029},{1.725597, 0.378971, -0.013153},{
      1.733574, 0.377707, -0.013153},{1.733574, 0.380083, -0.017029}}],
    Polygon[{{1.725597, 0.378971, -0.013153},{1.725059, 0.377316, -0.008953},{
      1.733574, 0.375968, -0.008953},{1.733574, 0.377707, -0.013153}}],
    Polygon[{{1.725059, 0.377316, -0.008953},{1.724731, 0.376307, -0.004532},{
      1.733574, 0.374906, -0.004532},{1.733574, 0.375968, -0.008953}}],
    Polygon[{{1.724731, 0.376307, -0.004532},{1.724621, 0.375968, 0.000000},{
      1.733574, 0.374550, 0.000000},{1.733574, 0.374906, -0.004532}}],
    Polygon[{{1.724621, 0.375968, 0.000000},{1.724731, 0.376307, 0.004532},{
      1.733574, 0.374906, 0.004532},{1.733574, 0.374550, 0.000000}}],
    Polygon[{{1.724731, 0.376307, 0.004532},{1.725059, 0.377316, 0.008953},{
      1.733574, 0.375968, 0.008953},{1.733574, 0.374906, 0.004532}}],
    Polygon[{{1.725059, 0.377316, 0.008953},{1.725597, 0.378971, 0.013153},{
      1.733574, 0.377707, 0.013153},{1.733574, 0.375968, 0.008953}}],
    Polygon[{{1.725597, 0.378971, 0.013153},{1.726331, 0.381230, 0.017029},{
      1.733574, 0.380083, 0.017029},{1.733574, 0.377707, 0.013153}}],
    Polygon[{{1.726331, 0.381230, 0.017029},{1.727243, 0.384038, 0.020486},{
      1.733574, 0.383035, 0.020486},{1.733574, 0.380083, 0.017029}}],
    Polygon[{{1.727243, 0.384038, 0.020486},{1.728311, 0.387326, 0.023438},{
      1.733574, 0.386492, 0.023438},{1.733574, 0.383035, 0.020486}}],
    Polygon[{{1.728311, 0.387326, 0.023438},{1.729509, 0.391012, 0.025814},{
      1.733574, 0.390368, 0.025814},{1.733574, 0.386492, 0.023438}}],
    Polygon[{{1.729509, 0.391012, 0.025814},{1.730807, 0.395007, 0.027554},{
      1.733574, 0.394568, 0.027554},{1.733574, 0.390368, 0.025814}}],
    Polygon[{{1.730807, 0.395007, 0.027554},{1.732173, 0.399211, 0.028615},{
      1.733574, 0.398989, 0.028615},{1.733574, 0.394568, 0.027554}}],
    Polygon[{{1.733574, 0.398989, -0.028615},{1.733574, 0.394568, -0.027554},{
      1.736340, 0.395007, -0.027554},{1.734974, 0.399211, -0.028615}}],
    Polygon[{{1.733574, 0.394568, -0.027554},{1.733574, 0.390368, -0.025814},{
      1.737638, 0.391012, -0.025814},{1.736340, 0.395007, -0.027554}}],
    Polygon[{{1.733574, 0.390368, -0.025814},{1.733574, 0.386492, -0.023438},{
      1.738836, 0.387326, -0.023438},{1.737638, 0.391012, -0.025814}}],
    Polygon[{{1.733574, 0.386492, -0.023438},{1.733574, 0.383035, -0.020486},{
      1.739904, 0.384038, -0.020486},{1.738836, 0.387326, -0.023438}}],
    Polygon[{{1.733574, 0.383035, -0.020486},{1.733574, 0.380083, -0.017029},{
      1.740816, 0.381230, -0.017029},{1.739904, 0.384038, -0.020486}}],
    Polygon[{{1.733574, 0.380083, -0.017029},{1.733574, 0.377707, -0.013153},{
      1.741550, 0.378971, -0.013153},{1.740816, 0.381230, -0.017029}}],
    Polygon[{{1.733574, 0.377707, -0.013153},{1.733574, 0.375968, -0.008953},{
      1.742088, 0.377316, -0.008953},{1.741550, 0.378971, -0.013153}}],
    Polygon[{{1.733574, 0.375968, -0.008953},{1.733574, 0.374906, -0.004532},{
      1.742416, 0.376307, -0.004532},{1.742088, 0.377316, -0.008953}}],
    Polygon[{{1.733574, 0.374906, -0.004532},{1.733574, 0.374550, 0.000000},{
      1.742526, 0.375968, 0.000000},{1.742416, 0.376307, -0.004532}}],
    Polygon[{{1.733574, 0.374550, 0.000000},{1.733574, 0.374906, 0.004532},{
      1.742416, 0.376307, 0.004532},{1.742526, 0.375968, 0.000000}}],
    Polygon[{{1.733574, 0.374906, 0.004532},{1.733574, 0.375968, 0.008953},{
      1.742088, 0.377316, 0.008953},{1.742416, 0.376307, 0.004532}}],
    Polygon[{{1.733574, 0.375968, 0.008953},{1.733574, 0.377707, 0.013153},{
      1.741550, 0.378971, 0.013153},{1.742088, 0.377316, 0.008953}}],
    Polygon[{{1.733574, 0.377707, 0.013153},{1.733574, 0.380083, 0.017029},{
      1.740816, 0.381230, 0.017029},{1.741550, 0.378971, 0.013153}}],
    Polygon[{{1.733574, 0.380083, 0.017029},{1.733574, 0.383035, 0.020486},{
      1.739904, 0.384038, 0.020486},{1.740816, 0.381230, 0.017029}}],
    Polygon[{{1.733574, 0.383035, 0.020486},{1.733574, 0.386492, 0.023438},{
      1.738836, 0.387326, 0.023438},{1.739904, 0.384038, 0.020486}}],
    Polygon[{{1.733574, 0.386492, 0.023438},{1.733574, 0.390368, 0.025814},{
      1.737638, 0.391012, 0.025814},{1.738836, 0.387326, 0.023438}}],
    Polygon[{{1.733574, 0.390368, 0.025814},{1.733574, 0.394568, 0.027554},{
      1.736340, 0.395007, 0.027554},{1.737638, 0.391012, 0.025814}}],
    Polygon[{{1.733574, 0.394568, 0.027554},{1.733574, 0.398989, 0.028615},{
      1.734974, 0.399211, 0.028615},{1.736340, 0.395007, 0.027554}}],
    Polygon[{{1.734974, 0.399211, -0.028615},{1.736340, 0.395007, -0.027554},{
      1.738836, 0.396278, -0.027554},{1.736237, 0.399855, -0.028615}}],
    Polygon[{{1.736340, 0.395007, -0.027554},{1.737638, 0.391012, -0.025814},{
      1.741305, 0.392880, -0.025814},{1.738836, 0.396278, -0.027554}}],
    Polygon[{{1.737638, 0.391012, -0.025814},{1.738836, 0.387326, -0.023438},{
      1.743583, 0.389744, -0.023438},{1.741305, 0.392880, -0.025814}}],
    Polygon[{{1.738836, 0.387326, -0.023438},{1.739904, 0.384038, -0.020486},{
      1.745615, 0.386948, -0.020486},{1.743583, 0.389744, -0.023438}}],
    Polygon[{{1.739904, 0.384038, -0.020486},{1.740816, 0.381230, -0.017029},{
      1.747350, 0.384559, -0.017029},{1.745615, 0.386948, -0.020486}}],
    Polygon[{{1.740816, 0.381230, -0.017029},{1.741550, 0.378971, -0.013153},{
      1.748747, 0.382637, -0.013153},{1.747350, 0.384559, -0.017029}}],
    Polygon[{{1.741550, 0.378971, -0.013153},{1.742088, 0.377316, -0.008953},{
      1.749769, 0.381230, -0.008953},{1.748747, 0.382637, -0.013153}}],
    Polygon[{{1.742088, 0.377316, -0.008953},{1.742416, 0.376307, -0.004532},{
      1.750393, 0.380371, -0.004532},{1.749769, 0.381230, -0.008953}}],
    Polygon[{{1.742416, 0.376307, -0.004532},{1.742526, 0.375968, 0.000000},{
      1.750603, 0.380083, 0.000000},{1.750393, 0.380371, -0.004532}}],
    Polygon[{{1.742526, 0.375968, 0.000000},{1.742416, 0.376307, 0.004532},{
      1.750393, 0.380371, 0.004532},{1.750603, 0.380083, 0.000000}}],
    Polygon[{{1.742416, 0.376307, 0.004532},{1.742088, 0.377316, 0.008953},{
      1.749769, 0.381230, 0.008953},{1.750393, 0.380371, 0.004532}}],
    Polygon[{{1.742088, 0.377316, 0.008953},{1.741550, 0.378971, 0.013153},{
      1.748747, 0.382637, 0.013153},{1.749769, 0.381230, 0.008953}}],
    Polygon[{{1.741550, 0.378971, 0.013153},{1.740816, 0.381230, 0.017029},{
      1.747350, 0.384559, 0.017029},{1.748747, 0.382637, 0.013153}}],
    Polygon[{{1.740816, 0.381230, 0.017029},{1.739904, 0.384038, 0.020486},{
      1.745615, 0.386948, 0.020486},{1.747350, 0.384559, 0.017029}}],
    Polygon[{{1.739904, 0.384038, 0.020486},{1.738836, 0.387326, 0.023438},{
      1.743583, 0.389744, 0.023438},{1.745615, 0.386948, 0.020486}}],
    Polygon[{{1.738836, 0.387326, 0.023438},{1.737638, 0.391012, 0.025814},{
      1.741305, 0.392880, 0.025814},{1.743583, 0.389744, 0.023438}}],
    Polygon[{{1.737638, 0.391012, 0.025814},{1.736340, 0.395007, 0.027554},{
      1.738836, 0.396278, 0.027554},{1.741305, 0.392880, 0.025814}}],
    Polygon[{{1.736340, 0.395007, 0.027554},{1.734974, 0.399211, 0.028615},{
      1.736237, 0.399855, 0.028615},{1.738836, 0.396278, 0.027554}}],
    Polygon[{{1.736237, 0.399855, -0.028615},{1.738836, 0.396278, -0.027554},{
      1.740816, 0.398259, -0.027554},{1.737240, 0.400857, -0.028615}}],
    Polygon[{{1.738836, 0.396278, -0.027554},{1.741305, 0.392880, -0.025814},{
      1.744214, 0.395790, -0.025814},{1.740816, 0.398259, -0.027554}}],
    Polygon[{{1.741305, 0.392880, -0.025814},{1.743583, 0.389744, -0.023438},{
      1.747350, 0.393512, -0.023438},{1.744214, 0.395790, -0.025814}}],
    Polygon[{{1.743583, 0.389744, -0.023438},{1.745615, 0.386948, -0.020486},{
      1.750147, 0.391480, -0.020486},{1.747350, 0.393512, -0.023438}}],
    Polygon[{{1.745615, 0.386948, -0.020486},{1.747350, 0.384559, -0.017029},{
      1.752536, 0.389744, -0.017029},{1.750147, 0.391480, -0.020486}}],
    Polygon[{{1.747350, 0.384559, -0.017029},{1.748747, 0.382637, -0.013153},{
      1.754457, 0.388348, -0.013153},{1.752536, 0.389744, -0.017029}}],
    Polygon[{{1.748747, 0.382637, -0.013153},{1.749769, 0.381230, -0.008953},{
      1.755865, 0.387326, -0.008953},{1.754457, 0.388348, -0.013153}}],
    Polygon[{{1.749769, 0.381230, -0.008953},{1.750393, 0.380371, -0.004532},{
      1.756723, 0.386702, -0.004532},{1.755865, 0.387326, -0.008953}}],
    Polygon[{{1.750393, 0.380371, -0.004532},{1.750603, 0.380083, 0.000000},{
      1.757012, 0.386492, 0.000000},{1.756723, 0.386702, -0.004532}}],
    Polygon[{{1.750603, 0.380083, 0.000000},{1.750393, 0.380371, 0.004532},{
      1.756723, 0.386702, 0.004532},{1.757012, 0.386492, 0.000000}}],
    Polygon[{{1.750393, 0.380371, 0.004532},{1.749769, 0.381230, 0.008953},{
      1.755865, 0.387326, 0.008953},{1.756723, 0.386702, 0.004532}}],
    Polygon[{{1.749769, 0.381230, 0.008953},{1.748747, 0.382637, 0.013153},{
      1.754457, 0.388348, 0.013153},{1.755865, 0.387326, 0.008953}}],
    Polygon[{{1.748747, 0.382637, 0.013153},{1.747350, 0.384559, 0.017029},{
      1.752536, 0.389744, 0.017029},{1.754457, 0.388348, 0.013153}}],
    Polygon[{{1.747350, 0.384559, 0.017029},{1.745615, 0.386948, 0.020486},{
      1.750147, 0.391480, 0.020486},{1.752536, 0.389744, 0.017029}}],
    Polygon[{{1.745615, 0.386948, 0.020486},{1.743583, 0.389744, 0.023438},{
      1.747350, 0.393512, 0.023438},{1.750147, 0.391480, 0.020486}}],
    Polygon[{{1.743583, 0.389744, 0.023438},{1.741305, 0.392880, 0.025814},{
      1.744214, 0.395790, 0.025814},{1.747350, 0.393512, 0.023438}}],
    Polygon[{{1.741305, 0.392880, 0.025814},{1.738836, 0.396278, 0.027554},{
      1.740816, 0.398259, 0.027554},{1.744214, 0.395790, 0.025814}}],
    Polygon[{{1.738836, 0.396278, 0.027554},{1.736237, 0.399855, 0.028615},{
      1.737240, 0.400857, 0.028615},{1.740816, 0.398259, 0.027554}}],
    Polygon[{{1.737240, 0.400857, -0.028615},{1.740816, 0.398259, -0.027554},{
      1.742088, 0.400755, -0.027554},{1.737884, 0.402121, -0.028615}}],
    Polygon[{{1.740816, 0.398259, -0.027554},{1.744214, 0.395790, -0.025814},{
      1.746083, 0.399457, -0.025814},{1.742088, 0.400755, -0.027554}}],
    Polygon[{{1.744214, 0.395790, -0.025814},{1.747350, 0.393512, -0.023438},{
      1.749769, 0.398259, -0.023438},{1.746083, 0.399457, -0.025814}}],
    Polygon[{{1.747350, 0.393512, -0.023438},{1.750147, 0.391480, -0.020486},{
      1.753057, 0.397191, -0.020486},{1.749769, 0.398259, -0.023438}}],
    Polygon[{{1.750147, 0.391480, -0.020486},{1.752536, 0.389744, -0.017029},{
      1.755865, 0.396278, -0.017029},{1.753057, 0.397191, -0.020486}}],
    Polygon[{{1.752536, 0.389744, -0.017029},{1.754457, 0.388348, -0.013153},{
      1.758124, 0.395544, -0.013153},{1.755865, 0.396278, -0.017029}}],
    Polygon[{{1.754457, 0.388348, -0.013153},{1.755865, 0.387326, -0.008953},{
      1.759778, 0.395007, -0.008953},{1.758124, 0.395544, -0.013153}}],
    Polygon[{{1.755865, 0.387326, -0.008953},{1.756723, 0.386702, -0.004532},{
      1.760788, 0.394679, -0.004532},{1.759778, 0.395007, -0.008953}}],
    Polygon[{{1.756723, 0.386702, -0.004532},{1.757012, 0.386492, 0.000000},{
      1.761127, 0.394568, 0.000000},{1.760788, 0.394679, -0.004532}}],
    Polygon[{{1.757012, 0.386492, 0.000000},{1.756723, 0.386702, 0.004532},{
      1.760788, 0.394679, 0.004532},{1.761127, 0.394568, 0.000000}}],
    Polygon[{{1.756723, 0.386702, 0.004532},{1.755865, 0.387326, 0.008953},{
      1.759778, 0.395007, 0.008953},{1.760788, 0.394679, 0.004532}}],
    Polygon[{{1.755865, 0.387326, 0.008953},{1.754457, 0.388348, 0.013153},{
      1.758124, 0.395544, 0.013153},{1.759778, 0.395007, 0.008953}}],
    Polygon[{{1.754457, 0.388348, 0.013153},{1.752536, 0.389744, 0.017029},{
      1.755865, 0.396278, 0.017029},{1.758124, 0.395544, 0.013153}}],
    Polygon[{{1.752536, 0.389744, 0.017029},{1.750147, 0.391480, 0.020486},{
      1.753057, 0.397191, 0.020486},{1.755865, 0.396278, 0.017029}}],
    Polygon[{{1.750147, 0.391480, 0.020486},{1.747350, 0.393512, 0.023438},{
      1.749769, 0.398259, 0.023438},{1.753057, 0.397191, 0.020486}}],
    Polygon[{{1.747350, 0.393512, 0.023438},{1.744214, 0.395790, 0.025814},{
      1.746083, 0.399457, 0.025814},{1.749769, 0.398259, 0.023438}}],
    Polygon[{{1.744214, 0.395790, 0.025814},{1.740816, 0.398259, 0.027554},{
      1.742088, 0.400755, 0.027554},{1.746083, 0.399457, 0.025814}}],
    Polygon[{{1.740816, 0.398259, 0.027554},{1.737240, 0.400857, 0.028615},{
      1.737884, 0.402121, 0.028615},{1.742088, 0.400755, 0.027554}}],
    Polygon[{{1.737884, 0.402121, -0.028615},{1.742088, 0.400755, -0.027554},{
      1.742526, 0.403521, -0.027554},{1.738106, 0.403521, -0.028615}}],
    Polygon[{{1.742088, 0.400755, -0.027554},{1.746083, 0.399457, -0.025814},{
      1.746726, 0.403521, -0.025814},{1.742526, 0.403521, -0.027554}}],
    Polygon[{{1.746083, 0.399457, -0.025814},{1.749769, 0.398259, -0.023438},{
      1.750603, 0.403521, -0.023438},{1.746726, 0.403521, -0.025814}}],
    Polygon[{{1.749769, 0.398259, -0.023438},{1.753057, 0.397191, -0.020486},{
      1.754059, 0.403521, -0.020486},{1.750603, 0.403521, -0.023438}}],
    Polygon[{{1.753057, 0.397191, -0.020486},{1.755865, 0.396278, -0.017029},{
      1.757012, 0.403521, -0.017029},{1.754059, 0.403521, -0.020486}}],
    Polygon[{{1.755865, 0.396278, -0.017029},{1.758124, 0.395544, -0.013153},{
      1.759387, 0.403521, -0.013153},{1.757012, 0.403521, -0.017029}}],
    Polygon[{{1.758124, 0.395544, -0.013153},{1.759778, 0.395007, -0.008953},{
      1.761127, 0.403521, -0.008953},{1.759387, 0.403521, -0.013153}}],
    Polygon[{{1.759778, 0.395007, -0.008953},{1.760788, 0.394679, -0.004532},{
      1.762188, 0.403521, -0.004532},{1.761127, 0.403521, -0.008953}}],
    Polygon[{{1.760788, 0.394679, -0.004532},{1.761127, 0.394568, 0.000000},{
      1.762545, 0.403521, 0.000000},{1.762188, 0.403521, -0.004532}}],
    Polygon[{{1.761127, 0.394568, 0.000000},{1.760788, 0.394679, 0.004532},{
      1.762188, 0.403521, 0.004532},{1.762545, 0.403521, 0.000000}}],
    Polygon[{{1.760788, 0.394679, 0.004532},{1.759778, 0.395007, 0.008953},{
      1.761127, 0.403521, 0.008953},{1.762188, 0.403521, 0.004532}}],
    Polygon[{{1.759778, 0.395007, 0.008953},{1.758124, 0.395544, 0.013153},{
      1.759387, 0.403521, 0.013153},{1.761127, 0.403521, 0.008953}}],
    Polygon[{{1.758124, 0.395544, 0.013153},{1.755865, 0.396278, 0.017029},{
      1.757012, 0.403521, 0.017029},{1.759387, 0.403521, 0.013153}}],
    Polygon[{{1.755865, 0.396278, 0.017029},{1.753057, 0.397191, 0.020486},{
      1.754059, 0.403521, 0.020486},{1.757012, 0.403521, 0.017029}}],
    Polygon[{{1.753057, 0.397191, 0.020486},{1.749769, 0.398259, 0.023438},{
      1.750603, 0.403521, 0.023438},{1.754059, 0.403521, 0.020486}}],
    Polygon[{{1.749769, 0.398259, 0.023438},{1.746083, 0.399457, 0.025814},{
      1.746726, 0.403521, 0.025814},{1.750603, 0.403521, 0.023438}}],
    Polygon[{{1.746083, 0.399457, 0.025814},{1.742088, 0.400755, 0.027554},{
      1.742526, 0.403521, 0.027554},{1.746726, 0.403521, 0.025814}}],
    Polygon[{{1.742088, 0.400755, 0.027554},{1.737884, 0.402121, 0.028615},{
      1.738106, 0.403521, 0.028615},{1.742526, 0.403521, 0.027554}}],
    Polygon[{{1.768866, 0.374335, -0.014853},{1.771160, 0.374335, -0.014302},{
      1.770933, 0.375771, -0.014302},{1.768750, 0.375062, -0.014853}}],
    Polygon[{{1.771160, 0.374335, -0.014302},{1.773340, 0.374335, -0.013399},{
      1.773006, 0.376445, -0.013399},{1.770933, 0.375771, -0.014302}}],
    Polygon[{{1.773340, 0.374335, -0.013399},{1.775352, 0.374335, -0.012166},{
      1.774920, 0.377066, -0.012166},{1.773006, 0.376445, -0.013399}}],
    Polygon[{{1.775352, 0.374335, -0.012166},{1.777147, 0.374335, -0.010634},{
      1.776626, 0.377621, -0.010634},{1.774920, 0.377066, -0.012166}}],
    Polygon[{{1.777147, 0.374335, -0.010634},{1.778679, 0.374335, -0.008839},{
      1.778084, 0.378094, -0.008839},{1.776626, 0.377621, -0.010634}}],
    Polygon[{{1.778679, 0.374335, -0.008839},{1.779912, 0.374335, -0.006827},{
      1.779256, 0.378475, -0.006827},{1.778084, 0.378094, -0.008839}}],
    Polygon[{{1.779912, 0.374335, -0.006827},{1.780815, 0.374335, -0.004647},{
      1.780115, 0.378754, -0.004647},{1.779256, 0.378475, -0.006827}}],
    Polygon[{{1.780815, 0.374335, -0.004647},{1.781366, 0.374335, -0.002352},{
      1.780639, 0.378925, -0.002352},{1.780115, 0.378754, -0.004647}}],
    Polygon[{{1.781366, 0.374335, -0.002352},{1.781551, 0.374335, 0.000000},{
      1.780815, 0.378982, 0.000000},{1.780639, 0.378925, -0.002352}}],
    Polygon[{{1.781551, 0.374335, 0.000000},{1.781366, 0.374335, 0.002352},{
      1.780639, 0.378925, 0.002352},{1.780815, 0.378982, 0.000000}}],
    Polygon[{{1.781366, 0.374335, 0.002352},{1.780815, 0.374335, 0.004647},{
      1.780115, 0.378754, 0.004647},{1.780639, 0.378925, 0.002352}}],
    Polygon[{{1.780815, 0.374335, 0.004647},{1.779912, 0.374335, 0.006827},{
      1.779256, 0.378475, 0.006827},{1.780115, 0.378754, 0.004647}}],
    Polygon[{{1.779912, 0.374335, 0.006827},{1.778679, 0.374335, 0.008839},{
      1.778084, 0.378094, 0.008839},{1.779256, 0.378475, 0.006827}}],
    Polygon[{{1.778679, 0.374335, 0.008839},{1.777147, 0.374335, 0.010634},{
      1.776626, 0.377621, 0.010634},{1.778084, 0.378094, 0.008839}}],
    Polygon[{{1.777147, 0.374335, 0.010634},{1.775352, 0.374335, 0.012166},{
      1.774920, 0.377066, 0.012166},{1.776626, 0.377621, 0.010634}}],
    Polygon[{{1.775352, 0.374335, 0.012166},{1.773340, 0.374335, 0.013399},{
      1.773006, 0.376445, 0.013399},{1.774920, 0.377066, 0.012166}}],
    Polygon[{{1.773340, 0.374335, 0.013399},{1.771160, 0.374335, 0.014302},{
      1.770933, 0.375771, 0.014302},{1.773006, 0.376445, 0.013399}}],
    Polygon[{{1.771160, 0.374335, 0.014302},{1.768866, 0.374335, 0.014853},{
      1.768750, 0.375062, 0.014853},{1.770933, 0.375771, 0.014302}}],
    Polygon[{{1.768750, 0.375062, -0.014853},{1.770933, 0.375771, -0.014302},{
      1.770273, 0.377066, -0.014302},{1.768416, 0.375718, -0.014853}}],
    Polygon[{{1.770933, 0.375771, -0.014302},{1.773006, 0.376445, -0.013399},{
      1.772036, 0.378348, -0.013399},{1.770273, 0.377066, -0.014302}}],
    Polygon[{{1.773006, 0.376445, -0.013399},{1.774920, 0.377066, -0.012166},{
      1.773664, 0.379530, -0.012166},{1.772036, 0.378348, -0.013399}}],
    Polygon[{{1.774920, 0.377066, -0.012166},{1.776626, 0.377621, -0.010634},{
      1.775116, 0.380585, -0.010634},{1.773664, 0.379530, -0.012166}}],
    Polygon[{{1.776626, 0.377621, -0.010634},{1.778084, 0.378094, -0.008839},{
      1.776356, 0.381486, -0.008839},{1.775116, 0.380585, -0.010634}}],
    Polygon[{{1.778084, 0.378094, -0.008839},{1.779256, 0.378475, -0.006827},{
      1.777353, 0.382211, -0.006827},{1.776356, 0.381486, -0.008839}}],
    Polygon[{{1.779256, 0.378475, -0.006827},{1.780115, 0.378754, -0.004647},{
      1.778084, 0.382741, -0.004647},{1.777353, 0.382211, -0.006827}}],
    Polygon[{{1.780115, 0.378754, -0.004647},{1.780639, 0.378925, -0.002352},{
      1.778529, 0.383065, -0.002352},{1.778084, 0.382741, -0.004647}}],
    Polygon[{{1.780639, 0.378925, -0.002352},{1.780815, 0.378982, 0.000000},{
      1.778679, 0.383174, 0.000000},{1.778529, 0.383065, -0.002352}}],
    Polygon[{{1.780815, 0.378982, 0.000000},{1.780639, 0.378925, 0.002352},{
      1.778529, 0.383065, 0.002352},{1.778679, 0.383174, 0.000000}}],
    Polygon[{{1.780639, 0.378925, 0.002352},{1.780115, 0.378754, 0.004647},{
      1.778084, 0.382741, 0.004647},{1.778529, 0.383065, 0.002352}}],
    Polygon[{{1.780115, 0.378754, 0.004647},{1.779256, 0.378475, 0.006827},{
      1.777353, 0.382211, 0.006827},{1.778084, 0.382741, 0.004647}}],
    Polygon[{{1.779256, 0.378475, 0.006827},{1.778084, 0.378094, 0.008839},{
      1.776356, 0.381486, 0.008839},{1.777353, 0.382211, 0.006827}}],
    Polygon[{{1.778084, 0.378094, 0.008839},{1.776626, 0.377621, 0.010634},{
      1.775116, 0.380585, 0.010634},{1.776356, 0.381486, 0.008839}}],
    Polygon[{{1.776626, 0.377621, 0.010634},{1.774920, 0.377066, 0.012166},{
      1.773664, 0.379530, 0.012166},{1.775116, 0.380585, 0.010634}}],
    Polygon[{{1.774920, 0.377066, 0.012166},{1.773006, 0.376445, 0.013399},{
      1.772036, 0.378348, 0.013399},{1.773664, 0.379530, 0.012166}}],
    Polygon[{{1.773006, 0.376445, 0.013399},{1.770933, 0.375771, 0.014302},{
      1.770273, 0.377066, 0.014302},{1.772036, 0.378348, 0.013399}}],
    Polygon[{{1.770933, 0.375771, 0.014302},{1.768750, 0.375062, 0.014853},{
      1.768416, 0.375718, 0.014853},{1.770273, 0.377066, 0.014302}}],
    Polygon[{{1.768416, 0.375718, -0.014853},{1.770273, 0.377066, -0.014302},{
      1.769245, 0.378094, -0.014302},{1.767896, 0.376238, -0.014853}}],
    Polygon[{{1.770273, 0.377066, -0.014302},{1.772036, 0.378348, -0.013399},{
      1.770526, 0.379858, -0.013399},{1.769245, 0.378094, -0.014302}}],
    Polygon[{{1.772036, 0.378348, -0.013399},{1.773664, 0.379530, -0.012166},{
      1.771709, 0.381486, -0.012166},{1.770526, 0.379858, -0.013399}}],
    Polygon[{{1.773664, 0.379530, -0.012166},{1.775116, 0.380585, -0.010634},{
      1.772763, 0.382938, -0.010634},{1.771709, 0.381486, -0.012166}}],
    Polygon[{{1.775116, 0.380585, -0.010634},{1.776356, 0.381486, -0.008839},{
      1.773664, 0.384178, -0.008839},{1.772763, 0.382938, -0.010634}}],
    Polygon[{{1.776356, 0.381486, -0.008839},{1.777353, 0.382211, -0.006827},{
      1.774389, 0.385175, -0.006827},{1.773664, 0.384178, -0.008839}}],
    Polygon[{{1.777353, 0.382211, -0.006827},{1.778084, 0.382741, -0.004647},{
      1.774920, 0.385906, -0.004647},{1.774389, 0.385175, -0.006827}}],
    Polygon[{{1.778084, 0.382741, -0.004647},{1.778529, 0.383065, -0.002352},{
      1.775243, 0.386351, -0.002352},{1.774920, 0.385906, -0.004647}}],
    Polygon[{{1.778529, 0.383065, -0.002352},{1.778679, 0.383174, 0.000000},{
      1.775352, 0.386501, 0.000000},{1.775243, 0.386351, -0.002352}}],
    Polygon[{{1.778679, 0.383174, 0.000000},{1.778529, 0.383065, 0.002352},{
      1.775243, 0.386351, 0.002352},{1.775352, 0.386501, 0.000000}}],
    Polygon[{{1.778529, 0.383065, 0.002352},{1.778084, 0.382741, 0.004647},{
      1.774920, 0.385906, 0.004647},{1.775243, 0.386351, 0.002352}}],
    Polygon[{{1.778084, 0.382741, 0.004647},{1.777353, 0.382211, 0.006827},{
      1.774389, 0.385175, 0.006827},{1.774920, 0.385906, 0.004647}}],
    Polygon[{{1.777353, 0.382211, 0.006827},{1.776356, 0.381486, 0.008839},{
      1.773664, 0.384178, 0.008839},{1.774389, 0.385175, 0.006827}}],
    Polygon[{{1.776356, 0.381486, 0.008839},{1.775116, 0.380585, 0.010634},{
      1.772763, 0.382938, 0.010634},{1.773664, 0.384178, 0.008839}}],
    Polygon[{{1.775116, 0.380585, 0.010634},{1.773664, 0.379530, 0.012166},{
      1.771709, 0.381486, 0.012166},{1.772763, 0.382938, 0.010634}}],
    Polygon[{{1.773664, 0.379530, 0.012166},{1.772036, 0.378348, 0.013399},{
      1.770526, 0.379858, 0.013399},{1.771709, 0.381486, 0.012166}}],
    Polygon[{{1.772036, 0.378348, 0.013399},{1.770273, 0.377066, 0.014302},{
      1.769245, 0.378094, 0.014302},{1.770526, 0.379858, 0.013399}}],
    Polygon[{{1.770273, 0.377066, 0.014302},{1.768416, 0.375718, 0.014853},{
      1.767896, 0.376238, 0.014853},{1.769245, 0.378094, 0.014302}}],
    Polygon[{{1.767896, 0.376238, -0.014853},{1.769245, 0.378094, -0.014302},{
      1.767949, 0.378754, -0.014302},{1.767240, 0.376572, -0.014853}}],
    Polygon[{{1.769245, 0.378094, -0.014302},{1.770526, 0.379858, -0.013399},{
      1.768623, 0.380828, -0.013399},{1.767949, 0.378754, -0.014302}}],
    Polygon[{{1.770526, 0.379858, -0.013399},{1.771709, 0.381486, -0.012166},{
      1.769245, 0.382741, -0.012166},{1.768623, 0.380828, -0.013399}}],
    Polygon[{{1.771709, 0.381486, -0.012166},{1.772763, 0.382938, -0.010634},{
      1.769799, 0.384448, -0.010634},{1.769245, 0.382741, -0.012166}}],
    Polygon[{{1.772763, 0.382938, -0.010634},{1.773664, 0.384178, -0.008839},{
      1.770273, 0.385906, -0.008839},{1.769799, 0.384448, -0.010634}}],
    Polygon[{{1.773664, 0.384178, -0.008839},{1.774389, 0.385175, -0.006827},{
      1.770654, 0.387078, -0.006827},{1.770273, 0.385906, -0.008839}}],
    Polygon[{{1.774389, 0.385175, -0.006827},{1.774920, 0.385906, -0.004647},{
      1.770933, 0.387937, -0.004647},{1.770654, 0.387078, -0.006827}}],
    Polygon[{{1.774920, 0.385906, -0.004647},{1.775243, 0.386351, -0.002352},{
      1.771103, 0.388461, -0.002352},{1.770933, 0.387937, -0.004647}}],
    Polygon[{{1.775243, 0.386351, -0.002352},{1.775352, 0.386501, 0.000000},{
      1.771160, 0.388637, 0.000000},{1.771103, 0.388461, -0.002352}}],
    Polygon[{{1.775352, 0.386501, 0.000000},{1.775243, 0.386351, 0.002352},{
      1.771103, 0.388461, 0.002352},{1.771160, 0.388637, 0.000000}}],
    Polygon[{{1.775243, 0.386351, 0.002352},{1.774920, 0.385906, 0.004647},{
      1.770933, 0.387937, 0.004647},{1.771103, 0.388461, 0.002352}}],
    Polygon[{{1.774920, 0.385906, 0.004647},{1.774389, 0.385175, 0.006827},{
      1.770654, 0.387078, 0.006827},{1.770933, 0.387937, 0.004647}}],
    Polygon[{{1.774389, 0.385175, 0.006827},{1.773664, 0.384178, 0.008839},{
      1.770273, 0.385906, 0.008839},{1.770654, 0.387078, 0.006827}}],
    Polygon[{{1.773664, 0.384178, 0.008839},{1.772763, 0.382938, 0.010634},{
      1.769799, 0.384448, 0.010634},{1.770273, 0.385906, 0.008839}}],
    Polygon[{{1.772763, 0.382938, 0.010634},{1.771709, 0.381486, 0.012166},{
      1.769245, 0.382741, 0.012166},{1.769799, 0.384448, 0.010634}}],
    Polygon[{{1.771709, 0.381486, 0.012166},{1.770526, 0.379858, 0.013399},{
      1.768623, 0.380828, 0.013399},{1.769245, 0.382741, 0.012166}}],
    Polygon[{{1.770526, 0.379858, 0.013399},{1.769245, 0.378094, 0.014302},{
      1.767949, 0.378754, 0.014302},{1.768623, 0.380828, 0.013399}}],
    Polygon[{{1.769245, 0.378094, 0.014302},{1.767896, 0.376238, 0.014853},{
      1.767240, 0.376572, 0.014853},{1.767949, 0.378754, 0.014302}}],
    Polygon[{{1.767240, 0.376572, -0.014853},{1.767949, 0.378754, -0.014302},{
      1.766513, 0.378982, -0.014302},{1.766513, 0.376687, -0.014853}}],
    Polygon[{{1.767949, 0.378754, -0.014302},{1.768623, 0.380828, -0.013399},{
      1.766513, 0.381162, -0.013399},{1.766513, 0.378982, -0.014302}}],
    Polygon[{{1.768623, 0.380828, -0.013399},{1.769245, 0.382741, -0.012166},{
      1.766513, 0.383174, -0.012166},{1.766513, 0.381162, -0.013399}}],
    Polygon[{{1.769245, 0.382741, -0.012166},{1.769799, 0.384448, -0.010634},{
      1.766513, 0.384968, -0.010634},{1.766513, 0.383174, -0.012166}}],
    Polygon[{{1.769799, 0.384448, -0.010634},{1.770273, 0.385906, -0.008839},{
      1.766513, 0.386501, -0.008839},{1.766513, 0.384968, -0.010634}}],
    Polygon[{{1.770273, 0.385906, -0.008839},{1.770654, 0.387078, -0.006827},{
      1.766513, 0.387734, -0.006827},{1.766513, 0.386501, -0.008839}}],
    Polygon[{{1.770654, 0.387078, -0.006827},{1.770933, 0.387937, -0.004647},{
      1.766513, 0.388637, -0.004647},{1.766513, 0.387734, -0.006827}}],
    Polygon[{{1.770933, 0.387937, -0.004647},{1.771103, 0.388461, -0.002352},{
      1.766513, 0.389188, -0.002352},{1.766513, 0.388637, -0.004647}}],
    Polygon[{{1.771103, 0.388461, -0.002352},{1.771160, 0.388637, 0.000000},{
      1.766513, 0.389373, 0.000000},{1.766513, 0.389188, -0.002352}}],
    Polygon[{{1.771160, 0.388637, 0.000000},{1.771103, 0.388461, 0.002352},{
      1.766513, 0.389188, 0.002352},{1.766513, 0.389373, 0.000000}}],
    Polygon[{{1.771103, 0.388461, 0.002352},{1.770933, 0.387937, 0.004647},{
      1.766513, 0.388637, 0.004647},{1.766513, 0.389188, 0.002352}}],
    Polygon[{{1.770933, 0.387937, 0.004647},{1.770654, 0.387078, 0.006827},{
      1.766513, 0.387734, 0.006827},{1.766513, 0.388637, 0.004647}}],
    Polygon[{{1.770654, 0.387078, 0.006827},{1.770273, 0.385906, 0.008839},{
      1.766513, 0.386501, 0.008839},{1.766513, 0.387734, 0.006827}}],
    Polygon[{{1.770273, 0.385906, 0.008839},{1.769799, 0.384448, 0.010634},{
      1.766513, 0.384968, 0.010634},{1.766513, 0.386501, 0.008839}}],
    Polygon[{{1.769799, 0.384448, 0.010634},{1.769245, 0.382741, 0.012166},{
      1.766513, 0.383174, 0.012166},{1.766513, 0.384968, 0.010634}}],
    Polygon[{{1.769245, 0.382741, 0.012166},{1.768623, 0.380828, 0.013399},{
      1.766513, 0.381162, 0.013399},{1.766513, 0.383174, 0.012166}}],
    Polygon[{{1.768623, 0.380828, 0.013399},{1.767949, 0.378754, 0.014302},{
      1.766513, 0.378982, 0.014302},{1.766513, 0.381162, 0.013399}}],
    Polygon[{{1.767949, 0.378754, 0.014302},{1.767240, 0.376572, 0.014853},{
      1.766513, 0.376687, 0.014853},{1.766513, 0.378982, 0.014302}}],
    Polygon[{{1.766513, 0.376687, -0.014853},{1.766513, 0.378982, -0.014302},{
      1.765077, 0.378754, -0.014302},{1.765786, 0.376572, -0.014853}}],
    Polygon[{{1.766513, 0.378982, -0.014302},{1.766513, 0.381162, -0.013399},{
      1.764403, 0.380828, -0.013399},{1.765077, 0.378754, -0.014302}}],
    Polygon[{{1.766513, 0.381162, -0.013399},{1.766513, 0.383174, -0.012166},{
      1.763782, 0.382741, -0.012166},{1.764403, 0.380828, -0.013399}}],
    Polygon[{{1.766513, 0.383174, -0.012166},{1.766513, 0.384968, -0.010634},{
      1.763227, 0.384448, -0.010634},{1.763782, 0.382741, -0.012166}}],
    Polygon[{{1.766513, 0.384968, -0.010634},{1.766513, 0.386501, -0.008839},{
      1.762753, 0.385906, -0.008839},{1.763227, 0.384448, -0.010634}}],
    Polygon[{{1.766513, 0.386501, -0.008839},{1.766513, 0.387734, -0.006827},{
      1.762372, 0.387078, -0.006827},{1.762753, 0.385906, -0.008839}}],
    Polygon[{{1.766513, 0.387734, -0.006827},{1.766513, 0.388637, -0.004647},{
      1.762093, 0.387937, -0.004647},{1.762372, 0.387078, -0.006827}}],
    Polygon[{{1.766513, 0.388637, -0.004647},{1.766513, 0.389188, -0.002352},{
      1.761923, 0.388461, -0.002352},{1.762093, 0.387937, -0.004647}}],
    Polygon[{{1.766513, 0.389188, -0.002352},{1.766513, 0.389373, 0.000000},{
      1.761866, 0.388637, 0.000000},{1.761923, 0.388461, -0.002352}}],
    Polygon[{{1.766513, 0.389373, 0.000000},{1.766513, 0.389188, 0.002352},{
      1.761923, 0.388461, 0.002352},{1.761866, 0.388637, 0.000000}}],
    Polygon[{{1.766513, 0.389188, 0.002352},{1.766513, 0.388637, 0.004647},{
      1.762093, 0.387937, 0.004647},{1.761923, 0.388461, 0.002352}}],
    Polygon[{{1.766513, 0.388637, 0.004647},{1.766513, 0.387734, 0.006827},{
      1.762372, 0.387078, 0.006827},{1.762093, 0.387937, 0.004647}}],
    Polygon[{{1.766513, 0.387734, 0.006827},{1.766513, 0.386501, 0.008839},{
      1.762753, 0.385906, 0.008839},{1.762372, 0.387078, 0.006827}}],
    Polygon[{{1.766513, 0.386501, 0.008839},{1.766513, 0.384968, 0.010634},{
      1.763227, 0.384448, 0.010634},{1.762753, 0.385906, 0.008839}}],
    Polygon[{{1.766513, 0.384968, 0.010634},{1.766513, 0.383174, 0.012166},{
      1.763782, 0.382741, 0.012166},{1.763227, 0.384448, 0.010634}}],
    Polygon[{{1.766513, 0.383174, 0.012166},{1.766513, 0.381162, 0.013399},{
      1.764403, 0.380828, 0.013399},{1.763782, 0.382741, 0.012166}}],
    Polygon[{{1.766513, 0.381162, 0.013399},{1.766513, 0.378982, 0.014302},{
      1.765077, 0.378754, 0.014302},{1.764403, 0.380828, 0.013399}}],
    Polygon[{{1.766513, 0.378982, 0.014302},{1.766513, 0.376687, 0.014853},{
      1.765786, 0.376572, 0.014853},{1.765077, 0.378754, 0.014302}}],
    Polygon[{{1.765786, 0.376572, -0.014853},{1.765077, 0.378754, -0.014302},{
      1.763782, 0.378094, -0.014302},{1.765130, 0.376238, -0.014853}}],
    Polygon[{{1.765077, 0.378754, -0.014302},{1.764403, 0.380828, -0.013399},{
      1.762500, 0.379858, -0.013399},{1.763782, 0.378094, -0.014302}}],
    Polygon[{{1.764403, 0.380828, -0.013399},{1.763782, 0.382741, -0.012166},{
      1.761317, 0.381486, -0.012166},{1.762500, 0.379858, -0.013399}}],
    Polygon[{{1.763782, 0.382741, -0.012166},{1.763227, 0.384448, -0.010634},{
      1.760263, 0.382938, -0.010634},{1.761317, 0.381486, -0.012166}}],
    Polygon[{{1.763227, 0.384448, -0.010634},{1.762753, 0.385906, -0.008839},{
      1.759362, 0.384178, -0.008839},{1.760263, 0.382938, -0.010634}}],
    Polygon[{{1.762753, 0.385906, -0.008839},{1.762372, 0.387078, -0.006827},{
      1.758637, 0.385175, -0.006827},{1.759362, 0.384178, -0.008839}}],
    Polygon[{{1.762372, 0.387078, -0.006827},{1.762093, 0.387937, -0.004647},{
      1.758106, 0.385906, -0.004647},{1.758637, 0.385175, -0.006827}}],
    Polygon[{{1.762093, 0.387937, -0.004647},{1.761923, 0.388461, -0.002352},{
      1.757783, 0.386351, -0.002352},{1.758106, 0.385906, -0.004647}}],
    Polygon[{{1.761923, 0.388461, -0.002352},{1.761866, 0.388637, 0.000000},{
      1.757674, 0.386501, 0.000000},{1.757783, 0.386351, -0.002352}}],
    Polygon[{{1.761866, 0.388637, 0.000000},{1.761923, 0.388461, 0.002352},{
      1.757783, 0.386351, 0.002352},{1.757674, 0.386501, 0.000000}}],
    Polygon[{{1.761923, 0.388461, 0.002352},{1.762093, 0.387937, 0.004647},{
      1.758106, 0.385906, 0.004647},{1.757783, 0.386351, 0.002352}}],
    Polygon[{{1.762093, 0.387937, 0.004647},{1.762372, 0.387078, 0.006827},{
      1.758637, 0.385175, 0.006827},{1.758106, 0.385906, 0.004647}}],
    Polygon[{{1.762372, 0.387078, 0.006827},{1.762753, 0.385906, 0.008839},{
      1.759362, 0.384178, 0.008839},{1.758637, 0.385175, 0.006827}}],
    Polygon[{{1.762753, 0.385906, 0.008839},{1.763227, 0.384448, 0.010634},{
      1.760263, 0.382938, 0.010634},{1.759362, 0.384178, 0.008839}}],
    Polygon[{{1.763227, 0.384448, 0.010634},{1.763782, 0.382741, 0.012166},{
      1.761317, 0.381486, 0.012166},{1.760263, 0.382938, 0.010634}}],
    Polygon[{{1.763782, 0.382741, 0.012166},{1.764403, 0.380828, 0.013399},{
      1.762500, 0.379858, 0.013399},{1.761317, 0.381486, 0.012166}}],
    Polygon[{{1.764403, 0.380828, 0.013399},{1.765077, 0.378754, 0.014302},{
      1.763782, 0.378094, 0.014302},{1.762500, 0.379858, 0.013399}}],
    Polygon[{{1.765077, 0.378754, 0.014302},{1.765786, 0.376572, 0.014853},{
      1.765130, 0.376238, 0.014853},{1.763782, 0.378094, 0.014302}}],
    Polygon[{{1.765130, 0.376238, -0.014853},{1.763782, 0.378094, -0.014302},{
      1.762753, 0.377066, -0.014302},{1.764610, 0.375718, -0.014853}}],
    Polygon[{{1.763782, 0.378094, -0.014302},{1.762500, 0.379858, -0.013399},{
      1.760990, 0.378348, -0.013399},{1.762753, 0.377066, -0.014302}}],
    Polygon[{{1.762500, 0.379858, -0.013399},{1.761317, 0.381486, -0.012166},{
      1.759362, 0.379530, -0.012166},{1.760990, 0.378348, -0.013399}}],
    Polygon[{{1.761317, 0.381486, -0.012166},{1.760263, 0.382938, -0.010634},{
      1.757910, 0.380585, -0.010634},{1.759362, 0.379530, -0.012166}}],
    Polygon[{{1.760263, 0.382938, -0.010634},{1.759362, 0.384178, -0.008839},{
      1.756670, 0.381486, -0.008839},{1.757910, 0.380585, -0.010634}}],
    Polygon[{{1.759362, 0.384178, -0.008839},{1.758637, 0.385175, -0.006827},{
      1.755673, 0.382211, -0.006827},{1.756670, 0.381486, -0.008839}}],
    Polygon[{{1.758637, 0.385175, -0.006827},{1.758106, 0.385906, -0.004647},{
      1.754942, 0.382741, -0.004647},{1.755673, 0.382211, -0.006827}}],
    Polygon[{{1.758106, 0.385906, -0.004647},{1.757783, 0.386351, -0.002352},{
      1.754497, 0.383065, -0.002352},{1.754942, 0.382741, -0.004647}}],
    Polygon[{{1.757783, 0.386351, -0.002352},{1.757674, 0.386501, 0.000000},{
      1.754347, 0.383174, 0.000000},{1.754497, 0.383065, -0.002352}}],
    Polygon[{{1.757674, 0.386501, 0.000000},{1.757783, 0.386351, 0.002352},{
      1.754497, 0.383065, 0.002352},{1.754347, 0.383174, 0.000000}}],
    Polygon[{{1.757783, 0.386351, 0.002352},{1.758106, 0.385906, 0.004647},{
      1.754942, 0.382741, 0.004647},{1.754497, 0.383065, 0.002352}}],
    Polygon[{{1.758106, 0.385906, 0.004647},{1.758637, 0.385175, 0.006827},{
      1.755673, 0.382211, 0.006827},{1.754942, 0.382741, 0.004647}}],
    Polygon[{{1.758637, 0.385175, 0.006827},{1.759362, 0.384178, 0.008839},{
      1.756670, 0.381486, 0.008839},{1.755673, 0.382211, 0.006827}}],
    Polygon[{{1.759362, 0.384178, 0.008839},{1.760263, 0.382938, 0.010634},{
      1.757910, 0.380585, 0.010634},{1.756670, 0.381486, 0.008839}}],
    Polygon[{{1.760263, 0.382938, 0.010634},{1.761317, 0.381486, 0.012166},{
      1.759362, 0.379530, 0.012166},{1.757910, 0.380585, 0.010634}}],
    Polygon[{{1.761317, 0.381486, 0.012166},{1.762500, 0.379858, 0.013399},{
      1.760990, 0.378348, 0.013399},{1.759362, 0.379530, 0.012166}}],
    Polygon[{{1.762500, 0.379858, 0.013399},{1.763782, 0.378094, 0.014302},{
      1.762753, 0.377066, 0.014302},{1.760990, 0.378348, 0.013399}}],
    Polygon[{{1.763782, 0.378094, 0.014302},{1.765130, 0.376238, 0.014853},{
      1.764610, 0.375718, 0.014853},{1.762753, 0.377066, 0.014302}}],
    Polygon[{{1.764610, 0.375718, -0.014853},{1.762753, 0.377066, -0.014302},{
      1.762093, 0.375771, -0.014302},{1.764276, 0.375062, -0.014853}}],
    Polygon[{{1.762753, 0.377066, -0.014302},{1.760990, 0.378348, -0.013399},{
      1.760020, 0.376445, -0.013399},{1.762093, 0.375771, -0.014302}}],
    Polygon[{{1.760990, 0.378348, -0.013399},{1.759362, 0.379530, -0.012166},{
      1.758106, 0.377066, -0.012166},{1.760020, 0.376445, -0.013399}}],
    Polygon[{{1.759362, 0.379530, -0.012166},{1.757910, 0.380585, -0.010634},{
      1.756400, 0.377621, -0.010634},{1.758106, 0.377066, -0.012166}}],
    Polygon[{{1.757910, 0.380585, -0.010634},{1.756670, 0.381486, -0.008839},{
      1.754942, 0.378094, -0.008839},{1.756400, 0.377621, -0.010634}}],
    Polygon[{{1.756670, 0.381486, -0.008839},{1.755673, 0.382211, -0.006827},{
      1.753770, 0.378475, -0.006827},{1.754942, 0.378094, -0.008839}}],
    Polygon[{{1.755673, 0.382211, -0.006827},{1.754942, 0.382741, -0.004647},{
      1.752911, 0.378754, -0.004647},{1.753770, 0.378475, -0.006827}}],
    Polygon[{{1.754942, 0.382741, -0.004647},{1.754497, 0.383065, -0.002352},{
      1.752387, 0.378925, -0.002352},{1.752911, 0.378754, -0.004647}}],
    Polygon[{{1.754497, 0.383065, -0.002352},{1.754347, 0.383174, 0.000000},{
      1.752211, 0.378982, 0.000000},{1.752387, 0.378925, -0.002352}}],
    Polygon[{{1.754347, 0.383174, 0.000000},{1.754497, 0.383065, 0.002352},{
      1.752387, 0.378925, 0.002352},{1.752211, 0.378982, 0.000000}}],
    Polygon[{{1.754497, 0.383065, 0.002352},{1.754942, 0.382741, 0.004647},{
      1.752911, 0.378754, 0.004647},{1.752387, 0.378925, 0.002352}}],
    Polygon[{{1.754942, 0.382741, 0.004647},{1.755673, 0.382211, 0.006827},{
      1.753770, 0.378475, 0.006827},{1.752911, 0.378754, 0.004647}}],
    Polygon[{{1.755673, 0.382211, 0.006827},{1.756670, 0.381486, 0.008839},{
      1.754942, 0.378094, 0.008839},{1.753770, 0.378475, 0.006827}}],
    Polygon[{{1.756670, 0.381486, 0.008839},{1.757910, 0.380585, 0.010634},{
      1.756400, 0.377621, 0.010634},{1.754942, 0.378094, 0.008839}}],
    Polygon[{{1.757910, 0.380585, 0.010634},{1.759362, 0.379530, 0.012166},{
      1.758106, 0.377066, 0.012166},{1.756400, 0.377621, 0.010634}}],
    Polygon[{{1.759362, 0.379530, 0.012166},{1.760990, 0.378348, 0.013399},{
      1.760020, 0.376445, 0.013399},{1.758106, 0.377066, 0.012166}}],
    Polygon[{{1.760990, 0.378348, 0.013399},{1.762753, 0.377066, 0.014302},{
      1.762093, 0.375771, 0.014302},{1.760020, 0.376445, 0.013399}}],
    Polygon[{{1.762753, 0.377066, 0.014302},{1.764610, 0.375718, 0.014853},{
      1.764276, 0.375062, 0.014853},{1.762093, 0.375771, 0.014302}}],
    Polygon[{{1.764276, 0.375062, -0.014853},{1.762093, 0.375771, -0.014302},{
      1.761866, 0.374335, -0.014302},{1.764161, 0.374335, -0.014853}}],
    Polygon[{{1.762093, 0.375771, -0.014302},{1.760020, 0.376445, -0.013399},{
      1.759686, 0.374335, -0.013399},{1.761866, 0.374335, -0.014302}}],
    Polygon[{{1.760020, 0.376445, -0.013399},{1.758106, 0.377066, -0.012166},{
      1.757674, 0.374335, -0.012166},{1.759686, 0.374335, -0.013399}}],
    Polygon[{{1.758106, 0.377066, -0.012166},{1.756400, 0.377621, -0.010634},{
      1.755880, 0.374335, -0.010634},{1.757674, 0.374335, -0.012166}}],
    Polygon[{{1.756400, 0.377621, -0.010634},{1.754942, 0.378094, -0.008839},{
      1.754347, 0.374335, -0.008839},{1.755880, 0.374335, -0.010634}}],
    Polygon[{{1.754942, 0.378094, -0.008839},{1.753770, 0.378475, -0.006827},{
      1.753114, 0.374335, -0.006827},{1.754347, 0.374335, -0.008839}}],
    Polygon[{{1.753770, 0.378475, -0.006827},{1.752911, 0.378754, -0.004647},{
      1.752211, 0.374335, -0.004647},{1.753114, 0.374335, -0.006827}}],
    Polygon[{{1.752911, 0.378754, -0.004647},{1.752387, 0.378925, -0.002352},{
      1.751660, 0.374335, -0.002352},{1.752211, 0.374335, -0.004647}}],
    Polygon[{{1.752387, 0.378925, -0.002352},{1.752211, 0.378982, 0.000000},{
      1.751475, 0.374335, 0.000000},{1.751660, 0.374335, -0.002352}}],
    Polygon[{{1.752211, 0.378982, 0.000000},{1.752387, 0.378925, 0.002352},{
      1.751660, 0.374335, 0.002352},{1.751475, 0.374335, 0.000000}}],
    Polygon[{{1.752387, 0.378925, 0.002352},{1.752911, 0.378754, 0.004647},{
      1.752211, 0.374335, 0.004647},{1.751660, 0.374335, 0.002352}}],
    Polygon[{{1.752911, 0.378754, 0.004647},{1.753770, 0.378475, 0.006827},{
      1.753114, 0.374335, 0.006827},{1.752211, 0.374335, 0.004647}}],
    Polygon[{{1.753770, 0.378475, 0.006827},{1.754942, 0.378094, 0.008839},{
      1.754347, 0.374335, 0.008839},{1.753114, 0.374335, 0.006827}}],
    Polygon[{{1.754942, 0.378094, 0.008839},{1.756400, 0.377621, 0.010634},{
      1.755880, 0.374335, 0.010634},{1.754347, 0.374335, 0.008839}}],
    Polygon[{{1.756400, 0.377621, 0.010634},{1.758106, 0.377066, 0.012166},{
      1.757674, 0.374335, 0.012166},{1.755880, 0.374335, 0.010634}}],
    Polygon[{{1.758106, 0.377066, 0.012166},{1.760020, 0.376445, 0.013399},{
      1.759686, 0.374335, 0.013399},{1.757674, 0.374335, 0.012166}}],
    Polygon[{{1.760020, 0.376445, 0.013399},{1.762093, 0.375771, 0.014302},{
      1.761866, 0.374335, 0.014302},{1.759686, 0.374335, 0.013399}}],
    Polygon[{{1.762093, 0.375771, 0.014302},{1.764276, 0.375062, 0.014853},{
      1.764161, 0.374335, 0.014853},{1.761866, 0.374335, 0.014302}}],
    Polygon[{{1.764161, 0.374335, -0.014853},{1.761866, 0.374335, -0.014302},{
      1.762093, 0.372899, -0.014302},{1.764276, 0.373608, -0.014853}}],
    Polygon[{{1.761866, 0.374335, -0.014302},{1.759686, 0.374335, -0.013399},{
      1.760020, 0.372225, -0.013399},{1.762093, 0.372899, -0.014302}}],
    Polygon[{{1.759686, 0.374335, -0.013399},{1.757674, 0.374335, -0.012166},{
      1.758106, 0.371603, -0.012166},{1.760020, 0.372225, -0.013399}}],
    Polygon[{{1.757674, 0.374335, -0.012166},{1.755880, 0.374335, -0.010634},{
      1.756400, 0.371049, -0.010634},{1.758106, 0.371603, -0.012166}}],
    Polygon[{{1.755880, 0.374335, -0.010634},{1.754347, 0.374335, -0.008839},{
      1.754942, 0.370575, -0.008839},{1.756400, 0.371049, -0.010634}}],
    Polygon[{{1.754347, 0.374335, -0.008839},{1.753114, 0.374335, -0.006827},{
      1.753770, 0.370194, -0.006827},{1.754942, 0.370575, -0.008839}}],
    Polygon[{{1.753114, 0.374335, -0.006827},{1.752211, 0.374335, -0.004647},{
      1.752911, 0.369915, -0.004647},{1.753770, 0.370194, -0.006827}}],
    Polygon[{{1.752211, 0.374335, -0.004647},{1.751660, 0.374335, -0.002352},{
      1.752387, 0.369745, -0.002352},{1.752911, 0.369915, -0.004647}}],
    Polygon[{{1.751660, 0.374335, -0.002352},{1.751475, 0.374335, 0.000000},{
      1.752211, 0.369688, 0.000000},{1.752387, 0.369745, -0.002352}}],
    Polygon[{{1.751475, 0.374335, 0.000000},{1.751660, 0.374335, 0.002352},{
      1.752387, 0.369745, 0.002352},{1.752211, 0.369688, 0.000000}}],
    Polygon[{{1.751660, 0.374335, 0.002352},{1.752211, 0.374335, 0.004647},{
      1.752911, 0.369915, 0.004647},{1.752387, 0.369745, 0.002352}}],
    Polygon[{{1.752211, 0.374335, 0.004647},{1.753114, 0.374335, 0.006827},{
      1.753770, 0.370194, 0.006827},{1.752911, 0.369915, 0.004647}}],
    Polygon[{{1.753114, 0.374335, 0.006827},{1.754347, 0.374335, 0.008839},{
      1.754942, 0.370575, 0.008839},{1.753770, 0.370194, 0.006827}}],
    Polygon[{{1.754347, 0.374335, 0.008839},{1.755880, 0.374335, 0.010634},{
      1.756400, 0.371049, 0.010634},{1.754942, 0.370575, 0.008839}}],
    Polygon[{{1.755880, 0.374335, 0.010634},{1.757674, 0.374335, 0.012166},{
      1.758106, 0.371603, 0.012166},{1.756400, 0.371049, 0.010634}}],
    Polygon[{{1.757674, 0.374335, 0.012166},{1.759686, 0.374335, 0.013399},{
      1.760020, 0.372225, 0.013399},{1.758106, 0.371603, 0.012166}}],
    Polygon[{{1.759686, 0.374335, 0.013399},{1.761866, 0.374335, 0.014302},{
      1.762093, 0.372899, 0.014302},{1.760020, 0.372225, 0.013399}}],
    Polygon[{{1.761866, 0.374335, 0.014302},{1.764161, 0.374335, 0.014853},{
      1.764276, 0.373608, 0.014853},{1.762093, 0.372899, 0.014302}}],
    Polygon[{{1.764276, 0.373608, -0.014853},{1.762093, 0.372899, -0.014302},{
      1.762753, 0.371603, -0.014302},{1.764610, 0.372952, -0.014853}}],
    Polygon[{{1.762093, 0.372899, -0.014302},{1.760020, 0.372225, -0.013399},{
      1.760990, 0.370322, -0.013399},{1.762753, 0.371603, -0.014302}}],
    Polygon[{{1.760020, 0.372225, -0.013399},{1.758106, 0.371603, -0.012166},{
      1.759362, 0.369139, -0.012166},{1.760990, 0.370322, -0.013399}}],
    Polygon[{{1.758106, 0.371603, -0.012166},{1.756400, 0.371049, -0.010634},{
      1.757910, 0.368085, -0.010634},{1.759362, 0.369139, -0.012166}}],
    Polygon[{{1.756400, 0.371049, -0.010634},{1.754942, 0.370575, -0.008839},{
      1.756670, 0.367184, -0.008839},{1.757910, 0.368085, -0.010634}}],
    Polygon[{{1.754942, 0.370575, -0.008839},{1.753770, 0.370194, -0.006827},{
      1.755673, 0.366459, -0.006827},{1.756670, 0.367184, -0.008839}}],
    Polygon[{{1.753770, 0.370194, -0.006827},{1.752911, 0.369915, -0.004647},{
      1.754942, 0.365928, -0.004647},{1.755673, 0.366459, -0.006827}}],
    Polygon[{{1.752911, 0.369915, -0.004647},{1.752387, 0.369745, -0.002352},{
      1.754497, 0.365604, -0.002352},{1.754942, 0.365928, -0.004647}}],
    Polygon[{{1.752387, 0.369745, -0.002352},{1.752211, 0.369688, 0.000000},{
      1.754347, 0.365496, 0.000000},{1.754497, 0.365604, -0.002352}}],
    Polygon[{{1.752211, 0.369688, 0.000000},{1.752387, 0.369745, 0.002352},{
      1.754497, 0.365604, 0.002352},{1.754347, 0.365496, 0.000000}}],
    Polygon[{{1.752387, 0.369745, 0.002352},{1.752911, 0.369915, 0.004647},{
      1.754942, 0.365928, 0.004647},{1.754497, 0.365604, 0.002352}}],
    Polygon[{{1.752911, 0.369915, 0.004647},{1.753770, 0.370194, 0.006827},{
      1.755673, 0.366459, 0.006827},{1.754942, 0.365928, 0.004647}}],
    Polygon[{{1.753770, 0.370194, 0.006827},{1.754942, 0.370575, 0.008839},{
      1.756670, 0.367184, 0.008839},{1.755673, 0.366459, 0.006827}}],
    Polygon[{{1.754942, 0.370575, 0.008839},{1.756400, 0.371049, 0.010634},{
      1.757910, 0.368085, 0.010634},{1.756670, 0.367184, 0.008839}}],
    Polygon[{{1.756400, 0.371049, 0.010634},{1.758106, 0.371603, 0.012166},{
      1.759362, 0.369139, 0.012166},{1.757910, 0.368085, 0.010634}}],
    Polygon[{{1.758106, 0.371603, 0.012166},{1.760020, 0.372225, 0.013399},{
      1.760990, 0.370322, 0.013399},{1.759362, 0.369139, 0.012166}}],
    Polygon[{{1.760020, 0.372225, 0.013399},{1.762093, 0.372899, 0.014302},{
      1.762753, 0.371603, 0.014302},{1.760990, 0.370322, 0.013399}}],
    Polygon[{{1.762093, 0.372899, 0.014302},{1.764276, 0.373608, 0.014853},{
      1.764610, 0.372952, 0.014853},{1.762753, 0.371603, 0.014302}}],
    Polygon[{{1.764610, 0.372952, -0.014853},{1.762753, 0.371603, -0.014302},{
      1.763782, 0.370575, -0.014302},{1.765130, 0.372432, -0.014853}}],
    Polygon[{{1.762753, 0.371603, -0.014302},{1.760990, 0.370322, -0.013399},{
      1.762500, 0.368812, -0.013399},{1.763782, 0.370575, -0.014302}}],
    Polygon[{{1.760990, 0.370322, -0.013399},{1.759362, 0.369139, -0.012166},{
      1.761317, 0.367184, -0.012166},{1.762500, 0.368812, -0.013399}}],
    Polygon[{{1.759362, 0.369139, -0.012166},{1.757910, 0.368085, -0.010634},{
      1.760263, 0.365732, -0.010634},{1.761317, 0.367184, -0.012166}}],
    Polygon[{{1.757910, 0.368085, -0.010634},{1.756670, 0.367184, -0.008839},{
      1.759362, 0.364492, -0.008839},{1.760263, 0.365732, -0.010634}}],
    Polygon[{{1.756670, 0.367184, -0.008839},{1.755673, 0.366459, -0.006827},{
      1.758637, 0.363495, -0.006827},{1.759362, 0.364492, -0.008839}}],
    Polygon[{{1.755673, 0.366459, -0.006827},{1.754942, 0.365928, -0.004647},{
      1.758106, 0.362764, -0.004647},{1.758637, 0.363495, -0.006827}}],
    Polygon[{{1.754942, 0.365928, -0.004647},{1.754497, 0.365604, -0.002352},{
      1.757783, 0.362319, -0.002352},{1.758106, 0.362764, -0.004647}}],
    Polygon[{{1.754497, 0.365604, -0.002352},{1.754347, 0.365496, 0.000000},{
      1.757674, 0.362169, 0.000000},{1.757783, 0.362319, -0.002352}}],
    Polygon[{{1.754347, 0.365496, 0.000000},{1.754497, 0.365604, 0.002352},{
      1.757783, 0.362319, 0.002352},{1.757674, 0.362169, 0.000000}}],
    Polygon[{{1.754497, 0.365604, 0.002352},{1.754942, 0.365928, 0.004647},{
      1.758106, 0.362764, 0.004647},{1.757783, 0.362319, 0.002352}}],
    Polygon[{{1.754942, 0.365928, 0.004647},{1.755673, 0.366459, 0.006827},{
      1.758637, 0.363495, 0.006827},{1.758106, 0.362764, 0.004647}}],
    Polygon[{{1.755673, 0.366459, 0.006827},{1.756670, 0.367184, 0.008839},{
      1.759362, 0.364492, 0.008839},{1.758637, 0.363495, 0.006827}}],
    Polygon[{{1.756670, 0.367184, 0.008839},{1.757910, 0.368085, 0.010634},{
      1.760263, 0.365732, 0.010634},{1.759362, 0.364492, 0.008839}}],
    Polygon[{{1.757910, 0.368085, 0.010634},{1.759362, 0.369139, 0.012166},{
      1.761317, 0.367184, 0.012166},{1.760263, 0.365732, 0.010634}}],
    Polygon[{{1.759362, 0.369139, 0.012166},{1.760990, 0.370322, 0.013399},{
      1.762500, 0.368812, 0.013399},{1.761317, 0.367184, 0.012166}}],
    Polygon[{{1.760990, 0.370322, 0.013399},{1.762753, 0.371603, 0.014302},{
      1.763782, 0.370575, 0.014302},{1.762500, 0.368812, 0.013399}}],
    Polygon[{{1.762753, 0.371603, 0.014302},{1.764610, 0.372952, 0.014853},{
      1.765130, 0.372432, 0.014853},{1.763782, 0.370575, 0.014302}}],
    Polygon[{{1.765130, 0.372432, -0.014853},{1.763782, 0.370575, -0.014302},{
      1.765077, 0.369915, -0.014302},{1.765786, 0.372098, -0.014853}}],
    Polygon[{{1.763782, 0.370575, -0.014302},{1.762500, 0.368812, -0.013399},{
      1.764403, 0.367842, -0.013399},{1.765077, 0.369915, -0.014302}}],
    Polygon[{{1.762500, 0.368812, -0.013399},{1.761317, 0.367184, -0.012166},{
      1.763782, 0.365928, -0.012166},{1.764403, 0.367842, -0.013399}}],
    Polygon[{{1.761317, 0.367184, -0.012166},{1.760263, 0.365732, -0.010634},{
      1.763227, 0.364222, -0.010634},{1.763782, 0.365928, -0.012166}}],
    Polygon[{{1.760263, 0.365732, -0.010634},{1.759362, 0.364492, -0.008839},{
      1.762753, 0.362764, -0.008839},{1.763227, 0.364222, -0.010634}}],
    Polygon[{{1.759362, 0.364492, -0.008839},{1.758637, 0.363495, -0.006827},{
      1.762372, 0.361592, -0.006827},{1.762753, 0.362764, -0.008839}}],
    Polygon[{{1.758637, 0.363495, -0.006827},{1.758106, 0.362764, -0.004647},{
      1.762093, 0.360733, -0.004647},{1.762372, 0.361592, -0.006827}}],
    Polygon[{{1.758106, 0.362764, -0.004647},{1.757783, 0.362319, -0.002352},{
      1.761923, 0.360209, -0.002352},{1.762093, 0.360733, -0.004647}}],
    Polygon[{{1.757783, 0.362319, -0.002352},{1.757674, 0.362169, 0.000000},{
      1.761866, 0.360033, 0.000000},{1.761923, 0.360209, -0.002352}}],
    Polygon[{{1.757674, 0.362169, 0.000000},{1.757783, 0.362319, 0.002352},{
      1.761923, 0.360209, 0.002352},{1.761866, 0.360033, 0.000000}}],
    Polygon[{{1.757783, 0.362319, 0.002352},{1.758106, 0.362764, 0.004647},{
      1.762093, 0.360733, 0.004647},{1.761923, 0.360209, 0.002352}}],
    Polygon[{{1.758106, 0.362764, 0.004647},{1.758637, 0.363495, 0.006827},{
      1.762372, 0.361592, 0.006827},{1.762093, 0.360733, 0.004647}}],
    Polygon[{{1.758637, 0.363495, 0.006827},{1.759362, 0.364492, 0.008839},{
      1.762753, 0.362764, 0.008839},{1.762372, 0.361592, 0.006827}}],
    Polygon[{{1.759362, 0.364492, 0.008839},{1.760263, 0.365732, 0.010634},{
      1.763227, 0.364222, 0.010634},{1.762753, 0.362764, 0.008839}}],
    Polygon[{{1.760263, 0.365732, 0.010634},{1.761317, 0.367184, 0.012166},{
      1.763782, 0.365928, 0.012166},{1.763227, 0.364222, 0.010634}}],
    Polygon[{{1.761317, 0.367184, 0.012166},{1.762500, 0.368812, 0.013399},{
      1.764403, 0.367842, 0.013399},{1.763782, 0.365928, 0.012166}}],
    Polygon[{{1.762500, 0.368812, 0.013399},{1.763782, 0.370575, 0.014302},{
      1.765077, 0.369915, 0.014302},{1.764403, 0.367842, 0.013399}}],
    Polygon[{{1.763782, 0.370575, 0.014302},{1.765130, 0.372432, 0.014853},{
      1.765786, 0.372098, 0.014853},{1.765077, 0.369915, 0.014302}}],
    Polygon[{{1.765786, 0.372098, -0.014853},{1.765077, 0.369915, -0.014302},{
      1.766513, 0.369688, -0.014302},{1.766513, 0.371982, -0.014853}}],
    Polygon[{{1.765077, 0.369915, -0.014302},{1.764403, 0.367842, -0.013399},{
      1.766513, 0.367508, -0.013399},{1.766513, 0.369688, -0.014302}}],
    Polygon[{{1.764403, 0.367842, -0.013399},{1.763782, 0.365928, -0.012166},{
      1.766513, 0.365496, -0.012166},{1.766513, 0.367508, -0.013399}}],
    Polygon[{{1.763782, 0.365928, -0.012166},{1.763227, 0.364222, -0.010634},{
      1.766513, 0.363701, -0.010634},{1.766513, 0.365496, -0.012166}}],
    Polygon[{{1.763227, 0.364222, -0.010634},{1.762753, 0.362764, -0.008839},{
      1.766513, 0.362169, -0.008839},{1.766513, 0.363701, -0.010634}}],
    Polygon[{{1.762753, 0.362764, -0.008839},{1.762372, 0.361592, -0.006827},{
      1.766513, 0.360936, -0.006827},{1.766513, 0.362169, -0.008839}}],
    Polygon[{{1.762372, 0.361592, -0.006827},{1.762093, 0.360733, -0.004647},{
      1.766513, 0.360033, -0.004647},{1.766513, 0.360936, -0.006827}}],
    Polygon[{{1.762093, 0.360733, -0.004647},{1.761923, 0.360209, -0.002352},{
      1.766513, 0.359482, -0.002352},{1.766513, 0.360033, -0.004647}}],
    Polygon[{{1.761923, 0.360209, -0.002352},{1.761866, 0.360033, 0.000000},{
      1.766513, 0.359297, 0.000000},{1.766513, 0.359482, -0.002352}}],
    Polygon[{{1.761866, 0.360033, 0.000000},{1.761923, 0.360209, 0.002352},{
      1.766513, 0.359482, 0.002352},{1.766513, 0.359297, 0.000000}}],
    Polygon[{{1.761923, 0.360209, 0.002352},{1.762093, 0.360733, 0.004647},{
      1.766513, 0.360033, 0.004647},{1.766513, 0.359482, 0.002352}}],
    Polygon[{{1.762093, 0.360733, 0.004647},{1.762372, 0.361592, 0.006827},{
      1.766513, 0.360936, 0.006827},{1.766513, 0.360033, 0.004647}}],
    Polygon[{{1.762372, 0.361592, 0.006827},{1.762753, 0.362764, 0.008839},{
      1.766513, 0.362169, 0.008839},{1.766513, 0.360936, 0.006827}}],
    Polygon[{{1.762753, 0.362764, 0.008839},{1.763227, 0.364222, 0.010634},{
      1.766513, 0.363701, 0.010634},{1.766513, 0.362169, 0.008839}}],
    Polygon[{{1.763227, 0.364222, 0.010634},{1.763782, 0.365928, 0.012166},{
      1.766513, 0.365496, 0.012166},{1.766513, 0.363701, 0.010634}}],
    Polygon[{{1.763782, 0.365928, 0.012166},{1.764403, 0.367842, 0.013399},{
      1.766513, 0.367508, 0.013399},{1.766513, 0.365496, 0.012166}}],
    Polygon[{{1.764403, 0.367842, 0.013399},{1.765077, 0.369915, 0.014302},{
      1.766513, 0.369688, 0.014302},{1.766513, 0.367508, 0.013399}}],
    Polygon[{{1.765077, 0.369915, 0.014302},{1.765786, 0.372098, 0.014853},{
      1.766513, 0.371982, 0.014853},{1.766513, 0.369688, 0.014302}}],
    Polygon[{{1.766513, 0.371982, -0.014853},{1.766513, 0.369688, -0.014302},{
      1.767949, 0.369915, -0.014302},{1.767240, 0.372098, -0.014853}}],
    Polygon[{{1.766513, 0.369688, -0.014302},{1.766513, 0.367508, -0.013399},{
      1.768623, 0.367842, -0.013399},{1.767949, 0.369915, -0.014302}}],
    Polygon[{{1.766513, 0.367508, -0.013399},{1.766513, 0.365496, -0.012166},{
      1.769245, 0.365928, -0.012166},{1.768623, 0.367842, -0.013399}}],
    Polygon[{{1.766513, 0.365496, -0.012166},{1.766513, 0.363701, -0.010634},{
      1.769799, 0.364222, -0.010634},{1.769245, 0.365928, -0.012166}}],
    Polygon[{{1.766513, 0.363701, -0.010634},{1.766513, 0.362169, -0.008839},{
      1.770273, 0.362764, -0.008839},{1.769799, 0.364222, -0.010634}}],
    Polygon[{{1.766513, 0.362169, -0.008839},{1.766513, 0.360936, -0.006827},{
      1.770654, 0.361592, -0.006827},{1.770273, 0.362764, -0.008839}}],
    Polygon[{{1.766513, 0.360936, -0.006827},{1.766513, 0.360033, -0.004647},{
      1.770933, 0.360733, -0.004647},{1.770654, 0.361592, -0.006827}}],
    Polygon[{{1.766513, 0.360033, -0.004647},{1.766513, 0.359482, -0.002352},{
      1.771103, 0.360209, -0.002352},{1.770933, 0.360733, -0.004647}}],
    Polygon[{{1.766513, 0.359482, -0.002352},{1.766513, 0.359297, 0.000000},{
      1.771160, 0.360033, 0.000000},{1.771103, 0.360209, -0.002352}}],
    Polygon[{{1.766513, 0.359297, 0.000000},{1.766513, 0.359482, 0.002352},{
      1.771103, 0.360209, 0.002352},{1.771160, 0.360033, 0.000000}}],
    Polygon[{{1.766513, 0.359482, 0.002352},{1.766513, 0.360033, 0.004647},{
      1.770933, 0.360733, 0.004647},{1.771103, 0.360209, 0.002352}}],
    Polygon[{{1.766513, 0.360033, 0.004647},{1.766513, 0.360936, 0.006827},{
      1.770654, 0.361592, 0.006827},{1.770933, 0.360733, 0.004647}}],
    Polygon[{{1.766513, 0.360936, 0.006827},{1.766513, 0.362169, 0.008839},{
      1.770273, 0.362764, 0.008839},{1.770654, 0.361592, 0.006827}}],
    Polygon[{{1.766513, 0.362169, 0.008839},{1.766513, 0.363701, 0.010634},{
      1.769799, 0.364222, 0.010634},{1.770273, 0.362764, 0.008839}}],
    Polygon[{{1.766513, 0.363701, 0.010634},{1.766513, 0.365496, 0.012166},{
      1.769245, 0.365928, 0.012166},{1.769799, 0.364222, 0.010634}}],
    Polygon[{{1.766513, 0.365496, 0.012166},{1.766513, 0.367508, 0.013399},{
      1.768623, 0.367842, 0.013399},{1.769245, 0.365928, 0.012166}}],
    Polygon[{{1.766513, 0.367508, 0.013399},{1.766513, 0.369688, 0.014302},{
      1.767949, 0.369915, 0.014302},{1.768623, 0.367842, 0.013399}}],
    Polygon[{{1.766513, 0.369688, 0.014302},{1.766513, 0.371982, 0.014853},{
      1.767240, 0.372098, 0.014853},{1.767949, 0.369915, 0.014302}}],
    Polygon[{{1.767240, 0.372098, -0.014853},{1.767949, 0.369915, -0.014302},{
      1.769245, 0.370575, -0.014302},{1.767896, 0.372432, -0.014853}}],
    Polygon[{{1.767949, 0.369915, -0.014302},{1.768623, 0.367842, -0.013399},{
      1.770526, 0.368812, -0.013399},{1.769245, 0.370575, -0.014302}}],
    Polygon[{{1.768623, 0.367842, -0.013399},{1.769245, 0.365928, -0.012166},{
      1.771709, 0.367184, -0.012166},{1.770526, 0.368812, -0.013399}}],
    Polygon[{{1.769245, 0.365928, -0.012166},{1.769799, 0.364222, -0.010634},{
      1.772763, 0.365732, -0.010634},{1.771709, 0.367184, -0.012166}}],
    Polygon[{{1.769799, 0.364222, -0.010634},{1.770273, 0.362764, -0.008839},{
      1.773664, 0.364492, -0.008839},{1.772763, 0.365732, -0.010634}}],
    Polygon[{{1.770273, 0.362764, -0.008839},{1.770654, 0.361592, -0.006827},{
      1.774389, 0.363495, -0.006827},{1.773664, 0.364492, -0.008839}}],
    Polygon[{{1.770654, 0.361592, -0.006827},{1.770933, 0.360733, -0.004647},{
      1.774920, 0.362764, -0.004647},{1.774389, 0.363495, -0.006827}}],
    Polygon[{{1.770933, 0.360733, -0.004647},{1.771103, 0.360209, -0.002352},{
      1.775243, 0.362319, -0.002352},{1.774920, 0.362764, -0.004647}}],
    Polygon[{{1.771103, 0.360209, -0.002352},{1.771160, 0.360033, 0.000000},{
      1.775352, 0.362169, 0.000000},{1.775243, 0.362319, -0.002352}}],
    Polygon[{{1.771160, 0.360033, 0.000000},{1.771103, 0.360209, 0.002352},{
      1.775243, 0.362319, 0.002352},{1.775352, 0.362169, 0.000000}}],
    Polygon[{{1.771103, 0.360209, 0.002352},{1.770933, 0.360733, 0.004647},{
      1.774920, 0.362764, 0.004647},{1.775243, 0.362319, 0.002352}}],
    Polygon[{{1.770933, 0.360733, 0.004647},{1.770654, 0.361592, 0.006827},{
      1.774389, 0.363495, 0.006827},{1.774920, 0.362764, 0.004647}}],
    Polygon[{{1.770654, 0.361592, 0.006827},{1.770273, 0.362764, 0.008839},{
      1.773664, 0.364492, 0.008839},{1.774389, 0.363495, 0.006827}}],
    Polygon[{{1.770273, 0.362764, 0.008839},{1.769799, 0.364222, 0.010634},{
      1.772763, 0.365732, 0.010634},{1.773664, 0.364492, 0.008839}}],
    Polygon[{{1.769799, 0.364222, 0.010634},{1.769245, 0.365928, 0.012166},{
      1.771709, 0.367184, 0.012166},{1.772763, 0.365732, 0.010634}}],
    Polygon[{{1.769245, 0.365928, 0.012166},{1.768623, 0.367842, 0.013399},{
      1.770526, 0.368812, 0.013399},{1.771709, 0.367184, 0.012166}}],
    Polygon[{{1.768623, 0.367842, 0.013399},{1.767949, 0.369915, 0.014302},{
      1.769245, 0.370575, 0.014302},{1.770526, 0.368812, 0.013399}}],
    Polygon[{{1.767949, 0.369915, 0.014302},{1.767240, 0.372098, 0.014853},{
      1.767896, 0.372432, 0.014853},{1.769245, 0.370575, 0.014302}}],
    Polygon[{{1.767896, 0.372432, -0.014853},{1.769245, 0.370575, -0.014302},{
      1.770273, 0.371603, -0.014302},{1.768416, 0.372952, -0.014853}}],
    Polygon[{{1.769245, 0.370575, -0.014302},{1.770526, 0.368812, -0.013399},{
      1.772036, 0.370322, -0.013399},{1.770273, 0.371603, -0.014302}}],
    Polygon[{{1.770526, 0.368812, -0.013399},{1.771709, 0.367184, -0.012166},{
      1.773664, 0.369139, -0.012166},{1.772036, 0.370322, -0.013399}}],
    Polygon[{{1.771709, 0.367184, -0.012166},{1.772763, 0.365732, -0.010634},{
      1.775116, 0.368085, -0.010634},{1.773664, 0.369139, -0.012166}}],
    Polygon[{{1.772763, 0.365732, -0.010634},{1.773664, 0.364492, -0.008839},{
      1.776356, 0.367184, -0.008839},{1.775116, 0.368085, -0.010634}}],
    Polygon[{{1.773664, 0.364492, -0.008839},{1.774389, 0.363495, -0.006827},{
      1.777353, 0.366459, -0.006827},{1.776356, 0.367184, -0.008839}}],
    Polygon[{{1.774389, 0.363495, -0.006827},{1.774920, 0.362764, -0.004647},{
      1.778084, 0.365928, -0.004647},{1.777353, 0.366459, -0.006827}}],
    Polygon[{{1.774920, 0.362764, -0.004647},{1.775243, 0.362319, -0.002352},{
      1.778529, 0.365604, -0.002352},{1.778084, 0.365928, -0.004647}}],
    Polygon[{{1.775243, 0.362319, -0.002352},{1.775352, 0.362169, 0.000000},{
      1.778679, 0.365496, 0.000000},{1.778529, 0.365604, -0.002352}}],
    Polygon[{{1.775352, 0.362169, 0.000000},{1.775243, 0.362319, 0.002352},{
      1.778529, 0.365604, 0.002352},{1.778679, 0.365496, 0.000000}}],
    Polygon[{{1.775243, 0.362319, 0.002352},{1.774920, 0.362764, 0.004647},{
      1.778084, 0.365928, 0.004647},{1.778529, 0.365604, 0.002352}}],
    Polygon[{{1.774920, 0.362764, 0.004647},{1.774389, 0.363495, 0.006827},{
      1.777353, 0.366459, 0.006827},{1.778084, 0.365928, 0.004647}}],
    Polygon[{{1.774389, 0.363495, 0.006827},{1.773664, 0.364492, 0.008839},{
      1.776356, 0.367184, 0.008839},{1.777353, 0.366459, 0.006827}}],
    Polygon[{{1.773664, 0.364492, 0.008839},{1.772763, 0.365732, 0.010634},{
      1.775116, 0.368085, 0.010634},{1.776356, 0.367184, 0.008839}}],
    Polygon[{{1.772763, 0.365732, 0.010634},{1.771709, 0.367184, 0.012166},{
      1.773664, 0.369139, 0.012166},{1.775116, 0.368085, 0.010634}}],
    Polygon[{{1.771709, 0.367184, 0.012166},{1.770526, 0.368812, 0.013399},{
      1.772036, 0.370322, 0.013399},{1.773664, 0.369139, 0.012166}}],
    Polygon[{{1.770526, 0.368812, 0.013399},{1.769245, 0.370575, 0.014302},{
      1.770273, 0.371603, 0.014302},{1.772036, 0.370322, 0.013399}}],
    Polygon[{{1.769245, 0.370575, 0.014302},{1.767896, 0.372432, 0.014853},{
      1.768416, 0.372952, 0.014853},{1.770273, 0.371603, 0.014302}}],
    Polygon[{{1.768416, 0.372952, -0.014853},{1.770273, 0.371603, -0.014302},{
      1.770933, 0.372899, -0.014302},{1.768750, 0.373608, -0.014853}}],
    Polygon[{{1.770273, 0.371603, -0.014302},{1.772036, 0.370322, -0.013399},{
      1.773006, 0.372225, -0.013399},{1.770933, 0.372899, -0.014302}}],
    Polygon[{{1.772036, 0.370322, -0.013399},{1.773664, 0.369139, -0.012166},{
      1.774920, 0.371603, -0.012166},{1.773006, 0.372225, -0.013399}}],
    Polygon[{{1.773664, 0.369139, -0.012166},{1.775116, 0.368085, -0.010634},{
      1.776626, 0.371049, -0.010634},{1.774920, 0.371603, -0.012166}}],
    Polygon[{{1.775116, 0.368085, -0.010634},{1.776356, 0.367184, -0.008839},{
      1.778084, 0.370575, -0.008839},{1.776626, 0.371049, -0.010634}}],
    Polygon[{{1.776356, 0.367184, -0.008839},{1.777353, 0.366459, -0.006827},{
      1.779256, 0.370194, -0.006827},{1.778084, 0.370575, -0.008839}}],
    Polygon[{{1.777353, 0.366459, -0.006827},{1.778084, 0.365928, -0.004647},{
      1.780115, 0.369915, -0.004647},{1.779256, 0.370194, -0.006827}}],
    Polygon[{{1.778084, 0.365928, -0.004647},{1.778529, 0.365604, -0.002352},{
      1.780639, 0.369745, -0.002352},{1.780115, 0.369915, -0.004647}}],
    Polygon[{{1.778529, 0.365604, -0.002352},{1.778679, 0.365496, 0.000000},{
      1.780815, 0.369688, 0.000000},{1.780639, 0.369745, -0.002352}}],
    Polygon[{{1.778679, 0.365496, 0.000000},{1.778529, 0.365604, 0.002352},{
      1.780639, 0.369745, 0.002352},{1.780815, 0.369688, 0.000000}}],
    Polygon[{{1.778529, 0.365604, 0.002352},{1.778084, 0.365928, 0.004647},{
      1.780115, 0.369915, 0.004647},{1.780639, 0.369745, 0.002352}}],
    Polygon[{{1.778084, 0.365928, 0.004647},{1.777353, 0.366459, 0.006827},{
      1.779256, 0.370194, 0.006827},{1.780115, 0.369915, 0.004647}}],
    Polygon[{{1.777353, 0.366459, 0.006827},{1.776356, 0.367184, 0.008839},{
      1.778084, 0.370575, 0.008839},{1.779256, 0.370194, 0.006827}}],
    Polygon[{{1.776356, 0.367184, 0.008839},{1.775116, 0.368085, 0.010634},{
      1.776626, 0.371049, 0.010634},{1.778084, 0.370575, 0.008839}}],
    Polygon[{{1.775116, 0.368085, 0.010634},{1.773664, 0.369139, 0.012166},{
      1.774920, 0.371603, 0.012166},{1.776626, 0.371049, 0.010634}}],
    Polygon[{{1.773664, 0.369139, 0.012166},{1.772036, 0.370322, 0.013399},{
      1.773006, 0.372225, 0.013399},{1.774920, 0.371603, 0.012166}}],
    Polygon[{{1.772036, 0.370322, 0.013399},{1.770273, 0.371603, 0.014302},{
      1.770933, 0.372899, 0.014302},{1.773006, 0.372225, 0.013399}}],
    Polygon[{{1.770273, 0.371603, 0.014302},{1.768416, 0.372952, 0.014853},{
      1.768750, 0.373608, 0.014853},{1.770933, 0.372899, 0.014302}}],
    Polygon[{{1.768750, 0.373608, -0.014853},{1.770933, 0.372899, -0.014302},{
      1.771160, 0.374335, -0.014302},{1.768866, 0.374335, -0.014853}}],
    Polygon[{{1.770933, 0.372899, -0.014302},{1.773006, 0.372225, -0.013399},{
      1.773340, 0.374335, -0.013399},{1.771160, 0.374335, -0.014302}}],
    Polygon[{{1.773006, 0.372225, -0.013399},{1.774920, 0.371603, -0.012166},{
      1.775352, 0.374335, -0.012166},{1.773340, 0.374335, -0.013399}}],
    Polygon[{{1.774920, 0.371603, -0.012166},{1.776626, 0.371049, -0.010634},{
      1.777147, 0.374335, -0.010634},{1.775352, 0.374335, -0.012166}}],
    Polygon[{{1.776626, 0.371049, -0.010634},{1.778084, 0.370575, -0.008839},{
      1.778679, 0.374335, -0.008839},{1.777147, 0.374335, -0.010634}}],
    Polygon[{{1.778084, 0.370575, -0.008839},{1.779256, 0.370194, -0.006827},{
      1.779912, 0.374335, -0.006827},{1.778679, 0.374335, -0.008839}}],
    Polygon[{{1.779256, 0.370194, -0.006827},{1.780115, 0.369915, -0.004647},{
      1.780815, 0.374335, -0.004647},{1.779912, 0.374335, -0.006827}}],
    Polygon[{{1.780115, 0.369915, -0.004647},{1.780639, 0.369745, -0.002352},{
      1.781366, 0.374335, -0.002352},{1.780815, 0.374335, -0.004647}}],
    Polygon[{{1.780639, 0.369745, -0.002352},{1.780815, 0.369688, 0.000000},{
      1.781551, 0.374335, 0.000000},{1.781366, 0.374335, -0.002352}}],
    Polygon[{{1.780815, 0.369688, 0.000000},{1.780639, 0.369745, 0.002352},{
      1.781366, 0.374335, 0.002352},{1.781551, 0.374335, 0.000000}}],
    Polygon[{{1.780639, 0.369745, 0.002352},{1.780115, 0.369915, 0.004647},{
      1.780815, 0.374335, 0.004647},{1.781366, 0.374335, 0.002352}}],
    Polygon[{{1.780115, 0.369915, 0.004647},{1.779256, 0.370194, 0.006827},{
      1.779912, 0.374335, 0.006827},{1.780815, 0.374335, 0.004647}}],
    Polygon[{{1.779256, 0.370194, 0.006827},{1.778084, 0.370575, 0.008839},{
      1.778679, 0.374335, 0.008839},{1.779912, 0.374335, 0.006827}}],
    Polygon[{{1.778084, 0.370575, 0.008839},{1.776626, 0.371049, 0.010634},{
      1.777147, 0.374335, 0.010634},{1.778679, 0.374335, 0.008839}}],
    Polygon[{{1.776626, 0.371049, 0.010634},{1.774920, 0.371603, 0.012166},{
      1.775352, 0.374335, 0.012166},{1.777147, 0.374335, 0.010634}}],
    Polygon[{{1.774920, 0.371603, 0.012166},{1.773006, 0.372225, 0.013399},{
      1.773340, 0.374335, 0.013399},{1.775352, 0.374335, 0.012166}}],
    Polygon[{{1.773006, 0.372225, 0.013399},{1.770933, 0.372899, 0.014302},{
      1.771160, 0.374335, 0.014302},{1.773340, 0.374335, 0.013399}}],
    Polygon[{{1.770933, 0.372899, 0.014302},{1.768750, 0.373608, 0.014853},{
      1.768866, 0.374335, 0.014853},{1.771160, 0.374335, 0.014302}}],
    Polygon[{{1.732780, 0.443561, -0.011012},{1.734481, 0.443561, -0.010603},{
      1.734313, 0.444626, -0.010603},{1.732695, 0.444100, -0.011012}}],
    Polygon[{{1.734481, 0.443561, -0.010603},{1.736097, 0.443561, -0.009934},{
      1.735850, 0.445126, -0.009934},{1.734313, 0.444626, -0.010603}}],
    Polygon[{{1.736097, 0.443561, -0.009934},{1.737589, 0.443561, -0.009020},{
      1.737268, 0.445587, -0.009020},{1.735850, 0.445126, -0.009934}}],
    Polygon[{{1.737589, 0.443561, -0.009020},{1.738919, 0.443561, -0.007884},{
      1.738534, 0.445998, -0.007884},{1.737268, 0.445587, -0.009020}}],
    Polygon[{{1.738919, 0.443561, -0.007884},{1.740056, 0.443561, -0.006553},{
      1.739614, 0.446349, -0.006553},{1.738534, 0.445998, -0.007884}}],
    Polygon[{{1.740056, 0.443561, -0.006553},{1.740970, 0.443561, -0.005062},{
      1.740484, 0.446631, -0.005062},{1.739614, 0.446349, -0.006553}}],
    Polygon[{{1.740970, 0.443561, -0.005062},{1.741639, 0.443561, -0.003445},{
      1.741120, 0.446838, -0.003445},{1.740484, 0.446631, -0.005062}}],
    Polygon[{{1.741639, 0.443561, -0.003445},{1.742048, 0.443561, -0.001744},{
      1.741509, 0.446964, -0.001744},{1.741120, 0.446838, -0.003445}}],
    Polygon[{{1.742048, 0.443561, -0.001744},{1.742185, 0.443561, 0.000000},{
      1.741639, 0.447007, 0.000000},{1.741509, 0.446964, -0.001744}}],
    Polygon[{{1.742185, 0.443561, 0.000000},{1.742048, 0.443561, 0.001744},{
      1.741509, 0.446964, 0.001744},{1.741639, 0.447007, 0.000000}}],
    Polygon[{{1.742048, 0.443561, 0.001744},{1.741639, 0.443561, 0.003445},{
      1.741120, 0.446838, 0.003445},{1.741509, 0.446964, 0.001744}}],
    Polygon[{{1.741639, 0.443561, 0.003445},{1.740970, 0.443561, 0.005062},{
      1.740484, 0.446631, 0.005062},{1.741120, 0.446838, 0.003445}}],
    Polygon[{{1.740970, 0.443561, 0.005062},{1.740056, 0.443561, 0.006553},{
      1.739614, 0.446349, 0.006553},{1.740484, 0.446631, 0.005062}}],
    Polygon[{{1.740056, 0.443561, 0.006553},{1.738919, 0.443561, 0.007884},{
      1.738534, 0.445998, 0.007884},{1.739614, 0.446349, 0.006553}}],
    Polygon[{{1.738919, 0.443561, 0.007884},{1.737589, 0.443561, 0.009020},{
      1.737268, 0.445587, 0.009020},{1.738534, 0.445998, 0.007884}}],
    Polygon[{{1.737589, 0.443561, 0.009020},{1.736097, 0.443561, 0.009934},{
      1.735850, 0.445126, 0.009934},{1.737268, 0.445587, 0.009020}}],
    Polygon[{{1.736097, 0.443561, 0.009934},{1.734481, 0.443561, 0.010603},{
      1.734313, 0.444626, 0.010603},{1.735850, 0.445126, 0.009934}}],
    Polygon[{{1.734481, 0.443561, 0.010603},{1.732780, 0.443561, 0.011012},{
      1.732695, 0.444100, 0.011012},{1.734313, 0.444626, 0.010603}}],
    Polygon[{{1.732695, 0.444100, -0.011012},{1.734313, 0.444626, -0.010603},{
      1.733823, 0.445587, -0.010603},{1.732447, 0.444587, -0.011012}}],
    Polygon[{{1.734313, 0.444626, -0.010603},{1.735850, 0.445126, -0.009934},{
      1.735131, 0.446537, -0.009934},{1.733823, 0.445587, -0.010603}}],
    Polygon[{{1.735850, 0.445126, -0.009934},{1.737268, 0.445587, -0.009020},{
      1.736338, 0.447413, -0.009020},{1.735131, 0.446537, -0.009934}}],
    Polygon[{{1.737268, 0.445587, -0.009020},{1.738534, 0.445998, -0.007884},{
      1.737414, 0.448195, -0.007884},{1.736338, 0.447413, -0.009020}}],
    Polygon[{{1.738534, 0.445998, -0.007884},{1.739614, 0.446349, -0.006553},{
      1.738333, 0.448863, -0.006553},{1.737414, 0.448195, -0.007884}}],
    Polygon[{{1.739614, 0.446349, -0.006553},{1.740484, 0.446631, -0.005062},{
      1.739073, 0.449400, -0.005062},{1.738333, 0.448863, -0.006553}}],
    Polygon[{{1.740484, 0.446631, -0.005062},{1.741120, 0.446838, -0.003445},{
      1.739614, 0.449794, -0.003445},{1.739073, 0.449400, -0.005062}}],
    Polygon[{{1.741120, 0.446838, -0.003445},{1.741509, 0.446964, -0.001744},{
      1.739945, 0.450034, -0.001744},{1.739614, 0.449794, -0.003445}}],
    Polygon[{{1.741509, 0.446964, -0.001744},{1.741639, 0.447007, 0.000000},{
      1.740056, 0.450115, 0.000000},{1.739945, 0.450034, -0.001744}}],
    Polygon[{{1.741639, 0.447007, 0.000000},{1.741509, 0.446964, 0.001744},{
      1.739945, 0.450034, 0.001744},{1.740056, 0.450115, 0.000000}}],
    Polygon[{{1.741509, 0.446964, 0.001744},{1.741120, 0.446838, 0.003445},{
      1.739614, 0.449794, 0.003445},{1.739945, 0.450034, 0.001744}}],
    Polygon[{{1.741120, 0.446838, 0.003445},{1.740484, 0.446631, 0.005062},{
      1.739073, 0.449400, 0.005062},{1.739614, 0.449794, 0.003445}}],
    Polygon[{{1.740484, 0.446631, 0.005062},{1.739614, 0.446349, 0.006553},{
      1.738333, 0.448863, 0.006553},{1.739073, 0.449400, 0.005062}}],
    Polygon[{{1.739614, 0.446349, 0.006553},{1.738534, 0.445998, 0.007884},{
      1.737414, 0.448195, 0.007884},{1.738333, 0.448863, 0.006553}}],
    Polygon[{{1.738534, 0.445998, 0.007884},{1.737268, 0.445587, 0.009020},{
      1.736338, 0.447413, 0.009020},{1.737414, 0.448195, 0.007884}}],
    Polygon[{{1.737268, 0.445587, 0.009020},{1.735850, 0.445126, 0.009934},{
      1.735131, 0.446537, 0.009934},{1.736338, 0.447413, 0.009020}}],
    Polygon[{{1.735850, 0.445126, 0.009934},{1.734313, 0.444626, 0.010603},{
      1.733823, 0.445587, 0.010603},{1.735131, 0.446537, 0.009934}}],
    Polygon[{{1.734313, 0.444626, 0.010603},{1.732695, 0.444100, 0.011012},{
      1.732447, 0.444587, 0.011012},{1.733823, 0.445587, 0.010603}}],
    Polygon[{{1.732447, 0.444587, -0.011012},{1.733823, 0.445587, -0.010603},{
      1.733061, 0.446349, -0.010603},{1.732061, 0.444972, -0.011012}}],
    Polygon[{{1.733823, 0.445587, -0.010603},{1.735131, 0.446537, -0.009934},{
      1.734011, 0.447656, -0.009934},{1.733061, 0.446349, -0.010603}}],
    Polygon[{{1.735131, 0.446537, -0.009934},{1.736338, 0.447413, -0.009020},{
      1.734888, 0.448863, -0.009020},{1.734011, 0.447656, -0.009934}}],
    Polygon[{{1.736338, 0.447413, -0.009020},{1.737414, 0.448195, -0.007884},{
      1.735670, 0.449939, -0.007884},{1.734888, 0.448863, -0.009020}}],
    Polygon[{{1.737414, 0.448195, -0.007884},{1.738333, 0.448863, -0.006553},{
      1.736338, 0.450859, -0.006553},{1.735670, 0.449939, -0.007884}}],
    Polygon[{{1.738333, 0.448863, -0.006553},{1.739073, 0.449400, -0.005062},{
      1.736875, 0.451598, -0.005062},{1.736338, 0.450859, -0.006553}}],
    Polygon[{{1.739073, 0.449400, -0.005062},{1.739614, 0.449794, -0.003445},{
      1.737268, 0.452140, -0.003445},{1.736875, 0.451598, -0.005062}}],
    Polygon[{{1.739614, 0.449794, -0.003445},{1.739945, 0.450034, -0.001744},{
      1.737508, 0.452470, -0.001744},{1.737268, 0.452140, -0.003445}}],
    Polygon[{{1.739945, 0.450034, -0.001744},{1.740056, 0.450115, 0.000000},{
      1.737589, 0.452581, 0.000000},{1.737508, 0.452470, -0.001744}}],
    Polygon[{{1.740056, 0.450115, 0.000000},{1.739945, 0.450034, 0.001744},{
      1.737508, 0.452470, 0.001744},{1.737589, 0.452581, 0.000000}}],
    Polygon[{{1.739945, 0.450034, 0.001744},{1.739614, 0.449794, 0.003445},{
      1.737268, 0.452140, 0.003445},{1.737508, 0.452470, 0.001744}}],
    Polygon[{{1.739614, 0.449794, 0.003445},{1.739073, 0.449400, 0.005062},{
      1.736875, 0.451598, 0.005062},{1.737268, 0.452140, 0.003445}}],
    Polygon[{{1.739073, 0.449400, 0.005062},{1.738333, 0.448863, 0.006553},{
      1.736338, 0.450859, 0.006553},{1.736875, 0.451598, 0.005062}}],
    Polygon[{{1.738333, 0.448863, 0.006553},{1.737414, 0.448195, 0.007884},{
      1.735670, 0.449939, 0.007884},{1.736338, 0.450859, 0.006553}}],
    Polygon[{{1.737414, 0.448195, 0.007884},{1.736338, 0.447413, 0.009020},{
      1.734888, 0.448863, 0.009020},{1.735670, 0.449939, 0.007884}}],
    Polygon[{{1.736338, 0.447413, 0.009020},{1.735131, 0.446537, 0.009934},{
      1.734011, 0.447656, 0.009934},{1.734888, 0.448863, 0.009020}}],
    Polygon[{{1.735131, 0.446537, 0.009934},{1.733823, 0.445587, 0.010603},{
      1.733061, 0.446349, 0.010603},{1.734011, 0.447656, 0.009934}}],
    Polygon[{{1.733823, 0.445587, 0.010603},{1.732447, 0.444587, 0.011012},{
      1.732061, 0.444972, 0.011012},{1.733061, 0.446349, 0.010603}}],
    Polygon[{{1.732061, 0.444972, -0.011012},{1.733061, 0.446349, -0.010603},{
      1.732100, 0.446838, -0.010603},{1.731575, 0.445220, -0.011012}}],
    Polygon[{{1.733061, 0.446349, -0.010603},{1.734011, 0.447656, -0.009934},{
      1.732600, 0.448375, -0.009934},{1.732100, 0.446838, -0.010603}}],
    Polygon[{{1.734011, 0.447656, -0.009934},{1.734888, 0.448863, -0.009020},{
      1.733061, 0.449794, -0.009020},{1.732600, 0.448375, -0.009934}}],
    Polygon[{{1.734888, 0.448863, -0.009020},{1.735670, 0.449939, -0.007884},{
      1.733472, 0.451059, -0.007884},{1.733061, 0.449794, -0.009020}}],
    Polygon[{{1.735670, 0.449939, -0.007884},{1.736338, 0.450859, -0.006553},{
      1.733823, 0.452140, -0.006553},{1.733472, 0.451059, -0.007884}}],
    Polygon[{{1.736338, 0.450859, -0.006553},{1.736875, 0.451598, -0.005062},{
      1.734106, 0.453009, -0.005062},{1.733823, 0.452140, -0.006553}}],
    Polygon[{{1.736875, 0.451598, -0.005062},{1.737268, 0.452140, -0.003445},{
      1.734313, 0.453646, -0.003445},{1.734106, 0.453009, -0.005062}}],
    Polygon[{{1.737268, 0.452140, -0.003445},{1.737508, 0.452470, -0.001744},{
      1.734439, 0.454034, -0.001744},{1.734313, 0.453646, -0.003445}}],
    Polygon[{{1.737508, 0.452470, -0.001744},{1.737589, 0.452581, 0.000000},{
      1.734481, 0.454165, 0.000000},{1.734439, 0.454034, -0.001744}}],
    Polygon[{{1.737589, 0.452581, 0.000000},{1.737508, 0.452470, 0.001744},{
      1.734439, 0.454034, 0.001744},{1.734481, 0.454165, 0.000000}}],
    Polygon[{{1.737508, 0.452470, 0.001744},{1.737268, 0.452140, 0.003445},{
      1.734313, 0.453646, 0.003445},{1.734439, 0.454034, 0.001744}}],
    Polygon[{{1.737268, 0.452140, 0.003445},{1.736875, 0.451598, 0.005062},{
      1.734106, 0.453009, 0.005062},{1.734313, 0.453646, 0.003445}}],
    Polygon[{{1.736875, 0.451598, 0.005062},{1.736338, 0.450859, 0.006553},{
      1.733823, 0.452140, 0.006553},{1.734106, 0.453009, 0.005062}}],
    Polygon[{{1.736338, 0.450859, 0.006553},{1.735670, 0.449939, 0.007884},{
      1.733472, 0.451059, 0.007884},{1.733823, 0.452140, 0.006553}}],
    Polygon[{{1.735670, 0.449939, 0.007884},{1.734888, 0.448863, 0.009020},{
      1.733061, 0.449794, 0.009020},{1.733472, 0.451059, 0.007884}}],
    Polygon[{{1.734888, 0.448863, 0.009020},{1.734011, 0.447656, 0.009934},{
      1.732600, 0.448375, 0.009934},{1.733061, 0.449794, 0.009020}}],
    Polygon[{{1.734011, 0.447656, 0.009934},{1.733061, 0.446349, 0.010603},{
      1.732100, 0.446838, 0.010603},{1.732600, 0.448375, 0.009934}}],
    Polygon[{{1.733061, 0.446349, 0.010603},{1.732061, 0.444972, 0.011012},{
      1.731575, 0.445220, 0.011012},{1.732100, 0.446838, 0.010603}}],
    Polygon[{{1.731575, 0.445220, -0.011012},{1.732100, 0.446838, -0.010603},{
      1.731036, 0.447007, -0.010603},{1.731036, 0.445306, -0.011012}}],
    Polygon[{{1.732100, 0.446838, -0.010603},{1.732600, 0.448375, -0.009934},{
      1.731036, 0.448623, -0.009934},{1.731036, 0.447007, -0.010603}}],
    Polygon[{{1.732600, 0.448375, -0.009934},{1.733061, 0.449794, -0.009020},{
      1.731036, 0.450115, -0.009020},{1.731036, 0.448623, -0.009934}}],
    Polygon[{{1.733061, 0.449794, -0.009020},{1.733472, 0.451059, -0.007884},{
      1.731036, 0.451445, -0.007884},{1.731036, 0.450115, -0.009020}}],
    Polygon[{{1.733472, 0.451059, -0.007884},{1.733823, 0.452140, -0.006553},{
      1.731036, 0.452581, -0.006553},{1.731036, 0.451445, -0.007884}}],
    Polygon[{{1.733823, 0.452140, -0.006553},{1.734106, 0.453009, -0.005062},{
      1.731036, 0.453495, -0.005062},{1.731036, 0.452581, -0.006553}}],
    Polygon[{{1.734106, 0.453009, -0.005062},{1.734313, 0.453646, -0.003445},{
      1.731036, 0.454165, -0.003445},{1.731036, 0.453495, -0.005062}}],
    Polygon[{{1.734313, 0.453646, -0.003445},{1.734439, 0.454034, -0.001744},{
      1.731036, 0.454573, -0.001744},{1.731036, 0.454165, -0.003445}}],
    Polygon[{{1.734439, 0.454034, -0.001744},{1.734481, 0.454165, 0.000000},{
      1.731036, 0.454710, 0.000000},{1.731036, 0.454573, -0.001744}}],
    Polygon[{{1.734481, 0.454165, 0.000000},{1.734439, 0.454034, 0.001744},{
      1.731036, 0.454573, 0.001744},{1.731036, 0.454710, 0.000000}}],
    Polygon[{{1.734439, 0.454034, 0.001744},{1.734313, 0.453646, 0.003445},{
      1.731036, 0.454165, 0.003445},{1.731036, 0.454573, 0.001744}}],
    Polygon[{{1.734313, 0.453646, 0.003445},{1.734106, 0.453009, 0.005062},{
      1.731036, 0.453495, 0.005062},{1.731036, 0.454165, 0.003445}}],
    Polygon[{{1.734106, 0.453009, 0.005062},{1.733823, 0.452140, 0.006553},{
      1.731036, 0.452581, 0.006553},{1.731036, 0.453495, 0.005062}}],
    Polygon[{{1.733823, 0.452140, 0.006553},{1.733472, 0.451059, 0.007884},{
      1.731036, 0.451445, 0.007884},{1.731036, 0.452581, 0.006553}}],
    Polygon[{{1.733472, 0.451059, 0.007884},{1.733061, 0.449794, 0.009020},{
      1.731036, 0.450115, 0.009020},{1.731036, 0.451445, 0.007884}}],
    Polygon[{{1.733061, 0.449794, 0.009020},{1.732600, 0.448375, 0.009934},{
      1.731036, 0.448623, 0.009934},{1.731036, 0.450115, 0.009020}}],
    Polygon[{{1.732600, 0.448375, 0.009934},{1.732100, 0.446838, 0.010603},{
      1.731036, 0.447007, 0.010603},{1.731036, 0.448623, 0.009934}}],
    Polygon[{{1.732100, 0.446838, 0.010603},{1.731575, 0.445220, 0.011012},{
      1.731036, 0.445306, 0.011012},{1.731036, 0.447007, 0.010603}}],
    Polygon[{{1.731036, 0.445306, -0.011012},{1.731036, 0.447007, -0.010603},{
      1.729971, 0.446838, -0.010603},{1.730497, 0.445220, -0.011012}}],
    Polygon[{{1.731036, 0.447007, -0.010603},{1.731036, 0.448623, -0.009934},{
      1.729472, 0.448375, -0.009934},{1.729971, 0.446838, -0.010603}}],
    Polygon[{{1.731036, 0.448623, -0.009934},{1.731036, 0.450115, -0.009020},{
      1.729011, 0.449794, -0.009020},{1.729472, 0.448375, -0.009934}}],
    Polygon[{{1.731036, 0.450115, -0.009020},{1.731036, 0.451445, -0.007884},{
      1.728600, 0.451059, -0.007884},{1.729011, 0.449794, -0.009020}}],
    Polygon[{{1.731036, 0.451445, -0.007884},{1.731036, 0.452581, -0.006553},{
      1.728249, 0.452140, -0.006553},{1.728600, 0.451059, -0.007884}}],
    Polygon[{{1.731036, 0.452581, -0.006553},{1.731036, 0.453495, -0.005062},{
      1.727966, 0.453009, -0.005062},{1.728249, 0.452140, -0.006553}}],
    Polygon[{{1.731036, 0.453495, -0.005062},{1.731036, 0.454165, -0.003445},{
      1.727759, 0.453646, -0.003445},{1.727966, 0.453009, -0.005062}}],
    Polygon[{{1.731036, 0.454165, -0.003445},{1.731036, 0.454573, -0.001744},{
      1.727633, 0.454034, -0.001744},{1.727759, 0.453646, -0.003445}}],
    Polygon[{{1.731036, 0.454573, -0.001744},{1.731036, 0.454710, 0.000000},{
      1.727591, 0.454165, 0.000000},{1.727633, 0.454034, -0.001744}}],
    Polygon[{{1.731036, 0.454710, 0.000000},{1.731036, 0.454573, 0.001744},{
      1.727633, 0.454034, 0.001744},{1.727591, 0.454165, 0.000000}}],
    Polygon[{{1.731036, 0.454573, 0.001744},{1.731036, 0.454165, 0.003445},{
      1.727759, 0.453646, 0.003445},{1.727633, 0.454034, 0.001744}}],
    Polygon[{{1.731036, 0.454165, 0.003445},{1.731036, 0.453495, 0.005062},{
      1.727966, 0.453009, 0.005062},{1.727759, 0.453646, 0.003445}}],
    Polygon[{{1.731036, 0.453495, 0.005062},{1.731036, 0.452581, 0.006553},{
      1.728249, 0.452140, 0.006553},{1.727966, 0.453009, 0.005062}}],
    Polygon[{{1.731036, 0.452581, 0.006553},{1.731036, 0.451445, 0.007884},{
      1.728600, 0.451059, 0.007884},{1.728249, 0.452140, 0.006553}}],
    Polygon[{{1.731036, 0.451445, 0.007884},{1.731036, 0.450115, 0.009020},{
      1.729011, 0.449794, 0.009020},{1.728600, 0.451059, 0.007884}}],
    Polygon[{{1.731036, 0.450115, 0.009020},{1.731036, 0.448623, 0.009934},{
      1.729472, 0.448375, 0.009934},{1.729011, 0.449794, 0.009020}}],
    Polygon[{{1.731036, 0.448623, 0.009934},{1.731036, 0.447007, 0.010603},{
      1.729971, 0.446838, 0.010603},{1.729472, 0.448375, 0.009934}}],
    Polygon[{{1.731036, 0.447007, 0.010603},{1.731036, 0.445306, 0.011012},{
      1.730497, 0.445220, 0.011012},{1.729971, 0.446838, 0.010603}}],
    Polygon[{{1.730497, 0.445220, -0.011012},{1.729971, 0.446838, -0.010603},{
      1.729011, 0.446349, -0.010603},{1.730011, 0.444972, -0.011012}}],
    Polygon[{{1.729971, 0.446838, -0.010603},{1.729472, 0.448375, -0.009934},{
      1.728061, 0.447656, -0.009934},{1.729011, 0.446349, -0.010603}}],
    Polygon[{{1.729472, 0.448375, -0.009934},{1.729011, 0.449794, -0.009020},{
      1.727184, 0.448863, -0.009020},{1.728061, 0.447656, -0.009934}}],
    Polygon[{{1.729011, 0.449794, -0.009020},{1.728600, 0.451059, -0.007884},{
      1.726402, 0.449939, -0.007884},{1.727184, 0.448863, -0.009020}}],
    Polygon[{{1.728600, 0.451059, -0.007884},{1.728249, 0.452140, -0.006553},{
      1.725734, 0.450859, -0.006553},{1.726402, 0.449939, -0.007884}}],
    Polygon[{{1.728249, 0.452140, -0.006553},{1.727966, 0.453009, -0.005062},{
      1.725197, 0.451598, -0.005062},{1.725734, 0.450859, -0.006553}}],
    Polygon[{{1.727966, 0.453009, -0.005062},{1.727759, 0.453646, -0.003445},{
      1.724803, 0.452140, -0.003445},{1.725197, 0.451598, -0.005062}}],
    Polygon[{{1.727759, 0.453646, -0.003445},{1.727633, 0.454034, -0.001744},{
      1.724563, 0.452470, -0.001744},{1.724803, 0.452140, -0.003445}}],
    Polygon[{{1.727633, 0.454034, -0.001744},{1.727591, 0.454165, 0.000000},{
      1.724483, 0.452581, 0.000000},{1.724563, 0.452470, -0.001744}}],
    Polygon[{{1.727591, 0.454165, 0.000000},{1.727633, 0.454034, 0.001744},{
      1.724563, 0.452470, 0.001744},{1.724483, 0.452581, 0.000000}}],
    Polygon[{{1.727633, 0.454034, 0.001744},{1.727759, 0.453646, 0.003445},{
      1.724803, 0.452140, 0.003445},{1.724563, 0.452470, 0.001744}}],
    Polygon[{{1.727759, 0.453646, 0.003445},{1.727966, 0.453009, 0.005062},{
      1.725197, 0.451598, 0.005062},{1.724803, 0.452140, 0.003445}}],
    Polygon[{{1.727966, 0.453009, 0.005062},{1.728249, 0.452140, 0.006553},{
      1.725734, 0.450859, 0.006553},{1.725197, 0.451598, 0.005062}}],
    Polygon[{{1.728249, 0.452140, 0.006553},{1.728600, 0.451059, 0.007884},{
      1.726402, 0.449939, 0.007884},{1.725734, 0.450859, 0.006553}}],
    Polygon[{{1.728600, 0.451059, 0.007884},{1.729011, 0.449794, 0.009020},{
      1.727184, 0.448863, 0.009020},{1.726402, 0.449939, 0.007884}}],
    Polygon[{{1.729011, 0.449794, 0.009020},{1.729472, 0.448375, 0.009934},{
      1.728061, 0.447656, 0.009934},{1.727184, 0.448863, 0.009020}}],
    Polygon[{{1.729472, 0.448375, 0.009934},{1.729971, 0.446838, 0.010603},{
      1.729011, 0.446349, 0.010603},{1.728061, 0.447656, 0.009934}}],
    Polygon[{{1.729971, 0.446838, 0.010603},{1.730497, 0.445220, 0.011012},{
      1.730011, 0.444972, 0.011012},{1.729011, 0.446349, 0.010603}}],
    Polygon[{{1.730011, 0.444972, -0.011012},{1.729011, 0.446349, -0.010603},{
      1.728249, 0.445587, -0.010603},{1.729625, 0.444587, -0.011012}}],
    Polygon[{{1.729011, 0.446349, -0.010603},{1.728061, 0.447656, -0.009934},{
      1.726941, 0.446537, -0.009934},{1.728249, 0.445587, -0.010603}}],
    Polygon[{{1.728061, 0.447656, -0.009934},{1.727184, 0.448863, -0.009020},{
      1.725734, 0.447413, -0.009020},{1.726941, 0.446537, -0.009934}}],
    Polygon[{{1.727184, 0.448863, -0.009020},{1.726402, 0.449939, -0.007884},{
      1.724658, 0.448195, -0.007884},{1.725734, 0.447413, -0.009020}}],
    Polygon[{{1.726402, 0.449939, -0.007884},{1.725734, 0.450859, -0.006553},{
      1.723739, 0.448863, -0.006553},{1.724658, 0.448195, -0.007884}}],
    Polygon[{{1.725734, 0.450859, -0.006553},{1.725197, 0.451598, -0.005062},{
      1.722999, 0.449400, -0.005062},{1.723739, 0.448863, -0.006553}}],
    Polygon[{{1.725197, 0.451598, -0.005062},{1.724803, 0.452140, -0.003445},{
      1.722458, 0.449794, -0.003445},{1.722999, 0.449400, -0.005062}}],
    Polygon[{{1.724803, 0.452140, -0.003445},{1.724563, 0.452470, -0.001744},{
      1.722127, 0.450034, -0.001744},{1.722458, 0.449794, -0.003445}}],
    Polygon[{{1.724563, 0.452470, -0.001744},{1.724483, 0.452581, 0.000000},{
      1.722016, 0.450115, 0.000000},{1.722127, 0.450034, -0.001744}}],
    Polygon[{{1.724483, 0.452581, 0.000000},{1.724563, 0.452470, 0.001744},{
      1.722127, 0.450034, 0.001744},{1.722016, 0.450115, 0.000000}}],
    Polygon[{{1.724563, 0.452470, 0.001744},{1.724803, 0.452140, 0.003445},{
      1.722458, 0.449794, 0.003445},{1.722127, 0.450034, 0.001744}}],
    Polygon[{{1.724803, 0.452140, 0.003445},{1.725197, 0.451598, 0.005062},{
      1.722999, 0.449400, 0.005062},{1.722458, 0.449794, 0.003445}}],
    Polygon[{{1.725197, 0.451598, 0.005062},{1.725734, 0.450859, 0.006553},{
      1.723739, 0.448863, 0.006553},{1.722999, 0.449400, 0.005062}}],
    Polygon[{{1.725734, 0.450859, 0.006553},{1.726402, 0.449939, 0.007884},{
      1.724658, 0.448195, 0.007884},{1.723739, 0.448863, 0.006553}}],
    Polygon[{{1.726402, 0.449939, 0.007884},{1.727184, 0.448863, 0.009020},{
      1.725734, 0.447413, 0.009020},{1.724658, 0.448195, 0.007884}}],
    Polygon[{{1.727184, 0.448863, 0.009020},{1.728061, 0.447656, 0.009934},{
      1.726941, 0.446537, 0.009934},{1.725734, 0.447413, 0.009020}}],
    Polygon[{{1.728061, 0.447656, 0.009934},{1.729011, 0.446349, 0.010603},{
      1.728249, 0.445587, 0.010603},{1.726941, 0.446537, 0.009934}}],
    Polygon[{{1.729011, 0.446349, 0.010603},{1.730011, 0.444972, 0.011012},{
      1.729625, 0.444587, 0.011012},{1.728249, 0.445587, 0.010603}}],
    Polygon[{{1.729625, 0.444587, -0.011012},{1.728249, 0.445587, -0.010603},{
      1.727759, 0.444626, -0.010603},{1.729377, 0.444100, -0.011012}}],
    Polygon[{{1.728249, 0.445587, -0.010603},{1.726941, 0.446537, -0.009934},{
      1.726222, 0.445126, -0.009934},{1.727759, 0.444626, -0.010603}}],
    Polygon[{{1.726941, 0.446537, -0.009934},{1.725734, 0.447413, -0.009020},{
      1.724803, 0.445587, -0.009020},{1.726222, 0.445126, -0.009934}}],
    Polygon[{{1.725734, 0.447413, -0.009020},{1.724658, 0.448195, -0.007884},{
      1.723538, 0.445998, -0.007884},{1.724803, 0.445587, -0.009020}}],
    Polygon[{{1.724658, 0.448195, -0.007884},{1.723739, 0.448863, -0.006553},{
      1.722458, 0.446349, -0.006553},{1.723538, 0.445998, -0.007884}}],
    Polygon[{{1.723739, 0.448863, -0.006553},{1.722999, 0.449400, -0.005062},{
      1.721588, 0.446631, -0.005062},{1.722458, 0.446349, -0.006553}}],
    Polygon[{{1.722999, 0.449400, -0.005062},{1.722458, 0.449794, -0.003445},{
      1.720951, 0.446838, -0.003445},{1.721588, 0.446631, -0.005062}}],
    Polygon[{{1.722458, 0.449794, -0.003445},{1.722127, 0.450034, -0.001744},{
      1.720563, 0.446964, -0.001744},{1.720951, 0.446838, -0.003445}}],
    Polygon[{{1.722127, 0.450034, -0.001744},{1.722016, 0.450115, 0.000000},{
      1.720432, 0.447007, 0.000000},{1.720563, 0.446964, -0.001744}}],
    Polygon[{{1.722016, 0.450115, 0.000000},{1.722127, 0.450034, 0.001744},{
      1.720563, 0.446964, 0.001744},{1.720432, 0.447007, 0.000000}}],
    Polygon[{{1.722127, 0.450034, 0.001744},{1.722458, 0.449794, 0.003445},{
      1.720951, 0.446838, 0.003445},{1.720563, 0.446964, 0.001744}}],
    Polygon[{{1.722458, 0.449794, 0.003445},{1.722999, 0.449400, 0.005062},{
      1.721588, 0.446631, 0.005062},{1.720951, 0.446838, 0.003445}}],
    Polygon[{{1.722999, 0.449400, 0.005062},{1.723739, 0.448863, 0.006553},{
      1.722458, 0.446349, 0.006553},{1.721588, 0.446631, 0.005062}}],
    Polygon[{{1.723739, 0.448863, 0.006553},{1.724658, 0.448195, 0.007884},{
      1.723538, 0.445998, 0.007884},{1.722458, 0.446349, 0.006553}}],
    Polygon[{{1.724658, 0.448195, 0.007884},{1.725734, 0.447413, 0.009020},{
      1.724803, 0.445587, 0.009020},{1.723538, 0.445998, 0.007884}}],
    Polygon[{{1.725734, 0.447413, 0.009020},{1.726941, 0.446537, 0.009934},{
      1.726222, 0.445126, 0.009934},{1.724803, 0.445587, 0.009020}}],
    Polygon[{{1.726941, 0.446537, 0.009934},{1.728249, 0.445587, 0.010603},{
      1.727759, 0.444626, 0.010603},{1.726222, 0.445126, 0.009934}}],
    Polygon[{{1.728249, 0.445587, 0.010603},{1.729625, 0.444587, 0.011012},{
      1.729377, 0.444100, 0.011012},{1.727759, 0.444626, 0.010603}}],
    Polygon[{{1.729377, 0.444100, -0.011012},{1.727759, 0.444626, -0.010603},{
      1.727591, 0.443561, -0.010603},{1.729292, 0.443561, -0.011012}}],
    Polygon[{{1.727759, 0.444626, -0.010603},{1.726222, 0.445126, -0.009934},{
      1.725974, 0.443561, -0.009934},{1.727591, 0.443561, -0.010603}}],
    Polygon[{{1.726222, 0.445126, -0.009934},{1.724803, 0.445587, -0.009020},{
      1.724483, 0.443561, -0.009020},{1.725974, 0.443561, -0.009934}}],
    Polygon[{{1.724803, 0.445587, -0.009020},{1.723538, 0.445998, -0.007884},{
      1.723152, 0.443561, -0.007884},{1.724483, 0.443561, -0.009020}}],
    Polygon[{{1.723538, 0.445998, -0.007884},{1.722458, 0.446349, -0.006553},{
      1.722016, 0.443561, -0.006553},{1.723152, 0.443561, -0.007884}}],
    Polygon[{{1.722458, 0.446349, -0.006553},{1.721588, 0.446631, -0.005062},{
      1.721102, 0.443561, -0.005062},{1.722016, 0.443561, -0.006553}}],
    Polygon[{{1.721588, 0.446631, -0.005062},{1.720951, 0.446838, -0.003445},{
      1.720432, 0.443561, -0.003445},{1.721102, 0.443561, -0.005062}}],
    Polygon[{{1.720951, 0.446838, -0.003445},{1.720563, 0.446964, -0.001744},{
      1.720024, 0.443561, -0.001744},{1.720432, 0.443561, -0.003445}}],
    Polygon[{{1.720563, 0.446964, -0.001744},{1.720432, 0.447007, 0.000000},{
      1.719887, 0.443561, 0.000000},{1.720024, 0.443561, -0.001744}}],
    Polygon[{{1.720432, 0.447007, 0.000000},{1.720563, 0.446964, 0.001744},{
      1.720024, 0.443561, 0.001744},{1.719887, 0.443561, 0.000000}}],
    Polygon[{{1.720563, 0.446964, 0.001744},{1.720951, 0.446838, 0.003445},{
      1.720432, 0.443561, 0.003445},{1.720024, 0.443561, 0.001744}}],
    Polygon[{{1.720951, 0.446838, 0.003445},{1.721588, 0.446631, 0.005062},{
      1.721102, 0.443561, 0.005062},{1.720432, 0.443561, 0.003445}}],
    Polygon[{{1.721588, 0.446631, 0.005062},{1.722458, 0.446349, 0.006553},{
      1.722016, 0.443561, 0.006553},{1.721102, 0.443561, 0.005062}}],
    Polygon[{{1.722458, 0.446349, 0.006553},{1.723538, 0.445998, 0.007884},{
      1.723152, 0.443561, 0.007884},{1.722016, 0.443561, 0.006553}}],
    Polygon[{{1.723538, 0.445998, 0.007884},{1.724803, 0.445587, 0.009020},{
      1.724483, 0.443561, 0.009020},{1.723152, 0.443561, 0.007884}}],
    Polygon[{{1.724803, 0.445587, 0.009020},{1.726222, 0.445126, 0.009934},{
      1.725974, 0.443561, 0.009934},{1.724483, 0.443561, 0.009020}}],
    Polygon[{{1.726222, 0.445126, 0.009934},{1.727759, 0.444626, 0.010603},{
      1.727591, 0.443561, 0.010603},{1.725974, 0.443561, 0.009934}}],
    Polygon[{{1.727759, 0.444626, 0.010603},{1.729377, 0.444100, 0.011012},{
      1.729292, 0.443561, 0.011012},{1.727591, 0.443561, 0.010603}}],
    Polygon[{{1.729292, 0.443561, -0.011012},{1.727591, 0.443561, -0.010603},{
      1.727759, 0.442497, -0.010603},{1.729377, 0.443022, -0.011012}}],
    Polygon[{{1.727591, 0.443561, -0.010603},{1.725974, 0.443561, -0.009934},{
      1.726222, 0.441997, -0.009934},{1.727759, 0.442497, -0.010603}}],
    Polygon[{{1.725974, 0.443561, -0.009934},{1.724483, 0.443561, -0.009020},{
      1.724803, 0.441536, -0.009020},{1.726222, 0.441997, -0.009934}}],
    Polygon[{{1.724483, 0.443561, -0.009020},{1.723152, 0.443561, -0.007884},{
      1.723538, 0.441125, -0.007884},{1.724803, 0.441536, -0.009020}}],
    Polygon[{{1.723152, 0.443561, -0.007884},{1.722016, 0.443561, -0.006553},{
      1.722458, 0.440774, -0.006553},{1.723538, 0.441125, -0.007884}}],
    Polygon[{{1.722016, 0.443561, -0.006553},{1.721102, 0.443561, -0.005062},{
      1.721588, 0.440492, -0.005062},{1.722458, 0.440774, -0.006553}}],
    Polygon[{{1.721102, 0.443561, -0.005062},{1.720432, 0.443561, -0.003445},{
      1.720951, 0.440285, -0.003445},{1.721588, 0.440492, -0.005062}}],
    Polygon[{{1.720432, 0.443561, -0.003445},{1.720024, 0.443561, -0.001744},{
      1.720563, 0.440159, -0.001744},{1.720951, 0.440285, -0.003445}}],
    Polygon[{{1.720024, 0.443561, -0.001744},{1.719887, 0.443561, 0.000000},{
      1.720432, 0.440116, 0.000000},{1.720563, 0.440159, -0.001744}}],
    Polygon[{{1.719887, 0.443561, 0.000000},{1.720024, 0.443561, 0.001744},{
      1.720563, 0.440159, 0.001744},{1.720432, 0.440116, 0.000000}}],
    Polygon[{{1.720024, 0.443561, 0.001744},{1.720432, 0.443561, 0.003445},{
      1.720951, 0.440285, 0.003445},{1.720563, 0.440159, 0.001744}}],
    Polygon[{{1.720432, 0.443561, 0.003445},{1.721102, 0.443561, 0.005062},{
      1.721588, 0.440492, 0.005062},{1.720951, 0.440285, 0.003445}}],
    Polygon[{{1.721102, 0.443561, 0.005062},{1.722016, 0.443561, 0.006553},{
      1.722458, 0.440774, 0.006553},{1.721588, 0.440492, 0.005062}}],
    Polygon[{{1.722016, 0.443561, 0.006553},{1.723152, 0.443561, 0.007884},{
      1.723538, 0.441125, 0.007884},{1.722458, 0.440774, 0.006553}}],
    Polygon[{{1.723152, 0.443561, 0.007884},{1.724483, 0.443561, 0.009020},{
      1.724803, 0.441536, 0.009020},{1.723538, 0.441125, 0.007884}}],
    Polygon[{{1.724483, 0.443561, 0.009020},{1.725974, 0.443561, 0.009934},{
      1.726222, 0.441997, 0.009934},{1.724803, 0.441536, 0.009020}}],
    Polygon[{{1.725974, 0.443561, 0.009934},{1.727591, 0.443561, 0.010603},{
      1.727759, 0.442497, 0.010603},{1.726222, 0.441997, 0.009934}}],
    Polygon[{{1.727591, 0.443561, 0.010603},{1.729292, 0.443561, 0.011012},{
      1.729377, 0.443022, 0.011012},{1.727759, 0.442497, 0.010603}}],
    Polygon[{{1.729377, 0.443022, -0.011012},{1.727759, 0.442497, -0.010603},{
      1.728249, 0.441536, -0.010603},{1.729625, 0.442536, -0.011012}}],
    Polygon[{{1.727759, 0.442497, -0.010603},{1.726222, 0.441997, -0.009934},{
      1.726941, 0.440586, -0.009934},{1.728249, 0.441536, -0.010603}}],
    Polygon[{{1.726222, 0.441997, -0.009934},{1.724803, 0.441536, -0.009020},{
      1.725734, 0.439710, -0.009020},{1.726941, 0.440586, -0.009934}}],
    Polygon[{{1.724803, 0.441536, -0.009020},{1.723538, 0.441125, -0.007884},{
      1.724658, 0.438928, -0.007884},{1.725734, 0.439710, -0.009020}}],
    Polygon[{{1.723538, 0.441125, -0.007884},{1.722458, 0.440774, -0.006553},{
      1.723739, 0.438260, -0.006553},{1.724658, 0.438928, -0.007884}}],
    Polygon[{{1.722458, 0.440774, -0.006553},{1.721588, 0.440492, -0.005062},{
      1.722999, 0.437722, -0.005062},{1.723739, 0.438260, -0.006553}}],
    Polygon[{{1.721588, 0.440492, -0.005062},{1.720951, 0.440285, -0.003445},{
      1.722458, 0.437329, -0.003445},{1.722999, 0.437722, -0.005062}}],
    Polygon[{{1.720951, 0.440285, -0.003445},{1.720563, 0.440159, -0.001744},{
      1.722127, 0.437089, -0.001744},{1.722458, 0.437329, -0.003445}}],
    Polygon[{{1.720563, 0.440159, -0.001744},{1.720432, 0.440116, 0.000000},{
      1.722016, 0.437008, 0.000000},{1.722127, 0.437089, -0.001744}}],
    Polygon[{{1.720432, 0.440116, 0.000000},{1.720563, 0.440159, 0.001744},{
      1.722127, 0.437089, 0.001744},{1.722016, 0.437008, 0.000000}}],
    Polygon[{{1.720563, 0.440159, 0.001744},{1.720951, 0.440285, 0.003445},{
      1.722458, 0.437329, 0.003445},{1.722127, 0.437089, 0.001744}}],
    Polygon[{{1.720951, 0.440285, 0.003445},{1.721588, 0.440492, 0.005062},{
      1.722999, 0.437722, 0.005062},{1.722458, 0.437329, 0.003445}}],
    Polygon[{{1.721588, 0.440492, 0.005062},{1.722458, 0.440774, 0.006553},{
      1.723739, 0.438260, 0.006553},{1.722999, 0.437722, 0.005062}}],
    Polygon[{{1.722458, 0.440774, 0.006553},{1.723538, 0.441125, 0.007884},{
      1.724658, 0.438928, 0.007884},{1.723739, 0.438260, 0.006553}}],
    Polygon[{{1.723538, 0.441125, 0.007884},{1.724803, 0.441536, 0.009020},{
      1.725734, 0.439710, 0.009020},{1.724658, 0.438928, 0.007884}}],
    Polygon[{{1.724803, 0.441536, 0.009020},{1.726222, 0.441997, 0.009934},{
      1.726941, 0.440586, 0.009934},{1.725734, 0.439710, 0.009020}}],
    Polygon[{{1.726222, 0.441997, 0.009934},{1.727759, 0.442497, 0.010603},{
      1.728249, 0.441536, 0.010603},{1.726941, 0.440586, 0.009934}}],
    Polygon[{{1.727759, 0.442497, 0.010603},{1.729377, 0.443022, 0.011012},{
      1.729625, 0.442536, 0.011012},{1.728249, 0.441536, 0.010603}}],
    Polygon[{{1.729625, 0.442536, -0.011012},{1.728249, 0.441536, -0.010603},{
      1.729011, 0.440774, -0.010603},{1.730011, 0.442150, -0.011012}}],
    Polygon[{{1.728249, 0.441536, -0.010603},{1.726941, 0.440586, -0.009934},{
      1.728061, 0.439467, -0.009934},{1.729011, 0.440774, -0.010603}}],
    Polygon[{{1.726941, 0.440586, -0.009934},{1.725734, 0.439710, -0.009020},{
      1.727184, 0.438260, -0.009020},{1.728061, 0.439467, -0.009934}}],
    Polygon[{{1.725734, 0.439710, -0.009020},{1.724658, 0.438928, -0.007884},{
      1.726402, 0.437183, -0.007884},{1.727184, 0.438260, -0.009020}}],
    Polygon[{{1.724658, 0.438928, -0.007884},{1.723739, 0.438260, -0.006553},{
      1.725734, 0.436264, -0.006553},{1.726402, 0.437183, -0.007884}}],
    Polygon[{{1.723739, 0.438260, -0.006553},{1.722999, 0.437722, -0.005062},{
      1.725197, 0.435525, -0.005062},{1.725734, 0.436264, -0.006553}}],
    Polygon[{{1.722999, 0.437722, -0.005062},{1.722458, 0.437329, -0.003445},{
      1.724803, 0.434983, -0.003445},{1.725197, 0.435525, -0.005062}}],
    Polygon[{{1.722458, 0.437329, -0.003445},{1.722127, 0.437089, -0.001744},{
      1.724563, 0.434653, -0.001744},{1.724803, 0.434983, -0.003445}}],
    Polygon[{{1.722127, 0.437089, -0.001744},{1.722016, 0.437008, 0.000000},{
      1.724483, 0.434542, 0.000000},{1.724563, 0.434653, -0.001744}}],
    Polygon[{{1.722016, 0.437008, 0.000000},{1.722127, 0.437089, 0.001744},{
      1.724563, 0.434653, 0.001744},{1.724483, 0.434542, 0.000000}}],
    Polygon[{{1.722127, 0.437089, 0.001744},{1.722458, 0.437329, 0.003445},{
      1.724803, 0.434983, 0.003445},{1.724563, 0.434653, 0.001744}}],
    Polygon[{{1.722458, 0.437329, 0.003445},{1.722999, 0.437722, 0.005062},{
      1.725197, 0.435525, 0.005062},{1.724803, 0.434983, 0.003445}}],
    Polygon[{{1.722999, 0.437722, 0.005062},{1.723739, 0.438260, 0.006553},{
      1.725734, 0.436264, 0.006553},{1.725197, 0.435525, 0.005062}}],
    Polygon[{{1.723739, 0.438260, 0.006553},{1.724658, 0.438928, 0.007884},{
      1.726402, 0.437183, 0.007884},{1.725734, 0.436264, 0.006553}}],
    Polygon[{{1.724658, 0.438928, 0.007884},{1.725734, 0.439710, 0.009020},{
      1.727184, 0.438260, 0.009020},{1.726402, 0.437183, 0.007884}}],
    Polygon[{{1.725734, 0.439710, 0.009020},{1.726941, 0.440586, 0.009934},{
      1.728061, 0.439467, 0.009934},{1.727184, 0.438260, 0.009020}}],
    Polygon[{{1.726941, 0.440586, 0.009934},{1.728249, 0.441536, 0.010603},{
      1.729011, 0.440774, 0.010603},{1.728061, 0.439467, 0.009934}}],
    Polygon[{{1.728249, 0.441536, 0.010603},{1.729625, 0.442536, 0.011012},{
      1.730011, 0.442150, 0.011012},{1.729011, 0.440774, 0.010603}}],
    Polygon[{{1.730011, 0.442150, -0.011012},{1.729011, 0.440774, -0.010603},{
      1.729971, 0.440285, -0.010603},{1.730497, 0.441903, -0.011012}}],
    Polygon[{{1.729011, 0.440774, -0.010603},{1.728061, 0.439467, -0.009934},{
      1.729472, 0.438748, -0.009934},{1.729971, 0.440285, -0.010603}}],
    Polygon[{{1.728061, 0.439467, -0.009934},{1.727184, 0.438260, -0.009020},{
      1.729011, 0.437329, -0.009020},{1.729472, 0.438748, -0.009934}}],
    Polygon[{{1.727184, 0.438260, -0.009020},{1.726402, 0.437183, -0.007884},{
      1.728600, 0.436064, -0.007884},{1.729011, 0.437329, -0.009020}}],
    Polygon[{{1.726402, 0.437183, -0.007884},{1.725734, 0.436264, -0.006553},{
      1.728249, 0.434983, -0.006553},{1.728600, 0.436064, -0.007884}}],
    Polygon[{{1.725734, 0.436264, -0.006553},{1.725197, 0.435525, -0.005062},{
      1.727966, 0.434114, -0.005062},{1.728249, 0.434983, -0.006553}}],
    Polygon[{{1.725197, 0.435525, -0.005062},{1.724803, 0.434983, -0.003445},{
      1.727759, 0.433477, -0.003445},{1.727966, 0.434114, -0.005062}}],
    Polygon[{{1.724803, 0.434983, -0.003445},{1.724563, 0.434653, -0.001744},{
      1.727633, 0.433089, -0.001744},{1.727759, 0.433477, -0.003445}}],
    Polygon[{{1.724563, 0.434653, -0.001744},{1.724483, 0.434542, 0.000000},{
      1.727591, 0.432958, 0.000000},{1.727633, 0.433089, -0.001744}}],
    Polygon[{{1.724483, 0.434542, 0.000000},{1.724563, 0.434653, 0.001744},{
      1.727633, 0.433089, 0.001744},{1.727591, 0.432958, 0.000000}}],
    Polygon[{{1.724563, 0.434653, 0.001744},{1.724803, 0.434983, 0.003445},{
      1.727759, 0.433477, 0.003445},{1.727633, 0.433089, 0.001744}}],
    Polygon[{{1.724803, 0.434983, 0.003445},{1.725197, 0.435525, 0.005062},{
      1.727966, 0.434114, 0.005062},{1.727759, 0.433477, 0.003445}}],
    Polygon[{{1.725197, 0.435525, 0.005062},{1.725734, 0.436264, 0.006553},{
      1.728249, 0.434983, 0.006553},{1.727966, 0.434114, 0.005062}}],
    Polygon[{{1.725734, 0.436264, 0.006553},{1.726402, 0.437183, 0.007884},{
      1.728600, 0.436064, 0.007884},{1.728249, 0.434983, 0.006553}}],
    Polygon[{{1.726402, 0.437183, 0.007884},{1.727184, 0.438260, 0.009020},{
      1.729011, 0.437329, 0.009020},{1.728600, 0.436064, 0.007884}}],
    Polygon[{{1.727184, 0.438260, 0.009020},{1.728061, 0.439467, 0.009934},{
      1.729472, 0.438748, 0.009934},{1.729011, 0.437329, 0.009020}}],
    Polygon[{{1.728061, 0.439467, 0.009934},{1.729011, 0.440774, 0.010603},{
      1.729971, 0.440285, 0.010603},{1.729472, 0.438748, 0.009934}}],
    Polygon[{{1.729011, 0.440774, 0.010603},{1.730011, 0.442150, 0.011012},{
      1.730497, 0.441903, 0.011012},{1.729971, 0.440285, 0.010603}}],
    Polygon[{{1.730497, 0.441903, -0.011012},{1.729971, 0.440285, -0.010603},{
      1.731036, 0.440116, -0.010603},{1.731036, 0.441817, -0.011012}}],
    Polygon[{{1.729971, 0.440285, -0.010603},{1.729472, 0.438748, -0.009934},{
      1.731036, 0.438500, -0.009934},{1.731036, 0.440116, -0.010603}}],
    Polygon[{{1.729472, 0.438748, -0.009934},{1.729011, 0.437329, -0.009020},{
      1.731036, 0.437008, -0.009020},{1.731036, 0.438500, -0.009934}}],
    Polygon[{{1.729011, 0.437329, -0.009020},{1.728600, 0.436064, -0.007884},{
      1.731036, 0.435678, -0.007884},{1.731036, 0.437008, -0.009020}}],
    Polygon[{{1.728600, 0.436064, -0.007884},{1.728249, 0.434983, -0.006553},{
      1.731036, 0.434542, -0.006553},{1.731036, 0.435678, -0.007884}}],
    Polygon[{{1.728249, 0.434983, -0.006553},{1.727966, 0.434114, -0.005062},{
      1.731036, 0.433628, -0.005062},{1.731036, 0.434542, -0.006553}}],
    Polygon[{{1.727966, 0.434114, -0.005062},{1.727759, 0.433477, -0.003445},{
      1.731036, 0.432958, -0.003445},{1.731036, 0.433628, -0.005062}}],
    Polygon[{{1.727759, 0.433477, -0.003445},{1.727633, 0.433089, -0.001744},{
      1.731036, 0.432550, -0.001744},{1.731036, 0.432958, -0.003445}}],
    Polygon[{{1.727633, 0.433089, -0.001744},{1.727591, 0.432958, 0.000000},{
      1.731036, 0.432412, 0.000000},{1.731036, 0.432550, -0.001744}}],
    Polygon[{{1.727591, 0.432958, 0.000000},{1.727633, 0.433089, 0.001744},{
      1.731036, 0.432550, 0.001744},{1.731036, 0.432412, 0.000000}}],
    Polygon[{{1.727633, 0.433089, 0.001744},{1.727759, 0.433477, 0.003445},{
      1.731036, 0.432958, 0.003445},{1.731036, 0.432550, 0.001744}}],
    Polygon[{{1.727759, 0.433477, 0.003445},{1.727966, 0.434114, 0.005062},{
      1.731036, 0.433628, 0.005062},{1.731036, 0.432958, 0.003445}}],
    Polygon[{{1.727966, 0.434114, 0.005062},{1.728249, 0.434983, 0.006553},{
      1.731036, 0.434542, 0.006553},{1.731036, 0.433628, 0.005062}}],
    Polygon[{{1.728249, 0.434983, 0.006553},{1.728600, 0.436064, 0.007884},{
      1.731036, 0.435678, 0.007884},{1.731036, 0.434542, 0.006553}}],
    Polygon[{{1.728600, 0.436064, 0.007884},{1.729011, 0.437329, 0.009020},{
      1.731036, 0.437008, 0.009020},{1.731036, 0.435678, 0.007884}}],
    Polygon[{{1.729011, 0.437329, 0.009020},{1.729472, 0.438748, 0.009934},{
      1.731036, 0.438500, 0.009934},{1.731036, 0.437008, 0.009020}}],
    Polygon[{{1.729472, 0.438748, 0.009934},{1.729971, 0.440285, 0.010603},{
      1.731036, 0.440116, 0.010603},{1.731036, 0.438500, 0.009934}}],
    Polygon[{{1.729971, 0.440285, 0.010603},{1.730497, 0.441903, 0.011012},{
      1.731036, 0.441817, 0.011012},{1.731036, 0.440116, 0.010603}}],
    Polygon[{{1.731036, 0.441817, -0.011012},{1.731036, 0.440116, -0.010603},{
      1.732100, 0.440285, -0.010603},{1.731575, 0.441903, -0.011012}}],
    Polygon[{{1.731036, 0.440116, -0.010603},{1.731036, 0.438500, -0.009934},{
      1.732600, 0.438748, -0.009934},{1.732100, 0.440285, -0.010603}}],
    Polygon[{{1.731036, 0.438500, -0.009934},{1.731036, 0.437008, -0.009020},{
      1.733061, 0.437329, -0.009020},{1.732600, 0.438748, -0.009934}}],
    Polygon[{{1.731036, 0.437008, -0.009020},{1.731036, 0.435678, -0.007884},{
      1.733472, 0.436064, -0.007884},{1.733061, 0.437329, -0.009020}}],
    Polygon[{{1.731036, 0.435678, -0.007884},{1.731036, 0.434542, -0.006553},{
      1.733823, 0.434983, -0.006553},{1.733472, 0.436064, -0.007884}}],
    Polygon[{{1.731036, 0.434542, -0.006553},{1.731036, 0.433628, -0.005062},{
      1.734106, 0.434114, -0.005062},{1.733823, 0.434983, -0.006553}}],
    Polygon[{{1.731036, 0.433628, -0.005062},{1.731036, 0.432958, -0.003445},{
      1.734313, 0.433477, -0.003445},{1.734106, 0.434114, -0.005062}}],
    Polygon[{{1.731036, 0.432958, -0.003445},{1.731036, 0.432550, -0.001744},{
      1.734439, 0.433089, -0.001744},{1.734313, 0.433477, -0.003445}}],
    Polygon[{{1.731036, 0.432550, -0.001744},{1.731036, 0.432412, 0.000000},{
      1.734481, 0.432958, 0.000000},{1.734439, 0.433089, -0.001744}}],
    Polygon[{{1.731036, 0.432412, 0.000000},{1.731036, 0.432550, 0.001744},{
      1.734439, 0.433089, 0.001744},{1.734481, 0.432958, 0.000000}}],
    Polygon[{{1.731036, 0.432550, 0.001744},{1.731036, 0.432958, 0.003445},{
      1.734313, 0.433477, 0.003445},{1.734439, 0.433089, 0.001744}}],
    Polygon[{{1.731036, 0.432958, 0.003445},{1.731036, 0.433628, 0.005062},{
      1.734106, 0.434114, 0.005062},{1.734313, 0.433477, 0.003445}}],
    Polygon[{{1.731036, 0.433628, 0.005062},{1.731036, 0.434542, 0.006553},{
      1.733823, 0.434983, 0.006553},{1.734106, 0.434114, 0.005062}}],
    Polygon[{{1.731036, 0.434542, 0.006553},{1.731036, 0.435678, 0.007884},{
      1.733472, 0.436064, 0.007884},{1.733823, 0.434983, 0.006553}}],
    Polygon[{{1.731036, 0.435678, 0.007884},{1.731036, 0.437008, 0.009020},{
      1.733061, 0.437329, 0.009020},{1.733472, 0.436064, 0.007884}}],
    Polygon[{{1.731036, 0.437008, 0.009020},{1.731036, 0.438500, 0.009934},{
      1.732600, 0.438748, 0.009934},{1.733061, 0.437329, 0.009020}}],
    Polygon[{{1.731036, 0.438500, 0.009934},{1.731036, 0.440116, 0.010603},{
      1.732100, 0.440285, 0.010603},{1.732600, 0.438748, 0.009934}}],
    Polygon[{{1.731036, 0.440116, 0.010603},{1.731036, 0.441817, 0.011012},{
      1.731575, 0.441903, 0.011012},{1.732100, 0.440285, 0.010603}}],
    Polygon[{{1.731575, 0.441903, -0.011012},{1.732100, 0.440285, -0.010603},{
      1.733061, 0.440774, -0.010603},{1.732061, 0.442150, -0.011012}}],
    Polygon[{{1.732100, 0.440285, -0.010603},{1.732600, 0.438748, -0.009934},{
      1.734011, 0.439467, -0.009934},{1.733061, 0.440774, -0.010603}}],
    Polygon[{{1.732600, 0.438748, -0.009934},{1.733061, 0.437329, -0.009020},{
      1.734888, 0.438260, -0.009020},{1.734011, 0.439467, -0.009934}}],
    Polygon[{{1.733061, 0.437329, -0.009020},{1.733472, 0.436064, -0.007884},{
      1.735670, 0.437183, -0.007884},{1.734888, 0.438260, -0.009020}}],
    Polygon[{{1.733472, 0.436064, -0.007884},{1.733823, 0.434983, -0.006553},{
      1.736338, 0.436264, -0.006553},{1.735670, 0.437183, -0.007884}}],
    Polygon[{{1.733823, 0.434983, -0.006553},{1.734106, 0.434114, -0.005062},{
      1.736875, 0.435525, -0.005062},{1.736338, 0.436264, -0.006553}}],
    Polygon[{{1.734106, 0.434114, -0.005062},{1.734313, 0.433477, -0.003445},{
      1.737268, 0.434983, -0.003445},{1.736875, 0.435525, -0.005062}}],
    Polygon[{{1.734313, 0.433477, -0.003445},{1.734439, 0.433089, -0.001744},{
      1.737508, 0.434653, -0.001744},{1.737268, 0.434983, -0.003445}}],
    Polygon[{{1.734439, 0.433089, -0.001744},{1.734481, 0.432958, 0.000000},{
      1.737589, 0.434542, 0.000000},{1.737508, 0.434653, -0.001744}}],
    Polygon[{{1.734481, 0.432958, 0.000000},{1.734439, 0.433089, 0.001744},{
      1.737508, 0.434653, 0.001744},{1.737589, 0.434542, 0.000000}}],
    Polygon[{{1.734439, 0.433089, 0.001744},{1.734313, 0.433477, 0.003445},{
      1.737268, 0.434983, 0.003445},{1.737508, 0.434653, 0.001744}}],
    Polygon[{{1.734313, 0.433477, 0.003445},{1.734106, 0.434114, 0.005062},{
      1.736875, 0.435525, 0.005062},{1.737268, 0.434983, 0.003445}}],
    Polygon[{{1.734106, 0.434114, 0.005062},{1.733823, 0.434983, 0.006553},{
      1.736338, 0.436264, 0.006553},{1.736875, 0.435525, 0.005062}}],
    Polygon[{{1.733823, 0.434983, 0.006553},{1.733472, 0.436064, 0.007884},{
      1.735670, 0.437183, 0.007884},{1.736338, 0.436264, 0.006553}}],
    Polygon[{{1.733472, 0.436064, 0.007884},{1.733061, 0.437329, 0.009020},{
      1.734888, 0.438260, 0.009020},{1.735670, 0.437183, 0.007884}}],
    Polygon[{{1.733061, 0.437329, 0.009020},{1.732600, 0.438748, 0.009934},{
      1.734011, 0.439467, 0.009934},{1.734888, 0.438260, 0.009020}}],
    Polygon[{{1.732600, 0.438748, 0.009934},{1.732100, 0.440285, 0.010603},{
      1.733061, 0.440774, 0.010603},{1.734011, 0.439467, 0.009934}}],
    Polygon[{{1.732100, 0.440285, 0.010603},{1.731575, 0.441903, 0.011012},{
      1.732061, 0.442150, 0.011012},{1.733061, 0.440774, 0.010603}}],
    Polygon[{{1.732061, 0.442150, -0.011012},{1.733061, 0.440774, -0.010603},{
      1.733823, 0.441536, -0.010603},{1.732447, 0.442536, -0.011012}}],
    Polygon[{{1.733061, 0.440774, -0.010603},{1.734011, 0.439467, -0.009934},{
      1.735131, 0.440586, -0.009934},{1.733823, 0.441536, -0.010603}}],
    Polygon[{{1.734011, 0.439467, -0.009934},{1.734888, 0.438260, -0.009020},{
      1.736338, 0.439710, -0.009020},{1.735131, 0.440586, -0.009934}}],
    Polygon[{{1.734888, 0.438260, -0.009020},{1.735670, 0.437183, -0.007884},{
      1.737414, 0.438928, -0.007884},{1.736338, 0.439710, -0.009020}}],
    Polygon[{{1.735670, 0.437183, -0.007884},{1.736338, 0.436264, -0.006553},{
      1.738333, 0.438260, -0.006553},{1.737414, 0.438928, -0.007884}}],
    Polygon[{{1.736338, 0.436264, -0.006553},{1.736875, 0.435525, -0.005062},{
      1.739073, 0.437722, -0.005062},{1.738333, 0.438260, -0.006553}}],
    Polygon[{{1.736875, 0.435525, -0.005062},{1.737268, 0.434983, -0.003445},{
      1.739614, 0.437329, -0.003445},{1.739073, 0.437722, -0.005062}}],
    Polygon[{{1.737268, 0.434983, -0.003445},{1.737508, 0.434653, -0.001744},{
      1.739945, 0.437089, -0.001744},{1.739614, 0.437329, -0.003445}}],
    Polygon[{{1.737508, 0.434653, -0.001744},{1.737589, 0.434542, 0.000000},{
      1.740056, 0.437008, 0.000000},{1.739945, 0.437089, -0.001744}}],
    Polygon[{{1.737589, 0.434542, 0.000000},{1.737508, 0.434653, 0.001744},{
      1.739945, 0.437089, 0.001744},{1.740056, 0.437008, 0.000000}}],
    Polygon[{{1.737508, 0.434653, 0.001744},{1.737268, 0.434983, 0.003445},{
      1.739614, 0.437329, 0.003445},{1.739945, 0.437089, 0.001744}}],
    Polygon[{{1.737268, 0.434983, 0.003445},{1.736875, 0.435525, 0.005062},{
      1.739073, 0.437722, 0.005062},{1.739614, 0.437329, 0.003445}}],
    Polygon[{{1.736875, 0.435525, 0.005062},{1.736338, 0.436264, 0.006553},{
      1.738333, 0.438260, 0.006553},{1.739073, 0.437722, 0.005062}}],
    Polygon[{{1.736338, 0.436264, 0.006553},{1.735670, 0.437183, 0.007884},{
      1.737414, 0.438928, 0.007884},{1.738333, 0.438260, 0.006553}}],
    Polygon[{{1.735670, 0.437183, 0.007884},{1.734888, 0.438260, 0.009020},{
      1.736338, 0.439710, 0.009020},{1.737414, 0.438928, 0.007884}}],
    Polygon[{{1.734888, 0.438260, 0.009020},{1.734011, 0.439467, 0.009934},{
      1.735131, 0.440586, 0.009934},{1.736338, 0.439710, 0.009020}}],
    Polygon[{{1.734011, 0.439467, 0.009934},{1.733061, 0.440774, 0.010603},{
      1.733823, 0.441536, 0.010603},{1.735131, 0.440586, 0.009934}}],
    Polygon[{{1.733061, 0.440774, 0.010603},{1.732061, 0.442150, 0.011012},{
      1.732447, 0.442536, 0.011012},{1.733823, 0.441536, 0.010603}}],
    Polygon[{{1.732447, 0.442536, -0.011012},{1.733823, 0.441536, -0.010603},{
      1.734313, 0.442497, -0.010603},{1.732695, 0.443022, -0.011012}}],
    Polygon[{{1.733823, 0.441536, -0.010603},{1.735131, 0.440586, -0.009934},{
      1.735850, 0.441997, -0.009934},{1.734313, 0.442497, -0.010603}}],
    Polygon[{{1.735131, 0.440586, -0.009934},{1.736338, 0.439710, -0.009020},{
      1.737268, 0.441536, -0.009020},{1.735850, 0.441997, -0.009934}}],
    Polygon[{{1.736338, 0.439710, -0.009020},{1.737414, 0.438928, -0.007884},{
      1.738534, 0.441125, -0.007884},{1.737268, 0.441536, -0.009020}}],
    Polygon[{{1.737414, 0.438928, -0.007884},{1.738333, 0.438260, -0.006553},{
      1.739614, 0.440774, -0.006553},{1.738534, 0.441125, -0.007884}}],
    Polygon[{{1.738333, 0.438260, -0.006553},{1.739073, 0.437722, -0.005062},{
      1.740484, 0.440492, -0.005062},{1.739614, 0.440774, -0.006553}}],
    Polygon[{{1.739073, 0.437722, -0.005062},{1.739614, 0.437329, -0.003445},{
      1.741120, 0.440285, -0.003445},{1.740484, 0.440492, -0.005062}}],
    Polygon[{{1.739614, 0.437329, -0.003445},{1.739945, 0.437089, -0.001744},{
      1.741509, 0.440159, -0.001744},{1.741120, 0.440285, -0.003445}}],
    Polygon[{{1.739945, 0.437089, -0.001744},{1.740056, 0.437008, 0.000000},{
      1.741639, 0.440116, 0.000000},{1.741509, 0.440159, -0.001744}}],
    Polygon[{{1.740056, 0.437008, 0.000000},{1.739945, 0.437089, 0.001744},{
      1.741509, 0.440159, 0.001744},{1.741639, 0.440116, 0.000000}}],
    Polygon[{{1.739945, 0.437089, 0.001744},{1.739614, 0.437329, 0.003445},{
      1.741120, 0.440285, 0.003445},{1.741509, 0.440159, 0.001744}}],
    Polygon[{{1.739614, 0.437329, 0.003445},{1.739073, 0.437722, 0.005062},{
      1.740484, 0.440492, 0.005062},{1.741120, 0.440285, 0.003445}}],
    Polygon[{{1.739073, 0.437722, 0.005062},{1.738333, 0.438260, 0.006553},{
      1.739614, 0.440774, 0.006553},{1.740484, 0.440492, 0.005062}}],
    Polygon[{{1.738333, 0.438260, 0.006553},{1.737414, 0.438928, 0.007884},{
      1.738534, 0.441125, 0.007884},{1.739614, 0.440774, 0.006553}}],
    Polygon[{{1.737414, 0.438928, 0.007884},{1.736338, 0.439710, 0.009020},{
      1.737268, 0.441536, 0.009020},{1.738534, 0.441125, 0.007884}}],
    Polygon[{{1.736338, 0.439710, 0.009020},{1.735131, 0.440586, 0.009934},{
      1.735850, 0.441997, 0.009934},{1.737268, 0.441536, 0.009020}}],
    Polygon[{{1.735131, 0.440586, 0.009934},{1.733823, 0.441536, 0.010603},{
      1.734313, 0.442497, 0.010603},{1.735850, 0.441997, 0.009934}}],
    Polygon[{{1.733823, 0.441536, 0.010603},{1.732447, 0.442536, 0.011012},{
      1.732695, 0.443022, 0.011012},{1.734313, 0.442497, 0.010603}}],
    Polygon[{{1.732695, 0.443022, -0.011012},{1.734313, 0.442497, -0.010603},{
      1.734481, 0.443561, -0.010603},{1.732780, 0.443561, -0.011012}}],
    Polygon[{{1.734313, 0.442497, -0.010603},{1.735850, 0.441997, -0.009934},{
      1.736097, 0.443561, -0.009934},{1.734481, 0.443561, -0.010603}}],
    Polygon[{{1.735850, 0.441997, -0.009934},{1.737268, 0.441536, -0.009020},{
      1.737589, 0.443561, -0.009020},{1.736097, 0.443561, -0.009934}}],
    Polygon[{{1.737268, 0.441536, -0.009020},{1.738534, 0.441125, -0.007884},{
      1.738919, 0.443561, -0.007884},{1.737589, 0.443561, -0.009020}}],
    Polygon[{{1.738534, 0.441125, -0.007884},{1.739614, 0.440774, -0.006553},{
      1.740056, 0.443561, -0.006553},{1.738919, 0.443561, -0.007884}}],
    Polygon[{{1.739614, 0.440774, -0.006553},{1.740484, 0.440492, -0.005062},{
      1.740970, 0.443561, -0.005062},{1.740056, 0.443561, -0.006553}}],
    Polygon[{{1.740484, 0.440492, -0.005062},{1.741120, 0.440285, -0.003445},{
      1.741639, 0.443561, -0.003445},{1.740970, 0.443561, -0.005062}}],
    Polygon[{{1.741120, 0.440285, -0.003445},{1.741509, 0.440159, -0.001744},{
      1.742048, 0.443561, -0.001744},{1.741639, 0.443561, -0.003445}}],
    Polygon[{{1.741509, 0.440159, -0.001744},{1.741639, 0.440116, 0.000000},{
      1.742185, 0.443561, 0.000000},{1.742048, 0.443561, -0.001744}}],
    Polygon[{{1.741639, 0.440116, 0.000000},{1.741509, 0.440159, 0.001744},{
      1.742048, 0.443561, 0.001744},{1.742185, 0.443561, 0.000000}}],
    Polygon[{{1.741509, 0.440159, 0.001744},{1.741120, 0.440285, 0.003445},{
      1.741639, 0.443561, 0.003445},{1.742048, 0.443561, 0.001744}}],
    Polygon[{{1.741120, 0.440285, 0.003445},{1.740484, 0.440492, 0.005062},{
      1.740970, 0.443561, 0.005062},{1.741639, 0.443561, 0.003445}}],
    Polygon[{{1.740484, 0.440492, 0.005062},{1.739614, 0.440774, 0.006553},{
      1.740056, 0.443561, 0.006553},{1.740970, 0.443561, 0.005062}}],
    Polygon[{{1.739614, 0.440774, 0.006553},{1.738534, 0.441125, 0.007884},{
      1.738919, 0.443561, 0.007884},{1.740056, 0.443561, 0.006553}}],
    Polygon[{{1.738534, 0.441125, 0.007884},{1.737268, 0.441536, 0.009020},{
      1.737589, 0.443561, 0.009020},{1.738919, 0.443561, 0.007884}}],
    Polygon[{{1.737268, 0.441536, 0.009020},{1.735850, 0.441997, 0.009934},{
      1.736097, 0.443561, 0.009934},{1.737589, 0.443561, 0.009020}}],
    Polygon[{{1.735850, 0.441997, 0.009934},{1.734313, 0.442497, 0.010603},{
      1.734481, 0.443561, 0.010603},{1.736097, 0.443561, 0.009934}}],
    Polygon[{{1.734313, 0.442497, 0.010603},{1.732695, 0.443022, 0.011012},{
      1.732780, 0.443561, 0.011012},{1.734481, 0.443561, 0.010603}}],
    Polygon[{{1.698314, 0.392133, -0.009381},{1.699763, 0.392133, -0.009033},{
      1.699619, 0.393040, -0.009033},{1.698241, 0.392593, -0.009381}}],
    Polygon[{{1.699763, 0.392133, -0.009033},{1.701140, 0.392133, -0.008463},{
      1.700929, 0.393466, -0.008463},{1.699619, 0.393040, -0.009033}}],
    Polygon[{{1.701140, 0.392133, -0.008463},{1.702411, 0.392133, -0.007684},{
      1.702137, 0.393859, -0.007684},{1.700929, 0.393466, -0.008463}}],
    Polygon[{{1.702411, 0.392133, -0.007684},{1.703544, 0.392133, -0.006716},{
      1.703215, 0.394209, -0.006716},{1.702137, 0.393859, -0.007684}}],
    Polygon[{{1.703544, 0.392133, -0.006716},{1.704512, 0.392133, -0.005583},{
      1.704136, 0.394508, -0.005583},{1.703215, 0.394209, -0.006716}}],
    Polygon[{{1.704512, 0.392133, -0.005583},{1.705291, 0.392133, -0.004312},{
      1.704877, 0.394749, -0.004312},{1.704136, 0.394508, -0.005583}}],
    Polygon[{{1.705291, 0.392133, -0.004312},{1.705861, 0.392133, -0.002935},{
      1.705419, 0.394925, -0.002935},{1.704877, 0.394749, -0.004312}}],
    Polygon[{{1.705861, 0.392133, -0.002935},{1.706209, 0.392133, -0.001486},{
      1.705750, 0.395032, -0.001486},{1.705419, 0.394925, -0.002935}}],
    Polygon[{{1.706209, 0.392133, -0.001486},{1.706326, 0.392133, 0.000000},{
      1.705861, 0.395069, 0.000000},{1.705750, 0.395032, -0.001486}}],
    Polygon[{{1.706326, 0.392133, 0.000000},{1.706209, 0.392133, 0.001486},{
      1.705750, 0.395032, 0.001486},{1.705861, 0.395069, 0.000000}}],
    Polygon[{{1.706209, 0.392133, 0.001486},{1.705861, 0.392133, 0.002935},{
      1.705419, 0.394925, 0.002935},{1.705750, 0.395032, 0.001486}}],
    Polygon[{{1.705861, 0.392133, 0.002935},{1.705291, 0.392133, 0.004312},{
      1.704877, 0.394749, 0.004312},{1.705419, 0.394925, 0.002935}}],
    Polygon[{{1.705291, 0.392133, 0.004312},{1.704512, 0.392133, 0.005583},{
      1.704136, 0.394508, 0.005583},{1.704877, 0.394749, 0.004312}}],
    Polygon[{{1.704512, 0.392133, 0.005583},{1.703544, 0.392133, 0.006716},{
      1.703215, 0.394209, 0.006716},{1.704136, 0.394508, 0.005583}}],
    Polygon[{{1.703544, 0.392133, 0.006716},{1.702411, 0.392133, 0.007684},{
      1.702137, 0.393859, 0.007684},{1.703215, 0.394209, 0.006716}}],
    Polygon[{{1.702411, 0.392133, 0.007684},{1.701140, 0.392133, 0.008463},{
      1.700929, 0.393466, 0.008463},{1.702137, 0.393859, 0.007684}}],
    Polygon[{{1.701140, 0.392133, 0.008463},{1.699763, 0.392133, 0.009033},{
      1.699619, 0.393040, 0.009033},{1.700929, 0.393466, 0.008463}}],
    Polygon[{{1.699763, 0.392133, 0.009033},{1.698314, 0.392133, 0.009381},{
      1.698241, 0.392593, 0.009381},{1.699619, 0.393040, 0.009033}}],
    Polygon[{{1.698241, 0.392593, -0.009381},{1.699619, 0.393040, -0.009033},{
      1.699202, 0.393859, -0.009033},{1.698030, 0.393007, -0.009381}}],
    Polygon[{{1.699619, 0.393040, -0.009033},{1.700929, 0.393466, -0.008463},{
      1.700316, 0.394668, -0.008463},{1.699202, 0.393859, -0.009033}}],
    Polygon[{{1.700929, 0.393466, -0.008463},{1.702137, 0.393859, -0.007684},{
      1.701344, 0.395415, -0.007684},{1.700316, 0.394668, -0.008463}}],
    Polygon[{{1.702137, 0.393859, -0.007684},{1.703215, 0.394209, -0.006716},{
      1.702261, 0.396081, -0.006716},{1.701344, 0.395415, -0.007684}}],
    Polygon[{{1.703215, 0.394209, -0.006716},{1.704136, 0.394508, -0.005583},{
      1.703045, 0.396650, -0.005583},{1.702261, 0.396081, -0.006716}}],
    Polygon[{{1.704136, 0.394508, -0.005583},{1.704877, 0.394749, -0.004312},{
      1.703675, 0.397108, -0.004312},{1.703045, 0.396650, -0.005583}}],
    Polygon[{{1.704877, 0.394749, -0.004312},{1.705419, 0.394925, -0.002935},{
      1.704136, 0.397443, -0.002935},{1.703675, 0.397108, -0.004312}}],
    Polygon[{{1.705419, 0.394925, -0.002935},{1.705750, 0.395032, -0.001486},{
      1.704417, 0.397648, -0.001486},{1.704136, 0.397443, -0.002935}}],
    Polygon[{{1.705750, 0.395032, -0.001486},{1.705861, 0.395069, 0.000000},{
      1.704512, 0.397716, 0.000000},{1.704417, 0.397648, -0.001486}}],
    Polygon[{{1.705861, 0.395069, 0.000000},{1.705750, 0.395032, 0.001486},{
      1.704417, 0.397648, 0.001486},{1.704512, 0.397716, 0.000000}}],
    Polygon[{{1.705750, 0.395032, 0.001486},{1.705419, 0.394925, 0.002935},{
      1.704136, 0.397443, 0.002935},{1.704417, 0.397648, 0.001486}}],
    Polygon[{{1.705419, 0.394925, 0.002935},{1.704877, 0.394749, 0.004312},{
      1.703675, 0.397108, 0.004312},{1.704136, 0.397443, 0.002935}}],
    Polygon[{{1.704877, 0.394749, 0.004312},{1.704136, 0.394508, 0.005583},{
      1.703045, 0.396650, 0.005583},{1.703675, 0.397108, 0.004312}}],
    Polygon[{{1.704136, 0.394508, 0.005583},{1.703215, 0.394209, 0.006716},{
      1.702261, 0.396081, 0.006716},{1.703045, 0.396650, 0.005583}}],
    Polygon[{{1.703215, 0.394209, 0.006716},{1.702137, 0.393859, 0.007684},{
      1.701344, 0.395415, 0.007684},{1.702261, 0.396081, 0.006716}}],
    Polygon[{{1.702137, 0.393859, 0.007684},{1.700929, 0.393466, 0.008463},{
      1.700316, 0.394668, 0.008463},{1.701344, 0.395415, 0.007684}}],
    Polygon[{{1.700929, 0.393466, 0.008463},{1.699619, 0.393040, 0.009033},{
      1.699202, 0.393859, 0.009033},{1.700316, 0.394668, 0.008463}}],
    Polygon[{{1.699619, 0.393040, 0.009033},{1.698241, 0.392593, 0.009381},{
      1.698030, 0.393007, 0.009381},{1.699202, 0.393859, 0.009033}}],
    Polygon[{{1.698030, 0.393007, -0.009381},{1.699202, 0.393859, -0.009033},{
      1.698553, 0.394508, -0.009033},{1.697701, 0.393336, -0.009381}}],
    Polygon[{{1.699202, 0.393859, -0.009033},{1.700316, 0.394668, -0.008463},{
      1.699362, 0.395622, -0.008463},{1.698553, 0.394508, -0.009033}}],
    Polygon[{{1.700316, 0.394668, -0.008463},{1.701344, 0.395415, -0.007684},{
      1.700109, 0.396650, -0.007684},{1.699362, 0.395622, -0.008463}}],
    Polygon[{{1.701344, 0.395415, -0.007684},{1.702261, 0.396081, -0.006716},{
      1.700776, 0.397567, -0.006716},{1.700109, 0.396650, -0.007684}}],
    Polygon[{{1.702261, 0.396081, -0.006716},{1.703045, 0.396650, -0.005583},{
      1.701344, 0.398350, -0.005583},{1.700776, 0.397567, -0.006716}}],
    Polygon[{{1.703045, 0.396650, -0.005583},{1.703675, 0.397108, -0.004312},{
      1.701802, 0.398980, -0.004312},{1.701344, 0.398350, -0.005583}}],
    Polygon[{{1.703675, 0.397108, -0.004312},{1.704136, 0.397443, -0.002935},{
      1.702137, 0.399442, -0.002935},{1.701802, 0.398980, -0.004312}}],
    Polygon[{{1.704136, 0.397443, -0.002935},{1.704417, 0.397648, -0.001486},{
      1.702342, 0.399723, -0.001486},{1.702137, 0.399442, -0.002935}}],
    Polygon[{{1.704417, 0.397648, -0.001486},{1.704512, 0.397716, 0.000000},{
      1.702411, 0.399818, 0.000000},{1.702342, 0.399723, -0.001486}}],
    Polygon[{{1.704512, 0.397716, 0.000000},{1.704417, 0.397648, 0.001486},{
      1.702342, 0.399723, 0.001486},{1.702411, 0.399818, 0.000000}}],
    Polygon[{{1.704417, 0.397648, 0.001486},{1.704136, 0.397443, 0.002935},{
      1.702137, 0.399442, 0.002935},{1.702342, 0.399723, 0.001486}}],
    Polygon[{{1.704136, 0.397443, 0.002935},{1.703675, 0.397108, 0.004312},{
      1.701802, 0.398980, 0.004312},{1.702137, 0.399442, 0.002935}}],
    Polygon[{{1.703675, 0.397108, 0.004312},{1.703045, 0.396650, 0.005583},{
      1.701344, 0.398350, 0.005583},{1.701802, 0.398980, 0.004312}}],
    Polygon[{{1.703045, 0.396650, 0.005583},{1.702261, 0.396081, 0.006716},{
      1.700776, 0.397567, 0.006716},{1.701344, 0.398350, 0.005583}}],
    Polygon[{{1.702261, 0.396081, 0.006716},{1.701344, 0.395415, 0.007684},{
      1.700109, 0.396650, 0.007684},{1.700776, 0.397567, 0.006716}}],
    Polygon[{{1.701344, 0.395415, 0.007684},{1.700316, 0.394668, 0.008463},{
      1.699362, 0.395622, 0.008463},{1.700109, 0.396650, 0.007684}}],
    Polygon[{{1.700316, 0.394668, 0.008463},{1.699202, 0.393859, 0.009033},{
      1.698553, 0.394508, 0.009033},{1.699362, 0.395622, 0.008463}}],
    Polygon[{{1.699202, 0.393859, 0.009033},{1.698030, 0.393007, 0.009381},{
      1.697701, 0.393336, 0.009381},{1.698553, 0.394508, 0.009033}}],
    Polygon[{{1.697701, 0.393336, -0.009381},{1.698553, 0.394508, -0.009033},{
      1.697735, 0.394925, -0.009033},{1.697287, 0.393547, -0.009381}}],
    Polygon[{{1.698553, 0.394508, -0.009033},{1.699362, 0.395622, -0.008463},{
      1.698160, 0.396235, -0.008463},{1.697735, 0.394925, -0.009033}}],
    Polygon[{{1.699362, 0.395622, -0.008463},{1.700109, 0.396650, -0.007684},{
      1.698553, 0.397443, -0.007684},{1.698160, 0.396235, -0.008463}}],
    Polygon[{{1.700109, 0.396650, -0.007684},{1.700776, 0.397567, -0.006716},{
      1.698903, 0.398521, -0.006716},{1.698553, 0.397443, -0.007684}}],
    Polygon[{{1.700776, 0.397567, -0.006716},{1.701344, 0.398350, -0.005583},{
      1.699202, 0.399442, -0.005583},{1.698903, 0.398521, -0.006716}}],
    Polygon[{{1.701344, 0.398350, -0.005583},{1.701802, 0.398980, -0.004312},{
      1.699443, 0.400182, -0.004312},{1.699202, 0.399442, -0.005583}}],
    Polygon[{{1.701802, 0.398980, -0.004312},{1.702137, 0.399442, -0.002935},{
      1.699619, 0.400725, -0.002935},{1.699443, 0.400182, -0.004312}}],
    Polygon[{{1.702137, 0.399442, -0.002935},{1.702342, 0.399723, -0.001486},{
      1.699727, 0.401056, -0.001486},{1.699619, 0.400725, -0.002935}}],
    Polygon[{{1.702342, 0.399723, -0.001486},{1.702411, 0.399818, 0.000000},{
      1.699763, 0.401167, 0.000000},{1.699727, 0.401056, -0.001486}}],
    Polygon[{{1.702411, 0.399818, 0.000000},{1.702342, 0.399723, 0.001486},{
      1.699727, 0.401056, 0.001486},{1.699763, 0.401167, 0.000000}}],
    Polygon[{{1.702342, 0.399723, 0.001486},{1.702137, 0.399442, 0.002935},{
      1.699619, 0.400725, 0.002935},{1.699727, 0.401056, 0.001486}}],
    Polygon[{{1.702137, 0.399442, 0.002935},{1.701802, 0.398980, 0.004312},{
      1.699443, 0.400182, 0.004312},{1.699619, 0.400725, 0.002935}}],
    Polygon[{{1.701802, 0.398980, 0.004312},{1.701344, 0.398350, 0.005583},{
      1.699202, 0.399442, 0.005583},{1.699443, 0.400182, 0.004312}}],
    Polygon[{{1.701344, 0.398350, 0.005583},{1.700776, 0.397567, 0.006716},{
      1.698903, 0.398521, 0.006716},{1.699202, 0.399442, 0.005583}}],
    Polygon[{{1.700776, 0.397567, 0.006716},{1.700109, 0.396650, 0.007684},{
      1.698553, 0.397443, 0.007684},{1.698903, 0.398521, 0.006716}}],
    Polygon[{{1.700109, 0.396650, 0.007684},{1.699362, 0.395622, 0.008463},{
      1.698160, 0.396235, 0.008463},{1.698553, 0.397443, 0.007684}}],
    Polygon[{{1.699362, 0.395622, 0.008463},{1.698553, 0.394508, 0.009033},{
      1.697735, 0.394925, 0.009033},{1.698160, 0.396235, 0.008463}}],
    Polygon[{{1.698553, 0.394508, 0.009033},{1.697701, 0.393336, 0.009381},{
      1.697287, 0.393547, 0.009381},{1.697735, 0.394925, 0.009033}}],
    Polygon[{{1.697287, 0.393547, -0.009381},{1.697735, 0.394925, -0.009033},{
      1.696828, 0.395069, -0.009033},{1.696828, 0.393619, -0.009381}}],
    Polygon[{{1.697735, 0.394925, -0.009033},{1.698160, 0.396235, -0.008463},{
      1.696828, 0.396446, -0.008463},{1.696828, 0.395069, -0.009033}}],
    Polygon[{{1.698160, 0.396235, -0.008463},{1.698553, 0.397443, -0.007684},{
      1.696828, 0.397716, -0.007684},{1.696828, 0.396446, -0.008463}}],
    Polygon[{{1.698553, 0.397443, -0.007684},{1.698903, 0.398521, -0.006716},{
      1.696828, 0.398850, -0.006716},{1.696828, 0.397716, -0.007684}}],
    Polygon[{{1.698903, 0.398521, -0.006716},{1.699202, 0.399442, -0.005583},{
      1.696828, 0.399818, -0.005583},{1.696828, 0.398850, -0.006716}}],
    Polygon[{{1.699202, 0.399442, -0.005583},{1.699443, 0.400182, -0.004312},{
      1.696828, 0.400597, -0.004312},{1.696828, 0.399818, -0.005583}}],
    Polygon[{{1.699443, 0.400182, -0.004312},{1.699619, 0.400725, -0.002935},{
      1.696828, 0.401167, -0.002935},{1.696828, 0.400597, -0.004312}}],
    Polygon[{{1.699619, 0.400725, -0.002935},{1.699727, 0.401056, -0.001486},{
      1.696828, 0.401515, -0.001486},{1.696828, 0.401167, -0.002935}}],
    Polygon[{{1.699727, 0.401056, -0.001486},{1.699763, 0.401167, 0.000000},{
      1.696828, 0.401632, 0.000000},{1.696828, 0.401515, -0.001486}}],
    Polygon[{{1.699763, 0.401167, 0.000000},{1.699727, 0.401056, 0.001486},{
      1.696828, 0.401515, 0.001486},{1.696828, 0.401632, 0.000000}}],
    Polygon[{{1.699727, 0.401056, 0.001486},{1.699619, 0.400725, 0.002935},{
      1.696828, 0.401167, 0.002935},{1.696828, 0.401515, 0.001486}}],
    Polygon[{{1.699619, 0.400725, 0.002935},{1.699443, 0.400182, 0.004312},{
      1.696828, 0.400597, 0.004312},{1.696828, 0.401167, 0.002935}}],
    Polygon[{{1.699443, 0.400182, 0.004312},{1.699202, 0.399442, 0.005583},{
      1.696828, 0.399818, 0.005583},{1.696828, 0.400597, 0.004312}}],
    Polygon[{{1.699202, 0.399442, 0.005583},{1.698903, 0.398521, 0.006716},{
      1.696828, 0.398850, 0.006716},{1.696828, 0.399818, 0.005583}}],
    Polygon[{{1.698903, 0.398521, 0.006716},{1.698553, 0.397443, 0.007684},{
      1.696828, 0.397716, 0.007684},{1.696828, 0.398850, 0.006716}}],
    Polygon[{{1.698553, 0.397443, 0.007684},{1.698160, 0.396235, 0.008463},{
      1.696828, 0.396446, 0.008463},{1.696828, 0.397716, 0.007684}}],
    Polygon[{{1.698160, 0.396235, 0.008463},{1.697735, 0.394925, 0.009033},{
      1.696828, 0.395069, 0.009033},{1.696828, 0.396446, 0.008463}}],
    Polygon[{{1.697735, 0.394925, 0.009033},{1.697287, 0.393547, 0.009381},{
      1.696828, 0.393619, 0.009381},{1.696828, 0.395069, 0.009033}}],
    Polygon[{{1.696828, 0.393619, -0.009381},{1.696828, 0.395069, -0.009033},{
      1.695921, 0.394925, -0.009033},{1.696369, 0.393547, -0.009381}}],
    Polygon[{{1.696828, 0.395069, -0.009033},{1.696828, 0.396446, -0.008463},{
      1.695495, 0.396235, -0.008463},{1.695921, 0.394925, -0.009033}}],
    Polygon[{{1.696828, 0.396446, -0.008463},{1.696828, 0.397716, -0.007684},{
      1.695103, 0.397443, -0.007684},{1.695495, 0.396235, -0.008463}}],
    Polygon[{{1.696828, 0.397716, -0.007684},{1.696828, 0.398850, -0.006716},{
      1.694752, 0.398521, -0.006716},{1.695103, 0.397443, -0.007684}}],
    Polygon[{{1.696828, 0.398850, -0.006716},{1.696828, 0.399818, -0.005583},{
      1.694453, 0.399442, -0.005583},{1.694752, 0.398521, -0.006716}}],
    Polygon[{{1.696828, 0.399818, -0.005583},{1.696828, 0.400597, -0.004312},{
      1.694213, 0.400182, -0.004312},{1.694453, 0.399442, -0.005583}}],
    Polygon[{{1.696828, 0.400597, -0.004312},{1.696828, 0.401167, -0.002935},{
      1.694036, 0.400725, -0.002935},{1.694213, 0.400182, -0.004312}}],
    Polygon[{{1.696828, 0.401167, -0.002935},{1.696828, 0.401515, -0.001486},{
      1.693929, 0.401056, -0.001486},{1.694036, 0.400725, -0.002935}}],
    Polygon[{{1.696828, 0.401515, -0.001486},{1.696828, 0.401632, 0.000000},{
      1.693893, 0.401167, 0.000000},{1.693929, 0.401056, -0.001486}}],
    Polygon[{{1.696828, 0.401632, 0.000000},{1.696828, 0.401515, 0.001486},{
      1.693929, 0.401056, 0.001486},{1.693893, 0.401167, 0.000000}}],
    Polygon[{{1.696828, 0.401515, 0.001486},{1.696828, 0.401167, 0.002935},{
      1.694036, 0.400725, 0.002935},{1.693929, 0.401056, 0.001486}}],
    Polygon[{{1.696828, 0.401167, 0.002935},{1.696828, 0.400597, 0.004312},{
      1.694213, 0.400182, 0.004312},{1.694036, 0.400725, 0.002935}}],
    Polygon[{{1.696828, 0.400597, 0.004312},{1.696828, 0.399818, 0.005583},{
      1.694453, 0.399442, 0.005583},{1.694213, 0.400182, 0.004312}}],
    Polygon[{{1.696828, 0.399818, 0.005583},{1.696828, 0.398850, 0.006716},{
      1.694752, 0.398521, 0.006716},{1.694453, 0.399442, 0.005583}}],
    Polygon[{{1.696828, 0.398850, 0.006716},{1.696828, 0.397716, 0.007684},{
      1.695103, 0.397443, 0.007684},{1.694752, 0.398521, 0.006716}}],
    Polygon[{{1.696828, 0.397716, 0.007684},{1.696828, 0.396446, 0.008463},{
      1.695495, 0.396235, 0.008463},{1.695103, 0.397443, 0.007684}}],
    Polygon[{{1.696828, 0.396446, 0.008463},{1.696828, 0.395069, 0.009033},{
      1.695921, 0.394925, 0.009033},{1.695495, 0.396235, 0.008463}}],
    Polygon[{{1.696828, 0.395069, 0.009033},{1.696828, 0.393619, 0.009381},{
      1.696369, 0.393547, 0.009381},{1.695921, 0.394925, 0.009033}}],
    Polygon[{{1.696369, 0.393547, -0.009381},{1.695921, 0.394925, -0.009033},{
      1.695103, 0.394508, -0.009033},{1.695954, 0.393336, -0.009381}}],
    Polygon[{{1.695921, 0.394925, -0.009033},{1.695495, 0.396235, -0.008463},{
      1.694293, 0.395622, -0.008463},{1.695103, 0.394508, -0.009033}}],
    Polygon[{{1.695495, 0.396235, -0.008463},{1.695103, 0.397443, -0.007684},{
      1.693546, 0.396650, -0.007684},{1.694293, 0.395622, -0.008463}}],
    Polygon[{{1.695103, 0.397443, -0.007684},{1.694752, 0.398521, -0.006716},{
      1.692880, 0.397567, -0.006716},{1.693546, 0.396650, -0.007684}}],
    Polygon[{{1.694752, 0.398521, -0.006716},{1.694453, 0.399442, -0.005583},{
      1.692311, 0.398350, -0.005583},{1.692880, 0.397567, -0.006716}}],
    Polygon[{{1.694453, 0.399442, -0.005583},{1.694213, 0.400182, -0.004312},{
      1.691853, 0.398980, -0.004312},{1.692311, 0.398350, -0.005583}}],
    Polygon[{{1.694213, 0.400182, -0.004312},{1.694036, 0.400725, -0.002935},{
      1.691518, 0.399442, -0.002935},{1.691853, 0.398980, -0.004312}}],
    Polygon[{{1.694036, 0.400725, -0.002935},{1.693929, 0.401056, -0.001486},{
      1.691314, 0.399723, -0.001486},{1.691518, 0.399442, -0.002935}}],
    Polygon[{{1.693929, 0.401056, -0.001486},{1.693893, 0.401167, 0.000000},{
      1.691245, 0.399818, 0.000000},{1.691314, 0.399723, -0.001486}}],
    Polygon[{{1.693893, 0.401167, 0.000000},{1.693929, 0.401056, 0.001486},{
      1.691314, 0.399723, 0.001486},{1.691245, 0.399818, 0.000000}}],
    Polygon[{{1.693929, 0.401056, 0.001486},{1.694036, 0.400725, 0.002935},{
      1.691518, 0.399442, 0.002935},{1.691314, 0.399723, 0.001486}}],
    Polygon[{{1.694036, 0.400725, 0.002935},{1.694213, 0.400182, 0.004312},{
      1.691853, 0.398980, 0.004312},{1.691518, 0.399442, 0.002935}}],
    Polygon[{{1.694213, 0.400182, 0.004312},{1.694453, 0.399442, 0.005583},{
      1.692311, 0.398350, 0.005583},{1.691853, 0.398980, 0.004312}}],
    Polygon[{{1.694453, 0.399442, 0.005583},{1.694752, 0.398521, 0.006716},{
      1.692880, 0.397567, 0.006716},{1.692311, 0.398350, 0.005583}}],
    Polygon[{{1.694752, 0.398521, 0.006716},{1.695103, 0.397443, 0.007684},{
      1.693546, 0.396650, 0.007684},{1.692880, 0.397567, 0.006716}}],
    Polygon[{{1.695103, 0.397443, 0.007684},{1.695495, 0.396235, 0.008463},{
      1.694293, 0.395622, 0.008463},{1.693546, 0.396650, 0.007684}}],
    Polygon[{{1.695495, 0.396235, 0.008463},{1.695921, 0.394925, 0.009033},{
      1.695103, 0.394508, 0.009033},{1.694293, 0.395622, 0.008463}}],
    Polygon[{{1.695921, 0.394925, 0.009033},{1.696369, 0.393547, 0.009381},{
      1.695954, 0.393336, 0.009381},{1.695103, 0.394508, 0.009033}}],
    Polygon[{{1.695954, 0.393336, -0.009381},{1.695103, 0.394508, -0.009033},{
      1.694453, 0.393859, -0.009033},{1.695626, 0.393007, -0.009381}}],
    Polygon[{{1.695103, 0.394508, -0.009033},{1.694293, 0.395622, -0.008463},{
      1.693339, 0.394668, -0.008463},{1.694453, 0.393859, -0.009033}}],
    Polygon[{{1.694293, 0.395622, -0.008463},{1.693546, 0.396650, -0.007684},{
      1.692311, 0.395415, -0.007684},{1.693339, 0.394668, -0.008463}}],
    Polygon[{{1.693546, 0.396650, -0.007684},{1.692880, 0.397567, -0.006716},{
      1.691394, 0.396081, -0.006716},{1.692311, 0.395415, -0.007684}}],
    Polygon[{{1.692880, 0.397567, -0.006716},{1.692311, 0.398350, -0.005583},{
      1.690611, 0.396650, -0.005583},{1.691394, 0.396081, -0.006716}}],
    Polygon[{{1.692311, 0.398350, -0.005583},{1.691853, 0.398980, -0.004312},{
      1.689981, 0.397108, -0.004312},{1.690611, 0.396650, -0.005583}}],
    Polygon[{{1.691853, 0.398980, -0.004312},{1.691518, 0.399442, -0.002935},{
      1.689520, 0.397443, -0.002935},{1.689981, 0.397108, -0.004312}}],
    Polygon[{{1.691518, 0.399442, -0.002935},{1.691314, 0.399723, -0.001486},{
      1.689238, 0.397648, -0.001486},{1.689520, 0.397443, -0.002935}}],
    Polygon[{{1.691314, 0.399723, -0.001486},{1.691245, 0.399818, 0.000000},{
      1.689144, 0.397716, 0.000000},{1.689238, 0.397648, -0.001486}}],
    Polygon[{{1.691245, 0.399818, 0.000000},{1.691314, 0.399723, 0.001486},{
      1.689238, 0.397648, 0.001486},{1.689144, 0.397716, 0.000000}}],
    Polygon[{{1.691314, 0.399723, 0.001486},{1.691518, 0.399442, 0.002935},{
      1.689520, 0.397443, 0.002935},{1.689238, 0.397648, 0.001486}}],
    Polygon[{{1.691518, 0.399442, 0.002935},{1.691853, 0.398980, 0.004312},{
      1.689981, 0.397108, 0.004312},{1.689520, 0.397443, 0.002935}}],
    Polygon[{{1.691853, 0.398980, 0.004312},{1.692311, 0.398350, 0.005583},{
      1.690611, 0.396650, 0.005583},{1.689981, 0.397108, 0.004312}}],
    Polygon[{{1.692311, 0.398350, 0.005583},{1.692880, 0.397567, 0.006716},{
      1.691394, 0.396081, 0.006716},{1.690611, 0.396650, 0.005583}}],
    Polygon[{{1.692880, 0.397567, 0.006716},{1.693546, 0.396650, 0.007684},{
      1.692311, 0.395415, 0.007684},{1.691394, 0.396081, 0.006716}}],
    Polygon[{{1.693546, 0.396650, 0.007684},{1.694293, 0.395622, 0.008463},{
      1.693339, 0.394668, 0.008463},{1.692311, 0.395415, 0.007684}}],
    Polygon[{{1.694293, 0.395622, 0.008463},{1.695103, 0.394508, 0.009033},{
      1.694453, 0.393859, 0.009033},{1.693339, 0.394668, 0.008463}}],
    Polygon[{{1.695103, 0.394508, 0.009033},{1.695954, 0.393336, 0.009381},{
      1.695626, 0.393007, 0.009381},{1.694453, 0.393859, 0.009033}}],
    Polygon[{{1.695626, 0.393007, -0.009381},{1.694453, 0.393859, -0.009033},{
      1.694036, 0.393040, -0.009033},{1.695415, 0.392593, -0.009381}}],
    Polygon[{{1.694453, 0.393859, -0.009033},{1.693339, 0.394668, -0.008463},{
      1.692727, 0.393466, -0.008463},{1.694036, 0.393040, -0.009033}}],
    Polygon[{{1.693339, 0.394668, -0.008463},{1.692311, 0.395415, -0.007684},{
      1.691518, 0.393859, -0.007684},{1.692727, 0.393466, -0.008463}}],
    Polygon[{{1.692311, 0.395415, -0.007684},{1.691394, 0.396081, -0.006716},{
      1.690440, 0.394209, -0.006716},{1.691518, 0.393859, -0.007684}}],
    Polygon[{{1.691394, 0.396081, -0.006716},{1.690611, 0.396650, -0.005583},{
      1.689520, 0.394508, -0.005583},{1.690440, 0.394209, -0.006716}}],
    Polygon[{{1.690611, 0.396650, -0.005583},{1.689981, 0.397108, -0.004312},{
      1.688779, 0.394749, -0.004312},{1.689520, 0.394508, -0.005583}}],
    Polygon[{{1.689981, 0.397108, -0.004312},{1.689520, 0.397443, -0.002935},{
      1.688236, 0.394925, -0.002935},{1.688779, 0.394749, -0.004312}}],
    Polygon[{{1.689520, 0.397443, -0.002935},{1.689238, 0.397648, -0.001486},{
      1.687906, 0.395032, -0.001486},{1.688236, 0.394925, -0.002935}}],
    Polygon[{{1.689238, 0.397648, -0.001486},{1.689144, 0.397716, 0.000000},{
      1.687794, 0.395069, 0.000000},{1.687906, 0.395032, -0.001486}}],
    Polygon[{{1.689144, 0.397716, 0.000000},{1.689238, 0.397648, 0.001486},{
      1.687906, 0.395032, 0.001486},{1.687794, 0.395069, 0.000000}}],
    Polygon[{{1.689238, 0.397648, 0.001486},{1.689520, 0.397443, 0.002935},{
      1.688236, 0.394925, 0.002935},{1.687906, 0.395032, 0.001486}}],
    Polygon[{{1.689520, 0.397443, 0.002935},{1.689981, 0.397108, 0.004312},{
      1.688779, 0.394749, 0.004312},{1.688236, 0.394925, 0.002935}}],
    Polygon[{{1.689981, 0.397108, 0.004312},{1.690611, 0.396650, 0.005583},{
      1.689520, 0.394508, 0.005583},{1.688779, 0.394749, 0.004312}}],
    Polygon[{{1.690611, 0.396650, 0.005583},{1.691394, 0.396081, 0.006716},{
      1.690440, 0.394209, 0.006716},{1.689520, 0.394508, 0.005583}}],
    Polygon[{{1.691394, 0.396081, 0.006716},{1.692311, 0.395415, 0.007684},{
      1.691518, 0.393859, 0.007684},{1.690440, 0.394209, 0.006716}}],
    Polygon[{{1.692311, 0.395415, 0.007684},{1.693339, 0.394668, 0.008463},{
      1.692727, 0.393466, 0.008463},{1.691518, 0.393859, 0.007684}}],
    Polygon[{{1.693339, 0.394668, 0.008463},{1.694453, 0.393859, 0.009033},{
      1.694036, 0.393040, 0.009033},{1.692727, 0.393466, 0.008463}}],
    Polygon[{{1.694453, 0.393859, 0.009033},{1.695626, 0.393007, 0.009381},{
      1.695415, 0.392593, 0.009381},{1.694036, 0.393040, 0.009033}}],
    Polygon[{{1.695415, 0.392593, -0.009381},{1.694036, 0.393040, -0.009033},{
      1.693893, 0.392133, -0.009033},{1.695342, 0.392133, -0.009381}}],
    Polygon[{{1.694036, 0.393040, -0.009033},{1.692727, 0.393466, -0.008463},{
      1.692516, 0.392133, -0.008463},{1.693893, 0.392133, -0.009033}}],
    Polygon[{{1.692727, 0.393466, -0.008463},{1.691518, 0.393859, -0.007684},{
      1.691245, 0.392133, -0.007684},{1.692516, 0.392133, -0.008463}}],
    Polygon[{{1.691518, 0.393859, -0.007684},{1.690440, 0.394209, -0.006716},{
      1.690112, 0.392133, -0.006716},{1.691245, 0.392133, -0.007684}}],
    Polygon[{{1.690440, 0.394209, -0.006716},{1.689520, 0.394508, -0.005583},{
      1.689144, 0.392133, -0.005583},{1.690112, 0.392133, -0.006716}}],
    Polygon[{{1.689520, 0.394508, -0.005583},{1.688779, 0.394749, -0.004312},{
      1.688365, 0.392133, -0.004312},{1.689144, 0.392133, -0.005583}}],
    Polygon[{{1.688779, 0.394749, -0.004312},{1.688236, 0.394925, -0.002935},{
      1.687794, 0.392133, -0.002935},{1.688365, 0.392133, -0.004312}}],
    Polygon[{{1.688236, 0.394925, -0.002935},{1.687906, 0.395032, -0.001486},{
      1.687446, 0.392133, -0.001486},{1.687794, 0.392133, -0.002935}}],
    Polygon[{{1.687906, 0.395032, -0.001486},{1.687794, 0.395069, 0.000000},{
      1.687330, 0.392133, 0.000000},{1.687446, 0.392133, -0.001486}}],
    Polygon[{{1.687794, 0.395069, 0.000000},{1.687906, 0.395032, 0.001486},{
      1.687446, 0.392133, 0.001486},{1.687330, 0.392133, 0.000000}}],
    Polygon[{{1.687906, 0.395032, 0.001486},{1.688236, 0.394925, 0.002935},{
      1.687794, 0.392133, 0.002935},{1.687446, 0.392133, 0.001486}}],
    Polygon[{{1.688236, 0.394925, 0.002935},{1.688779, 0.394749, 0.004312},{
      1.688365, 0.392133, 0.004312},{1.687794, 0.392133, 0.002935}}],
    Polygon[{{1.688779, 0.394749, 0.004312},{1.689520, 0.394508, 0.005583},{
      1.689144, 0.392133, 0.005583},{1.688365, 0.392133, 0.004312}}],
    Polygon[{{1.689520, 0.394508, 0.005583},{1.690440, 0.394209, 0.006716},{
      1.690112, 0.392133, 0.006716},{1.689144, 0.392133, 0.005583}}],
    Polygon[{{1.690440, 0.394209, 0.006716},{1.691518, 0.393859, 0.007684},{
      1.691245, 0.392133, 0.007684},{1.690112, 0.392133, 0.006716}}],
    Polygon[{{1.691518, 0.393859, 0.007684},{1.692727, 0.393466, 0.008463},{
      1.692516, 0.392133, 0.008463},{1.691245, 0.392133, 0.007684}}],
    Polygon[{{1.692727, 0.393466, 0.008463},{1.694036, 0.393040, 0.009033},{
      1.693893, 0.392133, 0.009033},{1.692516, 0.392133, 0.008463}}],
    Polygon[{{1.694036, 0.393040, 0.009033},{1.695415, 0.392593, 0.009381},{
      1.695342, 0.392133, 0.009381},{1.693893, 0.392133, 0.009033}}],
    Polygon[{{1.695342, 0.392133, -0.009381},{1.693893, 0.392133, -0.009033},{
      1.694036, 0.391226, -0.009033},{1.695415, 0.391674, -0.009381}}],
    Polygon[{{1.693893, 0.392133, -0.009033},{1.692516, 0.392133, -0.008463},{
      1.692727, 0.390801, -0.008463},{1.694036, 0.391226, -0.009033}}],
    Polygon[{{1.692516, 0.392133, -0.008463},{1.691245, 0.392133, -0.007684},{
      1.691518, 0.390408, -0.007684},{1.692727, 0.390801, -0.008463}}],
    Polygon[{{1.691245, 0.392133, -0.007684},{1.690112, 0.392133, -0.006716},{
      1.690440, 0.390058, -0.006716},{1.691518, 0.390408, -0.007684}}],
    Polygon[{{1.690112, 0.392133, -0.006716},{1.689144, 0.392133, -0.005583},{
      1.689520, 0.389759, -0.005583},{1.690440, 0.390058, -0.006716}}],
    Polygon[{{1.689144, 0.392133, -0.005583},{1.688365, 0.392133, -0.004312},{
      1.688779, 0.389518, -0.004312},{1.689520, 0.389759, -0.005583}}],
    Polygon[{{1.688365, 0.392133, -0.004312},{1.687794, 0.392133, -0.002935},{
      1.688236, 0.389342, -0.002935},{1.688779, 0.389518, -0.004312}}],
    Polygon[{{1.687794, 0.392133, -0.002935},{1.687446, 0.392133, -0.001486},{
      1.687906, 0.389234, -0.001486},{1.688236, 0.389342, -0.002935}}],
    Polygon[{{1.687446, 0.392133, -0.001486},{1.687330, 0.392133, 0.000000},{
      1.687794, 0.389198, 0.000000},{1.687906, 0.389234, -0.001486}}],
    Polygon[{{1.687330, 0.392133, 0.000000},{1.687446, 0.392133, 0.001486},{
      1.687906, 0.389234, 0.001486},{1.687794, 0.389198, 0.000000}}],
    Polygon[{{1.687446, 0.392133, 0.001486},{1.687794, 0.392133, 0.002935},{
      1.688236, 0.389342, 0.002935},{1.687906, 0.389234, 0.001486}}],
    Polygon[{{1.687794, 0.392133, 0.002935},{1.688365, 0.392133, 0.004312},{
      1.688779, 0.389518, 0.004312},{1.688236, 0.389342, 0.002935}}],
    Polygon[{{1.688365, 0.392133, 0.004312},{1.689144, 0.392133, 0.005583},{
      1.689520, 0.389759, 0.005583},{1.688779, 0.389518, 0.004312}}],
    Polygon[{{1.689144, 0.392133, 0.005583},{1.690112, 0.392133, 0.006716},{
      1.690440, 0.390058, 0.006716},{1.689520, 0.389759, 0.005583}}],
    Polygon[{{1.690112, 0.392133, 0.006716},{1.691245, 0.392133, 0.007684},{
      1.691518, 0.390408, 0.007684},{1.690440, 0.390058, 0.006716}}],
    Polygon[{{1.691245, 0.392133, 0.007684},{1.692516, 0.392133, 0.008463},{
      1.692727, 0.390801, 0.008463},{1.691518, 0.390408, 0.007684}}],
    Polygon[{{1.692516, 0.392133, 0.008463},{1.693893, 0.392133, 0.009033},{
      1.694036, 0.391226, 0.009033},{1.692727, 0.390801, 0.008463}}],
    Polygon[{{1.693893, 0.392133, 0.009033},{1.695342, 0.392133, 0.009381},{
      1.695415, 0.391674, 0.009381},{1.694036, 0.391226, 0.009033}}],
    Polygon[{{1.695415, 0.391674, -0.009381},{1.694036, 0.391226, -0.009033},{
      1.694453, 0.390408, -0.009033},{1.695626, 0.391260, -0.009381}}],
    Polygon[{{1.694036, 0.391226, -0.009033},{1.692727, 0.390801, -0.008463},{
      1.693339, 0.389599, -0.008463},{1.694453, 0.390408, -0.009033}}],
    Polygon[{{1.692727, 0.390801, -0.008463},{1.691518, 0.390408, -0.007684},{
      1.692311, 0.388852, -0.007684},{1.693339, 0.389599, -0.008463}}],
    Polygon[{{1.691518, 0.390408, -0.007684},{1.690440, 0.390058, -0.006716},{
      1.691394, 0.388186, -0.006716},{1.692311, 0.388852, -0.007684}}],
    Polygon[{{1.690440, 0.390058, -0.006716},{1.689520, 0.389759, -0.005583},{
      1.690611, 0.387617, -0.005583},{1.691394, 0.388186, -0.006716}}],
    Polygon[{{1.689520, 0.389759, -0.005583},{1.688779, 0.389518, -0.004312},{
      1.689981, 0.387159, -0.004312},{1.690611, 0.387617, -0.005583}}],
    Polygon[{{1.688779, 0.389518, -0.004312},{1.688236, 0.389342, -0.002935},{
      1.689520, 0.386824, -0.002935},{1.689981, 0.387159, -0.004312}}],
    Polygon[{{1.688236, 0.389342, -0.002935},{1.687906, 0.389234, -0.001486},{
      1.689238, 0.386619, -0.001486},{1.689520, 0.386824, -0.002935}}],
    Polygon[{{1.687906, 0.389234, -0.001486},{1.687794, 0.389198, 0.000000},{
      1.689144, 0.386551, 0.000000},{1.689238, 0.386619, -0.001486}}],
    Polygon[{{1.687794, 0.389198, 0.000000},{1.687906, 0.389234, 0.001486},{
      1.689238, 0.386619, 0.001486},{1.689144, 0.386551, 0.000000}}],
    Polygon[{{1.687906, 0.389234, 0.001486},{1.688236, 0.389342, 0.002935},{
      1.689520, 0.386824, 0.002935},{1.689238, 0.386619, 0.001486}}],
    Polygon[{{1.688236, 0.389342, 0.002935},{1.688779, 0.389518, 0.004312},{
      1.689981, 0.387159, 0.004312},{1.689520, 0.386824, 0.002935}}],
    Polygon[{{1.688779, 0.389518, 0.004312},{1.689520, 0.389759, 0.005583},{
      1.690611, 0.387617, 0.005583},{1.689981, 0.387159, 0.004312}}],
    Polygon[{{1.689520, 0.389759, 0.005583},{1.690440, 0.390058, 0.006716},{
      1.691394, 0.388186, 0.006716},{1.690611, 0.387617, 0.005583}}],
    Polygon[{{1.690440, 0.390058, 0.006716},{1.691518, 0.390408, 0.007684},{
      1.692311, 0.388852, 0.007684},{1.691394, 0.388186, 0.006716}}],
    Polygon[{{1.691518, 0.390408, 0.007684},{1.692727, 0.390801, 0.008463},{
      1.693339, 0.389599, 0.008463},{1.692311, 0.388852, 0.007684}}],
    Polygon[{{1.692727, 0.390801, 0.008463},{1.694036, 0.391226, 0.009033},{
      1.694453, 0.390408, 0.009033},{1.693339, 0.389599, 0.008463}}],
    Polygon[{{1.694036, 0.391226, 0.009033},{1.695415, 0.391674, 0.009381},{
      1.695626, 0.391260, 0.009381},{1.694453, 0.390408, 0.009033}}],
    Polygon[{{1.695626, 0.391260, -0.009381},{1.694453, 0.390408, -0.009033},{
      1.695103, 0.389759, -0.009033},{1.695954, 0.390931, -0.009381}}],
    Polygon[{{1.694453, 0.390408, -0.009033},{1.693339, 0.389599, -0.008463},{
      1.694293, 0.388645, -0.008463},{1.695103, 0.389759, -0.009033}}],
    Polygon[{{1.693339, 0.389599, -0.008463},{1.692311, 0.388852, -0.007684},{
      1.693546, 0.387617, -0.007684},{1.694293, 0.388645, -0.008463}}],
    Polygon[{{1.692311, 0.388852, -0.007684},{1.691394, 0.388186, -0.006716},{
      1.692880, 0.386700, -0.006716},{1.693546, 0.387617, -0.007684}}],
    Polygon[{{1.691394, 0.388186, -0.006716},{1.690611, 0.387617, -0.005583},{
      1.692311, 0.385917, -0.005583},{1.692880, 0.386700, -0.006716}}],
    Polygon[{{1.690611, 0.387617, -0.005583},{1.689981, 0.387159, -0.004312},{
      1.691853, 0.385287, -0.004312},{1.692311, 0.385917, -0.005583}}],
    Polygon[{{1.689981, 0.387159, -0.004312},{1.689520, 0.386824, -0.002935},{
      1.691518, 0.384825, -0.002935},{1.691853, 0.385287, -0.004312}}],
    Polygon[{{1.689520, 0.386824, -0.002935},{1.689238, 0.386619, -0.001486},{
      1.691314, 0.384544, -0.001486},{1.691518, 0.384825, -0.002935}}],
    Polygon[{{1.689238, 0.386619, -0.001486},{1.689144, 0.386551, 0.000000},{
      1.691245, 0.384449, 0.000000},{1.691314, 0.384544, -0.001486}}],
    Polygon[{{1.689144, 0.386551, 0.000000},{1.689238, 0.386619, 0.001486},{
      1.691314, 0.384544, 0.001486},{1.691245, 0.384449, 0.000000}}],
    Polygon[{{1.689238, 0.386619, 0.001486},{1.689520, 0.386824, 0.002935},{
      1.691518, 0.384825, 0.002935},{1.691314, 0.384544, 0.001486}}],
    Polygon[{{1.689520, 0.386824, 0.002935},{1.689981, 0.387159, 0.004312},{
      1.691853, 0.385287, 0.004312},{1.691518, 0.384825, 0.002935}}],
    Polygon[{{1.689981, 0.387159, 0.004312},{1.690611, 0.387617, 0.005583},{
      1.692311, 0.385917, 0.005583},{1.691853, 0.385287, 0.004312}}],
    Polygon[{{1.690611, 0.387617, 0.005583},{1.691394, 0.388186, 0.006716},{
      1.692880, 0.386700, 0.006716},{1.692311, 0.385917, 0.005583}}],
    Polygon[{{1.691394, 0.388186, 0.006716},{1.692311, 0.388852, 0.007684},{
      1.693546, 0.387617, 0.007684},{1.692880, 0.386700, 0.006716}}],
    Polygon[{{1.692311, 0.388852, 0.007684},{1.693339, 0.389599, 0.008463},{
      1.694293, 0.388645, 0.008463},{1.693546, 0.387617, 0.007684}}],
    Polygon[{{1.693339, 0.389599, 0.008463},{1.694453, 0.390408, 0.009033},{
      1.695103, 0.389759, 0.009033},{1.694293, 0.388645, 0.008463}}],
    Polygon[{{1.694453, 0.390408, 0.009033},{1.695626, 0.391260, 0.009381},{
      1.695954, 0.390931, 0.009381},{1.695103, 0.389759, 0.009033}}],
    Polygon[{{1.695954, 0.390931, -0.009381},{1.695103, 0.389759, -0.009033},{
      1.695921, 0.389342, -0.009033},{1.696369, 0.390720, -0.009381}}],
    Polygon[{{1.695103, 0.389759, -0.009033},{1.694293, 0.388645, -0.008463},{
      1.695495, 0.388032, -0.008463},{1.695921, 0.389342, -0.009033}}],
    Polygon[{{1.694293, 0.388645, -0.008463},{1.693546, 0.387617, -0.007684},{
      1.695103, 0.386824, -0.007684},{1.695495, 0.388032, -0.008463}}],
    Polygon[{{1.693546, 0.387617, -0.007684},{1.692880, 0.386700, -0.006716},{
      1.694752, 0.385746, -0.006716},{1.695103, 0.386824, -0.007684}}],
    Polygon[{{1.692880, 0.386700, -0.006716},{1.692311, 0.385917, -0.005583},{
      1.694453, 0.384825, -0.005583},{1.694752, 0.385746, -0.006716}}],
    Polygon[{{1.692311, 0.385917, -0.005583},{1.691853, 0.385287, -0.004312},{
      1.694213, 0.384085, -0.004312},{1.694453, 0.384825, -0.005583}}],
    Polygon[{{1.691853, 0.385287, -0.004312},{1.691518, 0.384825, -0.002935},{
      1.694036, 0.383542, -0.002935},{1.694213, 0.384085, -0.004312}}],
    Polygon[{{1.691518, 0.384825, -0.002935},{1.691314, 0.384544, -0.001486},{
      1.693929, 0.383211, -0.001486},{1.694036, 0.383542, -0.002935}}],
    Polygon[{{1.691314, 0.384544, -0.001486},{1.691245, 0.384449, 0.000000},{
      1.693893, 0.383100, 0.000000},{1.693929, 0.383211, -0.001486}}],
    Polygon[{{1.691245, 0.384449, 0.000000},{1.691314, 0.384544, 0.001486},{
      1.693929, 0.383211, 0.001486},{1.693893, 0.383100, 0.000000}}],
    Polygon[{{1.691314, 0.384544, 0.001486},{1.691518, 0.384825, 0.002935},{
      1.694036, 0.383542, 0.002935},{1.693929, 0.383211, 0.001486}}],
    Polygon[{{1.691518, 0.384825, 0.002935},{1.691853, 0.385287, 0.004312},{
      1.694213, 0.384085, 0.004312},{1.694036, 0.383542, 0.002935}}],
    Polygon[{{1.691853, 0.385287, 0.004312},{1.692311, 0.385917, 0.005583},{
      1.694453, 0.384825, 0.005583},{1.694213, 0.384085, 0.004312}}],
    Polygon[{{1.692311, 0.385917, 0.005583},{1.692880, 0.386700, 0.006716},{
      1.694752, 0.385746, 0.006716},{1.694453, 0.384825, 0.005583}}],
    Polygon[{{1.692880, 0.386700, 0.006716},{1.693546, 0.387617, 0.007684},{
      1.695103, 0.386824, 0.007684},{1.694752, 0.385746, 0.006716}}],
    Polygon[{{1.693546, 0.387617, 0.007684},{1.694293, 0.388645, 0.008463},{
      1.695495, 0.388032, 0.008463},{1.695103, 0.386824, 0.007684}}],
    Polygon[{{1.694293, 0.388645, 0.008463},{1.695103, 0.389759, 0.009033},{
      1.695921, 0.389342, 0.009033},{1.695495, 0.388032, 0.008463}}],
    Polygon[{{1.695103, 0.389759, 0.009033},{1.695954, 0.390931, 0.009381},{
      1.696369, 0.390720, 0.009381},{1.695921, 0.389342, 0.009033}}],
    Polygon[{{1.696369, 0.390720, -0.009381},{1.695921, 0.389342, -0.009033},{
      1.696828, 0.389198, -0.009033},{1.696828, 0.390648, -0.009381}}],
    Polygon[{{1.695921, 0.389342, -0.009033},{1.695495, 0.388032, -0.008463},{
      1.696828, 0.387821, -0.008463},{1.696828, 0.389198, -0.009033}}],
    Polygon[{{1.695495, 0.388032, -0.008463},{1.695103, 0.386824, -0.007684},{
      1.696828, 0.386551, -0.007684},{1.696828, 0.387821, -0.008463}}],
    Polygon[{{1.695103, 0.386824, -0.007684},{1.694752, 0.385746, -0.006716},{
      1.696828, 0.385417, -0.006716},{1.696828, 0.386551, -0.007684}}],
    Polygon[{{1.694752, 0.385746, -0.006716},{1.694453, 0.384825, -0.005583},{
      1.696828, 0.384449, -0.005583},{1.696828, 0.385417, -0.006716}}],
    Polygon[{{1.694453, 0.384825, -0.005583},{1.694213, 0.384085, -0.004312},{
      1.696828, 0.383670, -0.004312},{1.696828, 0.384449, -0.005583}}],
    Polygon[{{1.694213, 0.384085, -0.004312},{1.694036, 0.383542, -0.002935},{
      1.696828, 0.383100, -0.002935},{1.696828, 0.383670, -0.004312}}],
    Polygon[{{1.694036, 0.383542, -0.002935},{1.693929, 0.383211, -0.001486},{
      1.696828, 0.382752, -0.001486},{1.696828, 0.383100, -0.002935}}],
    Polygon[{{1.693929, 0.383211, -0.001486},{1.693893, 0.383100, 0.000000},{
      1.696828, 0.382635, 0.000000},{1.696828, 0.382752, -0.001486}}],
    Polygon[{{1.693893, 0.383100, 0.000000},{1.693929, 0.383211, 0.001486},{
      1.696828, 0.382752, 0.001486},{1.696828, 0.382635, 0.000000}}],
    Polygon[{{1.693929, 0.383211, 0.001486},{1.694036, 0.383542, 0.002935},{
      1.696828, 0.383100, 0.002935},{1.696828, 0.382752, 0.001486}}],
    Polygon[{{1.694036, 0.383542, 0.002935},{1.694213, 0.384085, 0.004312},{
      1.696828, 0.383670, 0.004312},{1.696828, 0.383100, 0.002935}}],
    Polygon[{{1.694213, 0.384085, 0.004312},{1.694453, 0.384825, 0.005583},{
      1.696828, 0.384449, 0.005583},{1.696828, 0.383670, 0.004312}}],
    Polygon[{{1.694453, 0.384825, 0.005583},{1.694752, 0.385746, 0.006716},{
      1.696828, 0.385417, 0.006716},{1.696828, 0.384449, 0.005583}}],
    Polygon[{{1.694752, 0.385746, 0.006716},{1.695103, 0.386824, 0.007684},{
      1.696828, 0.386551, 0.007684},{1.696828, 0.385417, 0.006716}}],
    Polygon[{{1.695103, 0.386824, 0.007684},{1.695495, 0.388032, 0.008463},{
      1.696828, 0.387821, 0.008463},{1.696828, 0.386551, 0.007684}}],
    Polygon[{{1.695495, 0.388032, 0.008463},{1.695921, 0.389342, 0.009033},{
      1.696828, 0.389198, 0.009033},{1.696828, 0.387821, 0.008463}}],
    Polygon[{{1.695921, 0.389342, 0.009033},{1.696369, 0.390720, 0.009381},{
      1.696828, 0.390648, 0.009381},{1.696828, 0.389198, 0.009033}}],
    Polygon[{{1.696828, 0.390648, -0.009381},{1.696828, 0.389198, -0.009033},{
      1.697735, 0.389342, -0.009033},{1.697287, 0.390720, -0.009381}}],
    Polygon[{{1.696828, 0.389198, -0.009033},{1.696828, 0.387821, -0.008463},{
      1.698160, 0.388032, -0.008463},{1.697735, 0.389342, -0.009033}}],
    Polygon[{{1.696828, 0.387821, -0.008463},{1.696828, 0.386551, -0.007684},{
      1.698553, 0.386824, -0.007684},{1.698160, 0.388032, -0.008463}}],
    Polygon[{{1.696828, 0.386551, -0.007684},{1.696828, 0.385417, -0.006716},{
      1.698903, 0.385746, -0.006716},{1.698553, 0.386824, -0.007684}}],
    Polygon[{{1.696828, 0.385417, -0.006716},{1.696828, 0.384449, -0.005583},{
      1.699202, 0.384825, -0.005583},{1.698903, 0.385746, -0.006716}}],
    Polygon[{{1.696828, 0.384449, -0.005583},{1.696828, 0.383670, -0.004312},{
      1.699443, 0.384085, -0.004312},{1.699202, 0.384825, -0.005583}}],
    Polygon[{{1.696828, 0.383670, -0.004312},{1.696828, 0.383100, -0.002935},{
      1.699619, 0.383542, -0.002935},{1.699443, 0.384085, -0.004312}}],
    Polygon[{{1.696828, 0.383100, -0.002935},{1.696828, 0.382752, -0.001486},{
      1.699727, 0.383211, -0.001486},{1.699619, 0.383542, -0.002935}}],
    Polygon[{{1.696828, 0.382752, -0.001486},{1.696828, 0.382635, 0.000000},{
      1.699763, 0.383100, 0.000000},{1.699727, 0.383211, -0.001486}}],
    Polygon[{{1.696828, 0.382635, 0.000000},{1.696828, 0.382752, 0.001486},{
      1.699727, 0.383211, 0.001486},{1.699763, 0.383100, 0.000000}}],
    Polygon[{{1.696828, 0.382752, 0.001486},{1.696828, 0.383100, 0.002935},{
      1.699619, 0.383542, 0.002935},{1.699727, 0.383211, 0.001486}}],
    Polygon[{{1.696828, 0.383100, 0.002935},{1.696828, 0.383670, 0.004312},{
      1.699443, 0.384085, 0.004312},{1.699619, 0.383542, 0.002935}}],
    Polygon[{{1.696828, 0.383670, 0.004312},{1.696828, 0.384449, 0.005583},{
      1.699202, 0.384825, 0.005583},{1.699443, 0.384085, 0.004312}}],
    Polygon[{{1.696828, 0.384449, 0.005583},{1.696828, 0.385417, 0.006716},{
      1.698903, 0.385746, 0.006716},{1.699202, 0.384825, 0.005583}}],
    Polygon[{{1.696828, 0.385417, 0.006716},{1.696828, 0.386551, 0.007684},{
      1.698553, 0.386824, 0.007684},{1.698903, 0.385746, 0.006716}}],
    Polygon[{{1.696828, 0.386551, 0.007684},{1.696828, 0.387821, 0.008463},{
      1.698160, 0.388032, 0.008463},{1.698553, 0.386824, 0.007684}}],
    Polygon[{{1.696828, 0.387821, 0.008463},{1.696828, 0.389198, 0.009033},{
      1.697735, 0.389342, 0.009033},{1.698160, 0.388032, 0.008463}}],
    Polygon[{{1.696828, 0.389198, 0.009033},{1.696828, 0.390648, 0.009381},{
      1.697287, 0.390720, 0.009381},{1.697735, 0.389342, 0.009033}}],
    Polygon[{{1.697287, 0.390720, -0.009381},{1.697735, 0.389342, -0.009033},{
      1.698553, 0.389759, -0.009033},{1.697701, 0.390931, -0.009381}}],
    Polygon[{{1.697735, 0.389342, -0.009033},{1.698160, 0.388032, -0.008463},{
      1.699362, 0.388645, -0.008463},{1.698553, 0.389759, -0.009033}}],
    Polygon[{{1.698160, 0.388032, -0.008463},{1.698553, 0.386824, -0.007684},{
      1.700109, 0.387617, -0.007684},{1.699362, 0.388645, -0.008463}}],
    Polygon[{{1.698553, 0.386824, -0.007684},{1.698903, 0.385746, -0.006716},{
      1.700776, 0.386700, -0.006716},{1.700109, 0.387617, -0.007684}}],
    Polygon[{{1.698903, 0.385746, -0.006716},{1.699202, 0.384825, -0.005583},{
      1.701344, 0.385917, -0.005583},{1.700776, 0.386700, -0.006716}}],
    Polygon[{{1.699202, 0.384825, -0.005583},{1.699443, 0.384085, -0.004312},{
      1.701802, 0.385287, -0.004312},{1.701344, 0.385917, -0.005583}}],
    Polygon[{{1.699443, 0.384085, -0.004312},{1.699619, 0.383542, -0.002935},{
      1.702137, 0.384825, -0.002935},{1.701802, 0.385287, -0.004312}}],
    Polygon[{{1.699619, 0.383542, -0.002935},{1.699727, 0.383211, -0.001486},{
      1.702342, 0.384544, -0.001486},{1.702137, 0.384825, -0.002935}}],
    Polygon[{{1.699727, 0.383211, -0.001486},{1.699763, 0.383100, 0.000000},{
      1.702411, 0.384449, 0.000000},{1.702342, 0.384544, -0.001486}}],
    Polygon[{{1.699763, 0.383100, 0.000000},{1.699727, 0.383211, 0.001486},{
      1.702342, 0.384544, 0.001486},{1.702411, 0.384449, 0.000000}}],
    Polygon[{{1.699727, 0.383211, 0.001486},{1.699619, 0.383542, 0.002935},{
      1.702137, 0.384825, 0.002935},{1.702342, 0.384544, 0.001486}}],
    Polygon[{{1.699619, 0.383542, 0.002935},{1.699443, 0.384085, 0.004312},{
      1.701802, 0.385287, 0.004312},{1.702137, 0.384825, 0.002935}}],
    Polygon[{{1.699443, 0.384085, 0.004312},{1.699202, 0.384825, 0.005583},{
      1.701344, 0.385917, 0.005583},{1.701802, 0.385287, 0.004312}}],
    Polygon[{{1.699202, 0.384825, 0.005583},{1.698903, 0.385746, 0.006716},{
      1.700776, 0.386700, 0.006716},{1.701344, 0.385917, 0.005583}}],
    Polygon[{{1.698903, 0.385746, 0.006716},{1.698553, 0.386824, 0.007684},{
      1.700109, 0.387617, 0.007684},{1.700776, 0.386700, 0.006716}}],
    Polygon[{{1.698553, 0.386824, 0.007684},{1.698160, 0.388032, 0.008463},{
      1.699362, 0.388645, 0.008463},{1.700109, 0.387617, 0.007684}}],
    Polygon[{{1.698160, 0.388032, 0.008463},{1.697735, 0.389342, 0.009033},{
      1.698553, 0.389759, 0.009033},{1.699362, 0.388645, 0.008463}}],
    Polygon[{{1.697735, 0.389342, 0.009033},{1.697287, 0.390720, 0.009381},{
      1.697701, 0.390931, 0.009381},{1.698553, 0.389759, 0.009033}}],
    Polygon[{{1.697701, 0.390931, -0.009381},{1.698553, 0.389759, -0.009033},{
      1.699202, 0.390408, -0.009033},{1.698030, 0.391260, -0.009381}}],
    Polygon[{{1.698553, 0.389759, -0.009033},{1.699362, 0.388645, -0.008463},{
      1.700316, 0.389599, -0.008463},{1.699202, 0.390408, -0.009033}}],
    Polygon[{{1.699362, 0.388645, -0.008463},{1.700109, 0.387617, -0.007684},{
      1.701344, 0.388852, -0.007684},{1.700316, 0.389599, -0.008463}}],
    Polygon[{{1.700109, 0.387617, -0.007684},{1.700776, 0.386700, -0.006716},{
      1.702261, 0.388186, -0.006716},{1.701344, 0.388852, -0.007684}}],
    Polygon[{{1.700776, 0.386700, -0.006716},{1.701344, 0.385917, -0.005583},{
      1.703045, 0.387617, -0.005583},{1.702261, 0.388186, -0.006716}}],
    Polygon[{{1.701344, 0.385917, -0.005583},{1.701802, 0.385287, -0.004312},{
      1.703675, 0.387159, -0.004312},{1.703045, 0.387617, -0.005583}}],
    Polygon[{{1.701802, 0.385287, -0.004312},{1.702137, 0.384825, -0.002935},{
      1.704136, 0.386824, -0.002935},{1.703675, 0.387159, -0.004312}}],
    Polygon[{{1.702137, 0.384825, -0.002935},{1.702342, 0.384544, -0.001486},{
      1.704417, 0.386619, -0.001486},{1.704136, 0.386824, -0.002935}}],
    Polygon[{{1.702342, 0.384544, -0.001486},{1.702411, 0.384449, 0.000000},{
      1.704512, 0.386551, 0.000000},{1.704417, 0.386619, -0.001486}}],
    Polygon[{{1.702411, 0.384449, 0.000000},{1.702342, 0.384544, 0.001486},{
      1.704417, 0.386619, 0.001486},{1.704512, 0.386551, 0.000000}}],
    Polygon[{{1.702342, 0.384544, 0.001486},{1.702137, 0.384825, 0.002935},{
      1.704136, 0.386824, 0.002935},{1.704417, 0.386619, 0.001486}}],
    Polygon[{{1.702137, 0.384825, 0.002935},{1.701802, 0.385287, 0.004312},{
      1.703675, 0.387159, 0.004312},{1.704136, 0.386824, 0.002935}}],
    Polygon[{{1.701802, 0.385287, 0.004312},{1.701344, 0.385917, 0.005583},{
      1.703045, 0.387617, 0.005583},{1.703675, 0.387159, 0.004312}}],
    Polygon[{{1.701344, 0.385917, 0.005583},{1.700776, 0.386700, 0.006716},{
      1.702261, 0.388186, 0.006716},{1.703045, 0.387617, 0.005583}}],
    Polygon[{{1.700776, 0.386700, 0.006716},{1.700109, 0.387617, 0.007684},{
      1.701344, 0.388852, 0.007684},{1.702261, 0.388186, 0.006716}}],
    Polygon[{{1.700109, 0.387617, 0.007684},{1.699362, 0.388645, 0.008463},{
      1.700316, 0.389599, 0.008463},{1.701344, 0.388852, 0.007684}}],
    Polygon[{{1.699362, 0.388645, 0.008463},{1.698553, 0.389759, 0.009033},{
      1.699202, 0.390408, 0.009033},{1.700316, 0.389599, 0.008463}}],
    Polygon[{{1.698553, 0.389759, 0.009033},{1.697701, 0.390931, 0.009381},{
      1.698030, 0.391260, 0.009381},{1.699202, 0.390408, 0.009033}}],
    Polygon[{{1.698030, 0.391260, -0.009381},{1.699202, 0.390408, -0.009033},{
      1.699619, 0.391226, -0.009033},{1.698241, 0.391674, -0.009381}}],
    Polygon[{{1.699202, 0.390408, -0.009033},{1.700316, 0.389599, -0.008463},{
      1.700929, 0.390801, -0.008463},{1.699619, 0.391226, -0.009033}}],
    Polygon[{{1.700316, 0.389599, -0.008463},{1.701344, 0.388852, -0.007684},{
      1.702137, 0.390408, -0.007684},{1.700929, 0.390801, -0.008463}}],
    Polygon[{{1.701344, 0.388852, -0.007684},{1.702261, 0.388186, -0.006716},{
      1.703215, 0.390058, -0.006716},{1.702137, 0.390408, -0.007684}}],
    Polygon[{{1.702261, 0.388186, -0.006716},{1.703045, 0.387617, -0.005583},{
      1.704136, 0.389759, -0.005583},{1.703215, 0.390058, -0.006716}}],
    Polygon[{{1.703045, 0.387617, -0.005583},{1.703675, 0.387159, -0.004312},{
      1.704877, 0.389518, -0.004312},{1.704136, 0.389759, -0.005583}}],
    Polygon[{{1.703675, 0.387159, -0.004312},{1.704136, 0.386824, -0.002935},{
      1.705419, 0.389342, -0.002935},{1.704877, 0.389518, -0.004312}}],
    Polygon[{{1.704136, 0.386824, -0.002935},{1.704417, 0.386619, -0.001486},{
      1.705750, 0.389234, -0.001486},{1.705419, 0.389342, -0.002935}}],
    Polygon[{{1.704417, 0.386619, -0.001486},{1.704512, 0.386551, 0.000000},{
      1.705861, 0.389198, 0.000000},{1.705750, 0.389234, -0.001486}}],
    Polygon[{{1.704512, 0.386551, 0.000000},{1.704417, 0.386619, 0.001486},{
      1.705750, 0.389234, 0.001486},{1.705861, 0.389198, 0.000000}}],
    Polygon[{{1.704417, 0.386619, 0.001486},{1.704136, 0.386824, 0.002935},{
      1.705419, 0.389342, 0.002935},{1.705750, 0.389234, 0.001486}}],
    Polygon[{{1.704136, 0.386824, 0.002935},{1.703675, 0.387159, 0.004312},{
      1.704877, 0.389518, 0.004312},{1.705419, 0.389342, 0.002935}}],
    Polygon[{{1.703675, 0.387159, 0.004312},{1.703045, 0.387617, 0.005583},{
      1.704136, 0.389759, 0.005583},{1.704877, 0.389518, 0.004312}}],
    Polygon[{{1.703045, 0.387617, 0.005583},{1.702261, 0.388186, 0.006716},{
      1.703215, 0.390058, 0.006716},{1.704136, 0.389759, 0.005583}}],
    Polygon[{{1.702261, 0.388186, 0.006716},{1.701344, 0.388852, 0.007684},{
      1.702137, 0.390408, 0.007684},{1.703215, 0.390058, 0.006716}}],
    Polygon[{{1.701344, 0.388852, 0.007684},{1.700316, 0.389599, 0.008463},{
      1.700929, 0.390801, 0.008463},{1.702137, 0.390408, 0.007684}}],
    Polygon[{{1.700316, 0.389599, 0.008463},{1.699202, 0.390408, 0.009033},{
      1.699619, 0.391226, 0.009033},{1.700929, 0.390801, 0.008463}}],
    Polygon[{{1.699202, 0.390408, 0.009033},{1.698030, 0.391260, 0.009381},{
      1.698241, 0.391674, 0.009381},{1.699619, 0.391226, 0.009033}}],
    Polygon[{{1.698241, 0.391674, -0.009381},{1.699619, 0.391226, -0.009033},{
      1.699763, 0.392133, -0.009033},{1.698314, 0.392133, -0.009381}}],
    Polygon[{{1.699619, 0.391226, -0.009033},{1.700929, 0.390801, -0.008463},{
      1.701140, 0.392133, -0.008463},{1.699763, 0.392133, -0.009033}}],
    Polygon[{{1.700929, 0.390801, -0.008463},{1.702137, 0.390408, -0.007684},{
      1.702411, 0.392133, -0.007684},{1.701140, 0.392133, -0.008463}}],
    Polygon[{{1.702137, 0.390408, -0.007684},{1.703215, 0.390058, -0.006716},{
      1.703544, 0.392133, -0.006716},{1.702411, 0.392133, -0.007684}}],
    Polygon[{{1.703215, 0.390058, -0.006716},{1.704136, 0.389759, -0.005583},{
      1.704512, 0.392133, -0.005583},{1.703544, 0.392133, -0.006716}}],
    Polygon[{{1.704136, 0.389759, -0.005583},{1.704877, 0.389518, -0.004312},{
      1.705291, 0.392133, -0.004312},{1.704512, 0.392133, -0.005583}}],
    Polygon[{{1.704877, 0.389518, -0.004312},{1.705419, 0.389342, -0.002935},{
      1.705861, 0.392133, -0.002935},{1.705291, 0.392133, -0.004312}}],
    Polygon[{{1.705419, 0.389342, -0.002935},{1.705750, 0.389234, -0.001486},{
      1.706209, 0.392133, -0.001486},{1.705861, 0.392133, -0.002935}}],
    Polygon[{{1.705750, 0.389234, -0.001486},{1.705861, 0.389198, 0.000000},{
      1.706326, 0.392133, 0.000000},{1.706209, 0.392133, -0.001486}}],
    Polygon[{{1.705861, 0.389198, 0.000000},{1.705750, 0.389234, 0.001486},{
      1.706209, 0.392133, 0.001486},{1.706326, 0.392133, 0.000000}}],
    Polygon[{{1.705750, 0.389234, 0.001486},{1.705419, 0.389342, 0.002935},{
      1.705861, 0.392133, 0.002935},{1.706209, 0.392133, 0.001486}}],
    Polygon[{{1.705419, 0.389342, 0.002935},{1.704877, 0.389518, 0.004312},{
      1.705291, 0.392133, 0.004312},{1.705861, 0.392133, 0.002935}}],
    Polygon[{{1.704877, 0.389518, 0.004312},{1.704136, 0.389759, 0.005583},{
      1.704512, 0.392133, 0.005583},{1.705291, 0.392133, 0.004312}}],
    Polygon[{{1.704136, 0.389759, 0.005583},{1.703215, 0.390058, 0.006716},{
      1.703544, 0.392133, 0.006716},{1.704512, 0.392133, 0.005583}}],
    Polygon[{{1.703215, 0.390058, 0.006716},{1.702137, 0.390408, 0.007684},{
      1.702411, 0.392133, 0.007684},{1.703544, 0.392133, 0.006716}}],
    Polygon[{{1.702137, 0.390408, 0.007684},{1.700929, 0.390801, 0.008463},{
      1.701140, 0.392133, 0.008463},{1.702411, 0.392133, 0.007684}}],
    Polygon[{{1.700929, 0.390801, 0.008463},{1.699619, 0.391226, 0.009033},{
      1.699763, 0.392133, 0.009033},{1.701140, 0.392133, 0.008463}}],
    Polygon[{{1.699619, 0.391226, 0.009033},{1.698241, 0.391674, 0.009381},{
      1.698314, 0.392133, 0.009381},{1.699763, 0.392133, 0.009033}}],
    Polygon[{{1.576108, 0.388494, -0.024871},{1.579950, 0.388494, -0.023948},{
      1.579569, 0.390899, -0.023948},{1.575915, 0.389712, -0.024871}}],
    Polygon[{{1.579950, 0.388494, -0.023948},{1.583601, 0.388494, -0.022436},{
      1.583041, 0.392027, -0.022436},{1.579569, 0.390899, -0.023948}}],
    Polygon[{{1.583601, 0.388494, -0.022436},{1.586970, 0.388494, -0.020372},{
      1.586245, 0.393068, -0.020372},{1.583041, 0.392027, -0.022436}}],
    Polygon[{{1.586970, 0.388494, -0.020372},{1.589974, 0.388494, -0.017806},{
      1.589103, 0.393997, -0.017806},{1.586245, 0.393068, -0.020372}}],
    Polygon[{{1.589974, 0.388494, -0.017806},{1.592541, 0.388494, -0.014801},{
      1.591543, 0.394790, -0.014801},{1.589103, 0.393997, -0.017806}}],
    Polygon[{{1.592541, 0.388494, -0.014801},{1.594605, 0.388494, -0.011432},{
      1.593507, 0.395428, -0.011432},{1.591543, 0.394790, -0.014801}}],
    Polygon[{{1.594605, 0.388494, -0.011432},{1.596117, 0.388494, -0.007781},{
      1.594945, 0.395895, -0.007781},{1.593507, 0.395428, -0.011432}}],
    Polygon[{{1.596117, 0.388494, -0.007781},{1.597040, 0.388494, -0.003939},{
      1.595822, 0.396180, -0.003939},{1.594945, 0.395895, -0.007781}}],
    Polygon[{{1.597040, 0.388494, -0.003939},{1.597350, 0.388494, 0.000000},{
      1.596117, 0.396276, 0.000000},{1.595822, 0.396180, -0.003939}}],
    Polygon[{{1.597350, 0.388494, 0.000000},{1.597040, 0.388494, 0.003939},{
      1.595822, 0.396180, 0.003939},{1.596117, 0.396276, 0.000000}}],
    Polygon[{{1.597040, 0.388494, 0.003939},{1.596117, 0.388494, 0.007781},{
      1.594945, 0.395895, 0.007781},{1.595822, 0.396180, 0.003939}}],
    Polygon[{{1.596117, 0.388494, 0.007781},{1.594605, 0.388494, 0.011432},{
      1.593507, 0.395428, 0.011432},{1.594945, 0.395895, 0.007781}}],
    Polygon[{{1.594605, 0.388494, 0.011432},{1.592541, 0.388494, 0.014801},{
      1.591543, 0.394790, 0.014801},{1.593507, 0.395428, 0.011432}}],
    Polygon[{{1.592541, 0.388494, 0.014801},{1.589974, 0.388494, 0.017806},{
      1.589103, 0.393997, 0.017806},{1.591543, 0.394790, 0.014801}}],
    Polygon[{{1.589974, 0.388494, 0.017806},{1.586970, 0.388494, 0.020372},{
      1.586245, 0.393068, 0.020372},{1.589103, 0.393997, 0.017806}}],
    Polygon[{{1.586970, 0.388494, 0.020372},{1.583601, 0.388494, 0.022436},{
      1.583041, 0.392027, 0.022436},{1.586245, 0.393068, 0.020372}}],
    Polygon[{{1.583601, 0.388494, 0.022436},{1.579950, 0.388494, 0.023948},{
      1.579569, 0.390899, 0.023948},{1.583041, 0.392027, 0.022436}}],
    Polygon[{{1.579950, 0.388494, 0.023948},{1.576108, 0.388494, 0.024871},{
      1.575915, 0.389712, 0.024871},{1.579569, 0.390899, 0.023948}}],
    Polygon[{{1.575915, 0.389712, -0.024871},{1.579569, 0.390899, -0.023948},{
      1.578464, 0.393068, -0.023948},{1.575356, 0.390810, -0.024871}}],
    Polygon[{{1.579569, 0.390899, -0.023948},{1.583041, 0.392027, -0.022436},{
      1.581417, 0.395214, -0.022436},{1.578464, 0.393068, -0.023948}}],
    Polygon[{{1.583041, 0.392027, -0.022436},{1.586245, 0.393068, -0.020372},{
      1.584143, 0.397194, -0.020372},{1.581417, 0.395214, -0.022436}}],
    Polygon[{{1.586245, 0.393068, -0.020372},{1.589103, 0.393997, -0.017806},{
      1.586574, 0.398960, -0.017806},{1.584143, 0.397194, -0.020372}}],
    Polygon[{{1.589103, 0.393997, -0.017806},{1.591543, 0.394790, -0.014801},{
      1.588650, 0.400469, -0.014801},{1.586574, 0.398960, -0.017806}}],
    Polygon[{{1.591543, 0.394790, -0.014801},{1.593507, 0.395428, -0.011432},{
      1.590320, 0.401682, -0.011432},{1.588650, 0.400469, -0.014801}}],
    Polygon[{{1.593507, 0.395428, -0.011432},{1.594945, 0.395895, -0.007781},{
      1.591543, 0.402571, -0.007781},{1.590320, 0.401682, -0.011432}}],
    Polygon[{{1.594945, 0.395895, -0.007781},{1.595822, 0.396180, -0.003939},{
      1.592290, 0.403113, -0.003939},{1.591543, 0.402571, -0.007781}}],
    Polygon[{{1.595822, 0.396180, -0.003939},{1.596117, 0.396276, 0.000000},{
      1.592541, 0.403295, 0.000000},{1.592290, 0.403113, -0.003939}}],
    Polygon[{{1.596117, 0.396276, 0.000000},{1.595822, 0.396180, 0.003939},{
      1.592290, 0.403113, 0.003939},{1.592541, 0.403295, 0.000000}}],
    Polygon[{{1.595822, 0.396180, 0.003939},{1.594945, 0.395895, 0.007781},{
      1.591543, 0.402571, 0.007781},{1.592290, 0.403113, 0.003939}}],
    Polygon[{{1.594945, 0.395895, 0.007781},{1.593507, 0.395428, 0.011432},{
      1.590320, 0.401682, 0.011432},{1.591543, 0.402571, 0.007781}}],
    Polygon[{{1.593507, 0.395428, 0.011432},{1.591543, 0.394790, 0.014801},{
      1.588650, 0.400469, 0.014801},{1.590320, 0.401682, 0.011432}}],
    Polygon[{{1.591543, 0.394790, 0.014801},{1.589103, 0.393997, 0.017806},{
      1.586574, 0.398960, 0.017806},{1.588650, 0.400469, 0.014801}}],
    Polygon[{{1.589103, 0.393997, 0.017806},{1.586245, 0.393068, 0.020372},{
      1.584143, 0.397194, 0.020372},{1.586574, 0.398960, 0.017806}}],
    Polygon[{{1.586245, 0.393068, 0.020372},{1.583041, 0.392027, 0.022436},{
      1.581417, 0.395214, 0.022436},{1.584143, 0.397194, 0.020372}}],
    Polygon[{{1.583041, 0.392027, 0.022436},{1.579569, 0.390899, 0.023948},{
      1.578464, 0.393068, 0.023948},{1.581417, 0.395214, 0.022436}}],
    Polygon[{{1.579569, 0.390899, 0.023948},{1.575915, 0.389712, 0.024871},{
      1.575356, 0.390810, 0.024871},{1.578464, 0.393068, 0.023948}}],
    Polygon[{{1.575356, 0.390810, -0.024871},{1.578464, 0.393068, -0.023948},{
      1.576743, 0.394790, -0.023948},{1.574484, 0.391681, -0.024871}}],
    Polygon[{{1.578464, 0.393068, -0.023948},{1.581417, 0.395214, -0.022436},{
      1.578888, 0.397743, -0.022436},{1.576743, 0.394790, -0.023948}}],
    Polygon[{{1.581417, 0.395214, -0.022436},{1.584143, 0.397194, -0.020372},{
      1.580868, 0.400469, -0.020372},{1.578888, 0.397743, -0.022436}}],
    Polygon[{{1.584143, 0.397194, -0.020372},{1.586574, 0.398960, -0.017806},{
      1.582635, 0.402899, -0.017806},{1.580868, 0.400469, -0.020372}}],
    Polygon[{{1.586574, 0.398960, -0.017806},{1.588650, 0.400469, -0.014801},{
      1.584143, 0.404975, -0.014801},{1.582635, 0.402899, -0.017806}}],
    Polygon[{{1.588650, 0.400469, -0.014801},{1.590320, 0.401682, -0.011432},{
      1.585356, 0.406646, -0.011432},{1.584143, 0.404975, -0.014801}}],
    Polygon[{{1.590320, 0.401682, -0.011432},{1.591543, 0.402571, -0.007781},{
      1.586245, 0.407869, -0.007781},{1.585356, 0.406646, -0.011432}}],
    Polygon[{{1.591543, 0.402571, -0.007781},{1.592290, 0.403113, -0.003939},{
      1.586787, 0.408615, -0.003939},{1.586245, 0.407869, -0.007781}}],
    Polygon[{{1.592290, 0.403113, -0.003939},{1.592541, 0.403295, 0.000000},{
      1.586970, 0.408866, 0.000000},{1.586787, 0.408615, -0.003939}}],
    Polygon[{{1.592541, 0.403295, 0.000000},{1.592290, 0.403113, 0.003939},{
      1.586787, 0.408615, 0.003939},{1.586970, 0.408866, 0.000000}}],
    Polygon[{{1.592290, 0.403113, 0.003939},{1.591543, 0.402571, 0.007781},{
      1.586245, 0.407869, 0.007781},{1.586787, 0.408615, 0.003939}}],
    Polygon[{{1.591543, 0.402571, 0.007781},{1.590320, 0.401682, 0.011432},{
      1.585356, 0.406646, 0.011432},{1.586245, 0.407869, 0.007781}}],
    Polygon[{{1.590320, 0.401682, 0.011432},{1.588650, 0.400469, 0.014801},{
      1.584143, 0.404975, 0.014801},{1.585356, 0.406646, 0.011432}}],
    Polygon[{{1.588650, 0.400469, 0.014801},{1.586574, 0.398960, 0.017806},{
      1.582635, 0.402899, 0.017806},{1.584143, 0.404975, 0.014801}}],
    Polygon[{{1.586574, 0.398960, 0.017806},{1.584143, 0.397194, 0.020372},{
      1.580868, 0.400469, 0.020372},{1.582635, 0.402899, 0.017806}}],
    Polygon[{{1.584143, 0.397194, 0.020372},{1.581417, 0.395214, 0.022436},{
      1.578888, 0.397743, 0.022436},{1.580868, 0.400469, 0.020372}}],
    Polygon[{{1.581417, 0.395214, 0.022436},{1.578464, 0.393068, 0.023948},{
      1.576743, 0.394790, 0.023948},{1.578888, 0.397743, 0.022436}}],
    Polygon[{{1.578464, 0.393068, 0.023948},{1.575356, 0.390810, 0.024871},{
      1.574484, 0.391681, 0.024871},{1.576743, 0.394790, 0.023948}}],
    Polygon[{{1.574484, 0.391681, -0.024871},{1.576743, 0.394790, -0.023948},{
      1.574573, 0.395895, -0.023948},{1.573386, 0.392241, -0.024871}}],
    Polygon[{{1.576743, 0.394790, -0.023948},{1.578888, 0.397743, -0.022436},{
      1.575701, 0.399367, -0.022436},{1.574573, 0.395895, -0.023948}}],
    Polygon[{{1.578888, 0.397743, -0.022436},{1.580868, 0.400469, -0.020372},{
      1.576743, 0.402571, -0.020372},{1.575701, 0.399367, -0.022436}}],
    Polygon[{{1.580868, 0.400469, -0.020372},{1.582635, 0.402899, -0.017806},{
      1.577671, 0.405428, -0.017806},{1.576743, 0.402571, -0.020372}}],
    Polygon[{{1.582635, 0.402899, -0.017806},{1.584143, 0.404975, -0.014801},{
      1.578464, 0.407869, -0.014801},{1.577671, 0.405428, -0.017806}}],
    Polygon[{{1.584143, 0.404975, -0.014801},{1.585356, 0.406646, -0.011432},{
      1.579102, 0.409832, -0.011432},{1.578464, 0.407869, -0.014801}}],
    Polygon[{{1.585356, 0.406646, -0.011432},{1.586245, 0.407869, -0.007781},{
      1.579569, 0.411271, -0.007781},{1.579102, 0.409832, -0.011432}}],
    Polygon[{{1.586245, 0.407869, -0.007781},{1.586787, 0.408615, -0.003939},{
      1.579854, 0.412148, -0.003939},{1.579569, 0.411271, -0.007781}}],
    Polygon[{{1.586787, 0.408615, -0.003939},{1.586970, 0.408866, 0.000000},{
      1.579950, 0.412443, 0.000000},{1.579854, 0.412148, -0.003939}}],
    Polygon[{{1.586970, 0.408866, 0.000000},{1.586787, 0.408615, 0.003939},{
      1.579854, 0.412148, 0.003939},{1.579950, 0.412443, 0.000000}}],
    Polygon[{{1.586787, 0.408615, 0.003939},{1.586245, 0.407869, 0.007781},{
      1.579569, 0.411271, 0.007781},{1.579854, 0.412148, 0.003939}}],
    Polygon[{{1.586245, 0.407869, 0.007781},{1.585356, 0.406646, 0.011432},{
      1.579102, 0.409832, 0.011432},{1.579569, 0.411271, 0.007781}}],
    Polygon[{{1.585356, 0.406646, 0.011432},{1.584143, 0.404975, 0.014801},{
      1.578464, 0.407869, 0.014801},{1.579102, 0.409832, 0.011432}}],
    Polygon[{{1.584143, 0.404975, 0.014801},{1.582635, 0.402899, 0.017806},{
      1.577671, 0.405428, 0.017806},{1.578464, 0.407869, 0.014801}}],
    Polygon[{{1.582635, 0.402899, 0.017806},{1.580868, 0.400469, 0.020372},{
      1.576743, 0.402571, 0.020372},{1.577671, 0.405428, 0.017806}}],
    Polygon[{{1.580868, 0.400469, 0.020372},{1.578888, 0.397743, 0.022436},{
      1.575701, 0.399367, 0.022436},{1.576743, 0.402571, 0.020372}}],
    Polygon[{{1.578888, 0.397743, 0.022436},{1.576743, 0.394790, 0.023948},{
      1.574573, 0.395895, 0.023948},{1.575701, 0.399367, 0.022436}}],
    Polygon[{{1.576743, 0.394790, 0.023948},{1.574484, 0.391681, 0.024871},{
      1.573386, 0.392241, 0.024871},{1.574573, 0.395895, 0.023948}}],
    Polygon[{{1.573386, 0.392241, -0.024871},{1.574573, 0.395895, -0.023948},{
      1.572169, 0.396276, -0.023948},{1.572169, 0.392433, -0.024871}}],
    Polygon[{{1.574573, 0.395895, -0.023948},{1.575701, 0.399367, -0.022436},{
      1.572169, 0.399926, -0.022436},{1.572169, 0.396276, -0.023948}}],
    Polygon[{{1.575701, 0.399367, -0.022436},{1.576743, 0.402571, -0.020372},{
      1.572169, 0.403295, -0.020372},{1.572169, 0.399926, -0.022436}}],
    Polygon[{{1.576743, 0.402571, -0.020372},{1.577671, 0.405428, -0.017806},{
      1.572169, 0.406300, -0.017806},{1.572169, 0.403295, -0.020372}}],
    Polygon[{{1.577671, 0.405428, -0.017806},{1.578464, 0.407869, -0.014801},{
      1.572169, 0.408866, -0.014801},{1.572169, 0.406300, -0.017806}}],
    Polygon[{{1.578464, 0.407869, -0.014801},{1.579102, 0.409832, -0.011432},{
      1.572169, 0.410931, -0.011432},{1.572169, 0.408866, -0.014801}}],
    Polygon[{{1.579102, 0.409832, -0.011432},{1.579569, 0.411271, -0.007781},{
      1.572169, 0.412443, -0.007781},{1.572169, 0.410931, -0.011432}}],
    Polygon[{{1.579569, 0.411271, -0.007781},{1.579854, 0.412148, -0.003939},{
      1.572169, 0.413365, -0.003939},{1.572169, 0.412443, -0.007781}}],
    Polygon[{{1.579854, 0.412148, -0.003939},{1.579950, 0.412443, 0.000000},{
      1.572169, 0.413675, 0.000000},{1.572169, 0.413365, -0.003939}}],
    Polygon[{{1.579950, 0.412443, 0.000000},{1.579854, 0.412148, 0.003939},{
      1.572169, 0.413365, 0.003939},{1.572169, 0.413675, 0.000000}}],
    Polygon[{{1.579854, 0.412148, 0.003939},{1.579569, 0.411271, 0.007781},{
      1.572169, 0.412443, 0.007781},{1.572169, 0.413365, 0.003939}}],
    Polygon[{{1.579569, 0.411271, 0.007781},{1.579102, 0.409832, 0.011432},{
      1.572169, 0.410931, 0.011432},{1.572169, 0.412443, 0.007781}}],
    Polygon[{{1.579102, 0.409832, 0.011432},{1.578464, 0.407869, 0.014801},{
      1.572169, 0.408866, 0.014801},{1.572169, 0.410931, 0.011432}}],
    Polygon[{{1.578464, 0.407869, 0.014801},{1.577671, 0.405428, 0.017806},{
      1.572169, 0.406300, 0.017806},{1.572169, 0.408866, 0.014801}}],
    Polygon[{{1.577671, 0.405428, 0.017806},{1.576743, 0.402571, 0.020372},{
      1.572169, 0.403295, 0.020372},{1.572169, 0.406300, 0.017806}}],
    Polygon[{{1.576743, 0.402571, 0.020372},{1.575701, 0.399367, 0.022436},{
      1.572169, 0.399926, 0.022436},{1.572169, 0.403295, 0.020372}}],
    Polygon[{{1.575701, 0.399367, 0.022436},{1.574573, 0.395895, 0.023948},{
      1.572169, 0.396276, 0.023948},{1.572169, 0.399926, 0.022436}}],
    Polygon[{{1.574573, 0.395895, 0.023948},{1.573386, 0.392241, 0.024871},{
      1.572169, 0.392433, 0.024871},{1.572169, 0.396276, 0.023948}}],
    Polygon[{{1.572169, 0.392433, -0.024871},{1.572169, 0.396276, -0.023948},{
      1.569764, 0.395895, -0.023948},{1.570951, 0.392241, -0.024871}}],
    Polygon[{{1.572169, 0.396276, -0.023948},{1.572169, 0.399926, -0.022436},{
      1.568636, 0.399367, -0.022436},{1.569764, 0.395895, -0.023948}}],
    Polygon[{{1.572169, 0.399926, -0.022436},{1.572169, 0.403295, -0.020372},{
      1.567595, 0.402571, -0.020372},{1.568636, 0.399367, -0.022436}}],
    Polygon[{{1.572169, 0.403295, -0.020372},{1.572169, 0.406300, -0.017806},{
      1.566667, 0.405428, -0.017806},{1.567595, 0.402571, -0.020372}}],
    Polygon[{{1.572169, 0.406300, -0.017806},{1.572169, 0.408866, -0.014801},{
      1.565874, 0.407869, -0.014801},{1.566667, 0.405428, -0.017806}}],
    Polygon[{{1.572169, 0.408866, -0.014801},{1.572169, 0.410931, -0.011432},{
      1.565236, 0.409832, -0.011432},{1.565874, 0.407869, -0.014801}}],
    Polygon[{{1.572169, 0.410931, -0.011432},{1.572169, 0.412443, -0.007781},{
      1.564768, 0.411271, -0.007781},{1.565236, 0.409832, -0.011432}}],
    Polygon[{{1.572169, 0.412443, -0.007781},{1.572169, 0.413365, -0.003939},{
      1.564483, 0.412148, -0.003939},{1.564768, 0.411271, -0.007781}}],
    Polygon[{{1.572169, 0.413365, -0.003939},{1.572169, 0.413675, 0.000000},{
      1.564387, 0.412443, 0.000000},{1.564483, 0.412148, -0.003939}}],
    Polygon[{{1.572169, 0.413675, 0.000000},{1.572169, 0.413365, 0.003939},{
      1.564483, 0.412148, 0.003939},{1.564387, 0.412443, 0.000000}}],
    Polygon[{{1.572169, 0.413365, 0.003939},{1.572169, 0.412443, 0.007781},{
      1.564768, 0.411271, 0.007781},{1.564483, 0.412148, 0.003939}}],
    Polygon[{{1.572169, 0.412443, 0.007781},{1.572169, 0.410931, 0.011432},{
      1.565236, 0.409832, 0.011432},{1.564768, 0.411271, 0.007781}}],
    Polygon[{{1.572169, 0.410931, 0.011432},{1.572169, 0.408866, 0.014801},{
      1.565874, 0.407869, 0.014801},{1.565236, 0.409832, 0.011432}}],
    Polygon[{{1.572169, 0.408866, 0.014801},{1.572169, 0.406300, 0.017806},{
      1.566667, 0.405428, 0.017806},{1.565874, 0.407869, 0.014801}}],
    Polygon[{{1.572169, 0.406300, 0.017806},{1.572169, 0.403295, 0.020372},{
      1.567595, 0.402571, 0.020372},{1.566667, 0.405428, 0.017806}}],
    Polygon[{{1.572169, 0.403295, 0.020372},{1.572169, 0.399926, 0.022436},{
      1.568636, 0.399367, 0.022436},{1.567595, 0.402571, 0.020372}}],
    Polygon[{{1.572169, 0.399926, 0.022436},{1.572169, 0.396276, 0.023948},{
      1.569764, 0.395895, 0.023948},{1.568636, 0.399367, 0.022436}}],
    Polygon[{{1.572169, 0.396276, 0.023948},{1.572169, 0.392433, 0.024871},{
      1.570951, 0.392241, 0.024871},{1.569764, 0.395895, 0.023948}}],
    Polygon[{{1.570951, 0.392241, -0.024871},{1.569764, 0.395895, -0.023948},{
      1.567595, 0.394790, -0.023948},{1.569853, 0.391681, -0.024871}}],
    Polygon[{{1.569764, 0.395895, -0.023948},{1.568636, 0.399367, -0.022436},{
      1.565449, 0.397743, -0.022436},{1.567595, 0.394790, -0.023948}}],
    Polygon[{{1.568636, 0.399367, -0.022436},{1.567595, 0.402571, -0.020372},{
      1.563469, 0.400469, -0.020372},{1.565449, 0.397743, -0.022436}}],
    Polygon[{{1.567595, 0.402571, -0.020372},{1.566667, 0.405428, -0.017806},{
      1.561703, 0.402899, -0.017806},{1.563469, 0.400469, -0.020372}}],
    Polygon[{{1.566667, 0.405428, -0.017806},{1.565874, 0.407869, -0.014801},{
      1.560195, 0.404975, -0.014801},{1.561703, 0.402899, -0.017806}}],
    Polygon[{{1.565874, 0.407869, -0.014801},{1.565236, 0.409832, -0.011432},{
      1.558981, 0.406646, -0.011432},{1.560195, 0.404975, -0.014801}}],
    Polygon[{{1.565236, 0.409832, -0.011432},{1.564768, 0.411271, -0.007781},{
      1.558092, 0.407869, -0.007781},{1.558981, 0.406646, -0.011432}}],
    Polygon[{{1.564768, 0.411271, -0.007781},{1.564483, 0.412148, -0.003939},{
      1.557550, 0.408615, -0.003939},{1.558092, 0.407869, -0.007781}}],
    Polygon[{{1.564483, 0.412148, -0.003939},{1.564387, 0.412443, 0.000000},{
      1.557368, 0.408866, 0.000000},{1.557550, 0.408615, -0.003939}}],
    Polygon[{{1.564387, 0.412443, 0.000000},{1.564483, 0.412148, 0.003939},{
      1.557550, 0.408615, 0.003939},{1.557368, 0.408866, 0.000000}}],
    Polygon[{{1.564483, 0.412148, 0.003939},{1.564768, 0.411271, 0.007781},{
      1.558092, 0.407869, 0.007781},{1.557550, 0.408615, 0.003939}}],
    Polygon[{{1.564768, 0.411271, 0.007781},{1.565236, 0.409832, 0.011432},{
      1.558981, 0.406646, 0.011432},{1.558092, 0.407869, 0.007781}}],
    Polygon[{{1.565236, 0.409832, 0.011432},{1.565874, 0.407869, 0.014801},{
      1.560195, 0.404975, 0.014801},{1.558981, 0.406646, 0.011432}}],
    Polygon[{{1.565874, 0.407869, 0.014801},{1.566667, 0.405428, 0.017806},{
      1.561703, 0.402899, 0.017806},{1.560195, 0.404975, 0.014801}}],
    Polygon[{{1.566667, 0.405428, 0.017806},{1.567595, 0.402571, 0.020372},{
      1.563469, 0.400469, 0.020372},{1.561703, 0.402899, 0.017806}}],
    Polygon[{{1.567595, 0.402571, 0.020372},{1.568636, 0.399367, 0.022436},{
      1.565449, 0.397743, 0.022436},{1.563469, 0.400469, 0.020372}}],
    Polygon[{{1.568636, 0.399367, 0.022436},{1.569764, 0.395895, 0.023948},{
      1.567595, 0.394790, 0.023948},{1.565449, 0.397743, 0.022436}}],
    Polygon[{{1.569764, 0.395895, 0.023948},{1.570951, 0.392241, 0.024871},{
      1.569853, 0.391681, 0.024871},{1.567595, 0.394790, 0.023948}}],
    Polygon[{{1.569853, 0.391681, -0.024871},{1.567595, 0.394790, -0.023948},{
      1.565874, 0.393068, -0.023948},{1.568982, 0.390810, -0.024871}}],
    Polygon[{{1.567595, 0.394790, -0.023948},{1.565449, 0.397743, -0.022436},{
      1.562920, 0.395214, -0.022436},{1.565874, 0.393068, -0.023948}}],
    Polygon[{{1.565449, 0.397743, -0.022436},{1.563469, 0.400469, -0.020372},{
      1.560195, 0.397194, -0.020372},{1.562920, 0.395214, -0.022436}}],
    Polygon[{{1.563469, 0.400469, -0.020372},{1.561703, 0.402899, -0.017806},{
      1.557764, 0.398960, -0.017806},{1.560195, 0.397194, -0.020372}}],
    Polygon[{{1.561703, 0.402899, -0.017806},{1.560195, 0.404975, -0.014801},{
      1.555688, 0.400469, -0.014801},{1.557764, 0.398960, -0.017806}}],
    Polygon[{{1.560195, 0.404975, -0.014801},{1.558981, 0.406646, -0.011432},{
      1.554017, 0.401682, -0.011432},{1.555688, 0.400469, -0.014801}}],
    Polygon[{{1.558981, 0.406646, -0.011432},{1.558092, 0.407869, -0.007781},{
      1.552794, 0.402571, -0.007781},{1.554017, 0.401682, -0.011432}}],
    Polygon[{{1.558092, 0.407869, -0.007781},{1.557550, 0.408615, -0.003939},{
      1.552048, 0.403113, -0.003939},{1.552794, 0.402571, -0.007781}}],
    Polygon[{{1.557550, 0.408615, -0.003939},{1.557368, 0.408866, 0.000000},{
      1.551797, 0.403295, 0.000000},{1.552048, 0.403113, -0.003939}}],
    Polygon[{{1.557368, 0.408866, 0.000000},{1.557550, 0.408615, 0.003939},{
      1.552048, 0.403113, 0.003939},{1.551797, 0.403295, 0.000000}}],
    Polygon[{{1.557550, 0.408615, 0.003939},{1.558092, 0.407869, 0.007781},{
      1.552794, 0.402571, 0.007781},{1.552048, 0.403113, 0.003939}}],
    Polygon[{{1.558092, 0.407869, 0.007781},{1.558981, 0.406646, 0.011432},{
      1.554017, 0.401682, 0.011432},{1.552794, 0.402571, 0.007781}}],
    Polygon[{{1.558981, 0.406646, 0.011432},{1.560195, 0.404975, 0.014801},{
      1.555688, 0.400469, 0.014801},{1.554017, 0.401682, 0.011432}}],
    Polygon[{{1.560195, 0.404975, 0.014801},{1.561703, 0.402899, 0.017806},{
      1.557764, 0.398960, 0.017806},{1.555688, 0.400469, 0.014801}}],
    Polygon[{{1.561703, 0.402899, 0.017806},{1.563469, 0.400469, 0.020372},{
      1.560195, 0.397194, 0.020372},{1.557764, 0.398960, 0.017806}}],
    Polygon[{{1.563469, 0.400469, 0.020372},{1.565449, 0.397743, 0.022436},{
      1.562920, 0.395214, 0.022436},{1.560195, 0.397194, 0.020372}}],
    Polygon[{{1.565449, 0.397743, 0.022436},{1.567595, 0.394790, 0.023948},{
      1.565874, 0.393068, 0.023948},{1.562920, 0.395214, 0.022436}}],
    Polygon[{{1.567595, 0.394790, 0.023948},{1.569853, 0.391681, 0.024871},{
      1.568982, 0.390810, 0.024871},{1.565874, 0.393068, 0.023948}}],
    Polygon[{{1.568982, 0.390810, -0.024871},{1.565874, 0.393068, -0.023948},{
      1.564768, 0.390899, -0.023948},{1.568422, 0.389712, -0.024871}}],
    Polygon[{{1.565874, 0.393068, -0.023948},{1.562920, 0.395214, -0.022436},{
      1.561296, 0.392027, -0.022436},{1.564768, 0.390899, -0.023948}}],
    Polygon[{{1.562920, 0.395214, -0.022436},{1.560195, 0.397194, -0.020372},{
      1.558092, 0.393068, -0.020372},{1.561296, 0.392027, -0.022436}}],
    Polygon[{{1.560195, 0.397194, -0.020372},{1.557764, 0.398960, -0.017806},{
      1.555235, 0.393997, -0.017806},{1.558092, 0.393068, -0.020372}}],
    Polygon[{{1.557764, 0.398960, -0.017806},{1.555688, 0.400469, -0.014801},{
      1.552794, 0.394790, -0.014801},{1.555235, 0.393997, -0.017806}}],
    Polygon[{{1.555688, 0.400469, -0.014801},{1.554017, 0.401682, -0.011432},{
      1.550831, 0.395428, -0.011432},{1.552794, 0.394790, -0.014801}}],
    Polygon[{{1.554017, 0.401682, -0.011432},{1.552794, 0.402571, -0.007781},{
      1.549393, 0.395895, -0.007781},{1.550831, 0.395428, -0.011432}}],
    Polygon[{{1.552794, 0.402571, -0.007781},{1.552048, 0.403113, -0.003939},{
      1.548515, 0.396180, -0.003939},{1.549393, 0.395895, -0.007781}}],
    Polygon[{{1.552048, 0.403113, -0.003939},{1.551797, 0.403295, 0.000000},{
      1.548220, 0.396276, 0.000000},{1.548515, 0.396180, -0.003939}}],
    Polygon[{{1.551797, 0.403295, 0.000000},{1.552048, 0.403113, 0.003939},{
      1.548515, 0.396180, 0.003939},{1.548220, 0.396276, 0.000000}}],
    Polygon[{{1.552048, 0.403113, 0.003939},{1.552794, 0.402571, 0.007781},{
      1.549393, 0.395895, 0.007781},{1.548515, 0.396180, 0.003939}}],
    Polygon[{{1.552794, 0.402571, 0.007781},{1.554017, 0.401682, 0.011432},{
      1.550831, 0.395428, 0.011432},{1.549393, 0.395895, 0.007781}}],
    Polygon[{{1.554017, 0.401682, 0.011432},{1.555688, 0.400469, 0.014801},{
      1.552794, 0.394790, 0.014801},{1.550831, 0.395428, 0.011432}}],
    Polygon[{{1.555688, 0.400469, 0.014801},{1.557764, 0.398960, 0.017806},{
      1.555235, 0.393997, 0.017806},{1.552794, 0.394790, 0.014801}}],
    Polygon[{{1.557764, 0.398960, 0.017806},{1.560195, 0.397194, 0.020372},{
      1.558092, 0.393068, 0.020372},{1.555235, 0.393997, 0.017806}}],
    Polygon[{{1.560195, 0.397194, 0.020372},{1.562920, 0.395214, 0.022436},{
      1.561296, 0.392027, 0.022436},{1.558092, 0.393068, 0.020372}}],
    Polygon[{{1.562920, 0.395214, 0.022436},{1.565874, 0.393068, 0.023948},{
      1.564768, 0.390899, 0.023948},{1.561296, 0.392027, 0.022436}}],
    Polygon[{{1.565874, 0.393068, 0.023948},{1.568982, 0.390810, 0.024871},{
      1.568422, 0.389712, 0.024871},{1.564768, 0.390899, 0.023948}}],
    Polygon[{{1.568422, 0.389712, -0.024871},{1.564768, 0.390899, -0.023948},{
      1.564387, 0.388494, -0.023948},{1.568230, 0.388494, -0.024871}}],
    Polygon[{{1.564768, 0.390899, -0.023948},{1.561296, 0.392027, -0.022436},{
      1.560737, 0.388494, -0.022436},{1.564387, 0.388494, -0.023948}}],
    Polygon[{{1.561296, 0.392027, -0.022436},{1.558092, 0.393068, -0.020372},{
      1.557368, 0.388494, -0.020372},{1.560737, 0.388494, -0.022436}}],
    Polygon[{{1.558092, 0.393068, -0.020372},{1.555235, 0.393997, -0.017806},{
      1.554363, 0.388494, -0.017806},{1.557368, 0.388494, -0.020372}}],
    Polygon[{{1.555235, 0.393997, -0.017806},{1.552794, 0.394790, -0.014801},{
      1.551797, 0.388494, -0.014801},{1.554363, 0.388494, -0.017806}}],
    Polygon[{{1.552794, 0.394790, -0.014801},{1.550831, 0.395428, -0.011432},{
      1.549733, 0.388494, -0.011432},{1.551797, 0.388494, -0.014801}}],
    Polygon[{{1.550831, 0.395428, -0.011432},{1.549393, 0.395895, -0.007781},{
      1.548220, 0.388494, -0.007781},{1.549733, 0.388494, -0.011432}}],
    Polygon[{{1.549393, 0.395895, -0.007781},{1.548515, 0.396180, -0.003939},{
      1.547298, 0.388494, -0.003939},{1.548220, 0.388494, -0.007781}}],
    Polygon[{{1.548515, 0.396180, -0.003939},{1.548220, 0.396276, 0.000000},{
      1.546988, 0.388494, 0.000000},{1.547298, 0.388494, -0.003939}}],
    Polygon[{{1.548220, 0.396276, 0.000000},{1.548515, 0.396180, 0.003939},{
      1.547298, 0.388494, 0.003939},{1.546988, 0.388494, 0.000000}}],
    Polygon[{{1.548515, 0.396180, 0.003939},{1.549393, 0.395895, 0.007781},{
      1.548220, 0.388494, 0.007781},{1.547298, 0.388494, 0.003939}}],
    Polygon[{{1.549393, 0.395895, 0.007781},{1.550831, 0.395428, 0.011432},{
      1.549733, 0.388494, 0.011432},{1.548220, 0.388494, 0.007781}}],
    Polygon[{{1.550831, 0.395428, 0.011432},{1.552794, 0.394790, 0.014801},{
      1.551797, 0.388494, 0.014801},{1.549733, 0.388494, 0.011432}}],
    Polygon[{{1.552794, 0.394790, 0.014801},{1.555235, 0.393997, 0.017806},{
      1.554363, 0.388494, 0.017806},{1.551797, 0.388494, 0.014801}}],
    Polygon[{{1.555235, 0.393997, 0.017806},{1.558092, 0.393068, 0.020372},{
      1.557368, 0.388494, 0.020372},{1.554363, 0.388494, 0.017806}}],
    Polygon[{{1.558092, 0.393068, 0.020372},{1.561296, 0.392027, 0.022436},{
      1.560737, 0.388494, 0.022436},{1.557368, 0.388494, 0.020372}}],
    Polygon[{{1.561296, 0.392027, 0.022436},{1.564768, 0.390899, 0.023948},{
      1.564387, 0.388494, 0.023948},{1.560737, 0.388494, 0.022436}}],
    Polygon[{{1.564768, 0.390899, 0.023948},{1.568422, 0.389712, 0.024871},{
      1.568230, 0.388494, 0.024871},{1.564387, 0.388494, 0.023948}}],
    Polygon[{{1.568230, 0.388494, -0.024871},{1.564387, 0.388494, -0.023948},{
      1.564768, 0.386090, -0.023948},{1.568422, 0.387277, -0.024871}}],
    Polygon[{{1.564387, 0.388494, -0.023948},{1.560737, 0.388494, -0.022436},{
      1.561296, 0.384962, -0.022436},{1.564768, 0.386090, -0.023948}}],
    Polygon[{{1.560737, 0.388494, -0.022436},{1.557368, 0.388494, -0.020372},{
      1.558092, 0.383921, -0.020372},{1.561296, 0.384962, -0.022436}}],
    Polygon[{{1.557368, 0.388494, -0.020372},{1.554363, 0.388494, -0.017806},{
      1.555235, 0.382992, -0.017806},{1.558092, 0.383921, -0.020372}}],
    Polygon[{{1.554363, 0.388494, -0.017806},{1.551797, 0.388494, -0.014801},{
      1.552794, 0.382199, -0.014801},{1.555235, 0.382992, -0.017806}}],
    Polygon[{{1.551797, 0.388494, -0.014801},{1.549733, 0.388494, -0.011432},{
      1.550831, 0.381561, -0.011432},{1.552794, 0.382199, -0.014801}}],
    Polygon[{{1.549733, 0.388494, -0.011432},{1.548220, 0.388494, -0.007781},{
      1.549393, 0.381094, -0.007781},{1.550831, 0.381561, -0.011432}}],
    Polygon[{{1.548220, 0.388494, -0.007781},{1.547298, 0.388494, -0.003939},{
      1.548515, 0.380809, -0.003939},{1.549393, 0.381094, -0.007781}}],
    Polygon[{{1.547298, 0.388494, -0.003939},{1.546988, 0.388494, 0.000000},{
      1.548220, 0.380713, 0.000000},{1.548515, 0.380809, -0.003939}}],
    Polygon[{{1.546988, 0.388494, 0.000000},{1.547298, 0.388494, 0.003939},{
      1.548515, 0.380809, 0.003939},{1.548220, 0.380713, 0.000000}}],
    Polygon[{{1.547298, 0.388494, 0.003939},{1.548220, 0.388494, 0.007781},{
      1.549393, 0.381094, 0.007781},{1.548515, 0.380809, 0.003939}}],
    Polygon[{{1.548220, 0.388494, 0.007781},{1.549733, 0.388494, 0.011432},{
      1.550831, 0.381561, 0.011432},{1.549393, 0.381094, 0.007781}}],
    Polygon[{{1.549733, 0.388494, 0.011432},{1.551797, 0.388494, 0.014801},{
      1.552794, 0.382199, 0.014801},{1.550831, 0.381561, 0.011432}}],
    Polygon[{{1.551797, 0.388494, 0.014801},{1.554363, 0.388494, 0.017806},{
      1.555235, 0.382992, 0.017806},{1.552794, 0.382199, 0.014801}}],
    Polygon[{{1.554363, 0.388494, 0.017806},{1.557368, 0.388494, 0.020372},{
      1.558092, 0.383921, 0.020372},{1.555235, 0.382992, 0.017806}}],
    Polygon[{{1.557368, 0.388494, 0.020372},{1.560737, 0.388494, 0.022436},{
      1.561296, 0.384962, 0.022436},{1.558092, 0.383921, 0.020372}}],
    Polygon[{{1.560737, 0.388494, 0.022436},{1.564387, 0.388494, 0.023948},{
      1.564768, 0.386090, 0.023948},{1.561296, 0.384962, 0.022436}}],
    Polygon[{{1.564387, 0.388494, 0.023948},{1.568230, 0.388494, 0.024871},{
      1.568422, 0.387277, 0.024871},{1.564768, 0.386090, 0.023948}}],
    Polygon[{{1.568422, 0.387277, -0.024871},{1.564768, 0.386090, -0.023948},{
      1.565874, 0.383921, -0.023948},{1.568982, 0.386179, -0.024871}}],
    Polygon[{{1.564768, 0.386090, -0.023948},{1.561296, 0.384962, -0.022436},{
      1.562920, 0.381775, -0.022436},{1.565874, 0.383921, -0.023948}}],
    Polygon[{{1.561296, 0.384962, -0.022436},{1.558092, 0.383921, -0.020372},{
      1.560195, 0.379795, -0.020372},{1.562920, 0.381775, -0.022436}}],
    Polygon[{{1.558092, 0.383921, -0.020372},{1.555235, 0.382992, -0.017806},{
      1.557764, 0.378029, -0.017806},{1.560195, 0.379795, -0.020372}}],
    Polygon[{{1.555235, 0.382992, -0.017806},{1.552794, 0.382199, -0.014801},{
      1.555688, 0.376520, -0.014801},{1.557764, 0.378029, -0.017806}}],
    Polygon[{{1.552794, 0.382199, -0.014801},{1.550831, 0.381561, -0.011432},{
      1.554017, 0.375307, -0.011432},{1.555688, 0.376520, -0.014801}}],
    Polygon[{{1.550831, 0.381561, -0.011432},{1.549393, 0.381094, -0.007781},{
      1.552794, 0.374418, -0.007781},{1.554017, 0.375307, -0.011432}}],
    Polygon[{{1.549393, 0.381094, -0.007781},{1.548515, 0.380809, -0.003939},{
      1.552048, 0.373876, -0.003939},{1.552794, 0.374418, -0.007781}}],
    Polygon[{{1.548515, 0.380809, -0.003939},{1.548220, 0.380713, 0.000000},{
      1.551797, 0.373693, 0.000000},{1.552048, 0.373876, -0.003939}}],
    Polygon[{{1.548220, 0.380713, 0.000000},{1.548515, 0.380809, 0.003939},{
      1.552048, 0.373876, 0.003939},{1.551797, 0.373693, 0.000000}}],
    Polygon[{{1.548515, 0.380809, 0.003939},{1.549393, 0.381094, 0.007781},{
      1.552794, 0.374418, 0.007781},{1.552048, 0.373876, 0.003939}}],
    Polygon[{{1.549393, 0.381094, 0.007781},{1.550831, 0.381561, 0.011432},{
      1.554017, 0.375307, 0.011432},{1.552794, 0.374418, 0.007781}}],
    Polygon[{{1.550831, 0.381561, 0.011432},{1.552794, 0.382199, 0.014801},{
      1.555688, 0.376520, 0.014801},{1.554017, 0.375307, 0.011432}}],
    Polygon[{{1.552794, 0.382199, 0.014801},{1.555235, 0.382992, 0.017806},{
      1.557764, 0.378029, 0.017806},{1.555688, 0.376520, 0.014801}}],
    Polygon[{{1.555235, 0.382992, 0.017806},{1.558092, 0.383921, 0.020372},{
      1.560195, 0.379795, 0.020372},{1.557764, 0.378029, 0.017806}}],
    Polygon[{{1.558092, 0.383921, 0.020372},{1.561296, 0.384962, 0.022436},{
      1.562920, 0.381775, 0.022436},{1.560195, 0.379795, 0.020372}}],
    Polygon[{{1.561296, 0.384962, 0.022436},{1.564768, 0.386090, 0.023948},{
      1.565874, 0.383921, 0.023948},{1.562920, 0.381775, 0.022436}}],
    Polygon[{{1.564768, 0.386090, 0.023948},{1.568422, 0.387277, 0.024871},{
      1.568982, 0.386179, 0.024871},{1.565874, 0.383921, 0.023948}}],
    Polygon[{{1.568982, 0.386179, -0.024871},{1.565874, 0.383921, -0.023948},{
      1.567595, 0.382199, -0.023948},{1.569853, 0.385308, -0.024871}}],
    Polygon[{{1.565874, 0.383921, -0.023948},{1.562920, 0.381775, -0.022436},{
      1.565449, 0.379246, -0.022436},{1.567595, 0.382199, -0.023948}}],
    Polygon[{{1.562920, 0.381775, -0.022436},{1.560195, 0.379795, -0.020372},{
      1.563469, 0.376520, -0.020372},{1.565449, 0.379246, -0.022436}}],
    Polygon[{{1.560195, 0.379795, -0.020372},{1.557764, 0.378029, -0.017806},{
      1.561703, 0.374089, -0.017806},{1.563469, 0.376520, -0.020372}}],
    Polygon[{{1.557764, 0.378029, -0.017806},{1.555688, 0.376520, -0.014801},{
      1.560195, 0.372013, -0.014801},{1.561703, 0.374089, -0.017806}}],
    Polygon[{{1.555688, 0.376520, -0.014801},{1.554017, 0.375307, -0.011432},{
      1.558981, 0.370343, -0.011432},{1.560195, 0.372013, -0.014801}}],
    Polygon[{{1.554017, 0.375307, -0.011432},{1.552794, 0.374418, -0.007781},{
      1.558092, 0.369120, -0.007781},{1.558981, 0.370343, -0.011432}}],
    Polygon[{{1.552794, 0.374418, -0.007781},{1.552048, 0.373876, -0.003939},{
      1.557550, 0.368373, -0.003939},{1.558092, 0.369120, -0.007781}}],
    Polygon[{{1.552048, 0.373876, -0.003939},{1.551797, 0.373693, 0.000000},{
      1.557368, 0.368123, 0.000000},{1.557550, 0.368373, -0.003939}}],
    Polygon[{{1.551797, 0.373693, 0.000000},{1.552048, 0.373876, 0.003939},{
      1.557550, 0.368373, 0.003939},{1.557368, 0.368123, 0.000000}}],
    Polygon[{{1.552048, 0.373876, 0.003939},{1.552794, 0.374418, 0.007781},{
      1.558092, 0.369120, 0.007781},{1.557550, 0.368373, 0.003939}}],
    Polygon[{{1.552794, 0.374418, 0.007781},{1.554017, 0.375307, 0.011432},{
      1.558981, 0.370343, 0.011432},{1.558092, 0.369120, 0.007781}}],
    Polygon[{{1.554017, 0.375307, 0.011432},{1.555688, 0.376520, 0.014801},{
      1.560195, 0.372013, 0.014801},{1.558981, 0.370343, 0.011432}}],
    Polygon[{{1.555688, 0.376520, 0.014801},{1.557764, 0.378029, 0.017806},{
      1.561703, 0.374089, 0.017806},{1.560195, 0.372013, 0.014801}}],
    Polygon[{{1.557764, 0.378029, 0.017806},{1.560195, 0.379795, 0.020372},{
      1.563469, 0.376520, 0.020372},{1.561703, 0.374089, 0.017806}}],
    Polygon[{{1.560195, 0.379795, 0.020372},{1.562920, 0.381775, 0.022436},{
      1.565449, 0.379246, 0.022436},{1.563469, 0.376520, 0.020372}}],
    Polygon[{{1.562920, 0.381775, 0.022436},{1.565874, 0.383921, 0.023948},{
      1.567595, 0.382199, 0.023948},{1.565449, 0.379246, 0.022436}}],
    Polygon[{{1.565874, 0.383921, 0.023948},{1.568982, 0.386179, 0.024871},{
      1.569853, 0.385308, 0.024871},{1.567595, 0.382199, 0.023948}}],
    Polygon[{{1.569853, 0.385308, -0.024871},{1.567595, 0.382199, -0.023948},{
      1.569764, 0.381094, -0.023948},{1.570951, 0.384748, -0.024871}}],
    Polygon[{{1.567595, 0.382199, -0.023948},{1.565449, 0.379246, -0.022436},{
      1.568636, 0.377622, -0.022436},{1.569764, 0.381094, -0.023948}}],
    Polygon[{{1.565449, 0.379246, -0.022436},{1.563469, 0.376520, -0.020372},{
      1.567595, 0.374418, -0.020372},{1.568636, 0.377622, -0.022436}}],
    Polygon[{{1.563469, 0.376520, -0.020372},{1.561703, 0.374089, -0.017806},{
      1.566667, 0.371560, -0.017806},{1.567595, 0.374418, -0.020372}}],
    Polygon[{{1.561703, 0.374089, -0.017806},{1.560195, 0.372013, -0.014801},{
      1.565874, 0.369120, -0.014801},{1.566667, 0.371560, -0.017806}}],
    Polygon[{{1.560195, 0.372013, -0.014801},{1.558981, 0.370343, -0.011432},{
      1.565236, 0.367156, -0.011432},{1.565874, 0.369120, -0.014801}}],
    Polygon[{{1.558981, 0.370343, -0.011432},{1.558092, 0.369120, -0.007781},{
      1.564768, 0.365718, -0.007781},{1.565236, 0.367156, -0.011432}}],
    Polygon[{{1.558092, 0.369120, -0.007781},{1.557550, 0.368373, -0.003939},{
      1.564483, 0.364841, -0.003939},{1.564768, 0.365718, -0.007781}}],
    Polygon[{{1.557550, 0.368373, -0.003939},{1.557368, 0.368123, 0.000000},{
      1.564387, 0.364546, 0.000000},{1.564483, 0.364841, -0.003939}}],
    Polygon[{{1.557368, 0.368123, 0.000000},{1.557550, 0.368373, 0.003939},{
      1.564483, 0.364841, 0.003939},{1.564387, 0.364546, 0.000000}}],
    Polygon[{{1.557550, 0.368373, 0.003939},{1.558092, 0.369120, 0.007781},{
      1.564768, 0.365718, 0.007781},{1.564483, 0.364841, 0.003939}}],
    Polygon[{{1.558092, 0.369120, 0.007781},{1.558981, 0.370343, 0.011432},{
      1.565236, 0.367156, 0.011432},{1.564768, 0.365718, 0.007781}}],
    Polygon[{{1.558981, 0.370343, 0.011432},{1.560195, 0.372013, 0.014801},{
      1.565874, 0.369120, 0.014801},{1.565236, 0.367156, 0.011432}}],
    Polygon[{{1.560195, 0.372013, 0.014801},{1.561703, 0.374089, 0.017806},{
      1.566667, 0.371560, 0.017806},{1.565874, 0.369120, 0.014801}}],
    Polygon[{{1.561703, 0.374089, 0.017806},{1.563469, 0.376520, 0.020372},{
      1.567595, 0.374418, 0.020372},{1.566667, 0.371560, 0.017806}}],
    Polygon[{{1.563469, 0.376520, 0.020372},{1.565449, 0.379246, 0.022436},{
      1.568636, 0.377622, 0.022436},{1.567595, 0.374418, 0.020372}}],
    Polygon[{{1.565449, 0.379246, 0.022436},{1.567595, 0.382199, 0.023948},{
      1.569764, 0.381094, 0.023948},{1.568636, 0.377622, 0.022436}}],
    Polygon[{{1.567595, 0.382199, 0.023948},{1.569853, 0.385308, 0.024871},{
      1.570951, 0.384748, 0.024871},{1.569764, 0.381094, 0.023948}}],
    Polygon[{{1.570951, 0.384748, -0.024871},{1.569764, 0.381094, -0.023948},{
      1.572169, 0.380713, -0.023948},{1.572169, 0.384555, -0.024871}}],
    Polygon[{{1.569764, 0.381094, -0.023948},{1.568636, 0.377622, -0.022436},{
      1.572169, 0.377062, -0.022436},{1.572169, 0.380713, -0.023948}}],
    Polygon[{{1.568636, 0.377622, -0.022436},{1.567595, 0.374418, -0.020372},{
      1.572169, 0.373693, -0.020372},{1.572169, 0.377062, -0.022436}}],
    Polygon[{{1.567595, 0.374418, -0.020372},{1.566667, 0.371560, -0.017806},{
      1.572169, 0.370689, -0.017806},{1.572169, 0.373693, -0.020372}}],
    Polygon[{{1.566667, 0.371560, -0.017806},{1.565874, 0.369120, -0.014801},{
      1.572169, 0.368123, -0.014801},{1.572169, 0.370689, -0.017806}}],
    Polygon[{{1.565874, 0.369120, -0.014801},{1.565236, 0.367156, -0.011432},{
      1.572169, 0.366058, -0.011432},{1.572169, 0.368123, -0.014801}}],
    Polygon[{{1.565236, 0.367156, -0.011432},{1.564768, 0.365718, -0.007781},{
      1.572169, 0.364546, -0.007781},{1.572169, 0.366058, -0.011432}}],
    Polygon[{{1.564768, 0.365718, -0.007781},{1.564483, 0.364841, -0.003939},{
      1.572169, 0.363624, -0.003939},{1.572169, 0.364546, -0.007781}}],
    Polygon[{{1.564483, 0.364841, -0.003939},{1.564387, 0.364546, 0.000000},{
      1.572169, 0.363314, 0.000000},{1.572169, 0.363624, -0.003939}}],
    Polygon[{{1.564387, 0.364546, 0.000000},{1.564483, 0.364841, 0.003939},{
      1.572169, 0.363624, 0.003939},{1.572169, 0.363314, 0.000000}}],
    Polygon[{{1.564483, 0.364841, 0.003939},{1.564768, 0.365718, 0.007781},{
      1.572169, 0.364546, 0.007781},{1.572169, 0.363624, 0.003939}}],
    Polygon[{{1.564768, 0.365718, 0.007781},{1.565236, 0.367156, 0.011432},{
      1.572169, 0.366058, 0.011432},{1.572169, 0.364546, 0.007781}}],
    Polygon[{{1.565236, 0.367156, 0.011432},{1.565874, 0.369120, 0.014801},{
      1.572169, 0.368123, 0.014801},{1.572169, 0.366058, 0.011432}}],
    Polygon[{{1.565874, 0.369120, 0.014801},{1.566667, 0.371560, 0.017806},{
      1.572169, 0.370689, 0.017806},{1.572169, 0.368123, 0.014801}}],
    Polygon[{{1.566667, 0.371560, 0.017806},{1.567595, 0.374418, 0.020372},{
      1.572169, 0.373693, 0.020372},{1.572169, 0.370689, 0.017806}}],
    Polygon[{{1.567595, 0.374418, 0.020372},{1.568636, 0.377622, 0.022436},{
      1.572169, 0.377062, 0.022436},{1.572169, 0.373693, 0.020372}}],
    Polygon[{{1.568636, 0.377622, 0.022436},{1.569764, 0.381094, 0.023948},{
      1.572169, 0.380713, 0.023948},{1.572169, 0.377062, 0.022436}}],
    Polygon[{{1.569764, 0.381094, 0.023948},{1.570951, 0.384748, 0.024871},{
      1.572169, 0.384555, 0.024871},{1.572169, 0.380713, 0.023948}}],
    Polygon[{{1.572169, 0.384555, -0.024871},{1.572169, 0.380713, -0.023948},{
      1.574573, 0.381094, -0.023948},{1.573386, 0.384748, -0.024871}}],
    Polygon[{{1.572169, 0.380713, -0.023948},{1.572169, 0.377062, -0.022436},{
      1.575701, 0.377622, -0.022436},{1.574573, 0.381094, -0.023948}}],
    Polygon[{{1.572169, 0.377062, -0.022436},{1.572169, 0.373693, -0.020372},{
      1.576743, 0.374418, -0.020372},{1.575701, 0.377622, -0.022436}}],
    Polygon[{{1.572169, 0.373693, -0.020372},{1.572169, 0.370689, -0.017806},{
      1.577671, 0.371560, -0.017806},{1.576743, 0.374418, -0.020372}}],
    Polygon[{{1.572169, 0.370689, -0.017806},{1.572169, 0.368123, -0.014801},{
      1.578464, 0.369120, -0.014801},{1.577671, 0.371560, -0.017806}}],
    Polygon[{{1.572169, 0.368123, -0.014801},{1.572169, 0.366058, -0.011432},{
      1.579102, 0.367156, -0.011432},{1.578464, 0.369120, -0.014801}}],
    Polygon[{{1.572169, 0.366058, -0.011432},{1.572169, 0.364546, -0.007781},{
      1.579569, 0.365718, -0.007781},{1.579102, 0.367156, -0.011432}}],
    Polygon[{{1.572169, 0.364546, -0.007781},{1.572169, 0.363624, -0.003939},{
      1.579854, 0.364841, -0.003939},{1.579569, 0.365718, -0.007781}}],
    Polygon[{{1.572169, 0.363624, -0.003939},{1.572169, 0.363314, 0.000000},{
      1.579950, 0.364546, 0.000000},{1.579854, 0.364841, -0.003939}}],
    Polygon[{{1.572169, 0.363314, 0.000000},{1.572169, 0.363624, 0.003939},{
      1.579854, 0.364841, 0.003939},{1.579950, 0.364546, 0.000000}}],
    Polygon[{{1.572169, 0.363624, 0.003939},{1.572169, 0.364546, 0.007781},{
      1.579569, 0.365718, 0.007781},{1.579854, 0.364841, 0.003939}}],
    Polygon[{{1.572169, 0.364546, 0.007781},{1.572169, 0.366058, 0.011432},{
      1.579102, 0.367156, 0.011432},{1.579569, 0.365718, 0.007781}}],
    Polygon[{{1.572169, 0.366058, 0.011432},{1.572169, 0.368123, 0.014801},{
      1.578464, 0.369120, 0.014801},{1.579102, 0.367156, 0.011432}}],
    Polygon[{{1.572169, 0.368123, 0.014801},{1.572169, 0.370689, 0.017806},{
      1.577671, 0.371560, 0.017806},{1.578464, 0.369120, 0.014801}}],
    Polygon[{{1.572169, 0.370689, 0.017806},{1.572169, 0.373693, 0.020372},{
      1.576743, 0.374418, 0.020372},{1.577671, 0.371560, 0.017806}}],
    Polygon[{{1.572169, 0.373693, 0.020372},{1.572169, 0.377062, 0.022436},{
      1.575701, 0.377622, 0.022436},{1.576743, 0.374418, 0.020372}}],
    Polygon[{{1.572169, 0.377062, 0.022436},{1.572169, 0.380713, 0.023948},{
      1.574573, 0.381094, 0.023948},{1.575701, 0.377622, 0.022436}}],
    Polygon[{{1.572169, 0.380713, 0.023948},{1.572169, 0.384555, 0.024871},{
      1.573386, 0.384748, 0.024871},{1.574573, 0.381094, 0.023948}}],
    Polygon[{{1.573386, 0.384748, -0.024871},{1.574573, 0.381094, -0.023948},{
      1.576743, 0.382199, -0.023948},{1.574484, 0.385308, -0.024871}}],
    Polygon[{{1.574573, 0.381094, -0.023948},{1.575701, 0.377622, -0.022436},{
      1.578888, 0.379246, -0.022436},{1.576743, 0.382199, -0.023948}}],
    Polygon[{{1.575701, 0.377622, -0.022436},{1.576743, 0.374418, -0.020372},{
      1.580868, 0.376520, -0.020372},{1.578888, 0.379246, -0.022436}}],
    Polygon[{{1.576743, 0.374418, -0.020372},{1.577671, 0.371560, -0.017806},{
      1.582635, 0.374089, -0.017806},{1.580868, 0.376520, -0.020372}}],
    Polygon[{{1.577671, 0.371560, -0.017806},{1.578464, 0.369120, -0.014801},{
      1.584143, 0.372013, -0.014801},{1.582635, 0.374089, -0.017806}}],
    Polygon[{{1.578464, 0.369120, -0.014801},{1.579102, 0.367156, -0.011432},{
      1.585356, 0.370343, -0.011432},{1.584143, 0.372013, -0.014801}}],
    Polygon[{{1.579102, 0.367156, -0.011432},{1.579569, 0.365718, -0.007781},{
      1.586245, 0.369120, -0.007781},{1.585356, 0.370343, -0.011432}}],
    Polygon[{{1.579569, 0.365718, -0.007781},{1.579854, 0.364841, -0.003939},{
      1.586787, 0.368373, -0.003939},{1.586245, 0.369120, -0.007781}}],
    Polygon[{{1.579854, 0.364841, -0.003939},{1.579950, 0.364546, 0.000000},{
      1.586970, 0.368123, 0.000000},{1.586787, 0.368373, -0.003939}}],
    Polygon[{{1.579950, 0.364546, 0.000000},{1.579854, 0.364841, 0.003939},{
      1.586787, 0.368373, 0.003939},{1.586970, 0.368123, 0.000000}}],
    Polygon[{{1.579854, 0.364841, 0.003939},{1.579569, 0.365718, 0.007781},{
      1.586245, 0.369120, 0.007781},{1.586787, 0.368373, 0.003939}}],
    Polygon[{{1.579569, 0.365718, 0.007781},{1.579102, 0.367156, 0.011432},{
      1.585356, 0.370343, 0.011432},{1.586245, 0.369120, 0.007781}}],
    Polygon[{{1.579102, 0.367156, 0.011432},{1.578464, 0.369120, 0.014801},{
      1.584143, 0.372013, 0.014801},{1.585356, 0.370343, 0.011432}}],
    Polygon[{{1.578464, 0.369120, 0.014801},{1.577671, 0.371560, 0.017806},{
      1.582635, 0.374089, 0.017806},{1.584143, 0.372013, 0.014801}}],
    Polygon[{{1.577671, 0.371560, 0.017806},{1.576743, 0.374418, 0.020372},{
      1.580868, 0.376520, 0.020372},{1.582635, 0.374089, 0.017806}}],
    Polygon[{{1.576743, 0.374418, 0.020372},{1.575701, 0.377622, 0.022436},{
      1.578888, 0.379246, 0.022436},{1.580868, 0.376520, 0.020372}}],
    Polygon[{{1.575701, 0.377622, 0.022436},{1.574573, 0.381094, 0.023948},{
      1.576743, 0.382199, 0.023948},{1.578888, 0.379246, 0.022436}}],
    Polygon[{{1.574573, 0.381094, 0.023948},{1.573386, 0.384748, 0.024871},{
      1.574484, 0.385308, 0.024871},{1.576743, 0.382199, 0.023948}}],
    Polygon[{{1.574484, 0.385308, -0.024871},{1.576743, 0.382199, -0.023948},{
      1.578464, 0.383921, -0.023948},{1.575356, 0.386179, -0.024871}}],
    Polygon[{{1.576743, 0.382199, -0.023948},{1.578888, 0.379246, -0.022436},{
      1.581417, 0.381775, -0.022436},{1.578464, 0.383921, -0.023948}}],
    Polygon[{{1.578888, 0.379246, -0.022436},{1.580868, 0.376520, -0.020372},{
      1.584143, 0.379795, -0.020372},{1.581417, 0.381775, -0.022436}}],
    Polygon[{{1.580868, 0.376520, -0.020372},{1.582635, 0.374089, -0.017806},{
      1.586574, 0.378029, -0.017806},{1.584143, 0.379795, -0.020372}}],
    Polygon[{{1.582635, 0.374089, -0.017806},{1.584143, 0.372013, -0.014801},{
      1.588650, 0.376520, -0.014801},{1.586574, 0.378029, -0.017806}}],
    Polygon[{{1.584143, 0.372013, -0.014801},{1.585356, 0.370343, -0.011432},{
      1.590320, 0.375307, -0.011432},{1.588650, 0.376520, -0.014801}}],
    Polygon[{{1.585356, 0.370343, -0.011432},{1.586245, 0.369120, -0.007781},{
      1.591543, 0.374418, -0.007781},{1.590320, 0.375307, -0.011432}}],
    Polygon[{{1.586245, 0.369120, -0.007781},{1.586787, 0.368373, -0.003939},{
      1.592290, 0.373876, -0.003939},{1.591543, 0.374418, -0.007781}}],
    Polygon[{{1.586787, 0.368373, -0.003939},{1.586970, 0.368123, 0.000000},{
      1.592541, 0.373693, 0.000000},{1.592290, 0.373876, -0.003939}}],
    Polygon[{{1.586970, 0.368123, 0.000000},{1.586787, 0.368373, 0.003939},{
      1.592290, 0.373876, 0.003939},{1.592541, 0.373693, 0.000000}}],
    Polygon[{{1.586787, 0.368373, 0.003939},{1.586245, 0.369120, 0.007781},{
      1.591543, 0.374418, 0.007781},{1.592290, 0.373876, 0.003939}}],
    Polygon[{{1.586245, 0.369120, 0.007781},{1.585356, 0.370343, 0.011432},{
      1.590320, 0.375307, 0.011432},{1.591543, 0.374418, 0.007781}}],
    Polygon[{{1.585356, 0.370343, 0.011432},{1.584143, 0.372013, 0.014801},{
      1.588650, 0.376520, 0.014801},{1.590320, 0.375307, 0.011432}}],
    Polygon[{{1.584143, 0.372013, 0.014801},{1.582635, 0.374089, 0.017806},{
      1.586574, 0.378029, 0.017806},{1.588650, 0.376520, 0.014801}}],
    Polygon[{{1.582635, 0.374089, 0.017806},{1.580868, 0.376520, 0.020372},{
      1.584143, 0.379795, 0.020372},{1.586574, 0.378029, 0.017806}}],
    Polygon[{{1.580868, 0.376520, 0.020372},{1.578888, 0.379246, 0.022436},{
      1.581417, 0.381775, 0.022436},{1.584143, 0.379795, 0.020372}}],
    Polygon[{{1.578888, 0.379246, 0.022436},{1.576743, 0.382199, 0.023948},{
      1.578464, 0.383921, 0.023948},{1.581417, 0.381775, 0.022436}}],
    Polygon[{{1.576743, 0.382199, 0.023948},{1.574484, 0.385308, 0.024871},{
      1.575356, 0.386179, 0.024871},{1.578464, 0.383921, 0.023948}}],
    Polygon[{{1.575356, 0.386179, -0.024871},{1.578464, 0.383921, -0.023948},{
      1.579569, 0.386090, -0.023948},{1.575915, 0.387277, -0.024871}}],
    Polygon[{{1.578464, 0.383921, -0.023948},{1.581417, 0.381775, -0.022436},{
      1.583041, 0.384962, -0.022436},{1.579569, 0.386090, -0.023948}}],
    Polygon[{{1.581417, 0.381775, -0.022436},{1.584143, 0.379795, -0.020372},{
      1.586245, 0.383921, -0.020372},{1.583041, 0.384962, -0.022436}}],
    Polygon[{{1.584143, 0.379795, -0.020372},{1.586574, 0.378029, -0.017806},{
      1.589103, 0.382992, -0.017806},{1.586245, 0.383921, -0.020372}}],
    Polygon[{{1.586574, 0.378029, -0.017806},{1.588650, 0.376520, -0.014801},{
      1.591543, 0.382199, -0.014801},{1.589103, 0.382992, -0.017806}}],
    Polygon[{{1.588650, 0.376520, -0.014801},{1.590320, 0.375307, -0.011432},{
      1.593507, 0.381561, -0.011432},{1.591543, 0.382199, -0.014801}}],
    Polygon[{{1.590320, 0.375307, -0.011432},{1.591543, 0.374418, -0.007781},{
      1.594945, 0.381094, -0.007781},{1.593507, 0.381561, -0.011432}}],
    Polygon[{{1.591543, 0.374418, -0.007781},{1.592290, 0.373876, -0.003939},{
      1.595822, 0.380809, -0.003939},{1.594945, 0.381094, -0.007781}}],
    Polygon[{{1.592290, 0.373876, -0.003939},{1.592541, 0.373693, 0.000000},{
      1.596117, 0.380713, 0.000000},{1.595822, 0.380809, -0.003939}}],
    Polygon[{{1.592541, 0.373693, 0.000000},{1.592290, 0.373876, 0.003939},{
      1.595822, 0.380809, 0.003939},{1.596117, 0.380713, 0.000000}}],
    Polygon[{{1.592290, 0.373876, 0.003939},{1.591543, 0.374418, 0.007781},{
      1.594945, 0.381094, 0.007781},{1.595822, 0.380809, 0.003939}}],
    Polygon[{{1.591543, 0.374418, 0.007781},{1.590320, 0.375307, 0.011432},{
      1.593507, 0.381561, 0.011432},{1.594945, 0.381094, 0.007781}}],
    Polygon[{{1.590320, 0.375307, 0.011432},{1.588650, 0.376520, 0.014801},{
      1.591543, 0.382199, 0.014801},{1.593507, 0.381561, 0.011432}}],
    Polygon[{{1.588650, 0.376520, 0.014801},{1.586574, 0.378029, 0.017806},{
      1.589103, 0.382992, 0.017806},{1.591543, 0.382199, 0.014801}}],
    Polygon[{{1.586574, 0.378029, 0.017806},{1.584143, 0.379795, 0.020372},{
      1.586245, 0.383921, 0.020372},{1.589103, 0.382992, 0.017806}}],
    Polygon[{{1.584143, 0.379795, 0.020372},{1.581417, 0.381775, 0.022436},{
      1.583041, 0.384962, 0.022436},{1.586245, 0.383921, 0.020372}}],
    Polygon[{{1.581417, 0.381775, 0.022436},{1.578464, 0.383921, 0.023948},{
      1.579569, 0.386090, 0.023948},{1.583041, 0.384962, 0.022436}}],
    Polygon[{{1.578464, 0.383921, 0.023948},{1.575356, 0.386179, 0.024871},{
      1.575915, 0.387277, 0.024871},{1.579569, 0.386090, 0.023948}}],
    Polygon[{{1.575915, 0.387277, -0.024871},{1.579569, 0.386090, -0.023948},{
      1.579950, 0.388494, -0.023948},{1.576108, 0.388494, -0.024871}}],
    Polygon[{{1.579569, 0.386090, -0.023948},{1.583041, 0.384962, -0.022436},{
      1.583601, 0.388494, -0.022436},{1.579950, 0.388494, -0.023948}}],
    Polygon[{{1.583041, 0.384962, -0.022436},{1.586245, 0.383921, -0.020372},{
      1.586970, 0.388494, -0.020372},{1.583601, 0.388494, -0.022436}}],
    Polygon[{{1.586245, 0.383921, -0.020372},{1.589103, 0.382992, -0.017806},{
      1.589974, 0.388494, -0.017806},{1.586970, 0.388494, -0.020372}}],
    Polygon[{{1.589103, 0.382992, -0.017806},{1.591543, 0.382199, -0.014801},{
      1.592541, 0.388494, -0.014801},{1.589974, 0.388494, -0.017806}}],
    Polygon[{{1.591543, 0.382199, -0.014801},{1.593507, 0.381561, -0.011432},{
      1.594605, 0.388494, -0.011432},{1.592541, 0.388494, -0.014801}}],
    Polygon[{{1.593507, 0.381561, -0.011432},{1.594945, 0.381094, -0.007781},{
      1.596117, 0.388494, -0.007781},{1.594605, 0.388494, -0.011432}}],
    Polygon[{{1.594945, 0.381094, -0.007781},{1.595822, 0.380809, -0.003939},{
      1.597040, 0.388494, -0.003939},{1.596117, 0.388494, -0.007781}}],
    Polygon[{{1.595822, 0.380809, -0.003939},{1.596117, 0.380713, 0.000000},{
      1.597350, 0.388494, 0.000000},{1.597040, 0.388494, -0.003939}}],
    Polygon[{{1.596117, 0.380713, 0.000000},{1.595822, 0.380809, 0.003939},{
      1.597040, 0.388494, 0.003939},{1.597350, 0.388494, 0.000000}}],
    Polygon[{{1.595822, 0.380809, 0.003939},{1.594945, 0.381094, 0.007781},{
      1.596117, 0.388494, 0.007781},{1.597040, 0.388494, 0.003939}}],
    Polygon[{{1.594945, 0.381094, 0.007781},{1.593507, 0.381561, 0.011432},{
      1.594605, 0.388494, 0.011432},{1.596117, 0.388494, 0.007781}}],
    Polygon[{{1.593507, 0.381561, 0.011432},{1.591543, 0.382199, 0.014801},{
      1.592541, 0.388494, 0.014801},{1.594605, 0.388494, 0.011432}}],
    Polygon[{{1.591543, 0.382199, 0.014801},{1.589103, 0.382992, 0.017806},{
      1.589974, 0.388494, 0.017806},{1.592541, 0.388494, 0.014801}}],
    Polygon[{{1.589103, 0.382992, 0.017806},{1.586245, 0.383921, 0.020372},{
      1.586970, 0.388494, 0.020372},{1.589974, 0.388494, 0.017806}}],
    Polygon[{{1.586245, 0.383921, 0.020372},{1.583041, 0.384962, 0.022436},{
      1.583601, 0.388494, 0.022436},{1.586970, 0.388494, 0.020372}}],
    Polygon[{{1.583041, 0.384962, 0.022436},{1.579569, 0.386090, 0.023948},{
      1.579950, 0.388494, 0.023948},{1.583601, 0.388494, 0.022436}}],
    Polygon[{{1.579569, 0.386090, 0.023948},{1.575915, 0.387277, 0.024871},{
      1.576108, 0.388494, 0.024871},{1.579950, 0.388494, 0.023948}}],
    Polygon[{{1.550059, 0.359563, -0.012292},{1.551958, 0.359563, -0.011836},{
      1.551770, 0.360752, -0.011836},{1.549964, 0.360165, -0.012292}}],
    Polygon[{{1.551958, 0.359563, -0.011836},{1.553762, 0.359563, -0.011089},{
      1.553486, 0.361309, -0.011089},{1.551770, 0.360752, -0.011836}}],
    Polygon[{{1.553762, 0.359563, -0.011089},{1.555427, 0.359563, -0.010068},{
      1.555069, 0.361824, -0.010068},{1.553486, 0.361309, -0.011089}}],
    Polygon[{{1.555427, 0.359563, -0.010068},{1.556912, 0.359563, -0.008800},{
      1.556482, 0.362283, -0.008800},{1.555069, 0.361824, -0.010068}}],
    Polygon[{{1.556912, 0.359563, -0.008800},{1.558181, 0.359563, -0.007315},{
      1.557688, 0.362675, -0.007315},{1.556482, 0.362283, -0.008800}}],
    Polygon[{{1.558181, 0.359563, -0.007315},{1.559201, 0.359563, -0.005650},{
      1.558658, 0.362990, -0.005650},{1.557688, 0.362675, -0.007315}}],
    Polygon[{{1.559201, 0.359563, -0.005650},{1.559948, 0.359563, -0.003846},{
      1.559369, 0.363221, -0.003846},{1.558658, 0.362990, -0.005650}}],
    Polygon[{{1.559948, 0.359563, -0.003846},{1.560404, 0.359563, -0.001947},{
      1.559803, 0.363362, -0.001947},{1.559369, 0.363221, -0.003846}}],
    Polygon[{{1.560404, 0.359563, -0.001947},{1.560557, 0.359563, 0.000000},{
      1.559948, 0.363409, 0.000000},{1.559803, 0.363362, -0.001947}}],
    Polygon[{{1.560557, 0.359563, 0.000000},{1.560404, 0.359563, 0.001947},{
      1.559803, 0.363362, 0.001947},{1.559948, 0.363409, 0.000000}}],
    Polygon[{{1.560404, 0.359563, 0.001947},{1.559948, 0.359563, 0.003846},{
      1.559369, 0.363221, 0.003846},{1.559803, 0.363362, 0.001947}}],
    Polygon[{{1.559948, 0.359563, 0.003846},{1.559201, 0.359563, 0.005650},{
      1.558658, 0.362990, 0.005650},{1.559369, 0.363221, 0.003846}}],
    Polygon[{{1.559201, 0.359563, 0.005650},{1.558181, 0.359563, 0.007315},{
      1.557688, 0.362675, 0.007315},{1.558658, 0.362990, 0.005650}}],
    Polygon[{{1.558181, 0.359563, 0.007315},{1.556912, 0.359563, 0.008800},{
      1.556482, 0.362283, 0.008800},{1.557688, 0.362675, 0.007315}}],
    Polygon[{{1.556912, 0.359563, 0.008800},{1.555427, 0.359563, 0.010068},{
      1.555069, 0.361824, 0.010068},{1.556482, 0.362283, 0.008800}}],
    Polygon[{{1.555427, 0.359563, 0.010068},{1.553762, 0.359563, 0.011089},{
      1.553486, 0.361309, 0.011089},{1.555069, 0.361824, 0.010068}}],
    Polygon[{{1.553762, 0.359563, 0.011089},{1.551958, 0.359563, 0.011836},{
      1.551770, 0.360752, 0.011836},{1.553486, 0.361309, 0.011089}}],
    Polygon[{{1.551958, 0.359563, 0.011836},{1.550059, 0.359563, 0.012292},{
      1.549964, 0.360165, 0.012292},{1.551770, 0.360752, 0.011836}}],
    Polygon[{{1.549964, 0.360165, -0.012292},{1.551770, 0.360752, -0.011836},{
      1.551224, 0.361824, -0.011836},{1.549688, 0.360708, -0.012292}}],
    Polygon[{{1.551770, 0.360752, -0.011836},{1.553486, 0.361309, -0.011089},{
      1.552683, 0.362884, -0.011089},{1.551224, 0.361824, -0.011836}}],
    Polygon[{{1.553486, 0.361309, -0.011089},{1.555069, 0.361824, -0.010068},{
      1.554030, 0.363863, -0.010068},{1.552683, 0.362884, -0.011089}}],
    Polygon[{{1.555069, 0.361824, -0.010068},{1.556482, 0.362283, -0.008800},{
      1.555232, 0.364736, -0.008800},{1.554030, 0.363863, -0.010068}}],
    Polygon[{{1.556482, 0.362283, -0.008800},{1.557688, 0.362675, -0.007315},{
      1.556258, 0.365481, -0.007315},{1.555232, 0.364736, -0.008800}}],
    Polygon[{{1.557688, 0.362675, -0.007315},{1.558658, 0.362990, -0.005650},{
      1.557083, 0.366081, -0.005650},{1.556258, 0.365481, -0.007315}}],
    Polygon[{{1.558658, 0.362990, -0.005650},{1.559369, 0.363221, -0.003846},{
      1.557688, 0.366520, -0.003846},{1.557083, 0.366081, -0.005650}}],
    Polygon[{{1.559369, 0.363221, -0.003846},{1.559803, 0.363362, -0.001947},{
      1.558057, 0.366788, -0.001947},{1.557688, 0.366520, -0.003846}}],
    Polygon[{{1.559803, 0.363362, -0.001947},{1.559948, 0.363409, 0.000000},{
      1.558181, 0.366878, 0.000000},{1.558057, 0.366788, -0.001947}}],
    Polygon[{{1.559948, 0.363409, 0.000000},{1.559803, 0.363362, 0.001947},{
      1.558057, 0.366788, 0.001947},{1.558181, 0.366878, 0.000000}}],
    Polygon[{{1.559803, 0.363362, 0.001947},{1.559369, 0.363221, 0.003846},{
      1.557688, 0.366520, 0.003846},{1.558057, 0.366788, 0.001947}}],
    Polygon[{{1.559369, 0.363221, 0.003846},{1.558658, 0.362990, 0.005650},{
      1.557083, 0.366081, 0.005650},{1.557688, 0.366520, 0.003846}}],
    Polygon[{{1.558658, 0.362990, 0.005650},{1.557688, 0.362675, 0.007315},{
      1.556258, 0.365481, 0.007315},{1.557083, 0.366081, 0.005650}}],
    Polygon[{{1.557688, 0.362675, 0.007315},{1.556482, 0.362283, 0.008800},{
      1.555232, 0.364736, 0.008800},{1.556258, 0.365481, 0.007315}}],
    Polygon[{{1.556482, 0.362283, 0.008800},{1.555069, 0.361824, 0.010068},{
      1.554030, 0.363863, 0.010068},{1.555232, 0.364736, 0.008800}}],
    Polygon[{{1.555069, 0.361824, 0.010068},{1.553486, 0.361309, 0.011089},{
      1.552683, 0.362884, 0.011089},{1.554030, 0.363863, 0.010068}}],
    Polygon[{{1.553486, 0.361309, 0.011089},{1.551770, 0.360752, 0.011836},{
      1.551224, 0.361824, 0.011836},{1.552683, 0.362884, 0.011089}}],
    Polygon[{{1.551770, 0.360752, 0.011836},{1.549964, 0.360165, 0.012292},{
      1.549688, 0.360708, 0.012292},{1.551224, 0.361824, 0.011836}}],
    Polygon[{{1.549688, 0.360708, -0.012292},{1.551224, 0.361824, -0.011836},{
      1.550373, 0.362675, -0.011836},{1.549257, 0.361139, -0.012292}}],
    Polygon[{{1.551224, 0.361824, -0.011836},{1.552683, 0.362884, -0.011089},{
      1.551433, 0.364134, -0.011089},{1.550373, 0.362675, -0.011836}}],
    Polygon[{{1.552683, 0.362884, -0.011089},{1.554030, 0.363863, -0.010068},{
      1.552412, 0.365481, -0.010068},{1.551433, 0.364134, -0.011089}}],
    Polygon[{{1.554030, 0.363863, -0.010068},{1.555232, 0.364736, -0.008800},{
      1.553285, 0.366683, -0.008800},{1.552412, 0.365481, -0.010068}}],
    Polygon[{{1.555232, 0.364736, -0.008800},{1.556258, 0.365481, -0.007315},{
      1.554030, 0.367709, -0.007315},{1.553285, 0.366683, -0.008800}}],
    Polygon[{{1.556258, 0.365481, -0.007315},{1.557083, 0.366081, -0.005650},{
      1.554630, 0.368534, -0.005650},{1.554030, 0.367709, -0.007315}}],
    Polygon[{{1.557083, 0.366081, -0.005650},{1.557688, 0.366520, -0.003846},{
      1.555069, 0.369139, -0.003846},{1.554630, 0.368534, -0.005650}}],
    Polygon[{{1.557688, 0.366520, -0.003846},{1.558057, 0.366788, -0.001947},{
      1.555337, 0.369508, -0.001947},{1.555069, 0.369139, -0.003846}}],
    Polygon[{{1.558057, 0.366788, -0.001947},{1.558181, 0.366878, 0.000000},{
      1.555427, 0.369632, 0.000000},{1.555337, 0.369508, -0.001947}}],
    Polygon[{{1.558181, 0.366878, 0.000000},{1.558057, 0.366788, 0.001947},{
      1.555337, 0.369508, 0.001947},{1.555427, 0.369632, 0.000000}}],
    Polygon[{{1.558057, 0.366788, 0.001947},{1.557688, 0.366520, 0.003846},{
      1.555069, 0.369139, 0.003846},{1.555337, 0.369508, 0.001947}}],
    Polygon[{{1.557688, 0.366520, 0.003846},{1.557083, 0.366081, 0.005650},{
      1.554630, 0.368534, 0.005650},{1.555069, 0.369139, 0.003846}}],
    Polygon[{{1.557083, 0.366081, 0.005650},{1.556258, 0.365481, 0.007315},{
      1.554030, 0.367709, 0.007315},{1.554630, 0.368534, 0.005650}}],
    Polygon[{{1.556258, 0.365481, 0.007315},{1.555232, 0.364736, 0.008800},{
      1.553285, 0.366683, 0.008800},{1.554030, 0.367709, 0.007315}}],
    Polygon[{{1.555232, 0.364736, 0.008800},{1.554030, 0.363863, 0.010068},{
      1.552412, 0.365481, 0.010068},{1.553285, 0.366683, 0.008800}}],
    Polygon[{{1.554030, 0.363863, 0.010068},{1.552683, 0.362884, 0.011089},{
      1.551433, 0.364134, 0.011089},{1.552412, 0.365481, 0.010068}}],
    Polygon[{{1.552683, 0.362884, 0.011089},{1.551224, 0.361824, 0.011836},{
      1.550373, 0.362675, 0.011836},{1.551433, 0.364134, 0.011089}}],
    Polygon[{{1.551224, 0.361824, 0.011836},{1.549688, 0.360708, 0.012292},{
      1.549257, 0.361139, 0.012292},{1.550373, 0.362675, 0.011836}}],
    Polygon[{{1.549257, 0.361139, -0.012292},{1.550373, 0.362675, -0.011836},{
      1.549301, 0.363221, -0.011836},{1.548714, 0.361415, -0.012292}}],
    Polygon[{{1.550373, 0.362675, -0.011836},{1.551433, 0.364134, -0.011089},{
      1.549858, 0.364937, -0.011089},{1.549301, 0.363221, -0.011836}}],
    Polygon[{{1.551433, 0.364134, -0.011089},{1.552412, 0.365481, -0.010068},{
      1.550373, 0.366520, -0.010068},{1.549858, 0.364937, -0.011089}}],
    Polygon[{{1.552412, 0.365481, -0.010068},{1.553285, 0.366683, -0.008800},{
      1.550832, 0.367933, -0.008800},{1.550373, 0.366520, -0.010068}}],
    Polygon[{{1.553285, 0.366683, -0.008800},{1.554030, 0.367709, -0.007315},{
      1.551224, 0.369139, -0.007315},{1.550832, 0.367933, -0.008800}}],
    Polygon[{{1.554030, 0.367709, -0.007315},{1.554630, 0.368534, -0.005650},{
      1.551539, 0.370109, -0.005650},{1.551224, 0.369139, -0.007315}}],
    Polygon[{{1.554630, 0.368534, -0.005650},{1.555069, 0.369139, -0.003846},{
      1.551770, 0.370820, -0.003846},{1.551539, 0.370109, -0.005650}}],
    Polygon[{{1.555069, 0.369139, -0.003846},{1.555337, 0.369508, -0.001947},{
      1.551911, 0.371254, -0.001947},{1.551770, 0.370820, -0.003846}}],
    Polygon[{{1.555337, 0.369508, -0.001947},{1.555427, 0.369632, 0.000000},{
      1.551958, 0.371399, 0.000000},{1.551911, 0.371254, -0.001947}}],
    Polygon[{{1.555427, 0.369632, 0.000000},{1.555337, 0.369508, 0.001947},{
      1.551911, 0.371254, 0.001947},{1.551958, 0.371399, 0.000000}}],
    Polygon[{{1.555337, 0.369508, 0.001947},{1.555069, 0.369139, 0.003846},{
      1.551770, 0.370820, 0.003846},{1.551911, 0.371254, 0.001947}}],
    Polygon[{{1.555069, 0.369139, 0.003846},{1.554630, 0.368534, 0.005650},{
      1.551539, 0.370109, 0.005650},{1.551770, 0.370820, 0.003846}}],
    Polygon[{{1.554630, 0.368534, 0.005650},{1.554030, 0.367709, 0.007315},{
      1.551224, 0.369139, 0.007315},{1.551539, 0.370109, 0.005650}}],
    Polygon[{{1.554030, 0.367709, 0.007315},{1.553285, 0.366683, 0.008800},{
      1.550832, 0.367933, 0.008800},{1.551224, 0.369139, 0.007315}}],
    Polygon[{{1.553285, 0.366683, 0.008800},{1.552412, 0.365481, 0.010068},{
      1.550373, 0.366520, 0.010068},{1.550832, 0.367933, 0.008800}}],
    Polygon[{{1.552412, 0.365481, 0.010068},{1.551433, 0.364134, 0.011089},{
      1.549858, 0.364937, 0.011089},{1.550373, 0.366520, 0.010068}}],
    Polygon[{{1.551433, 0.364134, 0.011089},{1.550373, 0.362675, 0.011836},{
      1.549301, 0.363221, 0.011836},{1.549858, 0.364937, 0.011089}}],
    Polygon[{{1.550373, 0.362675, 0.011836},{1.549257, 0.361139, 0.012292},{
      1.548714, 0.361415, 0.012292},{1.549301, 0.363221, 0.011836}}],
    Polygon[{{1.548714, 0.361415, -0.012292},{1.549301, 0.363221, -0.011836},{
      1.548113, 0.363409, -0.011836},{1.548113, 0.361510, -0.012292}}],
    Polygon[{{1.549301, 0.363221, -0.011836},{1.549858, 0.364937, -0.011089},{
      1.548113, 0.365213, -0.011089},{1.548113, 0.363409, -0.011836}}],
    Polygon[{{1.549858, 0.364937, -0.011089},{1.550373, 0.366520, -0.010068},{
      1.548113, 0.366878, -0.010068},{1.548113, 0.365213, -0.011089}}],
    Polygon[{{1.550373, 0.366520, -0.010068},{1.550832, 0.367933, -0.008800},{
      1.548113, 0.368363, -0.008800},{1.548113, 0.366878, -0.010068}}],
    Polygon[{{1.550832, 0.367933, -0.008800},{1.551224, 0.369139, -0.007315},{
      1.548113, 0.369632, -0.007315},{1.548113, 0.368363, -0.008800}}],
    Polygon[{{1.551224, 0.369139, -0.007315},{1.551539, 0.370109, -0.005650},{
      1.548113, 0.370652, -0.005650},{1.548113, 0.369632, -0.007315}}],
    Polygon[{{1.551539, 0.370109, -0.005650},{1.551770, 0.370820, -0.003846},{
      1.548113, 0.371399, -0.003846},{1.548113, 0.370652, -0.005650}}],
    Polygon[{{1.551770, 0.370820, -0.003846},{1.551911, 0.371254, -0.001947},{
      1.548113, 0.371855, -0.001947},{1.548113, 0.371399, -0.003846}}],
    Polygon[{{1.551911, 0.371254, -0.001947},{1.551958, 0.371399, 0.000000},{
      1.548113, 0.372008, 0.000000},{1.548113, 0.371855, -0.001947}}],
    Polygon[{{1.551958, 0.371399, 0.000000},{1.551911, 0.371254, 0.001947},{
      1.548113, 0.371855, 0.001947},{1.548113, 0.372008, 0.000000}}],
    Polygon[{{1.551911, 0.371254, 0.001947},{1.551770, 0.370820, 0.003846},{
      1.548113, 0.371399, 0.003846},{1.548113, 0.371855, 0.001947}}],
    Polygon[{{1.551770, 0.370820, 0.003846},{1.551539, 0.370109, 0.005650},{
      1.548113, 0.370652, 0.005650},{1.548113, 0.371399, 0.003846}}],
    Polygon[{{1.551539, 0.370109, 0.005650},{1.551224, 0.369139, 0.007315},{
      1.548113, 0.369632, 0.007315},{1.548113, 0.370652, 0.005650}}],
    Polygon[{{1.551224, 0.369139, 0.007315},{1.550832, 0.367933, 0.008800},{
      1.548113, 0.368363, 0.008800},{1.548113, 0.369632, 0.007315}}],
    Polygon[{{1.550832, 0.367933, 0.008800},{1.550373, 0.366520, 0.010068},{
      1.548113, 0.366878, 0.010068},{1.548113, 0.368363, 0.008800}}],
    Polygon[{{1.550373, 0.366520, 0.010068},{1.549858, 0.364937, 0.011089},{
      1.548113, 0.365213, 0.011089},{1.548113, 0.366878, 0.010068}}],
    Polygon[{{1.549858, 0.364937, 0.011089},{1.549301, 0.363221, 0.011836},{
      1.548113, 0.363409, 0.011836},{1.548113, 0.365213, 0.011089}}],
    Polygon[{{1.549301, 0.363221, 0.011836},{1.548714, 0.361415, 0.012292},{
      1.548113, 0.361510, 0.012292},{1.548113, 0.363409, 0.011836}}],
    Polygon[{{1.548113, 0.361510, -0.012292},{1.548113, 0.363409, -0.011836},{
      1.546924, 0.363221, -0.011836},{1.547511, 0.361415, -0.012292}}],
    Polygon[{{1.548113, 0.363409, -0.011836},{1.548113, 0.365213, -0.011089},{
      1.546367, 0.364937, -0.011089},{1.546924, 0.363221, -0.011836}}],
    Polygon[{{1.548113, 0.365213, -0.011089},{1.548113, 0.366878, -0.010068},{
      1.545852, 0.366520, -0.010068},{1.546367, 0.364937, -0.011089}}],
    Polygon[{{1.548113, 0.366878, -0.010068},{1.548113, 0.368363, -0.008800},{
      1.545393, 0.367933, -0.008800},{1.545852, 0.366520, -0.010068}}],
    Polygon[{{1.548113, 0.368363, -0.008800},{1.548113, 0.369632, -0.007315},{
      1.545001, 0.369139, -0.007315},{1.545393, 0.367933, -0.008800}}],
    Polygon[{{1.548113, 0.369632, -0.007315},{1.548113, 0.370652, -0.005650},{
      1.544686, 0.370109, -0.005650},{1.545001, 0.369139, -0.007315}}],
    Polygon[{{1.548113, 0.370652, -0.005650},{1.548113, 0.371399, -0.003846},{
      1.544455, 0.370820, -0.003846},{1.544686, 0.370109, -0.005650}}],
    Polygon[{{1.548113, 0.371399, -0.003846},{1.548113, 0.371855, -0.001947},{
      1.544314, 0.371254, -0.001947},{1.544455, 0.370820, -0.003846}}],
    Polygon[{{1.548113, 0.371855, -0.001947},{1.548113, 0.372008, 0.000000},{
      1.544267, 0.371399, 0.000000},{1.544314, 0.371254, -0.001947}}],
    Polygon[{{1.548113, 0.372008, 0.000000},{1.548113, 0.371855, 0.001947},{
      1.544314, 0.371254, 0.001947},{1.544267, 0.371399, 0.000000}}],
    Polygon[{{1.548113, 0.371855, 0.001947},{1.548113, 0.371399, 0.003846},{
      1.544455, 0.370820, 0.003846},{1.544314, 0.371254, 0.001947}}],
    Polygon[{{1.548113, 0.371399, 0.003846},{1.548113, 0.370652, 0.005650},{
      1.544686, 0.370109, 0.005650},{1.544455, 0.370820, 0.003846}}],
    Polygon[{{1.548113, 0.370652, 0.005650},{1.548113, 0.369632, 0.007315},{
      1.545001, 0.369139, 0.007315},{1.544686, 0.370109, 0.005650}}],
    Polygon[{{1.548113, 0.369632, 0.007315},{1.548113, 0.368363, 0.008800},{
      1.545393, 0.367933, 0.008800},{1.545001, 0.369139, 0.007315}}],
    Polygon[{{1.548113, 0.368363, 0.008800},{1.548113, 0.366878, 0.010068},{
      1.545852, 0.366520, 0.010068},{1.545393, 0.367933, 0.008800}}],
    Polygon[{{1.548113, 0.366878, 0.010068},{1.548113, 0.365213, 0.011089},{
      1.546367, 0.364937, 0.011089},{1.545852, 0.366520, 0.010068}}],
    Polygon[{{1.548113, 0.365213, 0.011089},{1.548113, 0.363409, 0.011836},{
      1.546924, 0.363221, 0.011836},{1.546367, 0.364937, 0.011089}}],
    Polygon[{{1.548113, 0.363409, 0.011836},{1.548113, 0.361510, 0.012292},{
      1.547511, 0.361415, 0.012292},{1.546924, 0.363221, 0.011836}}],
    Polygon[{{1.547511, 0.361415, -0.012292},{1.546924, 0.363221, -0.011836},{
      1.545852, 0.362675, -0.011836},{1.546968, 0.361139, -0.012292}}],
    Polygon[{{1.546924, 0.363221, -0.011836},{1.546367, 0.364937, -0.011089},{
      1.544792, 0.364134, -0.011089},{1.545852, 0.362675, -0.011836}}],
    Polygon[{{1.546367, 0.364937, -0.011089},{1.545852, 0.366520, -0.010068},{
      1.543813, 0.365481, -0.010068},{1.544792, 0.364134, -0.011089}}],
    Polygon[{{1.545852, 0.366520, -0.010068},{1.545393, 0.367933, -0.008800},{
      1.542940, 0.366683, -0.008800},{1.543813, 0.365481, -0.010068}}],
    Polygon[{{1.545393, 0.367933, -0.008800},{1.545001, 0.369139, -0.007315},{
      1.542195, 0.367709, -0.007315},{1.542940, 0.366683, -0.008800}}],
    Polygon[{{1.545001, 0.369139, -0.007315},{1.544686, 0.370109, -0.005650},{
      1.541595, 0.368534, -0.005650},{1.542195, 0.367709, -0.007315}}],
    Polygon[{{1.544686, 0.370109, -0.005650},{1.544455, 0.370820, -0.003846},{
      1.541156, 0.369139, -0.003846},{1.541595, 0.368534, -0.005650}}],
    Polygon[{{1.544455, 0.370820, -0.003846},{1.544314, 0.371254, -0.001947},{
      1.540888, 0.369508, -0.001947},{1.541156, 0.369139, -0.003846}}],
    Polygon[{{1.544314, 0.371254, -0.001947},{1.544267, 0.371399, 0.000000},{
      1.540798, 0.369632, 0.000000},{1.540888, 0.369508, -0.001947}}],
    Polygon[{{1.544267, 0.371399, 0.000000},{1.544314, 0.371254, 0.001947},{
      1.540888, 0.369508, 0.001947},{1.540798, 0.369632, 0.000000}}],
    Polygon[{{1.544314, 0.371254, 0.001947},{1.544455, 0.370820, 0.003846},{
      1.541156, 0.369139, 0.003846},{1.540888, 0.369508, 0.001947}}],
    Polygon[{{1.544455, 0.370820, 0.003846},{1.544686, 0.370109, 0.005650},{
      1.541595, 0.368534, 0.005650},{1.541156, 0.369139, 0.003846}}],
    Polygon[{{1.544686, 0.370109, 0.005650},{1.545001, 0.369139, 0.007315},{
      1.542195, 0.367709, 0.007315},{1.541595, 0.368534, 0.005650}}],
    Polygon[{{1.545001, 0.369139, 0.007315},{1.545393, 0.367933, 0.008800},{
      1.542940, 0.366683, 0.008800},{1.542195, 0.367709, 0.007315}}],
    Polygon[{{1.545393, 0.367933, 0.008800},{1.545852, 0.366520, 0.010068},{
      1.543813, 0.365481, 0.010068},{1.542940, 0.366683, 0.008800}}],
    Polygon[{{1.545852, 0.366520, 0.010068},{1.546367, 0.364937, 0.011089},{
      1.544792, 0.364134, 0.011089},{1.543813, 0.365481, 0.010068}}],
    Polygon[{{1.546367, 0.364937, 0.011089},{1.546924, 0.363221, 0.011836},{
      1.545852, 0.362675, 0.011836},{1.544792, 0.364134, 0.011089}}],
    Polygon[{{1.546924, 0.363221, 0.011836},{1.547511, 0.361415, 0.012292},{
      1.546968, 0.361139, 0.012292},{1.545852, 0.362675, 0.011836}}],
    Polygon[{{1.546968, 0.361139, -0.012292},{1.545852, 0.362675, -0.011836},{
      1.545001, 0.361824, -0.011836},{1.546538, 0.360708, -0.012292}}],
    Polygon[{{1.545852, 0.362675, -0.011836},{1.544792, 0.364134, -0.011089},{
      1.543542, 0.362884, -0.011089},{1.545001, 0.361824, -0.011836}}],
    Polygon[{{1.544792, 0.364134, -0.011089},{1.543813, 0.365481, -0.010068},{
      1.542195, 0.363863, -0.010068},{1.543542, 0.362884, -0.011089}}],
    Polygon[{{1.543813, 0.365481, -0.010068},{1.542940, 0.366683, -0.008800},{
      1.540993, 0.364736, -0.008800},{1.542195, 0.363863, -0.010068}}],
    Polygon[{{1.542940, 0.366683, -0.008800},{1.542195, 0.367709, -0.007315},{
      1.539967, 0.365481, -0.007315},{1.540993, 0.364736, -0.008800}}],
    Polygon[{{1.542195, 0.367709, -0.007315},{1.541595, 0.368534, -0.005650},{
      1.539142, 0.366081, -0.005650},{1.539967, 0.365481, -0.007315}}],
    Polygon[{{1.541595, 0.368534, -0.005650},{1.541156, 0.369139, -0.003846},{
      1.538537, 0.366520, -0.003846},{1.539142, 0.366081, -0.005650}}],
    Polygon[{{1.541156, 0.369139, -0.003846},{1.540888, 0.369508, -0.001947},{
      1.538168, 0.366788, -0.001947},{1.538537, 0.366520, -0.003846}}],
    Polygon[{{1.540888, 0.369508, -0.001947},{1.540798, 0.369632, 0.000000},{
      1.538044, 0.366878, 0.000000},{1.538168, 0.366788, -0.001947}}],
    Polygon[{{1.540798, 0.369632, 0.000000},{1.540888, 0.369508, 0.001947},{
      1.538168, 0.366788, 0.001947},{1.538044, 0.366878, 0.000000}}],
    Polygon[{{1.540888, 0.369508, 0.001947},{1.541156, 0.369139, 0.003846},{
      1.538537, 0.366520, 0.003846},{1.538168, 0.366788, 0.001947}}],
    Polygon[{{1.541156, 0.369139, 0.003846},{1.541595, 0.368534, 0.005650},{
      1.539142, 0.366081, 0.005650},{1.538537, 0.366520, 0.003846}}],
    Polygon[{{1.541595, 0.368534, 0.005650},{1.542195, 0.367709, 0.007315},{
      1.539967, 0.365481, 0.007315},{1.539142, 0.366081, 0.005650}}],
    Polygon[{{1.542195, 0.367709, 0.007315},{1.542940, 0.366683, 0.008800},{
      1.540993, 0.364736, 0.008800},{1.539967, 0.365481, 0.007315}}],
    Polygon[{{1.542940, 0.366683, 0.008800},{1.543813, 0.365481, 0.010068},{
      1.542195, 0.363863, 0.010068},{1.540993, 0.364736, 0.008800}}],
    Polygon[{{1.543813, 0.365481, 0.010068},{1.544792, 0.364134, 0.011089},{
      1.543542, 0.362884, 0.011089},{1.542195, 0.363863, 0.010068}}],
    Polygon[{{1.544792, 0.364134, 0.011089},{1.545852, 0.362675, 0.011836},{
      1.545001, 0.361824, 0.011836},{1.543542, 0.362884, 0.011089}}],
    Polygon[{{1.545852, 0.362675, 0.011836},{1.546968, 0.361139, 0.012292},{
      1.546538, 0.360708, 0.012292},{1.545001, 0.361824, 0.011836}}],
    Polygon[{{1.546538, 0.360708, -0.012292},{1.545001, 0.361824, -0.011836},{
      1.544455, 0.360752, -0.011836},{1.546261, 0.360165, -0.012292}}],
    Polygon[{{1.545001, 0.361824, -0.011836},{1.543542, 0.362884, -0.011089},{
      1.542739, 0.361309, -0.011089},{1.544455, 0.360752, -0.011836}}],
    Polygon[{{1.543542, 0.362884, -0.011089},{1.542195, 0.363863, -0.010068},{
      1.541156, 0.361824, -0.010068},{1.542739, 0.361309, -0.011089}}],
    Polygon[{{1.542195, 0.363863, -0.010068},{1.540993, 0.364736, -0.008800},{
      1.539743, 0.362283, -0.008800},{1.541156, 0.361824, -0.010068}}],
    Polygon[{{1.540993, 0.364736, -0.008800},{1.539967, 0.365481, -0.007315},{
      1.538537, 0.362675, -0.007315},{1.539743, 0.362283, -0.008800}}],
    Polygon[{{1.539967, 0.365481, -0.007315},{1.539142, 0.366081, -0.005650},{
      1.537567, 0.362990, -0.005650},{1.538537, 0.362675, -0.007315}}],
    Polygon[{{1.539142, 0.366081, -0.005650},{1.538537, 0.366520, -0.003846},{
      1.536856, 0.363221, -0.003846},{1.537567, 0.362990, -0.005650}}],
    Polygon[{{1.538537, 0.366520, -0.003846},{1.538168, 0.366788, -0.001947},{
      1.536422, 0.363362, -0.001947},{1.536856, 0.363221, -0.003846}}],
    Polygon[{{1.538168, 0.366788, -0.001947},{1.538044, 0.366878, 0.000000},{
      1.536277, 0.363409, 0.000000},{1.536422, 0.363362, -0.001947}}],
    Polygon[{{1.538044, 0.366878, 0.000000},{1.538168, 0.366788, 0.001947},{
      1.536422, 0.363362, 0.001947},{1.536277, 0.363409, 0.000000}}],
    Polygon[{{1.538168, 0.366788, 0.001947},{1.538537, 0.366520, 0.003846},{
      1.536856, 0.363221, 0.003846},{1.536422, 0.363362, 0.001947}}],
    Polygon[{{1.538537, 0.366520, 0.003846},{1.539142, 0.366081, 0.005650},{
      1.537567, 0.362990, 0.005650},{1.536856, 0.363221, 0.003846}}],
    Polygon[{{1.539142, 0.366081, 0.005650},{1.539967, 0.365481, 0.007315},{
      1.538537, 0.362675, 0.007315},{1.537567, 0.362990, 0.005650}}],
    Polygon[{{1.539967, 0.365481, 0.007315},{1.540993, 0.364736, 0.008800},{
      1.539743, 0.362283, 0.008800},{1.538537, 0.362675, 0.007315}}],
    Polygon[{{1.540993, 0.364736, 0.008800},{1.542195, 0.363863, 0.010068},{
      1.541156, 0.361824, 0.010068},{1.539743, 0.362283, 0.008800}}],
    Polygon[{{1.542195, 0.363863, 0.010068},{1.543542, 0.362884, 0.011089},{
      1.542739, 0.361309, 0.011089},{1.541156, 0.361824, 0.010068}}],
    Polygon[{{1.543542, 0.362884, 0.011089},{1.545001, 0.361824, 0.011836},{
      1.544455, 0.360752, 0.011836},{1.542739, 0.361309, 0.011089}}],
    Polygon[{{1.545001, 0.361824, 0.011836},{1.546538, 0.360708, 0.012292},{
      1.546261, 0.360165, 0.012292},{1.544455, 0.360752, 0.011836}}],
    Polygon[{{1.546261, 0.360165, -0.012292},{1.544455, 0.360752, -0.011836},{
      1.544267, 0.359563, -0.011836},{1.546166, 0.359563, -0.012292}}],
    Polygon[{{1.544455, 0.360752, -0.011836},{1.542739, 0.361309, -0.011089},{
      1.542463, 0.359563, -0.011089},{1.544267, 0.359563, -0.011836}}],
    Polygon[{{1.542739, 0.361309, -0.011089},{1.541156, 0.361824, -0.010068},{
      1.540798, 0.359563, -0.010068},{1.542463, 0.359563, -0.011089}}],
    Polygon[{{1.541156, 0.361824, -0.010068},{1.539743, 0.362283, -0.008800},{
      1.539313, 0.359563, -0.008800},{1.540798, 0.359563, -0.010068}}],
    Polygon[{{1.539743, 0.362283, -0.008800},{1.538537, 0.362675, -0.007315},{
      1.538044, 0.359563, -0.007315},{1.539313, 0.359563, -0.008800}}],
    Polygon[{{1.538537, 0.362675, -0.007315},{1.537567, 0.362990, -0.005650},{
      1.537024, 0.359563, -0.005650},{1.538044, 0.359563, -0.007315}}],
    Polygon[{{1.537567, 0.362990, -0.005650},{1.536856, 0.363221, -0.003846},{
      1.536277, 0.359563, -0.003846},{1.537024, 0.359563, -0.005650}}],
    Polygon[{{1.536856, 0.363221, -0.003846},{1.536422, 0.363362, -0.001947},{
      1.535821, 0.359563, -0.001947},{1.536277, 0.359563, -0.003846}}],
    Polygon[{{1.536422, 0.363362, -0.001947},{1.536277, 0.363409, 0.000000},{
      1.535668, 0.359563, 0.000000},{1.535821, 0.359563, -0.001947}}],
    Polygon[{{1.536277, 0.363409, 0.000000},{1.536422, 0.363362, 0.001947},{
      1.535821, 0.359563, 0.001947},{1.535668, 0.359563, 0.000000}}],
    Polygon[{{1.536422, 0.363362, 0.001947},{1.536856, 0.363221, 0.003846},{
      1.536277, 0.359563, 0.003846},{1.535821, 0.359563, 0.001947}}],
    Polygon[{{1.536856, 0.363221, 0.003846},{1.537567, 0.362990, 0.005650},{
      1.537024, 0.359563, 0.005650},{1.536277, 0.359563, 0.003846}}],
    Polygon[{{1.537567, 0.362990, 0.005650},{1.538537, 0.362675, 0.007315},{
      1.538044, 0.359563, 0.007315},{1.537024, 0.359563, 0.005650}}],
    Polygon[{{1.538537, 0.362675, 0.007315},{1.539743, 0.362283, 0.008800},{
      1.539313, 0.359563, 0.008800},{1.538044, 0.359563, 0.007315}}],
    Polygon[{{1.539743, 0.362283, 0.008800},{1.541156, 0.361824, 0.010068},{
      1.540798, 0.359563, 0.010068},{1.539313, 0.359563, 0.008800}}],
    Polygon[{{1.541156, 0.361824, 0.010068},{1.542739, 0.361309, 0.011089},{
      1.542463, 0.359563, 0.011089},{1.540798, 0.359563, 0.010068}}],
    Polygon[{{1.542739, 0.361309, 0.011089},{1.544455, 0.360752, 0.011836},{
      1.544267, 0.359563, 0.011836},{1.542463, 0.359563, 0.011089}}],
    Polygon[{{1.544455, 0.360752, 0.011836},{1.546261, 0.360165, 0.012292},{
      1.546166, 0.359563, 0.012292},{1.544267, 0.359563, 0.011836}}],
    Polygon[{{1.546166, 0.359563, -0.012292},{1.544267, 0.359563, -0.011836},{
      1.544455, 0.358375, -0.011836},{1.546261, 0.358962, -0.012292}}],
    Polygon[{{1.544267, 0.359563, -0.011836},{1.542463, 0.359563, -0.011089},{
      1.542739, 0.357818, -0.011089},{1.544455, 0.358375, -0.011836}}],
    Polygon[{{1.542463, 0.359563, -0.011089},{1.540798, 0.359563, -0.010068},{
      1.541156, 0.357303, -0.010068},{1.542739, 0.357818, -0.011089}}],
    Polygon[{{1.540798, 0.359563, -0.010068},{1.539313, 0.359563, -0.008800},{
      1.539743, 0.356844, -0.008800},{1.541156, 0.357303, -0.010068}}],
    Polygon[{{1.539313, 0.359563, -0.008800},{1.538044, 0.359563, -0.007315},{
      1.538537, 0.356452, -0.007315},{1.539743, 0.356844, -0.008800}}],
    Polygon[{{1.538044, 0.359563, -0.007315},{1.537024, 0.359563, -0.005650},{
      1.537567, 0.356137, -0.005650},{1.538537, 0.356452, -0.007315}}],
    Polygon[{{1.537024, 0.359563, -0.005650},{1.536277, 0.359563, -0.003846},{
      1.536856, 0.355906, -0.003846},{1.537567, 0.356137, -0.005650}}],
    Polygon[{{1.536277, 0.359563, -0.003846},{1.535821, 0.359563, -0.001947},{
      1.536422, 0.355765, -0.001947},{1.536856, 0.355906, -0.003846}}],
    Polygon[{{1.535821, 0.359563, -0.001947},{1.535668, 0.359563, 0.000000},{
      1.536277, 0.355718, 0.000000},{1.536422, 0.355765, -0.001947}}],
    Polygon[{{1.535668, 0.359563, 0.000000},{1.535821, 0.359563, 0.001947},{
      1.536422, 0.355765, 0.001947},{1.536277, 0.355718, 0.000000}}],
    Polygon[{{1.535821, 0.359563, 0.001947},{1.536277, 0.359563, 0.003846},{
      1.536856, 0.355906, 0.003846},{1.536422, 0.355765, 0.001947}}],
    Polygon[{{1.536277, 0.359563, 0.003846},{1.537024, 0.359563, 0.005650},{
      1.537567, 0.356137, 0.005650},{1.536856, 0.355906, 0.003846}}],
    Polygon[{{1.537024, 0.359563, 0.005650},{1.538044, 0.359563, 0.007315},{
      1.538537, 0.356452, 0.007315},{1.537567, 0.356137, 0.005650}}],
    Polygon[{{1.538044, 0.359563, 0.007315},{1.539313, 0.359563, 0.008800},{
      1.539743, 0.356844, 0.008800},{1.538537, 0.356452, 0.007315}}],
    Polygon[{{1.539313, 0.359563, 0.008800},{1.540798, 0.359563, 0.010068},{
      1.541156, 0.357303, 0.010068},{1.539743, 0.356844, 0.008800}}],
    Polygon[{{1.540798, 0.359563, 0.010068},{1.542463, 0.359563, 0.011089},{
      1.542739, 0.357818, 0.011089},{1.541156, 0.357303, 0.010068}}],
    Polygon[{{1.542463, 0.359563, 0.011089},{1.544267, 0.359563, 0.011836},{
      1.544455, 0.358375, 0.011836},{1.542739, 0.357818, 0.011089}}],
    Polygon[{{1.544267, 0.359563, 0.011836},{1.546166, 0.359563, 0.012292},{
      1.546261, 0.358962, 0.012292},{1.544455, 0.358375, 0.011836}}],
    Polygon[{{1.546261, 0.358962, -0.012292},{1.544455, 0.358375, -0.011836},{
      1.545001, 0.357303, -0.011836},{1.546538, 0.358419, -0.012292}}],
    Polygon[{{1.544455, 0.358375, -0.011836},{1.542739, 0.357818, -0.011089},{
      1.543542, 0.356243, -0.011089},{1.545001, 0.357303, -0.011836}}],
    Polygon[{{1.542739, 0.357818, -0.011089},{1.541156, 0.357303, -0.010068},{
      1.542195, 0.355264, -0.010068},{1.543542, 0.356243, -0.011089}}],
    Polygon[{{1.541156, 0.357303, -0.010068},{1.539743, 0.356844, -0.008800},{
      1.540993, 0.354391, -0.008800},{1.542195, 0.355264, -0.010068}}],
    Polygon[{{1.539743, 0.356844, -0.008800},{1.538537, 0.356452, -0.007315},{
      1.539967, 0.353646, -0.007315},{1.540993, 0.354391, -0.008800}}],
    Polygon[{{1.538537, 0.356452, -0.007315},{1.537567, 0.356137, -0.005650},{
      1.539142, 0.353046, -0.005650},{1.539967, 0.353646, -0.007315}}],
    Polygon[{{1.537567, 0.356137, -0.005650},{1.536856, 0.355906, -0.003846},{
      1.538537, 0.352607, -0.003846},{1.539142, 0.353046, -0.005650}}],
    Polygon[{{1.536856, 0.355906, -0.003846},{1.536422, 0.355765, -0.001947},{
      1.538168, 0.352339, -0.001947},{1.538537, 0.352607, -0.003846}}],
    Polygon[{{1.536422, 0.355765, -0.001947},{1.536277, 0.355718, 0.000000},{
      1.538044, 0.352249, 0.000000},{1.538168, 0.352339, -0.001947}}],
    Polygon[{{1.536277, 0.355718, 0.000000},{1.536422, 0.355765, 0.001947},{
      1.538168, 0.352339, 0.001947},{1.538044, 0.352249, 0.000000}}],
    Polygon[{{1.536422, 0.355765, 0.001947},{1.536856, 0.355906, 0.003846},{
      1.538537, 0.352607, 0.003846},{1.538168, 0.352339, 0.001947}}],
    Polygon[{{1.536856, 0.355906, 0.003846},{1.537567, 0.356137, 0.005650},{
      1.539142, 0.353046, 0.005650},{1.538537, 0.352607, 0.003846}}],
    Polygon[{{1.537567, 0.356137, 0.005650},{1.538537, 0.356452, 0.007315},{
      1.539967, 0.353646, 0.007315},{1.539142, 0.353046, 0.005650}}],
    Polygon[{{1.538537, 0.356452, 0.007315},{1.539743, 0.356844, 0.008800},{
      1.540993, 0.354391, 0.008800},{1.539967, 0.353646, 0.007315}}],
    Polygon[{{1.539743, 0.356844, 0.008800},{1.541156, 0.357303, 0.010068},{
      1.542195, 0.355264, 0.010068},{1.540993, 0.354391, 0.008800}}],
    Polygon[{{1.541156, 0.357303, 0.010068},{1.542739, 0.357818, 0.011089},{
      1.543542, 0.356243, 0.011089},{1.542195, 0.355264, 0.010068}}],
    Polygon[{{1.542739, 0.357818, 0.011089},{1.544455, 0.358375, 0.011836},{
      1.545001, 0.357303, 0.011836},{1.543542, 0.356243, 0.011089}}],
    Polygon[{{1.544455, 0.358375, 0.011836},{1.546261, 0.358962, 0.012292},{
      1.546538, 0.358419, 0.012292},{1.545001, 0.357303, 0.011836}}],
    Polygon[{{1.546538, 0.358419, -0.012292},{1.545001, 0.357303, -0.011836},{
      1.545852, 0.356452, -0.011836},{1.546968, 0.357989, -0.012292}}],
    Polygon[{{1.545001, 0.357303, -0.011836},{1.543542, 0.356243, -0.011089},{
      1.544792, 0.354993, -0.011089},{1.545852, 0.356452, -0.011836}}],
    Polygon[{{1.543542, 0.356243, -0.011089},{1.542195, 0.355264, -0.010068},{
      1.543813, 0.353646, -0.010068},{1.544792, 0.354993, -0.011089}}],
    Polygon[{{1.542195, 0.355264, -0.010068},{1.540993, 0.354391, -0.008800},{
      1.542940, 0.352444, -0.008800},{1.543813, 0.353646, -0.010068}}],
    Polygon[{{1.540993, 0.354391, -0.008800},{1.539967, 0.353646, -0.007315},{
      1.542195, 0.351418, -0.007315},{1.542940, 0.352444, -0.008800}}],
    Polygon[{{1.539967, 0.353646, -0.007315},{1.539142, 0.353046, -0.005650},{
      1.541595, 0.350593, -0.005650},{1.542195, 0.351418, -0.007315}}],
    Polygon[{{1.539142, 0.353046, -0.005650},{1.538537, 0.352607, -0.003846},{
      1.541156, 0.349988, -0.003846},{1.541595, 0.350593, -0.005650}}],
    Polygon[{{1.538537, 0.352607, -0.003846},{1.538168, 0.352339, -0.001947},{
      1.540888, 0.349619, -0.001947},{1.541156, 0.349988, -0.003846}}],
    Polygon[{{1.538168, 0.352339, -0.001947},{1.538044, 0.352249, 0.000000},{
      1.540798, 0.349495, 0.000000},{1.540888, 0.349619, -0.001947}}],
    Polygon[{{1.538044, 0.352249, 0.000000},{1.538168, 0.352339, 0.001947},{
      1.540888, 0.349619, 0.001947},{1.540798, 0.349495, 0.000000}}],
    Polygon[{{1.538168, 0.352339, 0.001947},{1.538537, 0.352607, 0.003846},{
      1.541156, 0.349988, 0.003846},{1.540888, 0.349619, 0.001947}}],
    Polygon[{{1.538537, 0.352607, 0.003846},{1.539142, 0.353046, 0.005650},{
      1.541595, 0.350593, 0.005650},{1.541156, 0.349988, 0.003846}}],
    Polygon[{{1.539142, 0.353046, 0.005650},{1.539967, 0.353646, 0.007315},{
      1.542195, 0.351418, 0.007315},{1.541595, 0.350593, 0.005650}}],
    Polygon[{{1.539967, 0.353646, 0.007315},{1.540993, 0.354391, 0.008800},{
      1.542940, 0.352444, 0.008800},{1.542195, 0.351418, 0.007315}}],
    Polygon[{{1.540993, 0.354391, 0.008800},{1.542195, 0.355264, 0.010068},{
      1.543813, 0.353646, 0.010068},{1.542940, 0.352444, 0.008800}}],
    Polygon[{{1.542195, 0.355264, 0.010068},{1.543542, 0.356243, 0.011089},{
      1.544792, 0.354993, 0.011089},{1.543813, 0.353646, 0.010068}}],
    Polygon[{{1.543542, 0.356243, 0.011089},{1.545001, 0.357303, 0.011836},{
      1.545852, 0.356452, 0.011836},{1.544792, 0.354993, 0.011089}}],
    Polygon[{{1.545001, 0.357303, 0.011836},{1.546538, 0.358419, 0.012292},{
      1.546968, 0.357989, 0.012292},{1.545852, 0.356452, 0.011836}}],
    Polygon[{{1.546968, 0.357989, -0.012292},{1.545852, 0.356452, -0.011836},{
      1.546924, 0.355906, -0.011836},{1.547511, 0.357712, -0.012292}}],
    Polygon[{{1.545852, 0.356452, -0.011836},{1.544792, 0.354993, -0.011089},{
      1.546367, 0.354190, -0.011089},{1.546924, 0.355906, -0.011836}}],
    Polygon[{{1.544792, 0.354993, -0.011089},{1.543813, 0.353646, -0.010068},{
      1.545852, 0.352607, -0.010068},{1.546367, 0.354190, -0.011089}}],
    Polygon[{{1.543813, 0.353646, -0.010068},{1.542940, 0.352444, -0.008800},{
      1.545393, 0.351194, -0.008800},{1.545852, 0.352607, -0.010068}}],
    Polygon[{{1.542940, 0.352444, -0.008800},{1.542195, 0.351418, -0.007315},{
      1.545001, 0.349988, -0.007315},{1.545393, 0.351194, -0.008800}}],
    Polygon[{{1.542195, 0.351418, -0.007315},{1.541595, 0.350593, -0.005650},{
      1.544686, 0.349018, -0.005650},{1.545001, 0.349988, -0.007315}}],
    Polygon[{{1.541595, 0.350593, -0.005650},{1.541156, 0.349988, -0.003846},{
      1.544455, 0.348307, -0.003846},{1.544686, 0.349018, -0.005650}}],
    Polygon[{{1.541156, 0.349988, -0.003846},{1.540888, 0.349619, -0.001947},{
      1.544314, 0.347873, -0.001947},{1.544455, 0.348307, -0.003846}}],
    Polygon[{{1.540888, 0.349619, -0.001947},{1.540798, 0.349495, 0.000000},{
      1.544267, 0.347728, 0.000000},{1.544314, 0.347873, -0.001947}}],
    Polygon[{{1.540798, 0.349495, 0.000000},{1.540888, 0.349619, 0.001947},{
      1.544314, 0.347873, 0.001947},{1.544267, 0.347728, 0.000000}}],
    Polygon[{{1.540888, 0.349619, 0.001947},{1.541156, 0.349988, 0.003846},{
      1.544455, 0.348307, 0.003846},{1.544314, 0.347873, 0.001947}}],
    Polygon[{{1.541156, 0.349988, 0.003846},{1.541595, 0.350593, 0.005650},{
      1.544686, 0.349018, 0.005650},{1.544455, 0.348307, 0.003846}}],
    Polygon[{{1.541595, 0.350593, 0.005650},{1.542195, 0.351418, 0.007315},{
      1.545001, 0.349988, 0.007315},{1.544686, 0.349018, 0.005650}}],
    Polygon[{{1.542195, 0.351418, 0.007315},{1.542940, 0.352444, 0.008800},{
      1.545393, 0.351194, 0.008800},{1.545001, 0.349988, 0.007315}}],
    Polygon[{{1.542940, 0.352444, 0.008800},{1.543813, 0.353646, 0.010068},{
      1.545852, 0.352607, 0.010068},{1.545393, 0.351194, 0.008800}}],
    Polygon[{{1.543813, 0.353646, 0.010068},{1.544792, 0.354993, 0.011089},{
      1.546367, 0.354190, 0.011089},{1.545852, 0.352607, 0.010068}}],
    Polygon[{{1.544792, 0.354993, 0.011089},{1.545852, 0.356452, 0.011836},{
      1.546924, 0.355906, 0.011836},{1.546367, 0.354190, 0.011089}}],
    Polygon[{{1.545852, 0.356452, 0.011836},{1.546968, 0.357989, 0.012292},{
      1.547511, 0.357712, 0.012292},{1.546924, 0.355906, 0.011836}}],
    Polygon[{{1.547511, 0.357712, -0.012292},{1.546924, 0.355906, -0.011836},{
      1.548113, 0.355718, -0.011836},{1.548113, 0.357617, -0.012292}}],
    Polygon[{{1.546924, 0.355906, -0.011836},{1.546367, 0.354190, -0.011089},{
      1.548113, 0.353914, -0.011089},{1.548113, 0.355718, -0.011836}}],
    Polygon[{{1.546367, 0.354190, -0.011089},{1.545852, 0.352607, -0.010068},{
      1.548113, 0.352249, -0.010068},{1.548113, 0.353914, -0.011089}}],
    Polygon[{{1.545852, 0.352607, -0.010068},{1.545393, 0.351194, -0.008800},{
      1.548113, 0.350764, -0.008800},{1.548113, 0.352249, -0.010068}}],
    Polygon[{{1.545393, 0.351194, -0.008800},{1.545001, 0.349988, -0.007315},{
      1.548113, 0.349495, -0.007315},{1.548113, 0.350764, -0.008800}}],
    Polygon[{{1.545001, 0.349988, -0.007315},{1.544686, 0.349018, -0.005650},{
      1.548113, 0.348475, -0.005650},{1.548113, 0.349495, -0.007315}}],
    Polygon[{{1.544686, 0.349018, -0.005650},{1.544455, 0.348307, -0.003846},{
      1.548113, 0.347728, -0.003846},{1.548113, 0.348475, -0.005650}}],
    Polygon[{{1.544455, 0.348307, -0.003846},{1.544314, 0.347873, -0.001947},{
      1.548113, 0.347272, -0.001947},{1.548113, 0.347728, -0.003846}}],
    Polygon[{{1.544314, 0.347873, -0.001947},{1.544267, 0.347728, 0.000000},{
      1.548113, 0.347119, 0.000000},{1.548113, 0.347272, -0.001947}}],
    Polygon[{{1.544267, 0.347728, 0.000000},{1.544314, 0.347873, 0.001947},{
      1.548113, 0.347272, 0.001947},{1.548113, 0.347119, 0.000000}}],
    Polygon[{{1.544314, 0.347873, 0.001947},{1.544455, 0.348307, 0.003846},{
      1.548113, 0.347728, 0.003846},{1.548113, 0.347272, 0.001947}}],
    Polygon[{{1.544455, 0.348307, 0.003846},{1.544686, 0.349018, 0.005650},{
      1.548113, 0.348475, 0.005650},{1.548113, 0.347728, 0.003846}}],
    Polygon[{{1.544686, 0.349018, 0.005650},{1.545001, 0.349988, 0.007315},{
      1.548113, 0.349495, 0.007315},{1.548113, 0.348475, 0.005650}}],
    Polygon[{{1.545001, 0.349988, 0.007315},{1.545393, 0.351194, 0.008800},{
      1.548113, 0.350764, 0.008800},{1.548113, 0.349495, 0.007315}}],
    Polygon[{{1.545393, 0.351194, 0.008800},{1.545852, 0.352607, 0.010068},{
      1.548113, 0.352249, 0.010068},{1.548113, 0.350764, 0.008800}}],
    Polygon[{{1.545852, 0.352607, 0.010068},{1.546367, 0.354190, 0.011089},{
      1.548113, 0.353914, 0.011089},{1.548113, 0.352249, 0.010068}}],
    Polygon[{{1.546367, 0.354190, 0.011089},{1.546924, 0.355906, 0.011836},{
      1.548113, 0.355718, 0.011836},{1.548113, 0.353914, 0.011089}}],
    Polygon[{{1.546924, 0.355906, 0.011836},{1.547511, 0.357712, 0.012292},{
      1.548113, 0.357617, 0.012292},{1.548113, 0.355718, 0.011836}}],
    Polygon[{{1.548113, 0.357617, -0.012292},{1.548113, 0.355718, -0.011836},{
      1.549301, 0.355906, -0.011836},{1.548714, 0.357712, -0.012292}}],
    Polygon[{{1.548113, 0.355718, -0.011836},{1.548113, 0.353914, -0.011089},{
      1.549858, 0.354190, -0.011089},{1.549301, 0.355906, -0.011836}}],
    Polygon[{{1.548113, 0.353914, -0.011089},{1.548113, 0.352249, -0.010068},{
      1.550373, 0.352607, -0.010068},{1.549858, 0.354190, -0.011089}}],
    Polygon[{{1.548113, 0.352249, -0.010068},{1.548113, 0.350764, -0.008800},{
      1.550832, 0.351194, -0.008800},{1.550373, 0.352607, -0.010068}}],
    Polygon[{{1.548113, 0.350764, -0.008800},{1.548113, 0.349495, -0.007315},{
      1.551224, 0.349988, -0.007315},{1.550832, 0.351194, -0.008800}}],
    Polygon[{{1.548113, 0.349495, -0.007315},{1.548113, 0.348475, -0.005650},{
      1.551539, 0.349018, -0.005650},{1.551224, 0.349988, -0.007315}}],
    Polygon[{{1.548113, 0.348475, -0.005650},{1.548113, 0.347728, -0.003846},{
      1.551770, 0.348307, -0.003846},{1.551539, 0.349018, -0.005650}}],
    Polygon[{{1.548113, 0.347728, -0.003846},{1.548113, 0.347272, -0.001947},{
      1.551911, 0.347873, -0.001947},{1.551770, 0.348307, -0.003846}}],
    Polygon[{{1.548113, 0.347272, -0.001947},{1.548113, 0.347119, 0.000000},{
      1.551958, 0.347728, 0.000000},{1.551911, 0.347873, -0.001947}}],
    Polygon[{{1.548113, 0.347119, 0.000000},{1.548113, 0.347272, 0.001947},{
      1.551911, 0.347873, 0.001947},{1.551958, 0.347728, 0.000000}}],
    Polygon[{{1.548113, 0.347272, 0.001947},{1.548113, 0.347728, 0.003846},{
      1.551770, 0.348307, 0.003846},{1.551911, 0.347873, 0.001947}}],
    Polygon[{{1.548113, 0.347728, 0.003846},{1.548113, 0.348475, 0.005650},{
      1.551539, 0.349018, 0.005650},{1.551770, 0.348307, 0.003846}}],
    Polygon[{{1.548113, 0.348475, 0.005650},{1.548113, 0.349495, 0.007315},{
      1.551224, 0.349988, 0.007315},{1.551539, 0.349018, 0.005650}}],
    Polygon[{{1.548113, 0.349495, 0.007315},{1.548113, 0.350764, 0.008800},{
      1.550832, 0.351194, 0.008800},{1.551224, 0.349988, 0.007315}}],
    Polygon[{{1.548113, 0.350764, 0.008800},{1.548113, 0.352249, 0.010068},{
      1.550373, 0.352607, 0.010068},{1.550832, 0.351194, 0.008800}}],
    Polygon[{{1.548113, 0.352249, 0.010068},{1.548113, 0.353914, 0.011089},{
      1.549858, 0.354190, 0.011089},{1.550373, 0.352607, 0.010068}}],
    Polygon[{{1.548113, 0.353914, 0.011089},{1.548113, 0.355718, 0.011836},{
      1.549301, 0.355906, 0.011836},{1.549858, 0.354190, 0.011089}}],
    Polygon[{{1.548113, 0.355718, 0.011836},{1.548113, 0.357617, 0.012292},{
      1.548714, 0.357712, 0.012292},{1.549301, 0.355906, 0.011836}}],
    Polygon[{{1.548714, 0.357712, -0.012292},{1.549301, 0.355906, -0.011836},{
      1.550373, 0.356452, -0.011836},{1.549257, 0.357989, -0.012292}}],
    Polygon[{{1.549301, 0.355906, -0.011836},{1.549858, 0.354190, -0.011089},{
      1.551433, 0.354993, -0.011089},{1.550373, 0.356452, -0.011836}}],
    Polygon[{{1.549858, 0.354190, -0.011089},{1.550373, 0.352607, -0.010068},{
      1.552412, 0.353646, -0.010068},{1.551433, 0.354993, -0.011089}}],
    Polygon[{{1.550373, 0.352607, -0.010068},{1.550832, 0.351194, -0.008800},{
      1.553285, 0.352444, -0.008800},{1.552412, 0.353646, -0.010068}}],
    Polygon[{{1.550832, 0.351194, -0.008800},{1.551224, 0.349988, -0.007315},{
      1.554030, 0.351418, -0.007315},{1.553285, 0.352444, -0.008800}}],
    Polygon[{{1.551224, 0.349988, -0.007315},{1.551539, 0.349018, -0.005650},{
      1.554630, 0.350593, -0.005650},{1.554030, 0.351418, -0.007315}}],
    Polygon[{{1.551539, 0.349018, -0.005650},{1.551770, 0.348307, -0.003846},{
      1.555069, 0.349988, -0.003846},{1.554630, 0.350593, -0.005650}}],
    Polygon[{{1.551770, 0.348307, -0.003846},{1.551911, 0.347873, -0.001947},{
      1.555337, 0.349619, -0.001947},{1.555069, 0.349988, -0.003846}}],
    Polygon[{{1.551911, 0.347873, -0.001947},{1.551958, 0.347728, 0.000000},{
      1.555427, 0.349495, 0.000000},{1.555337, 0.349619, -0.001947}}],
    Polygon[{{1.551958, 0.347728, 0.000000},{1.551911, 0.347873, 0.001947},{
      1.555337, 0.349619, 0.001947},{1.555427, 0.349495, 0.000000}}],
    Polygon[{{1.551911, 0.347873, 0.001947},{1.551770, 0.348307, 0.003846},{
      1.555069, 0.349988, 0.003846},{1.555337, 0.349619, 0.001947}}],
    Polygon[{{1.551770, 0.348307, 0.003846},{1.551539, 0.349018, 0.005650},{
      1.554630, 0.350593, 0.005650},{1.555069, 0.349988, 0.003846}}],
    Polygon[{{1.551539, 0.349018, 0.005650},{1.551224, 0.349988, 0.007315},{
      1.554030, 0.351418, 0.007315},{1.554630, 0.350593, 0.005650}}],
    Polygon[{{1.551224, 0.349988, 0.007315},{1.550832, 0.351194, 0.008800},{
      1.553285, 0.352444, 0.008800},{1.554030, 0.351418, 0.007315}}],
    Polygon[{{1.550832, 0.351194, 0.008800},{1.550373, 0.352607, 0.010068},{
      1.552412, 0.353646, 0.010068},{1.553285, 0.352444, 0.008800}}],
    Polygon[{{1.550373, 0.352607, 0.010068},{1.549858, 0.354190, 0.011089},{
      1.551433, 0.354993, 0.011089},{1.552412, 0.353646, 0.010068}}],
    Polygon[{{1.549858, 0.354190, 0.011089},{1.549301, 0.355906, 0.011836},{
      1.550373, 0.356452, 0.011836},{1.551433, 0.354993, 0.011089}}],
    Polygon[{{1.549301, 0.355906, 0.011836},{1.548714, 0.357712, 0.012292},{
      1.549257, 0.357989, 0.012292},{1.550373, 0.356452, 0.011836}}],
    Polygon[{{1.549257, 0.357989, -0.012292},{1.550373, 0.356452, -0.011836},{
      1.551224, 0.357303, -0.011836},{1.549688, 0.358419, -0.012292}}],
    Polygon[{{1.550373, 0.356452, -0.011836},{1.551433, 0.354993, -0.011089},{
      1.552683, 0.356243, -0.011089},{1.551224, 0.357303, -0.011836}}],
    Polygon[{{1.551433, 0.354993, -0.011089},{1.552412, 0.353646, -0.010068},{
      1.554030, 0.355264, -0.010068},{1.552683, 0.356243, -0.011089}}],
    Polygon[{{1.552412, 0.353646, -0.010068},{1.553285, 0.352444, -0.008800},{
      1.555232, 0.354391, -0.008800},{1.554030, 0.355264, -0.010068}}],
    Polygon[{{1.553285, 0.352444, -0.008800},{1.554030, 0.351418, -0.007315},{
      1.556258, 0.353646, -0.007315},{1.555232, 0.354391, -0.008800}}],
    Polygon[{{1.554030, 0.351418, -0.007315},{1.554630, 0.350593, -0.005650},{
      1.557083, 0.353046, -0.005650},{1.556258, 0.353646, -0.007315}}],
    Polygon[{{1.554630, 0.350593, -0.005650},{1.555069, 0.349988, -0.003846},{
      1.557688, 0.352607, -0.003846},{1.557083, 0.353046, -0.005650}}],
    Polygon[{{1.555069, 0.349988, -0.003846},{1.555337, 0.349619, -0.001947},{
      1.558057, 0.352339, -0.001947},{1.557688, 0.352607, -0.003846}}],
    Polygon[{{1.555337, 0.349619, -0.001947},{1.555427, 0.349495, 0.000000},{
      1.558181, 0.352249, 0.000000},{1.558057, 0.352339, -0.001947}}],
    Polygon[{{1.555427, 0.349495, 0.000000},{1.555337, 0.349619, 0.001947},{
      1.558057, 0.352339, 0.001947},{1.558181, 0.352249, 0.000000}}],
    Polygon[{{1.555337, 0.349619, 0.001947},{1.555069, 0.349988, 0.003846},{
      1.557688, 0.352607, 0.003846},{1.558057, 0.352339, 0.001947}}],
    Polygon[{{1.555069, 0.349988, 0.003846},{1.554630, 0.350593, 0.005650},{
      1.557083, 0.353046, 0.005650},{1.557688, 0.352607, 0.003846}}],
    Polygon[{{1.554630, 0.350593, 0.005650},{1.554030, 0.351418, 0.007315},{
      1.556258, 0.353646, 0.007315},{1.557083, 0.353046, 0.005650}}],
    Polygon[{{1.554030, 0.351418, 0.007315},{1.553285, 0.352444, 0.008800},{
      1.555232, 0.354391, 0.008800},{1.556258, 0.353646, 0.007315}}],
    Polygon[{{1.553285, 0.352444, 0.008800},{1.552412, 0.353646, 0.010068},{
      1.554030, 0.355264, 0.010068},{1.555232, 0.354391, 0.008800}}],
    Polygon[{{1.552412, 0.353646, 0.010068},{1.551433, 0.354993, 0.011089},{
      1.552683, 0.356243, 0.011089},{1.554030, 0.355264, 0.010068}}],
    Polygon[{{1.551433, 0.354993, 0.011089},{1.550373, 0.356452, 0.011836},{
      1.551224, 0.357303, 0.011836},{1.552683, 0.356243, 0.011089}}],
    Polygon[{{1.550373, 0.356452, 0.011836},{1.549257, 0.357989, 0.012292},{
      1.549688, 0.358419, 0.012292},{1.551224, 0.357303, 0.011836}}],
    Polygon[{{1.549688, 0.358419, -0.012292},{1.551224, 0.357303, -0.011836},{
      1.551770, 0.358375, -0.011836},{1.549964, 0.358962, -0.012292}}],
    Polygon[{{1.551224, 0.357303, -0.011836},{1.552683, 0.356243, -0.011089},{
      1.553486, 0.357818, -0.011089},{1.551770, 0.358375, -0.011836}}],
    Polygon[{{1.552683, 0.356243, -0.011089},{1.554030, 0.355264, -0.010068},{
      1.555069, 0.357303, -0.010068},{1.553486, 0.357818, -0.011089}}],
    Polygon[{{1.554030, 0.355264, -0.010068},{1.555232, 0.354391, -0.008800},{
      1.556482, 0.356844, -0.008800},{1.555069, 0.357303, -0.010068}}],
    Polygon[{{1.555232, 0.354391, -0.008800},{1.556258, 0.353646, -0.007315},{
      1.557688, 0.356452, -0.007315},{1.556482, 0.356844, -0.008800}}],
    Polygon[{{1.556258, 0.353646, -0.007315},{1.557083, 0.353046, -0.005650},{
      1.558658, 0.356137, -0.005650},{1.557688, 0.356452, -0.007315}}],
    Polygon[{{1.557083, 0.353046, -0.005650},{1.557688, 0.352607, -0.003846},{
      1.559369, 0.355906, -0.003846},{1.558658, 0.356137, -0.005650}}],
    Polygon[{{1.557688, 0.352607, -0.003846},{1.558057, 0.352339, -0.001947},{
      1.559803, 0.355765, -0.001947},{1.559369, 0.355906, -0.003846}}],
    Polygon[{{1.558057, 0.352339, -0.001947},{1.558181, 0.352249, 0.000000},{
      1.559948, 0.355718, 0.000000},{1.559803, 0.355765, -0.001947}}],
    Polygon[{{1.558181, 0.352249, 0.000000},{1.558057, 0.352339, 0.001947},{
      1.559803, 0.355765, 0.001947},{1.559948, 0.355718, 0.000000}}],
    Polygon[{{1.558057, 0.352339, 0.001947},{1.557688, 0.352607, 0.003846},{
      1.559369, 0.355906, 0.003846},{1.559803, 0.355765, 0.001947}}],
    Polygon[{{1.557688, 0.352607, 0.003846},{1.557083, 0.353046, 0.005650},{
      1.558658, 0.356137, 0.005650},{1.559369, 0.355906, 0.003846}}],
    Polygon[{{1.557083, 0.353046, 0.005650},{1.556258, 0.353646, 0.007315},{
      1.557688, 0.356452, 0.007315},{1.558658, 0.356137, 0.005650}}],
    Polygon[{{1.556258, 0.353646, 0.007315},{1.555232, 0.354391, 0.008800},{
      1.556482, 0.356844, 0.008800},{1.557688, 0.356452, 0.007315}}],
    Polygon[{{1.555232, 0.354391, 0.008800},{1.554030, 0.355264, 0.010068},{
      1.555069, 0.357303, 0.010068},{1.556482, 0.356844, 0.008800}}],
    Polygon[{{1.554030, 0.355264, 0.010068},{1.552683, 0.356243, 0.011089},{
      1.553486, 0.357818, 0.011089},{1.555069, 0.357303, 0.010068}}],
    Polygon[{{1.552683, 0.356243, 0.011089},{1.551224, 0.357303, 0.011836},{
      1.551770, 0.358375, 0.011836},{1.553486, 0.357818, 0.011089}}],
    Polygon[{{1.551224, 0.357303, 0.011836},{1.549688, 0.358419, 0.012292},{
      1.549964, 0.358962, 0.012292},{1.551770, 0.358375, 0.011836}}],
    Polygon[{{1.549964, 0.358962, -0.012292},{1.551770, 0.358375, -0.011836},{
      1.551958, 0.359563, -0.011836},{1.550059, 0.359563, -0.012292}}],
    Polygon[{{1.551770, 0.358375, -0.011836},{1.553486, 0.357818, -0.011089},{
      1.553762, 0.359563, -0.011089},{1.551958, 0.359563, -0.011836}}],
    Polygon[{{1.553486, 0.357818, -0.011089},{1.555069, 0.357303, -0.010068},{
      1.555427, 0.359563, -0.010068},{1.553762, 0.359563, -0.011089}}],
    Polygon[{{1.555069, 0.357303, -0.010068},{1.556482, 0.356844, -0.008800},{
      1.556912, 0.359563, -0.008800},{1.555427, 0.359563, -0.010068}}],
    Polygon[{{1.556482, 0.356844, -0.008800},{1.557688, 0.356452, -0.007315},{
      1.558181, 0.359563, -0.007315},{1.556912, 0.359563, -0.008800}}],
    Polygon[{{1.557688, 0.356452, -0.007315},{1.558658, 0.356137, -0.005650},{
      1.559201, 0.359563, -0.005650},{1.558181, 0.359563, -0.007315}}],
    Polygon[{{1.558658, 0.356137, -0.005650},{1.559369, 0.355906, -0.003846},{
      1.559948, 0.359563, -0.003846},{1.559201, 0.359563, -0.005650}}],
    Polygon[{{1.559369, 0.355906, -0.003846},{1.559803, 0.355765, -0.001947},{
      1.560404, 0.359563, -0.001947},{1.559948, 0.359563, -0.003846}}],
    Polygon[{{1.559803, 0.355765, -0.001947},{1.559948, 0.355718, 0.000000},{
      1.560557, 0.359563, 0.000000},{1.560404, 0.359563, -0.001947}}],
    Polygon[{{1.559948, 0.355718, 0.000000},{1.559803, 0.355765, 0.001947},{
      1.560404, 0.359563, 0.001947},{1.560557, 0.359563, 0.000000}}],
    Polygon[{{1.559803, 0.355765, 0.001947},{1.559369, 0.355906, 0.003846},{
      1.559948, 0.359563, 0.003846},{1.560404, 0.359563, 0.001947}}],
    Polygon[{{1.559369, 0.355906, 0.003846},{1.558658, 0.356137, 0.005650},{
      1.559201, 0.359563, 0.005650},{1.559948, 0.359563, 0.003846}}],
    Polygon[{{1.558658, 0.356137, 0.005650},{1.557688, 0.356452, 0.007315},{
      1.558181, 0.359563, 0.007315},{1.559201, 0.359563, 0.005650}}],
    Polygon[{{1.557688, 0.356452, 0.007315},{1.556482, 0.356844, 0.008800},{
      1.556912, 0.359563, 0.008800},{1.558181, 0.359563, 0.007315}}],
    Polygon[{{1.556482, 0.356844, 0.008800},{1.555069, 0.357303, 0.010068},{
      1.555427, 0.359563, 0.010068},{1.556912, 0.359563, 0.008800}}],
    Polygon[{{1.555069, 0.357303, 0.010068},{1.553486, 0.357818, 0.011089},{
      1.553762, 0.359563, 0.011089},{1.555427, 0.359563, 0.010068}}],
    Polygon[{{1.553486, 0.357818, 0.011089},{1.551770, 0.358375, 0.011836},{
      1.551958, 0.359563, 0.011836},{1.553762, 0.359563, 0.011089}}],
    Polygon[{{1.551770, 0.358375, 0.011836},{1.549964, 0.358962, 0.012292},{
      1.550059, 0.359563, 0.012292},{1.551958, 0.359563, 0.011836}}],
    Polygon[{{1.567817, 0.422836, -0.009538},{1.569291, 0.422836, -0.009185},{
      1.569145, 0.423758, -0.009185},{1.567743, 0.423302, -0.009538}}],
    Polygon[{{1.569291, 0.422836, -0.009185},{1.570691, 0.422836, -0.008605},{
      1.570476, 0.424190, -0.008605},{1.569145, 0.423758, -0.009185}}],
    Polygon[{{1.570691, 0.422836, -0.008605},{1.571983, 0.422836, -0.007813},{
      1.571705, 0.424590, -0.007813},{1.570476, 0.424190, -0.008605}}],
    Polygon[{{1.571983, 0.422836, -0.007813},{1.573135, 0.422836, -0.006829},{
      1.572801, 0.424946, -0.006829},{1.571705, 0.424590, -0.007813}}],
    Polygon[{{1.573135, 0.422836, -0.006829},{1.574119, 0.422836, -0.005676},{
      1.573737, 0.425250, -0.005676},{1.572801, 0.424946, -0.006829}}],
    Polygon[{{1.574119, 0.422836, -0.005676},{1.574911, 0.422836, -0.004384},{
      1.574490, 0.425494, -0.004384},{1.573737, 0.425250, -0.005676}}],
    Polygon[{{1.574911, 0.422836, -0.004384},{1.575491, 0.422836, -0.002984},{
      1.575041, 0.425674, -0.002984},{1.574490, 0.425494, -0.004384}}],
    Polygon[{{1.575491, 0.422836, -0.002984},{1.575845, 0.422836, -0.001511},{
      1.575378, 0.425783, -0.001511},{1.575041, 0.425674, -0.002984}}],
    Polygon[{{1.575845, 0.422836, -0.001511},{1.575964, 0.422836, 0.000000},{
      1.575491, 0.425820, 0.000000},{1.575378, 0.425783, -0.001511}}],
    Polygon[{{1.575964, 0.422836, 0.000000},{1.575845, 0.422836, 0.001511},{
      1.575378, 0.425783, 0.001511},{1.575491, 0.425820, 0.000000}}],
    Polygon[{{1.575845, 0.422836, 0.001511},{1.575491, 0.422836, 0.002984},{
      1.575041, 0.425674, 0.002984},{1.575378, 0.425783, 0.001511}}],
    Polygon[{{1.575491, 0.422836, 0.002984},{1.574911, 0.422836, 0.004384},{
      1.574490, 0.425494, 0.004384},{1.575041, 0.425674, 0.002984}}],
    Polygon[{{1.574911, 0.422836, 0.004384},{1.574119, 0.422836, 0.005676},{
      1.573737, 0.425250, 0.005676},{1.574490, 0.425494, 0.004384}}],
    Polygon[{{1.574119, 0.422836, 0.005676},{1.573135, 0.422836, 0.006829},{
      1.572801, 0.424946, 0.006829},{1.573737, 0.425250, 0.005676}}],
    Polygon[{{1.573135, 0.422836, 0.006829},{1.571983, 0.422836, 0.007813},{
      1.571705, 0.424590, 0.007813},{1.572801, 0.424946, 0.006829}}],
    Polygon[{{1.571983, 0.422836, 0.007813},{1.570691, 0.422836, 0.008605},{
      1.570476, 0.424190, 0.008605},{1.571705, 0.424590, 0.007813}}],
    Polygon[{{1.570691, 0.422836, 0.008605},{1.569291, 0.422836, 0.009185},{
      1.569145, 0.423758, 0.009185},{1.570476, 0.424190, 0.008605}}],
    Polygon[{{1.569291, 0.422836, 0.009185},{1.567817, 0.422836, 0.009538},{
      1.567743, 0.423302, 0.009538},{1.569145, 0.423758, 0.009185}}],
    Polygon[{{1.567743, 0.423302, -0.009538},{1.569145, 0.423758, -0.009185},{
      1.568721, 0.424590, -0.009185},{1.567529, 0.423723, -0.009538}}],
    Polygon[{{1.569145, 0.423758, -0.009185},{1.570476, 0.424190, -0.008605},{
      1.569853, 0.425413, -0.008605},{1.568721, 0.424590, -0.009185}}],
    Polygon[{{1.570476, 0.424190, -0.008605},{1.571705, 0.424590, -0.007813},{
      1.570899, 0.426172, -0.007813},{1.569853, 0.425413, -0.008605}}],
    Polygon[{{1.571705, 0.424590, -0.007813},{1.572801, 0.424946, -0.006829},{
      1.571831, 0.426849, -0.006829},{1.570899, 0.426172, -0.007813}}],
    Polygon[{{1.572801, 0.424946, -0.006829},{1.573737, 0.425250, -0.005676},{
      1.572627, 0.427428, -0.005676},{1.571831, 0.426849, -0.006829}}],
    Polygon[{{1.573737, 0.425250, -0.005676},{1.574490, 0.425494, -0.004384},{
      1.573268, 0.427893, -0.004384},{1.572627, 0.427428, -0.005676}}],
    Polygon[{{1.574490, 0.425494, -0.004384},{1.575041, 0.425674, -0.002984},{
      1.573737, 0.428234, -0.002984},{1.573268, 0.427893, -0.004384}}],
    Polygon[{{1.575041, 0.425674, -0.002984},{1.575378, 0.425783, -0.001511},{
      1.574023, 0.428442, -0.001511},{1.573737, 0.428234, -0.002984}}],
    Polygon[{{1.575378, 0.425783, -0.001511},{1.575491, 0.425820, 0.000000},{
      1.574119, 0.428512, 0.000000},{1.574023, 0.428442, -0.001511}}],
    Polygon[{{1.575491, 0.425820, 0.000000},{1.575378, 0.425783, 0.001511},{
      1.574023, 0.428442, 0.001511},{1.574119, 0.428512, 0.000000}}],
    Polygon[{{1.575378, 0.425783, 0.001511},{1.575041, 0.425674, 0.002984},{
      1.573737, 0.428234, 0.002984},{1.574023, 0.428442, 0.001511}}],
    Polygon[{{1.575041, 0.425674, 0.002984},{1.574490, 0.425494, 0.004384},{
      1.573268, 0.427893, 0.004384},{1.573737, 0.428234, 0.002984}}],
    Polygon[{{1.574490, 0.425494, 0.004384},{1.573737, 0.425250, 0.005676},{
      1.572627, 0.427428, 0.005676},{1.573268, 0.427893, 0.004384}}],
    Polygon[{{1.573737, 0.425250, 0.005676},{1.572801, 0.424946, 0.006829},{
      1.571831, 0.426849, 0.006829},{1.572627, 0.427428, 0.005676}}],
    Polygon[{{1.572801, 0.424946, 0.006829},{1.571705, 0.424590, 0.007813},{
      1.570899, 0.426172, 0.007813},{1.571831, 0.426849, 0.006829}}],
    Polygon[{{1.571705, 0.424590, 0.007813},{1.570476, 0.424190, 0.008605},{
      1.569853, 0.425413, 0.008605},{1.570899, 0.426172, 0.007813}}],
    Polygon[{{1.570476, 0.424190, 0.008605},{1.569145, 0.423758, 0.009185},{
      1.568721, 0.424590, 0.009185},{1.569853, 0.425413, 0.008605}}],
    Polygon[{{1.569145, 0.423758, 0.009185},{1.567743, 0.423302, 0.009538},{
      1.567529, 0.423723, 0.009538},{1.568721, 0.424590, 0.009185}}],
    Polygon[{{1.567529, 0.423723, -0.009538},{1.568721, 0.424590, -0.009185},{
      1.568061, 0.425250, -0.009185},{1.567194, 0.424058, -0.009538}}],
    Polygon[{{1.568721, 0.424590, -0.009185},{1.569853, 0.425413, -0.008605},{
      1.568883, 0.426382, -0.008605},{1.568061, 0.425250, -0.009185}}],
    Polygon[{{1.569853, 0.425413, -0.008605},{1.570899, 0.426172, -0.007813},{
      1.569643, 0.427428, -0.007813},{1.568883, 0.426382, -0.008605}}],
    Polygon[{{1.570899, 0.426172, -0.007813},{1.571831, 0.426849, -0.006829},{
      1.570320, 0.428360, -0.006829},{1.569643, 0.427428, -0.007813}}],
    Polygon[{{1.571831, 0.426849, -0.006829},{1.572627, 0.427428, -0.005676},{
      1.570899, 0.429156, -0.005676},{1.570320, 0.428360, -0.006829}}],
    Polygon[{{1.572627, 0.427428, -0.005676},{1.573268, 0.427893, -0.004384},{
      1.571364, 0.429797, -0.004384},{1.570899, 0.429156, -0.005676}}],
    Polygon[{{1.573268, 0.427893, -0.004384},{1.573737, 0.428234, -0.002984},{
      1.571705, 0.430266, -0.002984},{1.571364, 0.429797, -0.004384}}],
    Polygon[{{1.573737, 0.428234, -0.002984},{1.574023, 0.428442, -0.001511},{
      1.571913, 0.430552, -0.001511},{1.571705, 0.430266, -0.002984}}],
    Polygon[{{1.574023, 0.428442, -0.001511},{1.574119, 0.428512, 0.000000},{
      1.571983, 0.430648, 0.000000},{1.571913, 0.430552, -0.001511}}],
    Polygon[{{1.574119, 0.428512, 0.000000},{1.574023, 0.428442, 0.001511},{
      1.571913, 0.430552, 0.001511},{1.571983, 0.430648, 0.000000}}],
    Polygon[{{1.574023, 0.428442, 0.001511},{1.573737, 0.428234, 0.002984},{
      1.571705, 0.430266, 0.002984},{1.571913, 0.430552, 0.001511}}],
    Polygon[{{1.573737, 0.428234, 0.002984},{1.573268, 0.427893, 0.004384},{
      1.571364, 0.429797, 0.004384},{1.571705, 0.430266, 0.002984}}],
    Polygon[{{1.573268, 0.427893, 0.004384},{1.572627, 0.427428, 0.005676},{
      1.570899, 0.429156, 0.005676},{1.571364, 0.429797, 0.004384}}],
    Polygon[{{1.572627, 0.427428, 0.005676},{1.571831, 0.426849, 0.006829},{
      1.570320, 0.428360, 0.006829},{1.570899, 0.429156, 0.005676}}],
    Polygon[{{1.571831, 0.426849, 0.006829},{1.570899, 0.426172, 0.007813},{
      1.569643, 0.427428, 0.007813},{1.570320, 0.428360, 0.006829}}],
    Polygon[{{1.570899, 0.426172, 0.007813},{1.569853, 0.425413, 0.008605},{
      1.568883, 0.426382, 0.008605},{1.569643, 0.427428, 0.007813}}],
    Polygon[{{1.569853, 0.425413, 0.008605},{1.568721, 0.424590, 0.009185},{
      1.568061, 0.425250, 0.009185},{1.568883, 0.426382, 0.008605}}],
    Polygon[{{1.568721, 0.424590, 0.009185},{1.567529, 0.423723, 0.009538},{
      1.567194, 0.424058, 0.009538},{1.568061, 0.425250, 0.009185}}],
    Polygon[{{1.567194, 0.424058, -0.009538},{1.568061, 0.425250, -0.009185},{
      1.567229, 0.425674, -0.009185},{1.566773, 0.424272, -0.009538}}],
    Polygon[{{1.568061, 0.425250, -0.009185},{1.568883, 0.426382, -0.008605},{
      1.567661, 0.427005, -0.008605},{1.567229, 0.425674, -0.009185}}],
    Polygon[{{1.568883, 0.426382, -0.008605},{1.569643, 0.427428, -0.007813},{
      1.568061, 0.428234, -0.007813},{1.567661, 0.427005, -0.008605}}],
    Polygon[{{1.569643, 0.427428, -0.007813},{1.570320, 0.428360, -0.006829},{
      1.568417, 0.429330, -0.006829},{1.568061, 0.428234, -0.007813}}],
    Polygon[{{1.570320, 0.428360, -0.006829},{1.570899, 0.429156, -0.005676},{
      1.568721, 0.430266, -0.005676},{1.568417, 0.429330, -0.006829}}],
    Polygon[{{1.570899, 0.429156, -0.005676},{1.571364, 0.429797, -0.004384},{
      1.568965, 0.431019, -0.004384},{1.568721, 0.430266, -0.005676}}],
    Polygon[{{1.571364, 0.429797, -0.004384},{1.571705, 0.430266, -0.002984},{
      1.569145, 0.431571, -0.002984},{1.568965, 0.431019, -0.004384}}],
    Polygon[{{1.571705, 0.430266, -0.002984},{1.571913, 0.430552, -0.001511},{
      1.569254, 0.431907, -0.001511},{1.569145, 0.431571, -0.002984}}],
    Polygon[{{1.571913, 0.430552, -0.001511},{1.571983, 0.430648, 0.000000},{
      1.569291, 0.432020, 0.000000},{1.569254, 0.431907, -0.001511}}],
    Polygon[{{1.571983, 0.430648, 0.000000},{1.571913, 0.430552, 0.001511},{
      1.569254, 0.431907, 0.001511},{1.569291, 0.432020, 0.000000}}],
    Polygon[{{1.571913, 0.430552, 0.001511},{1.571705, 0.430266, 0.002984},{
      1.569145, 0.431571, 0.002984},{1.569254, 0.431907, 0.001511}}],
    Polygon[{{1.571705, 0.430266, 0.002984},{1.571364, 0.429797, 0.004384},{
      1.568965, 0.431019, 0.004384},{1.569145, 0.431571, 0.002984}}],
    Polygon[{{1.571364, 0.429797, 0.004384},{1.570899, 0.429156, 0.005676},{
      1.568721, 0.430266, 0.005676},{1.568965, 0.431019, 0.004384}}],
    Polygon[{{1.570899, 0.429156, 0.005676},{1.570320, 0.428360, 0.006829},{
      1.568417, 0.429330, 0.006829},{1.568721, 0.430266, 0.005676}}],
    Polygon[{{1.570320, 0.428360, 0.006829},{1.569643, 0.427428, 0.007813},{
      1.568061, 0.428234, 0.007813},{1.568417, 0.429330, 0.006829}}],
    Polygon[{{1.569643, 0.427428, 0.007813},{1.568883, 0.426382, 0.008605},{
      1.567661, 0.427005, 0.008605},{1.568061, 0.428234, 0.007813}}],
    Polygon[{{1.568883, 0.426382, 0.008605},{1.568061, 0.425250, 0.009185},{
      1.567229, 0.425674, 0.009185},{1.567661, 0.427005, 0.008605}}],
    Polygon[{{1.568061, 0.425250, 0.009185},{1.567194, 0.424058, 0.009538},{
      1.566773, 0.424272, 0.009538},{1.567229, 0.425674, 0.009185}}],
    Polygon[{{1.566773, 0.424272, -0.009538},{1.567229, 0.425674, -0.009185},{
      1.566306, 0.425820, -0.009185},{1.566306, 0.424346, -0.009538}}],
    Polygon[{{1.567229, 0.425674, -0.009185},{1.567661, 0.427005, -0.008605},{
      1.566306, 0.427220, -0.008605},{1.566306, 0.425820, -0.009185}}],
    Polygon[{{1.567661, 0.427005, -0.008605},{1.568061, 0.428234, -0.007813},{
      1.566306, 0.428512, -0.007813},{1.566306, 0.427220, -0.008605}}],
    Polygon[{{1.568061, 0.428234, -0.007813},{1.568417, 0.429330, -0.006829},{
      1.566306, 0.429664, -0.006829},{1.566306, 0.428512, -0.007813}}],
    Polygon[{{1.568417, 0.429330, -0.006829},{1.568721, 0.430266, -0.005676},{
      1.566306, 0.430648, -0.005676},{1.566306, 0.429664, -0.006829}}],
    Polygon[{{1.568721, 0.430266, -0.005676},{1.568965, 0.431019, -0.004384},{
      1.566306, 0.431440, -0.004384},{1.566306, 0.430648, -0.005676}}],
    Polygon[{{1.568965, 0.431019, -0.004384},{1.569145, 0.431571, -0.002984},{
      1.566306, 0.432020, -0.002984},{1.566306, 0.431440, -0.004384}}],
    Polygon[{{1.569145, 0.431571, -0.002984},{1.569254, 0.431907, -0.001511},{
      1.566306, 0.432374, -0.001511},{1.566306, 0.432020, -0.002984}}],
    Polygon[{{1.569254, 0.431907, -0.001511},{1.569291, 0.432020, 0.000000},{
      1.566306, 0.432493, 0.000000},{1.566306, 0.432374, -0.001511}}],
    Polygon[{{1.569291, 0.432020, 0.000000},{1.569254, 0.431907, 0.001511},{
      1.566306, 0.432374, 0.001511},{1.566306, 0.432493, 0.000000}}],
    Polygon[{{1.569254, 0.431907, 0.001511},{1.569145, 0.431571, 0.002984},{
      1.566306, 0.432020, 0.002984},{1.566306, 0.432374, 0.001511}}],
    Polygon[{{1.569145, 0.431571, 0.002984},{1.568965, 0.431019, 0.004384},{
      1.566306, 0.431440, 0.004384},{1.566306, 0.432020, 0.002984}}],
    Polygon[{{1.568965, 0.431019, 0.004384},{1.568721, 0.430266, 0.005676},{
      1.566306, 0.430648, 0.005676},{1.566306, 0.431440, 0.004384}}],
    Polygon[{{1.568721, 0.430266, 0.005676},{1.568417, 0.429330, 0.006829},{
      1.566306, 0.429664, 0.006829},{1.566306, 0.430648, 0.005676}}],
    Polygon[{{1.568417, 0.429330, 0.006829},{1.568061, 0.428234, 0.007813},{
      1.566306, 0.428512, 0.007813},{1.566306, 0.429664, 0.006829}}],
    Polygon[{{1.568061, 0.428234, 0.007813},{1.567661, 0.427005, 0.008605},{
      1.566306, 0.427220, 0.008605},{1.566306, 0.428512, 0.007813}}],
    Polygon[{{1.567661, 0.427005, 0.008605},{1.567229, 0.425674, 0.009185},{
      1.566306, 0.425820, 0.009185},{1.566306, 0.427220, 0.008605}}],
    Polygon[{{1.567229, 0.425674, 0.009185},{1.566773, 0.424272, 0.009538},{
      1.566306, 0.424346, 0.009538},{1.566306, 0.425820, 0.009185}}],
    Polygon[{{1.566306, 0.424346, -0.009538},{1.566306, 0.425820, -0.009185},{
      1.565384, 0.425674, -0.009185},{1.565840, 0.424272, -0.009538}}],
    Polygon[{{1.566306, 0.425820, -0.009185},{1.566306, 0.427220, -0.008605},{
      1.564952, 0.427005, -0.008605},{1.565384, 0.425674, -0.009185}}],
    Polygon[{{1.566306, 0.427220, -0.008605},{1.566306, 0.428512, -0.007813},{
      1.564552, 0.428234, -0.007813},{1.564952, 0.427005, -0.008605}}],
    Polygon[{{1.566306, 0.428512, -0.007813},{1.566306, 0.429664, -0.006829},{
      1.564196, 0.429330, -0.006829},{1.564552, 0.428234, -0.007813}}],
    Polygon[{{1.566306, 0.429664, -0.006829},{1.566306, 0.430648, -0.005676},{
      1.563892, 0.430266, -0.005676},{1.564196, 0.429330, -0.006829}}],
    Polygon[{{1.566306, 0.430648, -0.005676},{1.566306, 0.431440, -0.004384},{
      1.563647, 0.431019, -0.004384},{1.563892, 0.430266, -0.005676}}],
    Polygon[{{1.566306, 0.431440, -0.004384},{1.566306, 0.432020, -0.002984},{
      1.563468, 0.431571, -0.002984},{1.563647, 0.431019, -0.004384}}],
    Polygon[{{1.566306, 0.432020, -0.002984},{1.566306, 0.432374, -0.001511},{
      1.563359, 0.431907, -0.001511},{1.563468, 0.431571, -0.002984}}],
    Polygon[{{1.566306, 0.432374, -0.001511},{1.566306, 0.432493, 0.000000},{
      1.563322, 0.432020, 0.000000},{1.563359, 0.431907, -0.001511}}],
    Polygon[{{1.566306, 0.432493, 0.000000},{1.566306, 0.432374, 0.001511},{
      1.563359, 0.431907, 0.001511},{1.563322, 0.432020, 0.000000}}],
    Polygon[{{1.566306, 0.432374, 0.001511},{1.566306, 0.432020, 0.002984},{
      1.563468, 0.431571, 0.002984},{1.563359, 0.431907, 0.001511}}],
    Polygon[{{1.566306, 0.432020, 0.002984},{1.566306, 0.431440, 0.004384},{
      1.563647, 0.431019, 0.004384},{1.563468, 0.431571, 0.002984}}],
    Polygon[{{1.566306, 0.431440, 0.004384},{1.566306, 0.430648, 0.005676},{
      1.563892, 0.430266, 0.005676},{1.563647, 0.431019, 0.004384}}],
    Polygon[{{1.566306, 0.430648, 0.005676},{1.566306, 0.429664, 0.006829},{
      1.564196, 0.429330, 0.006829},{1.563892, 0.430266, 0.005676}}],
    Polygon[{{1.566306, 0.429664, 0.006829},{1.566306, 0.428512, 0.007813},{
      1.564552, 0.428234, 0.007813},{1.564196, 0.429330, 0.006829}}],
    Polygon[{{1.566306, 0.428512, 0.007813},{1.566306, 0.427220, 0.008605},{
      1.564952, 0.427005, 0.008605},{1.564552, 0.428234, 0.007813}}],
    Polygon[{{1.566306, 0.427220, 0.008605},{1.566306, 0.425820, 0.009185},{
      1.565384, 0.425674, 0.009185},{1.564952, 0.427005, 0.008605}}],
    Polygon[{{1.566306, 0.425820, 0.009185},{1.566306, 0.424346, 0.009538},{
      1.565840, 0.424272, 0.009538},{1.565384, 0.425674, 0.009185}}],
    Polygon[{{1.565840, 0.424272, -0.009538},{1.565384, 0.425674, -0.009185},{
      1.564552, 0.425250, -0.009185},{1.565418, 0.424058, -0.009538}}],
    Polygon[{{1.565384, 0.425674, -0.009185},{1.564952, 0.427005, -0.008605},{
      1.563729, 0.426382, -0.008605},{1.564552, 0.425250, -0.009185}}],
    Polygon[{{1.564952, 0.427005, -0.008605},{1.564552, 0.428234, -0.007813},{
      1.562970, 0.427428, -0.007813},{1.563729, 0.426382, -0.008605}}],
    Polygon[{{1.564552, 0.428234, -0.007813},{1.564196, 0.429330, -0.006829},{
      1.562293, 0.428360, -0.006829},{1.562970, 0.427428, -0.007813}}],
    Polygon[{{1.564196, 0.429330, -0.006829},{1.563892, 0.430266, -0.005676},{
      1.561714, 0.429156, -0.005676},{1.562293, 0.428360, -0.006829}}],
    Polygon[{{1.563892, 0.430266, -0.005676},{1.563647, 0.431019, -0.004384},{
      1.561249, 0.429797, -0.004384},{1.561714, 0.429156, -0.005676}}],
    Polygon[{{1.563647, 0.431019, -0.004384},{1.563468, 0.431571, -0.002984},{
      1.560908, 0.430266, -0.002984},{1.561249, 0.429797, -0.004384}}],
    Polygon[{{1.563468, 0.431571, -0.002984},{1.563359, 0.431907, -0.001511},{
      1.560700, 0.430552, -0.001511},{1.560908, 0.430266, -0.002984}}],
    Polygon[{{1.563359, 0.431907, -0.001511},{1.563322, 0.432020, 0.000000},{
      1.560630, 0.430648, 0.000000},{1.560700, 0.430552, -0.001511}}],
    Polygon[{{1.563322, 0.432020, 0.000000},{1.563359, 0.431907, 0.001511},{
      1.560700, 0.430552, 0.001511},{1.560630, 0.430648, 0.000000}}],
    Polygon[{{1.563359, 0.431907, 0.001511},{1.563468, 0.431571, 0.002984},{
      1.560908, 0.430266, 0.002984},{1.560700, 0.430552, 0.001511}}],
    Polygon[{{1.563468, 0.431571, 0.002984},{1.563647, 0.431019, 0.004384},{
      1.561249, 0.429797, 0.004384},{1.560908, 0.430266, 0.002984}}],
    Polygon[{{1.563647, 0.431019, 0.004384},{1.563892, 0.430266, 0.005676},{
      1.561714, 0.429156, 0.005676},{1.561249, 0.429797, 0.004384}}],
    Polygon[{{1.563892, 0.430266, 0.005676},{1.564196, 0.429330, 0.006829},{
      1.562293, 0.428360, 0.006829},{1.561714, 0.429156, 0.005676}}],
    Polygon[{{1.564196, 0.429330, 0.006829},{1.564552, 0.428234, 0.007813},{
      1.562970, 0.427428, 0.007813},{1.562293, 0.428360, 0.006829}}],
    Polygon[{{1.564552, 0.428234, 0.007813},{1.564952, 0.427005, 0.008605},{
      1.563729, 0.426382, 0.008605},{1.562970, 0.427428, 0.007813}}],
    Polygon[{{1.564952, 0.427005, 0.008605},{1.565384, 0.425674, 0.009185},{
      1.564552, 0.425250, 0.009185},{1.563729, 0.426382, 0.008605}}],
    Polygon[{{1.565384, 0.425674, 0.009185},{1.565840, 0.424272, 0.009538},{
      1.565418, 0.424058, 0.009538},{1.564552, 0.425250, 0.009185}}],
    Polygon[{{1.565418, 0.424058, -0.009538},{1.564552, 0.425250, -0.009185},{
      1.563892, 0.424590, -0.009185},{1.565084, 0.423723, -0.009538}}],
    Polygon[{{1.564552, 0.425250, -0.009185},{1.563729, 0.426382, -0.008605},{
      1.562759, 0.425413, -0.008605},{1.563892, 0.424590, -0.009185}}],
    Polygon[{{1.563729, 0.426382, -0.008605},{1.562970, 0.427428, -0.007813},{
      1.561714, 0.426172, -0.007813},{1.562759, 0.425413, -0.008605}}],
    Polygon[{{1.562970, 0.427428, -0.007813},{1.562293, 0.428360, -0.006829},{
      1.560782, 0.426849, -0.006829},{1.561714, 0.426172, -0.007813}}],
    Polygon[{{1.562293, 0.428360, -0.006829},{1.561714, 0.429156, -0.005676},{
      1.559986, 0.427428, -0.005676},{1.560782, 0.426849, -0.006829}}],
    Polygon[{{1.561714, 0.429156, -0.005676},{1.561249, 0.429797, -0.004384},{
      1.559345, 0.427893, -0.004384},{1.559986, 0.427428, -0.005676}}],
    Polygon[{{1.561249, 0.429797, -0.004384},{1.560908, 0.430266, -0.002984},{
      1.558876, 0.428234, -0.002984},{1.559345, 0.427893, -0.004384}}],
    Polygon[{{1.560908, 0.430266, -0.002984},{1.560700, 0.430552, -0.001511},{
      1.558590, 0.428442, -0.001511},{1.558876, 0.428234, -0.002984}}],
    Polygon[{{1.560700, 0.430552, -0.001511},{1.560630, 0.430648, 0.000000},{
      1.558494, 0.428512, 0.000000},{1.558590, 0.428442, -0.001511}}],
    Polygon[{{1.560630, 0.430648, 0.000000},{1.560700, 0.430552, 0.001511},{
      1.558590, 0.428442, 0.001511},{1.558494, 0.428512, 0.000000}}],
    Polygon[{{1.560700, 0.430552, 0.001511},{1.560908, 0.430266, 0.002984},{
      1.558876, 0.428234, 0.002984},{1.558590, 0.428442, 0.001511}}],
    Polygon[{{1.560908, 0.430266, 0.002984},{1.561249, 0.429797, 0.004384},{
      1.559345, 0.427893, 0.004384},{1.558876, 0.428234, 0.002984}}],
    Polygon[{{1.561249, 0.429797, 0.004384},{1.561714, 0.429156, 0.005676},{
      1.559986, 0.427428, 0.005676},{1.559345, 0.427893, 0.004384}}],
    Polygon[{{1.561714, 0.429156, 0.005676},{1.562293, 0.428360, 0.006829},{
      1.560782, 0.426849, 0.006829},{1.559986, 0.427428, 0.005676}}],
    Polygon[{{1.562293, 0.428360, 0.006829},{1.562970, 0.427428, 0.007813},{
      1.561714, 0.426172, 0.007813},{1.560782, 0.426849, 0.006829}}],
    Polygon[{{1.562970, 0.427428, 0.007813},{1.563729, 0.426382, 0.008605},{
      1.562759, 0.425413, 0.008605},{1.561714, 0.426172, 0.007813}}],
    Polygon[{{1.563729, 0.426382, 0.008605},{1.564552, 0.425250, 0.009185},{
      1.563892, 0.424590, 0.009185},{1.562759, 0.425413, 0.008605}}],
    Polygon[{{1.564552, 0.425250, 0.009185},{1.565418, 0.424058, 0.009538},{
      1.565084, 0.423723, 0.009538},{1.563892, 0.424590, 0.009185}}],
    Polygon[{{1.565084, 0.423723, -0.009538},{1.563892, 0.424590, -0.009185},{
      1.563468, 0.423758, -0.009185},{1.564870, 0.423302, -0.009538}}],
    Polygon[{{1.563892, 0.424590, -0.009185},{1.562759, 0.425413, -0.008605},{
      1.562137, 0.424190, -0.008605},{1.563468, 0.423758, -0.009185}}],
    Polygon[{{1.562759, 0.425413, -0.008605},{1.561714, 0.426172, -0.007813},{
      1.560908, 0.424590, -0.007813},{1.562137, 0.424190, -0.008605}}],
    Polygon[{{1.561714, 0.426172, -0.007813},{1.560782, 0.426849, -0.006829},{
      1.559812, 0.424946, -0.006829},{1.560908, 0.424590, -0.007813}}],
    Polygon[{{1.560782, 0.426849, -0.006829},{1.559986, 0.427428, -0.005676},{
      1.558876, 0.425250, -0.005676},{1.559812, 0.424946, -0.006829}}],
    Polygon[{{1.559986, 0.427428, -0.005676},{1.559345, 0.427893, -0.004384},{
      1.558123, 0.425494, -0.004384},{1.558876, 0.425250, -0.005676}}],
    Polygon[{{1.559345, 0.427893, -0.004384},{1.558876, 0.428234, -0.002984},{
      1.557571, 0.425674, -0.002984},{1.558123, 0.425494, -0.004384}}],
    Polygon[{{1.558876, 0.428234, -0.002984},{1.558590, 0.428442, -0.001511},{
      1.557235, 0.425783, -0.001511},{1.557571, 0.425674, -0.002984}}],
    Polygon[{{1.558590, 0.428442, -0.001511},{1.558494, 0.428512, 0.000000},{
      1.557122, 0.425820, 0.000000},{1.557235, 0.425783, -0.001511}}],
    Polygon[{{1.558494, 0.428512, 0.000000},{1.558590, 0.428442, 0.001511},{
      1.557235, 0.425783, 0.001511},{1.557122, 0.425820, 0.000000}}],
    Polygon[{{1.558590, 0.428442, 0.001511},{1.558876, 0.428234, 0.002984},{
      1.557571, 0.425674, 0.002984},{1.557235, 0.425783, 0.001511}}],
    Polygon[{{1.558876, 0.428234, 0.002984},{1.559345, 0.427893, 0.004384},{
      1.558123, 0.425494, 0.004384},{1.557571, 0.425674, 0.002984}}],
    Polygon[{{1.559345, 0.427893, 0.004384},{1.559986, 0.427428, 0.005676},{
      1.558876, 0.425250, 0.005676},{1.558123, 0.425494, 0.004384}}],
    Polygon[{{1.559986, 0.427428, 0.005676},{1.560782, 0.426849, 0.006829},{
      1.559812, 0.424946, 0.006829},{1.558876, 0.425250, 0.005676}}],
    Polygon[{{1.560782, 0.426849, 0.006829},{1.561714, 0.426172, 0.007813},{
      1.560908, 0.424590, 0.007813},{1.559812, 0.424946, 0.006829}}],
    Polygon[{{1.561714, 0.426172, 0.007813},{1.562759, 0.425413, 0.008605},{
      1.562137, 0.424190, 0.008605},{1.560908, 0.424590, 0.007813}}],
    Polygon[{{1.562759, 0.425413, 0.008605},{1.563892, 0.424590, 0.009185},{
      1.563468, 0.423758, 0.009185},{1.562137, 0.424190, 0.008605}}],
    Polygon[{{1.563892, 0.424590, 0.009185},{1.565084, 0.423723, 0.009538},{
      1.564870, 0.423302, 0.009538},{1.563468, 0.423758, 0.009185}}],
    Polygon[{{1.564870, 0.423302, -0.009538},{1.563468, 0.423758, -0.009185},{
      1.563322, 0.422836, -0.009185},{1.564796, 0.422836, -0.009538}}],
    Polygon[{{1.563468, 0.423758, -0.009185},{1.562137, 0.424190, -0.008605},{
      1.561922, 0.422836, -0.008605},{1.563322, 0.422836, -0.009185}}],
    Polygon[{{1.562137, 0.424190, -0.008605},{1.560908, 0.424590, -0.007813},{
      1.560630, 0.422836, -0.007813},{1.561922, 0.422836, -0.008605}}],
    Polygon[{{1.560908, 0.424590, -0.007813},{1.559812, 0.424946, -0.006829},{
      1.559478, 0.422836, -0.006829},{1.560630, 0.422836, -0.007813}}],
    Polygon[{{1.559812, 0.424946, -0.006829},{1.558876, 0.425250, -0.005676},{
      1.558494, 0.422836, -0.005676},{1.559478, 0.422836, -0.006829}}],
    Polygon[{{1.558876, 0.425250, -0.005676},{1.558123, 0.425494, -0.004384},{
      1.557702, 0.422836, -0.004384},{1.558494, 0.422836, -0.005676}}],
    Polygon[{{1.558123, 0.425494, -0.004384},{1.557571, 0.425674, -0.002984},{
      1.557122, 0.422836, -0.002984},{1.557702, 0.422836, -0.004384}}],
    Polygon[{{1.557571, 0.425674, -0.002984},{1.557235, 0.425783, -0.001511},{
      1.556768, 0.422836, -0.001511},{1.557122, 0.422836, -0.002984}}],
    Polygon[{{1.557235, 0.425783, -0.001511},{1.557122, 0.425820, 0.000000},{
      1.556649, 0.422836, 0.000000},{1.556768, 0.422836, -0.001511}}],
    Polygon[{{1.557122, 0.425820, 0.000000},{1.557235, 0.425783, 0.001511},{
      1.556768, 0.422836, 0.001511},{1.556649, 0.422836, 0.000000}}],
    Polygon[{{1.557235, 0.425783, 0.001511},{1.557571, 0.425674, 0.002984},{
      1.557122, 0.422836, 0.002984},{1.556768, 0.422836, 0.001511}}],
    Polygon[{{1.557571, 0.425674, 0.002984},{1.558123, 0.425494, 0.004384},{
      1.557702, 0.422836, 0.004384},{1.557122, 0.422836, 0.002984}}],
    Polygon[{{1.558123, 0.425494, 0.004384},{1.558876, 0.425250, 0.005676},{
      1.558494, 0.422836, 0.005676},{1.557702, 0.422836, 0.004384}}],
    Polygon[{{1.558876, 0.425250, 0.005676},{1.559812, 0.424946, 0.006829},{
      1.559478, 0.422836, 0.006829},{1.558494, 0.422836, 0.005676}}],
    Polygon[{{1.559812, 0.424946, 0.006829},{1.560908, 0.424590, 0.007813},{
      1.560630, 0.422836, 0.007813},{1.559478, 0.422836, 0.006829}}],
    Polygon[{{1.560908, 0.424590, 0.007813},{1.562137, 0.424190, 0.008605},{
      1.561922, 0.422836, 0.008605},{1.560630, 0.422836, 0.007813}}],
    Polygon[{{1.562137, 0.424190, 0.008605},{1.563468, 0.423758, 0.009185},{
      1.563322, 0.422836, 0.009185},{1.561922, 0.422836, 0.008605}}],
    Polygon[{{1.563468, 0.423758, 0.009185},{1.564870, 0.423302, 0.009538},{
      1.564796, 0.422836, 0.009538},{1.563322, 0.422836, 0.009185}}],
    Polygon[{{1.564796, 0.422836, -0.009538},{1.563322, 0.422836, -0.009185},{
      1.563468, 0.421913, -0.009185},{1.564870, 0.422369, -0.009538}}],
    Polygon[{{1.563322, 0.422836, -0.009185},{1.561922, 0.422836, -0.008605},{
      1.562137, 0.421481, -0.008605},{1.563468, 0.421913, -0.009185}}],
    Polygon[{{1.561922, 0.422836, -0.008605},{1.560630, 0.422836, -0.007813},{
      1.560908, 0.421081, -0.007813},{1.562137, 0.421481, -0.008605}}],
    Polygon[{{1.560630, 0.422836, -0.007813},{1.559478, 0.422836, -0.006829},{
      1.559812, 0.420725, -0.006829},{1.560908, 0.421081, -0.007813}}],
    Polygon[{{1.559478, 0.422836, -0.006829},{1.558494, 0.422836, -0.005676},{
      1.558876, 0.420421, -0.005676},{1.559812, 0.420725, -0.006829}}],
    Polygon[{{1.558494, 0.422836, -0.005676},{1.557702, 0.422836, -0.004384},{
      1.558123, 0.420177, -0.004384},{1.558876, 0.420421, -0.005676}}],
    Polygon[{{1.557702, 0.422836, -0.004384},{1.557122, 0.422836, -0.002984},{
      1.557571, 0.419997, -0.002984},{1.558123, 0.420177, -0.004384}}],
    Polygon[{{1.557122, 0.422836, -0.002984},{1.556768, 0.422836, -0.001511},{
      1.557235, 0.419888, -0.001511},{1.557571, 0.419997, -0.002984}}],
    Polygon[{{1.556768, 0.422836, -0.001511},{1.556649, 0.422836, 0.000000},{
      1.557122, 0.419851, 0.000000},{1.557235, 0.419888, -0.001511}}],
    Polygon[{{1.556649, 0.422836, 0.000000},{1.556768, 0.422836, 0.001511},{
      1.557235, 0.419888, 0.001511},{1.557122, 0.419851, 0.000000}}],
    Polygon[{{1.556768, 0.422836, 0.001511},{1.557122, 0.422836, 0.002984},{
      1.557571, 0.419997, 0.002984},{1.557235, 0.419888, 0.001511}}],
    Polygon[{{1.557122, 0.422836, 0.002984},{1.557702, 0.422836, 0.004384},{
      1.558123, 0.420177, 0.004384},{1.557571, 0.419997, 0.002984}}],
    Polygon[{{1.557702, 0.422836, 0.004384},{1.558494, 0.422836, 0.005676},{
      1.558876, 0.420421, 0.005676},{1.558123, 0.420177, 0.004384}}],
    Polygon[{{1.558494, 0.422836, 0.005676},{1.559478, 0.422836, 0.006829},{
      1.559812, 0.420725, 0.006829},{1.558876, 0.420421, 0.005676}}],
    Polygon[{{1.559478, 0.422836, 0.006829},{1.560630, 0.422836, 0.007813},{
      1.560908, 0.421081, 0.007813},{1.559812, 0.420725, 0.006829}}],
    Polygon[{{1.560630, 0.422836, 0.007813},{1.561922, 0.422836, 0.008605},{
      1.562137, 0.421481, 0.008605},{1.560908, 0.421081, 0.007813}}],
    Polygon[{{1.561922, 0.422836, 0.008605},{1.563322, 0.422836, 0.009185},{
      1.563468, 0.421913, 0.009185},{1.562137, 0.421481, 0.008605}}],
    Polygon[{{1.563322, 0.422836, 0.009185},{1.564796, 0.422836, 0.009538},{
      1.564870, 0.422369, 0.009538},{1.563468, 0.421913, 0.009185}}],
    Polygon[{{1.564870, 0.422369, -0.009538},{1.563468, 0.421913, -0.009185},{
      1.563892, 0.421081, -0.009185},{1.565084, 0.421948, -0.009538}}],
    Polygon[{{1.563468, 0.421913, -0.009185},{1.562137, 0.421481, -0.008605},{
      1.562759, 0.420259, -0.008605},{1.563892, 0.421081, -0.009185}}],
    Polygon[{{1.562137, 0.421481, -0.008605},{1.560908, 0.421081, -0.007813},{
      1.561714, 0.419499, -0.007813},{1.562759, 0.420259, -0.008605}}],
    Polygon[{{1.560908, 0.421081, -0.007813},{1.559812, 0.420725, -0.006829},{
      1.560782, 0.418822, -0.006829},{1.561714, 0.419499, -0.007813}}],
    Polygon[{{1.559812, 0.420725, -0.006829},{1.558876, 0.420421, -0.005676},{
      1.559986, 0.418243, -0.005676},{1.560782, 0.418822, -0.006829}}],
    Polygon[{{1.558876, 0.420421, -0.005676},{1.558123, 0.420177, -0.004384},{
      1.559345, 0.417778, -0.004384},{1.559986, 0.418243, -0.005676}}],
    Polygon[{{1.558123, 0.420177, -0.004384},{1.557571, 0.419997, -0.002984},{
      1.558876, 0.417437, -0.002984},{1.559345, 0.417778, -0.004384}}],
    Polygon[{{1.557571, 0.419997, -0.002984},{1.557235, 0.419888, -0.001511},{
      1.558590, 0.417229, -0.001511},{1.558876, 0.417437, -0.002984}}],
    Polygon[{{1.557235, 0.419888, -0.001511},{1.557122, 0.419851, 0.000000},{
      1.558494, 0.417159, 0.000000},{1.558590, 0.417229, -0.001511}}],
    Polygon[{{1.557122, 0.419851, 0.000000},{1.557235, 0.419888, 0.001511},{
      1.558590, 0.417229, 0.001511},{1.558494, 0.417159, 0.000000}}],
    Polygon[{{1.557235, 0.419888, 0.001511},{1.557571, 0.419997, 0.002984},{
      1.558876, 0.417437, 0.002984},{1.558590, 0.417229, 0.001511}}],
    Polygon[{{1.557571, 0.419997, 0.002984},{1.558123, 0.420177, 0.004384},{
      1.559345, 0.417778, 0.004384},{1.558876, 0.417437, 0.002984}}],
    Polygon[{{1.558123, 0.420177, 0.004384},{1.558876, 0.420421, 0.005676},{
      1.559986, 0.418243, 0.005676},{1.559345, 0.417778, 0.004384}}],
    Polygon[{{1.558876, 0.420421, 0.005676},{1.559812, 0.420725, 0.006829},{
      1.560782, 0.418822, 0.006829},{1.559986, 0.418243, 0.005676}}],
    Polygon[{{1.559812, 0.420725, 0.006829},{1.560908, 0.421081, 0.007813},{
      1.561714, 0.419499, 0.007813},{1.560782, 0.418822, 0.006829}}],
    Polygon[{{1.560908, 0.421081, 0.007813},{1.562137, 0.421481, 0.008605},{
      1.562759, 0.420259, 0.008605},{1.561714, 0.419499, 0.007813}}],
    Polygon[{{1.562137, 0.421481, 0.008605},{1.563468, 0.421913, 0.009185},{
      1.563892, 0.421081, 0.009185},{1.562759, 0.420259, 0.008605}}],
    Polygon[{{1.563468, 0.421913, 0.009185},{1.564870, 0.422369, 0.009538},{
      1.565084, 0.421948, 0.009538},{1.563892, 0.421081, 0.009185}}],
    Polygon[{{1.565084, 0.421948, -0.009538},{1.563892, 0.421081, -0.009185},{
      1.564552, 0.420421, -0.009185},{1.565418, 0.421613, -0.009538}}],
    Polygon[{{1.563892, 0.421081, -0.009185},{1.562759, 0.420259, -0.008605},{
      1.563729, 0.419289, -0.008605},{1.564552, 0.420421, -0.009185}}],
    Polygon[{{1.562759, 0.420259, -0.008605},{1.561714, 0.419499, -0.007813},{
      1.562970, 0.418243, -0.007813},{1.563729, 0.419289, -0.008605}}],
    Polygon[{{1.561714, 0.419499, -0.007813},{1.560782, 0.418822, -0.006829},{
      1.562293, 0.417311, -0.006829},{1.562970, 0.418243, -0.007813}}],
    Polygon[{{1.560782, 0.418822, -0.006829},{1.559986, 0.418243, -0.005676},{
      1.561714, 0.416515, -0.005676},{1.562293, 0.417311, -0.006829}}],
    Polygon[{{1.559986, 0.418243, -0.005676},{1.559345, 0.417778, -0.004384},{
      1.561249, 0.415874, -0.004384},{1.561714, 0.416515, -0.005676}}],
    Polygon[{{1.559345, 0.417778, -0.004384},{1.558876, 0.417437, -0.002984},{
      1.560908, 0.415405, -0.002984},{1.561249, 0.415874, -0.004384}}],
    Polygon[{{1.558876, 0.417437, -0.002984},{1.558590, 0.417229, -0.001511},{
      1.560700, 0.415119, -0.001511},{1.560908, 0.415405, -0.002984}}],
    Polygon[{{1.558590, 0.417229, -0.001511},{1.558494, 0.417159, 0.000000},{
      1.560630, 0.415023, 0.000000},{1.560700, 0.415119, -0.001511}}],
    Polygon[{{1.558494, 0.417159, 0.000000},{1.558590, 0.417229, 0.001511},{
      1.560700, 0.415119, 0.001511},{1.560630, 0.415023, 0.000000}}],
    Polygon[{{1.558590, 0.417229, 0.001511},{1.558876, 0.417437, 0.002984},{
      1.560908, 0.415405, 0.002984},{1.560700, 0.415119, 0.001511}}],
    Polygon[{{1.558876, 0.417437, 0.002984},{1.559345, 0.417778, 0.004384},{
      1.561249, 0.415874, 0.004384},{1.560908, 0.415405, 0.002984}}],
    Polygon[{{1.559345, 0.417778, 0.004384},{1.559986, 0.418243, 0.005676},{
      1.561714, 0.416515, 0.005676},{1.561249, 0.415874, 0.004384}}],
    Polygon[{{1.559986, 0.418243, 0.005676},{1.560782, 0.418822, 0.006829},{
      1.562293, 0.417311, 0.006829},{1.561714, 0.416515, 0.005676}}],
    Polygon[{{1.560782, 0.418822, 0.006829},{1.561714, 0.419499, 0.007813},{
      1.562970, 0.418243, 0.007813},{1.562293, 0.417311, 0.006829}}],
    Polygon[{{1.561714, 0.419499, 0.007813},{1.562759, 0.420259, 0.008605},{
      1.563729, 0.419289, 0.008605},{1.562970, 0.418243, 0.007813}}],
    Polygon[{{1.562759, 0.420259, 0.008605},{1.563892, 0.421081, 0.009185},{
      1.564552, 0.420421, 0.009185},{1.563729, 0.419289, 0.008605}}],
    Polygon[{{1.563892, 0.421081, 0.009185},{1.565084, 0.421948, 0.009538},{
      1.565418, 0.421613, 0.009538},{1.564552, 0.420421, 0.009185}}],
    Polygon[{{1.565418, 0.421613, -0.009538},{1.564552, 0.420421, -0.009185},{
      1.565384, 0.419997, -0.009185},{1.565840, 0.421399, -0.009538}}],
    Polygon[{{1.564552, 0.420421, -0.009185},{1.563729, 0.419289, -0.008605},{
      1.564952, 0.418666, -0.008605},{1.565384, 0.419997, -0.009185}}],
    Polygon[{{1.563729, 0.419289, -0.008605},{1.562970, 0.418243, -0.007813},{
      1.564552, 0.417437, -0.007813},{1.564952, 0.418666, -0.008605}}],
    Polygon[{{1.562970, 0.418243, -0.007813},{1.562293, 0.417311, -0.006829},{
      1.564196, 0.416341, -0.006829},{1.564552, 0.417437, -0.007813}}],
    Polygon[{{1.562293, 0.417311, -0.006829},{1.561714, 0.416515, -0.005676},{
      1.563892, 0.415405, -0.005676},{1.564196, 0.416341, -0.006829}}],
    Polygon[{{1.561714, 0.416515, -0.005676},{1.561249, 0.415874, -0.004384},{
      1.563647, 0.414652, -0.004384},{1.563892, 0.415405, -0.005676}}],
    Polygon[{{1.561249, 0.415874, -0.004384},{1.560908, 0.415405, -0.002984},{
      1.563468, 0.414101, -0.002984},{1.563647, 0.414652, -0.004384}}],
    Polygon[{{1.560908, 0.415405, -0.002984},{1.560700, 0.415119, -0.001511},{
      1.563359, 0.413764, -0.001511},{1.563468, 0.414101, -0.002984}}],
    Polygon[{{1.560700, 0.415119, -0.001511},{1.560630, 0.415023, 0.000000},{
      1.563322, 0.413651, 0.000000},{1.563359, 0.413764, -0.001511}}],
    Polygon[{{1.560630, 0.415023, 0.000000},{1.560700, 0.415119, 0.001511},{
      1.563359, 0.413764, 0.001511},{1.563322, 0.413651, 0.000000}}],
    Polygon[{{1.560700, 0.415119, 0.001511},{1.560908, 0.415405, 0.002984},{
      1.563468, 0.414101, 0.002984},{1.563359, 0.413764, 0.001511}}],
    Polygon[{{1.560908, 0.415405, 0.002984},{1.561249, 0.415874, 0.004384},{
      1.563647, 0.414652, 0.004384},{1.563468, 0.414101, 0.002984}}],
    Polygon[{{1.561249, 0.415874, 0.004384},{1.561714, 0.416515, 0.005676},{
      1.563892, 0.415405, 0.005676},{1.563647, 0.414652, 0.004384}}],
    Polygon[{{1.561714, 0.416515, 0.005676},{1.562293, 0.417311, 0.006829},{
      1.564196, 0.416341, 0.006829},{1.563892, 0.415405, 0.005676}}],
    Polygon[{{1.562293, 0.417311, 0.006829},{1.562970, 0.418243, 0.007813},{
      1.564552, 0.417437, 0.007813},{1.564196, 0.416341, 0.006829}}],
    Polygon[{{1.562970, 0.418243, 0.007813},{1.563729, 0.419289, 0.008605},{
      1.564952, 0.418666, 0.008605},{1.564552, 0.417437, 0.007813}}],
    Polygon[{{1.563729, 0.419289, 0.008605},{1.564552, 0.420421, 0.009185},{
      1.565384, 0.419997, 0.009185},{1.564952, 0.418666, 0.008605}}],
    Polygon[{{1.564552, 0.420421, 0.009185},{1.565418, 0.421613, 0.009538},{
      1.565840, 0.421399, 0.009538},{1.565384, 0.419997, 0.009185}}],
    Polygon[{{1.565840, 0.421399, -0.009538},{1.565384, 0.419997, -0.009185},{
      1.566306, 0.419851, -0.009185},{1.566306, 0.421325, -0.009538}}],
    Polygon[{{1.565384, 0.419997, -0.009185},{1.564952, 0.418666, -0.008605},{
      1.566306, 0.418451, -0.008605},{1.566306, 0.419851, -0.009185}}],
    Polygon[{{1.564952, 0.418666, -0.008605},{1.564552, 0.417437, -0.007813},{
      1.566306, 0.417159, -0.007813},{1.566306, 0.418451, -0.008605}}],
    Polygon[{{1.564552, 0.417437, -0.007813},{1.564196, 0.416341, -0.006829},{
      1.566306, 0.416007, -0.006829},{1.566306, 0.417159, -0.007813}}],
    Polygon[{{1.564196, 0.416341, -0.006829},{1.563892, 0.415405, -0.005676},{
      1.566306, 0.415023, -0.005676},{1.566306, 0.416007, -0.006829}}],
    Polygon[{{1.563892, 0.415405, -0.005676},{1.563647, 0.414652, -0.004384},{
      1.566306, 0.414231, -0.004384},{1.566306, 0.415023, -0.005676}}],
    Polygon[{{1.563647, 0.414652, -0.004384},{1.563468, 0.414101, -0.002984},{
      1.566306, 0.413651, -0.002984},{1.566306, 0.414231, -0.004384}}],
    Polygon[{{1.563468, 0.414101, -0.002984},{1.563359, 0.413764, -0.001511},{
      1.566306, 0.413297, -0.001511},{1.566306, 0.413651, -0.002984}}],
    Polygon[{{1.563359, 0.413764, -0.001511},{1.563322, 0.413651, 0.000000},{
      1.566306, 0.413178, 0.000000},{1.566306, 0.413297, -0.001511}}],
    Polygon[{{1.563322, 0.413651, 0.000000},{1.563359, 0.413764, 0.001511},{
      1.566306, 0.413297, 0.001511},{1.566306, 0.413178, 0.000000}}],
    Polygon[{{1.563359, 0.413764, 0.001511},{1.563468, 0.414101, 0.002984},{
      1.566306, 0.413651, 0.002984},{1.566306, 0.413297, 0.001511}}],
    Polygon[{{1.563468, 0.414101, 0.002984},{1.563647, 0.414652, 0.004384},{
      1.566306, 0.414231, 0.004384},{1.566306, 0.413651, 0.002984}}],
    Polygon[{{1.563647, 0.414652, 0.004384},{1.563892, 0.415405, 0.005676},{
      1.566306, 0.415023, 0.005676},{1.566306, 0.414231, 0.004384}}],
    Polygon[{{1.563892, 0.415405, 0.005676},{1.564196, 0.416341, 0.006829},{
      1.566306, 0.416007, 0.006829},{1.566306, 0.415023, 0.005676}}],
    Polygon[{{1.564196, 0.416341, 0.006829},{1.564552, 0.417437, 0.007813},{
      1.566306, 0.417159, 0.007813},{1.566306, 0.416007, 0.006829}}],
    Polygon[{{1.564552, 0.417437, 0.007813},{1.564952, 0.418666, 0.008605},{
      1.566306, 0.418451, 0.008605},{1.566306, 0.417159, 0.007813}}],
    Polygon[{{1.564952, 0.418666, 0.008605},{1.565384, 0.419997, 0.009185},{
      1.566306, 0.419851, 0.009185},{1.566306, 0.418451, 0.008605}}],
    Polygon[{{1.565384, 0.419997, 0.009185},{1.565840, 0.421399, 0.009538},{
      1.566306, 0.421325, 0.009538},{1.566306, 0.419851, 0.009185}}],
    Polygon[{{1.566306, 0.421325, -0.009538},{1.566306, 0.419851, -0.009185},{
      1.567229, 0.419997, -0.009185},{1.566773, 0.421399, -0.009538}}],
    Polygon[{{1.566306, 0.419851, -0.009185},{1.566306, 0.418451, -0.008605},{
      1.567661, 0.418666, -0.008605},{1.567229, 0.419997, -0.009185}}],
    Polygon[{{1.566306, 0.418451, -0.008605},{1.566306, 0.417159, -0.007813},{
      1.568061, 0.417437, -0.007813},{1.567661, 0.418666, -0.008605}}],
    Polygon[{{1.566306, 0.417159, -0.007813},{1.566306, 0.416007, -0.006829},{
      1.568417, 0.416341, -0.006829},{1.568061, 0.417437, -0.007813}}],
    Polygon[{{1.566306, 0.416007, -0.006829},{1.566306, 0.415023, -0.005676},{
      1.568721, 0.415405, -0.005676},{1.568417, 0.416341, -0.006829}}],
    Polygon[{{1.566306, 0.415023, -0.005676},{1.566306, 0.414231, -0.004384},{
      1.568965, 0.414652, -0.004384},{1.568721, 0.415405, -0.005676}}],
    Polygon[{{1.566306, 0.414231, -0.004384},{1.566306, 0.413651, -0.002984},{
      1.569145, 0.414101, -0.002984},{1.568965, 0.414652, -0.004384}}],
    Polygon[{{1.566306, 0.413651, -0.002984},{1.566306, 0.413297, -0.001511},{
      1.569254, 0.413764, -0.001511},{1.569145, 0.414101, -0.002984}}],
    Polygon[{{1.566306, 0.413297, -0.001511},{1.566306, 0.413178, 0.000000},{
      1.569291, 0.413651, 0.000000},{1.569254, 0.413764, -0.001511}}],
    Polygon[{{1.566306, 0.413178, 0.000000},{1.566306, 0.413297, 0.001511},{
      1.569254, 0.413764, 0.001511},{1.569291, 0.413651, 0.000000}}],
    Polygon[{{1.566306, 0.413297, 0.001511},{1.566306, 0.413651, 0.002984},{
      1.569145, 0.414101, 0.002984},{1.569254, 0.413764, 0.001511}}],
    Polygon[{{1.566306, 0.413651, 0.002984},{1.566306, 0.414231, 0.004384},{
      1.568965, 0.414652, 0.004384},{1.569145, 0.414101, 0.002984}}],
    Polygon[{{1.566306, 0.414231, 0.004384},{1.566306, 0.415023, 0.005676},{
      1.568721, 0.415405, 0.005676},{1.568965, 0.414652, 0.004384}}],
    Polygon[{{1.566306, 0.415023, 0.005676},{1.566306, 0.416007, 0.006829},{
      1.568417, 0.416341, 0.006829},{1.568721, 0.415405, 0.005676}}],
    Polygon[{{1.566306, 0.416007, 0.006829},{1.566306, 0.417159, 0.007813},{
      1.568061, 0.417437, 0.007813},{1.568417, 0.416341, 0.006829}}],
    Polygon[{{1.566306, 0.417159, 0.007813},{1.566306, 0.418451, 0.008605},{
      1.567661, 0.418666, 0.008605},{1.568061, 0.417437, 0.007813}}],
    Polygon[{{1.566306, 0.418451, 0.008605},{1.566306, 0.419851, 0.009185},{
      1.567229, 0.419997, 0.009185},{1.567661, 0.418666, 0.008605}}],
    Polygon[{{1.566306, 0.419851, 0.009185},{1.566306, 0.421325, 0.009538},{
      1.566773, 0.421399, 0.009538},{1.567229, 0.419997, 0.009185}}],
    Polygon[{{1.566773, 0.421399, -0.009538},{1.567229, 0.419997, -0.009185},{
      1.568061, 0.420421, -0.009185},{1.567194, 0.421613, -0.009538}}],
    Polygon[{{1.567229, 0.419997, -0.009185},{1.567661, 0.418666, -0.008605},{
      1.568883, 0.419289, -0.008605},{1.568061, 0.420421, -0.009185}}],
    Polygon[{{1.567661, 0.418666, -0.008605},{1.568061, 0.417437, -0.007813},{
      1.569643, 0.418243, -0.007813},{1.568883, 0.419289, -0.008605}}],
    Polygon[{{1.568061, 0.417437, -0.007813},{1.568417, 0.416341, -0.006829},{
      1.570320, 0.417311, -0.006829},{1.569643, 0.418243, -0.007813}}],
    Polygon[{{1.568417, 0.416341, -0.006829},{1.568721, 0.415405, -0.005676},{
      1.570899, 0.416515, -0.005676},{1.570320, 0.417311, -0.006829}}],
    Polygon[{{1.568721, 0.415405, -0.005676},{1.568965, 0.414652, -0.004384},{
      1.571364, 0.415874, -0.004384},{1.570899, 0.416515, -0.005676}}],
    Polygon[{{1.568965, 0.414652, -0.004384},{1.569145, 0.414101, -0.002984},{
      1.571705, 0.415405, -0.002984},{1.571364, 0.415874, -0.004384}}],
    Polygon[{{1.569145, 0.414101, -0.002984},{1.569254, 0.413764, -0.001511},{
      1.571913, 0.415119, -0.001511},{1.571705, 0.415405, -0.002984}}],
    Polygon[{{1.569254, 0.413764, -0.001511},{1.569291, 0.413651, 0.000000},{
      1.571983, 0.415023, 0.000000},{1.571913, 0.415119, -0.001511}}],
    Polygon[{{1.569291, 0.413651, 0.000000},{1.569254, 0.413764, 0.001511},{
      1.571913, 0.415119, 0.001511},{1.571983, 0.415023, 0.000000}}],
    Polygon[{{1.569254, 0.413764, 0.001511},{1.569145, 0.414101, 0.002984},{
      1.571705, 0.415405, 0.002984},{1.571913, 0.415119, 0.001511}}],
    Polygon[{{1.569145, 0.414101, 0.002984},{1.568965, 0.414652, 0.004384},{
      1.571364, 0.415874, 0.004384},{1.571705, 0.415405, 0.002984}}],
    Polygon[{{1.568965, 0.414652, 0.004384},{1.568721, 0.415405, 0.005676},{
      1.570899, 0.416515, 0.005676},{1.571364, 0.415874, 0.004384}}],
    Polygon[{{1.568721, 0.415405, 0.005676},{1.568417, 0.416341, 0.006829},{
      1.570320, 0.417311, 0.006829},{1.570899, 0.416515, 0.005676}}],
    Polygon[{{1.568417, 0.416341, 0.006829},{1.568061, 0.417437, 0.007813},{
      1.569643, 0.418243, 0.007813},{1.570320, 0.417311, 0.006829}}],
    Polygon[{{1.568061, 0.417437, 0.007813},{1.567661, 0.418666, 0.008605},{
      1.568883, 0.419289, 0.008605},{1.569643, 0.418243, 0.007813}}],
    Polygon[{{1.567661, 0.418666, 0.008605},{1.567229, 0.419997, 0.009185},{
      1.568061, 0.420421, 0.009185},{1.568883, 0.419289, 0.008605}}],
    Polygon[{{1.567229, 0.419997, 0.009185},{1.566773, 0.421399, 0.009538},{
      1.567194, 0.421613, 0.009538},{1.568061, 0.420421, 0.009185}}],
    Polygon[{{1.567194, 0.421613, -0.009538},{1.568061, 0.420421, -0.009185},{
      1.568721, 0.421081, -0.009185},{1.567529, 0.421948, -0.009538}}],
    Polygon[{{1.568061, 0.420421, -0.009185},{1.568883, 0.419289, -0.008605},{
      1.569853, 0.420259, -0.008605},{1.568721, 0.421081, -0.009185}}],
    Polygon[{{1.568883, 0.419289, -0.008605},{1.569643, 0.418243, -0.007813},{
      1.570899, 0.419499, -0.007813},{1.569853, 0.420259, -0.008605}}],
    Polygon[{{1.569643, 0.418243, -0.007813},{1.570320, 0.417311, -0.006829},{
      1.571831, 0.418822, -0.006829},{1.570899, 0.419499, -0.007813}}],
    Polygon[{{1.570320, 0.417311, -0.006829},{1.570899, 0.416515, -0.005676},{
      1.572627, 0.418243, -0.005676},{1.571831, 0.418822, -0.006829}}],
    Polygon[{{1.570899, 0.416515, -0.005676},{1.571364, 0.415874, -0.004384},{
      1.573268, 0.417778, -0.004384},{1.572627, 0.418243, -0.005676}}],
    Polygon[{{1.571364, 0.415874, -0.004384},{1.571705, 0.415405, -0.002984},{
      1.573737, 0.417437, -0.002984},{1.573268, 0.417778, -0.004384}}],
    Polygon[{{1.571705, 0.415405, -0.002984},{1.571913, 0.415119, -0.001511},{
      1.574023, 0.417229, -0.001511},{1.573737, 0.417437, -0.002984}}],
    Polygon[{{1.571913, 0.415119, -0.001511},{1.571983, 0.415023, 0.000000},{
      1.574119, 0.417159, 0.000000},{1.574023, 0.417229, -0.001511}}],
    Polygon[{{1.571983, 0.415023, 0.000000},{1.571913, 0.415119, 0.001511},{
      1.574023, 0.417229, 0.001511},{1.574119, 0.417159, 0.000000}}],
    Polygon[{{1.571913, 0.415119, 0.001511},{1.571705, 0.415405, 0.002984},{
      1.573737, 0.417437, 0.002984},{1.574023, 0.417229, 0.001511}}],
    Polygon[{{1.571705, 0.415405, 0.002984},{1.571364, 0.415874, 0.004384},{
      1.573268, 0.417778, 0.004384},{1.573737, 0.417437, 0.002984}}],
    Polygon[{{1.571364, 0.415874, 0.004384},{1.570899, 0.416515, 0.005676},{
      1.572627, 0.418243, 0.005676},{1.573268, 0.417778, 0.004384}}],
    Polygon[{{1.570899, 0.416515, 0.005676},{1.570320, 0.417311, 0.006829},{
      1.571831, 0.418822, 0.006829},{1.572627, 0.418243, 0.005676}}],
    Polygon[{{1.570320, 0.417311, 0.006829},{1.569643, 0.418243, 0.007813},{
      1.570899, 0.419499, 0.007813},{1.571831, 0.418822, 0.006829}}],
    Polygon[{{1.569643, 0.418243, 0.007813},{1.568883, 0.419289, 0.008605},{
      1.569853, 0.420259, 0.008605},{1.570899, 0.419499, 0.007813}}],
    Polygon[{{1.568883, 0.419289, 0.008605},{1.568061, 0.420421, 0.009185},{
      1.568721, 0.421081, 0.009185},{1.569853, 0.420259, 0.008605}}],
    Polygon[{{1.568061, 0.420421, 0.009185},{1.567194, 0.421613, 0.009538},{
      1.567529, 0.421948, 0.009538},{1.568721, 0.421081, 0.009185}}],
    Polygon[{{1.567529, 0.421948, -0.009538},{1.568721, 0.421081, -0.009185},{
      1.569145, 0.421913, -0.009185},{1.567743, 0.422369, -0.009538}}],
    Polygon[{{1.568721, 0.421081, -0.009185},{1.569853, 0.420259, -0.008605},{
      1.570476, 0.421481, -0.008605},{1.569145, 0.421913, -0.009185}}],
    Polygon[{{1.569853, 0.420259, -0.008605},{1.570899, 0.419499, -0.007813},{
      1.571705, 0.421081, -0.007813},{1.570476, 0.421481, -0.008605}}],
    Polygon[{{1.570899, 0.419499, -0.007813},{1.571831, 0.418822, -0.006829},{
      1.572801, 0.420725, -0.006829},{1.571705, 0.421081, -0.007813}}],
    Polygon[{{1.571831, 0.418822, -0.006829},{1.572627, 0.418243, -0.005676},{
      1.573737, 0.420421, -0.005676},{1.572801, 0.420725, -0.006829}}],
    Polygon[{{1.572627, 0.418243, -0.005676},{1.573268, 0.417778, -0.004384},{
      1.574490, 0.420177, -0.004384},{1.573737, 0.420421, -0.005676}}],
    Polygon[{{1.573268, 0.417778, -0.004384},{1.573737, 0.417437, -0.002984},{
      1.575041, 0.419997, -0.002984},{1.574490, 0.420177, -0.004384}}],
    Polygon[{{1.573737, 0.417437, -0.002984},{1.574023, 0.417229, -0.001511},{
      1.575378, 0.419888, -0.001511},{1.575041, 0.419997, -0.002984}}],
    Polygon[{{1.574023, 0.417229, -0.001511},{1.574119, 0.417159, 0.000000},{
      1.575491, 0.419851, 0.000000},{1.575378, 0.419888, -0.001511}}],
    Polygon[{{1.574119, 0.417159, 0.000000},{1.574023, 0.417229, 0.001511},{
      1.575378, 0.419888, 0.001511},{1.575491, 0.419851, 0.000000}}],
    Polygon[{{1.574023, 0.417229, 0.001511},{1.573737, 0.417437, 0.002984},{
      1.575041, 0.419997, 0.002984},{1.575378, 0.419888, 0.001511}}],
    Polygon[{{1.573737, 0.417437, 0.002984},{1.573268, 0.417778, 0.004384},{
      1.574490, 0.420177, 0.004384},{1.575041, 0.419997, 0.002984}}],
    Polygon[{{1.573268, 0.417778, 0.004384},{1.572627, 0.418243, 0.005676},{
      1.573737, 0.420421, 0.005676},{1.574490, 0.420177, 0.004384}}],
    Polygon[{{1.572627, 0.418243, 0.005676},{1.571831, 0.418822, 0.006829},{
      1.572801, 0.420725, 0.006829},{1.573737, 0.420421, 0.005676}}],
    Polygon[{{1.571831, 0.418822, 0.006829},{1.570899, 0.419499, 0.007813},{
      1.571705, 0.421081, 0.007813},{1.572801, 0.420725, 0.006829}}],
    Polygon[{{1.570899, 0.419499, 0.007813},{1.569853, 0.420259, 0.008605},{
      1.570476, 0.421481, 0.008605},{1.571705, 0.421081, 0.007813}}],
    Polygon[{{1.569853, 0.420259, 0.008605},{1.568721, 0.421081, 0.009185},{
      1.569145, 0.421913, 0.009185},{1.570476, 0.421481, 0.008605}}],
    Polygon[{{1.568721, 0.421081, 0.009185},{1.567529, 0.421948, 0.009538},{
      1.567743, 0.422369, 0.009538},{1.569145, 0.421913, 0.009185}}],
    Polygon[{{1.567743, 0.422369, -0.009538},{1.569145, 0.421913, -0.009185},{
      1.569291, 0.422836, -0.009185},{1.567817, 0.422836, -0.009538}}],
    Polygon[{{1.569145, 0.421913, -0.009185},{1.570476, 0.421481, -0.008605},{
      1.570691, 0.422836, -0.008605},{1.569291, 0.422836, -0.009185}}],
    Polygon[{{1.570476, 0.421481, -0.008605},{1.571705, 0.421081, -0.007813},{
      1.571983, 0.422836, -0.007813},{1.570691, 0.422836, -0.008605}}],
    Polygon[{{1.571705, 0.421081, -0.007813},{1.572801, 0.420725, -0.006829},{
      1.573135, 0.422836, -0.006829},{1.571983, 0.422836, -0.007813}}],
    Polygon[{{1.572801, 0.420725, -0.006829},{1.573737, 0.420421, -0.005676},{
      1.574119, 0.422836, -0.005676},{1.573135, 0.422836, -0.006829}}],
    Polygon[{{1.573737, 0.420421, -0.005676},{1.574490, 0.420177, -0.004384},{
      1.574911, 0.422836, -0.004384},{1.574119, 0.422836, -0.005676}}],
    Polygon[{{1.574490, 0.420177, -0.004384},{1.575041, 0.419997, -0.002984},{
      1.575491, 0.422836, -0.002984},{1.574911, 0.422836, -0.004384}}],
    Polygon[{{1.575041, 0.419997, -0.002984},{1.575378, 0.419888, -0.001511},{
      1.575845, 0.422836, -0.001511},{1.575491, 0.422836, -0.002984}}],
    Polygon[{{1.575378, 0.419888, -0.001511},{1.575491, 0.419851, 0.000000},{
      1.575964, 0.422836, 0.000000},{1.575845, 0.422836, -0.001511}}],
    Polygon[{{1.575491, 0.419851, 0.000000},{1.575378, 0.419888, 0.001511},{
      1.575845, 0.422836, 0.001511},{1.575964, 0.422836, 0.000000}}],
    Polygon[{{1.575378, 0.419888, 0.001511},{1.575041, 0.419997, 0.002984},{
      1.575491, 0.422836, 0.002984},{1.575845, 0.422836, 0.001511}}],
    Polygon[{{1.575041, 0.419997, 0.002984},{1.574490, 0.420177, 0.004384},{
      1.574911, 0.422836, 0.004384},{1.575491, 0.422836, 0.002984}}],
    Polygon[{{1.574490, 0.420177, 0.004384},{1.573737, 0.420421, 0.005676},{
      1.574119, 0.422836, 0.005676},{1.574911, 0.422836, 0.004384}}],
    Polygon[{{1.573737, 0.420421, 0.005676},{1.572801, 0.420725, 0.006829},{
      1.573135, 0.422836, 0.006829},{1.574119, 0.422836, 0.005676}}],
    Polygon[{{1.572801, 0.420725, 0.006829},{1.571705, 0.421081, 0.007813},{
      1.571983, 0.422836, 0.007813},{1.573135, 0.422836, 0.006829}}],
    Polygon[{{1.571705, 0.421081, 0.007813},{1.570476, 0.421481, 0.008605},{
      1.570691, 0.422836, 0.008605},{1.571983, 0.422836, 0.007813}}],
    Polygon[{{1.570476, 0.421481, 0.008605},{1.569145, 0.421913, 0.009185},{
      1.569291, 0.422836, 0.009185},{1.570691, 0.422836, 0.008605}}],
    Polygon[{{1.569145, 0.421913, 0.009185},{1.567743, 0.422369, 0.009538},{
      1.567817, 0.422836, 0.009538},{1.569291, 0.422836, 0.009185}}],
    Polygon[{{1.607235, 0.384270, -0.008668},{1.608574, 0.384270, -0.008347},{
      1.608441, 0.385108, -0.008347},{1.607168, 0.384694, -0.008668}}],
    Polygon[{{1.608574, 0.384270, -0.008347},{1.609847, 0.384270, -0.007820},{
      1.609652, 0.385501, -0.007820},{1.608441, 0.385108, -0.008347}}],
    Polygon[{{1.609847, 0.384270, -0.007820},{1.611021, 0.384270, -0.007100},{
      1.610768, 0.385864, -0.007100},{1.609652, 0.385501, -0.007820}}],
    Polygon[{{1.611021, 0.384270, -0.007100},{1.612068, 0.384270, -0.006206},{
      1.611764, 0.386188, -0.006206},{1.610768, 0.385864, -0.007100}}],
    Polygon[{{1.612068, 0.384270, -0.006206},{1.612962, 0.384270, -0.005159},{
      1.612615, 0.386464, -0.005159},{1.611764, 0.386188, -0.006206}}],
    Polygon[{{1.612962, 0.384270, -0.005159},{1.613682, 0.384270, -0.003984},{
      1.613299, 0.386687, -0.003984},{1.612615, 0.386464, -0.005159}}],
    Polygon[{{1.613682, 0.384270, -0.003984},{1.614209, 0.384270, -0.002712},{
      1.613801, 0.386849, -0.002712},{1.613299, 0.386687, -0.003984}}],
    Polygon[{{1.614209, 0.384270, -0.002712},{1.614530, 0.384270, -0.001373},{
      1.614106, 0.386949, -0.001373},{1.613801, 0.386849, -0.002712}}],
    Polygon[{{1.614530, 0.384270, -0.001373},{1.614639, 0.384270, 0.000000},{
      1.614209, 0.386982, 0.000000},{1.614106, 0.386949, -0.001373}}],
    Polygon[{{1.614639, 0.384270, 0.000000},{1.614530, 0.384270, 0.001373},{
      1.614106, 0.386949, 0.001373},{1.614209, 0.386982, 0.000000}}],
    Polygon[{{1.614530, 0.384270, 0.001373},{1.614209, 0.384270, 0.002712},{
      1.613801, 0.386849, 0.002712},{1.614106, 0.386949, 0.001373}}],
    Polygon[{{1.614209, 0.384270, 0.002712},{1.613682, 0.384270, 0.003984},{
      1.613299, 0.386687, 0.003984},{1.613801, 0.386849, 0.002712}}],
    Polygon[{{1.613682, 0.384270, 0.003984},{1.612962, 0.384270, 0.005159},{
      1.612615, 0.386464, 0.005159},{1.613299, 0.386687, 0.003984}}],
    Polygon[{{1.612962, 0.384270, 0.005159},{1.612068, 0.384270, 0.006206},{
      1.611764, 0.386188, 0.006206},{1.612615, 0.386464, 0.005159}}],
    Polygon[{{1.612068, 0.384270, 0.006206},{1.611021, 0.384270, 0.007100},{
      1.610768, 0.385864, 0.007100},{1.611764, 0.386188, 0.006206}}],
    Polygon[{{1.611021, 0.384270, 0.007100},{1.609847, 0.384270, 0.007820},{
      1.609652, 0.385501, 0.007820},{1.610768, 0.385864, 0.007100}}],
    Polygon[{{1.609847, 0.384270, 0.007820},{1.608574, 0.384270, 0.008347},{
      1.608441, 0.385108, 0.008347},{1.609652, 0.385501, 0.007820}}],
    Polygon[{{1.608574, 0.384270, 0.008347},{1.607235, 0.384270, 0.008668},{
      1.607168, 0.384694, 0.008668},{1.608441, 0.385108, 0.008347}}],
    Polygon[{{1.607168, 0.384694, -0.008668},{1.608441, 0.385108, -0.008347},{
      1.608056, 0.385864, -0.008347},{1.606973, 0.385077, -0.008668}}],
    Polygon[{{1.608441, 0.385108, -0.008347},{1.609652, 0.385501, -0.007820},{
      1.609086, 0.386612, -0.007820},{1.608056, 0.385864, -0.008347}}],
    Polygon[{{1.609652, 0.385501, -0.007820},{1.610768, 0.385864, -0.007100},{
      1.610036, 0.387302, -0.007100},{1.609086, 0.386612, -0.007820}}],
    Polygon[{{1.610768, 0.385864, -0.007100},{1.611764, 0.386188, -0.006206},{
      1.610883, 0.387918, -0.006206},{1.610036, 0.387302, -0.007100}}],
    Polygon[{{1.611764, 0.386188, -0.006206},{1.612615, 0.386464, -0.005159},{
      1.611606, 0.388443, -0.005159},{1.610883, 0.387918, -0.006206}}],
    Polygon[{{1.612615, 0.386464, -0.005159},{1.613299, 0.386687, -0.003984},{
      1.612189, 0.388866, -0.003984},{1.611606, 0.388443, -0.005159}}],
    Polygon[{{1.613299, 0.386687, -0.003984},{1.613801, 0.386849, -0.002712},{
      1.612615, 0.389176, -0.002712},{1.612189, 0.388866, -0.003984}}],
    Polygon[{{1.613801, 0.386849, -0.002712},{1.614106, 0.386949, -0.001373},{
      1.612875, 0.389365, -0.001373},{1.612615, 0.389176, -0.002712}}],
    Polygon[{{1.614106, 0.386949, -0.001373},{1.614209, 0.386982, 0.000000},{
      1.612962, 0.389429, 0.000000},{1.612875, 0.389365, -0.001373}}],
    Polygon[{{1.614209, 0.386982, 0.000000},{1.614106, 0.386949, 0.001373},{
      1.612875, 0.389365, 0.001373},{1.612962, 0.389429, 0.000000}}],
    Polygon[{{1.614106, 0.386949, 0.001373},{1.613801, 0.386849, 0.002712},{
      1.612615, 0.389176, 0.002712},{1.612875, 0.389365, 0.001373}}],
    Polygon[{{1.613801, 0.386849, 0.002712},{1.613299, 0.386687, 0.003984},{
      1.612189, 0.388866, 0.003984},{1.612615, 0.389176, 0.002712}}],
    Polygon[{{1.613299, 0.386687, 0.003984},{1.612615, 0.386464, 0.005159},{
      1.611606, 0.388443, 0.005159},{1.612189, 0.388866, 0.003984}}],
    Polygon[{{1.612615, 0.386464, 0.005159},{1.611764, 0.386188, 0.006206},{
      1.610883, 0.387918, 0.006206},{1.611606, 0.388443, 0.005159}}],
    Polygon[{{1.611764, 0.386188, 0.006206},{1.610768, 0.385864, 0.007100},{
      1.610036, 0.387302, 0.007100},{1.610883, 0.387918, 0.006206}}],
    Polygon[{{1.610768, 0.385864, 0.007100},{1.609652, 0.385501, 0.007820},{
      1.609086, 0.386612, 0.007820},{1.610036, 0.387302, 0.007100}}],
    Polygon[{{1.609652, 0.385501, 0.007820},{1.608441, 0.385108, 0.008347},{
      1.608056, 0.385864, 0.008347},{1.609086, 0.386612, 0.007820}}],
    Polygon[{{1.608441, 0.385108, 0.008347},{1.607168, 0.384694, 0.008668},{
      1.606973, 0.385077, 0.008668},{1.608056, 0.385864, 0.008347}}],
    Polygon[{{1.606973, 0.385077, -0.008668},{1.608056, 0.385864, -0.008347},{
      1.607456, 0.386464, -0.008347},{1.606669, 0.385381, -0.008668}}],
    Polygon[{{1.608056, 0.385864, -0.008347},{1.609086, 0.386612, -0.007820},{
      1.608204, 0.387493, -0.007820},{1.607456, 0.386464, -0.008347}}],
    Polygon[{{1.609086, 0.386612, -0.007820},{1.610036, 0.387302, -0.007100},{
      1.608894, 0.388443, -0.007100},{1.608204, 0.387493, -0.007820}}],
    Polygon[{{1.610036, 0.387302, -0.007100},{1.610883, 0.387918, -0.006206},{
      1.609510, 0.389291, -0.006206},{1.608894, 0.388443, -0.007100}}],
    Polygon[{{1.610883, 0.387918, -0.006206},{1.611606, 0.388443, -0.005159},{
      1.610036, 0.390014, -0.005159},{1.609510, 0.389291, -0.006206}}],
    Polygon[{{1.611606, 0.388443, -0.005159},{1.612189, 0.388866, -0.003984},{
      1.610458, 0.390596, -0.003984},{1.610036, 0.390014, -0.005159}}],
    Polygon[{{1.612189, 0.388866, -0.003984},{1.612615, 0.389176, -0.002712},{
      1.610768, 0.391023, -0.002712},{1.610458, 0.390596, -0.003984}}],
    Polygon[{{1.612615, 0.389176, -0.002712},{1.612875, 0.389365, -0.001373},{
      1.610957, 0.391283, -0.001373},{1.610768, 0.391023, -0.002712}}],
    Polygon[{{1.612875, 0.389365, -0.001373},{1.612962, 0.389429, 0.000000},{
      1.611021, 0.391370, 0.000000},{1.610957, 0.391283, -0.001373}}],
    Polygon[{{1.612962, 0.389429, 0.000000},{1.612875, 0.389365, 0.001373},{
      1.610957, 0.391283, 0.001373},{1.611021, 0.391370, 0.000000}}],
    Polygon[{{1.612875, 0.389365, 0.001373},{1.612615, 0.389176, 0.002712},{
      1.610768, 0.391023, 0.002712},{1.610957, 0.391283, 0.001373}}],
    Polygon[{{1.612615, 0.389176, 0.002712},{1.612189, 0.388866, 0.003984},{
      1.610458, 0.390596, 0.003984},{1.610768, 0.391023, 0.002712}}],
    Polygon[{{1.612189, 0.388866, 0.003984},{1.611606, 0.388443, 0.005159},{
      1.610036, 0.390014, 0.005159},{1.610458, 0.390596, 0.003984}}],
    Polygon[{{1.611606, 0.388443, 0.005159},{1.610883, 0.387918, 0.006206},{
      1.609510, 0.389291, 0.006206},{1.610036, 0.390014, 0.005159}}],
    Polygon[{{1.610883, 0.387918, 0.006206},{1.610036, 0.387302, 0.007100},{
      1.608894, 0.388443, 0.007100},{1.609510, 0.389291, 0.006206}}],
    Polygon[{{1.610036, 0.387302, 0.007100},{1.609086, 0.386612, 0.007820},{
      1.608204, 0.387493, 0.007820},{1.608894, 0.388443, 0.007100}}],
    Polygon[{{1.609086, 0.386612, 0.007820},{1.608056, 0.385864, 0.008347},{
      1.607456, 0.386464, 0.008347},{1.608204, 0.387493, 0.007820}}],
    Polygon[{{1.608056, 0.385864, 0.008347},{1.606973, 0.385077, 0.008668},{
      1.606669, 0.385381, 0.008668},{1.607456, 0.386464, 0.008347}}],
    Polygon[{{1.606669, 0.385381, -0.008668},{1.607456, 0.386464, -0.008347},{
      1.606700, 0.386849, -0.008347},{1.606286, 0.385576, -0.008668}}],
    Polygon[{{1.607456, 0.386464, -0.008347},{1.608204, 0.387493, -0.007820},{
      1.607093, 0.388059, -0.007820},{1.606700, 0.386849, -0.008347}}],
    Polygon[{{1.608204, 0.387493, -0.007820},{1.608894, 0.388443, -0.007100},{
      1.607456, 0.389176, -0.007100},{1.607093, 0.388059, -0.007820}}],
    Polygon[{{1.608894, 0.388443, -0.007100},{1.609510, 0.389291, -0.006206},{
      1.607780, 0.390172, -0.006206},{1.607456, 0.389176, -0.007100}}],
    Polygon[{{1.609510, 0.389291, -0.006206},{1.610036, 0.390014, -0.005159},{
      1.608056, 0.391023, -0.005159},{1.607780, 0.390172, -0.006206}}],
    Polygon[{{1.610036, 0.390014, -0.005159},{1.610458, 0.390596, -0.003984},{
      1.608279, 0.391707, -0.003984},{1.608056, 0.391023, -0.005159}}],
    Polygon[{{1.610458, 0.390596, -0.003984},{1.610768, 0.391023, -0.002712},{
      1.608441, 0.392208, -0.002712},{1.608279, 0.391707, -0.003984}}],
    Polygon[{{1.610768, 0.391023, -0.002712},{1.610957, 0.391283, -0.001373},{
      1.608541, 0.392514, -0.001373},{1.608441, 0.392208, -0.002712}}],
    Polygon[{{1.610957, 0.391283, -0.001373},{1.611021, 0.391370, 0.000000},{
      1.608574, 0.392617, 0.000000},{1.608541, 0.392514, -0.001373}}],
    Polygon[{{1.611021, 0.391370, 0.000000},{1.610957, 0.391283, 0.001373},{
      1.608541, 0.392514, 0.001373},{1.608574, 0.392617, 0.000000}}],
    Polygon[{{1.610957, 0.391283, 0.001373},{1.610768, 0.391023, 0.002712},{
      1.608441, 0.392208, 0.002712},{1.608541, 0.392514, 0.001373}}],
    Polygon[{{1.610768, 0.391023, 0.002712},{1.610458, 0.390596, 0.003984},{
      1.608279, 0.391707, 0.003984},{1.608441, 0.392208, 0.002712}}],
    Polygon[{{1.610458, 0.390596, 0.003984},{1.610036, 0.390014, 0.005159},{
      1.608056, 0.391023, 0.005159},{1.608279, 0.391707, 0.003984}}],
    Polygon[{{1.610036, 0.390014, 0.005159},{1.609510, 0.389291, 0.006206},{
      1.607780, 0.390172, 0.006206},{1.608056, 0.391023, 0.005159}}],
    Polygon[{{1.609510, 0.389291, 0.006206},{1.608894, 0.388443, 0.007100},{
      1.607456, 0.389176, 0.007100},{1.607780, 0.390172, 0.006206}}],
    Polygon[{{1.608894, 0.388443, 0.007100},{1.608204, 0.387493, 0.007820},{
      1.607093, 0.388059, 0.007820},{1.607456, 0.389176, 0.007100}}],
    Polygon[{{1.608204, 0.387493, 0.007820},{1.607456, 0.386464, 0.008347},{
      1.606700, 0.386849, 0.008347},{1.607093, 0.388059, 0.007820}}],
    Polygon[{{1.607456, 0.386464, 0.008347},{1.606669, 0.385381, 0.008668},{
      1.606286, 0.385576, 0.008668},{1.606700, 0.386849, 0.008347}}],
    Polygon[{{1.606286, 0.385576, -0.008668},{1.606700, 0.386849, -0.008347},{
      1.605862, 0.386982, -0.008347},{1.605862, 0.385643, -0.008668}}],
    Polygon[{{1.606700, 0.386849, -0.008347},{1.607093, 0.388059, -0.007820},{
      1.605862, 0.388254, -0.007820},{1.605862, 0.386982, -0.008347}}],
    Polygon[{{1.607093, 0.388059, -0.007820},{1.607456, 0.389176, -0.007100},{
      1.605862, 0.389429, -0.007100},{1.605862, 0.388254, -0.007820}}],
    Polygon[{{1.607456, 0.389176, -0.007100},{1.607780, 0.390172, -0.006206},{
      1.605862, 0.390476, -0.006206},{1.605862, 0.389429, -0.007100}}],
    Polygon[{{1.607780, 0.390172, -0.006206},{1.608056, 0.391023, -0.005159},{
      1.605862, 0.391370, -0.005159},{1.605862, 0.390476, -0.006206}}],
    Polygon[{{1.608056, 0.391023, -0.005159},{1.608279, 0.391707, -0.003984},{
      1.605862, 0.392090, -0.003984},{1.605862, 0.391370, -0.005159}}],
    Polygon[{{1.608279, 0.391707, -0.003984},{1.608441, 0.392208, -0.002712},{
      1.605862, 0.392617, -0.002712},{1.605862, 0.392090, -0.003984}}],
    Polygon[{{1.608441, 0.392208, -0.002712},{1.608541, 0.392514, -0.001373},{
      1.605862, 0.392938, -0.001373},{1.605862, 0.392617, -0.002712}}],
    Polygon[{{1.608541, 0.392514, -0.001373},{1.608574, 0.392617, 0.000000},{
      1.605862, 0.393046, 0.000000},{1.605862, 0.392938, -0.001373}}],
    Polygon[{{1.608574, 0.392617, 0.000000},{1.608541, 0.392514, 0.001373},{
      1.605862, 0.392938, 0.001373},{1.605862, 0.393046, 0.000000}}],
    Polygon[{{1.608541, 0.392514, 0.001373},{1.608441, 0.392208, 0.002712},{
      1.605862, 0.392617, 0.002712},{1.605862, 0.392938, 0.001373}}],
    Polygon[{{1.608441, 0.392208, 0.002712},{1.608279, 0.391707, 0.003984},{
      1.605862, 0.392090, 0.003984},{1.605862, 0.392617, 0.002712}}],
    Polygon[{{1.608279, 0.391707, 0.003984},{1.608056, 0.391023, 0.005159},{
      1.605862, 0.391370, 0.005159},{1.605862, 0.392090, 0.003984}}],
    Polygon[{{1.608056, 0.391023, 0.005159},{1.607780, 0.390172, 0.006206},{
      1.605862, 0.390476, 0.006206},{1.605862, 0.391370, 0.005159}}],
    Polygon[{{1.607780, 0.390172, 0.006206},{1.607456, 0.389176, 0.007100},{
      1.605862, 0.389429, 0.007100},{1.605862, 0.390476, 0.006206}}],
    Polygon[{{1.607456, 0.389176, 0.007100},{1.607093, 0.388059, 0.007820},{
      1.605862, 0.388254, 0.007820},{1.605862, 0.389429, 0.007100}}],
    Polygon[{{1.607093, 0.388059, 0.007820},{1.606700, 0.386849, 0.008347},{
      1.605862, 0.386982, 0.008347},{1.605862, 0.388254, 0.007820}}],
    Polygon[{{1.606700, 0.386849, 0.008347},{1.606286, 0.385576, 0.008668},{
      1.605862, 0.385643, 0.008668},{1.605862, 0.386982, 0.008347}}],
    Polygon[{{1.605862, 0.385643, -0.008668},{1.605862, 0.386982, -0.008347},{
      1.605024, 0.386849, -0.008347},{1.605438, 0.385576, -0.008668}}],
    Polygon[{{1.605862, 0.386982, -0.008347},{1.605862, 0.388254, -0.007820},{
      1.604631, 0.388059, -0.007820},{1.605024, 0.386849, -0.008347}}],
    Polygon[{{1.605862, 0.388254, -0.007820},{1.605862, 0.389429, -0.007100},{
      1.604268, 0.389176, -0.007100},{1.604631, 0.388059, -0.007820}}],
    Polygon[{{1.605862, 0.389429, -0.007100},{1.605862, 0.390476, -0.006206},{
      1.603944, 0.390172, -0.006206},{1.604268, 0.389176, -0.007100}}],
    Polygon[{{1.605862, 0.390476, -0.006206},{1.605862, 0.391370, -0.005159},{
      1.603668, 0.391023, -0.005159},{1.603944, 0.390172, -0.006206}}],
    Polygon[{{1.605862, 0.391370, -0.005159},{1.605862, 0.392090, -0.003984},{
      1.603446, 0.391707, -0.003984},{1.603668, 0.391023, -0.005159}}],
    Polygon[{{1.605862, 0.392090, -0.003984},{1.605862, 0.392617, -0.002712},{
      1.603283, 0.392208, -0.002712},{1.603446, 0.391707, -0.003984}}],
    Polygon[{{1.605862, 0.392617, -0.002712},{1.605862, 0.392938, -0.001373},{
      1.603184, 0.392514, -0.001373},{1.603283, 0.392208, -0.002712}}],
    Polygon[{{1.605862, 0.392938, -0.001373},{1.605862, 0.393046, 0.000000},{
      1.603150, 0.392617, 0.000000},{1.603184, 0.392514, -0.001373}}],
    Polygon[{{1.605862, 0.393046, 0.000000},{1.605862, 0.392938, 0.001373},{
      1.603184, 0.392514, 0.001373},{1.603150, 0.392617, 0.000000}}],
    Polygon[{{1.605862, 0.392938, 0.001373},{1.605862, 0.392617, 0.002712},{
      1.603283, 0.392208, 0.002712},{1.603184, 0.392514, 0.001373}}],
    Polygon[{{1.605862, 0.392617, 0.002712},{1.605862, 0.392090, 0.003984},{
      1.603446, 0.391707, 0.003984},{1.603283, 0.392208, 0.002712}}],
    Polygon[{{1.605862, 0.392090, 0.003984},{1.605862, 0.391370, 0.005159},{
      1.603668, 0.391023, 0.005159},{1.603446, 0.391707, 0.003984}}],
    Polygon[{{1.605862, 0.391370, 0.005159},{1.605862, 0.390476, 0.006206},{
      1.603944, 0.390172, 0.006206},{1.603668, 0.391023, 0.005159}}],
    Polygon[{{1.605862, 0.390476, 0.006206},{1.605862, 0.389429, 0.007100},{
      1.604268, 0.389176, 0.007100},{1.603944, 0.390172, 0.006206}}],
    Polygon[{{1.605862, 0.389429, 0.007100},{1.605862, 0.388254, 0.007820},{
      1.604631, 0.388059, 0.007820},{1.604268, 0.389176, 0.007100}}],
    Polygon[{{1.605862, 0.388254, 0.007820},{1.605862, 0.386982, 0.008347},{
      1.605024, 0.386849, 0.008347},{1.604631, 0.388059, 0.007820}}],
    Polygon[{{1.605862, 0.386982, 0.008347},{1.605862, 0.385643, 0.008668},{
      1.605438, 0.385576, 0.008668},{1.605024, 0.386849, 0.008347}}],
    Polygon[{{1.605438, 0.385576, -0.008668},{1.605024, 0.386849, -0.008347},{
      1.604268, 0.386464, -0.008347},{1.605055, 0.385381, -0.008668}}],
    Polygon[{{1.605024, 0.386849, -0.008347},{1.604631, 0.388059, -0.007820},{
      1.603520, 0.387493, -0.007820},{1.604268, 0.386464, -0.008347}}],
    Polygon[{{1.604631, 0.388059, -0.007820},{1.604268, 0.389176, -0.007100},{
      1.602830, 0.388443, -0.007100},{1.603520, 0.387493, -0.007820}}],
    Polygon[{{1.604268, 0.389176, -0.007100},{1.603944, 0.390172, -0.006206},{
      1.602214, 0.389291, -0.006206},{1.602830, 0.388443, -0.007100}}],
    Polygon[{{1.603944, 0.390172, -0.006206},{1.603668, 0.391023, -0.005159},{
      1.601689, 0.390014, -0.005159},{1.602214, 0.389291, -0.006206}}],
    Polygon[{{1.603668, 0.391023, -0.005159},{1.603446, 0.391707, -0.003984},{
      1.601266, 0.390596, -0.003984},{1.601689, 0.390014, -0.005159}}],
    Polygon[{{1.603446, 0.391707, -0.003984},{1.603283, 0.392208, -0.002712},{
      1.600956, 0.391023, -0.002712},{1.601266, 0.390596, -0.003984}}],
    Polygon[{{1.603283, 0.392208, -0.002712},{1.603184, 0.392514, -0.001373},{
      1.600767, 0.391283, -0.001373},{1.600956, 0.391023, -0.002712}}],
    Polygon[{{1.603184, 0.392514, -0.001373},{1.603150, 0.392617, 0.000000},{
      1.600704, 0.391370, 0.000000},{1.600767, 0.391283, -0.001373}}],
    Polygon[{{1.603150, 0.392617, 0.000000},{1.603184, 0.392514, 0.001373},{
      1.600767, 0.391283, 0.001373},{1.600704, 0.391370, 0.000000}}],
    Polygon[{{1.603184, 0.392514, 0.001373},{1.603283, 0.392208, 0.002712},{
      1.600956, 0.391023, 0.002712},{1.600767, 0.391283, 0.001373}}],
    Polygon[{{1.603283, 0.392208, 0.002712},{1.603446, 0.391707, 0.003984},{
      1.601266, 0.390596, 0.003984},{1.600956, 0.391023, 0.002712}}],
    Polygon[{{1.603446, 0.391707, 0.003984},{1.603668, 0.391023, 0.005159},{
      1.601689, 0.390014, 0.005159},{1.601266, 0.390596, 0.003984}}],
    Polygon[{{1.603668, 0.391023, 0.005159},{1.603944, 0.390172, 0.006206},{
      1.602214, 0.389291, 0.006206},{1.601689, 0.390014, 0.005159}}],
    Polygon[{{1.603944, 0.390172, 0.006206},{1.604268, 0.389176, 0.007100},{
      1.602830, 0.388443, 0.007100},{1.602214, 0.389291, 0.006206}}],
    Polygon[{{1.604268, 0.389176, 0.007100},{1.604631, 0.388059, 0.007820},{
      1.603520, 0.387493, 0.007820},{1.602830, 0.388443, 0.007100}}],
    Polygon[{{1.604631, 0.388059, 0.007820},{1.605024, 0.386849, 0.008347},{
      1.604268, 0.386464, 0.008347},{1.603520, 0.387493, 0.007820}}],
    Polygon[{{1.605024, 0.386849, 0.008347},{1.605438, 0.385576, 0.008668},{
      1.605055, 0.385381, 0.008668},{1.604268, 0.386464, 0.008347}}],
    Polygon[{{1.605055, 0.385381, -0.008668},{1.604268, 0.386464, -0.008347},{
      1.603668, 0.385864, -0.008347},{1.604751, 0.385077, -0.008668}}],
    Polygon[{{1.604268, 0.386464, -0.008347},{1.603520, 0.387493, -0.007820},{
      1.602639, 0.386612, -0.007820},{1.603668, 0.385864, -0.008347}}],
    Polygon[{{1.603520, 0.387493, -0.007820},{1.602830, 0.388443, -0.007100},{
      1.601689, 0.387302, -0.007100},{1.602639, 0.386612, -0.007820}}],
    Polygon[{{1.602830, 0.388443, -0.007100},{1.602214, 0.389291, -0.006206},{
      1.600842, 0.387918, -0.006206},{1.601689, 0.387302, -0.007100}}],
    Polygon[{{1.602214, 0.389291, -0.006206},{1.601689, 0.390014, -0.005159},{
      1.600118, 0.388443, -0.005159},{1.600842, 0.387918, -0.006206}}],
    Polygon[{{1.601689, 0.390014, -0.005159},{1.601266, 0.390596, -0.003984},{
      1.599536, 0.388866, -0.003984},{1.600118, 0.388443, -0.005159}}],
    Polygon[{{1.601266, 0.390596, -0.003984},{1.600956, 0.391023, -0.002712},{
      1.599109, 0.389176, -0.002712},{1.599536, 0.388866, -0.003984}}],
    Polygon[{{1.600956, 0.391023, -0.002712},{1.600767, 0.391283, -0.001373},{
      1.598849, 0.389365, -0.001373},{1.599109, 0.389176, -0.002712}}],
    Polygon[{{1.600767, 0.391283, -0.001373},{1.600704, 0.391370, 0.000000},{
      1.598762, 0.389429, 0.000000},{1.598849, 0.389365, -0.001373}}],
    Polygon[{{1.600704, 0.391370, 0.000000},{1.600767, 0.391283, 0.001373},{
      1.598849, 0.389365, 0.001373},{1.598762, 0.389429, 0.000000}}],
    Polygon[{{1.600767, 0.391283, 0.001373},{1.600956, 0.391023, 0.002712},{
      1.599109, 0.389176, 0.002712},{1.598849, 0.389365, 0.001373}}],
    Polygon[{{1.600956, 0.391023, 0.002712},{1.601266, 0.390596, 0.003984},{
      1.599536, 0.388866, 0.003984},{1.599109, 0.389176, 0.002712}}],
    Polygon[{{1.601266, 0.390596, 0.003984},{1.601689, 0.390014, 0.005159},{
      1.600118, 0.388443, 0.005159},{1.599536, 0.388866, 0.003984}}],
    Polygon[{{1.601689, 0.390014, 0.005159},{1.602214, 0.389291, 0.006206},{
      1.600842, 0.387918, 0.006206},{1.600118, 0.388443, 0.005159}}],
    Polygon[{{1.602214, 0.389291, 0.006206},{1.602830, 0.388443, 0.007100},{
      1.601689, 0.387302, 0.007100},{1.600842, 0.387918, 0.006206}}],
    Polygon[{{1.602830, 0.388443, 0.007100},{1.603520, 0.387493, 0.007820},{
      1.602639, 0.386612, 0.007820},{1.601689, 0.387302, 0.007100}}],
    Polygon[{{1.603520, 0.387493, 0.007820},{1.604268, 0.386464, 0.008347},{
      1.603668, 0.385864, 0.008347},{1.602639, 0.386612, 0.007820}}],
    Polygon[{{1.604268, 0.386464, 0.008347},{1.605055, 0.385381, 0.008668},{
      1.604751, 0.385077, 0.008668},{1.603668, 0.385864, 0.008347}}],
    Polygon[{{1.604751, 0.385077, -0.008668},{1.603668, 0.385864, -0.008347},{
      1.603283, 0.385108, -0.008347},{1.604556, 0.384694, -0.008668}}],
    Polygon[{{1.603668, 0.385864, -0.008347},{1.602639, 0.386612, -0.007820},{
      1.602073, 0.385501, -0.007820},{1.603283, 0.385108, -0.008347}}],
    Polygon[{{1.602639, 0.386612, -0.007820},{1.601689, 0.387302, -0.007100},{
      1.600956, 0.385864, -0.007100},{1.602073, 0.385501, -0.007820}}],
    Polygon[{{1.601689, 0.387302, -0.007100},{1.600842, 0.387918, -0.006206},{
      1.599960, 0.386188, -0.006206},{1.600956, 0.385864, -0.007100}}],
    Polygon[{{1.600842, 0.387918, -0.006206},{1.600118, 0.388443, -0.005159},{
      1.599109, 0.386464, -0.005159},{1.599960, 0.386188, -0.006206}}],
    Polygon[{{1.600118, 0.388443, -0.005159},{1.599536, 0.388866, -0.003984},{
      1.598425, 0.386687, -0.003984},{1.599109, 0.386464, -0.005159}}],
    Polygon[{{1.599536, 0.388866, -0.003984},{1.599109, 0.389176, -0.002712},{
      1.597924, 0.386849, -0.002712},{1.598425, 0.386687, -0.003984}}],
    Polygon[{{1.599109, 0.389176, -0.002712},{1.598849, 0.389365, -0.001373},{
      1.597618, 0.386949, -0.001373},{1.597924, 0.386849, -0.002712}}],
    Polygon[{{1.598849, 0.389365, -0.001373},{1.598762, 0.389429, 0.000000},{
      1.597515, 0.386982, 0.000000},{1.597618, 0.386949, -0.001373}}],
    Polygon[{{1.598762, 0.389429, 0.000000},{1.598849, 0.389365, 0.001373},{
      1.597618, 0.386949, 0.001373},{1.597515, 0.386982, 0.000000}}],
    Polygon[{{1.598849, 0.389365, 0.001373},{1.599109, 0.389176, 0.002712},{
      1.597924, 0.386849, 0.002712},{1.597618, 0.386949, 0.001373}}],
    Polygon[{{1.599109, 0.389176, 0.002712},{1.599536, 0.388866, 0.003984},{
      1.598425, 0.386687, 0.003984},{1.597924, 0.386849, 0.002712}}],
    Polygon[{{1.599536, 0.388866, 0.003984},{1.600118, 0.388443, 0.005159},{
      1.599109, 0.386464, 0.005159},{1.598425, 0.386687, 0.003984}}],
    Polygon[{{1.600118, 0.388443, 0.005159},{1.600842, 0.387918, 0.006206},{
      1.599960, 0.386188, 0.006206},{1.599109, 0.386464, 0.005159}}],
    Polygon[{{1.600842, 0.387918, 0.006206},{1.601689, 0.387302, 0.007100},{
      1.600956, 0.385864, 0.007100},{1.599960, 0.386188, 0.006206}}],
    Polygon[{{1.601689, 0.387302, 0.007100},{1.602639, 0.386612, 0.007820},{
      1.602073, 0.385501, 0.007820},{1.600956, 0.385864, 0.007100}}],
    Polygon[{{1.602639, 0.386612, 0.007820},{1.603668, 0.385864, 0.008347},{
      1.603283, 0.385108, 0.008347},{1.602073, 0.385501, 0.007820}}],
    Polygon[{{1.603668, 0.385864, 0.008347},{1.604751, 0.385077, 0.008668},{
      1.604556, 0.384694, 0.008668},{1.603283, 0.385108, 0.008347}}],
    Polygon[{{1.604556, 0.384694, -0.008668},{1.603283, 0.385108, -0.008347},{
      1.603150, 0.384270, -0.008347},{1.604489, 0.384270, -0.008668}}],
    Polygon[{{1.603283, 0.385108, -0.008347},{1.602073, 0.385501, -0.007820},{
      1.601878, 0.384270, -0.007820},{1.603150, 0.384270, -0.008347}}],
    Polygon[{{1.602073, 0.385501, -0.007820},{1.600956, 0.385864, -0.007100},{
      1.600704, 0.384270, -0.007100},{1.601878, 0.384270, -0.007820}}],
    Polygon[{{1.600956, 0.385864, -0.007100},{1.599960, 0.386188, -0.006206},{
      1.599656, 0.384270, -0.006206},{1.600704, 0.384270, -0.007100}}],
    Polygon[{{1.599960, 0.386188, -0.006206},{1.599109, 0.386464, -0.005159},{
      1.598762, 0.384270, -0.005159},{1.599656, 0.384270, -0.006206}}],
    Polygon[{{1.599109, 0.386464, -0.005159},{1.598425, 0.386687, -0.003984},{
      1.598042, 0.384270, -0.003984},{1.598762, 0.384270, -0.005159}}],
    Polygon[{{1.598425, 0.386687, -0.003984},{1.597924, 0.386849, -0.002712},{
      1.597515, 0.384270, -0.002712},{1.598042, 0.384270, -0.003984}}],
    Polygon[{{1.597924, 0.386849, -0.002712},{1.597618, 0.386949, -0.001373},{
      1.597194, 0.384270, -0.001373},{1.597515, 0.384270, -0.002712}}],
    Polygon[{{1.597618, 0.386949, -0.001373},{1.597515, 0.386982, 0.000000},{
      1.597086, 0.384270, 0.000000},{1.597194, 0.384270, -0.001373}}],
    Polygon[{{1.597515, 0.386982, 0.000000},{1.597618, 0.386949, 0.001373},{
      1.597194, 0.384270, 0.001373},{1.597086, 0.384270, 0.000000}}],
    Polygon[{{1.597618, 0.386949, 0.001373},{1.597924, 0.386849, 0.002712},{
      1.597515, 0.384270, 0.002712},{1.597194, 0.384270, 0.001373}}],
    Polygon[{{1.597924, 0.386849, 0.002712},{1.598425, 0.386687, 0.003984},{
      1.598042, 0.384270, 0.003984},{1.597515, 0.384270, 0.002712}}],
    Polygon[{{1.598425, 0.386687, 0.003984},{1.599109, 0.386464, 0.005159},{
      1.598762, 0.384270, 0.005159},{1.598042, 0.384270, 0.003984}}],
    Polygon[{{1.599109, 0.386464, 0.005159},{1.599960, 0.386188, 0.006206},{
      1.599656, 0.384270, 0.006206},{1.598762, 0.384270, 0.005159}}],
    Polygon[{{1.599960, 0.386188, 0.006206},{1.600956, 0.385864, 0.007100},{
      1.600704, 0.384270, 0.007100},{1.599656, 0.384270, 0.006206}}],
    Polygon[{{1.600956, 0.385864, 0.007100},{1.602073, 0.385501, 0.007820},{
      1.601878, 0.384270, 0.007820},{1.600704, 0.384270, 0.007100}}],
    Polygon[{{1.602073, 0.385501, 0.007820},{1.603283, 0.385108, 0.008347},{
      1.603150, 0.384270, 0.008347},{1.601878, 0.384270, 0.007820}}],
    Polygon[{{1.603283, 0.385108, 0.008347},{1.604556, 0.384694, 0.008668},{
      1.604489, 0.384270, 0.008668},{1.603150, 0.384270, 0.008347}}],
    Polygon[{{1.604489, 0.384270, -0.008668},{1.603150, 0.384270, -0.008347},{
      1.603283, 0.383432, -0.008347},{1.604556, 0.383846, -0.008668}}],
    Polygon[{{1.603150, 0.384270, -0.008347},{1.601878, 0.384270, -0.007820},{
      1.602073, 0.383039, -0.007820},{1.603283, 0.383432, -0.008347}}],
    Polygon[{{1.601878, 0.384270, -0.007820},{1.600704, 0.384270, -0.007100},{
      1.600956, 0.382676, -0.007100},{1.602073, 0.383039, -0.007820}}],
    Polygon[{{1.600704, 0.384270, -0.007100},{1.599656, 0.384270, -0.006206},{
      1.599960, 0.382352, -0.006206},{1.600956, 0.382676, -0.007100}}],
    Polygon[{{1.599656, 0.384270, -0.006206},{1.598762, 0.384270, -0.005159},{
      1.599109, 0.382076, -0.005159},{1.599960, 0.382352, -0.006206}}],
    Polygon[{{1.598762, 0.384270, -0.005159},{1.598042, 0.384270, -0.003984},{
      1.598425, 0.381854, -0.003984},{1.599109, 0.382076, -0.005159}}],
    Polygon[{{1.598042, 0.384270, -0.003984},{1.597515, 0.384270, -0.002712},{
      1.597924, 0.381691, -0.002712},{1.598425, 0.381854, -0.003984}}],
    Polygon[{{1.597515, 0.384270, -0.002712},{1.597194, 0.384270, -0.001373},{
      1.597618, 0.381591, -0.001373},{1.597924, 0.381691, -0.002712}}],
    Polygon[{{1.597194, 0.384270, -0.001373},{1.597086, 0.384270, 0.000000},{
      1.597515, 0.381558, 0.000000},{1.597618, 0.381591, -0.001373}}],
    Polygon[{{1.597086, 0.384270, 0.000000},{1.597194, 0.384270, 0.001373},{
      1.597618, 0.381591, 0.001373},{1.597515, 0.381558, 0.000000}}],
    Polygon[{{1.597194, 0.384270, 0.001373},{1.597515, 0.384270, 0.002712},{
      1.597924, 0.381691, 0.002712},{1.597618, 0.381591, 0.001373}}],
    Polygon[{{1.597515, 0.384270, 0.002712},{1.598042, 0.384270, 0.003984},{
      1.598425, 0.381854, 0.003984},{1.597924, 0.381691, 0.002712}}],
    Polygon[{{1.598042, 0.384270, 0.003984},{1.598762, 0.384270, 0.005159},{
      1.599109, 0.382076, 0.005159},{1.598425, 0.381854, 0.003984}}],
    Polygon[{{1.598762, 0.384270, 0.005159},{1.599656, 0.384270, 0.006206},{
      1.599960, 0.382352, 0.006206},{1.599109, 0.382076, 0.005159}}],
    Polygon[{{1.599656, 0.384270, 0.006206},{1.600704, 0.384270, 0.007100},{
      1.600956, 0.382676, 0.007100},{1.599960, 0.382352, 0.006206}}],
    Polygon[{{1.600704, 0.384270, 0.007100},{1.601878, 0.384270, 0.007820},{
      1.602073, 0.383039, 0.007820},{1.600956, 0.382676, 0.007100}}],
    Polygon[{{1.601878, 0.384270, 0.007820},{1.603150, 0.384270, 0.008347},{
      1.603283, 0.383432, 0.008347},{1.602073, 0.383039, 0.007820}}],
    Polygon[{{1.603150, 0.384270, 0.008347},{1.604489, 0.384270, 0.008668},{
      1.604556, 0.383846, 0.008668},{1.603283, 0.383432, 0.008347}}],
    Polygon[{{1.604556, 0.383846, -0.008668},{1.603283, 0.383432, -0.008347},{
      1.603668, 0.382676, -0.008347},{1.604751, 0.383463, -0.008668}}],
    Polygon[{{1.603283, 0.383432, -0.008347},{1.602073, 0.383039, -0.007820},{
      1.602639, 0.381928, -0.007820},{1.603668, 0.382676, -0.008347}}],
    Polygon[{{1.602073, 0.383039, -0.007820},{1.600956, 0.382676, -0.007100},{
      1.601689, 0.381238, -0.007100},{1.602639, 0.381928, -0.007820}}],
    Polygon[{{1.600956, 0.382676, -0.007100},{1.599960, 0.382352, -0.006206},{
      1.600842, 0.380622, -0.006206},{1.601689, 0.381238, -0.007100}}],
    Polygon[{{1.599960, 0.382352, -0.006206},{1.599109, 0.382076, -0.005159},{
      1.600118, 0.380097, -0.005159},{1.600842, 0.380622, -0.006206}}],
    Polygon[{{1.599109, 0.382076, -0.005159},{1.598425, 0.381854, -0.003984},{
      1.599536, 0.379674, -0.003984},{1.600118, 0.380097, -0.005159}}],
    Polygon[{{1.598425, 0.381854, -0.003984},{1.597924, 0.381691, -0.002712},{
      1.599109, 0.379364, -0.002712},{1.599536, 0.379674, -0.003984}}],
    Polygon[{{1.597924, 0.381691, -0.002712},{1.597618, 0.381591, -0.001373},{
      1.598849, 0.379175, -0.001373},{1.599109, 0.379364, -0.002712}}],
    Polygon[{{1.597618, 0.381591, -0.001373},{1.597515, 0.381558, 0.000000},{
      1.598762, 0.379111, 0.000000},{1.598849, 0.379175, -0.001373}}],
    Polygon[{{1.597515, 0.381558, 0.000000},{1.597618, 0.381591, 0.001373},{
      1.598849, 0.379175, 0.001373},{1.598762, 0.379111, 0.000000}}],
    Polygon[{{1.597618, 0.381591, 0.001373},{1.597924, 0.381691, 0.002712},{
      1.599109, 0.379364, 0.002712},{1.598849, 0.379175, 0.001373}}],
    Polygon[{{1.597924, 0.381691, 0.002712},{1.598425, 0.381854, 0.003984},{
      1.599536, 0.379674, 0.003984},{1.599109, 0.379364, 0.002712}}],
    Polygon[{{1.598425, 0.381854, 0.003984},{1.599109, 0.382076, 0.005159},{
      1.600118, 0.380097, 0.005159},{1.599536, 0.379674, 0.003984}}],
    Polygon[{{1.599109, 0.382076, 0.005159},{1.599960, 0.382352, 0.006206},{
      1.600842, 0.380622, 0.006206},{1.600118, 0.380097, 0.005159}}],
    Polygon[{{1.599960, 0.382352, 0.006206},{1.600956, 0.382676, 0.007100},{
      1.601689, 0.381238, 0.007100},{1.600842, 0.380622, 0.006206}}],
    Polygon[{{1.600956, 0.382676, 0.007100},{1.602073, 0.383039, 0.007820},{
      1.602639, 0.381928, 0.007820},{1.601689, 0.381238, 0.007100}}],
    Polygon[{{1.602073, 0.383039, 0.007820},{1.603283, 0.383432, 0.008347},{
      1.603668, 0.382676, 0.008347},{1.602639, 0.381928, 0.007820}}],
    Polygon[{{1.603283, 0.383432, 0.008347},{1.604556, 0.383846, 0.008668},{
      1.604751, 0.383463, 0.008668},{1.603668, 0.382676, 0.008347}}],
    Polygon[{{1.604751, 0.383463, -0.008668},{1.603668, 0.382676, -0.008347},{
      1.604268, 0.382076, -0.008347},{1.605055, 0.383159, -0.008668}}],
    Polygon[{{1.603668, 0.382676, -0.008347},{1.602639, 0.381928, -0.007820},{
      1.603520, 0.381047, -0.007820},{1.604268, 0.382076, -0.008347}}],
    Polygon[{{1.602639, 0.381928, -0.007820},{1.601689, 0.381238, -0.007100},{
      1.602830, 0.380097, -0.007100},{1.603520, 0.381047, -0.007820}}],
    Polygon[{{1.601689, 0.381238, -0.007100},{1.600842, 0.380622, -0.006206},{
      1.602214, 0.379249, -0.006206},{1.602830, 0.380097, -0.007100}}],
    Polygon[{{1.600842, 0.380622, -0.006206},{1.600118, 0.380097, -0.005159},{
      1.601689, 0.378526, -0.005159},{1.602214, 0.379249, -0.006206}}],
    Polygon[{{1.600118, 0.380097, -0.005159},{1.599536, 0.379674, -0.003984},{
      1.601266, 0.377944, -0.003984},{1.601689, 0.378526, -0.005159}}],
    Polygon[{{1.599536, 0.379674, -0.003984},{1.599109, 0.379364, -0.002712},{
      1.600956, 0.377517, -0.002712},{1.601266, 0.377944, -0.003984}}],
    Polygon[{{1.599109, 0.379364, -0.002712},{1.598849, 0.379175, -0.001373},{
      1.600767, 0.377257, -0.001373},{1.600956, 0.377517, -0.002712}}],
    Polygon[{{1.598849, 0.379175, -0.001373},{1.598762, 0.379111, 0.000000},{
      1.600704, 0.377170, 0.000000},{1.600767, 0.377257, -0.001373}}],
    Polygon[{{1.598762, 0.379111, 0.000000},{1.598849, 0.379175, 0.001373},{
      1.600767, 0.377257, 0.001373},{1.600704, 0.377170, 0.000000}}],
    Polygon[{{1.598849, 0.379175, 0.001373},{1.599109, 0.379364, 0.002712},{
      1.600956, 0.377517, 0.002712},{1.600767, 0.377257, 0.001373}}],
    Polygon[{{1.599109, 0.379364, 0.002712},{1.599536, 0.379674, 0.003984},{
      1.601266, 0.377944, 0.003984},{1.600956, 0.377517, 0.002712}}],
    Polygon[{{1.599536, 0.379674, 0.003984},{1.600118, 0.380097, 0.005159},{
      1.601689, 0.378526, 0.005159},{1.601266, 0.377944, 0.003984}}],
    Polygon[{{1.600118, 0.380097, 0.005159},{1.600842, 0.380622, 0.006206},{
      1.602214, 0.379249, 0.006206},{1.601689, 0.378526, 0.005159}}],
    Polygon[{{1.600842, 0.380622, 0.006206},{1.601689, 0.381238, 0.007100},{
      1.602830, 0.380097, 0.007100},{1.602214, 0.379249, 0.006206}}],
    Polygon[{{1.601689, 0.381238, 0.007100},{1.602639, 0.381928, 0.007820},{
      1.603520, 0.381047, 0.007820},{1.602830, 0.380097, 0.007100}}],
    Polygon[{{1.602639, 0.381928, 0.007820},{1.603668, 0.382676, 0.008347},{
      1.604268, 0.382076, 0.008347},{1.603520, 0.381047, 0.007820}}],
    Polygon[{{1.603668, 0.382676, 0.008347},{1.604751, 0.383463, 0.008668},{
      1.605055, 0.383159, 0.008668},{1.604268, 0.382076, 0.008347}}],
    Polygon[{{1.605055, 0.383159, -0.008668},{1.604268, 0.382076, -0.008347},{
      1.605024, 0.381691, -0.008347},{1.605438, 0.382964, -0.008668}}],
    Polygon[{{1.604268, 0.382076, -0.008347},{1.603520, 0.381047, -0.007820},{
      1.604631, 0.380481, -0.007820},{1.605024, 0.381691, -0.008347}}],
    Polygon[{{1.603520, 0.381047, -0.007820},{1.602830, 0.380097, -0.007100},{
      1.604268, 0.379364, -0.007100},{1.604631, 0.380481, -0.007820}}],
    Polygon[{{1.602830, 0.380097, -0.007100},{1.602214, 0.379249, -0.006206},{
      1.603944, 0.378368, -0.006206},{1.604268, 0.379364, -0.007100}}],
    Polygon[{{1.602214, 0.379249, -0.006206},{1.601689, 0.378526, -0.005159},{
      1.603668, 0.377517, -0.005159},{1.603944, 0.378368, -0.006206}}],
    Polygon[{{1.601689, 0.378526, -0.005159},{1.601266, 0.377944, -0.003984},{
      1.603446, 0.376833, -0.003984},{1.603668, 0.377517, -0.005159}}],
    Polygon[{{1.601266, 0.377944, -0.003984},{1.600956, 0.377517, -0.002712},{
      1.603283, 0.376332, -0.002712},{1.603446, 0.376833, -0.003984}}],
    Polygon[{{1.600956, 0.377517, -0.002712},{1.600767, 0.377257, -0.001373},{
      1.603184, 0.376026, -0.001373},{1.603283, 0.376332, -0.002712}}],
    Polygon[{{1.600767, 0.377257, -0.001373},{1.600704, 0.377170, 0.000000},{
      1.603150, 0.375923, 0.000000},{1.603184, 0.376026, -0.001373}}],
    Polygon[{{1.600704, 0.377170, 0.000000},{1.600767, 0.377257, 0.001373},{
      1.603184, 0.376026, 0.001373},{1.603150, 0.375923, 0.000000}}],
    Polygon[{{1.600767, 0.377257, 0.001373},{1.600956, 0.377517, 0.002712},{
      1.603283, 0.376332, 0.002712},{1.603184, 0.376026, 0.001373}}],
    Polygon[{{1.600956, 0.377517, 0.002712},{1.601266, 0.377944, 0.003984},{
      1.603446, 0.376833, 0.003984},{1.603283, 0.376332, 0.002712}}],
    Polygon[{{1.601266, 0.377944, 0.003984},{1.601689, 0.378526, 0.005159},{
      1.603668, 0.377517, 0.005159},{1.603446, 0.376833, 0.003984}}],
    Polygon[{{1.601689, 0.378526, 0.005159},{1.602214, 0.379249, 0.006206},{
      1.603944, 0.378368, 0.006206},{1.603668, 0.377517, 0.005159}}],
    Polygon[{{1.602214, 0.379249, 0.006206},{1.602830, 0.380097, 0.007100},{
      1.604268, 0.379364, 0.007100},{1.603944, 0.378368, 0.006206}}],
    Polygon[{{1.602830, 0.380097, 0.007100},{1.603520, 0.381047, 0.007820},{
      1.604631, 0.380481, 0.007820},{1.604268, 0.379364, 0.007100}}],
    Polygon[{{1.603520, 0.381047, 0.007820},{1.604268, 0.382076, 0.008347},{
      1.605024, 0.381691, 0.008347},{1.604631, 0.380481, 0.007820}}],
    Polygon[{{1.604268, 0.382076, 0.008347},{1.605055, 0.383159, 0.008668},{
      1.605438, 0.382964, 0.008668},{1.605024, 0.381691, 0.008347}}],
    Polygon[{{1.605438, 0.382964, -0.008668},{1.605024, 0.381691, -0.008347},{
      1.605862, 0.381558, -0.008347},{1.605862, 0.382897, -0.008668}}],
    Polygon[{{1.605024, 0.381691, -0.008347},{1.604631, 0.380481, -0.007820},{
      1.605862, 0.380286, -0.007820},{1.605862, 0.381558, -0.008347}}],
    Polygon[{{1.604631, 0.380481, -0.007820},{1.604268, 0.379364, -0.007100},{
      1.605862, 0.379111, -0.007100},{1.605862, 0.380286, -0.007820}}],
    Polygon[{{1.604268, 0.379364, -0.007100},{1.603944, 0.378368, -0.006206},{
      1.605862, 0.378064, -0.006206},{1.605862, 0.379111, -0.007100}}],
    Polygon[{{1.603944, 0.378368, -0.006206},{1.603668, 0.377517, -0.005159},{
      1.605862, 0.377170, -0.005159},{1.605862, 0.378064, -0.006206}}],
    Polygon[{{1.603668, 0.377517, -0.005159},{1.603446, 0.376833, -0.003984},{
      1.605862, 0.376450, -0.003984},{1.605862, 0.377170, -0.005159}}],
    Polygon[{{1.603446, 0.376833, -0.003984},{1.603283, 0.376332, -0.002712},{
      1.605862, 0.375923, -0.002712},{1.605862, 0.376450, -0.003984}}],
    Polygon[{{1.603283, 0.376332, -0.002712},{1.603184, 0.376026, -0.001373},{
      1.605862, 0.375602, -0.001373},{1.605862, 0.375923, -0.002712}}],
    Polygon[{{1.603184, 0.376026, -0.001373},{1.603150, 0.375923, 0.000000},{
      1.605862, 0.375494, 0.000000},{1.605862, 0.375602, -0.001373}}],
    Polygon[{{1.603150, 0.375923, 0.000000},{1.603184, 0.376026, 0.001373},{
      1.605862, 0.375602, 0.001373},{1.605862, 0.375494, 0.000000}}],
    Polygon[{{1.603184, 0.376026, 0.001373},{1.603283, 0.376332, 0.002712},{
      1.605862, 0.375923, 0.002712},{1.605862, 0.375602, 0.001373}}],
    Polygon[{{1.603283, 0.376332, 0.002712},{1.603446, 0.376833, 0.003984},{
      1.605862, 0.376450, 0.003984},{1.605862, 0.375923, 0.002712}}],
    Polygon[{{1.603446, 0.376833, 0.003984},{1.603668, 0.377517, 0.005159},{
      1.605862, 0.377170, 0.005159},{1.605862, 0.376450, 0.003984}}],
    Polygon[{{1.603668, 0.377517, 0.005159},{1.603944, 0.378368, 0.006206},{
      1.605862, 0.378064, 0.006206},{1.605862, 0.377170, 0.005159}}],
    Polygon[{{1.603944, 0.378368, 0.006206},{1.604268, 0.379364, 0.007100},{
      1.605862, 0.379111, 0.007100},{1.605862, 0.378064, 0.006206}}],
    Polygon[{{1.604268, 0.379364, 0.007100},{1.604631, 0.380481, 0.007820},{
      1.605862, 0.380286, 0.007820},{1.605862, 0.379111, 0.007100}}],
    Polygon[{{1.604631, 0.380481, 0.007820},{1.605024, 0.381691, 0.008347},{
      1.605862, 0.381558, 0.008347},{1.605862, 0.380286, 0.007820}}],
    Polygon[{{1.605024, 0.381691, 0.008347},{1.605438, 0.382964, 0.008668},{
      1.605862, 0.382897, 0.008668},{1.605862, 0.381558, 0.008347}}],
    Polygon[{{1.605862, 0.382897, -0.008668},{1.605862, 0.381558, -0.008347},{
      1.606700, 0.381691, -0.008347},{1.606286, 0.382964, -0.008668}}],
    Polygon[{{1.605862, 0.381558, -0.008347},{1.605862, 0.380286, -0.007820},{
      1.607093, 0.380481, -0.007820},{1.606700, 0.381691, -0.008347}}],
    Polygon[{{1.605862, 0.380286, -0.007820},{1.605862, 0.379111, -0.007100},{
      1.607456, 0.379364, -0.007100},{1.607093, 0.380481, -0.007820}}],
    Polygon[{{1.605862, 0.379111, -0.007100},{1.605862, 0.378064, -0.006206},{
      1.607780, 0.378368, -0.006206},{1.607456, 0.379364, -0.007100}}],
    Polygon[{{1.605862, 0.378064, -0.006206},{1.605862, 0.377170, -0.005159},{
      1.608056, 0.377517, -0.005159},{1.607780, 0.378368, -0.006206}}],
    Polygon[{{1.605862, 0.377170, -0.005159},{1.605862, 0.376450, -0.003984},{
      1.608279, 0.376833, -0.003984},{1.608056, 0.377517, -0.005159}}],
    Polygon[{{1.605862, 0.376450, -0.003984},{1.605862, 0.375923, -0.002712},{
      1.608441, 0.376332, -0.002712},{1.608279, 0.376833, -0.003984}}],
    Polygon[{{1.605862, 0.375923, -0.002712},{1.605862, 0.375602, -0.001373},{
      1.608541, 0.376026, -0.001373},{1.608441, 0.376332, -0.002712}}],
    Polygon[{{1.605862, 0.375602, -0.001373},{1.605862, 0.375494, 0.000000},{
      1.608574, 0.375923, 0.000000},{1.608541, 0.376026, -0.001373}}],
    Polygon[{{1.605862, 0.375494, 0.000000},{1.605862, 0.375602, 0.001373},{
      1.608541, 0.376026, 0.001373},{1.608574, 0.375923, 0.000000}}],
    Polygon[{{1.605862, 0.375602, 0.001373},{1.605862, 0.375923, 0.002712},{
      1.608441, 0.376332, 0.002712},{1.608541, 0.376026, 0.001373}}],
    Polygon[{{1.605862, 0.375923, 0.002712},{1.605862, 0.376450, 0.003984},{
      1.608279, 0.376833, 0.003984},{1.608441, 0.376332, 0.002712}}],
    Polygon[{{1.605862, 0.376450, 0.003984},{1.605862, 0.377170, 0.005159},{
      1.608056, 0.377517, 0.005159},{1.608279, 0.376833, 0.003984}}],
    Polygon[{{1.605862, 0.377170, 0.005159},{1.605862, 0.378064, 0.006206},{
      1.607780, 0.378368, 0.006206},{1.608056, 0.377517, 0.005159}}],
    Polygon[{{1.605862, 0.378064, 0.006206},{1.605862, 0.379111, 0.007100},{
      1.607456, 0.379364, 0.007100},{1.607780, 0.378368, 0.006206}}],
    Polygon[{{1.605862, 0.379111, 0.007100},{1.605862, 0.380286, 0.007820},{
      1.607093, 0.380481, 0.007820},{1.607456, 0.379364, 0.007100}}],
    Polygon[{{1.605862, 0.380286, 0.007820},{1.605862, 0.381558, 0.008347},{
      1.606700, 0.381691, 0.008347},{1.607093, 0.380481, 0.007820}}],
    Polygon[{{1.605862, 0.381558, 0.008347},{1.605862, 0.382897, 0.008668},{
      1.606286, 0.382964, 0.008668},{1.606700, 0.381691, 0.008347}}],
    Polygon[{{1.606286, 0.382964, -0.008668},{1.606700, 0.381691, -0.008347},{
      1.607456, 0.382076, -0.008347},{1.606669, 0.383159, -0.008668}}],
    Polygon[{{1.606700, 0.381691, -0.008347},{1.607093, 0.380481, -0.007820},{
      1.608204, 0.381047, -0.007820},{1.607456, 0.382076, -0.008347}}],
    Polygon[{{1.607093, 0.380481, -0.007820},{1.607456, 0.379364, -0.007100},{
      1.608894, 0.380097, -0.007100},{1.608204, 0.381047, -0.007820}}],
    Polygon[{{1.607456, 0.379364, -0.007100},{1.607780, 0.378368, -0.006206},{
      1.609510, 0.379249, -0.006206},{1.608894, 0.380097, -0.007100}}],
    Polygon[{{1.607780, 0.378368, -0.006206},{1.608056, 0.377517, -0.005159},{
      1.610036, 0.378526, -0.005159},{1.609510, 0.379249, -0.006206}}],
    Polygon[{{1.608056, 0.377517, -0.005159},{1.608279, 0.376833, -0.003984},{
      1.610458, 0.377944, -0.003984},{1.610036, 0.378526, -0.005159}}],
    Polygon[{{1.608279, 0.376833, -0.003984},{1.608441, 0.376332, -0.002712},{
      1.610768, 0.377517, -0.002712},{1.610458, 0.377944, -0.003984}}],
    Polygon[{{1.608441, 0.376332, -0.002712},{1.608541, 0.376026, -0.001373},{
      1.610957, 0.377257, -0.001373},{1.610768, 0.377517, -0.002712}}],
    Polygon[{{1.608541, 0.376026, -0.001373},{1.608574, 0.375923, 0.000000},{
      1.611021, 0.377170, 0.000000},{1.610957, 0.377257, -0.001373}}],
    Polygon[{{1.608574, 0.375923, 0.000000},{1.608541, 0.376026, 0.001373},{
      1.610957, 0.377257, 0.001373},{1.611021, 0.377170, 0.000000}}],
    Polygon[{{1.608541, 0.376026, 0.001373},{1.608441, 0.376332, 0.002712},{
      1.610768, 0.377517, 0.002712},{1.610957, 0.377257, 0.001373}}],
    Polygon[{{1.608441, 0.376332, 0.002712},{1.608279, 0.376833, 0.003984},{
      1.610458, 0.377944, 0.003984},{1.610768, 0.377517, 0.002712}}],
    Polygon[{{1.608279, 0.376833, 0.003984},{1.608056, 0.377517, 0.005159},{
      1.610036, 0.378526, 0.005159},{1.610458, 0.377944, 0.003984}}],
    Polygon[{{1.608056, 0.377517, 0.005159},{1.607780, 0.378368, 0.006206},{
      1.609510, 0.379249, 0.006206},{1.610036, 0.378526, 0.005159}}],
    Polygon[{{1.607780, 0.378368, 0.006206},{1.607456, 0.379364, 0.007100},{
      1.608894, 0.380097, 0.007100},{1.609510, 0.379249, 0.006206}}],
    Polygon[{{1.607456, 0.379364, 0.007100},{1.607093, 0.380481, 0.007820},{
      1.608204, 0.381047, 0.007820},{1.608894, 0.380097, 0.007100}}],
    Polygon[{{1.607093, 0.380481, 0.007820},{1.606700, 0.381691, 0.008347},{
      1.607456, 0.382076, 0.008347},{1.608204, 0.381047, 0.007820}}],
    Polygon[{{1.606700, 0.381691, 0.008347},{1.606286, 0.382964, 0.008668},{
      1.606669, 0.383159, 0.008668},{1.607456, 0.382076, 0.008347}}],
    Polygon[{{1.606669, 0.383159, -0.008668},{1.607456, 0.382076, -0.008347},{
      1.608056, 0.382676, -0.008347},{1.606973, 0.383463, -0.008668}}],
    Polygon[{{1.607456, 0.382076, -0.008347},{1.608204, 0.381047, -0.007820},{
      1.609086, 0.381928, -0.007820},{1.608056, 0.382676, -0.008347}}],
    Polygon[{{1.608204, 0.381047, -0.007820},{1.608894, 0.380097, -0.007100},{
      1.610036, 0.381238, -0.007100},{1.609086, 0.381928, -0.007820}}],
    Polygon[{{1.608894, 0.380097, -0.007100},{1.609510, 0.379249, -0.006206},{
      1.610883, 0.380622, -0.006206},{1.610036, 0.381238, -0.007100}}],
    Polygon[{{1.609510, 0.379249, -0.006206},{1.610036, 0.378526, -0.005159},{
      1.611606, 0.380097, -0.005159},{1.610883, 0.380622, -0.006206}}],
    Polygon[{{1.610036, 0.378526, -0.005159},{1.610458, 0.377944, -0.003984},{
      1.612189, 0.379674, -0.003984},{1.611606, 0.380097, -0.005159}}],
    Polygon[{{1.610458, 0.377944, -0.003984},{1.610768, 0.377517, -0.002712},{
      1.612615, 0.379364, -0.002712},{1.612189, 0.379674, -0.003984}}],
    Polygon[{{1.610768, 0.377517, -0.002712},{1.610957, 0.377257, -0.001373},{
      1.612875, 0.379175, -0.001373},{1.612615, 0.379364, -0.002712}}],
    Polygon[{{1.610957, 0.377257, -0.001373},{1.611021, 0.377170, 0.000000},{
      1.612962, 0.379111, 0.000000},{1.612875, 0.379175, -0.001373}}],
    Polygon[{{1.611021, 0.377170, 0.000000},{1.610957, 0.377257, 0.001373},{
      1.612875, 0.379175, 0.001373},{1.612962, 0.379111, 0.000000}}],
    Polygon[{{1.610957, 0.377257, 0.001373},{1.610768, 0.377517, 0.002712},{
      1.612615, 0.379364, 0.002712},{1.612875, 0.379175, 0.001373}}],
    Polygon[{{1.610768, 0.377517, 0.002712},{1.610458, 0.377944, 0.003984},{
      1.612189, 0.379674, 0.003984},{1.612615, 0.379364, 0.002712}}],
    Polygon[{{1.610458, 0.377944, 0.003984},{1.610036, 0.378526, 0.005159},{
      1.611606, 0.380097, 0.005159},{1.612189, 0.379674, 0.003984}}],
    Polygon[{{1.610036, 0.378526, 0.005159},{1.609510, 0.379249, 0.006206},{
      1.610883, 0.380622, 0.006206},{1.611606, 0.380097, 0.005159}}],
    Polygon[{{1.609510, 0.379249, 0.006206},{1.608894, 0.380097, 0.007100},{
      1.610036, 0.381238, 0.007100},{1.610883, 0.380622, 0.006206}}],
    Polygon[{{1.608894, 0.380097, 0.007100},{1.608204, 0.381047, 0.007820},{
      1.609086, 0.381928, 0.007820},{1.610036, 0.381238, 0.007100}}],
    Polygon[{{1.608204, 0.381047, 0.007820},{1.607456, 0.382076, 0.008347},{
      1.608056, 0.382676, 0.008347},{1.609086, 0.381928, 0.007820}}],
    Polygon[{{1.607456, 0.382076, 0.008347},{1.606669, 0.383159, 0.008668},{
      1.606973, 0.383463, 0.008668},{1.608056, 0.382676, 0.008347}}],
    Polygon[{{1.606973, 0.383463, -0.008668},{1.608056, 0.382676, -0.008347},{
      1.608441, 0.383432, -0.008347},{1.607168, 0.383846, -0.008668}}],
    Polygon[{{1.608056, 0.382676, -0.008347},{1.609086, 0.381928, -0.007820},{
      1.609652, 0.383039, -0.007820},{1.608441, 0.383432, -0.008347}}],
    Polygon[{{1.609086, 0.381928, -0.007820},{1.610036, 0.381238, -0.007100},{
      1.610768, 0.382676, -0.007100},{1.609652, 0.383039, -0.007820}}],
    Polygon[{{1.610036, 0.381238, -0.007100},{1.610883, 0.380622, -0.006206},{
      1.611764, 0.382352, -0.006206},{1.610768, 0.382676, -0.007100}}],
    Polygon[{{1.610883, 0.380622, -0.006206},{1.611606, 0.380097, -0.005159},{
      1.612615, 0.382076, -0.005159},{1.611764, 0.382352, -0.006206}}],
    Polygon[{{1.611606, 0.380097, -0.005159},{1.612189, 0.379674, -0.003984},{
      1.613299, 0.381854, -0.003984},{1.612615, 0.382076, -0.005159}}],
    Polygon[{{1.612189, 0.379674, -0.003984},{1.612615, 0.379364, -0.002712},{
      1.613801, 0.381691, -0.002712},{1.613299, 0.381854, -0.003984}}],
    Polygon[{{1.612615, 0.379364, -0.002712},{1.612875, 0.379175, -0.001373},{
      1.614106, 0.381591, -0.001373},{1.613801, 0.381691, -0.002712}}],
    Polygon[{{1.612875, 0.379175, -0.001373},{1.612962, 0.379111, 0.000000},{
      1.614209, 0.381558, 0.000000},{1.614106, 0.381591, -0.001373}}],
    Polygon[{{1.612962, 0.379111, 0.000000},{1.612875, 0.379175, 0.001373},{
      1.614106, 0.381591, 0.001373},{1.614209, 0.381558, 0.000000}}],
    Polygon[{{1.612875, 0.379175, 0.001373},{1.612615, 0.379364, 0.002712},{
      1.613801, 0.381691, 0.002712},{1.614106, 0.381591, 0.001373}}],
    Polygon[{{1.612615, 0.379364, 0.002712},{1.612189, 0.379674, 0.003984},{
      1.613299, 0.381854, 0.003984},{1.613801, 0.381691, 0.002712}}],
    Polygon[{{1.612189, 0.379674, 0.003984},{1.611606, 0.380097, 0.005159},{
      1.612615, 0.382076, 0.005159},{1.613299, 0.381854, 0.003984}}],
    Polygon[{{1.611606, 0.380097, 0.005159},{1.610883, 0.380622, 0.006206},{
      1.611764, 0.382352, 0.006206},{1.612615, 0.382076, 0.005159}}],
    Polygon[{{1.610883, 0.380622, 0.006206},{1.610036, 0.381238, 0.007100},{
      1.610768, 0.382676, 0.007100},{1.611764, 0.382352, 0.006206}}],
    Polygon[{{1.610036, 0.381238, 0.007100},{1.609086, 0.381928, 0.007820},{
      1.609652, 0.383039, 0.007820},{1.610768, 0.382676, 0.007100}}],
    Polygon[{{1.609086, 0.381928, 0.007820},{1.608056, 0.382676, 0.008347},{
      1.608441, 0.383432, 0.008347},{1.609652, 0.383039, 0.007820}}],
    Polygon[{{1.608056, 0.382676, 0.008347},{1.606973, 0.383463, 0.008668},{
      1.607168, 0.383846, 0.008668},{1.608441, 0.383432, 0.008347}}],
    Polygon[{{1.607168, 0.383846, -0.008668},{1.608441, 0.383432, -0.008347},{
      1.608574, 0.384270, -0.008347},{1.607235, 0.384270, -0.008668}}],
    Polygon[{{1.608441, 0.383432, -0.008347},{1.609652, 0.383039, -0.007820},{
      1.609847, 0.384270, -0.007820},{1.608574, 0.384270, -0.008347}}],
    Polygon[{{1.609652, 0.383039, -0.007820},{1.610768, 0.382676, -0.007100},{
      1.611021, 0.384270, -0.007100},{1.609847, 0.384270, -0.007820}}],
    Polygon[{{1.610768, 0.382676, -0.007100},{1.611764, 0.382352, -0.006206},{
      1.612068, 0.384270, -0.006206},{1.611021, 0.384270, -0.007100}}],
    Polygon[{{1.611764, 0.382352, -0.006206},{1.612615, 0.382076, -0.005159},{
      1.612962, 0.384270, -0.005159},{1.612068, 0.384270, -0.006206}}],
    Polygon[{{1.612615, 0.382076, -0.005159},{1.613299, 0.381854, -0.003984},{
      1.613682, 0.384270, -0.003984},{1.612962, 0.384270, -0.005159}}],
    Polygon[{{1.613299, 0.381854, -0.003984},{1.613801, 0.381691, -0.002712},{
      1.614209, 0.384270, -0.002712},{1.613682, 0.384270, -0.003984}}],
    Polygon[{{1.613801, 0.381691, -0.002712},{1.614106, 0.381591, -0.001373},{
      1.614530, 0.384270, -0.001373},{1.614209, 0.384270, -0.002712}}],
    Polygon[{{1.614106, 0.381591, -0.001373},{1.614209, 0.381558, 0.000000},{
      1.614639, 0.384270, 0.000000},{1.614530, 0.384270, -0.001373}}],
    Polygon[{{1.614209, 0.381558, 0.000000},{1.614106, 0.381591, 0.001373},{
      1.614530, 0.384270, 0.001373},{1.614639, 0.384270, 0.000000}}],
    Polygon[{{1.614106, 0.381591, 0.001373},{1.613801, 0.381691, 0.002712},{
      1.614209, 0.384270, 0.002712},{1.614530, 0.384270, 0.001373}}],
    Polygon[{{1.613801, 0.381691, 0.002712},{1.613299, 0.381854, 0.003984},{
      1.613682, 0.384270, 0.003984},{1.614209, 0.384270, 0.002712}}],
    Polygon[{{1.613299, 0.381854, 0.003984},{1.612615, 0.382076, 0.005159},{
      1.612962, 0.384270, 0.005159},{1.613682, 0.384270, 0.003984}}],
    Polygon[{{1.612615, 0.382076, 0.005159},{1.611764, 0.382352, 0.006206},{
      1.612068, 0.384270, 0.006206},{1.612962, 0.384270, 0.005159}}],
    Polygon[{{1.611764, 0.382352, 0.006206},{1.610768, 0.382676, 0.007100},{
      1.611021, 0.384270, 0.007100},{1.612068, 0.384270, 0.006206}}],
    Polygon[{{1.610768, 0.382676, 0.007100},{1.609652, 0.383039, 0.007820},{
      1.609847, 0.384270, 0.007820},{1.611021, 0.384270, 0.007100}}],
    Polygon[{{1.609652, 0.383039, 0.007820},{1.608441, 0.383432, 0.008347},{
      1.608574, 0.384270, 0.008347},{1.609847, 0.384270, 0.007820}}],
    Polygon[{{1.608441, 0.383432, 0.008347},{1.607168, 0.383846, 0.008668},{
      1.607235, 0.384270, 0.008668},{1.608574, 0.384270, 0.008347}}],
    Polygon[{{1.030106, 1.347151, -0.190081},{1.059470, 1.347151, -0.183031},{
      1.056560, 1.365528, -0.183031},{1.028632, 1.356454, -0.190081}}],
    Polygon[{{1.059470, 1.347151, -0.183031},{1.087371, 1.347151, -0.171474},{
      1.083094, 1.374150, -0.171474},{1.056560, 1.365528, -0.183031}}],
    Polygon[{{1.087371, 1.347151, -0.171474},{1.113119, 1.347151, -0.155695},{
      1.107583, 1.382106, -0.155695},{1.083094, 1.374150, -0.171474}}],
    Polygon[{{1.113119, 1.347151, -0.155695},{1.136083, 1.347151, -0.136083},{
      1.129422, 1.389202, -0.136083},{1.107583, 1.382106, -0.155695}}],
    Polygon[{{1.136083, 1.347151, -0.136083},{1.155695, 1.347151, -0.113119},{
      1.148075, 1.395263, -0.113119},{1.129422, 1.389202, -0.136083}}],
    Polygon[{{1.155695, 1.347151, -0.113119},{1.171474, 1.347151, -0.087371},{
      1.163082, 1.400139, -0.087371},{1.148075, 1.395263, -0.113119}}],
    Polygon[{{1.171474, 1.347151, -0.087371},{1.183031, 1.347151, -0.059470},{
      1.174073, 1.403710, -0.059470},{1.163082, 1.400139, -0.087371}}],
    Polygon[{{1.183031, 1.347151, -0.059470},{1.190081, 1.347151, -0.030106},{
      1.180778, 1.405889, -0.030106},{1.174073, 1.403710, -0.059470}}],
    Polygon[{{1.190081, 1.347151, -0.030106},{1.192450, 1.347151, 0.000000},{
      1.183031, 1.406621, 0.000000},{1.180778, 1.405889, -0.030106}}],
    Polygon[{{1.192450, 1.347151, 0.000000},{1.190081, 1.347151, 0.030106},{
      1.180778, 1.405889, 0.030106},{1.183031, 1.406621, 0.000000}}],
    Polygon[{{1.190081, 1.347151, 0.030106},{1.183031, 1.347151, 0.059470},{
      1.174073, 1.403710, 0.059470},{1.180778, 1.405889, 0.030106}}],
    Polygon[{{1.183031, 1.347151, 0.059470},{1.171474, 1.347151, 0.087371},{
      1.163082, 1.400139, 0.087371},{1.174073, 1.403710, 0.059470}}],
    Polygon[{{1.171474, 1.347151, 0.087371},{1.155695, 1.347151, 0.113119},{
      1.148075, 1.395263, 0.113119},{1.163082, 1.400139, 0.087371}}],
    Polygon[{{1.155695, 1.347151, 0.113119},{1.136083, 1.347151, 0.136083},{
      1.129422, 1.389202, 0.136083},{1.148075, 1.395263, 0.113119}}],
    Polygon[{{1.136083, 1.347151, 0.136083},{1.113119, 1.347151, 0.155695},{
      1.107583, 1.382106, 0.155695},{1.129422, 1.389202, 0.136083}}],
    Polygon[{{1.113119, 1.347151, 0.155695},{1.087371, 1.347151, 0.171474},{
      1.083094, 1.374150, 0.171474},{1.107583, 1.382106, 0.155695}}],
    Polygon[{{1.087371, 1.347151, 0.171474},{1.059470, 1.347151, 0.183031},{
      1.056560, 1.365528, 0.183031},{1.083094, 1.374150, 0.171474}}],
    Polygon[{{1.059470, 1.347151, 0.183031},{1.030106, 1.347151, 0.190081},{
      1.028632, 1.356454, 0.190081},{1.056560, 1.365528, 0.183031}}],
    Polygon[{{1.028632, 1.356454, -0.190081},{1.056560, 1.365528, -0.183031},{
      1.048113, 1.382106, -0.183031},{1.024356, 1.364846, -0.190081}}],
    Polygon[{{1.056560, 1.365528, -0.183031},{1.083094, 1.374150, -0.171474},{
      1.070684, 1.398506, -0.171474},{1.048113, 1.382106, -0.183031}}],
    Polygon[{{1.083094, 1.374150, -0.171474},{1.107583, 1.382106, -0.155695},{
      1.091515, 1.413640, -0.155695},{1.070684, 1.398506, -0.171474}}],
    Polygon[{{1.107583, 1.382106, -0.155695},{1.129422, 1.389202, -0.136083},{
      1.110093, 1.427138, -0.136083},{1.091515, 1.413640, -0.155695}}],
    Polygon[{{1.129422, 1.389202, -0.136083},{1.148075, 1.395263, -0.113119},{
      1.125960, 1.438666, -0.113119},{1.110093, 1.427138, -0.136083}}],
    Polygon[{{1.148075, 1.395263, -0.113119},{1.163082, 1.400139, -0.087371},{
      1.138726, 1.447941, -0.087371},{1.125960, 1.438666, -0.113119}}],
    Polygon[{{1.163082, 1.400139, -0.087371},{1.174073, 1.403710, -0.059470},{
      1.148075, 1.454733, -0.059470},{1.138726, 1.447941, -0.087371}}],
    Polygon[{{1.174073, 1.403710, -0.059470},{1.180778, 1.405889, -0.030106},{
      1.153779, 1.458877, -0.030106},{1.148075, 1.454733, -0.059470}}],
    Polygon[{{1.180778, 1.405889, -0.030106},{1.183031, 1.406621, 0.000000},{
      1.155695, 1.460270, 0.000000},{1.153779, 1.458877, -0.030106}}],
    Polygon[{{1.183031, 1.406621, 0.000000},{1.180778, 1.405889, 0.030106},{
      1.153779, 1.458877, 0.030106},{1.155695, 1.460270, 0.000000}}],
    Polygon[{{1.180778, 1.405889, 0.030106},{1.174073, 1.403710, 0.059470},{
      1.148075, 1.454733, 0.059470},{1.153779, 1.458877, 0.030106}}],
    Polygon[{{1.174073, 1.403710, 0.059470},{1.163082, 1.400139, 0.087371},{
      1.138726, 1.447941, 0.087371},{1.148075, 1.454733, 0.059470}}],
    Polygon[{{1.163082, 1.400139, 0.087371},{1.148075, 1.395263, 0.113119},{
      1.125960, 1.438666, 0.113119},{1.138726, 1.447941, 0.087371}}],
    Polygon[{{1.148075, 1.395263, 0.113119},{1.129422, 1.389202, 0.136083},{
      1.110093, 1.427138, 0.136083},{1.125960, 1.438666, 0.113119}}],
    Polygon[{{1.129422, 1.389202, 0.136083},{1.107583, 1.382106, 0.155695},{
      1.091515, 1.413640, 0.155695},{1.110093, 1.427138, 0.136083}}],
    Polygon[{{1.107583, 1.382106, 0.155695},{1.083094, 1.374150, 0.171474},{
      1.070684, 1.398506, 0.171474},{1.091515, 1.413640, 0.155695}}],
    Polygon[{{1.083094, 1.374150, 0.171474},{1.056560, 1.365528, 0.183031},{
      1.048113, 1.382106, 0.183031},{1.070684, 1.398506, 0.171474}}],
    Polygon[{{1.056560, 1.365528, 0.183031},{1.028632, 1.356454, 0.190081},{
      1.024356, 1.364846, 0.190081},{1.048113, 1.382106, 0.183031}}],
    Polygon[{{1.024356, 1.364846, -0.190081},{1.048113, 1.382106, -0.183031},{
      1.034956, 1.395263, -0.183031},{1.017696, 1.371507, -0.190081}}],
    Polygon[{{1.048113, 1.382106, -0.183031},{1.070684, 1.398506, -0.171474},{
      1.051355, 1.417835, -0.171474},{1.034956, 1.395263, -0.183031}}],
    Polygon[{{1.070684, 1.398506, -0.171474},{1.091515, 1.413640, -0.155695},{
      1.066490, 1.438666, -0.155695},{1.051355, 1.417835, -0.171474}}],
    Polygon[{{1.091515, 1.413640, -0.155695},{1.110093, 1.427138, -0.136083},{
      1.079987, 1.457244, -0.136083},{1.066490, 1.438666, -0.155695}}],
    Polygon[{{1.110093, 1.427138, -0.136083},{1.125960, 1.438666, -0.113119},{
      1.091515, 1.473111, -0.113119},{1.079987, 1.457244, -0.136083}}],
    Polygon[{{1.125960, 1.438666, -0.113119},{1.138726, 1.447941, -0.087371},{
      1.100790, 1.485876, -0.087371},{1.091515, 1.473111, -0.113119}}],
    Polygon[{{1.138726, 1.447941, -0.087371},{1.148075, 1.454733, -0.059470},{
      1.107583, 1.495226, -0.059470},{1.100790, 1.485876, -0.087371}}],
    Polygon[{{1.148075, 1.454733, -0.059470},{1.153779, 1.458877, -0.030106},{
      1.111727, 1.500929, -0.030106},{1.107583, 1.495226, -0.059470}}],
    Polygon[{{1.153779, 1.458877, -0.030106},{1.155695, 1.460270, 0.000000},{
      1.113119, 1.502846, 0.000000},{1.111727, 1.500929, -0.030106}}],
    Polygon[{{1.155695, 1.460270, 0.000000},{1.153779, 1.458877, 0.030106},{
      1.111727, 1.500929, 0.030106},{1.113119, 1.502846, 0.000000}}],
    Polygon[{{1.153779, 1.458877, 0.030106},{1.148075, 1.454733, 0.059470},{
      1.107583, 1.495226, 0.059470},{1.111727, 1.500929, 0.030106}}],
    Polygon[{{1.148075, 1.454733, 0.059470},{1.138726, 1.447941, 0.087371},{
      1.100790, 1.485876, 0.087371},{1.107583, 1.495226, 0.059470}}],
    Polygon[{{1.138726, 1.447941, 0.087371},{1.125960, 1.438666, 0.113119},{
      1.091515, 1.473111, 0.113119},{1.100790, 1.485876, 0.087371}}],
    Polygon[{{1.125960, 1.438666, 0.113119},{1.110093, 1.427138, 0.136083},{
      1.079987, 1.457244, 0.136083},{1.091515, 1.473111, 0.113119}}],
    Polygon[{{1.110093, 1.427138, 0.136083},{1.091515, 1.413640, 0.155695},{
      1.066490, 1.438666, 0.155695},{1.079987, 1.457244, 0.136083}}],
    Polygon[{{1.091515, 1.413640, 0.155695},{1.070684, 1.398506, 0.171474},{
      1.051355, 1.417835, 0.171474},{1.066490, 1.438666, 0.155695}}],
    Polygon[{{1.070684, 1.398506, 0.171474},{1.048113, 1.382106, 0.183031},{
      1.034956, 1.395263, 0.183031},{1.051355, 1.417835, 0.171474}}],
    Polygon[{{1.048113, 1.382106, 0.183031},{1.024356, 1.364846, 0.190081},{
      1.017696, 1.371507, 0.190081},{1.034956, 1.395263, 0.183031}}],
    Polygon[{{1.017696, 1.371507, -0.190081},{1.034956, 1.395263, -0.183031},{
      1.018377, 1.403710, -0.183031},{1.009303, 1.375783, -0.190081}}],
    Polygon[{{1.034956, 1.395263, -0.183031},{1.051355, 1.417835, -0.171474},{
      1.026999, 1.430245, -0.171474},{1.018377, 1.403710, -0.183031}}],
    Polygon[{{1.051355, 1.417835, -0.171474},{1.066490, 1.438666, -0.155695},{
      1.034956, 1.454733, -0.155695},{1.026999, 1.430245, -0.171474}}],
    Polygon[{{1.066490, 1.438666, -0.155695},{1.079987, 1.457244, -0.136083},{
      1.042052, 1.476573, -0.136083},{1.034956, 1.454733, -0.155695}}],
    Polygon[{{1.079987, 1.457244, -0.136083},{1.091515, 1.473111, -0.113119},{
      1.048113, 1.495226, -0.113119},{1.042052, 1.476573, -0.136083}}],
    Polygon[{{1.091515, 1.473111, -0.113119},{1.100790, 1.485876, -0.087371},{
      1.052988, 1.510232, -0.087371},{1.048113, 1.495226, -0.113119}}],
    Polygon[{{1.100790, 1.485876, -0.087371},{1.107583, 1.495226, -0.059470},{
      1.056560, 1.521223, -0.059470},{1.052988, 1.510232, -0.087371}}],
    Polygon[{{1.107583, 1.495226, -0.059470},{1.111727, 1.500929, -0.030106},{
      1.058738, 1.527928, -0.030106},{1.056560, 1.521223, -0.059470}}],
    Polygon[{{1.111727, 1.500929, -0.030106},{1.113119, 1.502846, 0.000000},{
      1.059470, 1.530182, 0.000000},{1.058738, 1.527928, -0.030106}}],
    Polygon[{{1.113119, 1.502846, 0.000000},{1.111727, 1.500929, 0.030106},{
      1.058738, 1.527928, 0.030106},{1.059470, 1.530182, 0.000000}}],
    Polygon[{{1.111727, 1.500929, 0.030106},{1.107583, 1.495226, 0.059470},{
      1.056560, 1.521223, 0.059470},{1.058738, 1.527928, 0.030106}}],
    Polygon[{{1.107583, 1.495226, 0.059470},{1.100790, 1.485876, 0.087371},{
      1.052988, 1.510232, 0.087371},{1.056560, 1.521223, 0.059470}}],
    Polygon[{{1.100790, 1.485876, 0.087371},{1.091515, 1.473111, 0.113119},{
      1.048113, 1.495226, 0.113119},{1.052988, 1.510232, 0.087371}}],
    Polygon[{{1.091515, 1.473111, 0.113119},{1.079987, 1.457244, 0.136083},{
      1.042052, 1.476573, 0.136083},{1.048113, 1.495226, 0.113119}}],
    Polygon[{{1.079987, 1.457244, 0.136083},{1.066490, 1.438666, 0.155695},{
      1.034956, 1.454733, 0.155695},{1.042052, 1.476573, 0.136083}}],
    Polygon[{{1.066490, 1.438666, 0.155695},{1.051355, 1.417835, 0.171474},{
      1.026999, 1.430245, 0.171474},{1.034956, 1.454733, 0.155695}}],
    Polygon[{{1.051355, 1.417835, 0.171474},{1.034956, 1.395263, 0.183031},{
      1.018377, 1.403710, 0.183031},{1.026999, 1.430245, 0.171474}}],
    Polygon[{{1.034956, 1.395263, 0.183031},{1.017696, 1.371507, 0.190081},{
      1.009303, 1.375783, 0.190081},{1.018377, 1.403710, 0.183031}}],
    Polygon[{{1.009303, 1.375783, -0.190081},{1.018377, 1.403710, -0.183031},{
      1.000000, 1.406621, -0.183031},{1.000000, 1.377257, -0.190081}}],
    Polygon[{{1.018377, 1.403710, -0.183031},{1.026999, 1.430245, -0.171474},{
      1.000000, 1.434521, -0.171474},{1.000000, 1.406621, -0.183031}}],
    Polygon[{{1.026999, 1.430245, -0.171474},{1.034956, 1.454733, -0.155695},{
      1.000000, 1.460270, -0.155695},{1.000000, 1.434521, -0.171474}}],
    Polygon[{{1.034956, 1.454733, -0.155695},{1.042052, 1.476573, -0.136083},{
      1.000000, 1.483233, -0.136083},{1.000000, 1.460270, -0.155695}}],
    Polygon[{{1.042052, 1.476573, -0.136083},{1.048113, 1.495226, -0.113119},{
      1.000000, 1.502846, -0.113119},{1.000000, 1.483233, -0.136083}}],
    Polygon[{{1.048113, 1.495226, -0.113119},{1.052988, 1.510232, -0.087371},{
      1.000000, 1.518625, -0.087371},{1.000000, 1.502846, -0.113119}}],
    Polygon[{{1.052988, 1.510232, -0.087371},{1.056560, 1.521223, -0.059470},{
      1.000000, 1.530182, -0.059470},{1.000000, 1.518625, -0.087371}}],
    Polygon[{{1.056560, 1.521223, -0.059470},{1.058738, 1.527928, -0.030106},{
      1.000000, 1.537231, -0.030106},{1.000000, 1.530182, -0.059470}}],
    Polygon[{{1.058738, 1.527928, -0.030106},{1.059470, 1.530182, 0.000000},{
      1.000000, 1.539601, 0.000000},{1.000000, 1.537231, -0.030106}}],
    Polygon[{{1.059470, 1.530182, 0.000000},{1.058738, 1.527928, 0.030106},{
      1.000000, 1.537231, 0.030106},{1.000000, 1.539601, 0.000000}}],
    Polygon[{{1.058738, 1.527928, 0.030106},{1.056560, 1.521223, 0.059470},{
      1.000000, 1.530182, 0.059470},{1.000000, 1.537231, 0.030106}}],
    Polygon[{{1.056560, 1.521223, 0.059470},{1.052988, 1.510232, 0.087371},{
      1.000000, 1.518625, 0.087371},{1.000000, 1.530182, 0.059470}}],
    Polygon[{{1.052988, 1.510232, 0.087371},{1.048113, 1.495226, 0.113119},{
      1.000000, 1.502846, 0.113119},{1.000000, 1.518625, 0.087371}}],
    Polygon[{{1.048113, 1.495226, 0.113119},{1.042052, 1.476573, 0.136083},{
      1.000000, 1.483233, 0.136083},{1.000000, 1.502846, 0.113119}}],
    Polygon[{{1.042052, 1.476573, 0.136083},{1.034956, 1.454733, 0.155695},{
      1.000000, 1.460270, 0.155695},{1.000000, 1.483233, 0.136083}}],
    Polygon[{{1.034956, 1.454733, 0.155695},{1.026999, 1.430245, 0.171474},{
      1.000000, 1.434521, 0.171474},{1.000000, 1.460270, 0.155695}}],
    Polygon[{{1.026999, 1.430245, 0.171474},{1.018377, 1.403710, 0.183031},{
      1.000000, 1.406621, 0.183031},{1.000000, 1.434521, 0.171474}}],
    Polygon[{{1.018377, 1.403710, 0.183031},{1.009303, 1.375783, 0.190081},{
      1.000000, 1.377257, 0.190081},{1.000000, 1.406621, 0.183031}}],
    Polygon[{{1.000000, 1.377257, -0.190081},{1.000000, 1.406621, -0.183031},{
      0.981623, 1.403710, -0.183031},{0.990697, 1.375783, -0.190081}}],
    Polygon[{{1.000000, 1.406621, -0.183031},{1.000000, 1.434521, -0.171474},{
      0.973001, 1.430245, -0.171474},{0.981623, 1.403710, -0.183031}}],
    Polygon[{{1.000000, 1.434521, -0.171474},{1.000000, 1.460270, -0.155695},{
      0.965044, 1.454733, -0.155695},{0.973001, 1.430245, -0.171474}}],
    Polygon[{{1.000000, 1.460270, -0.155695},{1.000000, 1.483233, -0.136083},{
      0.957948, 1.476573, -0.136083},{0.965044, 1.454733, -0.155695}}],
    Polygon[{{1.000000, 1.483233, -0.136083},{1.000000, 1.502846, -0.113119},{
      0.951887, 1.495226, -0.113119},{0.957948, 1.476573, -0.136083}}],
    Polygon[{{1.000000, 1.502846, -0.113119},{1.000000, 1.518625, -0.087371},{
      0.947012, 1.510232, -0.087371},{0.951887, 1.495226, -0.113119}}],
    Polygon[{{1.000000, 1.518625, -0.087371},{1.000000, 1.530182, -0.059470},{
      0.943440, 1.521223, -0.059470},{0.947012, 1.510232, -0.087371}}],
    Polygon[{{1.000000, 1.530182, -0.059470},{1.000000, 1.537231, -0.030106},{
      0.941262, 1.527928, -0.030106},{0.943440, 1.521223, -0.059470}}],
    Polygon[{{1.000000, 1.537231, -0.030106},{1.000000, 1.539601, 0.000000},{
      0.940530, 1.530182, 0.000000},{0.941262, 1.527928, -0.030106}}],
    Polygon[{{1.000000, 1.539601, 0.000000},{1.000000, 1.537231, 0.030106},{
      0.941262, 1.527928, 0.030106},{0.940530, 1.530182, 0.000000}}],
    Polygon[{{1.000000, 1.537231, 0.030106},{1.000000, 1.530182, 0.059470},{
      0.943440, 1.521223, 0.059470},{0.941262, 1.527928, 0.030106}}],
    Polygon[{{1.000000, 1.530182, 0.059470},{1.000000, 1.518625, 0.087371},{
      0.947012, 1.510232, 0.087371},{0.943440, 1.521223, 0.059470}}],
    Polygon[{{1.000000, 1.518625, 0.087371},{1.000000, 1.502846, 0.113119},{
      0.951887, 1.495226, 0.113119},{0.947012, 1.510232, 0.087371}}],
    Polygon[{{1.000000, 1.502846, 0.113119},{1.000000, 1.483233, 0.136083},{
      0.957948, 1.476573, 0.136083},{0.951887, 1.495226, 0.113119}}],
    Polygon[{{1.000000, 1.483233, 0.136083},{1.000000, 1.460270, 0.155695},{
      0.965044, 1.454733, 0.155695},{0.957948, 1.476573, 0.136083}}],
    Polygon[{{1.000000, 1.460270, 0.155695},{1.000000, 1.434521, 0.171474},{
      0.973001, 1.430245, 0.171474},{0.965044, 1.454733, 0.155695}}],
    Polygon[{{1.000000, 1.434521, 0.171474},{1.000000, 1.406621, 0.183031},{
      0.981623, 1.403710, 0.183031},{0.973001, 1.430245, 0.171474}}],
    Polygon[{{1.000000, 1.406621, 0.183031},{1.000000, 1.377257, 0.190081},{
      0.990697, 1.375783, 0.190081},{0.981623, 1.403710, 0.183031}}],
    Polygon[{{0.990697, 1.375783, -0.190081},{0.981623, 1.403710, -0.183031},{
      0.965044, 1.395263, -0.183031},{0.982304, 1.371507, -0.190081}}],
    Polygon[{{0.981623, 1.403710, -0.183031},{0.973001, 1.430245, -0.171474},{
      0.948645, 1.417835, -0.171474},{0.965044, 1.395263, -0.183031}}],
    Polygon[{{0.973001, 1.430245, -0.171474},{0.965044, 1.454733, -0.155695},{
      0.933510, 1.438666, -0.155695},{0.948645, 1.417835, -0.171474}}],
    Polygon[{{0.965044, 1.454733, -0.155695},{0.957948, 1.476573, -0.136083},{
      0.920013, 1.457244, -0.136083},{0.933510, 1.438666, -0.155695}}],
    Polygon[{{0.957948, 1.476573, -0.136083},{0.951887, 1.495226, -0.113119},{
      0.908485, 1.473111, -0.113119},{0.920013, 1.457244, -0.136083}}],
    Polygon[{{0.951887, 1.495226, -0.113119},{0.947012, 1.510232, -0.087371},{
      0.899210, 1.485876, -0.087371},{0.908485, 1.473111, -0.113119}}],
    Polygon[{{0.947012, 1.510232, -0.087371},{0.943440, 1.521223, -0.059470},{
      0.892417, 1.495226, -0.059470},{0.899210, 1.485876, -0.087371}}],
    Polygon[{{0.943440, 1.521223, -0.059470},{0.941262, 1.527928, -0.030106},{
      0.888273, 1.500929, -0.030106},{0.892417, 1.495226, -0.059470}}],
    Polygon[{{0.941262, 1.527928, -0.030106},{0.940530, 1.530182, 0.000000},{
      0.886881, 1.502846, 0.000000},{0.888273, 1.500929, -0.030106}}],
    Polygon[{{0.940530, 1.530182, 0.000000},{0.941262, 1.527928, 0.030106},{
      0.888273, 1.500929, 0.030106},{0.886881, 1.502846, 0.000000}}],
    Polygon[{{0.941262, 1.527928, 0.030106},{0.943440, 1.521223, 0.059470},{
      0.892417, 1.495226, 0.059470},{0.888273, 1.500929, 0.030106}}],
    Polygon[{{0.943440, 1.521223, 0.059470},{0.947012, 1.510232, 0.087371},{
      0.899210, 1.485876, 0.087371},{0.892417, 1.495226, 0.059470}}],
    Polygon[{{0.947012, 1.510232, 0.087371},{0.951887, 1.495226, 0.113119},{
      0.908485, 1.473111, 0.113119},{0.899210, 1.485876, 0.087371}}],
    Polygon[{{0.951887, 1.495226, 0.113119},{0.957948, 1.476573, 0.136083},{
      0.920013, 1.457244, 0.136083},{0.908485, 1.473111, 0.113119}}],
    Polygon[{{0.957948, 1.476573, 0.136083},{0.965044, 1.454733, 0.155695},{
      0.933510, 1.438666, 0.155695},{0.920013, 1.457244, 0.136083}}],
    Polygon[{{0.965044, 1.454733, 0.155695},{0.973001, 1.430245, 0.171474},{
      0.948645, 1.417835, 0.171474},{0.933510, 1.438666, 0.155695}}],
    Polygon[{{0.973001, 1.430245, 0.171474},{0.981623, 1.403710, 0.183031},{
      0.965044, 1.395263, 0.183031},{0.948645, 1.417835, 0.171474}}],
    Polygon[{{0.981623, 1.403710, 0.183031},{0.990697, 1.375783, 0.190081},{
      0.982304, 1.371507, 0.190081},{0.965044, 1.395263, 0.183031}}],
    Polygon[{{0.982304, 1.371507, -0.190081},{0.965044, 1.395263, -0.183031},{
      0.951887, 1.382106, -0.183031},{0.975644, 1.364846, -0.190081}}],
    Polygon[{{0.965044, 1.395263, -0.183031},{0.948645, 1.417835, -0.171474},{
      0.929316, 1.398506, -0.171474},{0.951887, 1.382106, -0.183031}}],
    Polygon[{{0.948645, 1.417835, -0.171474},{0.933510, 1.438666, -0.155695},{
      0.908485, 1.413640, -0.155695},{0.929316, 1.398506, -0.171474}}],
    Polygon[{{0.933510, 1.438666, -0.155695},{0.920013, 1.457244, -0.136083},{
      0.889907, 1.427138, -0.136083},{0.908485, 1.413640, -0.155695}}],
    Polygon[{{0.920013, 1.457244, -0.136083},{0.908485, 1.473111, -0.113119},{
      0.874040, 1.438666, -0.113119},{0.889907, 1.427138, -0.136083}}],
    Polygon[{{0.908485, 1.473111, -0.113119},{0.899210, 1.485876, -0.087371},{
      0.861274, 1.447941, -0.087371},{0.874040, 1.438666, -0.113119}}],
    Polygon[{{0.899210, 1.485876, -0.087371},{0.892417, 1.495226, -0.059470},{
      0.851925, 1.454733, -0.059470},{0.861274, 1.447941, -0.087371}}],
    Polygon[{{0.892417, 1.495226, -0.059470},{0.888273, 1.500929, -0.030106},{
      0.846221, 1.458877, -0.030106},{0.851925, 1.454733, -0.059470}}],
    Polygon[{{0.888273, 1.500929, -0.030106},{0.886881, 1.502846, 0.000000},{
      0.844305, 1.460270, 0.000000},{0.846221, 1.458877, -0.030106}}],
    Polygon[{{0.886881, 1.502846, 0.000000},{0.888273, 1.500929, 0.030106},{
      0.846221, 1.458877, 0.030106},{0.844305, 1.460270, 0.000000}}],
    Polygon[{{0.888273, 1.500929, 0.030106},{0.892417, 1.495226, 0.059470},{
      0.851925, 1.454733, 0.059470},{0.846221, 1.458877, 0.030106}}],
    Polygon[{{0.892417, 1.495226, 0.059470},{0.899210, 1.485876, 0.087371},{
      0.861274, 1.447941, 0.087371},{0.851925, 1.454733, 0.059470}}],
    Polygon[{{0.899210, 1.485876, 0.087371},{0.908485, 1.473111, 0.113119},{
      0.874040, 1.438666, 0.113119},{0.861274, 1.447941, 0.087371}}],
    Polygon[{{0.908485, 1.473111, 0.113119},{0.920013, 1.457244, 0.136083},{
      0.889907, 1.427138, 0.136083},{0.874040, 1.438666, 0.113119}}],
    Polygon[{{0.920013, 1.457244, 0.136083},{0.933510, 1.438666, 0.155695},{
      0.908485, 1.413640, 0.155695},{0.889907, 1.427138, 0.136083}}],
    Polygon[{{0.933510, 1.438666, 0.155695},{0.948645, 1.417835, 0.171474},{
      0.929316, 1.398506, 0.171474},{0.908485, 1.413640, 0.155695}}],
    Polygon[{{0.948645, 1.417835, 0.171474},{0.965044, 1.395263, 0.183031},{
      0.951887, 1.382106, 0.183031},{0.929316, 1.398506, 0.171474}}],
    Polygon[{{0.965044, 1.395263, 0.183031},{0.982304, 1.371507, 0.190081},{
      0.975644, 1.364846, 0.190081},{0.951887, 1.382106, 0.183031}}],
    Polygon[{{0.975644, 1.364846, -0.190081},{0.951887, 1.382106, -0.183031},{
      0.943440, 1.365528, -0.183031},{0.971368, 1.356454, -0.190081}}],
    Polygon[{{0.951887, 1.382106, -0.183031},{0.929316, 1.398506, -0.171474},{
      0.916906, 1.374150, -0.171474},{0.943440, 1.365528, -0.183031}}],
    Polygon[{{0.929316, 1.398506, -0.171474},{0.908485, 1.413640, -0.155695},{
      0.892417, 1.382106, -0.155695},{0.916906, 1.374150, -0.171474}}],
    Polygon[{{0.908485, 1.413640, -0.155695},{0.889907, 1.427138, -0.136083},{
      0.870578, 1.389202, -0.136083},{0.892417, 1.382106, -0.155695}}],
    Polygon[{{0.889907, 1.427138, -0.136083},{0.874040, 1.438666, -0.113119},{
      0.851925, 1.395263, -0.113119},{0.870578, 1.389202, -0.136083}}],
    Polygon[{{0.874040, 1.438666, -0.113119},{0.861274, 1.447941, -0.087371},{
      0.836918, 1.400139, -0.087371},{0.851925, 1.395263, -0.113119}}],
    Polygon[{{0.861274, 1.447941, -0.087371},{0.851925, 1.454733, -0.059470},{
      0.825927, 1.403710, -0.059470},{0.836918, 1.400139, -0.087371}}],
    Polygon[{{0.851925, 1.454733, -0.059470},{0.846221, 1.458877, -0.030106},{
      0.819223, 1.405889, -0.030106},{0.825927, 1.403710, -0.059470}}],
    Polygon[{{0.846221, 1.458877, -0.030106},{0.844305, 1.460270, 0.000000},{
      0.816969, 1.406621, 0.000000},{0.819223, 1.405889, -0.030106}}],
    Polygon[{{0.844305, 1.460270, 0.000000},{0.846221, 1.458877, 0.030106},{
      0.819223, 1.405889, 0.030106},{0.816969, 1.406621, 0.000000}}],
    Polygon[{{0.846221, 1.458877, 0.030106},{0.851925, 1.454733, 0.059470},{
      0.825927, 1.403710, 0.059470},{0.819223, 1.405889, 0.030106}}],
    Polygon[{{0.851925, 1.454733, 0.059470},{0.861274, 1.447941, 0.087371},{
      0.836918, 1.400139, 0.087371},{0.825927, 1.403710, 0.059470}}],
    Polygon[{{0.861274, 1.447941, 0.087371},{0.874040, 1.438666, 0.113119},{
      0.851925, 1.395263, 0.113119},{0.836918, 1.400139, 0.087371}}],
    Polygon[{{0.874040, 1.438666, 0.113119},{0.889907, 1.427138, 0.136083},{
      0.870578, 1.389202, 0.136083},{0.851925, 1.395263, 0.113119}}],
    Polygon[{{0.889907, 1.427138, 0.136083},{0.908485, 1.413640, 0.155695},{
      0.892417, 1.382106, 0.155695},{0.870578, 1.389202, 0.136083}}],
    Polygon[{{0.908485, 1.413640, 0.155695},{0.929316, 1.398506, 0.171474},{
      0.916906, 1.374150, 0.171474},{0.892417, 1.382106, 0.155695}}],
    Polygon[{{0.929316, 1.398506, 0.171474},{0.951887, 1.382106, 0.183031},{
      0.943440, 1.365528, 0.183031},{0.916906, 1.374150, 0.171474}}],
    Polygon[{{0.951887, 1.382106, 0.183031},{0.975644, 1.364846, 0.190081},{
      0.971368, 1.356454, 0.190081},{0.943440, 1.365528, 0.183031}}],
    Polygon[{{0.971368, 1.356454, -0.190081},{0.943440, 1.365528, -0.183031},{
      0.940530, 1.347151, -0.183031},{0.969894, 1.347151, -0.190081}}],
    Polygon[{{0.943440, 1.365528, -0.183031},{0.916906, 1.374150, -0.171474},{
      0.912629, 1.347151, -0.171474},{0.940530, 1.347151, -0.183031}}],
    Polygon[{{0.916906, 1.374150, -0.171474},{0.892417, 1.382106, -0.155695},{
      0.886881, 1.347151, -0.155695},{0.912629, 1.347151, -0.171474}}],
    Polygon[{{0.892417, 1.382106, -0.155695},{0.870578, 1.389202, -0.136083},{
      0.863917, 1.347151, -0.136083},{0.886881, 1.347151, -0.155695}}],
    Polygon[{{0.870578, 1.389202, -0.136083},{0.851925, 1.395263, -0.113119},{
      0.844305, 1.347151, -0.113119},{0.863917, 1.347151, -0.136083}}],
    Polygon[{{0.851925, 1.395263, -0.113119},{0.836918, 1.400139, -0.087371},{
      0.828526, 1.347151, -0.087371},{0.844305, 1.347151, -0.113119}}],
    Polygon[{{0.836918, 1.400139, -0.087371},{0.825927, 1.403710, -0.059470},{
      0.816969, 1.347151, -0.059470},{0.828526, 1.347151, -0.087371}}],
    Polygon[{{0.825927, 1.403710, -0.059470},{0.819223, 1.405889, -0.030106},{
      0.809919, 1.347151, -0.030106},{0.816969, 1.347151, -0.059470}}],
    Polygon[{{0.819223, 1.405889, -0.030106},{0.816969, 1.406621, 0.000000},{
      0.807550, 1.347151, 0.000000},{0.809919, 1.347151, -0.030106}}],
    Polygon[{{0.816969, 1.406621, 0.000000},{0.819223, 1.405889, 0.030106},{
      0.809919, 1.347151, 0.030106},{0.807550, 1.347151, 0.000000}}],
    Polygon[{{0.819223, 1.405889, 0.030106},{0.825927, 1.403710, 0.059470},{
      0.816969, 1.347151, 0.059470},{0.809919, 1.347151, 0.030106}}],
    Polygon[{{0.825927, 1.403710, 0.059470},{0.836918, 1.400139, 0.087371},{
      0.828526, 1.347151, 0.087371},{0.816969, 1.347151, 0.059470}}],
    Polygon[{{0.836918, 1.400139, 0.087371},{0.851925, 1.395263, 0.113119},{
      0.844305, 1.347151, 0.113119},{0.828526, 1.347151, 0.087371}}],
    Polygon[{{0.851925, 1.395263, 0.113119},{0.870578, 1.389202, 0.136083},{
      0.863917, 1.347151, 0.136083},{0.844305, 1.347151, 0.113119}}],
    Polygon[{{0.870578, 1.389202, 0.136083},{0.892417, 1.382106, 0.155695},{
      0.886881, 1.347151, 0.155695},{0.863917, 1.347151, 0.136083}}],
    Polygon[{{0.892417, 1.382106, 0.155695},{0.916906, 1.374150, 0.171474},{
      0.912629, 1.347151, 0.171474},{0.886881, 1.347151, 0.155695}}],
    Polygon[{{0.916906, 1.374150, 0.171474},{0.943440, 1.365528, 0.183031},{
      0.940530, 1.347151, 0.183031},{0.912629, 1.347151, 0.171474}}],
    Polygon[{{0.943440, 1.365528, 0.183031},{0.971368, 1.356454, 0.190081},{
      0.969894, 1.347151, 0.190081},{0.940530, 1.347151, 0.183031}}],
    Polygon[{{0.969894, 1.347151, -0.190081},{0.940530, 1.347151, -0.183031},{
      0.943440, 1.328773, -0.183031},{0.971368, 1.337847, -0.190081}}],
    Polygon[{{0.940530, 1.347151, -0.183031},{0.912629, 1.347151, -0.171474},{
      0.916906, 1.320152, -0.171474},{0.943440, 1.328773, -0.183031}}],
    Polygon[{{0.912629, 1.347151, -0.171474},{0.886881, 1.347151, -0.155695},{
      0.892417, 1.312195, -0.155695},{0.916906, 1.320152, -0.171474}}],
    Polygon[{{0.886881, 1.347151, -0.155695},{0.863917, 1.347151, -0.136083},{
      0.870578, 1.305099, -0.136083},{0.892417, 1.312195, -0.155695}}],
    Polygon[{{0.863917, 1.347151, -0.136083},{0.844305, 1.347151, -0.113119},{
      0.851925, 1.299038, -0.113119},{0.870578, 1.305099, -0.136083}}],
    Polygon[{{0.844305, 1.347151, -0.113119},{0.828526, 1.347151, -0.087371},{
      0.836918, 1.294162, -0.087371},{0.851925, 1.299038, -0.113119}}],
    Polygon[{{0.828526, 1.347151, -0.087371},{0.816969, 1.347151, -0.059470},{
      0.825927, 1.290591, -0.059470},{0.836918, 1.294162, -0.087371}}],
    Polygon[{{0.816969, 1.347151, -0.059470},{0.809919, 1.347151, -0.030106},{
      0.819223, 1.288412, -0.030106},{0.825927, 1.290591, -0.059470}}],
    Polygon[{{0.809919, 1.347151, -0.030106},{0.807550, 1.347151, 0.000000},{
      0.816969, 1.287680, 0.000000},{0.819223, 1.288412, -0.030106}}],
    Polygon[{{0.807550, 1.347151, 0.000000},{0.809919, 1.347151, 0.030106},{
      0.819223, 1.288412, 0.030106},{0.816969, 1.287680, 0.000000}}],
    Polygon[{{0.809919, 1.347151, 0.030106},{0.816969, 1.347151, 0.059470},{
      0.825927, 1.290591, 0.059470},{0.819223, 1.288412, 0.030106}}],
    Polygon[{{0.816969, 1.347151, 0.059470},{0.828526, 1.347151, 0.087371},{
      0.836918, 1.294162, 0.087371},{0.825927, 1.290591, 0.059470}}],
    Polygon[{{0.828526, 1.347151, 0.087371},{0.844305, 1.347151, 0.113119},{
      0.851925, 1.299038, 0.113119},{0.836918, 1.294162, 0.087371}}],
    Polygon[{{0.844305, 1.347151, 0.113119},{0.863917, 1.347151, 0.136083},{
      0.870578, 1.305099, 0.136083},{0.851925, 1.299038, 0.113119}}],
    Polygon[{{0.863917, 1.347151, 0.136083},{0.886881, 1.347151, 0.155695},{
      0.892417, 1.312195, 0.155695},{0.870578, 1.305099, 0.136083}}],
    Polygon[{{0.886881, 1.347151, 0.155695},{0.912629, 1.347151, 0.171474},{
      0.916906, 1.320152, 0.171474},{0.892417, 1.312195, 0.155695}}],
    Polygon[{{0.912629, 1.347151, 0.171474},{0.940530, 1.347151, 0.183031},{
      0.943440, 1.328773, 0.183031},{0.916906, 1.320152, 0.171474}}],
    Polygon[{{0.940530, 1.347151, 0.183031},{0.969894, 1.347151, 0.190081},{
      0.971368, 1.337847, 0.190081},{0.943440, 1.328773, 0.183031}}],
    Polygon[{{0.971368, 1.337847, -0.190081},{0.943440, 1.328773, -0.183031},{
      0.951887, 1.312195, -0.183031},{0.975644, 1.329455, -0.190081}}],
    Polygon[{{0.943440, 1.328773, -0.183031},{0.916906, 1.320152, -0.171474},{
      0.929316, 1.295796, -0.171474},{0.951887, 1.312195, -0.183031}}],
    Polygon[{{0.916906, 1.320152, -0.171474},{0.892417, 1.312195, -0.155695},{
      0.908485, 1.280661, -0.155695},{0.929316, 1.295796, -0.171474}}],
    Polygon[{{0.892417, 1.312195, -0.155695},{0.870578, 1.305099, -0.136083},{
      0.889907, 1.267163, -0.136083},{0.908485, 1.280661, -0.155695}}],
    Polygon[{{0.870578, 1.305099, -0.136083},{0.851925, 1.299038, -0.113119},{
      0.874040, 1.255635, -0.113119},{0.889907, 1.267163, -0.136083}}],
    Polygon[{{0.851925, 1.299038, -0.113119},{0.836918, 1.294162, -0.087371},{
      0.861274, 1.246361, -0.087371},{0.874040, 1.255635, -0.113119}}],
    Polygon[{{0.836918, 1.294162, -0.087371},{0.825927, 1.290591, -0.059470},{
      0.851925, 1.239568, -0.059470},{0.861274, 1.246361, -0.087371}}],
    Polygon[{{0.825927, 1.290591, -0.059470},{0.819223, 1.288412, -0.030106},{
      0.846221, 1.235424, -0.030106},{0.851925, 1.239568, -0.059470}}],
    Polygon[{{0.819223, 1.288412, -0.030106},{0.816969, 1.287680, 0.000000},{
      0.844305, 1.234031, 0.000000},{0.846221, 1.235424, -0.030106}}],
    Polygon[{{0.816969, 1.287680, 0.000000},{0.819223, 1.288412, 0.030106},{
      0.846221, 1.235424, 0.030106},{0.844305, 1.234031, 0.000000}}],
    Polygon[{{0.819223, 1.288412, 0.030106},{0.825927, 1.290591, 0.059470},{
      0.851925, 1.239568, 0.059470},{0.846221, 1.235424, 0.030106}}],
    Polygon[{{0.825927, 1.290591, 0.059470},{0.836918, 1.294162, 0.087371},{
      0.861274, 1.246361, 0.087371},{0.851925, 1.239568, 0.059470}}],
    Polygon[{{0.836918, 1.294162, 0.087371},{0.851925, 1.299038, 0.113119},{
      0.874040, 1.255635, 0.113119},{0.861274, 1.246361, 0.087371}}],
    Polygon[{{0.851925, 1.299038, 0.113119},{0.870578, 1.305099, 0.136083},{
      0.889907, 1.267163, 0.136083},{0.874040, 1.255635, 0.113119}}],
    Polygon[{{0.870578, 1.305099, 0.136083},{0.892417, 1.312195, 0.155695},{
      0.908485, 1.280661, 0.155695},{0.889907, 1.267163, 0.136083}}],
    Polygon[{{0.892417, 1.312195, 0.155695},{0.916906, 1.320152, 0.171474},{
      0.929316, 1.295796, 0.171474},{0.908485, 1.280661, 0.155695}}],
    Polygon[{{0.916906, 1.320152, 0.171474},{0.943440, 1.328773, 0.183031},{
      0.951887, 1.312195, 0.183031},{0.929316, 1.295796, 0.171474}}],
    Polygon[{{0.943440, 1.328773, 0.183031},{0.971368, 1.337847, 0.190081},{
      0.975644, 1.329455, 0.190081},{0.951887, 1.312195, 0.183031}}],
    Polygon[{{0.975644, 1.329455, -0.190081},{0.951887, 1.312195, -0.183031},{
      0.965044, 1.299038, -0.183031},{0.982304, 1.322795, -0.190081}}],
    Polygon[{{0.951887, 1.312195, -0.183031},{0.929316, 1.295796, -0.171474},{
      0.948645, 1.276466, -0.171474},{0.965044, 1.299038, -0.183031}}],
    Polygon[{{0.929316, 1.295796, -0.171474},{0.908485, 1.280661, -0.155695},{
      0.933510, 1.255635, -0.155695},{0.948645, 1.276466, -0.171474}}],
    Polygon[{{0.908485, 1.280661, -0.155695},{0.889907, 1.267163, -0.136083},{
      0.920013, 1.237057, -0.136083},{0.933510, 1.255635, -0.155695}}],
    Polygon[{{0.889907, 1.267163, -0.136083},{0.874040, 1.255635, -0.113119},{
      0.908485, 1.221190, -0.113119},{0.920013, 1.237057, -0.136083}}],
    Polygon[{{0.874040, 1.255635, -0.113119},{0.861274, 1.246361, -0.087371},{
      0.899210, 1.208425, -0.087371},{0.908485, 1.221190, -0.113119}}],
    Polygon[{{0.861274, 1.246361, -0.087371},{0.851925, 1.239568, -0.059470},{
      0.892417, 1.199075, -0.059470},{0.899210, 1.208425, -0.087371}}],
    Polygon[{{0.851925, 1.239568, -0.059470},{0.846221, 1.235424, -0.030106},{
      0.888273, 1.193372, -0.030106},{0.892417, 1.199075, -0.059470}}],
    Polygon[{{0.846221, 1.235424, -0.030106},{0.844305, 1.234031, 0.000000},{
      0.886881, 1.191455, 0.000000},{0.888273, 1.193372, -0.030106}}],
    Polygon[{{0.844305, 1.234031, 0.000000},{0.846221, 1.235424, 0.030106},{
      0.888273, 1.193372, 0.030106},{0.886881, 1.191455, 0.000000}}],
    Polygon[{{0.846221, 1.235424, 0.030106},{0.851925, 1.239568, 0.059470},{
      0.892417, 1.199075, 0.059470},{0.888273, 1.193372, 0.030106}}],
    Polygon[{{0.851925, 1.239568, 0.059470},{0.861274, 1.246361, 0.087371},{
      0.899210, 1.208425, 0.087371},{0.892417, 1.199075, 0.059470}}],
    Polygon[{{0.861274, 1.246361, 0.087371},{0.874040, 1.255635, 0.113119},{
      0.908485, 1.221190, 0.113119},{0.899210, 1.208425, 0.087371}}],
    Polygon[{{0.874040, 1.255635, 0.113119},{0.889907, 1.267163, 0.136083},{
      0.920013, 1.237057, 0.136083},{0.908485, 1.221190, 0.113119}}],
    Polygon[{{0.889907, 1.267163, 0.136083},{0.908485, 1.280661, 0.155695},{
      0.933510, 1.255635, 0.155695},{0.920013, 1.237057, 0.136083}}],
    Polygon[{{0.908485, 1.280661, 0.155695},{0.929316, 1.295796, 0.171474},{
      0.948645, 1.276466, 0.171474},{0.933510, 1.255635, 0.155695}}],
    Polygon[{{0.929316, 1.295796, 0.171474},{0.951887, 1.312195, 0.183031},{
      0.965044, 1.299038, 0.183031},{0.948645, 1.276466, 0.171474}}],
    Polygon[{{0.951887, 1.312195, 0.183031},{0.975644, 1.329455, 0.190081},{
      0.982304, 1.322795, 0.190081},{0.965044, 1.299038, 0.183031}}],
    Polygon[{{0.982304, 1.322795, -0.190081},{0.965044, 1.299038, -0.183031},{
      0.981623, 1.290591, -0.183031},{0.990697, 1.318518, -0.190081}}],
    Polygon[{{0.965044, 1.299038, -0.183031},{0.948645, 1.276466, -0.171474},{
      0.973001, 1.264056, -0.171474},{0.981623, 1.290591, -0.183031}}],
    Polygon[{{0.948645, 1.276466, -0.171474},{0.933510, 1.255635, -0.155695},{
      0.965044, 1.239568, -0.155695},{0.973001, 1.264056, -0.171474}}],
    Polygon[{{0.933510, 1.255635, -0.155695},{0.920013, 1.237057, -0.136083},{
      0.957948, 1.217728, -0.136083},{0.965044, 1.239568, -0.155695}}],
    Polygon[{{0.920013, 1.237057, -0.136083},{0.908485, 1.221190, -0.113119},{
      0.951887, 1.199075, -0.113119},{0.957948, 1.217728, -0.136083}}],
    Polygon[{{0.908485, 1.221190, -0.113119},{0.899210, 1.208425, -0.087371},{
      0.947012, 1.184069, -0.087371},{0.951887, 1.199075, -0.113119}}],
    Polygon[{{0.899210, 1.208425, -0.087371},{0.892417, 1.199075, -0.059470},{
      0.943440, 1.173078, -0.059470},{0.947012, 1.184069, -0.087371}}],
    Polygon[{{0.892417, 1.199075, -0.059470},{0.888273, 1.193372, -0.030106},{
      0.941262, 1.166373, -0.030106},{0.943440, 1.173078, -0.059470}}],
    Polygon[{{0.888273, 1.193372, -0.030106},{0.886881, 1.191455, 0.000000},{
      0.940530, 1.164120, 0.000000},{0.941262, 1.166373, -0.030106}}],
    Polygon[{{0.886881, 1.191455, 0.000000},{0.888273, 1.193372, 0.030106},{
      0.941262, 1.166373, 0.030106},{0.940530, 1.164120, 0.000000}}],
    Polygon[{{0.888273, 1.193372, 0.030106},{0.892417, 1.199075, 0.059470},{
      0.943440, 1.173078, 0.059470},{0.941262, 1.166373, 0.030106}}],
    Polygon[{{0.892417, 1.199075, 0.059470},{0.899210, 1.208425, 0.087371},{
      0.947012, 1.184069, 0.087371},{0.943440, 1.173078, 0.059470}}],
    Polygon[{{0.899210, 1.208425, 0.087371},{0.908485, 1.221190, 0.113119},{
      0.951887, 1.199075, 0.113119},{0.947012, 1.184069, 0.087371}}],
    Polygon[{{0.908485, 1.221190, 0.113119},{0.920013, 1.237057, 0.136083},{
      0.957948, 1.217728, 0.136083},{0.951887, 1.199075, 0.113119}}],
    Polygon[{{0.920013, 1.237057, 0.136083},{0.933510, 1.255635, 0.155695},{
      0.965044, 1.239568, 0.155695},{0.957948, 1.217728, 0.136083}}],
    Polygon[{{0.933510, 1.255635, 0.155695},{0.948645, 1.276466, 0.171474},{
      0.973001, 1.264056, 0.171474},{0.965044, 1.239568, 0.155695}}],
    Polygon[{{0.948645, 1.276466, 0.171474},{0.965044, 1.299038, 0.183031},{
      0.981623, 1.290591, 0.183031},{0.973001, 1.264056, 0.171474}}],
    Polygon[{{0.965044, 1.299038, 0.183031},{0.982304, 1.322795, 0.190081},{
      0.990697, 1.318518, 0.190081},{0.981623, 1.290591, 0.183031}}],
    Polygon[{{0.990697, 1.318518, -0.190081},{0.981623, 1.290591, -0.183031},{
      1.000000, 1.287680, -0.183031},{1.000000, 1.317045, -0.190081}}],
    Polygon[{{0.981623, 1.290591, -0.183031},{0.973001, 1.264056, -0.171474},{
      1.000000, 1.259780, -0.171474},{1.000000, 1.287680, -0.183031}}],
    Polygon[{{0.973001, 1.264056, -0.171474},{0.965044, 1.239568, -0.155695},{
      1.000000, 1.234031, -0.155695},{1.000000, 1.259780, -0.171474}}],
    Polygon[{{0.965044, 1.239568, -0.155695},{0.957948, 1.217728, -0.136083},{
      1.000000, 1.211068, -0.136083},{1.000000, 1.234031, -0.155695}}],
    Polygon[{{0.957948, 1.217728, -0.136083},{0.951887, 1.199075, -0.113119},{
      1.000000, 1.191455, -0.113119},{1.000000, 1.211068, -0.136083}}],
    Polygon[{{0.951887, 1.199075, -0.113119},{0.947012, 1.184069, -0.087371},{
      1.000000, 1.175676, -0.087371},{1.000000, 1.191455, -0.113119}}],
    Polygon[{{0.947012, 1.184069, -0.087371},{0.943440, 1.173078, -0.059470},{
      1.000000, 1.164120, -0.059470},{1.000000, 1.175676, -0.087371}}],
    Polygon[{{0.943440, 1.173078, -0.059470},{0.941262, 1.166373, -0.030106},{
      1.000000, 1.157070, -0.030106},{1.000000, 1.164120, -0.059470}}],
    Polygon[{{0.941262, 1.166373, -0.030106},{0.940530, 1.164120, 0.000000},{
      1.000000, 1.154701, 0.000000},{1.000000, 1.157070, -0.030106}}],
    Polygon[{{0.940530, 1.164120, 0.000000},{0.941262, 1.166373, 0.030106},{
      1.000000, 1.157070, 0.030106},{1.000000, 1.154701, 0.000000}}],
    Polygon[{{0.941262, 1.166373, 0.030106},{0.943440, 1.173078, 0.059470},{
      1.000000, 1.164120, 0.059470},{1.000000, 1.157070, 0.030106}}],
    Polygon[{{0.943440, 1.173078, 0.059470},{0.947012, 1.184069, 0.087371},{
      1.000000, 1.175676, 0.087371},{1.000000, 1.164120, 0.059470}}],
    Polygon[{{0.947012, 1.184069, 0.087371},{0.951887, 1.199075, 0.113119},{
      1.000000, 1.191455, 0.113119},{1.000000, 1.175676, 0.087371}}],
    Polygon[{{0.951887, 1.199075, 0.113119},{0.957948, 1.217728, 0.136083},{
      1.000000, 1.211068, 0.136083},{1.000000, 1.191455, 0.113119}}],
    Polygon[{{0.957948, 1.217728, 0.136083},{0.965044, 1.239568, 0.155695},{
      1.000000, 1.234031, 0.155695},{1.000000, 1.211068, 0.136083}}],
    Polygon[{{0.965044, 1.239568, 0.155695},{0.973001, 1.264056, 0.171474},{
      1.000000, 1.259780, 0.171474},{1.000000, 1.234031, 0.155695}}],
    Polygon[{{0.973001, 1.264056, 0.171474},{0.981623, 1.290591, 0.183031},{
      1.000000, 1.287680, 0.183031},{1.000000, 1.259780, 0.171474}}],
    Polygon[{{0.981623, 1.290591, 0.183031},{0.990697, 1.318518, 0.190081},{
      1.000000, 1.317045, 0.190081},{1.000000, 1.287680, 0.183031}}],
    Polygon[{{1.000000, 1.317045, -0.190081},{1.000000, 1.287680, -0.183031},{
      1.018377, 1.290591, -0.183031},{1.009303, 1.318518, -0.190081}}],
    Polygon[{{1.000000, 1.287680, -0.183031},{1.000000, 1.259780, -0.171474},{
      1.026999, 1.264056, -0.171474},{1.018377, 1.290591, -0.183031}}],
    Polygon[{{1.000000, 1.259780, -0.171474},{1.000000, 1.234031, -0.155695},{
      1.034956, 1.239568, -0.155695},{1.026999, 1.264056, -0.171474}}],
    Polygon[{{1.000000, 1.234031, -0.155695},{1.000000, 1.211068, -0.136083},{
      1.042052, 1.217728, -0.136083},{1.034956, 1.239568, -0.155695}}],
    Polygon[{{1.000000, 1.211068, -0.136083},{1.000000, 1.191455, -0.113119},{
      1.048113, 1.199075, -0.113119},{1.042052, 1.217728, -0.136083}}],
    Polygon[{{1.000000, 1.191455, -0.113119},{1.000000, 1.175676, -0.087371},{
      1.052988, 1.184069, -0.087371},{1.048113, 1.199075, -0.113119}}],
    Polygon[{{1.000000, 1.175676, -0.087371},{1.000000, 1.164120, -0.059470},{
      1.056560, 1.173078, -0.059470},{1.052988, 1.184069, -0.087371}}],
    Polygon[{{1.000000, 1.164120, -0.059470},{1.000000, 1.157070, -0.030106},{
      1.058738, 1.166373, -0.030106},{1.056560, 1.173078, -0.059470}}],
    Polygon[{{1.000000, 1.157070, -0.030106},{1.000000, 1.154701, 0.000000},{
      1.059470, 1.164120, 0.000000},{1.058738, 1.166373, -0.030106}}],
    Polygon[{{1.000000, 1.154701, 0.000000},{1.000000, 1.157070, 0.030106},{
      1.058738, 1.166373, 0.030106},{1.059470, 1.164120, 0.000000}}],
    Polygon[{{1.000000, 1.157070, 0.030106},{1.000000, 1.164120, 0.059470},{
      1.056560, 1.173078, 0.059470},{1.058738, 1.166373, 0.030106}}],
    Polygon[{{1.000000, 1.164120, 0.059470},{1.000000, 1.175676, 0.087371},{
      1.052988, 1.184069, 0.087371},{1.056560, 1.173078, 0.059470}}],
    Polygon[{{1.000000, 1.175676, 0.087371},{1.000000, 1.191455, 0.113119},{
      1.048113, 1.199075, 0.113119},{1.052988, 1.184069, 0.087371}}],
    Polygon[{{1.000000, 1.191455, 0.113119},{1.000000, 1.211068, 0.136083},{
      1.042052, 1.217728, 0.136083},{1.048113, 1.199075, 0.113119}}],
    Polygon[{{1.000000, 1.211068, 0.136083},{1.000000, 1.234031, 0.155695},{
      1.034956, 1.239568, 0.155695},{1.042052, 1.217728, 0.136083}}],
    Polygon[{{1.000000, 1.234031, 0.155695},{1.000000, 1.259780, 0.171474},{
      1.026999, 1.264056, 0.171474},{1.034956, 1.239568, 0.155695}}],
    Polygon[{{1.000000, 1.259780, 0.171474},{1.000000, 1.287680, 0.183031},{
      1.018377, 1.290591, 0.183031},{1.026999, 1.264056, 0.171474}}],
    Polygon[{{1.000000, 1.287680, 0.183031},{1.000000, 1.317045, 0.190081},{
      1.009303, 1.318518, 0.190081},{1.018377, 1.290591, 0.183031}}],
    Polygon[{{1.009303, 1.318518, -0.190081},{1.018377, 1.290591, -0.183031},{
      1.034956, 1.299038, -0.183031},{1.017696, 1.322795, -0.190081}}],
    Polygon[{{1.018377, 1.290591, -0.183031},{1.026999, 1.264056, -0.171474},{
      1.051355, 1.276466, -0.171474},{1.034956, 1.299038, -0.183031}}],
    Polygon[{{1.026999, 1.264056, -0.171474},{1.034956, 1.239568, -0.155695},{
      1.066490, 1.255635, -0.155695},{1.051355, 1.276466, -0.171474}}],
    Polygon[{{1.034956, 1.239568, -0.155695},{1.042052, 1.217728, -0.136083},{
      1.079987, 1.237057, -0.136083},{1.066490, 1.255635, -0.155695}}],
    Polygon[{{1.042052, 1.217728, -0.136083},{1.048113, 1.199075, -0.113119},{
      1.091515, 1.221190, -0.113119},{1.079987, 1.237057, -0.136083}}],
    Polygon[{{1.048113, 1.199075, -0.113119},{1.052988, 1.184069, -0.087371},{
      1.100790, 1.208425, -0.087371},{1.091515, 1.221190, -0.113119}}],
    Polygon[{{1.052988, 1.184069, -0.087371},{1.056560, 1.173078, -0.059470},{
      1.107583, 1.199075, -0.059470},{1.100790, 1.208425, -0.087371}}],
    Polygon[{{1.056560, 1.173078, -0.059470},{1.058738, 1.166373, -0.030106},{
      1.111727, 1.193372, -0.030106},{1.107583, 1.199075, -0.059470}}],
    Polygon[{{1.058738, 1.166373, -0.030106},{1.059470, 1.164120, 0.000000},{
      1.113119, 1.191455, 0.000000},{1.111727, 1.193372, -0.030106}}],
    Polygon[{{1.059470, 1.164120, 0.000000},{1.058738, 1.166373, 0.030106},{
      1.111727, 1.193372, 0.030106},{1.113119, 1.191455, 0.000000}}],
    Polygon[{{1.058738, 1.166373, 0.030106},{1.056560, 1.173078, 0.059470},{
      1.107583, 1.199075, 0.059470},{1.111727, 1.193372, 0.030106}}],
    Polygon[{{1.056560, 1.173078, 0.059470},{1.052988, 1.184069, 0.087371},{
      1.100790, 1.208425, 0.087371},{1.107583, 1.199075, 0.059470}}],
    Polygon[{{1.052988, 1.184069, 0.087371},{1.048113, 1.199075, 0.113119},{
      1.091515, 1.221190, 0.113119},{1.100790, 1.208425, 0.087371}}],
    Polygon[{{1.048113, 1.199075, 0.113119},{1.042052, 1.217728, 0.136083},{
      1.079987, 1.237057, 0.136083},{1.091515, 1.221190, 0.113119}}],
    Polygon[{{1.042052, 1.217728, 0.136083},{1.034956, 1.239568, 0.155695},{
      1.066490, 1.255635, 0.155695},{1.079987, 1.237057, 0.136083}}],
    Polygon[{{1.034956, 1.239568, 0.155695},{1.026999, 1.264056, 0.171474},{
      1.051355, 1.276466, 0.171474},{1.066490, 1.255635, 0.155695}}],
    Polygon[{{1.026999, 1.264056, 0.171474},{1.018377, 1.290591, 0.183031},{
      1.034956, 1.299038, 0.183031},{1.051355, 1.276466, 0.171474}}],
    Polygon[{{1.018377, 1.290591, 0.183031},{1.009303, 1.318518, 0.190081},{
      1.017696, 1.322795, 0.190081},{1.034956, 1.299038, 0.183031}}],
    Polygon[{{1.017696, 1.322795, -0.190081},{1.034956, 1.299038, -0.183031},{
      1.048113, 1.312195, -0.183031},{1.024356, 1.329455, -0.190081}}],
    Polygon[{{1.034956, 1.299038, -0.183031},{1.051355, 1.276466, -0.171474},{
      1.070684, 1.295796, -0.171474},{1.048113, 1.312195, -0.183031}}],
    Polygon[{{1.051355, 1.276466, -0.171474},{1.066490, 1.255635, -0.155695},{
      1.091515, 1.280661, -0.155695},{1.070684, 1.295796, -0.171474}}],
    Polygon[{{1.066490, 1.255635, -0.155695},{1.079987, 1.237057, -0.136083},{
      1.110093, 1.267163, -0.136083},{1.091515, 1.280661, -0.155695}}],
    Polygon[{{1.079987, 1.237057, -0.136083},{1.091515, 1.221190, -0.113119},{
      1.125960, 1.255635, -0.113119},{1.110093, 1.267163, -0.136083}}],
    Polygon[{{1.091515, 1.221190, -0.113119},{1.100790, 1.208425, -0.087371},{
      1.138726, 1.246361, -0.087371},{1.125960, 1.255635, -0.113119}}],
    Polygon[{{1.100790, 1.208425, -0.087371},{1.107583, 1.199075, -0.059470},{
      1.148075, 1.239568, -0.059470},{1.138726, 1.246361, -0.087371}}],
    Polygon[{{1.107583, 1.199075, -0.059470},{1.111727, 1.193372, -0.030106},{
      1.153779, 1.235424, -0.030106},{1.148075, 1.239568, -0.059470}}],
    Polygon[{{1.111727, 1.193372, -0.030106},{1.113119, 1.191455, 0.000000},{
      1.155695, 1.234031, 0.000000},{1.153779, 1.235424, -0.030106}}],
    Polygon[{{1.113119, 1.191455, 0.000000},{1.111727, 1.193372, 0.030106},{
      1.153779, 1.235424, 0.030106},{1.155695, 1.234031, 0.000000}}],
    Polygon[{{1.111727, 1.193372, 0.030106},{1.107583, 1.199075, 0.059470},{
      1.148075, 1.239568, 0.059470},{1.153779, 1.235424, 0.030106}}],
    Polygon[{{1.107583, 1.199075, 0.059470},{1.100790, 1.208425, 0.087371},{
      1.138726, 1.246361, 0.087371},{1.148075, 1.239568, 0.059470}}],
    Polygon[{{1.100790, 1.208425, 0.087371},{1.091515, 1.221190, 0.113119},{
      1.125960, 1.255635, 0.113119},{1.138726, 1.246361, 0.087371}}],
    Polygon[{{1.091515, 1.221190, 0.113119},{1.079987, 1.237057, 0.136083},{
      1.110093, 1.267163, 0.136083},{1.125960, 1.255635, 0.113119}}],
    Polygon[{{1.079987, 1.237057, 0.136083},{1.066490, 1.255635, 0.155695},{
      1.091515, 1.280661, 0.155695},{1.110093, 1.267163, 0.136083}}],
    Polygon[{{1.066490, 1.255635, 0.155695},{1.051355, 1.276466, 0.171474},{
      1.070684, 1.295796, 0.171474},{1.091515, 1.280661, 0.155695}}],
    Polygon[{{1.051355, 1.276466, 0.171474},{1.034956, 1.299038, 0.183031},{
      1.048113, 1.312195, 0.183031},{1.070684, 1.295796, 0.171474}}],
    Polygon[{{1.034956, 1.299038, 0.183031},{1.017696, 1.322795, 0.190081},{
      1.024356, 1.329455, 0.190081},{1.048113, 1.312195, 0.183031}}],
    Polygon[{{1.024356, 1.329455, -0.190081},{1.048113, 1.312195, -0.183031},{
      1.056560, 1.328773, -0.183031},{1.028632, 1.337847, -0.190081}}],
    Polygon[{{1.048113, 1.312195, -0.183031},{1.070684, 1.295796, -0.171474},{
      1.083094, 1.320152, -0.171474},{1.056560, 1.328773, -0.183031}}],
    Polygon[{{1.070684, 1.295796, -0.171474},{1.091515, 1.280661, -0.155695},{
      1.107583, 1.312195, -0.155695},{1.083094, 1.320152, -0.171474}}],
    Polygon[{{1.091515, 1.280661, -0.155695},{1.110093, 1.267163, -0.136083},{
      1.129422, 1.305099, -0.136083},{1.107583, 1.312195, -0.155695}}],
    Polygon[{{1.110093, 1.267163, -0.136083},{1.125960, 1.255635, -0.113119},{
      1.148075, 1.299038, -0.113119},{1.129422, 1.305099, -0.136083}}],
    Polygon[{{1.125960, 1.255635, -0.113119},{1.138726, 1.246361, -0.087371},{
      1.163082, 1.294162, -0.087371},{1.148075, 1.299038, -0.113119}}],
    Polygon[{{1.138726, 1.246361, -0.087371},{1.148075, 1.239568, -0.059470},{
      1.174073, 1.290591, -0.059470},{1.163082, 1.294162, -0.087371}}],
    Polygon[{{1.148075, 1.239568, -0.059470},{1.153779, 1.235424, -0.030106},{
      1.180778, 1.288412, -0.030106},{1.174073, 1.290591, -0.059470}}],
    Polygon[{{1.153779, 1.235424, -0.030106},{1.155695, 1.234031, 0.000000},{
      1.183031, 1.287680, 0.000000},{1.180778, 1.288412, -0.030106}}],
    Polygon[{{1.155695, 1.234031, 0.000000},{1.153779, 1.235424, 0.030106},{
      1.180778, 1.288412, 0.030106},{1.183031, 1.287680, 0.000000}}],
    Polygon[{{1.153779, 1.235424, 0.030106},{1.148075, 1.239568, 0.059470},{
      1.174073, 1.290591, 0.059470},{1.180778, 1.288412, 0.030106}}],
    Polygon[{{1.148075, 1.239568, 0.059470},{1.138726, 1.246361, 0.087371},{
      1.163082, 1.294162, 0.087371},{1.174073, 1.290591, 0.059470}}],
    Polygon[{{1.138726, 1.246361, 0.087371},{1.125960, 1.255635, 0.113119},{
      1.148075, 1.299038, 0.113119},{1.163082, 1.294162, 0.087371}}],
    Polygon[{{1.125960, 1.255635, 0.113119},{1.110093, 1.267163, 0.136083},{
      1.129422, 1.305099, 0.136083},{1.148075, 1.299038, 0.113119}}],
    Polygon[{{1.110093, 1.267163, 0.136083},{1.091515, 1.280661, 0.155695},{
      1.107583, 1.312195, 0.155695},{1.129422, 1.305099, 0.136083}}],
    Polygon[{{1.091515, 1.280661, 0.155695},{1.070684, 1.295796, 0.171474},{
      1.083094, 1.320152, 0.171474},{1.107583, 1.312195, 0.155695}}],
    Polygon[{{1.070684, 1.295796, 0.171474},{1.048113, 1.312195, 0.183031},{
      1.056560, 1.328773, 0.183031},{1.083094, 1.320152, 0.171474}}],
    Polygon[{{1.048113, 1.312195, 0.183031},{1.024356, 1.329455, 0.190081},{
      1.028632, 1.337847, 0.190081},{1.056560, 1.328773, 0.183031}}],
    Polygon[{{1.028632, 1.337847, -0.190081},{1.056560, 1.328773, -0.183031},{
      1.059470, 1.347151, -0.183031},{1.030106, 1.347151, -0.190081}}],
    Polygon[{{1.056560, 1.328773, -0.183031},{1.083094, 1.320152, -0.171474},{
      1.087371, 1.347151, -0.171474},{1.059470, 1.347151, -0.183031}}],
    Polygon[{{1.083094, 1.320152, -0.171474},{1.107583, 1.312195, -0.155695},{
      1.113119, 1.347151, -0.155695},{1.087371, 1.347151, -0.171474}}],
    Polygon[{{1.107583, 1.312195, -0.155695},{1.129422, 1.305099, -0.136083},{
      1.136083, 1.347151, -0.136083},{1.113119, 1.347151, -0.155695}}],
    Polygon[{{1.129422, 1.305099, -0.136083},{1.148075, 1.299038, -0.113119},{
      1.155695, 1.347151, -0.113119},{1.136083, 1.347151, -0.136083}}],
    Polygon[{{1.148075, 1.299038, -0.113119},{1.163082, 1.294162, -0.087371},{
      1.171474, 1.347151, -0.087371},{1.155695, 1.347151, -0.113119}}],
    Polygon[{{1.163082, 1.294162, -0.087371},{1.174073, 1.290591, -0.059470},{
      1.183031, 1.347151, -0.059470},{1.171474, 1.347151, -0.087371}}],
    Polygon[{{1.174073, 1.290591, -0.059470},{1.180778, 1.288412, -0.030106},{
      1.190081, 1.347151, -0.030106},{1.183031, 1.347151, -0.059470}}],
    Polygon[{{1.180778, 1.288412, -0.030106},{1.183031, 1.287680, 0.000000},{
      1.192450, 1.347151, 0.000000},{1.190081, 1.347151, -0.030106}}],
    Polygon[{{1.183031, 1.287680, 0.000000},{1.180778, 1.288412, 0.030106},{
      1.190081, 1.347151, 0.030106},{1.192450, 1.347151, 0.000000}}],
    Polygon[{{1.180778, 1.288412, 0.030106},{1.174073, 1.290591, 0.059470},{
      1.183031, 1.347151, 0.059470},{1.190081, 1.347151, 0.030106}}],
    Polygon[{{1.174073, 1.290591, 0.059470},{1.163082, 1.294162, 0.087371},{
      1.171474, 1.347151, 0.087371},{1.183031, 1.347151, 0.059470}}],
    Polygon[{{1.163082, 1.294162, 0.087371},{1.148075, 1.299038, 0.113119},{
      1.155695, 1.347151, 0.113119},{1.171474, 1.347151, 0.087371}}],
    Polygon[{{1.148075, 1.299038, 0.113119},{1.129422, 1.305099, 0.136083},{
      1.136083, 1.347151, 0.136083},{1.155695, 1.347151, 0.113119}}],
    Polygon[{{1.129422, 1.305099, 0.136083},{1.107583, 1.312195, 0.155695},{
      1.113119, 1.347151, 0.155695},{1.136083, 1.347151, 0.136083}}],
    Polygon[{{1.107583, 1.312195, 0.155695},{1.083094, 1.320152, 0.171474},{
      1.087371, 1.347151, 0.171474},{1.113119, 1.347151, 0.155695}}],
    Polygon[{{1.083094, 1.320152, 0.171474},{1.056560, 1.328773, 0.183031},{
      1.059470, 1.347151, 0.183031},{1.087371, 1.347151, 0.171474}}],
    Polygon[{{1.056560, 1.328773, 0.183031},{1.028632, 1.337847, 0.190081},{
      1.030106, 1.347151, 0.190081},{1.059470, 1.347151, 0.183031}}],
    Polygon[{{1.010035, 1.603751, -0.063360},{1.019823, 1.603751, -0.061010},{
      1.018853, 1.609877, -0.061010},{1.009544, 1.606852, -0.063360}}],
    Polygon[{{1.019823, 1.603751, -0.061010},{1.029124, 1.603751, -0.057158},{
      1.027698, 1.612750, -0.057158},{1.018853, 1.609877, -0.061010}}],
    Polygon[{{1.029124, 1.603751, -0.057158},{1.037706, 1.603751, -0.051898},{
      1.035861, 1.615403, -0.051898},{1.027698, 1.612750, -0.057158}}],
    Polygon[{{1.037706, 1.603751, -0.051898},{1.045361, 1.603751, -0.045361},{
      1.043141, 1.617768, -0.045361},{1.035861, 1.615403, -0.051898}}],
    Polygon[{{1.045361, 1.603751, -0.045361},{1.051898, 1.603751, -0.037706},{
      1.049358, 1.619788, -0.037706},{1.043141, 1.617768, -0.045361}}],
    Polygon[{{1.051898, 1.603751, -0.037706},{1.057158, 1.603751, -0.029124},{
      1.054361, 1.621414, -0.029124},{1.049358, 1.619788, -0.037706}}],
    Polygon[{{1.057158, 1.603751, -0.029124},{1.061010, 1.603751, -0.019823},{
      1.058024, 1.622604, -0.019823},{1.054361, 1.621414, -0.029124}}],
    Polygon[{{1.061010, 1.603751, -0.019823},{1.063360, 1.603751, -0.010035},{
      1.060259, 1.623330, -0.010035},{1.058024, 1.622604, -0.019823}}],
    Polygon[{{1.063360, 1.603751, -0.010035},{1.064150, 1.603751, 0.000000},{
      1.061010, 1.623574, 0.000000},{1.060259, 1.623330, -0.010035}}],
    Polygon[{{1.064150, 1.603751, 0.000000},{1.063360, 1.603751, 0.010035},{
      1.060259, 1.623330, 0.010035},{1.061010, 1.623574, 0.000000}}],
    Polygon[{{1.063360, 1.603751, 0.010035},{1.061010, 1.603751, 0.019823},{
      1.058024, 1.622604, 0.019823},{1.060259, 1.623330, 0.010035}}],
    Polygon[{{1.061010, 1.603751, 0.019823},{1.057158, 1.603751, 0.029124},{
      1.054361, 1.621414, 0.029124},{1.058024, 1.622604, 0.019823}}],
    Polygon[{{1.057158, 1.603751, 0.029124},{1.051898, 1.603751, 0.037706},{
      1.049358, 1.619788, 0.037706},{1.054361, 1.621414, 0.029124}}],
    Polygon[{{1.051898, 1.603751, 0.037706},{1.045361, 1.603751, 0.045361},{
      1.043141, 1.617768, 0.045361},{1.049358, 1.619788, 0.037706}}],
    Polygon[{{1.045361, 1.603751, 0.045361},{1.037706, 1.603751, 0.051898},{
      1.035861, 1.615403, 0.051898},{1.043141, 1.617768, 0.045361}}],
    Polygon[{{1.037706, 1.603751, 0.051898},{1.029124, 1.603751, 0.057158},{
      1.027698, 1.612750, 0.057158},{1.035861, 1.615403, 0.051898}}],
    Polygon[{{1.029124, 1.603751, 0.057158},{1.019823, 1.603751, 0.061010},{
      1.018853, 1.609877, 0.061010},{1.027698, 1.612750, 0.057158}}],
    Polygon[{{1.019823, 1.603751, 0.061010},{1.010035, 1.603751, 0.063360},{
      1.009544, 1.606852, 0.063360},{1.018853, 1.609877, 0.061010}}],
    Polygon[{{1.009544, 1.606852, -0.063360},{1.018853, 1.609877, -0.061010},{
      1.016037, 1.615403, -0.061010},{1.008119, 1.609649, -0.063360}}],
    Polygon[{{1.018853, 1.609877, -0.061010},{1.027698, 1.612750, -0.057158},{
      1.023561, 1.620869, -0.057158},{1.016037, 1.615403, -0.061010}}],
    Polygon[{{1.027698, 1.612750, -0.057158},{1.035861, 1.615403, -0.051898},{
      1.030505, 1.625914, -0.051898},{1.023561, 1.620869, -0.057158}}],
    Polygon[{{1.035861, 1.615403, -0.051898},{1.043141, 1.617768, -0.045361},{
      1.036698, 1.630413, -0.045361},{1.030505, 1.625914, -0.051898}}],
    Polygon[{{1.043141, 1.617768, -0.045361},{1.049358, 1.619788, -0.037706},{
      1.041987, 1.634256, -0.037706},{1.036698, 1.630413, -0.045361}}],
    Polygon[{{1.049358, 1.619788, -0.037706},{1.054361, 1.621414, -0.029124},{
      1.046242, 1.637347, -0.029124},{1.041987, 1.634256, -0.037706}}],
    Polygon[{{1.054361, 1.621414, -0.029124},{1.058024, 1.622604, -0.019823},{
      1.049358, 1.639612, -0.019823},{1.046242, 1.637347, -0.029124}}],
    Polygon[{{1.058024, 1.622604, -0.019823},{1.060259, 1.623330, -0.010035},{
      1.051260, 1.640993, -0.010035},{1.049358, 1.639612, -0.019823}}],
    Polygon[{{1.060259, 1.623330, -0.010035},{1.061010, 1.623574, 0.000000},{
      1.051898, 1.641457, 0.000000},{1.051260, 1.640993, -0.010035}}],
    Polygon[{{1.061010, 1.623574, 0.000000},{1.060259, 1.623330, 0.010035},{
      1.051260, 1.640993, 0.010035},{1.051898, 1.641457, 0.000000}}],
    Polygon[{{1.060259, 1.623330, 0.010035},{1.058024, 1.622604, 0.019823},{
      1.049358, 1.639612, 0.019823},{1.051260, 1.640993, 0.010035}}],
    Polygon[{{1.058024, 1.622604, 0.019823},{1.054361, 1.621414, 0.029124},{
      1.046242, 1.637347, 0.029124},{1.049358, 1.639612, 0.019823}}],
    Polygon[{{1.054361, 1.621414, 0.029124},{1.049358, 1.619788, 0.037706},{
      1.041987, 1.634256, 0.037706},{1.046242, 1.637347, 0.029124}}],
    Polygon[{{1.049358, 1.619788, 0.037706},{1.043141, 1.617768, 0.045361},{
      1.036698, 1.630413, 0.045361},{1.041987, 1.634256, 0.037706}}],
    Polygon[{{1.043141, 1.617768, 0.045361},{1.035861, 1.615403, 0.051898},{
      1.030505, 1.625914, 0.051898},{1.036698, 1.630413, 0.045361}}],
    Polygon[{{1.035861, 1.615403, 0.051898},{1.027698, 1.612750, 0.057158},{
      1.023561, 1.620869, 0.057158},{1.030505, 1.625914, 0.051898}}],
    Polygon[{{1.027698, 1.612750, 0.057158},{1.018853, 1.609877, 0.061010},{
      1.016037, 1.615403, 0.061010},{1.023561, 1.620869, 0.057158}}],
    Polygon[{{1.018853, 1.609877, 0.061010},{1.009544, 1.606852, 0.063360},{
      1.008119, 1.609649, 0.063360},{1.016037, 1.615403, 0.061010}}],
    Polygon[{{1.008119, 1.609649, -0.063360},{1.016037, 1.615403, -0.061010},{
      1.011652, 1.619788, -0.061010},{1.005899, 1.611869, -0.063360}}],
    Polygon[{{1.016037, 1.615403, -0.061010},{1.023561, 1.620869, -0.057158},{
      1.017118, 1.627312, -0.057158},{1.011652, 1.619788, -0.061010}}],
    Polygon[{{1.023561, 1.620869, -0.057158},{1.030505, 1.625914, -0.051898},{
      1.022163, 1.634256, -0.051898},{1.017118, 1.627312, -0.057158}}],
    Polygon[{{1.030505, 1.625914, -0.051898},{1.036698, 1.630413, -0.045361},{
      1.026662, 1.640448, -0.045361},{1.022163, 1.634256, -0.051898}}],
    Polygon[{{1.036698, 1.630413, -0.045361},{1.041987, 1.634256, -0.037706},{
      1.030505, 1.645738, -0.037706},{1.026662, 1.640448, -0.045361}}],
    Polygon[{{1.041987, 1.634256, -0.037706},{1.046242, 1.637347, -0.029124},{
      1.033597, 1.649993, -0.029124},{1.030505, 1.645738, -0.037706}}],
    Polygon[{{1.046242, 1.637347, -0.029124},{1.049358, 1.639612, -0.019823},{
      1.035861, 1.653109, -0.019823},{1.033597, 1.649993, -0.029124}}],
    Polygon[{{1.049358, 1.639612, -0.019823},{1.051260, 1.640993, -0.010035},{
      1.037242, 1.655010, -0.010035},{1.035861, 1.653109, -0.019823}}],
    Polygon[{{1.051260, 1.640993, -0.010035},{1.051898, 1.641457, 0.000000},{
      1.037706, 1.655649, 0.000000},{1.037242, 1.655010, -0.010035}}],
    Polygon[{{1.051898, 1.641457, 0.000000},{1.051260, 1.640993, 0.010035},{
      1.037242, 1.655010, 0.010035},{1.037706, 1.655649, 0.000000}}],
    Polygon[{{1.051260, 1.640993, 0.010035},{1.049358, 1.639612, 0.019823},{
      1.035861, 1.653109, 0.019823},{1.037242, 1.655010, 0.010035}}],
    Polygon[{{1.049358, 1.639612, 0.019823},{1.046242, 1.637347, 0.029124},{
      1.033597, 1.649993, 0.029124},{1.035861, 1.653109, 0.019823}}],
    Polygon[{{1.046242, 1.637347, 0.029124},{1.041987, 1.634256, 0.037706},{
      1.030505, 1.645738, 0.037706},{1.033597, 1.649993, 0.029124}}],
    Polygon[{{1.041987, 1.634256, 0.037706},{1.036698, 1.630413, 0.045361},{
      1.026662, 1.640448, 0.045361},{1.030505, 1.645738, 0.037706}}],
    Polygon[{{1.036698, 1.630413, 0.045361},{1.030505, 1.625914, 0.051898},{
      1.022163, 1.634256, 0.051898},{1.026662, 1.640448, 0.045361}}],
    Polygon[{{1.030505, 1.625914, 0.051898},{1.023561, 1.620869, 0.057158},{
      1.017118, 1.627312, 0.057158},{1.022163, 1.634256, 0.051898}}],
    Polygon[{{1.023561, 1.620869, 0.057158},{1.016037, 1.615403, 0.061010},{
      1.011652, 1.619788, 0.061010},{1.017118, 1.627312, 0.057158}}],
    Polygon[{{1.016037, 1.615403, 0.061010},{1.008119, 1.609649, 0.063360},{
      1.005899, 1.611869, 0.063360},{1.011652, 1.619788, 0.061010}}],
    Polygon[{{1.005899, 1.611869, -0.063360},{1.011652, 1.619788, -0.061010},{
      1.006126, 1.622604, -0.061010},{1.003101, 1.613295, -0.063360}}],
    Polygon[{{1.011652, 1.619788, -0.061010},{1.017118, 1.627312, -0.057158},{
      1.009000, 1.631449, -0.057158},{1.006126, 1.622604, -0.061010}}],
    Polygon[{{1.017118, 1.627312, -0.057158},{1.022163, 1.634256, -0.051898},{
      1.011652, 1.639612, -0.051898},{1.009000, 1.631449, -0.057158}}],
    Polygon[{{1.022163, 1.634256, -0.051898},{1.026662, 1.640448, -0.045361},{
      1.014017, 1.646892, -0.045361},{1.011652, 1.639612, -0.051898}}],
    Polygon[{{1.026662, 1.640448, -0.045361},{1.030505, 1.645738, -0.037706},{
      1.016037, 1.653109, -0.037706},{1.014017, 1.646892, -0.045361}}],
    Polygon[{{1.030505, 1.645738, -0.037706},{1.033597, 1.649993, -0.029124},{
      1.017663, 1.658111, -0.029124},{1.016037, 1.653109, -0.037706}}],
    Polygon[{{1.033597, 1.649993, -0.029124},{1.035861, 1.653109, -0.019823},{
      1.018853, 1.661775, -0.019823},{1.017663, 1.658111, -0.029124}}],
    Polygon[{{1.035861, 1.653109, -0.019823},{1.037242, 1.655010, -0.010035},{
      1.019579, 1.664010, -0.010035},{1.018853, 1.661775, -0.019823}}],
    Polygon[{{1.037242, 1.655010, -0.010035},{1.037706, 1.655649, 0.000000},{
      1.019823, 1.664761, 0.000000},{1.019579, 1.664010, -0.010035}}],
    Polygon[{{1.037706, 1.655649, 0.000000},{1.037242, 1.655010, 0.010035},{
      1.019579, 1.664010, 0.010035},{1.019823, 1.664761, 0.000000}}],
    Polygon[{{1.037242, 1.655010, 0.010035},{1.035861, 1.653109, 0.019823},{
      1.018853, 1.661775, 0.019823},{1.019579, 1.664010, 0.010035}}],
    Polygon[{{1.035861, 1.653109, 0.019823},{1.033597, 1.649993, 0.029124},{
      1.017663, 1.658111, 0.029124},{1.018853, 1.661775, 0.019823}}],
    Polygon[{{1.033597, 1.649993, 0.029124},{1.030505, 1.645738, 0.037706},{
      1.016037, 1.653109, 0.037706},{1.017663, 1.658111, 0.029124}}],
    Polygon[{{1.030505, 1.645738, 0.037706},{1.026662, 1.640448, 0.045361},{
      1.014017, 1.646892, 0.045361},{1.016037, 1.653109, 0.037706}}],
    Polygon[{{1.026662, 1.640448, 0.045361},{1.022163, 1.634256, 0.051898},{
      1.011652, 1.639612, 0.051898},{1.014017, 1.646892, 0.045361}}],
    Polygon[{{1.022163, 1.634256, 0.051898},{1.017118, 1.627312, 0.057158},{
      1.009000, 1.631449, 0.057158},{1.011652, 1.639612, 0.051898}}],
    Polygon[{{1.017118, 1.627312, 0.057158},{1.011652, 1.619788, 0.061010},{
      1.006126, 1.622604, 0.061010},{1.009000, 1.631449, 0.057158}}],
    Polygon[{{1.011652, 1.619788, 0.061010},{1.005899, 1.611869, 0.063360},{
      1.003101, 1.613295, 0.063360},{1.006126, 1.622604, 0.061010}}],
    Polygon[{{1.003101, 1.613295, -0.063360},{1.006126, 1.622604, -0.061010},{
      1.000000, 1.623574, -0.061010},{1.000000, 1.613786, -0.063360}}],
    Polygon[{{1.006126, 1.622604, -0.061010},{1.009000, 1.631449, -0.057158},{
      1.000000, 1.632874, -0.057158},{1.000000, 1.623574, -0.061010}}],
    Polygon[{{1.009000, 1.631449, -0.057158},{1.011652, 1.639612, -0.051898},{
      1.000000, 1.641457, -0.051898},{1.000000, 1.632874, -0.057158}}],
    Polygon[{{1.011652, 1.639612, -0.051898},{1.014017, 1.646892, -0.045361},{
      1.000000, 1.649112, -0.045361},{1.000000, 1.641457, -0.051898}}],
    Polygon[{{1.014017, 1.646892, -0.045361},{1.016037, 1.653109, -0.037706},{
      1.000000, 1.655649, -0.037706},{1.000000, 1.649112, -0.045361}}],
    Polygon[{{1.016037, 1.653109, -0.037706},{1.017663, 1.658111, -0.029124},{
      1.000000, 1.660909, -0.029124},{1.000000, 1.655649, -0.037706}}],
    Polygon[{{1.017663, 1.658111, -0.029124},{1.018853, 1.661775, -0.019823},{
      1.000000, 1.664761, -0.019823},{1.000000, 1.660909, -0.029124}}],
    Polygon[{{1.018853, 1.661775, -0.019823},{1.019579, 1.664010, -0.010035},{
      1.000000, 1.667111, -0.010035},{1.000000, 1.664761, -0.019823}}],
    Polygon[{{1.019579, 1.664010, -0.010035},{1.019823, 1.664761, 0.000000},{
      1.000000, 1.667901, 0.000000},{1.000000, 1.667111, -0.010035}}],
    Polygon[{{1.019823, 1.664761, 0.000000},{1.019579, 1.664010, 0.010035},{
      1.000000, 1.667111, 0.010035},{1.000000, 1.667901, 0.000000}}],
    Polygon[{{1.019579, 1.664010, 0.010035},{1.018853, 1.661775, 0.019823},{
      1.000000, 1.664761, 0.019823},{1.000000, 1.667111, 0.010035}}],
    Polygon[{{1.018853, 1.661775, 0.019823},{1.017663, 1.658111, 0.029124},{
      1.000000, 1.660909, 0.029124},{1.000000, 1.664761, 0.019823}}],
    Polygon[{{1.017663, 1.658111, 0.029124},{1.016037, 1.653109, 0.037706},{
      1.000000, 1.655649, 0.037706},{1.000000, 1.660909, 0.029124}}],
    Polygon[{{1.016037, 1.653109, 0.037706},{1.014017, 1.646892, 0.045361},{
      1.000000, 1.649112, 0.045361},{1.000000, 1.655649, 0.037706}}],
    Polygon[{{1.014017, 1.646892, 0.045361},{1.011652, 1.639612, 0.051898},{
      1.000000, 1.641457, 0.051898},{1.000000, 1.649112, 0.045361}}],
    Polygon[{{1.011652, 1.639612, 0.051898},{1.009000, 1.631449, 0.057158},{
      1.000000, 1.632874, 0.057158},{1.000000, 1.641457, 0.051898}}],
    Polygon[{{1.009000, 1.631449, 0.057158},{1.006126, 1.622604, 0.061010},{
      1.000000, 1.623574, 0.061010},{1.000000, 1.632874, 0.057158}}],
    Polygon[{{1.006126, 1.622604, 0.061010},{1.003101, 1.613295, 0.063360},{
      1.000000, 1.613786, 0.063360},{1.000000, 1.623574, 0.061010}}],
    Polygon[{{1.000000, 1.613786, -0.063360},{1.000000, 1.623574, -0.061010},{
      0.993874, 1.622604, -0.061010},{0.996899, 1.613295, -0.063360}}],
    Polygon[{{1.000000, 1.623574, -0.061010},{1.000000, 1.632874, -0.057158},{
      0.991000, 1.631449, -0.057158},{0.993874, 1.622604, -0.061010}}],
    Polygon[{{1.000000, 1.632874, -0.057158},{1.000000, 1.641457, -0.051898},{
      0.988348, 1.639612, -0.051898},{0.991000, 1.631449, -0.057158}}],
    Polygon[{{1.000000, 1.641457, -0.051898},{1.000000, 1.649112, -0.045361},{
      0.985983, 1.646892, -0.045361},{0.988348, 1.639612, -0.051898}}],
    Polygon[{{1.000000, 1.649112, -0.045361},{1.000000, 1.655649, -0.037706},{
      0.983962, 1.653109, -0.037706},{0.985983, 1.646892, -0.045361}}],
    Polygon[{{1.000000, 1.655649, -0.037706},{1.000000, 1.660909, -0.029124},{
      0.982337, 1.658111, -0.029124},{0.983962, 1.653109, -0.037706}}],
    Polygon[{{1.000000, 1.660909, -0.029124},{1.000000, 1.664761, -0.019823},{
      0.981147, 1.661775, -0.019823},{0.982337, 1.658111, -0.029124}}],
    Polygon[{{1.000000, 1.664761, -0.019823},{1.000000, 1.667111, -0.010035},{
      0.980421, 1.664010, -0.010035},{0.981147, 1.661775, -0.019823}}],
    Polygon[{{1.000000, 1.667111, -0.010035},{1.000000, 1.667901, 0.000000},{
      0.980177, 1.664761, 0.000000},{0.980421, 1.664010, -0.010035}}],
    Polygon[{{1.000000, 1.667901, 0.000000},{1.000000, 1.667111, 0.010035},{
      0.980421, 1.664010, 0.010035},{0.980177, 1.664761, 0.000000}}],
    Polygon[{{1.000000, 1.667111, 0.010035},{1.000000, 1.664761, 0.019823},{
      0.981147, 1.661775, 0.019823},{0.980421, 1.664010, 0.010035}}],
    Polygon[{{1.000000, 1.664761, 0.019823},{1.000000, 1.660909, 0.029124},{
      0.982337, 1.658111, 0.029124},{0.981147, 1.661775, 0.019823}}],
    Polygon[{{1.000000, 1.660909, 0.029124},{1.000000, 1.655649, 0.037706},{
      0.983962, 1.653109, 0.037706},{0.982337, 1.658111, 0.029124}}],
    Polygon[{{1.000000, 1.655649, 0.037706},{1.000000, 1.649112, 0.045361},{
      0.985983, 1.646892, 0.045361},{0.983962, 1.653109, 0.037706}}],
    Polygon[{{1.000000, 1.649112, 0.045361},{1.000000, 1.641457, 0.051898},{
      0.988348, 1.639612, 0.051898},{0.985983, 1.646892, 0.045361}}],
    Polygon[{{1.000000, 1.641457, 0.051898},{1.000000, 1.632874, 0.057158},{
      0.991000, 1.631449, 0.057158},{0.988348, 1.639612, 0.051898}}],
    Polygon[{{1.000000, 1.632874, 0.057158},{1.000000, 1.623574, 0.061010},{
      0.993874, 1.622604, 0.061010},{0.991000, 1.631449, 0.057158}}],
    Polygon[{{1.000000, 1.623574, 0.061010},{1.000000, 1.613786, 0.063360},{
      0.996899, 1.613295, 0.063360},{0.993874, 1.622604, 0.061010}}],
    Polygon[{{0.996899, 1.613295, -0.063360},{0.993874, 1.622604, -0.061010},{
      0.988348, 1.619788, -0.061010},{0.994101, 1.611869, -0.063360}}],
    Polygon[{{0.993874, 1.622604, -0.061010},{0.991000, 1.631449, -0.057158},{
      0.982882, 1.627312, -0.057158},{0.988348, 1.619788, -0.061010}}],
    Polygon[{{0.991000, 1.631449, -0.057158},{0.988348, 1.639612, -0.051898},{
      0.977837, 1.634256, -0.051898},{0.982882, 1.627312, -0.057158}}],
    Polygon[{{0.988348, 1.639612, -0.051898},{0.985983, 1.646892, -0.045361},{
      0.973338, 1.640448, -0.045361},{0.977837, 1.634256, -0.051898}}],
    Polygon[{{0.985983, 1.646892, -0.045361},{0.983962, 1.653109, -0.037706},{
      0.969495, 1.645738, -0.037706},{0.973338, 1.640448, -0.045361}}],
    Polygon[{{0.983962, 1.653109, -0.037706},{0.982337, 1.658111, -0.029124},{
      0.966403, 1.649993, -0.029124},{0.969495, 1.645738, -0.037706}}],
    Polygon[{{0.982337, 1.658111, -0.029124},{0.981147, 1.661775, -0.019823},{
      0.964139, 1.653109, -0.019823},{0.966403, 1.649993, -0.029124}}],
    Polygon[{{0.981147, 1.661775, -0.019823},{0.980421, 1.664010, -0.010035},{
      0.962758, 1.655010, -0.010035},{0.964139, 1.653109, -0.019823}}],
    Polygon[{{0.980421, 1.664010, -0.010035},{0.980177, 1.664761, 0.000000},{
      0.962294, 1.655649, 0.000000},{0.962758, 1.655010, -0.010035}}],
    Polygon[{{0.980177, 1.664761, 0.000000},{0.980421, 1.664010, 0.010035},{
      0.962758, 1.655010, 0.010035},{0.962294, 1.655649, 0.000000}}],
    Polygon[{{0.980421, 1.664010, 0.010035},{0.981147, 1.661775, 0.019823},{
      0.964139, 1.653109, 0.019823},{0.962758, 1.655010, 0.010035}}],
    Polygon[{{0.981147, 1.661775, 0.019823},{0.982337, 1.658111, 0.029124},{
      0.966403, 1.649993, 0.029124},{0.964139, 1.653109, 0.019823}}],
    Polygon[{{0.982337, 1.658111, 0.029124},{0.983962, 1.653109, 0.037706},{
      0.969495, 1.645738, 0.037706},{0.966403, 1.649993, 0.029124}}],
    Polygon[{{0.983962, 1.653109, 0.037706},{0.985983, 1.646892, 0.045361},{
      0.973338, 1.640448, 0.045361},{0.969495, 1.645738, 0.037706}}],
    Polygon[{{0.985983, 1.646892, 0.045361},{0.988348, 1.639612, 0.051898},{
      0.977837, 1.634256, 0.051898},{0.973338, 1.640448, 0.045361}}],
    Polygon[{{0.988348, 1.639612, 0.051898},{0.991000, 1.631449, 0.057158},{
      0.982882, 1.627312, 0.057158},{0.977837, 1.634256, 0.051898}}],
    Polygon[{{0.991000, 1.631449, 0.057158},{0.993874, 1.622604, 0.061010},{
      0.988348, 1.619788, 0.061010},{0.982882, 1.627312, 0.057158}}],
    Polygon[{{0.993874, 1.622604, 0.061010},{0.996899, 1.613295, 0.063360},{
      0.994101, 1.611869, 0.063360},{0.988348, 1.619788, 0.061010}}],
    Polygon[{{0.994101, 1.611869, -0.063360},{0.988348, 1.619788, -0.061010},{
      0.983962, 1.615403, -0.061010},{0.991881, 1.609649, -0.063360}}],
    Polygon[{{0.988348, 1.619788, -0.061010},{0.982882, 1.627312, -0.057158},{
      0.976439, 1.620869, -0.057158},{0.983962, 1.615403, -0.061010}}],
    Polygon[{{0.982882, 1.627312, -0.057158},{0.977837, 1.634256, -0.051898},{
      0.969495, 1.625914, -0.051898},{0.976439, 1.620869, -0.057158}}],
    Polygon[{{0.977837, 1.634256, -0.051898},{0.973338, 1.640448, -0.045361},{
      0.963302, 1.630413, -0.045361},{0.969495, 1.625914, -0.051898}}],
    Polygon[{{0.973338, 1.640448, -0.045361},{0.969495, 1.645738, -0.037706},{
      0.958013, 1.634256, -0.037706},{0.963302, 1.630413, -0.045361}}],
    Polygon[{{0.969495, 1.645738, -0.037706},{0.966403, 1.649993, -0.029124},{
      0.953758, 1.637347, -0.029124},{0.958013, 1.634256, -0.037706}}],
    Polygon[{{0.966403, 1.649993, -0.029124},{0.964139, 1.653109, -0.019823},{
      0.950642, 1.639612, -0.019823},{0.953758, 1.637347, -0.029124}}],
    Polygon[{{0.964139, 1.653109, -0.019823},{0.962758, 1.655010, -0.010035},{
      0.948740, 1.640993, -0.010035},{0.950642, 1.639612, -0.019823}}],
    Polygon[{{0.962758, 1.655010, -0.010035},{0.962294, 1.655649, 0.000000},{
      0.948102, 1.641457, 0.000000},{0.948740, 1.640993, -0.010035}}],
    Polygon[{{0.962294, 1.655649, 0.000000},{0.962758, 1.655010, 0.010035},{
      0.948740, 1.640993, 0.010035},{0.948102, 1.641457, 0.000000}}],
    Polygon[{{0.962758, 1.655010, 0.010035},{0.964139, 1.653109, 0.019823},{
      0.950642, 1.639612, 0.019823},{0.948740, 1.640993, 0.010035}}],
    Polygon[{{0.964139, 1.653109, 0.019823},{0.966403, 1.649993, 0.029124},{
      0.953758, 1.637347, 0.029124},{0.950642, 1.639612, 0.019823}}],
    Polygon[{{0.966403, 1.649993, 0.029124},{0.969495, 1.645738, 0.037706},{
      0.958013, 1.634256, 0.037706},{0.953758, 1.637347, 0.029124}}],
    Polygon[{{0.969495, 1.645738, 0.037706},{0.973338, 1.640448, 0.045361},{
      0.963302, 1.630413, 0.045361},{0.958013, 1.634256, 0.037706}}],
    Polygon[{{0.973338, 1.640448, 0.045361},{0.977837, 1.634256, 0.051898},{
      0.969495, 1.625914, 0.051898},{0.963302, 1.630413, 0.045361}}],
    Polygon[{{0.977837, 1.634256, 0.051898},{0.982882, 1.627312, 0.057158},{
      0.976439, 1.620869, 0.057158},{0.969495, 1.625914, 0.051898}}],
    Polygon[{{0.982882, 1.627312, 0.057158},{0.988348, 1.619788, 0.061010},{
      0.983962, 1.615403, 0.061010},{0.976439, 1.620869, 0.057158}}],
    Polygon[{{0.988348, 1.619788, 0.061010},{0.994101, 1.611869, 0.063360},{
      0.991881, 1.609649, 0.063360},{0.983962, 1.615403, 0.061010}}],
    Polygon[{{0.991881, 1.609649, -0.063360},{0.983962, 1.615403, -0.061010},{
      0.981147, 1.609877, -0.061010},{0.990456, 1.606852, -0.063360}}],
    Polygon[{{0.983962, 1.615403, -0.061010},{0.976439, 1.620869, -0.057158},{
      0.972302, 1.612750, -0.057158},{0.981147, 1.609877, -0.061010}}],
    Polygon[{{0.976439, 1.620869, -0.057158},{0.969495, 1.625914, -0.051898},{
      0.964139, 1.615403, -0.051898},{0.972302, 1.612750, -0.057158}}],
    Polygon[{{0.969495, 1.625914, -0.051898},{0.963302, 1.630413, -0.045361},{
      0.956859, 1.617768, -0.045361},{0.964139, 1.615403, -0.051898}}],
    Polygon[{{0.963302, 1.630413, -0.045361},{0.958013, 1.634256, -0.037706},{
      0.950642, 1.619788, -0.037706},{0.956859, 1.617768, -0.045361}}],
    Polygon[{{0.958013, 1.634256, -0.037706},{0.953758, 1.637347, -0.029124},{
      0.945639, 1.621414, -0.029124},{0.950642, 1.619788, -0.037706}}],
    Polygon[{{0.953758, 1.637347, -0.029124},{0.950642, 1.639612, -0.019823},{
      0.941976, 1.622604, -0.019823},{0.945639, 1.621414, -0.029124}}],
    Polygon[{{0.950642, 1.639612, -0.019823},{0.948740, 1.640993, -0.010035},{
      0.939741, 1.623330, -0.010035},{0.941976, 1.622604, -0.019823}}],
    Polygon[{{0.948740, 1.640993, -0.010035},{0.948102, 1.641457, 0.000000},{
      0.938990, 1.623574, 0.000000},{0.939741, 1.623330, -0.010035}}],
    Polygon[{{0.948102, 1.641457, 0.000000},{0.948740, 1.640993, 0.010035},{
      0.939741, 1.623330, 0.010035},{0.938990, 1.623574, 0.000000}}],
    Polygon[{{0.948740, 1.640993, 0.010035},{0.950642, 1.639612, 0.019823},{
      0.941976, 1.622604, 0.019823},{0.939741, 1.623330, 0.010035}}],
    Polygon[{{0.950642, 1.639612, 0.019823},{0.953758, 1.637347, 0.029124},{
      0.945639, 1.621414, 0.029124},{0.941976, 1.622604, 0.019823}}],
    Polygon[{{0.953758, 1.637347, 0.029124},{0.958013, 1.634256, 0.037706},{
      0.950642, 1.619788, 0.037706},{0.945639, 1.621414, 0.029124}}],
    Polygon[{{0.958013, 1.634256, 0.037706},{0.963302, 1.630413, 0.045361},{
      0.956859, 1.617768, 0.045361},{0.950642, 1.619788, 0.037706}}],
    Polygon[{{0.963302, 1.630413, 0.045361},{0.969495, 1.625914, 0.051898},{
      0.964139, 1.615403, 0.051898},{0.956859, 1.617768, 0.045361}}],
    Polygon[{{0.969495, 1.625914, 0.051898},{0.976439, 1.620869, 0.057158},{
      0.972302, 1.612750, 0.057158},{0.964139, 1.615403, 0.051898}}],
    Polygon[{{0.976439, 1.620869, 0.057158},{0.983962, 1.615403, 0.061010},{
      0.981147, 1.609877, 0.061010},{0.972302, 1.612750, 0.057158}}],
    Polygon[{{0.983962, 1.615403, 0.061010},{0.991881, 1.609649, 0.063360},{
      0.990456, 1.606852, 0.063360},{0.981147, 1.609877, 0.061010}}],
    Polygon[{{0.990456, 1.606852, -0.063360},{0.981147, 1.609877, -0.061010},{
      0.980177, 1.603751, -0.061010},{0.989965, 1.603751, -0.063360}}],
    Polygon[{{0.981147, 1.609877, -0.061010},{0.972302, 1.612750, -0.057158},{
      0.970877, 1.603751, -0.057158},{0.980177, 1.603751, -0.061010}}],
    Polygon[{{0.972302, 1.612750, -0.057158},{0.964139, 1.615403, -0.051898},{
      0.962294, 1.603751, -0.051898},{0.970877, 1.603751, -0.057158}}],
    Polygon[{{0.964139, 1.615403, -0.051898},{0.956859, 1.617768, -0.045361},{
      0.954639, 1.603751, -0.045361},{0.962294, 1.603751, -0.051898}}],
    Polygon[{{0.956859, 1.617768, -0.045361},{0.950642, 1.619788, -0.037706},{
      0.948102, 1.603751, -0.037706},{0.954639, 1.603751, -0.045361}}],
    Polygon[{{0.950642, 1.619788, -0.037706},{0.945639, 1.621414, -0.029124},{
      0.942842, 1.603751, -0.029124},{0.948102, 1.603751, -0.037706}}],
    Polygon[{{0.945639, 1.621414, -0.029124},{0.941976, 1.622604, -0.019823},{
      0.938990, 1.603751, -0.019823},{0.942842, 1.603751, -0.029124}}],
    Polygon[{{0.941976, 1.622604, -0.019823},{0.939741, 1.623330, -0.010035},{
      0.936640, 1.603751, -0.010035},{0.938990, 1.603751, -0.019823}}],
    Polygon[{{0.939741, 1.623330, -0.010035},{0.938990, 1.623574, 0.000000},{
      0.935850, 1.603751, 0.000000},{0.936640, 1.603751, -0.010035}}],
    Polygon[{{0.938990, 1.623574, 0.000000},{0.939741, 1.623330, 0.010035},{
      0.936640, 1.603751, 0.010035},{0.935850, 1.603751, 0.000000}}],
    Polygon[{{0.939741, 1.623330, 0.010035},{0.941976, 1.622604, 0.019823},{
      0.938990, 1.603751, 0.019823},{0.936640, 1.603751, 0.010035}}],
    Polygon[{{0.941976, 1.622604, 0.019823},{0.945639, 1.621414, 0.029124},{
      0.942842, 1.603751, 0.029124},{0.938990, 1.603751, 0.019823}}],
    Polygon[{{0.945639, 1.621414, 0.029124},{0.950642, 1.619788, 0.037706},{
      0.948102, 1.603751, 0.037706},{0.942842, 1.603751, 0.029124}}],
    Polygon[{{0.950642, 1.619788, 0.037706},{0.956859, 1.617768, 0.045361},{
      0.954639, 1.603751, 0.045361},{0.948102, 1.603751, 0.037706}}],
    Polygon[{{0.956859, 1.617768, 0.045361},{0.964139, 1.615403, 0.051898},{
      0.962294, 1.603751, 0.051898},{0.954639, 1.603751, 0.045361}}],
    Polygon[{{0.964139, 1.615403, 0.051898},{0.972302, 1.612750, 0.057158},{
      0.970877, 1.603751, 0.057158},{0.962294, 1.603751, 0.051898}}],
    Polygon[{{0.972302, 1.612750, 0.057158},{0.981147, 1.609877, 0.061010},{
      0.980177, 1.603751, 0.061010},{0.970877, 1.603751, 0.057158}}],
    Polygon[{{0.981147, 1.609877, 0.061010},{0.990456, 1.606852, 0.063360},{
      0.989965, 1.603751, 0.063360},{0.980177, 1.603751, 0.061010}}],
    Polygon[{{0.989965, 1.603751, -0.063360},{0.980177, 1.603751, -0.061010},{
      0.981147, 1.597625, -0.061010},{0.990456, 1.600650, -0.063360}}],
    Polygon[{{0.980177, 1.603751, -0.061010},{0.970877, 1.603751, -0.057158},{
      0.972302, 1.594751, -0.057158},{0.981147, 1.597625, -0.061010}}],
    Polygon[{{0.970877, 1.603751, -0.057158},{0.962294, 1.603751, -0.051898},{
      0.964139, 1.592099, -0.051898},{0.972302, 1.594751, -0.057158}}],
    Polygon[{{0.962294, 1.603751, -0.051898},{0.954639, 1.603751, -0.045361},{
      0.956859, 1.589733, -0.045361},{0.964139, 1.592099, -0.051898}}],
    Polygon[{{0.954639, 1.603751, -0.045361},{0.948102, 1.603751, -0.037706},{
      0.950642, 1.587713, -0.037706},{0.956859, 1.589733, -0.045361}}],
    Polygon[{{0.948102, 1.603751, -0.037706},{0.942842, 1.603751, -0.029124},{
      0.945639, 1.586088, -0.029124},{0.950642, 1.587713, -0.037706}}],
    Polygon[{{0.942842, 1.603751, -0.029124},{0.938990, 1.603751, -0.019823},{
      0.941976, 1.584898, -0.019823},{0.945639, 1.586088, -0.029124}}],
    Polygon[{{0.938990, 1.603751, -0.019823},{0.936640, 1.603751, -0.010035},{
      0.939741, 1.584171, -0.010035},{0.941976, 1.584898, -0.019823}}],
    Polygon[{{0.936640, 1.603751, -0.010035},{0.935850, 1.603751, 0.000000},{
      0.938990, 1.583927, 0.000000},{0.939741, 1.584171, -0.010035}}],
    Polygon[{{0.935850, 1.603751, 0.000000},{0.936640, 1.603751, 0.010035},{
      0.939741, 1.584171, 0.010035},{0.938990, 1.583927, 0.000000}}],
    Polygon[{{0.936640, 1.603751, 0.010035},{0.938990, 1.603751, 0.019823},{
      0.941976, 1.584898, 0.019823},{0.939741, 1.584171, 0.010035}}],
    Polygon[{{0.938990, 1.603751, 0.019823},{0.942842, 1.603751, 0.029124},{
      0.945639, 1.586088, 0.029124},{0.941976, 1.584898, 0.019823}}],
    Polygon[{{0.942842, 1.603751, 0.029124},{0.948102, 1.603751, 0.037706},{
      0.950642, 1.587713, 0.037706},{0.945639, 1.586088, 0.029124}}],
    Polygon[{{0.948102, 1.603751, 0.037706},{0.954639, 1.603751, 0.045361},{
      0.956859, 1.589733, 0.045361},{0.950642, 1.587713, 0.037706}}],
    Polygon[{{0.954639, 1.603751, 0.045361},{0.962294, 1.603751, 0.051898},{
      0.964139, 1.592099, 0.051898},{0.956859, 1.589733, 0.045361}}],
    Polygon[{{0.962294, 1.603751, 0.051898},{0.970877, 1.603751, 0.057158},{
      0.972302, 1.594751, 0.057158},{0.964139, 1.592099, 0.051898}}],
    Polygon[{{0.970877, 1.603751, 0.057158},{0.980177, 1.603751, 0.061010},{
      0.981147, 1.597625, 0.061010},{0.972302, 1.594751, 0.057158}}],
    Polygon[{{0.980177, 1.603751, 0.061010},{0.989965, 1.603751, 0.063360},{
      0.990456, 1.600650, 0.063360},{0.981147, 1.597625, 0.061010}}],
    Polygon[{{0.990456, 1.600650, -0.063360},{0.981147, 1.597625, -0.061010},{
      0.983962, 1.592099, -0.061010},{0.991881, 1.597852, -0.063360}}],
    Polygon[{{0.981147, 1.597625, -0.061010},{0.972302, 1.594751, -0.057158},{
      0.976439, 1.586632, -0.057158},{0.983962, 1.592099, -0.061010}}],
    Polygon[{{0.972302, 1.594751, -0.057158},{0.964139, 1.592099, -0.051898},{
      0.969495, 1.581587, -0.051898},{0.976439, 1.586632, -0.057158}}],
    Polygon[{{0.964139, 1.592099, -0.051898},{0.956859, 1.589733, -0.045361},{
      0.963302, 1.577088, -0.045361},{0.969495, 1.581587, -0.051898}}],
    Polygon[{{0.956859, 1.589733, -0.045361},{0.950642, 1.587713, -0.037706},{
      0.958013, 1.573246, -0.037706},{0.963302, 1.577088, -0.045361}}],
    Polygon[{{0.950642, 1.587713, -0.037706},{0.945639, 1.586088, -0.029124},{
      0.953758, 1.570154, -0.029124},{0.958013, 1.573246, -0.037706}}],
    Polygon[{{0.945639, 1.586088, -0.029124},{0.941976, 1.584898, -0.019823},{
      0.950642, 1.567890, -0.019823},{0.953758, 1.570154, -0.029124}}],
    Polygon[{{0.941976, 1.584898, -0.019823},{0.939741, 1.584171, -0.010035},{
      0.948740, 1.566509, -0.010035},{0.950642, 1.567890, -0.019823}}],
    Polygon[{{0.939741, 1.584171, -0.010035},{0.938990, 1.583927, 0.000000},{
      0.948102, 1.566044, 0.000000},{0.948740, 1.566509, -0.010035}}],
    Polygon[{{0.938990, 1.583927, 0.000000},{0.939741, 1.584171, 0.010035},{
      0.948740, 1.566509, 0.010035},{0.948102, 1.566044, 0.000000}}],
    Polygon[{{0.939741, 1.584171, 0.010035},{0.941976, 1.584898, 0.019823},{
      0.950642, 1.567890, 0.019823},{0.948740, 1.566509, 0.010035}}],
    Polygon[{{0.941976, 1.584898, 0.019823},{0.945639, 1.586088, 0.029124},{
      0.953758, 1.570154, 0.029124},{0.950642, 1.567890, 0.019823}}],
    Polygon[{{0.945639, 1.586088, 0.029124},{0.950642, 1.587713, 0.037706},{
      0.958013, 1.573246, 0.037706},{0.953758, 1.570154, 0.029124}}],
    Polygon[{{0.950642, 1.587713, 0.037706},{0.956859, 1.589733, 0.045361},{
      0.963302, 1.577088, 0.045361},{0.958013, 1.573246, 0.037706}}],
    Polygon[{{0.956859, 1.589733, 0.045361},{0.964139, 1.592099, 0.051898},{
      0.969495, 1.581587, 0.051898},{0.963302, 1.577088, 0.045361}}],
    Polygon[{{0.964139, 1.592099, 0.051898},{0.972302, 1.594751, 0.057158},{
      0.976439, 1.586632, 0.057158},{0.969495, 1.581587, 0.051898}}],
    Polygon[{{0.972302, 1.594751, 0.057158},{0.981147, 1.597625, 0.061010},{
      0.983962, 1.592099, 0.061010},{0.976439, 1.586632, 0.057158}}],
    Polygon[{{0.981147, 1.597625, 0.061010},{0.990456, 1.600650, 0.063360},{
      0.991881, 1.597852, 0.063360},{0.983962, 1.592099, 0.061010}}],
    Polygon[{{0.991881, 1.597852, -0.063360},{0.983962, 1.592099, -0.061010},{
      0.988348, 1.587713, -0.061010},{0.994101, 1.595632, -0.063360}}],
    Polygon[{{0.983962, 1.592099, -0.061010},{0.976439, 1.586632, -0.057158},{
      0.982882, 1.580189, -0.057158},{0.988348, 1.587713, -0.061010}}],
    Polygon[{{0.976439, 1.586632, -0.057158},{0.969495, 1.581587, -0.051898},{
      0.977837, 1.573246, -0.051898},{0.982882, 1.580189, -0.057158}}],
    Polygon[{{0.969495, 1.581587, -0.051898},{0.963302, 1.577088, -0.045361},{
      0.973338, 1.567053, -0.045361},{0.977837, 1.573246, -0.051898}}],
    Polygon[{{0.963302, 1.577088, -0.045361},{0.958013, 1.573246, -0.037706},{
      0.969495, 1.561764, -0.037706},{0.973338, 1.567053, -0.045361}}],
    Polygon[{{0.958013, 1.573246, -0.037706},{0.953758, 1.570154, -0.029124},{
      0.966403, 1.557509, -0.029124},{0.969495, 1.561764, -0.037706}}],
    Polygon[{{0.953758, 1.570154, -0.029124},{0.950642, 1.567890, -0.019823},{
      0.964139, 1.554392, -0.019823},{0.966403, 1.557509, -0.029124}}],
    Polygon[{{0.950642, 1.567890, -0.019823},{0.948740, 1.566509, -0.010035},{
      0.962758, 1.552491, -0.010035},{0.964139, 1.554392, -0.019823}}],
    Polygon[{{0.948740, 1.566509, -0.010035},{0.948102, 1.566044, 0.000000},{
      0.962294, 1.551852, 0.000000},{0.962758, 1.552491, -0.010035}}],
    Polygon[{{0.948102, 1.566044, 0.000000},{0.948740, 1.566509, 0.010035},{
      0.962758, 1.552491, 0.010035},{0.962294, 1.551852, 0.000000}}],
    Polygon[{{0.948740, 1.566509, 0.010035},{0.950642, 1.567890, 0.019823},{
      0.964139, 1.554392, 0.019823},{0.962758, 1.552491, 0.010035}}],
    Polygon[{{0.950642, 1.567890, 0.019823},{0.953758, 1.570154, 0.029124},{
      0.966403, 1.557509, 0.029124},{0.964139, 1.554392, 0.019823}}],
    Polygon[{{0.953758, 1.570154, 0.029124},{0.958013, 1.573246, 0.037706},{
      0.969495, 1.561764, 0.037706},{0.966403, 1.557509, 0.029124}}],
    Polygon[{{0.958013, 1.573246, 0.037706},{0.963302, 1.577088, 0.045361},{
      0.973338, 1.567053, 0.045361},{0.969495, 1.561764, 0.037706}}],
    Polygon[{{0.963302, 1.577088, 0.045361},{0.969495, 1.581587, 0.051898},{
      0.977837, 1.573246, 0.051898},{0.973338, 1.567053, 0.045361}}],
    Polygon[{{0.969495, 1.581587, 0.051898},{0.976439, 1.586632, 0.057158},{
      0.982882, 1.580189, 0.057158},{0.977837, 1.573246, 0.051898}}],
    Polygon[{{0.976439, 1.586632, 0.057158},{0.983962, 1.592099, 0.061010},{
      0.988348, 1.587713, 0.061010},{0.982882, 1.580189, 0.057158}}],
    Polygon[{{0.983962, 1.592099, 0.061010},{0.991881, 1.597852, 0.063360},{
      0.994101, 1.595632, 0.063360},{0.988348, 1.587713, 0.061010}}],
    Polygon[{{0.994101, 1.595632, -0.063360},{0.988348, 1.587713, -0.061010},{
      0.993874, 1.584898, -0.061010},{0.996899, 1.594207, -0.063360}}],
    Polygon[{{0.988348, 1.587713, -0.061010},{0.982882, 1.580189, -0.057158},{
      0.991000, 1.576053, -0.057158},{0.993874, 1.584898, -0.061010}}],
    Polygon[{{0.982882, 1.580189, -0.057158},{0.977837, 1.573246, -0.051898},{
      0.988348, 1.567890, -0.051898},{0.991000, 1.576053, -0.057158}}],
    Polygon[{{0.977837, 1.573246, -0.051898},{0.973338, 1.567053, -0.045361},{
      0.985983, 1.560610, -0.045361},{0.988348, 1.567890, -0.051898}}],
    Polygon[{{0.973338, 1.567053, -0.045361},{0.969495, 1.561764, -0.037706},{
      0.983962, 1.554392, -0.037706},{0.985983, 1.560610, -0.045361}}],
    Polygon[{{0.969495, 1.561764, -0.037706},{0.966403, 1.557509, -0.029124},{
      0.982337, 1.549390, -0.029124},{0.983962, 1.554392, -0.037706}}],
    Polygon[{{0.966403, 1.557509, -0.029124},{0.964139, 1.554392, -0.019823},{
      0.981147, 1.545727, -0.019823},{0.982337, 1.549390, -0.029124}}],
    Polygon[{{0.964139, 1.554392, -0.019823},{0.962758, 1.552491, -0.010035},{
      0.980421, 1.543492, -0.010035},{0.981147, 1.545727, -0.019823}}],
    Polygon[{{0.962758, 1.552491, -0.010035},{0.962294, 1.551852, 0.000000},{
      0.980177, 1.542740, 0.000000},{0.980421, 1.543492, -0.010035}}],
    Polygon[{{0.962294, 1.551852, 0.000000},{0.962758, 1.552491, 0.010035},{
      0.980421, 1.543492, 0.010035},{0.980177, 1.542740, 0.000000}}],
    Polygon[{{0.962758, 1.552491, 0.010035},{0.964139, 1.554392, 0.019823},{
      0.981147, 1.545727, 0.019823},{0.980421, 1.543492, 0.010035}}],
    Polygon[{{0.964139, 1.554392, 0.019823},{0.966403, 1.557509, 0.029124},{
      0.982337, 1.549390, 0.029124},{0.981147, 1.545727, 0.019823}}],
    Polygon[{{0.966403, 1.557509, 0.029124},{0.969495, 1.561764, 0.037706},{
      0.983962, 1.554392, 0.037706},{0.982337, 1.549390, 0.029124}}],
    Polygon[{{0.969495, 1.561764, 0.037706},{0.973338, 1.567053, 0.045361},{
      0.985983, 1.560610, 0.045361},{0.983962, 1.554392, 0.037706}}],
    Polygon[{{0.973338, 1.567053, 0.045361},{0.977837, 1.573246, 0.051898},{
      0.988348, 1.567890, 0.051898},{0.985983, 1.560610, 0.045361}}],
    Polygon[{{0.977837, 1.573246, 0.051898},{0.982882, 1.580189, 0.057158},{
      0.991000, 1.576053, 0.057158},{0.988348, 1.567890, 0.051898}}],
    Polygon[{{0.982882, 1.580189, 0.057158},{0.988348, 1.587713, 0.061010},{
      0.993874, 1.584898, 0.061010},{0.991000, 1.576053, 0.057158}}],
    Polygon[{{0.988348, 1.587713, 0.061010},{0.994101, 1.595632, 0.063360},{
      0.996899, 1.594207, 0.063360},{0.993874, 1.584898, 0.061010}}],
    Polygon[{{0.996899, 1.594207, -0.063360},{0.993874, 1.584898, -0.061010},{
      1.000000, 1.583927, -0.061010},{1.000000, 1.593715, -0.063360}}],
    Polygon[{{0.993874, 1.584898, -0.061010},{0.991000, 1.576053, -0.057158},{
      1.000000, 1.574627, -0.057158},{1.000000, 1.583927, -0.061010}}],
    Polygon[{{0.991000, 1.576053, -0.057158},{0.988348, 1.567890, -0.051898},{
      1.000000, 1.566044, -0.051898},{1.000000, 1.574627, -0.057158}}],
    Polygon[{{0.988348, 1.567890, -0.051898},{0.985983, 1.560610, -0.045361},{
      1.000000, 1.558390, -0.045361},{1.000000, 1.566044, -0.051898}}],
    Polygon[{{0.985983, 1.560610, -0.045361},{0.983962, 1.554392, -0.037706},{
      1.000000, 1.551852, -0.037706},{1.000000, 1.558390, -0.045361}}],
    Polygon[{{0.983962, 1.554392, -0.037706},{0.982337, 1.549390, -0.029124},{
      1.000000, 1.546593, -0.029124},{1.000000, 1.551852, -0.037706}}],
    Polygon[{{0.982337, 1.549390, -0.029124},{0.981147, 1.545727, -0.019823},{
      1.000000, 1.542740, -0.019823},{1.000000, 1.546593, -0.029124}}],
    Polygon[{{0.981147, 1.545727, -0.019823},{0.980421, 1.543492, -0.010035},{
      1.000000, 1.540390, -0.010035},{1.000000, 1.542740, -0.019823}}],
    Polygon[{{0.980421, 1.543492, -0.010035},{0.980177, 1.542740, 0.000000},{
      1.000000, 1.539601, 0.000000},{1.000000, 1.540390, -0.010035}}],
    Polygon[{{0.980177, 1.542740, 0.000000},{0.980421, 1.543492, 0.010035},{
      1.000000, 1.540390, 0.010035},{1.000000, 1.539601, 0.000000}}],
    Polygon[{{0.980421, 1.543492, 0.010035},{0.981147, 1.545727, 0.019823},{
      1.000000, 1.542740, 0.019823},{1.000000, 1.540390, 0.010035}}],
    Polygon[{{0.981147, 1.545727, 0.019823},{0.982337, 1.549390, 0.029124},{
      1.000000, 1.546593, 0.029124},{1.000000, 1.542740, 0.019823}}],
    Polygon[{{0.982337, 1.549390, 0.029124},{0.983962, 1.554392, 0.037706},{
      1.000000, 1.551852, 0.037706},{1.000000, 1.546593, 0.029124}}],
    Polygon[{{0.983962, 1.554392, 0.037706},{0.985983, 1.560610, 0.045361},{
      1.000000, 1.558390, 0.045361},{1.000000, 1.551852, 0.037706}}],
    Polygon[{{0.985983, 1.560610, 0.045361},{0.988348, 1.567890, 0.051898},{
      1.000000, 1.566044, 0.051898},{1.000000, 1.558390, 0.045361}}],
    Polygon[{{0.988348, 1.567890, 0.051898},{0.991000, 1.576053, 0.057158},{
      1.000000, 1.574627, 0.057158},{1.000000, 1.566044, 0.051898}}],
    Polygon[{{0.991000, 1.576053, 0.057158},{0.993874, 1.584898, 0.061010},{
      1.000000, 1.583927, 0.061010},{1.000000, 1.574627, 0.057158}}],
    Polygon[{{0.993874, 1.584898, 0.061010},{0.996899, 1.594207, 0.063360},{
      1.000000, 1.593715, 0.063360},{1.000000, 1.583927, 0.061010}}],
    Polygon[{{1.000000, 1.593715, -0.063360},{1.000000, 1.583927, -0.061010},{
      1.006126, 1.584898, -0.061010},{1.003101, 1.594207, -0.063360}}],
    Polygon[{{1.000000, 1.583927, -0.061010},{1.000000, 1.574627, -0.057158},{
      1.009000, 1.576053, -0.057158},{1.006126, 1.584898, -0.061010}}],
    Polygon[{{1.000000, 1.574627, -0.057158},{1.000000, 1.566044, -0.051898},{
      1.011652, 1.567890, -0.051898},{1.009000, 1.576053, -0.057158}}],
    Polygon[{{1.000000, 1.566044, -0.051898},{1.000000, 1.558390, -0.045361},{
      1.014017, 1.560610, -0.045361},{1.011652, 1.567890, -0.051898}}],
    Polygon[{{1.000000, 1.558390, -0.045361},{1.000000, 1.551852, -0.037706},{
      1.016037, 1.554392, -0.037706},{1.014017, 1.560610, -0.045361}}],
    Polygon[{{1.000000, 1.551852, -0.037706},{1.000000, 1.546593, -0.029124},{
      1.017663, 1.549390, -0.029124},{1.016037, 1.554392, -0.037706}}],
    Polygon[{{1.000000, 1.546593, -0.029124},{1.000000, 1.542740, -0.019823},{
      1.018853, 1.545727, -0.019823},{1.017663, 1.549390, -0.029124}}],
    Polygon[{{1.000000, 1.542740, -0.019823},{1.000000, 1.540390, -0.010035},{
      1.019579, 1.543492, -0.010035},{1.018853, 1.545727, -0.019823}}],
    Polygon[{{1.000000, 1.540390, -0.010035},{1.000000, 1.539601, 0.000000},{
      1.019823, 1.542740, 0.000000},{1.019579, 1.543492, -0.010035}}],
    Polygon[{{1.000000, 1.539601, 0.000000},{1.000000, 1.540390, 0.010035},{
      1.019579, 1.543492, 0.010035},{1.019823, 1.542740, 0.000000}}],
    Polygon[{{1.000000, 1.540390, 0.010035},{1.000000, 1.542740, 0.019823},{
      1.018853, 1.545727, 0.019823},{1.019579, 1.543492, 0.010035}}],
    Polygon[{{1.000000, 1.542740, 0.019823},{1.000000, 1.546593, 0.029124},{
      1.017663, 1.549390, 0.029124},{1.018853, 1.545727, 0.019823}}],
    Polygon[{{1.000000, 1.546593, 0.029124},{1.000000, 1.551852, 0.037706},{
      1.016037, 1.554392, 0.037706},{1.017663, 1.549390, 0.029124}}],
    Polygon[{{1.000000, 1.551852, 0.037706},{1.000000, 1.558390, 0.045361},{
      1.014017, 1.560610, 0.045361},{1.016037, 1.554392, 0.037706}}],
    Polygon[{{1.000000, 1.558390, 0.045361},{1.000000, 1.566044, 0.051898},{
      1.011652, 1.567890, 0.051898},{1.014017, 1.560610, 0.045361}}],
    Polygon[{{1.000000, 1.566044, 0.051898},{1.000000, 1.574627, 0.057158},{
      1.009000, 1.576053, 0.057158},{1.011652, 1.567890, 0.051898}}],
    Polygon[{{1.000000, 1.574627, 0.057158},{1.000000, 1.583927, 0.061010},{
      1.006126, 1.584898, 0.061010},{1.009000, 1.576053, 0.057158}}],
    Polygon[{{1.000000, 1.583927, 0.061010},{1.000000, 1.593715, 0.063360},{
      1.003101, 1.594207, 0.063360},{1.006126, 1.584898, 0.061010}}],
    Polygon[{{1.003101, 1.594207, -0.063360},{1.006126, 1.584898, -0.061010},{
      1.011652, 1.587713, -0.061010},{1.005899, 1.595632, -0.063360}}],
    Polygon[{{1.006126, 1.584898, -0.061010},{1.009000, 1.576053, -0.057158},{
      1.017118, 1.580189, -0.057158},{1.011652, 1.587713, -0.061010}}],
    Polygon[{{1.009000, 1.576053, -0.057158},{1.011652, 1.567890, -0.051898},{
      1.022163, 1.573246, -0.051898},{1.017118, 1.580189, -0.057158}}],
    Polygon[{{1.011652, 1.567890, -0.051898},{1.014017, 1.560610, -0.045361},{
      1.026662, 1.567053, -0.045361},{1.022163, 1.573246, -0.051898}}],
    Polygon[{{1.014017, 1.560610, -0.045361},{1.016037, 1.554392, -0.037706},{
      1.030505, 1.561764, -0.037706},{1.026662, 1.567053, -0.045361}}],
    Polygon[{{1.016037, 1.554392, -0.037706},{1.017663, 1.549390, -0.029124},{
      1.033597, 1.557509, -0.029124},{1.030505, 1.561764, -0.037706}}],
    Polygon[{{1.017663, 1.549390, -0.029124},{1.018853, 1.545727, -0.019823},{
      1.035861, 1.554392, -0.019823},{1.033597, 1.557509, -0.029124}}],
    Polygon[{{1.018853, 1.545727, -0.019823},{1.019579, 1.543492, -0.010035},{
      1.037242, 1.552491, -0.010035},{1.035861, 1.554392, -0.019823}}],
    Polygon[{{1.019579, 1.543492, -0.010035},{1.019823, 1.542740, 0.000000},{
      1.037706, 1.551852, 0.000000},{1.037242, 1.552491, -0.010035}}],
    Polygon[{{1.019823, 1.542740, 0.000000},{1.019579, 1.543492, 0.010035},{
      1.037242, 1.552491, 0.010035},{1.037706, 1.551852, 0.000000}}],
    Polygon[{{1.019579, 1.543492, 0.010035},{1.018853, 1.545727, 0.019823},{
      1.035861, 1.554392, 0.019823},{1.037242, 1.552491, 0.010035}}],
    Polygon[{{1.018853, 1.545727, 0.019823},{1.017663, 1.549390, 0.029124},{
      1.033597, 1.557509, 0.029124},{1.035861, 1.554392, 0.019823}}],
    Polygon[{{1.017663, 1.549390, 0.029124},{1.016037, 1.554392, 0.037706},{
      1.030505, 1.561764, 0.037706},{1.033597, 1.557509, 0.029124}}],
    Polygon[{{1.016037, 1.554392, 0.037706},{1.014017, 1.560610, 0.045361},{
      1.026662, 1.567053, 0.045361},{1.030505, 1.561764, 0.037706}}],
    Polygon[{{1.014017, 1.560610, 0.045361},{1.011652, 1.567890, 0.051898},{
      1.022163, 1.573246, 0.051898},{1.026662, 1.567053, 0.045361}}],
    Polygon[{{1.011652, 1.567890, 0.051898},{1.009000, 1.576053, 0.057158},{
      1.017118, 1.580189, 0.057158},{1.022163, 1.573246, 0.051898}}],
    Polygon[{{1.009000, 1.576053, 0.057158},{1.006126, 1.584898, 0.061010},{
      1.011652, 1.587713, 0.061010},{1.017118, 1.580189, 0.057158}}],
    Polygon[{{1.006126, 1.584898, 0.061010},{1.003101, 1.594207, 0.063360},{
      1.005899, 1.595632, 0.063360},{1.011652, 1.587713, 0.061010}}],
    Polygon[{{1.005899, 1.595632, -0.063360},{1.011652, 1.587713, -0.061010},{
      1.016037, 1.592099, -0.061010},{1.008119, 1.597852, -0.063360}}],
    Polygon[{{1.011652, 1.587713, -0.061010},{1.017118, 1.580189, -0.057158},{
      1.023561, 1.586632, -0.057158},{1.016037, 1.592099, -0.061010}}],
    Polygon[{{1.017118, 1.580189, -0.057158},{1.022163, 1.573246, -0.051898},{
      1.030505, 1.581587, -0.051898},{1.023561, 1.586632, -0.057158}}],
    Polygon[{{1.022163, 1.573246, -0.051898},{1.026662, 1.567053, -0.045361},{
      1.036698, 1.577088, -0.045361},{1.030505, 1.581587, -0.051898}}],
    Polygon[{{1.026662, 1.567053, -0.045361},{1.030505, 1.561764, -0.037706},{
      1.041987, 1.573246, -0.037706},{1.036698, 1.577088, -0.045361}}],
    Polygon[{{1.030505, 1.561764, -0.037706},{1.033597, 1.557509, -0.029124},{
      1.046242, 1.570154, -0.029124},{1.041987, 1.573246, -0.037706}}],
    Polygon[{{1.033597, 1.557509, -0.029124},{1.035861, 1.554392, -0.019823},{
      1.049358, 1.567890, -0.019823},{1.046242, 1.570154, -0.029124}}],
    Polygon[{{1.035861, 1.554392, -0.019823},{1.037242, 1.552491, -0.010035},{
      1.051260, 1.566509, -0.010035},{1.049358, 1.567890, -0.019823}}],
    Polygon[{{1.037242, 1.552491, -0.010035},{1.037706, 1.551852, 0.000000},{
      1.051898, 1.566044, 0.000000},{1.051260, 1.566509, -0.010035}}],
    Polygon[{{1.037706, 1.551852, 0.000000},{1.037242, 1.552491, 0.010035},{
      1.051260, 1.566509, 0.010035},{1.051898, 1.566044, 0.000000}}],
    Polygon[{{1.037242, 1.552491, 0.010035},{1.035861, 1.554392, 0.019823},{
      1.049358, 1.567890, 0.019823},{1.051260, 1.566509, 0.010035}}],
    Polygon[{{1.035861, 1.554392, 0.019823},{1.033597, 1.557509, 0.029124},{
      1.046242, 1.570154, 0.029124},{1.049358, 1.567890, 0.019823}}],
    Polygon[{{1.033597, 1.557509, 0.029124},{1.030505, 1.561764, 0.037706},{
      1.041987, 1.573246, 0.037706},{1.046242, 1.570154, 0.029124}}],
    Polygon[{{1.030505, 1.561764, 0.037706},{1.026662, 1.567053, 0.045361},{
      1.036698, 1.577088, 0.045361},{1.041987, 1.573246, 0.037706}}],
    Polygon[{{1.026662, 1.567053, 0.045361},{1.022163, 1.573246, 0.051898},{
      1.030505, 1.581587, 0.051898},{1.036698, 1.577088, 0.045361}}],
    Polygon[{{1.022163, 1.573246, 0.051898},{1.017118, 1.580189, 0.057158},{
      1.023561, 1.586632, 0.057158},{1.030505, 1.581587, 0.051898}}],
    Polygon[{{1.017118, 1.580189, 0.057158},{1.011652, 1.587713, 0.061010},{
      1.016037, 1.592099, 0.061010},{1.023561, 1.586632, 0.057158}}],
    Polygon[{{1.011652, 1.587713, 0.061010},{1.005899, 1.595632, 0.063360},{
      1.008119, 1.597852, 0.063360},{1.016037, 1.592099, 0.061010}}],
    Polygon[{{1.008119, 1.597852, -0.063360},{1.016037, 1.592099, -0.061010},{
      1.018853, 1.597625, -0.061010},{1.009544, 1.600650, -0.063360}}],
    Polygon[{{1.016037, 1.592099, -0.061010},{1.023561, 1.586632, -0.057158},{
      1.027698, 1.594751, -0.057158},{1.018853, 1.597625, -0.061010}}],
    Polygon[{{1.023561, 1.586632, -0.057158},{1.030505, 1.581587, -0.051898},{
      1.035861, 1.592099, -0.051898},{1.027698, 1.594751, -0.057158}}],
    Polygon[{{1.030505, 1.581587, -0.051898},{1.036698, 1.577088, -0.045361},{
      1.043141, 1.589733, -0.045361},{1.035861, 1.592099, -0.051898}}],
    Polygon[{{1.036698, 1.577088, -0.045361},{1.041987, 1.573246, -0.037706},{
      1.049358, 1.587713, -0.037706},{1.043141, 1.589733, -0.045361}}],
    Polygon[{{1.041987, 1.573246, -0.037706},{1.046242, 1.570154, -0.029124},{
      1.054361, 1.586088, -0.029124},{1.049358, 1.587713, -0.037706}}],
    Polygon[{{1.046242, 1.570154, -0.029124},{1.049358, 1.567890, -0.019823},{
      1.058024, 1.584898, -0.019823},{1.054361, 1.586088, -0.029124}}],
    Polygon[{{1.049358, 1.567890, -0.019823},{1.051260, 1.566509, -0.010035},{
      1.060259, 1.584171, -0.010035},{1.058024, 1.584898, -0.019823}}],
    Polygon[{{1.051260, 1.566509, -0.010035},{1.051898, 1.566044, 0.000000},{
      1.061010, 1.583927, 0.000000},{1.060259, 1.584171, -0.010035}}],
    Polygon[{{1.051898, 1.566044, 0.000000},{1.051260, 1.566509, 0.010035},{
      1.060259, 1.584171, 0.010035},{1.061010, 1.583927, 0.000000}}],
    Polygon[{{1.051260, 1.566509, 0.010035},{1.049358, 1.567890, 0.019823},{
      1.058024, 1.584898, 0.019823},{1.060259, 1.584171, 0.010035}}],
    Polygon[{{1.049358, 1.567890, 0.019823},{1.046242, 1.570154, 0.029124},{
      1.054361, 1.586088, 0.029124},{1.058024, 1.584898, 0.019823}}],
    Polygon[{{1.046242, 1.570154, 0.029124},{1.041987, 1.573246, 0.037706},{
      1.049358, 1.587713, 0.037706},{1.054361, 1.586088, 0.029124}}],
    Polygon[{{1.041987, 1.573246, 0.037706},{1.036698, 1.577088, 0.045361},{
      1.043141, 1.589733, 0.045361},{1.049358, 1.587713, 0.037706}}],
    Polygon[{{1.036698, 1.577088, 0.045361},{1.030505, 1.581587, 0.051898},{
      1.035861, 1.592099, 0.051898},{1.043141, 1.589733, 0.045361}}],
    Polygon[{{1.030505, 1.581587, 0.051898},{1.023561, 1.586632, 0.057158},{
      1.027698, 1.594751, 0.057158},{1.035861, 1.592099, 0.051898}}],
    Polygon[{{1.023561, 1.586632, 0.057158},{1.016037, 1.592099, 0.061010},{
      1.018853, 1.597625, 0.061010},{1.027698, 1.594751, 0.057158}}],
    Polygon[{{1.016037, 1.592099, 0.061010},{1.008119, 1.597852, 0.063360},{
      1.009544, 1.600650, 0.063360},{1.018853, 1.597625, 0.061010}}],
    Polygon[{{1.009544, 1.600650, -0.063360},{1.018853, 1.597625, -0.061010},{
      1.019823, 1.603751, -0.061010},{1.010035, 1.603751, -0.063360}}],
    Polygon[{{1.018853, 1.597625, -0.061010},{1.027698, 1.594751, -0.057158},{
      1.029124, 1.603751, -0.057158},{1.019823, 1.603751, -0.061010}}],
    Polygon[{{1.027698, 1.594751, -0.057158},{1.035861, 1.592099, -0.051898},{
      1.037706, 1.603751, -0.051898},{1.029124, 1.603751, -0.057158}}],
    Polygon[{{1.035861, 1.592099, -0.051898},{1.043141, 1.589733, -0.045361},{
      1.045361, 1.603751, -0.045361},{1.037706, 1.603751, -0.051898}}],
    Polygon[{{1.043141, 1.589733, -0.045361},{1.049358, 1.587713, -0.037706},{
      1.051898, 1.603751, -0.037706},{1.045361, 1.603751, -0.045361}}],
    Polygon[{{1.049358, 1.587713, -0.037706},{1.054361, 1.586088, -0.029124},{
      1.057158, 1.603751, -0.029124},{1.051898, 1.603751, -0.037706}}],
    Polygon[{{1.054361, 1.586088, -0.029124},{1.058024, 1.584898, -0.019823},{
      1.061010, 1.603751, -0.019823},{1.057158, 1.603751, -0.029124}}],
    Polygon[{{1.058024, 1.584898, -0.019823},{1.060259, 1.584171, -0.010035},{
      1.063360, 1.603751, -0.010035},{1.061010, 1.603751, -0.019823}}],
    Polygon[{{1.060259, 1.584171, -0.010035},{1.061010, 1.583927, 0.000000},{
      1.064150, 1.603751, 0.000000},{1.063360, 1.603751, -0.010035}}],
    Polygon[{{1.061010, 1.583927, 0.000000},{1.060259, 1.584171, 0.010035},{
      1.063360, 1.603751, 0.010035},{1.064150, 1.603751, 0.000000}}],
    Polygon[{{1.060259, 1.584171, 0.010035},{1.058024, 1.584898, 0.019823},{
      1.061010, 1.603751, 0.019823},{1.063360, 1.603751, 0.010035}}],
    Polygon[{{1.058024, 1.584898, 0.019823},{1.054361, 1.586088, 0.029124},{
      1.057158, 1.603751, 0.029124},{1.061010, 1.603751, 0.019823}}],
    Polygon[{{1.054361, 1.586088, 0.029124},{1.049358, 1.587713, 0.037706},{
      1.051898, 1.603751, 0.037706},{1.057158, 1.603751, 0.029124}}],
    Polygon[{{1.049358, 1.587713, 0.037706},{1.043141, 1.589733, 0.045361},{
      1.045361, 1.603751, 0.045361},{1.051898, 1.603751, 0.037706}}],
    Polygon[{{1.043141, 1.589733, 0.045361},{1.035861, 1.592099, 0.051898},{
      1.037706, 1.603751, 0.051898},{1.045361, 1.603751, 0.045361}}],
    Polygon[{{1.035861, 1.592099, 0.051898},{1.027698, 1.594751, 0.057158},{
      1.029124, 1.603751, 0.057158},{1.037706, 1.603751, 0.051898}}],
    Polygon[{{1.027698, 1.594751, 0.057158},{1.018853, 1.597625, 0.061010},{
      1.019823, 1.603751, 0.061010},{1.029124, 1.603751, 0.057158}}],
    Polygon[{{1.018853, 1.597625, 0.061010},{1.009544, 1.600650, 0.063360},{
      1.010035, 1.603751, 0.063360},{1.019823, 1.603751, 0.061010}}],
    Polygon[{{1.003345, 1.689284, -0.021120},{1.006608, 1.689284, -0.020337},{
      1.006284, 1.691326, -0.020337},{1.003181, 1.690318, -0.021120}}],
    Polygon[{{1.006608, 1.689284, -0.020337},{1.009708, 1.689284, -0.019053},{
      1.009233, 1.692284, -0.019053},{1.006284, 1.691326, -0.020337}}],
    Polygon[{{1.009708, 1.689284, -0.019053},{1.012569, 1.689284, -0.017299},{
      1.011954, 1.693168, -0.017299},{1.009233, 1.692284, -0.019053}}],
    Polygon[{{1.012569, 1.689284, -0.017299},{1.015120, 1.689284, -0.015120},{
      1.014380, 1.693956, -0.015120},{1.011954, 1.693168, -0.017299}}],
    Polygon[{{1.015120, 1.689284, -0.015120},{1.017300, 1.689284, -0.012569},{
      1.016453, 1.694630, -0.012569},{1.014380, 1.693956, -0.015120}}],
    Polygon[{{1.017300, 1.689284, -0.012569},{1.019053, 1.689284, -0.009708},{
      1.018120, 1.695172, -0.009708},{1.016453, 1.694630, -0.012569}}],
    Polygon[{{1.019053, 1.689284, -0.009708},{1.020337, 1.689284, -0.006608},{
      1.019341, 1.695569, -0.006608},{1.018120, 1.695172, -0.009708}}],
    Polygon[{{1.020337, 1.689284, -0.006608},{1.021120, 1.689284, -0.003345},{
      1.020086, 1.695811, -0.003345},{1.019341, 1.695569, -0.006608}}],
    Polygon[{{1.021120, 1.689284, -0.003345},{1.021383, 1.689284, 0.000000},{
      1.020337, 1.695892, 0.000000},{1.020086, 1.695811, -0.003345}}],
    Polygon[{{1.021383, 1.689284, 0.000000},{1.021120, 1.689284, 0.003345},{
      1.020086, 1.695811, 0.003345},{1.020337, 1.695892, 0.000000}}],
    Polygon[{{1.021120, 1.689284, 0.003345},{1.020337, 1.689284, 0.006608},{
      1.019341, 1.695569, 0.006608},{1.020086, 1.695811, 0.003345}}],
    Polygon[{{1.020337, 1.689284, 0.006608},{1.019053, 1.689284, 0.009708},{
      1.018120, 1.695172, 0.009708},{1.019341, 1.695569, 0.006608}}],
    Polygon[{{1.019053, 1.689284, 0.009708},{1.017300, 1.689284, 0.012569},{
      1.016453, 1.694630, 0.012569},{1.018120, 1.695172, 0.009708}}],
    Polygon[{{1.017300, 1.689284, 0.012569},{1.015120, 1.689284, 0.015120},{
      1.014380, 1.693956, 0.015120},{1.016453, 1.694630, 0.012569}}],
    Polygon[{{1.015120, 1.689284, 0.015120},{1.012569, 1.689284, 0.017299},{
      1.011954, 1.693168, 0.017299},{1.014380, 1.693956, 0.015120}}],
    Polygon[{{1.012569, 1.689284, 0.017299},{1.009708, 1.689284, 0.019053},{
      1.009233, 1.692284, 0.019053},{1.011954, 1.693168, 0.017299}}],
    Polygon[{{1.009708, 1.689284, 0.019053},{1.006608, 1.689284, 0.020337},{
      1.006284, 1.691326, 0.020337},{1.009233, 1.692284, 0.019053}}],
    Polygon[{{1.006608, 1.689284, 0.020337},{1.003345, 1.689284, 0.021120},{
      1.003181, 1.690318, 0.021120},{1.006284, 1.691326, 0.020337}}],
    Polygon[{{1.003181, 1.690318, -0.021120},{1.006284, 1.691326, -0.020337},{
      1.005346, 1.693168, -0.020337},{1.002706, 1.691250, -0.021120}}],
    Polygon[{{1.006284, 1.691326, -0.020337},{1.009233, 1.692284, -0.019053},{
      1.007854, 1.694990, -0.019053},{1.005346, 1.693168, -0.020337}}],
    Polygon[{{1.009233, 1.692284, -0.019053},{1.011954, 1.693168, -0.017299},{
      1.010168, 1.696672, -0.017299},{1.007854, 1.694990, -0.019053}}],
    Polygon[{{1.011954, 1.693168, -0.017299},{1.014380, 1.693956, -0.015120},{
      1.012233, 1.698172, -0.015120},{1.010168, 1.696672, -0.017299}}],
    Polygon[{{1.014380, 1.693956, -0.015120},{1.016453, 1.694630, -0.012569},{
      1.013996, 1.699453, -0.012569},{1.012233, 1.698172, -0.015120}}],
    Polygon[{{1.016453, 1.694630, -0.012569},{1.018120, 1.695172, -0.009708},{
      1.015414, 1.700483, -0.009708},{1.013996, 1.699453, -0.012569}}],
    Polygon[{{1.018120, 1.695172, -0.009708},{1.019341, 1.695569, -0.006608},{
      1.016453, 1.701238, -0.006608},{1.015414, 1.700483, -0.009708}}],
    Polygon[{{1.019341, 1.695569, -0.006608},{1.020086, 1.695811, -0.003345},{
      1.017087, 1.701698, -0.003345},{1.016453, 1.701238, -0.006608}}],
    Polygon[{{1.020086, 1.695811, -0.003345},{1.020337, 1.695892, 0.000000},{
      1.017300, 1.701853, 0.000000},{1.017087, 1.701698, -0.003345}}],
    Polygon[{{1.020337, 1.695892, 0.000000},{1.020086, 1.695811, 0.003345},{
      1.017087, 1.701698, 0.003345},{1.017300, 1.701853, 0.000000}}],
    Polygon[{{1.020086, 1.695811, 0.003345},{1.019341, 1.695569, 0.006608},{
      1.016453, 1.701238, 0.006608},{1.017087, 1.701698, 0.003345}}],
    Polygon[{{1.019341, 1.695569, 0.006608},{1.018120, 1.695172, 0.009708},{
      1.015414, 1.700483, 0.009708},{1.016453, 1.701238, 0.006608}}],
    Polygon[{{1.018120, 1.695172, 0.009708},{1.016453, 1.694630, 0.012569},{
      1.013996, 1.699453, 0.012569},{1.015414, 1.700483, 0.009708}}],
    Polygon[{{1.016453, 1.694630, 0.012569},{1.014380, 1.693956, 0.015120},{
      1.012233, 1.698172, 0.015120},{1.013996, 1.699453, 0.012569}}],
    Polygon[{{1.014380, 1.693956, 0.015120},{1.011954, 1.693168, 0.017299},{
      1.010168, 1.696672, 0.017299},{1.012233, 1.698172, 0.015120}}],
    Polygon[{{1.011954, 1.693168, 0.017299},{1.009233, 1.692284, 0.019053},{
      1.007854, 1.694990, 0.019053},{1.010168, 1.696672, 0.017299}}],
    Polygon[{{1.009233, 1.692284, 0.019053},{1.006284, 1.691326, 0.020337},{
      1.005346, 1.693168, 0.020337},{1.007854, 1.694990, 0.019053}}],
    Polygon[{{1.006284, 1.691326, 0.020337},{1.003181, 1.690318, 0.021120},{
      1.002706, 1.691250, 0.021120},{1.005346, 1.693168, 0.020337}}],
    Polygon[{{1.002706, 1.691250, -0.021120},{1.005346, 1.693168, -0.020337},{
      1.003884, 1.694630, -0.020337},{1.001966, 1.691990, -0.021120}}],
    Polygon[{{1.005346, 1.693168, -0.020337},{1.007854, 1.694990, -0.019053},{
      1.005706, 1.697138, -0.019053},{1.003884, 1.694630, -0.020337}}],
    Polygon[{{1.007854, 1.694990, -0.019053},{1.010168, 1.696672, -0.017299},{
      1.007388, 1.699453, -0.017299},{1.005706, 1.697138, -0.019053}}],
    Polygon[{{1.010168, 1.696672, -0.017299},{1.012233, 1.698172, -0.015120},{
      1.008888, 1.701517, -0.015120},{1.007388, 1.699453, -0.017299}}],
    Polygon[{{1.012233, 1.698172, -0.015120},{1.013996, 1.699453, -0.012569},{
      1.010168, 1.703280, -0.012569},{1.008888, 1.701517, -0.015120}}],
    Polygon[{{1.013996, 1.699453, -0.012569},{1.015414, 1.700483, -0.009708},{
      1.011199, 1.704698, -0.009708},{1.010168, 1.703280, -0.012569}}],
    Polygon[{{1.015414, 1.700483, -0.009708},{1.016453, 1.701238, -0.006608},{
      1.011954, 1.705737, -0.006608},{1.011199, 1.704698, -0.009708}}],
    Polygon[{{1.016453, 1.701238, -0.006608},{1.017087, 1.701698, -0.003345},{
      1.012414, 1.706371, -0.003345},{1.011954, 1.705737, -0.006608}}],
    Polygon[{{1.017087, 1.701698, -0.003345},{1.017300, 1.701853, 0.000000},{
      1.012569, 1.706584, 0.000000},{1.012414, 1.706371, -0.003345}}],
    Polygon[{{1.017300, 1.701853, 0.000000},{1.017087, 1.701698, 0.003345},{
      1.012414, 1.706371, 0.003345},{1.012569, 1.706584, 0.000000}}],
    Polygon[{{1.017087, 1.701698, 0.003345},{1.016453, 1.701238, 0.006608},{
      1.011954, 1.705737, 0.006608},{1.012414, 1.706371, 0.003345}}],
    Polygon[{{1.016453, 1.701238, 0.006608},{1.015414, 1.700483, 0.009708},{
      1.011199, 1.704698, 0.009708},{1.011954, 1.705737, 0.006608}}],
    Polygon[{{1.015414, 1.700483, 0.009708},{1.013996, 1.699453, 0.012569},{
      1.010168, 1.703280, 0.012569},{1.011199, 1.704698, 0.009708}}],
    Polygon[{{1.013996, 1.699453, 0.012569},{1.012233, 1.698172, 0.015120},{
      1.008888, 1.701517, 0.015120},{1.010168, 1.703280, 0.012569}}],
    Polygon[{{1.012233, 1.698172, 0.015120},{1.010168, 1.696672, 0.017299},{
      1.007388, 1.699453, 0.017299},{1.008888, 1.701517, 0.015120}}],
    Polygon[{{1.010168, 1.696672, 0.017299},{1.007854, 1.694990, 0.019053},{
      1.005706, 1.697138, 0.019053},{1.007388, 1.699453, 0.017299}}],
    Polygon[{{1.007854, 1.694990, 0.019053},{1.005346, 1.693168, 0.020337},{
      1.003884, 1.694630, 0.020337},{1.005706, 1.697138, 0.019053}}],
    Polygon[{{1.005346, 1.693168, 0.020337},{1.002706, 1.691250, 0.021120},{
      1.001966, 1.691990, 0.021120},{1.003884, 1.694630, 0.020337}}],
    Polygon[{{1.001966, 1.691990, -0.021120},{1.003884, 1.694630, -0.020337},{
      1.002042, 1.695569, -0.020337},{1.001034, 1.692466, -0.021120}}],
    Polygon[{{1.003884, 1.694630, -0.020337},{1.005706, 1.697138, -0.019053},{
      1.003000, 1.698517, -0.019053},{1.002042, 1.695569, -0.020337}}],
    Polygon[{{1.005706, 1.697138, -0.019053},{1.007388, 1.699453, -0.017299},{
      1.003884, 1.701238, -0.017299},{1.003000, 1.698517, -0.019053}}],
    Polygon[{{1.007388, 1.699453, -0.017299},{1.008888, 1.701517, -0.015120},{
      1.004672, 1.703664, -0.015120},{1.003884, 1.701238, -0.017299}}],
    Polygon[{{1.008888, 1.701517, -0.015120},{1.010168, 1.703280, -0.012569},{
      1.005346, 1.705737, -0.012569},{1.004672, 1.703664, -0.015120}}],
    Polygon[{{1.010168, 1.703280, -0.012569},{1.011199, 1.704698, -0.009708},{
      1.005888, 1.707404, -0.009708},{1.005346, 1.705737, -0.012569}}],
    Polygon[{{1.011199, 1.704698, -0.009708},{1.011954, 1.705737, -0.006608},{
      1.006284, 1.708626, -0.006608},{1.005888, 1.707404, -0.009708}}],
    Polygon[{{1.011954, 1.705737, -0.006608},{1.012414, 1.706371, -0.003345},{
      1.006526, 1.709370, -0.003345},{1.006284, 1.708626, -0.006608}}],
    Polygon[{{1.012414, 1.706371, -0.003345},{1.012569, 1.706584, 0.000000},{
      1.006608, 1.709621, 0.000000},{1.006526, 1.709370, -0.003345}}],
    Polygon[{{1.012569, 1.706584, 0.000000},{1.012414, 1.706371, 0.003345},{
      1.006526, 1.709370, 0.003345},{1.006608, 1.709621, 0.000000}}],
    Polygon[{{1.012414, 1.706371, 0.003345},{1.011954, 1.705737, 0.006608},{
      1.006284, 1.708626, 0.006608},{1.006526, 1.709370, 0.003345}}],
    Polygon[{{1.011954, 1.705737, 0.006608},{1.011199, 1.704698, 0.009708},{
      1.005888, 1.707404, 0.009708},{1.006284, 1.708626, 0.006608}}],
    Polygon[{{1.011199, 1.704698, 0.009708},{1.010168, 1.703280, 0.012569},{
      1.005346, 1.705737, 0.012569},{1.005888, 1.707404, 0.009708}}],
    Polygon[{{1.010168, 1.703280, 0.012569},{1.008888, 1.701517, 0.015120},{
      1.004672, 1.703664, 0.015120},{1.005346, 1.705737, 0.012569}}],
    Polygon[{{1.008888, 1.701517, 0.015120},{1.007388, 1.699453, 0.017299},{
      1.003884, 1.701238, 0.017299},{1.004672, 1.703664, 0.015120}}],
    Polygon[{{1.007388, 1.699453, 0.017299},{1.005706, 1.697138, 0.019053},{
      1.003000, 1.698517, 0.019053},{1.003884, 1.701238, 0.017299}}],
    Polygon[{{1.005706, 1.697138, 0.019053},{1.003884, 1.694630, 0.020337},{
      1.002042, 1.695569, 0.020337},{1.003000, 1.698517, 0.019053}}],
    Polygon[{{1.003884, 1.694630, 0.020337},{1.001966, 1.691990, 0.021120},{
      1.001034, 1.692466, 0.021120},{1.002042, 1.695569, 0.020337}}],
    Polygon[{{1.001034, 1.692466, -0.021120},{1.002042, 1.695569, -0.020337},{
      1.000000, 1.695892, -0.020337},{1.000000, 1.692629, -0.021120}}],
    Polygon[{{1.002042, 1.695569, -0.020337},{1.003000, 1.698517, -0.019053},{
      1.000000, 1.698992, -0.019053},{1.000000, 1.695892, -0.020337}}],
    Polygon[{{1.003000, 1.698517, -0.019053},{1.003884, 1.701238, -0.017299},{
      1.000000, 1.701853, -0.017299},{1.000000, 1.698992, -0.019053}}],
    Polygon[{{1.003884, 1.701238, -0.017299},{1.004672, 1.703664, -0.015120},{
      1.000000, 1.704404, -0.015120},{1.000000, 1.701853, -0.017299}}],
    Polygon[{{1.004672, 1.703664, -0.015120},{1.005346, 1.705737, -0.012569},{
      1.000000, 1.706584, -0.012569},{1.000000, 1.704404, -0.015120}}],
    Polygon[{{1.005346, 1.705737, -0.012569},{1.005888, 1.707404, -0.009708},{
      1.000000, 1.708337, -0.009708},{1.000000, 1.706584, -0.012569}}],
    Polygon[{{1.005888, 1.707404, -0.009708},{1.006284, 1.708626, -0.006608},{
      1.000000, 1.709621, -0.006608},{1.000000, 1.708337, -0.009708}}],
    Polygon[{{1.006284, 1.708626, -0.006608},{1.006526, 1.709370, -0.003345},{
      1.000000, 1.710404, -0.003345},{1.000000, 1.709621, -0.006608}}],
    Polygon[{{1.006526, 1.709370, -0.003345},{1.006608, 1.709621, 0.000000},{
      1.000000, 1.710667, 0.000000},{1.000000, 1.710404, -0.003345}}],
    Polygon[{{1.006608, 1.709621, 0.000000},{1.006526, 1.709370, 0.003345},{
      1.000000, 1.710404, 0.003345},{1.000000, 1.710667, 0.000000}}],
    Polygon[{{1.006526, 1.709370, 0.003345},{1.006284, 1.708626, 0.006608},{
      1.000000, 1.709621, 0.006608},{1.000000, 1.710404, 0.003345}}],
    Polygon[{{1.006284, 1.708626, 0.006608},{1.005888, 1.707404, 0.009708},{
      1.000000, 1.708337, 0.009708},{1.000000, 1.709621, 0.006608}}],
    Polygon[{{1.005888, 1.707404, 0.009708},{1.005346, 1.705737, 0.012569},{
      1.000000, 1.706584, 0.012569},{1.000000, 1.708337, 0.009708}}],
    Polygon[{{1.005346, 1.705737, 0.012569},{1.004672, 1.703664, 0.015120},{
      1.000000, 1.704404, 0.015120},{1.000000, 1.706584, 0.012569}}],
    Polygon[{{1.004672, 1.703664, 0.015120},{1.003884, 1.701238, 0.017299},{
      1.000000, 1.701853, 0.017299},{1.000000, 1.704404, 0.015120}}],
    Polygon[{{1.003884, 1.701238, 0.017299},{1.003000, 1.698517, 0.019053},{
      1.000000, 1.698992, 0.019053},{1.000000, 1.701853, 0.017299}}],
    Polygon[{{1.003000, 1.698517, 0.019053},{1.002042, 1.695569, 0.020337},{
      1.000000, 1.695892, 0.020337},{1.000000, 1.698992, 0.019053}}],
    Polygon[{{1.002042, 1.695569, 0.020337},{1.001034, 1.692466, 0.021120},{
      1.000000, 1.692629, 0.021120},{1.000000, 1.695892, 0.020337}}],
    Polygon[{{1.000000, 1.692629, -0.021120},{1.000000, 1.695892, -0.020337},{
      0.997958, 1.695569, -0.020337},{0.998966, 1.692466, -0.021120}}],
    Polygon[{{1.000000, 1.695892, -0.020337},{1.000000, 1.698992, -0.019053},{
      0.997000, 1.698517, -0.019053},{0.997958, 1.695569, -0.020337}}],
    Polygon[{{1.000000, 1.698992, -0.019053},{1.000000, 1.701853, -0.017299},{
      0.996116, 1.701238, -0.017299},{0.997000, 1.698517, -0.019053}}],
    Polygon[{{1.000000, 1.701853, -0.017299},{1.000000, 1.704404, -0.015120},{
      0.995328, 1.703664, -0.015120},{0.996116, 1.701238, -0.017299}}],
    Polygon[{{1.000000, 1.704404, -0.015120},{1.000000, 1.706584, -0.012569},{
      0.994654, 1.705737, -0.012569},{0.995328, 1.703664, -0.015120}}],
    Polygon[{{1.000000, 1.706584, -0.012569},{1.000000, 1.708337, -0.009708},{
      0.994112, 1.707404, -0.009708},{0.994654, 1.705737, -0.012569}}],
    Polygon[{{1.000000, 1.708337, -0.009708},{1.000000, 1.709621, -0.006608},{
      0.993716, 1.708626, -0.006608},{0.994112, 1.707404, -0.009708}}],
    Polygon[{{1.000000, 1.709621, -0.006608},{1.000000, 1.710404, -0.003345},{
      0.993474, 1.709370, -0.003345},{0.993716, 1.708626, -0.006608}}],
    Polygon[{{1.000000, 1.710404, -0.003345},{1.000000, 1.710667, 0.000000},{
      0.993392, 1.709621, 0.000000},{0.993474, 1.709370, -0.003345}}],
    Polygon[{{1.000000, 1.710667, 0.000000},{1.000000, 1.710404, 0.003345},{
      0.993474, 1.709370, 0.003345},{0.993392, 1.709621, 0.000000}}],
    Polygon[{{1.000000, 1.710404, 0.003345},{1.000000, 1.709621, 0.006608},{
      0.993716, 1.708626, 0.006608},{0.993474, 1.709370, 0.003345}}],
    Polygon[{{1.000000, 1.709621, 0.006608},{1.000000, 1.708337, 0.009708},{
      0.994112, 1.707404, 0.009708},{0.993716, 1.708626, 0.006608}}],
    Polygon[{{1.000000, 1.708337, 0.009708},{1.000000, 1.706584, 0.012569},{
      0.994654, 1.705737, 0.012569},{0.994112, 1.707404, 0.009708}}],
    Polygon[{{1.000000, 1.706584, 0.012569},{1.000000, 1.704404, 0.015120},{
      0.995328, 1.703664, 0.015120},{0.994654, 1.705737, 0.012569}}],
    Polygon[{{1.000000, 1.704404, 0.015120},{1.000000, 1.701853, 0.017299},{
      0.996116, 1.701238, 0.017299},{0.995328, 1.703664, 0.015120}}],
    Polygon[{{1.000000, 1.701853, 0.017299},{1.000000, 1.698992, 0.019053},{
      0.997000, 1.698517, 0.019053},{0.996116, 1.701238, 0.017299}}],
    Polygon[{{1.000000, 1.698992, 0.019053},{1.000000, 1.695892, 0.020337},{
      0.997958, 1.695569, 0.020337},{0.997000, 1.698517, 0.019053}}],
    Polygon[{{1.000000, 1.695892, 0.020337},{1.000000, 1.692629, 0.021120},{
      0.998966, 1.692466, 0.021120},{0.997958, 1.695569, 0.020337}}],
    Polygon[{{0.998966, 1.692466, -0.021120},{0.997958, 1.695569, -0.020337},{
      0.996116, 1.694630, -0.020337},{0.998034, 1.691990, -0.021120}}],
    Polygon[{{0.997958, 1.695569, -0.020337},{0.997000, 1.698517, -0.019053},{
      0.994294, 1.697138, -0.019053},{0.996116, 1.694630, -0.020337}}],
    Polygon[{{0.997000, 1.698517, -0.019053},{0.996116, 1.701238, -0.017299},{
      0.992612, 1.699453, -0.017299},{0.994294, 1.697138, -0.019053}}],
    Polygon[{{0.996116, 1.701238, -0.017299},{0.995328, 1.703664, -0.015120},{
      0.991113, 1.701517, -0.015120},{0.992612, 1.699453, -0.017299}}],
    Polygon[{{0.995328, 1.703664, -0.015120},{0.994654, 1.705737, -0.012569},{
      0.989832, 1.703280, -0.012569},{0.991113, 1.701517, -0.015120}}],
    Polygon[{{0.994654, 1.705737, -0.012569},{0.994112, 1.707404, -0.009708},{
      0.988801, 1.704698, -0.009708},{0.989832, 1.703280, -0.012569}}],
    Polygon[{{0.994112, 1.707404, -0.009708},{0.993716, 1.708626, -0.006608},{
      0.988046, 1.705737, -0.006608},{0.988801, 1.704698, -0.009708}}],
    Polygon[{{0.993716, 1.708626, -0.006608},{0.993474, 1.709370, -0.003345},{
      0.987586, 1.706371, -0.003345},{0.988046, 1.705737, -0.006608}}],
    Polygon[{{0.993474, 1.709370, -0.003345},{0.993392, 1.709621, 0.000000},{
      0.987431, 1.706584, 0.000000},{0.987586, 1.706371, -0.003345}}],
    Polygon[{{0.993392, 1.709621, 0.000000},{0.993474, 1.709370, 0.003345},{
      0.987586, 1.706371, 0.003345},{0.987431, 1.706584, 0.000000}}],
    Polygon[{{0.993474, 1.709370, 0.003345},{0.993716, 1.708626, 0.006608},{
      0.988046, 1.705737, 0.006608},{0.987586, 1.706371, 0.003345}}],
    Polygon[{{0.993716, 1.708626, 0.006608},{0.994112, 1.707404, 0.009708},{
      0.988801, 1.704698, 0.009708},{0.988046, 1.705737, 0.006608}}],
    Polygon[{{0.994112, 1.707404, 0.009708},{0.994654, 1.705737, 0.012569},{
      0.989832, 1.703280, 0.012569},{0.988801, 1.704698, 0.009708}}],
    Polygon[{{0.994654, 1.705737, 0.012569},{0.995328, 1.703664, 0.015120},{
      0.991113, 1.701517, 0.015120},{0.989832, 1.703280, 0.012569}}],
    Polygon[{{0.995328, 1.703664, 0.015120},{0.996116, 1.701238, 0.017299},{
      0.992612, 1.699453, 0.017299},{0.991113, 1.701517, 0.015120}}],
    Polygon[{{0.996116, 1.701238, 0.017299},{0.997000, 1.698517, 0.019053},{
      0.994294, 1.697138, 0.019053},{0.992612, 1.699453, 0.017299}}],
    Polygon[{{0.997000, 1.698517, 0.019053},{0.997958, 1.695569, 0.020337},{
      0.996116, 1.694630, 0.020337},{0.994294, 1.697138, 0.019053}}],
    Polygon[{{0.997958, 1.695569, 0.020337},{0.998966, 1.692466, 0.021120},{
      0.998034, 1.691990, 0.021120},{0.996116, 1.694630, 0.020337}}],
    Polygon[{{0.998034, 1.691990, -0.021120},{0.996116, 1.694630, -0.020337},{
      0.994654, 1.693168, -0.020337},{0.997294, 1.691250, -0.021120}}],
    Polygon[{{0.996116, 1.694630, -0.020337},{0.994294, 1.697138, -0.019053},{
      0.992146, 1.694990, -0.019053},{0.994654, 1.693168, -0.020337}}],
    Polygon[{{0.994294, 1.697138, -0.019053},{0.992612, 1.699453, -0.017299},{
      0.989832, 1.696672, -0.017299},{0.992146, 1.694990, -0.019053}}],
    Polygon[{{0.992612, 1.699453, -0.017299},{0.991113, 1.701517, -0.015120},{
      0.987767, 1.698172, -0.015120},{0.989832, 1.696672, -0.017299}}],
    Polygon[{{0.991113, 1.701517, -0.015120},{0.989832, 1.703280, -0.012569},{
      0.986004, 1.699453, -0.012569},{0.987767, 1.698172, -0.015120}}],
    Polygon[{{0.989832, 1.703280, -0.012569},{0.988801, 1.704698, -0.009708},{
      0.984586, 1.700483, -0.009708},{0.986004, 1.699453, -0.012569}}],
    Polygon[{{0.988801, 1.704698, -0.009708},{0.988046, 1.705737, -0.006608},{
      0.983547, 1.701238, -0.006608},{0.984586, 1.700483, -0.009708}}],
    Polygon[{{0.988046, 1.705737, -0.006608},{0.987586, 1.706371, -0.003345},{
      0.982913, 1.701698, -0.003345},{0.983547, 1.701238, -0.006608}}],
    Polygon[{{0.987586, 1.706371, -0.003345},{0.987431, 1.706584, 0.000000},{
      0.982701, 1.701853, 0.000000},{0.982913, 1.701698, -0.003345}}],
    Polygon[{{0.987431, 1.706584, 0.000000},{0.987586, 1.706371, 0.003345},{
      0.982913, 1.701698, 0.003345},{0.982701, 1.701853, 0.000000}}],
    Polygon[{{0.987586, 1.706371, 0.003345},{0.988046, 1.705737, 0.006608},{
      0.983547, 1.701238, 0.006608},{0.982913, 1.701698, 0.003345}}],
    Polygon[{{0.988046, 1.705737, 0.006608},{0.988801, 1.704698, 0.009708},{
      0.984586, 1.700483, 0.009708},{0.983547, 1.701238, 0.006608}}],
    Polygon[{{0.988801, 1.704698, 0.009708},{0.989832, 1.703280, 0.012569},{
      0.986004, 1.699453, 0.012569},{0.984586, 1.700483, 0.009708}}],
    Polygon[{{0.989832, 1.703280, 0.012569},{0.991113, 1.701517, 0.015120},{
      0.987767, 1.698172, 0.015120},{0.986004, 1.699453, 0.012569}}],
    Polygon[{{0.991113, 1.701517, 0.015120},{0.992612, 1.699453, 0.017299},{
      0.989832, 1.696672, 0.017299},{0.987767, 1.698172, 0.015120}}],
    Polygon[{{0.992612, 1.699453, 0.017299},{0.994294, 1.697138, 0.019053},{
      0.992146, 1.694990, 0.019053},{0.989832, 1.696672, 0.017299}}],
    Polygon[{{0.994294, 1.697138, 0.019053},{0.996116, 1.694630, 0.020337},{
      0.994654, 1.693168, 0.020337},{0.992146, 1.694990, 0.019053}}],
    Polygon[{{0.996116, 1.694630, 0.020337},{0.998034, 1.691990, 0.021120},{
      0.997294, 1.691250, 0.021120},{0.994654, 1.693168, 0.020337}}],
    Polygon[{{0.997294, 1.691250, -0.021120},{0.994654, 1.693168, -0.020337},{
      0.993716, 1.691326, -0.020337},{0.996819, 1.690318, -0.021120}}],
    Polygon[{{0.994654, 1.693168, -0.020337},{0.992146, 1.694990, -0.019053},{
      0.990767, 1.692284, -0.019053},{0.993716, 1.691326, -0.020337}}],
    Polygon[{{0.992146, 1.694990, -0.019053},{0.989832, 1.696672, -0.017299},{
      0.988046, 1.693168, -0.017299},{0.990767, 1.692284, -0.019053}}],
    Polygon[{{0.989832, 1.696672, -0.017299},{0.987767, 1.698172, -0.015120},{
      0.985620, 1.693956, -0.015120},{0.988046, 1.693168, -0.017299}}],
    Polygon[{{0.987767, 1.698172, -0.015120},{0.986004, 1.699453, -0.012569},{
      0.983547, 1.694630, -0.012569},{0.985620, 1.693956, -0.015120}}],
    Polygon[{{0.986004, 1.699453, -0.012569},{0.984586, 1.700483, -0.009708},{
      0.981880, 1.695172, -0.009708},{0.983547, 1.694630, -0.012569}}],
    Polygon[{{0.984586, 1.700483, -0.009708},{0.983547, 1.701238, -0.006608},{
      0.980659, 1.695569, -0.006608},{0.981880, 1.695172, -0.009708}}],
    Polygon[{{0.983547, 1.701238, -0.006608},{0.982913, 1.701698, -0.003345},{
      0.979914, 1.695811, -0.003345},{0.980659, 1.695569, -0.006608}}],
    Polygon[{{0.982913, 1.701698, -0.003345},{0.982701, 1.701853, 0.000000},{
      0.979663, 1.695892, 0.000000},{0.979914, 1.695811, -0.003345}}],
    Polygon[{{0.982701, 1.701853, 0.000000},{0.982913, 1.701698, 0.003345},{
      0.979914, 1.695811, 0.003345},{0.979663, 1.695892, 0.000000}}],
    Polygon[{{0.982913, 1.701698, 0.003345},{0.983547, 1.701238, 0.006608},{
      0.980659, 1.695569, 0.006608},{0.979914, 1.695811, 0.003345}}],
    Polygon[{{0.983547, 1.701238, 0.006608},{0.984586, 1.700483, 0.009708},{
      0.981880, 1.695172, 0.009708},{0.980659, 1.695569, 0.006608}}],
    Polygon[{{0.984586, 1.700483, 0.009708},{0.986004, 1.699453, 0.012569},{
      0.983547, 1.694630, 0.012569},{0.981880, 1.695172, 0.009708}}],
    Polygon[{{0.986004, 1.699453, 0.012569},{0.987767, 1.698172, 0.015120},{
      0.985620, 1.693956, 0.015120},{0.983547, 1.694630, 0.012569}}],
    Polygon[{{0.987767, 1.698172, 0.015120},{0.989832, 1.696672, 0.017299},{
      0.988046, 1.693168, 0.017299},{0.985620, 1.693956, 0.015120}}],
    Polygon[{{0.989832, 1.696672, 0.017299},{0.992146, 1.694990, 0.019053},{
      0.990767, 1.692284, 0.019053},{0.988046, 1.693168, 0.017299}}],
    Polygon[{{0.992146, 1.694990, 0.019053},{0.994654, 1.693168, 0.020337},{
      0.993716, 1.691326, 0.020337},{0.990767, 1.692284, 0.019053}}],
    Polygon[{{0.994654, 1.693168, 0.020337},{0.997294, 1.691250, 0.021120},{
      0.996819, 1.690318, 0.021120},{0.993716, 1.691326, 0.020337}}],
    Polygon[{{0.996819, 1.690318, -0.021120},{0.993716, 1.691326, -0.020337},{
      0.993392, 1.689284, -0.020337},{0.996655, 1.689284, -0.021120}}],
    Polygon[{{0.993716, 1.691326, -0.020337},{0.990767, 1.692284, -0.019053},{
      0.990292, 1.689284, -0.019053},{0.993392, 1.689284, -0.020337}}],
    Polygon[{{0.990767, 1.692284, -0.019053},{0.988046, 1.693168, -0.017299},{
      0.987431, 1.689284, -0.017299},{0.990292, 1.689284, -0.019053}}],
    Polygon[{{0.988046, 1.693168, -0.017299},{0.985620, 1.693956, -0.015120},{
      0.984880, 1.689284, -0.015120},{0.987431, 1.689284, -0.017299}}],
    Polygon[{{0.985620, 1.693956, -0.015120},{0.983547, 1.694630, -0.012569},{
      0.982701, 1.689284, -0.012569},{0.984880, 1.689284, -0.015120}}],
    Polygon[{{0.983547, 1.694630, -0.012569},{0.981880, 1.695172, -0.009708},{
      0.980947, 1.689284, -0.009708},{0.982701, 1.689284, -0.012569}}],
    Polygon[{{0.981880, 1.695172, -0.009708},{0.980659, 1.695569, -0.006608},{
      0.979663, 1.689284, -0.006608},{0.980947, 1.689284, -0.009708}}],
    Polygon[{{0.980659, 1.695569, -0.006608},{0.979914, 1.695811, -0.003345},{
      0.978880, 1.689284, -0.003345},{0.979663, 1.689284, -0.006608}}],
    Polygon[{{0.979914, 1.695811, -0.003345},{0.979663, 1.695892, 0.000000},{
      0.978617, 1.689284, 0.000000},{0.978880, 1.689284, -0.003345}}],
    Polygon[{{0.979663, 1.695892, 0.000000},{0.979914, 1.695811, 0.003345},{
      0.978880, 1.689284, 0.003345},{0.978617, 1.689284, 0.000000}}],
    Polygon[{{0.979914, 1.695811, 0.003345},{0.980659, 1.695569, 0.006608},{
      0.979663, 1.689284, 0.006608},{0.978880, 1.689284, 0.003345}}],
    Polygon[{{0.980659, 1.695569, 0.006608},{0.981880, 1.695172, 0.009708},{
      0.980947, 1.689284, 0.009708},{0.979663, 1.689284, 0.006608}}],
    Polygon[{{0.981880, 1.695172, 0.009708},{0.983547, 1.694630, 0.012569},{
      0.982701, 1.689284, 0.012569},{0.980947, 1.689284, 0.009708}}],
    Polygon[{{0.983547, 1.694630, 0.012569},{0.985620, 1.693956, 0.015120},{
      0.984880, 1.689284, 0.015120},{0.982701, 1.689284, 0.012569}}],
    Polygon[{{0.985620, 1.693956, 0.015120},{0.988046, 1.693168, 0.017299},{
      0.987431, 1.689284, 0.017299},{0.984880, 1.689284, 0.015120}}],
    Polygon[{{0.988046, 1.693168, 0.017299},{0.990767, 1.692284, 0.019053},{
      0.990292, 1.689284, 0.019053},{0.987431, 1.689284, 0.017299}}],
    Polygon[{{0.990767, 1.692284, 0.019053},{0.993716, 1.691326, 0.020337},{
      0.993392, 1.689284, 0.020337},{0.990292, 1.689284, 0.019053}}],
    Polygon[{{0.993716, 1.691326, 0.020337},{0.996819, 1.690318, 0.021120},{
      0.996655, 1.689284, 0.021120},{0.993392, 1.689284, 0.020337}}],
    Polygon[{{0.996655, 1.689284, -0.021120},{0.993392, 1.689284, -0.020337},{
      0.993716, 1.687242, -0.020337},{0.996819, 1.688250, -0.021120}}],
    Polygon[{{0.993392, 1.689284, -0.020337},{0.990292, 1.689284, -0.019053},{
      0.990767, 1.686284, -0.019053},{0.993716, 1.687242, -0.020337}}],
    Polygon[{{0.990292, 1.689284, -0.019053},{0.987431, 1.689284, -0.017299},{
      0.988046, 1.685400, -0.017299},{0.990767, 1.686284, -0.019053}}],
    Polygon[{{0.987431, 1.689284, -0.017299},{0.984880, 1.689284, -0.015120},{
      0.985620, 1.684612, -0.015120},{0.988046, 1.685400, -0.017299}}],
    Polygon[{{0.984880, 1.689284, -0.015120},{0.982701, 1.689284, -0.012569},{
      0.983547, 1.683938, -0.012569},{0.985620, 1.684612, -0.015120}}],
    Polygon[{{0.982701, 1.689284, -0.012569},{0.980947, 1.689284, -0.009708},{
      0.981880, 1.683396, -0.009708},{0.983547, 1.683938, -0.012569}}],
    Polygon[{{0.980947, 1.689284, -0.009708},{0.979663, 1.689284, -0.006608},{
      0.980659, 1.683000, -0.006608},{0.981880, 1.683396, -0.009708}}],
    Polygon[{{0.979663, 1.689284, -0.006608},{0.978880, 1.689284, -0.003345},{
      0.979914, 1.682758, -0.003345},{0.980659, 1.683000, -0.006608}}],
    Polygon[{{0.978880, 1.689284, -0.003345},{0.978617, 1.689284, 0.000000},{
      0.979663, 1.682676, 0.000000},{0.979914, 1.682758, -0.003345}}],
    Polygon[{{0.978617, 1.689284, 0.000000},{0.978880, 1.689284, 0.003345},{
      0.979914, 1.682758, 0.003345},{0.979663, 1.682676, 0.000000}}],
    Polygon[{{0.978880, 1.689284, 0.003345},{0.979663, 1.689284, 0.006608},{
      0.980659, 1.683000, 0.006608},{0.979914, 1.682758, 0.003345}}],
    Polygon[{{0.979663, 1.689284, 0.006608},{0.980947, 1.689284, 0.009708},{
      0.981880, 1.683396, 0.009708},{0.980659, 1.683000, 0.006608}}],
    Polygon[{{0.980947, 1.689284, 0.009708},{0.982701, 1.689284, 0.012569},{
      0.983547, 1.683938, 0.012569},{0.981880, 1.683396, 0.009708}}],
    Polygon[{{0.982701, 1.689284, 0.012569},{0.984880, 1.689284, 0.015120},{
      0.985620, 1.684612, 0.015120},{0.983547, 1.683938, 0.012569}}],
    Polygon[{{0.984880, 1.689284, 0.015120},{0.987431, 1.689284, 0.017299},{
      0.988046, 1.685400, 0.017299},{0.985620, 1.684612, 0.015120}}],
    Polygon[{{0.987431, 1.689284, 0.017299},{0.990292, 1.689284, 0.019053},{
      0.990767, 1.686284, 0.019053},{0.988046, 1.685400, 0.017299}}],
    Polygon[{{0.990292, 1.689284, 0.019053},{0.993392, 1.689284, 0.020337},{
      0.993716, 1.687242, 0.020337},{0.990767, 1.686284, 0.019053}}],
    Polygon[{{0.993392, 1.689284, 0.020337},{0.996655, 1.689284, 0.021120},{
      0.996819, 1.688250, 0.021120},{0.993716, 1.687242, 0.020337}}],
    Polygon[{{0.996819, 1.688250, -0.021120},{0.993716, 1.687242, -0.020337},{
      0.994654, 1.685400, -0.020337},{0.997294, 1.687318, -0.021120}}],
    Polygon[{{0.993716, 1.687242, -0.020337},{0.990767, 1.686284, -0.019053},{
      0.992146, 1.683578, -0.019053},{0.994654, 1.685400, -0.020337}}],
    Polygon[{{0.990767, 1.686284, -0.019053},{0.988046, 1.685400, -0.017299},{
      0.989832, 1.681896, -0.017299},{0.992146, 1.683578, -0.019053}}],
    Polygon[{{0.988046, 1.685400, -0.017299},{0.985620, 1.684612, -0.015120},{
      0.987767, 1.680397, -0.015120},{0.989832, 1.681896, -0.017299}}],
    Polygon[{{0.985620, 1.684612, -0.015120},{0.983547, 1.683938, -0.012569},{
      0.986004, 1.679116, -0.012569},{0.987767, 1.680397, -0.015120}}],
    Polygon[{{0.983547, 1.683938, -0.012569},{0.981880, 1.683396, -0.009708},{
      0.984586, 1.678085, -0.009708},{0.986004, 1.679116, -0.012569}}],
    Polygon[{{0.981880, 1.683396, -0.009708},{0.980659, 1.683000, -0.006608},{
      0.983547, 1.677330, -0.006608},{0.984586, 1.678085, -0.009708}}],
    Polygon[{{0.980659, 1.683000, -0.006608},{0.979914, 1.682758, -0.003345},{
      0.982913, 1.676870, -0.003345},{0.983547, 1.677330, -0.006608}}],
    Polygon[{{0.979914, 1.682758, -0.003345},{0.979663, 1.682676, 0.000000},{
      0.982701, 1.676715, 0.000000},{0.982913, 1.676870, -0.003345}}],
    Polygon[{{0.979663, 1.682676, 0.000000},{0.979914, 1.682758, 0.003345},{
      0.982913, 1.676870, 0.003345},{0.982701, 1.676715, 0.000000}}],
    Polygon[{{0.979914, 1.682758, 0.003345},{0.980659, 1.683000, 0.006608},{
      0.983547, 1.677330, 0.006608},{0.982913, 1.676870, 0.003345}}],
    Polygon[{{0.980659, 1.683000, 0.006608},{0.981880, 1.683396, 0.009708},{
      0.984586, 1.678085, 0.009708},{0.983547, 1.677330, 0.006608}}],
    Polygon[{{0.981880, 1.683396, 0.009708},{0.983547, 1.683938, 0.012569},{
      0.986004, 1.679116, 0.012569},{0.984586, 1.678085, 0.009708}}],
    Polygon[{{0.983547, 1.683938, 0.012569},{0.985620, 1.684612, 0.015120},{
      0.987767, 1.680397, 0.015120},{0.986004, 1.679116, 0.012569}}],
    Polygon[{{0.985620, 1.684612, 0.015120},{0.988046, 1.685400, 0.017299},{
      0.989832, 1.681896, 0.017299},{0.987767, 1.680397, 0.015120}}],
    Polygon[{{0.988046, 1.685400, 0.017299},{0.990767, 1.686284, 0.019053},{
      0.992146, 1.683578, 0.019053},{0.989832, 1.681896, 0.017299}}],
    Polygon[{{0.990767, 1.686284, 0.019053},{0.993716, 1.687242, 0.020337},{
      0.994654, 1.685400, 0.020337},{0.992146, 1.683578, 0.019053}}],
    Polygon[{{0.993716, 1.687242, 0.020337},{0.996819, 1.688250, 0.021120},{
      0.997294, 1.687318, 0.021120},{0.994654, 1.685400, 0.020337}}],
    Polygon[{{0.997294, 1.687318, -0.021120},{0.994654, 1.685400, -0.020337},{
      0.996116, 1.683938, -0.020337},{0.998034, 1.686578, -0.021120}}],
    Polygon[{{0.994654, 1.685400, -0.020337},{0.992146, 1.683578, -0.019053},{
      0.994294, 1.681430, -0.019053},{0.996116, 1.683938, -0.020337}}],
    Polygon[{{0.992146, 1.683578, -0.019053},{0.989832, 1.681896, -0.017299},{
      0.992612, 1.679116, -0.017299},{0.994294, 1.681430, -0.019053}}],
    Polygon[{{0.989832, 1.681896, -0.017299},{0.987767, 1.680397, -0.015120},{
      0.991113, 1.677052, -0.015120},{0.992612, 1.679116, -0.017299}}],
    Polygon[{{0.987767, 1.680397, -0.015120},{0.986004, 1.679116, -0.012569},{
      0.989832, 1.675289, -0.012569},{0.991113, 1.677052, -0.015120}}],
    Polygon[{{0.986004, 1.679116, -0.012569},{0.984586, 1.678085, -0.009708},{
      0.988801, 1.673870, -0.009708},{0.989832, 1.675289, -0.012569}}],
    Polygon[{{0.984586, 1.678085, -0.009708},{0.983547, 1.677330, -0.006608},{
      0.988046, 1.672831, -0.006608},{0.988801, 1.673870, -0.009708}}],
    Polygon[{{0.983547, 1.677330, -0.006608},{0.982913, 1.676870, -0.003345},{
      0.987586, 1.672198, -0.003345},{0.988046, 1.672831, -0.006608}}],
    Polygon[{{0.982913, 1.676870, -0.003345},{0.982701, 1.676715, 0.000000},{
      0.987431, 1.671985, 0.000000},{0.987586, 1.672198, -0.003345}}],
    Polygon[{{0.982701, 1.676715, 0.000000},{0.982913, 1.676870, 0.003345},{
      0.987586, 1.672198, 0.003345},{0.987431, 1.671985, 0.000000}}],
    Polygon[{{0.982913, 1.676870, 0.003345},{0.983547, 1.677330, 0.006608},{
      0.988046, 1.672831, 0.006608},{0.987586, 1.672198, 0.003345}}],
    Polygon[{{0.983547, 1.677330, 0.006608},{0.984586, 1.678085, 0.009708},{
      0.988801, 1.673870, 0.009708},{0.988046, 1.672831, 0.006608}}],
    Polygon[{{0.984586, 1.678085, 0.009708},{0.986004, 1.679116, 0.012569},{
      0.989832, 1.675289, 0.012569},{0.988801, 1.673870, 0.009708}}],
    Polygon[{{0.986004, 1.679116, 0.012569},{0.987767, 1.680397, 0.015120},{
      0.991113, 1.677052, 0.015120},{0.989832, 1.675289, 0.012569}}],
    Polygon[{{0.987767, 1.680397, 0.015120},{0.989832, 1.681896, 0.017299},{
      0.992612, 1.679116, 0.017299},{0.991113, 1.677052, 0.015120}}],
    Polygon[{{0.989832, 1.681896, 0.017299},{0.992146, 1.683578, 0.019053},{
      0.994294, 1.681430, 0.019053},{0.992612, 1.679116, 0.017299}}],
    Polygon[{{0.992146, 1.683578, 0.019053},{0.994654, 1.685400, 0.020337},{
      0.996116, 1.683938, 0.020337},{0.994294, 1.681430, 0.019053}}],
    Polygon[{{0.994654, 1.685400, 0.020337},{0.997294, 1.687318, 0.021120},{
      0.998034, 1.686578, 0.021120},{0.996116, 1.683938, 0.020337}}],
    Polygon[{{0.998034, 1.686578, -0.021120},{0.996116, 1.683938, -0.020337},{
      0.997958, 1.683000, -0.020337},{0.998966, 1.686103, -0.021120}}],
    Polygon[{{0.996116, 1.683938, -0.020337},{0.994294, 1.681430, -0.019053},{
      0.997000, 1.680051, -0.019053},{0.997958, 1.683000, -0.020337}}],
    Polygon[{{0.994294, 1.681430, -0.019053},{0.992612, 1.679116, -0.017299},{
      0.996116, 1.677330, -0.017299},{0.997000, 1.680051, -0.019053}}],
    Polygon[{{0.992612, 1.679116, -0.017299},{0.991113, 1.677052, -0.015120},{
      0.995328, 1.674904, -0.015120},{0.996116, 1.677330, -0.017299}}],
    Polygon[{{0.991113, 1.677052, -0.015120},{0.989832, 1.675289, -0.012569},{
      0.994654, 1.672831, -0.012569},{0.995328, 1.674904, -0.015120}}],
    Polygon[{{0.989832, 1.675289, -0.012569},{0.988801, 1.673870, -0.009708},{
      0.994112, 1.671164, -0.009708},{0.994654, 1.672831, -0.012569}}],
    Polygon[{{0.988801, 1.673870, -0.009708},{0.988046, 1.672831, -0.006608},{
      0.993716, 1.669943, -0.006608},{0.994112, 1.671164, -0.009708}}],
    Polygon[{{0.988046, 1.672831, -0.006608},{0.987586, 1.672198, -0.003345},{
      0.993474, 1.669198, -0.003345},{0.993716, 1.669943, -0.006608}}],
    Polygon[{{0.987586, 1.672198, -0.003345},{0.987431, 1.671985, 0.000000},{
      0.993392, 1.668947, 0.000000},{0.993474, 1.669198, -0.003345}}],
    Polygon[{{0.987431, 1.671985, 0.000000},{0.987586, 1.672198, 0.003345},{
      0.993474, 1.669198, 0.003345},{0.993392, 1.668947, 0.000000}}],
    Polygon[{{0.987586, 1.672198, 0.003345},{0.988046, 1.672831, 0.006608},{
      0.993716, 1.669943, 0.006608},{0.993474, 1.669198, 0.003345}}],
    Polygon[{{0.988046, 1.672831, 0.006608},{0.988801, 1.673870, 0.009708},{
      0.994112, 1.671164, 0.009708},{0.993716, 1.669943, 0.006608}}],
    Polygon[{{0.988801, 1.673870, 0.009708},{0.989832, 1.675289, 0.012569},{
      0.994654, 1.672831, 0.012569},{0.994112, 1.671164, 0.009708}}],
    Polygon[{{0.989832, 1.675289, 0.012569},{0.991113, 1.677052, 0.015120},{
      0.995328, 1.674904, 0.015120},{0.994654, 1.672831, 0.012569}}],
    Polygon[{{0.991113, 1.677052, 0.015120},{0.992612, 1.679116, 0.017299},{
      0.996116, 1.677330, 0.017299},{0.995328, 1.674904, 0.015120}}],
    Polygon[{{0.992612, 1.679116, 0.017299},{0.994294, 1.681430, 0.019053},{
      0.997000, 1.680051, 0.019053},{0.996116, 1.677330, 0.017299}}],
    Polygon[{{0.994294, 1.681430, 0.019053},{0.996116, 1.683938, 0.020337},{
      0.997958, 1.683000, 0.020337},{0.997000, 1.680051, 0.019053}}],
    Polygon[{{0.996116, 1.683938, 0.020337},{0.998034, 1.686578, 0.021120},{
      0.998966, 1.686103, 0.021120},{0.997958, 1.683000, 0.020337}}],
    Polygon[{{0.998966, 1.686103, -0.021120},{0.997958, 1.683000, -0.020337},{
      1.000000, 1.682676, -0.020337},{1.000000, 1.685939, -0.021120}}],
    Polygon[{{0.997958, 1.683000, -0.020337},{0.997000, 1.680051, -0.019053},{
      1.000000, 1.679576, -0.019053},{1.000000, 1.682676, -0.020337}}],
    Polygon[{{0.997000, 1.680051, -0.019053},{0.996116, 1.677330, -0.017299},{
      1.000000, 1.676715, -0.017299},{1.000000, 1.679576, -0.019053}}],
    Polygon[{{0.996116, 1.677330, -0.017299},{0.995328, 1.674904, -0.015120},{
      1.000000, 1.674164, -0.015120},{1.000000, 1.676715, -0.017299}}],
    Polygon[{{0.995328, 1.674904, -0.015120},{0.994654, 1.672831, -0.012569},{
      1.000000, 1.671985, -0.012569},{1.000000, 1.674164, -0.015120}}],
    Polygon[{{0.994654, 1.672831, -0.012569},{0.994112, 1.671164, -0.009708},{
      1.000000, 1.670231, -0.009708},{1.000000, 1.671985, -0.012569}}],
    Polygon[{{0.994112, 1.671164, -0.009708},{0.993716, 1.669943, -0.006608},{
      1.000000, 1.668947, -0.006608},{1.000000, 1.670231, -0.009708}}],
    Polygon[{{0.993716, 1.669943, -0.006608},{0.993474, 1.669198, -0.003345},{
      1.000000, 1.668164, -0.003345},{1.000000, 1.668947, -0.006608}}],
    Polygon[{{0.993474, 1.669198, -0.003345},{0.993392, 1.668947, 0.000000},{
      1.000000, 1.667901, 0.000000},{1.000000, 1.668164, -0.003345}}],
    Polygon[{{0.993392, 1.668947, 0.000000},{0.993474, 1.669198, 0.003345},{
      1.000000, 1.668164, 0.003345},{1.000000, 1.667901, 0.000000}}],
    Polygon[{{0.993474, 1.669198, 0.003345},{0.993716, 1.669943, 0.006608},{
      1.000000, 1.668947, 0.006608},{1.000000, 1.668164, 0.003345}}],
    Polygon[{{0.993716, 1.669943, 0.006608},{0.994112, 1.671164, 0.009708},{
      1.000000, 1.670231, 0.009708},{1.000000, 1.668947, 0.006608}}],
    Polygon[{{0.994112, 1.671164, 0.009708},{0.994654, 1.672831, 0.012569},{
      1.000000, 1.671985, 0.012569},{1.000000, 1.670231, 0.009708}}],
    Polygon[{{0.994654, 1.672831, 0.012569},{0.995328, 1.674904, 0.015120},{
      1.000000, 1.674164, 0.015120},{1.000000, 1.671985, 0.012569}}],
    Polygon[{{0.995328, 1.674904, 0.015120},{0.996116, 1.677330, 0.017299},{
      1.000000, 1.676715, 0.017299},{1.000000, 1.674164, 0.015120}}],
    Polygon[{{0.996116, 1.677330, 0.017299},{0.997000, 1.680051, 0.019053},{
      1.000000, 1.679576, 0.019053},{1.000000, 1.676715, 0.017299}}],
    Polygon[{{0.997000, 1.680051, 0.019053},{0.997958, 1.683000, 0.020337},{
      1.000000, 1.682676, 0.020337},{1.000000, 1.679576, 0.019053}}],
    Polygon[{{0.997958, 1.683000, 0.020337},{0.998966, 1.686103, 0.021120},{
      1.000000, 1.685939, 0.021120},{1.000000, 1.682676, 0.020337}}],
    Polygon[{{1.000000, 1.685939, -0.021120},{1.000000, 1.682676, -0.020337},{
      1.002042, 1.683000, -0.020337},{1.001034, 1.686103, -0.021120}}],
    Polygon[{{1.000000, 1.682676, -0.020337},{1.000000, 1.679576, -0.019053},{
      1.003000, 1.680051, -0.019053},{1.002042, 1.683000, -0.020337}}],
    Polygon[{{1.000000, 1.679576, -0.019053},{1.000000, 1.676715, -0.017299},{
      1.003884, 1.677330, -0.017299},{1.003000, 1.680051, -0.019053}}],
    Polygon[{{1.000000, 1.676715, -0.017299},{1.000000, 1.674164, -0.015120},{
      1.004672, 1.674904, -0.015120},{1.003884, 1.677330, -0.017299}}],
    Polygon[{{1.000000, 1.674164, -0.015120},{1.000000, 1.671985, -0.012569},{
      1.005346, 1.672831, -0.012569},{1.004672, 1.674904, -0.015120}}],
    Polygon[{{1.000000, 1.671985, -0.012569},{1.000000, 1.670231, -0.009708},{
      1.005888, 1.671164, -0.009708},{1.005346, 1.672831, -0.012569}}],
    Polygon[{{1.000000, 1.670231, -0.009708},{1.000000, 1.668947, -0.006608},{
      1.006284, 1.669943, -0.006608},{1.005888, 1.671164, -0.009708}}],
    Polygon[{{1.000000, 1.668947, -0.006608},{1.000000, 1.668164, -0.003345},{
      1.006526, 1.669198, -0.003345},{1.006284, 1.669943, -0.006608}}],
    Polygon[{{1.000000, 1.668164, -0.003345},{1.000000, 1.667901, 0.000000},{
      1.006608, 1.668947, 0.000000},{1.006526, 1.669198, -0.003345}}],
    Polygon[{{1.000000, 1.667901, 0.000000},{1.000000, 1.668164, 0.003345},{
      1.006526, 1.669198, 0.003345},{1.006608, 1.668947, 0.000000}}],
    Polygon[{{1.000000, 1.668164, 0.003345},{1.000000, 1.668947, 0.006608},{
      1.006284, 1.669943, 0.006608},{1.006526, 1.669198, 0.003345}}],
    Polygon[{{1.000000, 1.668947, 0.006608},{1.000000, 1.670231, 0.009708},{
      1.005888, 1.671164, 0.009708},{1.006284, 1.669943, 0.006608}}],
    Polygon[{{1.000000, 1.670231, 0.009708},{1.000000, 1.671985, 0.012569},{
      1.005346, 1.672831, 0.012569},{1.005888, 1.671164, 0.009708}}],
    Polygon[{{1.000000, 1.671985, 0.012569},{1.000000, 1.674164, 0.015120},{
      1.004672, 1.674904, 0.015120},{1.005346, 1.672831, 0.012569}}],
    Polygon[{{1.000000, 1.674164, 0.015120},{1.000000, 1.676715, 0.017299},{
      1.003884, 1.677330, 0.017299},{1.004672, 1.674904, 0.015120}}],
    Polygon[{{1.000000, 1.676715, 0.017299},{1.000000, 1.679576, 0.019053},{
      1.003000, 1.680051, 0.019053},{1.003884, 1.677330, 0.017299}}],
    Polygon[{{1.000000, 1.679576, 0.019053},{1.000000, 1.682676, 0.020337},{
      1.002042, 1.683000, 0.020337},{1.003000, 1.680051, 0.019053}}],
    Polygon[{{1.000000, 1.682676, 0.020337},{1.000000, 1.685939, 0.021120},{
      1.001034, 1.686103, 0.021120},{1.002042, 1.683000, 0.020337}}],
    Polygon[{{1.001034, 1.686103, -0.021120},{1.002042, 1.683000, -0.020337},{
      1.003884, 1.683938, -0.020337},{1.001966, 1.686578, -0.021120}}],
    Polygon[{{1.002042, 1.683000, -0.020337},{1.003000, 1.680051, -0.019053},{
      1.005706, 1.681430, -0.019053},{1.003884, 1.683938, -0.020337}}],
    Polygon[{{1.003000, 1.680051, -0.019053},{1.003884, 1.677330, -0.017299},{
      1.007388, 1.679116, -0.017299},{1.005706, 1.681430, -0.019053}}],
    Polygon[{{1.003884, 1.677330, -0.017299},{1.004672, 1.674904, -0.015120},{
      1.008888, 1.677052, -0.015120},{1.007388, 1.679116, -0.017299}}],
    Polygon[{{1.004672, 1.674904, -0.015120},{1.005346, 1.672831, -0.012569},{
      1.010168, 1.675289, -0.012569},{1.008888, 1.677052, -0.015120}}],
    Polygon[{{1.005346, 1.672831, -0.012569},{1.005888, 1.671164, -0.009708},{
      1.011199, 1.673870, -0.009708},{1.010168, 1.675289, -0.012569}}],
    Polygon[{{1.005888, 1.671164, -0.009708},{1.006284, 1.669943, -0.006608},{
      1.011954, 1.672831, -0.006608},{1.011199, 1.673870, -0.009708}}],
    Polygon[{{1.006284, 1.669943, -0.006608},{1.006526, 1.669198, -0.003345},{
      1.012414, 1.672198, -0.003345},{1.011954, 1.672831, -0.006608}}],
    Polygon[{{1.006526, 1.669198, -0.003345},{1.006608, 1.668947, 0.000000},{
      1.012569, 1.671985, 0.000000},{1.012414, 1.672198, -0.003345}}],
    Polygon[{{1.006608, 1.668947, 0.000000},{1.006526, 1.669198, 0.003345},{
      1.012414, 1.672198, 0.003345},{1.012569, 1.671985, 0.000000}}],
    Polygon[{{1.006526, 1.669198, 0.003345},{1.006284, 1.669943, 0.006608},{
      1.011954, 1.672831, 0.006608},{1.012414, 1.672198, 0.003345}}],
    Polygon[{{1.006284, 1.669943, 0.006608},{1.005888, 1.671164, 0.009708},{
      1.011199, 1.673870, 0.009708},{1.011954, 1.672831, 0.006608}}],
    Polygon[{{1.005888, 1.671164, 0.009708},{1.005346, 1.672831, 0.012569},{
      1.010168, 1.675289, 0.012569},{1.011199, 1.673870, 0.009708}}],
    Polygon[{{1.005346, 1.672831, 0.012569},{1.004672, 1.674904, 0.015120},{
      1.008888, 1.677052, 0.015120},{1.010168, 1.675289, 0.012569}}],
    Polygon[{{1.004672, 1.674904, 0.015120},{1.003884, 1.677330, 0.017299},{
      1.007388, 1.679116, 0.017299},{1.008888, 1.677052, 0.015120}}],
    Polygon[{{1.003884, 1.677330, 0.017299},{1.003000, 1.680051, 0.019053},{
      1.005706, 1.681430, 0.019053},{1.007388, 1.679116, 0.017299}}],
    Polygon[{{1.003000, 1.680051, 0.019053},{1.002042, 1.683000, 0.020337},{
      1.003884, 1.683938, 0.020337},{1.005706, 1.681430, 0.019053}}],
    Polygon[{{1.002042, 1.683000, 0.020337},{1.001034, 1.686103, 0.021120},{
      1.001966, 1.686578, 0.021120},{1.003884, 1.683938, 0.020337}}],
    Polygon[{{1.001966, 1.686578, -0.021120},{1.003884, 1.683938, -0.020337},{
      1.005346, 1.685400, -0.020337},{1.002706, 1.687318, -0.021120}}],
    Polygon[{{1.003884, 1.683938, -0.020337},{1.005706, 1.681430, -0.019053},{
      1.007854, 1.683578, -0.019053},{1.005346, 1.685400, -0.020337}}],
    Polygon[{{1.005706, 1.681430, -0.019053},{1.007388, 1.679116, -0.017299},{
      1.010168, 1.681896, -0.017299},{1.007854, 1.683578, -0.019053}}],
    Polygon[{{1.007388, 1.679116, -0.017299},{1.008888, 1.677052, -0.015120},{
      1.012233, 1.680397, -0.015120},{1.010168, 1.681896, -0.017299}}],
    Polygon[{{1.008888, 1.677052, -0.015120},{1.010168, 1.675289, -0.012569},{
      1.013996, 1.679116, -0.012569},{1.012233, 1.680397, -0.015120}}],
    Polygon[{{1.010168, 1.675289, -0.012569},{1.011199, 1.673870, -0.009708},{
      1.015414, 1.678085, -0.009708},{1.013996, 1.679116, -0.012569}}],
    Polygon[{{1.011199, 1.673870, -0.009708},{1.011954, 1.672831, -0.006608},{
      1.016453, 1.677330, -0.006608},{1.015414, 1.678085, -0.009708}}],
    Polygon[{{1.011954, 1.672831, -0.006608},{1.012414, 1.672198, -0.003345},{
      1.017087, 1.676870, -0.003345},{1.016453, 1.677330, -0.006608}}],
    Polygon[{{1.012414, 1.672198, -0.003345},{1.012569, 1.671985, 0.000000},{
      1.017300, 1.676715, 0.000000},{1.017087, 1.676870, -0.003345}}],
    Polygon[{{1.012569, 1.671985, 0.000000},{1.012414, 1.672198, 0.003345},{
      1.017087, 1.676870, 0.003345},{1.017300, 1.676715, 0.000000}}],
    Polygon[{{1.012414, 1.672198, 0.003345},{1.011954, 1.672831, 0.006608},{
      1.016453, 1.677330, 0.006608},{1.017087, 1.676870, 0.003345}}],
    Polygon[{{1.011954, 1.672831, 0.006608},{1.011199, 1.673870, 0.009708},{
      1.015414, 1.678085, 0.009708},{1.016453, 1.677330, 0.006608}}],
    Polygon[{{1.011199, 1.673870, 0.009708},{1.010168, 1.675289, 0.012569},{
      1.013996, 1.679116, 0.012569},{1.015414, 1.678085, 0.009708}}],
    Polygon[{{1.010168, 1.675289, 0.012569},{1.008888, 1.677052, 0.015120},{
      1.012233, 1.680397, 0.015120},{1.013996, 1.679116, 0.012569}}],
    Polygon[{{1.008888, 1.677052, 0.015120},{1.007388, 1.679116, 0.017299},{
      1.010168, 1.681896, 0.017299},{1.012233, 1.680397, 0.015120}}],
    Polygon[{{1.007388, 1.679116, 0.017299},{1.005706, 1.681430, 0.019053},{
      1.007854, 1.683578, 0.019053},{1.010168, 1.681896, 0.017299}}],
    Polygon[{{1.005706, 1.681430, 0.019053},{1.003884, 1.683938, 0.020337},{
      1.005346, 1.685400, 0.020337},{1.007854, 1.683578, 0.019053}}],
    Polygon[{{1.003884, 1.683938, 0.020337},{1.001966, 1.686578, 0.021120},{
      1.002706, 1.687318, 0.021120},{1.005346, 1.685400, 0.020337}}],
    Polygon[{{1.002706, 1.687318, -0.021120},{1.005346, 1.685400, -0.020337},{
      1.006284, 1.687242, -0.020337},{1.003181, 1.688250, -0.021120}}],
    Polygon[{{1.005346, 1.685400, -0.020337},{1.007854, 1.683578, -0.019053},{
      1.009233, 1.686284, -0.019053},{1.006284, 1.687242, -0.020337}}],
    Polygon[{{1.007854, 1.683578, -0.019053},{1.010168, 1.681896, -0.017299},{
      1.011954, 1.685400, -0.017299},{1.009233, 1.686284, -0.019053}}],
    Polygon[{{1.010168, 1.681896, -0.017299},{1.012233, 1.680397, -0.015120},{
      1.014380, 1.684612, -0.015120},{1.011954, 1.685400, -0.017299}}],
    Polygon[{{1.012233, 1.680397, -0.015120},{1.013996, 1.679116, -0.012569},{
      1.016453, 1.683938, -0.012569},{1.014380, 1.684612, -0.015120}}],
    Polygon[{{1.013996, 1.679116, -0.012569},{1.015414, 1.678085, -0.009708},{
      1.018120, 1.683396, -0.009708},{1.016453, 1.683938, -0.012569}}],
    Polygon[{{1.015414, 1.678085, -0.009708},{1.016453, 1.677330, -0.006608},{
      1.019341, 1.683000, -0.006608},{1.018120, 1.683396, -0.009708}}],
    Polygon[{{1.016453, 1.677330, -0.006608},{1.017087, 1.676870, -0.003345},{
      1.020086, 1.682758, -0.003345},{1.019341, 1.683000, -0.006608}}],
    Polygon[{{1.017087, 1.676870, -0.003345},{1.017300, 1.676715, 0.000000},{
      1.020337, 1.682676, 0.000000},{1.020086, 1.682758, -0.003345}}],
    Polygon[{{1.017300, 1.676715, 0.000000},{1.017087, 1.676870, 0.003345},{
      1.020086, 1.682758, 0.003345},{1.020337, 1.682676, 0.000000}}],
    Polygon[{{1.017087, 1.676870, 0.003345},{1.016453, 1.677330, 0.006608},{
      1.019341, 1.683000, 0.006608},{1.020086, 1.682758, 0.003345}}],
    Polygon[{{1.016453, 1.677330, 0.006608},{1.015414, 1.678085, 0.009708},{
      1.018120, 1.683396, 0.009708},{1.019341, 1.683000, 0.006608}}],
    Polygon[{{1.015414, 1.678085, 0.009708},{1.013996, 1.679116, 0.012569},{
      1.016453, 1.683938, 0.012569},{1.018120, 1.683396, 0.009708}}],
    Polygon[{{1.013996, 1.679116, 0.012569},{1.012233, 1.680397, 0.015120},{
      1.014380, 1.684612, 0.015120},{1.016453, 1.683938, 0.012569}}],
    Polygon[{{1.012233, 1.680397, 0.015120},{1.010168, 1.681896, 0.017299},{
      1.011954, 1.685400, 0.017299},{1.014380, 1.684612, 0.015120}}],
    Polygon[{{1.010168, 1.681896, 0.017299},{1.007854, 1.683578, 0.019053},{
      1.009233, 1.686284, 0.019053},{1.011954, 1.685400, 0.017299}}],
    Polygon[{{1.007854, 1.683578, 0.019053},{1.005346, 1.685400, 0.020337},{
      1.006284, 1.687242, 0.020337},{1.009233, 1.686284, 0.019053}}],
    Polygon[{{1.005346, 1.685400, 0.020337},{1.002706, 1.687318, 0.021120},{
      1.003181, 1.688250, 0.021120},{1.006284, 1.687242, 0.020337}}],
    Polygon[{{1.003181, 1.688250, -0.021120},{1.006284, 1.687242, -0.020337},{
      1.006608, 1.689284, -0.020337},{1.003345, 1.689284, -0.021120}}],
    Polygon[{{1.006284, 1.687242, -0.020337},{1.009233, 1.686284, -0.019053},{
      1.009708, 1.689284, -0.019053},{1.006608, 1.689284, -0.020337}}],
    Polygon[{{1.009233, 1.686284, -0.019053},{1.011954, 1.685400, -0.017299},{
      1.012569, 1.689284, -0.017299},{1.009708, 1.689284, -0.019053}}],
    Polygon[{{1.011954, 1.685400, -0.017299},{1.014380, 1.684612, -0.015120},{
      1.015120, 1.689284, -0.015120},{1.012569, 1.689284, -0.017299}}],
    Polygon[{{1.014380, 1.684612, -0.015120},{1.016453, 1.683938, -0.012569},{
      1.017300, 1.689284, -0.012569},{1.015120, 1.689284, -0.015120}}],
    Polygon[{{1.016453, 1.683938, -0.012569},{1.018120, 1.683396, -0.009708},{
      1.019053, 1.689284, -0.009708},{1.017300, 1.689284, -0.012569}}],
    Polygon[{{1.018120, 1.683396, -0.009708},{1.019341, 1.683000, -0.006608},{
      1.020337, 1.689284, -0.006608},{1.019053, 1.689284, -0.009708}}],
    Polygon[{{1.019341, 1.683000, -0.006608},{1.020086, 1.682758, -0.003345},{
      1.021120, 1.689284, -0.003345},{1.020337, 1.689284, -0.006608}}],
    Polygon[{{1.020086, 1.682758, -0.003345},{1.020337, 1.682676, 0.000000},{
      1.021383, 1.689284, 0.000000},{1.021120, 1.689284, -0.003345}}],
    Polygon[{{1.020337, 1.682676, 0.000000},{1.020086, 1.682758, 0.003345},{
      1.021120, 1.689284, 0.003345},{1.021383, 1.689284, 0.000000}}],
    Polygon[{{1.020086, 1.682758, 0.003345},{1.019341, 1.683000, 0.006608},{
      1.020337, 1.689284, 0.006608},{1.021120, 1.689284, 0.003345}}],
    Polygon[{{1.019341, 1.683000, 0.006608},{1.018120, 1.683396, 0.009708},{
      1.019053, 1.689284, 0.009708},{1.020337, 1.689284, 0.006608}}],
    Polygon[{{1.018120, 1.683396, 0.009708},{1.016453, 1.683938, 0.012569},{
      1.017300, 1.689284, 0.012569},{1.019053, 1.689284, 0.009708}}],
    Polygon[{{1.016453, 1.683938, 0.012569},{1.014380, 1.684612, 0.015120},{
      1.015120, 1.689284, 0.015120},{1.017300, 1.689284, 0.012569}}],
    Polygon[{{1.014380, 1.684612, 0.015120},{1.011954, 1.685400, 0.017299},{
      1.012569, 1.689284, 0.017299},{1.015120, 1.689284, 0.015120}}],
    Polygon[{{1.011954, 1.685400, 0.017299},{1.009233, 1.686284, 0.019053},{
      1.009708, 1.689284, 0.019053},{1.012569, 1.689284, 0.017299}}],
    Polygon[{{1.009233, 1.686284, 0.019053},{1.006284, 1.687242, 0.020337},{
      1.006608, 1.689284, 0.020337},{1.009708, 1.689284, 0.019053}}],
    Polygon[{{1.006284, 1.687242, 0.020337},{1.003181, 1.688250, 0.021120},{
      1.003345, 1.689284, 0.021120},{1.006608, 1.689284, 0.020337}}],
    Polygon[{{1.001115, 1.717795, -0.007040},{1.002203, 1.717795, -0.006779},{
      1.002095, 1.718476, -0.006779},{1.001060, 1.718140, -0.007040}}],
    Polygon[{{1.002203, 1.717795, -0.006779},{1.003236, 1.717795, -0.006351},{
      1.003078, 1.718795, -0.006351},{1.002095, 1.718476, -0.006779}}],
    Polygon[{{1.003236, 1.717795, -0.006351},{1.004190, 1.717795, -0.005766},{
      1.003985, 1.719090, -0.005766},{1.003078, 1.718795, -0.006351}}],
    Polygon[{{1.004190, 1.717795, -0.005766},{1.005040, 1.717795, -0.005040},{
      1.004793, 1.719353, -0.005040},{1.003985, 1.719090, -0.005766}}],
    Polygon[{{1.005040, 1.717795, -0.005040},{1.005767, 1.717795, -0.004190},{
      1.005484, 1.719577, -0.004190},{1.004793, 1.719353, -0.005040}}],
    Polygon[{{1.005767, 1.717795, -0.004190},{1.006351, 1.717795, -0.003236},{
      1.006040, 1.719758, -0.003236},{1.005484, 1.719577, -0.004190}}],
    Polygon[{{1.006351, 1.717795, -0.003236},{1.006779, 1.717795, -0.002203},{
      1.006447, 1.719890, -0.002203},{1.006040, 1.719758, -0.003236}}],
    Polygon[{{1.006779, 1.717795, -0.002203},{1.007040, 1.717795, -0.001115},{
      1.006696, 1.719971, -0.001115},{1.006447, 1.719890, -0.002203}}],
    Polygon[{{1.007040, 1.717795, -0.001115},{1.007128, 1.717795, 0.000000},{
      1.006779, 1.719998, 0.000000},{1.006696, 1.719971, -0.001115}}],
    Polygon[{{1.007128, 1.717795, 0.000000},{1.007040, 1.717795, 0.001115},{
      1.006696, 1.719971, 0.001115},{1.006779, 1.719998, 0.000000}}],
    Polygon[{{1.007040, 1.717795, 0.001115},{1.006779, 1.717795, 0.002203},{
      1.006447, 1.719890, 0.002203},{1.006696, 1.719971, 0.001115}}],
    Polygon[{{1.006779, 1.717795, 0.002203},{1.006351, 1.717795, 0.003236},{
      1.006040, 1.719758, 0.003236},{1.006447, 1.719890, 0.002203}}],
    Polygon[{{1.006351, 1.717795, 0.003236},{1.005767, 1.717795, 0.004190},{
      1.005484, 1.719577, 0.004190},{1.006040, 1.719758, 0.003236}}],
    Polygon[{{1.005767, 1.717795, 0.004190},{1.005040, 1.717795, 0.005040},{
      1.004793, 1.719353, 0.005040},{1.005484, 1.719577, 0.004190}}],
    Polygon[{{1.005040, 1.717795, 0.005040},{1.004190, 1.717795, 0.005766},{
      1.003985, 1.719090, 0.005766},{1.004793, 1.719353, 0.005040}}],
    Polygon[{{1.004190, 1.717795, 0.005766},{1.003236, 1.717795, 0.006351},{
      1.003078, 1.718795, 0.006351},{1.003985, 1.719090, 0.005766}}],
    Polygon[{{1.003236, 1.717795, 0.006351},{1.002203, 1.717795, 0.006779},{
      1.002095, 1.718476, 0.006779},{1.003078, 1.718795, 0.006351}}],
    Polygon[{{1.002203, 1.717795, 0.006779},{1.001115, 1.717795, 0.007040},{
      1.001060, 1.718140, 0.007040},{1.002095, 1.718476, 0.006779}}],
    Polygon[{{1.001060, 1.718140, -0.007040},{1.002095, 1.718476, -0.006779},{
      1.001782, 1.719090, -0.006779},{1.000902, 1.718451, -0.007040}}],
    Polygon[{{1.002095, 1.718476, -0.006779},{1.003078, 1.718795, -0.006351},{
      1.002618, 1.719697, -0.006351},{1.001782, 1.719090, -0.006779}}],
    Polygon[{{1.003078, 1.718795, -0.006351},{1.003985, 1.719090, -0.005766},{
      1.003389, 1.720258, -0.005766},{1.002618, 1.719697, -0.006351}}],
    Polygon[{{1.003985, 1.719090, -0.005766},{1.004793, 1.719353, -0.005040},{
      1.004078, 1.720758, -0.005040},{1.003389, 1.720258, -0.005766}}],
    Polygon[{{1.004793, 1.719353, -0.005040},{1.005484, 1.719577, -0.004190},{
      1.004665, 1.721185, -0.004190},{1.004078, 1.720758, -0.005040}}],
    Polygon[{{1.005484, 1.719577, -0.004190},{1.006040, 1.719758, -0.003236},{
      1.005138, 1.721528, -0.003236},{1.004665, 1.721185, -0.004190}}],
    Polygon[{{1.006040, 1.719758, -0.003236},{1.006447, 1.719890, -0.002203},{
      1.005484, 1.721780, -0.002203},{1.005138, 1.721528, -0.003236}}],
    Polygon[{{1.006447, 1.719890, -0.002203},{1.006696, 1.719971, -0.001115},{
      1.005695, 1.721933, -0.001115},{1.005484, 1.721780, -0.002203}}],
    Polygon[{{1.006696, 1.719971, -0.001115},{1.006779, 1.719998, 0.000000},{
      1.005767, 1.721985, 0.000000},{1.005695, 1.721933, -0.001115}}],
    Polygon[{{1.006779, 1.719998, 0.000000},{1.006696, 1.719971, 0.001115},{
      1.005695, 1.721933, 0.001115},{1.005767, 1.721985, 0.000000}}],
    Polygon[{{1.006696, 1.719971, 0.001115},{1.006447, 1.719890, 0.002203},{
      1.005484, 1.721780, 0.002203},{1.005695, 1.721933, 0.001115}}],
    Polygon[{{1.006447, 1.719890, 0.002203},{1.006040, 1.719758, 0.003236},{
      1.005138, 1.721528, 0.003236},{1.005484, 1.721780, 0.002203}}],
    Polygon[{{1.006040, 1.719758, 0.003236},{1.005484, 1.719577, 0.004190},{
      1.004665, 1.721185, 0.004190},{1.005138, 1.721528, 0.003236}}],
    Polygon[{{1.005484, 1.719577, 0.004190},{1.004793, 1.719353, 0.005040},{
      1.004078, 1.720758, 0.005040},{1.004665, 1.721185, 0.004190}}],
    Polygon[{{1.004793, 1.719353, 0.005040},{1.003985, 1.719090, 0.005766},{
      1.003389, 1.720258, 0.005766},{1.004078, 1.720758, 0.005040}}],
    Polygon[{{1.003985, 1.719090, 0.005766},{1.003078, 1.718795, 0.006351},{
      1.002618, 1.719697, 0.006351},{1.003389, 1.720258, 0.005766}}],
    Polygon[{{1.003078, 1.718795, 0.006351},{1.002095, 1.718476, 0.006779},{
      1.001782, 1.719090, 0.006779},{1.002618, 1.719697, 0.006351}}],
    Polygon[{{1.002095, 1.718476, 0.006779},{1.001060, 1.718140, 0.007040},{
      1.000902, 1.718451, 0.007040},{1.001782, 1.719090, 0.006779}}],
    Polygon[{{1.000902, 1.718451, -0.007040},{1.001782, 1.719090, -0.006779},{
      1.001295, 1.719577, -0.006779},{1.000655, 1.718697, -0.007040}}],
    Polygon[{{1.001782, 1.719090, -0.006779},{1.002618, 1.719697, -0.006351},{
      1.001902, 1.720413, -0.006351},{1.001295, 1.719577, -0.006779}}],
    Polygon[{{1.002618, 1.719697, -0.006351},{1.003389, 1.720258, -0.005766},{
      1.002463, 1.721185, -0.005766},{1.001902, 1.720413, -0.006351}}],
    Polygon[{{1.003389, 1.720258, -0.005766},{1.004078, 1.720758, -0.005040},{
      1.002962, 1.721873, -0.005040},{1.002463, 1.721185, -0.005766}}],
    Polygon[{{1.004078, 1.720758, -0.005040},{1.004665, 1.721185, -0.004190},{
      1.003389, 1.722460, -0.004190},{1.002962, 1.721873, -0.005040}}],
    Polygon[{{1.004665, 1.721185, -0.004190},{1.005138, 1.721528, -0.003236},{
      1.003733, 1.722933, -0.003236},{1.003389, 1.722460, -0.004190}}],
    Polygon[{{1.005138, 1.721528, -0.003236},{1.005484, 1.721780, -0.002203},{
      1.003985, 1.723279, -0.002203},{1.003733, 1.722933, -0.003236}}],
    Polygon[{{1.005484, 1.721780, -0.002203},{1.005695, 1.721933, -0.001115},{
      1.004138, 1.723491, -0.001115},{1.003985, 1.723279, -0.002203}}],
    Polygon[{{1.005695, 1.721933, -0.001115},{1.005767, 1.721985, 0.000000},{
      1.004190, 1.723562, 0.000000},{1.004138, 1.723491, -0.001115}}],
    Polygon[{{1.005767, 1.721985, 0.000000},{1.005695, 1.721933, 0.001115},{
      1.004138, 1.723491, 0.001115},{1.004190, 1.723562, 0.000000}}],
    Polygon[{{1.005695, 1.721933, 0.001115},{1.005484, 1.721780, 0.002203},{
      1.003985, 1.723279, 0.002203},{1.004138, 1.723491, 0.001115}}],
    Polygon[{{1.005484, 1.721780, 0.002203},{1.005138, 1.721528, 0.003236},{
      1.003733, 1.722933, 0.003236},{1.003985, 1.723279, 0.002203}}],
    Polygon[{{1.005138, 1.721528, 0.003236},{1.004665, 1.721185, 0.004190},{
      1.003389, 1.722460, 0.004190},{1.003733, 1.722933, 0.003236}}],
    Polygon[{{1.004665, 1.721185, 0.004190},{1.004078, 1.720758, 0.005040},{
      1.002962, 1.721873, 0.005040},{1.003389, 1.722460, 0.004190}}],
    Polygon[{{1.004078, 1.720758, 0.005040},{1.003389, 1.720258, 0.005766},{
      1.002463, 1.721185, 0.005766},{1.002962, 1.721873, 0.005040}}],
    Polygon[{{1.003389, 1.720258, 0.005766},{1.002618, 1.719697, 0.006351},{
      1.001902, 1.720413, 0.006351},{1.002463, 1.721185, 0.005766}}],
    Polygon[{{1.002618, 1.719697, 0.006351},{1.001782, 1.719090, 0.006779},{
      1.001295, 1.719577, 0.006779},{1.001902, 1.720413, 0.006351}}],
    Polygon[{{1.001782, 1.719090, 0.006779},{1.000902, 1.718451, 0.007040},{
      1.000655, 1.718697, 0.007040},{1.001295, 1.719577, 0.006779}}],
    Polygon[{{1.000655, 1.718697, -0.007040},{1.001295, 1.719577, -0.006779},{
      1.000681, 1.719890, -0.006779},{1.000345, 1.718856, -0.007040}}],
    Polygon[{{1.001295, 1.719577, -0.006779},{1.001902, 1.720413, -0.006351},{
      1.001000, 1.720873, -0.006351},{1.000681, 1.719890, -0.006779}}],
    Polygon[{{1.001902, 1.720413, -0.006351},{1.002463, 1.721185, -0.005766},{
      1.001295, 1.721780, -0.005766},{1.001000, 1.720873, -0.006351}}],
    Polygon[{{1.002463, 1.721185, -0.005766},{1.002962, 1.721873, -0.005040},{
      1.001557, 1.722589, -0.005040},{1.001295, 1.721780, -0.005766}}],
    Polygon[{{1.002962, 1.721873, -0.005040},{1.003389, 1.722460, -0.004190},{
      1.001782, 1.723279, -0.004190},{1.001557, 1.722589, -0.005040}}],
    Polygon[{{1.003389, 1.722460, -0.004190},{1.003733, 1.722933, -0.003236},{
      1.001963, 1.723835, -0.003236},{1.001782, 1.723279, -0.004190}}],
    Polygon[{{1.003733, 1.722933, -0.003236},{1.003985, 1.723279, -0.002203},{
      1.002095, 1.724242, -0.002203},{1.001963, 1.723835, -0.003236}}],
    Polygon[{{1.003985, 1.723279, -0.002203},{1.004138, 1.723491, -0.001115},{
      1.002175, 1.724491, -0.001115},{1.002095, 1.724242, -0.002203}}],
    Polygon[{{1.004138, 1.723491, -0.001115},{1.004190, 1.723562, 0.000000},{
      1.002203, 1.724574, 0.000000},{1.002175, 1.724491, -0.001115}}],
    Polygon[{{1.004190, 1.723562, 0.000000},{1.004138, 1.723491, 0.001115},{
      1.002175, 1.724491, 0.001115},{1.002203, 1.724574, 0.000000}}],
    Polygon[{{1.004138, 1.723491, 0.001115},{1.003985, 1.723279, 0.002203},{
      1.002095, 1.724242, 0.002203},{1.002175, 1.724491, 0.001115}}],
    Polygon[{{1.003985, 1.723279, 0.002203},{1.003733, 1.722933, 0.003236},{
      1.001963, 1.723835, 0.003236},{1.002095, 1.724242, 0.002203}}],
    Polygon[{{1.003733, 1.722933, 0.003236},{1.003389, 1.722460, 0.004190},{
      1.001782, 1.723279, 0.004190},{1.001963, 1.723835, 0.003236}}],
    Polygon[{{1.003389, 1.722460, 0.004190},{1.002962, 1.721873, 0.005040},{
      1.001557, 1.722589, 0.005040},{1.001782, 1.723279, 0.004190}}],
    Polygon[{{1.002962, 1.721873, 0.005040},{1.002463, 1.721185, 0.005766},{
      1.001295, 1.721780, 0.005766},{1.001557, 1.722589, 0.005040}}],
    Polygon[{{1.002463, 1.721185, 0.005766},{1.001902, 1.720413, 0.006351},{
      1.001000, 1.720873, 0.006351},{1.001295, 1.721780, 0.005766}}],
    Polygon[{{1.001902, 1.720413, 0.006351},{1.001295, 1.719577, 0.006779},{
      1.000681, 1.719890, 0.006779},{1.001000, 1.720873, 0.006351}}],
    Polygon[{{1.001295, 1.719577, 0.006779},{1.000655, 1.718697, 0.007040},{
      1.000345, 1.718856, 0.007040},{1.000681, 1.719890, 0.006779}}],
    Polygon[{{1.000345, 1.718856, -0.007040},{1.000681, 1.719890, -0.006779},{
      1.000000, 1.719998, -0.006779},{1.000000, 1.718910, -0.007040}}],
    Polygon[{{1.000681, 1.719890, -0.006779},{1.001000, 1.720873, -0.006351},{
      1.000000, 1.721031, -0.006351},{1.000000, 1.719998, -0.006779}}],
    Polygon[{{1.001000, 1.720873, -0.006351},{1.001295, 1.721780, -0.005766},{
      1.000000, 1.721985, -0.005766},{1.000000, 1.721031, -0.006351}}],
    Polygon[{{1.001295, 1.721780, -0.005766},{1.001557, 1.722589, -0.005040},{
      1.000000, 1.722835, -0.005040},{1.000000, 1.721985, -0.005766}}],
    Polygon[{{1.001557, 1.722589, -0.005040},{1.001782, 1.723279, -0.004190},{
      1.000000, 1.723562, -0.004190},{1.000000, 1.722835, -0.005040}}],
    Polygon[{{1.001782, 1.723279, -0.004190},{1.001963, 1.723835, -0.003236},{
      1.000000, 1.724146, -0.003236},{1.000000, 1.723562, -0.004190}}],
    Polygon[{{1.001963, 1.723835, -0.003236},{1.002095, 1.724242, -0.002203},{
      1.000000, 1.724574, -0.002203},{1.000000, 1.724146, -0.003236}}],
    Polygon[{{1.002095, 1.724242, -0.002203},{1.002175, 1.724491, -0.001115},{
      1.000000, 1.724835, -0.001115},{1.000000, 1.724574, -0.002203}}],
    Polygon[{{1.002175, 1.724491, -0.001115},{1.002203, 1.724574, 0.000000},{
      1.000000, 1.724923, 0.000000},{1.000000, 1.724835, -0.001115}}],
    Polygon[{{1.002203, 1.724574, 0.000000},{1.002175, 1.724491, 0.001115},{
      1.000000, 1.724835, 0.001115},{1.000000, 1.724923, 0.000000}}],
    Polygon[{{1.002175, 1.724491, 0.001115},{1.002095, 1.724242, 0.002203},{
      1.000000, 1.724574, 0.002203},{1.000000, 1.724835, 0.001115}}],
    Polygon[{{1.002095, 1.724242, 0.002203},{1.001963, 1.723835, 0.003236},{
      1.000000, 1.724146, 0.003236},{1.000000, 1.724574, 0.002203}}],
    Polygon[{{1.001963, 1.723835, 0.003236},{1.001782, 1.723279, 0.004190},{
      1.000000, 1.723562, 0.004190},{1.000000, 1.724146, 0.003236}}],
    Polygon[{{1.001782, 1.723279, 0.004190},{1.001557, 1.722589, 0.005040},{
      1.000000, 1.722835, 0.005040},{1.000000, 1.723562, 0.004190}}],
    Polygon[{{1.001557, 1.722589, 0.005040},{1.001295, 1.721780, 0.005766},{
      1.000000, 1.721985, 0.005766},{1.000000, 1.722835, 0.005040}}],
    Polygon[{{1.001295, 1.721780, 0.005766},{1.001000, 1.720873, 0.006351},{
      1.000000, 1.721031, 0.006351},{1.000000, 1.721985, 0.005766}}],
    Polygon[{{1.001000, 1.720873, 0.006351},{1.000681, 1.719890, 0.006779},{
      1.000000, 1.719998, 0.006779},{1.000000, 1.721031, 0.006351}}],
    Polygon[{{1.000681, 1.719890, 0.006779},{1.000345, 1.718856, 0.007040},{
      1.000000, 1.718910, 0.007040},{1.000000, 1.719998, 0.006779}}],
    Polygon[{{1.000000, 1.718910, -0.007040},{1.000000, 1.719998, -0.006779},{
      0.999319, 1.719890, -0.006779},{0.999655, 1.718856, -0.007040}}],
    Polygon[{{1.000000, 1.719998, -0.006779},{1.000000, 1.721031, -0.006351},{
      0.999000, 1.720873, -0.006351},{0.999319, 1.719890, -0.006779}}],
    Polygon[{{1.000000, 1.721031, -0.006351},{1.000000, 1.721985, -0.005766},{
      0.998705, 1.721780, -0.005766},{0.999000, 1.720873, -0.006351}}],
    Polygon[{{1.000000, 1.721985, -0.005766},{1.000000, 1.722835, -0.005040},{
      0.998443, 1.722589, -0.005040},{0.998705, 1.721780, -0.005766}}],
    Polygon[{{1.000000, 1.722835, -0.005040},{1.000000, 1.723562, -0.004190},{
      0.998218, 1.723279, -0.004190},{0.998443, 1.722589, -0.005040}}],
    Polygon[{{1.000000, 1.723562, -0.004190},{1.000000, 1.724146, -0.003236},{
      0.998037, 1.723835, -0.003236},{0.998218, 1.723279, -0.004190}}],
    Polygon[{{1.000000, 1.724146, -0.003236},{1.000000, 1.724574, -0.002203},{
      0.997905, 1.724242, -0.002203},{0.998037, 1.723835, -0.003236}}],
    Polygon[{{1.000000, 1.724574, -0.002203},{1.000000, 1.724835, -0.001115},{
      0.997824, 1.724491, -0.001115},{0.997905, 1.724242, -0.002203}}],
    Polygon[{{1.000000, 1.724835, -0.001115},{1.000000, 1.724923, 0.000000},{
      0.997797, 1.724574, 0.000000},{0.997824, 1.724491, -0.001115}}],
    Polygon[{{1.000000, 1.724923, 0.000000},{1.000000, 1.724835, 0.001115},{
      0.997824, 1.724491, 0.001115},{0.997797, 1.724574, 0.000000}}],
    Polygon[{{1.000000, 1.724835, 0.001115},{1.000000, 1.724574, 0.002203},{
      0.997905, 1.724242, 0.002203},{0.997824, 1.724491, 0.001115}}],
    Polygon[{{1.000000, 1.724574, 0.002203},{1.000000, 1.724146, 0.003236},{
      0.998037, 1.723835, 0.003236},{0.997905, 1.724242, 0.002203}}],
    Polygon[{{1.000000, 1.724146, 0.003236},{1.000000, 1.723562, 0.004190},{
      0.998218, 1.723279, 0.004190},{0.998037, 1.723835, 0.003236}}],
    Polygon[{{1.000000, 1.723562, 0.004190},{1.000000, 1.722835, 0.005040},{
      0.998443, 1.722589, 0.005040},{0.998218, 1.723279, 0.004190}}],
    Polygon[{{1.000000, 1.722835, 0.005040},{1.000000, 1.721985, 0.005766},{
      0.998705, 1.721780, 0.005766},{0.998443, 1.722589, 0.005040}}],
    Polygon[{{1.000000, 1.721985, 0.005766},{1.000000, 1.721031, 0.006351},{
      0.999000, 1.720873, 0.006351},{0.998705, 1.721780, 0.005766}}],
    Polygon[{{1.000000, 1.721031, 0.006351},{1.000000, 1.719998, 0.006779},{
      0.999319, 1.719890, 0.006779},{0.999000, 1.720873, 0.006351}}],
    Polygon[{{1.000000, 1.719998, 0.006779},{1.000000, 1.718910, 0.007040},{
      0.999655, 1.718856, 0.007040},{0.999319, 1.719890, 0.006779}}],
    Polygon[{{0.999655, 1.718856, -0.007040},{0.999319, 1.719890, -0.006779},{
      0.998705, 1.719577, -0.006779},{0.999345, 1.718697, -0.007040}}],
    Polygon[{{0.999319, 1.719890, -0.006779},{0.999000, 1.720873, -0.006351},{
      0.998098, 1.720413, -0.006351},{0.998705, 1.719577, -0.006779}}],
    Polygon[{{0.999000, 1.720873, -0.006351},{0.998705, 1.721780, -0.005766},{
      0.997537, 1.721185, -0.005766},{0.998098, 1.720413, -0.006351}}],
    Polygon[{{0.998705, 1.721780, -0.005766},{0.998443, 1.722589, -0.005040},{
      0.997038, 1.721873, -0.005040},{0.997537, 1.721185, -0.005766}}],
    Polygon[{{0.998443, 1.722589, -0.005040},{0.998218, 1.723279, -0.004190},{
      0.996611, 1.722460, -0.004190},{0.997038, 1.721873, -0.005040}}],
    Polygon[{{0.998218, 1.723279, -0.004190},{0.998037, 1.723835, -0.003236},{
      0.996267, 1.722933, -0.003236},{0.996611, 1.722460, -0.004190}}],
    Polygon[{{0.998037, 1.723835, -0.003236},{0.997905, 1.724242, -0.002203},{
      0.996015, 1.723279, -0.002203},{0.996267, 1.722933, -0.003236}}],
    Polygon[{{0.997905, 1.724242, -0.002203},{0.997824, 1.724491, -0.001115},{
      0.995862, 1.723491, -0.001115},{0.996015, 1.723279, -0.002203}}],
    Polygon[{{0.997824, 1.724491, -0.001115},{0.997797, 1.724574, 0.000000},{
      0.995810, 1.723562, 0.000000},{0.995862, 1.723491, -0.001115}}],
    Polygon[{{0.997797, 1.724574, 0.000000},{0.997824, 1.724491, 0.001115},{
      0.995862, 1.723491, 0.001115},{0.995810, 1.723562, 0.000000}}],
    Polygon[{{0.997824, 1.724491, 0.001115},{0.997905, 1.724242, 0.002203},{
      0.996015, 1.723279, 0.002203},{0.995862, 1.723491, 0.001115}}],
    Polygon[{{0.997905, 1.724242, 0.002203},{0.998037, 1.723835, 0.003236},{
      0.996267, 1.722933, 0.003236},{0.996015, 1.723279, 0.002203}}],
    Polygon[{{0.998037, 1.723835, 0.003236},{0.998218, 1.723279, 0.004190},{
      0.996611, 1.722460, 0.004190},{0.996267, 1.722933, 0.003236}}],
    Polygon[{{0.998218, 1.723279, 0.004190},{0.998443, 1.722589, 0.005040},{
      0.997038, 1.721873, 0.005040},{0.996611, 1.722460, 0.004190}}],
    Polygon[{{0.998443, 1.722589, 0.005040},{0.998705, 1.721780, 0.005766},{
      0.997537, 1.721185, 0.005766},{0.997038, 1.721873, 0.005040}}],
    Polygon[{{0.998705, 1.721780, 0.005766},{0.999000, 1.720873, 0.006351},{
      0.998098, 1.720413, 0.006351},{0.997537, 1.721185, 0.005766}}],
    Polygon[{{0.999000, 1.720873, 0.006351},{0.999319, 1.719890, 0.006779},{
      0.998705, 1.719577, 0.006779},{0.998098, 1.720413, 0.006351}}],
    Polygon[{{0.999319, 1.719890, 0.006779},{0.999655, 1.718856, 0.007040},{
      0.999345, 1.718697, 0.007040},{0.998705, 1.719577, 0.006779}}],
    Polygon[{{0.999345, 1.718697, -0.007040},{0.998705, 1.719577, -0.006779},{
      0.998218, 1.719090, -0.006779},{0.999098, 1.718451, -0.007040}}],
    Polygon[{{0.998705, 1.719577, -0.006779},{0.998098, 1.720413, -0.006351},{
      0.997382, 1.719697, -0.006351},{0.998218, 1.719090, -0.006779}}],
    Polygon[{{0.998098, 1.720413, -0.006351},{0.997537, 1.721185, -0.005766},{
      0.996611, 1.720258, -0.005766},{0.997382, 1.719697, -0.006351}}],
    Polygon[{{0.997537, 1.721185, -0.005766},{0.997038, 1.721873, -0.005040},{
      0.995922, 1.720758, -0.005040},{0.996611, 1.720258, -0.005766}}],
    Polygon[{{0.997038, 1.721873, -0.005040},{0.996611, 1.722460, -0.004190},{
      0.995335, 1.721185, -0.004190},{0.995922, 1.720758, -0.005040}}],
    Polygon[{{0.996611, 1.722460, -0.004190},{0.996267, 1.722933, -0.003236},{
      0.994862, 1.721528, -0.003236},{0.995335, 1.721185, -0.004190}}],
    Polygon[{{0.996267, 1.722933, -0.003236},{0.996015, 1.723279, -0.002203},{
      0.994516, 1.721780, -0.002203},{0.994862, 1.721528, -0.003236}}],
    Polygon[{{0.996015, 1.723279, -0.002203},{0.995862, 1.723491, -0.001115},{
      0.994304, 1.721933, -0.001115},{0.994516, 1.721780, -0.002203}}],
    Polygon[{{0.995862, 1.723491, -0.001115},{0.995810, 1.723562, 0.000000},{
      0.994233, 1.721985, 0.000000},{0.994304, 1.721933, -0.001115}}],
    Polygon[{{0.995810, 1.723562, 0.000000},{0.995862, 1.723491, 0.001115},{
      0.994304, 1.721933, 0.001115},{0.994233, 1.721985, 0.000000}}],
    Polygon[{{0.995862, 1.723491, 0.001115},{0.996015, 1.723279, 0.002203},{
      0.994516, 1.721780, 0.002203},{0.994304, 1.721933, 0.001115}}],
    Polygon[{{0.996015, 1.723279, 0.002203},{0.996267, 1.722933, 0.003236},{
      0.994862, 1.721528, 0.003236},{0.994516, 1.721780, 0.002203}}],
    Polygon[{{0.996267, 1.722933, 0.003236},{0.996611, 1.722460, 0.004190},{
      0.995335, 1.721185, 0.004190},{0.994862, 1.721528, 0.003236}}],
    Polygon[{{0.996611, 1.722460, 0.004190},{0.997038, 1.721873, 0.005040},{
      0.995922, 1.720758, 0.005040},{0.995335, 1.721185, 0.004190}}],
    Polygon[{{0.997038, 1.721873, 0.005040},{0.997537, 1.721185, 0.005766},{
      0.996611, 1.720258, 0.005766},{0.995922, 1.720758, 0.005040}}],
    Polygon[{{0.997537, 1.721185, 0.005766},{0.998098, 1.720413, 0.006351},{
      0.997382, 1.719697, 0.006351},{0.996611, 1.720258, 0.005766}}],
    Polygon[{{0.998098, 1.720413, 0.006351},{0.998705, 1.719577, 0.006779},{
      0.998218, 1.719090, 0.006779},{0.997382, 1.719697, 0.006351}}],
    Polygon[{{0.998705, 1.719577, 0.006779},{0.999345, 1.718697, 0.007040},{
      0.999098, 1.718451, 0.007040},{0.998218, 1.719090, 0.006779}}],
    Polygon[{{0.999098, 1.718451, -0.007040},{0.998218, 1.719090, -0.006779},{
      0.997905, 1.718476, -0.006779},{0.998940, 1.718140, -0.007040}}],
    Polygon[{{0.998218, 1.719090, -0.006779},{0.997382, 1.719697, -0.006351},{
      0.996922, 1.718795, -0.006351},{0.997905, 1.718476, -0.006779}}],
    Polygon[{{0.997382, 1.719697, -0.006351},{0.996611, 1.720258, -0.005766},{
      0.996015, 1.719090, -0.005766},{0.996922, 1.718795, -0.006351}}],
    Polygon[{{0.996611, 1.720258, -0.005766},{0.995922, 1.720758, -0.005040},{
      0.995207, 1.719353, -0.005040},{0.996015, 1.719090, -0.005766}}],
    Polygon[{{0.995922, 1.720758, -0.005040},{0.995335, 1.721185, -0.004190},{
      0.994516, 1.719577, -0.004190},{0.995207, 1.719353, -0.005040}}],
    Polygon[{{0.995335, 1.721185, -0.004190},{0.994862, 1.721528, -0.003236},{
      0.993960, 1.719758, -0.003236},{0.994516, 1.719577, -0.004190}}],
    Polygon[{{0.994862, 1.721528, -0.003236},{0.994516, 1.721780, -0.002203},{
      0.993553, 1.719890, -0.002203},{0.993960, 1.719758, -0.003236}}],
    Polygon[{{0.994516, 1.721780, -0.002203},{0.994304, 1.721933, -0.001115},{
      0.993305, 1.719971, -0.001115},{0.993553, 1.719890, -0.002203}}],
    Polygon[{{0.994304, 1.721933, -0.001115},{0.994233, 1.721985, 0.000000},{
      0.993221, 1.719998, 0.000000},{0.993305, 1.719971, -0.001115}}],
    Polygon[{{0.994233, 1.721985, 0.000000},{0.994304, 1.721933, 0.001115},{
      0.993305, 1.719971, 0.001115},{0.993221, 1.719998, 0.000000}}],
    Polygon[{{0.994304, 1.721933, 0.001115},{0.994516, 1.721780, 0.002203},{
      0.993553, 1.719890, 0.002203},{0.993305, 1.719971, 0.001115}}],
    Polygon[{{0.994516, 1.721780, 0.002203},{0.994862, 1.721528, 0.003236},{
      0.993960, 1.719758, 0.003236},{0.993553, 1.719890, 0.002203}}],
    Polygon[{{0.994862, 1.721528, 0.003236},{0.995335, 1.721185, 0.004190},{
      0.994516, 1.719577, 0.004190},{0.993960, 1.719758, 0.003236}}],
    Polygon[{{0.995335, 1.721185, 0.004190},{0.995922, 1.720758, 0.005040},{
      0.995207, 1.719353, 0.005040},{0.994516, 1.719577, 0.004190}}],
    Polygon[{{0.995922, 1.720758, 0.005040},{0.996611, 1.720258, 0.005766},{
      0.996015, 1.719090, 0.005766},{0.995207, 1.719353, 0.005040}}],
    Polygon[{{0.996611, 1.720258, 0.005766},{0.997382, 1.719697, 0.006351},{
      0.996922, 1.718795, 0.006351},{0.996015, 1.719090, 0.005766}}],
    Polygon[{{0.997382, 1.719697, 0.006351},{0.998218, 1.719090, 0.006779},{
      0.997905, 1.718476, 0.006779},{0.996922, 1.718795, 0.006351}}],
    Polygon[{{0.998218, 1.719090, 0.006779},{0.999098, 1.718451, 0.007040},{
      0.998940, 1.718140, 0.007040},{0.997905, 1.718476, 0.006779}}],
    Polygon[{{0.998940, 1.718140, -0.007040},{0.997905, 1.718476, -0.006779},{
      0.997797, 1.717795, -0.006779},{0.998885, 1.717795, -0.007040}}],
    Polygon[{{0.997905, 1.718476, -0.006779},{0.996922, 1.718795, -0.006351},{
      0.996764, 1.717795, -0.006351},{0.997797, 1.717795, -0.006779}}],
    Polygon[{{0.996922, 1.718795, -0.006351},{0.996015, 1.719090, -0.005766},{
      0.995810, 1.717795, -0.005766},{0.996764, 1.717795, -0.006351}}],
    Polygon[{{0.996015, 1.719090, -0.005766},{0.995207, 1.719353, -0.005040},{
      0.994960, 1.717795, -0.005040},{0.995810, 1.717795, -0.005766}}],
    Polygon[{{0.995207, 1.719353, -0.005040},{0.994516, 1.719577, -0.004190},{
      0.994233, 1.717795, -0.004190},{0.994960, 1.717795, -0.005040}}],
    Polygon[{{0.994516, 1.719577, -0.004190},{0.993960, 1.719758, -0.003236},{
      0.993649, 1.717795, -0.003236},{0.994233, 1.717795, -0.004190}}],
    Polygon[{{0.993960, 1.719758, -0.003236},{0.993553, 1.719890, -0.002203},{
      0.993221, 1.717795, -0.002203},{0.993649, 1.717795, -0.003236}}],
    Polygon[{{0.993553, 1.719890, -0.002203},{0.993305, 1.719971, -0.001115},{
      0.992960, 1.717795, -0.001115},{0.993221, 1.717795, -0.002203}}],
    Polygon[{{0.993305, 1.719971, -0.001115},{0.993221, 1.719998, 0.000000},{
      0.992872, 1.717795, 0.000000},{0.992960, 1.717795, -0.001115}}],
    Polygon[{{0.993221, 1.719998, 0.000000},{0.993305, 1.719971, 0.001115},{
      0.992960, 1.717795, 0.001115},{0.992872, 1.717795, 0.000000}}],
    Polygon[{{0.993305, 1.719971, 0.001115},{0.993553, 1.719890, 0.002203},{
      0.993221, 1.717795, 0.002203},{0.992960, 1.717795, 0.001115}}],
    Polygon[{{0.993553, 1.719890, 0.002203},{0.993960, 1.719758, 0.003236},{
      0.993649, 1.717795, 0.003236},{0.993221, 1.717795, 0.002203}}],
    Polygon[{{0.993960, 1.719758, 0.003236},{0.994516, 1.719577, 0.004190},{
      0.994233, 1.717795, 0.004190},{0.993649, 1.717795, 0.003236}}],
    Polygon[{{0.994516, 1.719577, 0.004190},{0.995207, 1.719353, 0.005040},{
      0.994960, 1.717795, 0.005040},{0.994233, 1.717795, 0.004190}}],
    Polygon[{{0.995207, 1.719353, 0.005040},{0.996015, 1.719090, 0.005766},{
      0.995810, 1.717795, 0.005766},{0.994960, 1.717795, 0.005040}}],
    Polygon[{{0.996015, 1.719090, 0.005766},{0.996922, 1.718795, 0.006351},{
      0.996764, 1.717795, 0.006351},{0.995810, 1.717795, 0.005766}}],
    Polygon[{{0.996922, 1.718795, 0.006351},{0.997905, 1.718476, 0.006779},{
      0.997797, 1.717795, 0.006779},{0.996764, 1.717795, 0.006351}}],
    Polygon[{{0.997905, 1.718476, 0.006779},{0.998940, 1.718140, 0.007040},{
      0.998885, 1.717795, 0.007040},{0.997797, 1.717795, 0.006779}}],
    Polygon[{{0.998885, 1.717795, -0.007040},{0.997797, 1.717795, -0.006779},{
      0.997905, 1.717115, -0.006779},{0.998940, 1.717451, -0.007040}}],
    Polygon[{{0.997797, 1.717795, -0.006779},{0.996764, 1.717795, -0.006351},{
      0.996922, 1.716795, -0.006351},{0.997905, 1.717115, -0.006779}}],
    Polygon[{{0.996764, 1.717795, -0.006351},{0.995810, 1.717795, -0.005766},{
      0.996015, 1.716501, -0.005766},{0.996922, 1.716795, -0.006351}}],
    Polygon[{{0.995810, 1.717795, -0.005766},{0.994960, 1.717795, -0.005040},{
      0.995207, 1.716238, -0.005040},{0.996015, 1.716501, -0.005766}}],
    Polygon[{{0.994960, 1.717795, -0.005040},{0.994233, 1.717795, -0.004190},{
      0.994516, 1.716013, -0.004190},{0.995207, 1.716238, -0.005040}}],
    Polygon[{{0.994233, 1.717795, -0.004190},{0.993649, 1.717795, -0.003236},{
      0.993960, 1.715833, -0.003236},{0.994516, 1.716013, -0.004190}}],
    Polygon[{{0.993649, 1.717795, -0.003236},{0.993221, 1.717795, -0.002203},{
      0.993553, 1.715700, -0.002203},{0.993960, 1.715833, -0.003236}}],
    Polygon[{{0.993221, 1.717795, -0.002203},{0.992960, 1.717795, -0.001115},{
      0.993305, 1.715620, -0.001115},{0.993553, 1.715700, -0.002203}}],
    Polygon[{{0.992960, 1.717795, -0.001115},{0.992872, 1.717795, 0.000000},{
      0.993221, 1.715593, 0.000000},{0.993305, 1.715620, -0.001115}}],
    Polygon[{{0.992872, 1.717795, 0.000000},{0.992960, 1.717795, 0.001115},{
      0.993305, 1.715620, 0.001115},{0.993221, 1.715593, 0.000000}}],
    Polygon[{{0.992960, 1.717795, 0.001115},{0.993221, 1.717795, 0.002203},{
      0.993553, 1.715700, 0.002203},{0.993305, 1.715620, 0.001115}}],
    Polygon[{{0.993221, 1.717795, 0.002203},{0.993649, 1.717795, 0.003236},{
      0.993960, 1.715833, 0.003236},{0.993553, 1.715700, 0.002203}}],
    Polygon[{{0.993649, 1.717795, 0.003236},{0.994233, 1.717795, 0.004190},{
      0.994516, 1.716013, 0.004190},{0.993960, 1.715833, 0.003236}}],
    Polygon[{{0.994233, 1.717795, 0.004190},{0.994960, 1.717795, 0.005040},{
      0.995207, 1.716238, 0.005040},{0.994516, 1.716013, 0.004190}}],
    Polygon[{{0.994960, 1.717795, 0.005040},{0.995810, 1.717795, 0.005766},{
      0.996015, 1.716501, 0.005766},{0.995207, 1.716238, 0.005040}}],
    Polygon[{{0.995810, 1.717795, 0.005766},{0.996764, 1.717795, 0.006351},{
      0.996922, 1.716795, 0.006351},{0.996015, 1.716501, 0.005766}}],
    Polygon[{{0.996764, 1.717795, 0.006351},{0.997797, 1.717795, 0.006779},{
      0.997905, 1.717115, 0.006779},{0.996922, 1.716795, 0.006351}}],
    Polygon[{{0.997797, 1.717795, 0.006779},{0.998885, 1.717795, 0.007040},{
      0.998940, 1.717451, 0.007040},{0.997905, 1.717115, 0.006779}}],
    Polygon[{{0.998940, 1.717451, -0.007040},{0.997905, 1.717115, -0.006779},{
      0.998218, 1.716501, -0.006779},{0.999098, 1.717140, -0.007040}}],
    Polygon[{{0.997905, 1.717115, -0.006779},{0.996922, 1.716795, -0.006351},{
      0.997382, 1.715893, -0.006351},{0.998218, 1.716501, -0.006779}}],
    Polygon[{{0.996922, 1.716795, -0.006351},{0.996015, 1.716501, -0.005766},{
      0.996611, 1.715333, -0.005766},{0.997382, 1.715893, -0.006351}}],
    Polygon[{{0.996015, 1.716501, -0.005766},{0.995207, 1.716238, -0.005040},{
      0.995922, 1.714833, -0.005040},{0.996611, 1.715333, -0.005766}}],
    Polygon[{{0.995207, 1.716238, -0.005040},{0.994516, 1.716013, -0.004190},{
      0.995335, 1.714406, -0.004190},{0.995922, 1.714833, -0.005040}}],
    Polygon[{{0.994516, 1.716013, -0.004190},{0.993960, 1.715833, -0.003236},{
      0.994862, 1.714062, -0.003236},{0.995335, 1.714406, -0.004190}}],
    Polygon[{{0.993960, 1.715833, -0.003236},{0.993553, 1.715700, -0.002203},{
      0.994516, 1.713811, -0.002203},{0.994862, 1.714062, -0.003236}}],
    Polygon[{{0.993553, 1.715700, -0.002203},{0.993305, 1.715620, -0.001115},{
      0.994304, 1.713657, -0.001115},{0.994516, 1.713811, -0.002203}}],
    Polygon[{{0.993305, 1.715620, -0.001115},{0.993221, 1.715593, 0.000000},{
      0.994233, 1.713606, 0.000000},{0.994304, 1.713657, -0.001115}}],
    Polygon[{{0.993221, 1.715593, 0.000000},{0.993305, 1.715620, 0.001115},{
      0.994304, 1.713657, 0.001115},{0.994233, 1.713606, 0.000000}}],
    Polygon[{{0.993305, 1.715620, 0.001115},{0.993553, 1.715700, 0.002203},{
      0.994516, 1.713811, 0.002203},{0.994304, 1.713657, 0.001115}}],
    Polygon[{{0.993553, 1.715700, 0.002203},{0.993960, 1.715833, 0.003236},{
      0.994862, 1.714062, 0.003236},{0.994516, 1.713811, 0.002203}}],
    Polygon[{{0.993960, 1.715833, 0.003236},{0.994516, 1.716013, 0.004190},{
      0.995335, 1.714406, 0.004190},{0.994862, 1.714062, 0.003236}}],
    Polygon[{{0.994516, 1.716013, 0.004190},{0.995207, 1.716238, 0.005040},{
      0.995922, 1.714833, 0.005040},{0.995335, 1.714406, 0.004190}}],
    Polygon[{{0.995207, 1.716238, 0.005040},{0.996015, 1.716501, 0.005766},{
      0.996611, 1.715333, 0.005766},{0.995922, 1.714833, 0.005040}}],
    Polygon[{{0.996015, 1.716501, 0.005766},{0.996922, 1.716795, 0.006351},{
      0.997382, 1.715893, 0.006351},{0.996611, 1.715333, 0.005766}}],
    Polygon[{{0.996922, 1.716795, 0.006351},{0.997905, 1.717115, 0.006779},{
      0.998218, 1.716501, 0.006779},{0.997382, 1.715893, 0.006351}}],
    Polygon[{{0.997905, 1.717115, 0.006779},{0.998940, 1.717451, 0.007040},{
      0.999098, 1.717140, 0.007040},{0.998218, 1.716501, 0.006779}}],
    Polygon[{{0.999098, 1.717140, -0.007040},{0.998218, 1.716501, -0.006779},{
      0.998705, 1.716013, -0.006779},{0.999345, 1.716893, -0.007040}}],
    Polygon[{{0.998218, 1.716501, -0.006779},{0.997382, 1.715893, -0.006351},{
      0.998098, 1.715177, -0.006351},{0.998705, 1.716013, -0.006779}}],
    Polygon[{{0.997382, 1.715893, -0.006351},{0.996611, 1.715333, -0.005766},{
      0.997537, 1.714406, -0.005766},{0.998098, 1.715177, -0.006351}}],
    Polygon[{{0.996611, 1.715333, -0.005766},{0.995922, 1.714833, -0.005040},{
      0.997038, 1.713718, -0.005040},{0.997537, 1.714406, -0.005766}}],
    Polygon[{{0.995922, 1.714833, -0.005040},{0.995335, 1.714406, -0.004190},{
      0.996611, 1.713130, -0.004190},{0.997038, 1.713718, -0.005040}}],
    Polygon[{{0.995335, 1.714406, -0.004190},{0.994862, 1.714062, -0.003236},{
      0.996267, 1.712657, -0.003236},{0.996611, 1.713130, -0.004190}}],
    Polygon[{{0.994862, 1.714062, -0.003236},{0.994516, 1.713811, -0.002203},{
      0.996015, 1.712311, -0.002203},{0.996267, 1.712657, -0.003236}}],
    Polygon[{{0.994516, 1.713811, -0.002203},{0.994304, 1.713657, -0.001115},{
      0.995862, 1.712100, -0.001115},{0.996015, 1.712311, -0.002203}}],
    Polygon[{{0.994304, 1.713657, -0.001115},{0.994233, 1.713606, 0.000000},{
      0.995810, 1.712029, 0.000000},{0.995862, 1.712100, -0.001115}}],
    Polygon[{{0.994233, 1.713606, 0.000000},{0.994304, 1.713657, 0.001115},{
      0.995862, 1.712100, 0.001115},{0.995810, 1.712029, 0.000000}}],
    Polygon[{{0.994304, 1.713657, 0.001115},{0.994516, 1.713811, 0.002203},{
      0.996015, 1.712311, 0.002203},{0.995862, 1.712100, 0.001115}}],
    Polygon[{{0.994516, 1.713811, 0.002203},{0.994862, 1.714062, 0.003236},{
      0.996267, 1.712657, 0.003236},{0.996015, 1.712311, 0.002203}}],
    Polygon[{{0.994862, 1.714062, 0.003236},{0.995335, 1.714406, 0.004190},{
      0.996611, 1.713130, 0.004190},{0.996267, 1.712657, 0.003236}}],
    Polygon[{{0.995335, 1.714406, 0.004190},{0.995922, 1.714833, 0.005040},{
      0.997038, 1.713718, 0.005040},{0.996611, 1.713130, 0.004190}}],
    Polygon[{{0.995922, 1.714833, 0.005040},{0.996611, 1.715333, 0.005766},{
      0.997537, 1.714406, 0.005766},{0.997038, 1.713718, 0.005040}}],
    Polygon[{{0.996611, 1.715333, 0.005766},{0.997382, 1.715893, 0.006351},{
      0.998098, 1.715177, 0.006351},{0.997537, 1.714406, 0.005766}}],
    Polygon[{{0.997382, 1.715893, 0.006351},{0.998218, 1.716501, 0.006779},{
      0.998705, 1.716013, 0.006779},{0.998098, 1.715177, 0.006351}}],
    Polygon[{{0.998218, 1.716501, 0.006779},{0.999098, 1.717140, 0.007040},{
      0.999345, 1.716893, 0.007040},{0.998705, 1.716013, 0.006779}}],
    Polygon[{{0.999345, 1.716893, -0.007040},{0.998705, 1.716013, -0.006779},{
      0.999319, 1.715700, -0.006779},{0.999655, 1.716735, -0.007040}}],
    Polygon[{{0.998705, 1.716013, -0.006779},{0.998098, 1.715177, -0.006351},{
      0.999000, 1.714718, -0.006351},{0.999319, 1.715700, -0.006779}}],
    Polygon[{{0.998098, 1.715177, -0.006351},{0.997537, 1.714406, -0.005766},{
      0.998705, 1.713811, -0.005766},{0.999000, 1.714718, -0.006351}}],
    Polygon[{{0.997537, 1.714406, -0.005766},{0.997038, 1.713718, -0.005040},{
      0.998443, 1.713002, -0.005040},{0.998705, 1.713811, -0.005766}}],
    Polygon[{{0.997038, 1.713718, -0.005040},{0.996611, 1.713130, -0.004190},{
      0.998218, 1.712311, -0.004190},{0.998443, 1.713002, -0.005040}}],
    Polygon[{{0.996611, 1.713130, -0.004190},{0.996267, 1.712657, -0.003236},{
      0.998037, 1.711755, -0.003236},{0.998218, 1.712311, -0.004190}}],
    Polygon[{{0.996267, 1.712657, -0.003236},{0.996015, 1.712311, -0.002203},{
      0.997905, 1.711348, -0.002203},{0.998037, 1.711755, -0.003236}}],
    Polygon[{{0.996015, 1.712311, -0.002203},{0.995862, 1.712100, -0.001115},{
      0.997824, 1.711100, -0.001115},{0.997905, 1.711348, -0.002203}}],
    Polygon[{{0.995862, 1.712100, -0.001115},{0.995810, 1.712029, 0.000000},{
      0.997797, 1.711016, 0.000000},{0.997824, 1.711100, -0.001115}}],
    Polygon[{{0.995810, 1.712029, 0.000000},{0.995862, 1.712100, 0.001115},{
      0.997824, 1.711100, 0.001115},{0.997797, 1.711016, 0.000000}}],
    Polygon[{{0.995862, 1.712100, 0.001115},{0.996015, 1.712311, 0.002203},{
      0.997905, 1.711348, 0.002203},{0.997824, 1.711100, 0.001115}}],
    Polygon[{{0.996015, 1.712311, 0.002203},{0.996267, 1.712657, 0.003236},{
      0.998037, 1.711755, 0.003236},{0.997905, 1.711348, 0.002203}}],
    Polygon[{{0.996267, 1.712657, 0.003236},{0.996611, 1.713130, 0.004190},{
      0.998218, 1.712311, 0.004190},{0.998037, 1.711755, 0.003236}}],
    Polygon[{{0.996611, 1.713130, 0.004190},{0.997038, 1.713718, 0.005040},{
      0.998443, 1.713002, 0.005040},{0.998218, 1.712311, 0.004190}}],
    Polygon[{{0.997038, 1.713718, 0.005040},{0.997537, 1.714406, 0.005766},{
      0.998705, 1.713811, 0.005766},{0.998443, 1.713002, 0.005040}}],
    Polygon[{{0.997537, 1.714406, 0.005766},{0.998098, 1.715177, 0.006351},{
      0.999000, 1.714718, 0.006351},{0.998705, 1.713811, 0.005766}}],
    Polygon[{{0.998098, 1.715177, 0.006351},{0.998705, 1.716013, 0.006779},{
      0.999319, 1.715700, 0.006779},{0.999000, 1.714718, 0.006351}}],
    Polygon[{{0.998705, 1.716013, 0.006779},{0.999345, 1.716893, 0.007040},{
      0.999655, 1.716735, 0.007040},{0.999319, 1.715700, 0.006779}}],
    Polygon[{{0.999655, 1.716735, -0.007040},{0.999319, 1.715700, -0.006779},{
      1.000000, 1.715593, -0.006779},{1.000000, 1.716680, -0.007040}}],
    Polygon[{{0.999319, 1.715700, -0.006779},{0.999000, 1.714718, -0.006351},{
      1.000000, 1.714559, -0.006351},{1.000000, 1.715593, -0.006779}}],
    Polygon[{{0.999000, 1.714718, -0.006351},{0.998705, 1.713811, -0.005766},{
      1.000000, 1.713606, -0.005766},{1.000000, 1.714559, -0.006351}}],
    Polygon[{{0.998705, 1.713811, -0.005766},{0.998443, 1.713002, -0.005040},{
      1.000000, 1.712755, -0.005040},{1.000000, 1.713606, -0.005766}}],
    Polygon[{{0.998443, 1.713002, -0.005040},{0.998218, 1.712311, -0.004190},{
      1.000000, 1.712029, -0.004190},{1.000000, 1.712755, -0.005040}}],
    Polygon[{{0.998218, 1.712311, -0.004190},{0.998037, 1.711755, -0.003236},{
      1.000000, 1.711444, -0.003236},{1.000000, 1.712029, -0.004190}}],
    Polygon[{{0.998037, 1.711755, -0.003236},{0.997905, 1.711348, -0.002203},{
      1.000000, 1.711016, -0.002203},{1.000000, 1.711444, -0.003236}}],
    Polygon[{{0.997905, 1.711348, -0.002203},{0.997824, 1.711100, -0.001115},{
      1.000000, 1.710755, -0.001115},{1.000000, 1.711016, -0.002203}}],
    Polygon[{{0.997824, 1.711100, -0.001115},{0.997797, 1.711016, 0.000000},{
      1.000000, 1.710667, 0.000000},{1.000000, 1.710755, -0.001115}}],
    Polygon[{{0.997797, 1.711016, 0.000000},{0.997824, 1.711100, 0.001115},{
      1.000000, 1.710755, 0.001115},{1.000000, 1.710667, 0.000000}}],
    Polygon[{{0.997824, 1.711100, 0.001115},{0.997905, 1.711348, 0.002203},{
      1.000000, 1.711016, 0.002203},{1.000000, 1.710755, 0.001115}}],
    Polygon[{{0.997905, 1.711348, 0.002203},{0.998037, 1.711755, 0.003236},{
      1.000000, 1.711444, 0.003236},{1.000000, 1.711016, 0.002203}}],
    Polygon[{{0.998037, 1.711755, 0.003236},{0.998218, 1.712311, 0.004190},{
      1.000000, 1.712029, 0.004190},{1.000000, 1.711444, 0.003236}}],
    Polygon[{{0.998218, 1.712311, 0.004190},{0.998443, 1.713002, 0.005040},{
      1.000000, 1.712755, 0.005040},{1.000000, 1.712029, 0.004190}}],
    Polygon[{{0.998443, 1.713002, 0.005040},{0.998705, 1.713811, 0.005766},{
      1.000000, 1.713606, 0.005766},{1.000000, 1.712755, 0.005040}}],
    Polygon[{{0.998705, 1.713811, 0.005766},{0.999000, 1.714718, 0.006351},{
      1.000000, 1.714559, 0.006351},{1.000000, 1.713606, 0.005766}}],
    Polygon[{{0.999000, 1.714718, 0.006351},{0.999319, 1.715700, 0.006779},{
      1.000000, 1.715593, 0.006779},{1.000000, 1.714559, 0.006351}}],
    Polygon[{{0.999319, 1.715700, 0.006779},{0.999655, 1.716735, 0.007040},{
      1.000000, 1.716680, 0.007040},{1.000000, 1.715593, 0.006779}}],
    Polygon[{{1.000000, 1.716680, -0.007040},{1.000000, 1.715593, -0.006779},{
      1.000681, 1.715700, -0.006779},{1.000345, 1.716735, -0.007040}}],
    Polygon[{{1.000000, 1.715593, -0.006779},{1.000000, 1.714559, -0.006351},{
      1.001000, 1.714718, -0.006351},{1.000681, 1.715700, -0.006779}}],
    Polygon[{{1.000000, 1.714559, -0.006351},{1.000000, 1.713606, -0.005766},{
      1.001295, 1.713811, -0.005766},{1.001000, 1.714718, -0.006351}}],
    Polygon[{{1.000000, 1.713606, -0.005766},{1.000000, 1.712755, -0.005040},{
      1.001557, 1.713002, -0.005040},{1.001295, 1.713811, -0.005766}}],
    Polygon[{{1.000000, 1.712755, -0.005040},{1.000000, 1.712029, -0.004190},{
      1.001782, 1.712311, -0.004190},{1.001557, 1.713002, -0.005040}}],
    Polygon[{{1.000000, 1.712029, -0.004190},{1.000000, 1.711444, -0.003236},{
      1.001963, 1.711755, -0.003236},{1.001782, 1.712311, -0.004190}}],
    Polygon[{{1.000000, 1.711444, -0.003236},{1.000000, 1.711016, -0.002203},{
      1.002095, 1.711348, -0.002203},{1.001963, 1.711755, -0.003236}}],
    Polygon[{{1.000000, 1.711016, -0.002203},{1.000000, 1.710755, -0.001115},{
      1.002175, 1.711100, -0.001115},{1.002095, 1.711348, -0.002203}}],
    Polygon[{{1.000000, 1.710755, -0.001115},{1.000000, 1.710667, 0.000000},{
      1.002203, 1.711016, 0.000000},{1.002175, 1.711100, -0.001115}}],
    Polygon[{{1.000000, 1.710667, 0.000000},{1.000000, 1.710755, 0.001115},{
      1.002175, 1.711100, 0.001115},{1.002203, 1.711016, 0.000000}}],
    Polygon[{{1.000000, 1.710755, 0.001115},{1.000000, 1.711016, 0.002203},{
      1.002095, 1.711348, 0.002203},{1.002175, 1.711100, 0.001115}}],
    Polygon[{{1.000000, 1.711016, 0.002203},{1.000000, 1.711444, 0.003236},{
      1.001963, 1.711755, 0.003236},{1.002095, 1.711348, 0.002203}}],
    Polygon[{{1.000000, 1.711444, 0.003236},{1.000000, 1.712029, 0.004190},{
      1.001782, 1.712311, 0.004190},{1.001963, 1.711755, 0.003236}}],
    Polygon[{{1.000000, 1.712029, 0.004190},{1.000000, 1.712755, 0.005040},{
      1.001557, 1.713002, 0.005040},{1.001782, 1.712311, 0.004190}}],
    Polygon[{{1.000000, 1.712755, 0.005040},{1.000000, 1.713606, 0.005766},{
      1.001295, 1.713811, 0.005766},{1.001557, 1.713002, 0.005040}}],
    Polygon[{{1.000000, 1.713606, 0.005766},{1.000000, 1.714559, 0.006351},{
      1.001000, 1.714718, 0.006351},{1.001295, 1.713811, 0.005766}}],
    Polygon[{{1.000000, 1.714559, 0.006351},{1.000000, 1.715593, 0.006779},{
      1.000681, 1.715700, 0.006779},{1.001000, 1.714718, 0.006351}}],
    Polygon[{{1.000000, 1.715593, 0.006779},{1.000000, 1.716680, 0.007040},{
      1.000345, 1.716735, 0.007040},{1.000681, 1.715700, 0.006779}}],
    Polygon[{{1.000345, 1.716735, -0.007040},{1.000681, 1.715700, -0.006779},{
      1.001295, 1.716013, -0.006779},{1.000655, 1.716893, -0.007040}}],
    Polygon[{{1.000681, 1.715700, -0.006779},{1.001000, 1.714718, -0.006351},{
      1.001902, 1.715177, -0.006351},{1.001295, 1.716013, -0.006779}}],
    Polygon[{{1.001000, 1.714718, -0.006351},{1.001295, 1.713811, -0.005766},{
      1.002463, 1.714406, -0.005766},{1.001902, 1.715177, -0.006351}}],
    Polygon[{{1.001295, 1.713811, -0.005766},{1.001557, 1.713002, -0.005040},{
      1.002962, 1.713718, -0.005040},{1.002463, 1.714406, -0.005766}}],
    Polygon[{{1.001557, 1.713002, -0.005040},{1.001782, 1.712311, -0.004190},{
      1.003389, 1.713130, -0.004190},{1.002962, 1.713718, -0.005040}}],
    Polygon[{{1.001782, 1.712311, -0.004190},{1.001963, 1.711755, -0.003236},{
      1.003733, 1.712657, -0.003236},{1.003389, 1.713130, -0.004190}}],
    Polygon[{{1.001963, 1.711755, -0.003236},{1.002095, 1.711348, -0.002203},{
      1.003985, 1.712311, -0.002203},{1.003733, 1.712657, -0.003236}}],
    Polygon[{{1.002095, 1.711348, -0.002203},{1.002175, 1.711100, -0.001115},{
      1.004138, 1.712100, -0.001115},{1.003985, 1.712311, -0.002203}}],
    Polygon[{{1.002175, 1.711100, -0.001115},{1.002203, 1.711016, 0.000000},{
      1.004190, 1.712029, 0.000000},{1.004138, 1.712100, -0.001115}}],
    Polygon[{{1.002203, 1.711016, 0.000000},{1.002175, 1.711100, 0.001115},{
      1.004138, 1.712100, 0.001115},{1.004190, 1.712029, 0.000000}}],
    Polygon[{{1.002175, 1.711100, 0.001115},{1.002095, 1.711348, 0.002203},{
      1.003985, 1.712311, 0.002203},{1.004138, 1.712100, 0.001115}}],
    Polygon[{{1.002095, 1.711348, 0.002203},{1.001963, 1.711755, 0.003236},{
      1.003733, 1.712657, 0.003236},{1.003985, 1.712311, 0.002203}}],
    Polygon[{{1.001963, 1.711755, 0.003236},{1.001782, 1.712311, 0.004190},{
      1.003389, 1.713130, 0.004190},{1.003733, 1.712657, 0.003236}}],
    Polygon[{{1.001782, 1.712311, 0.004190},{1.001557, 1.713002, 0.005040},{
      1.002962, 1.713718, 0.005040},{1.003389, 1.713130, 0.004190}}],
    Polygon[{{1.001557, 1.713002, 0.005040},{1.001295, 1.713811, 0.005766},{
      1.002463, 1.714406, 0.005766},{1.002962, 1.713718, 0.005040}}],
    Polygon[{{1.001295, 1.713811, 0.005766},{1.001000, 1.714718, 0.006351},{
      1.001902, 1.715177, 0.006351},{1.002463, 1.714406, 0.005766}}],
    Polygon[{{1.001000, 1.714718, 0.006351},{1.000681, 1.715700, 0.006779},{
      1.001295, 1.716013, 0.006779},{1.001902, 1.715177, 0.006351}}],
    Polygon[{{1.000681, 1.715700, 0.006779},{1.000345, 1.716735, 0.007040},{
      1.000655, 1.716893, 0.007040},{1.001295, 1.716013, 0.006779}}],
    Polygon[{{1.000655, 1.716893, -0.007040},{1.001295, 1.716013, -0.006779},{
      1.001782, 1.716501, -0.006779},{1.000902, 1.717140, -0.007040}}],
    Polygon[{{1.001295, 1.716013, -0.006779},{1.001902, 1.715177, -0.006351},{
      1.002618, 1.715893, -0.006351},{1.001782, 1.716501, -0.006779}}],
    Polygon[{{1.001902, 1.715177, -0.006351},{1.002463, 1.714406, -0.005766},{
      1.003389, 1.715333, -0.005766},{1.002618, 1.715893, -0.006351}}],
    Polygon[{{1.002463, 1.714406, -0.005766},{1.002962, 1.713718, -0.005040},{
      1.004078, 1.714833, -0.005040},{1.003389, 1.715333, -0.005766}}],
    Polygon[{{1.002962, 1.713718, -0.005040},{1.003389, 1.713130, -0.004190},{
      1.004665, 1.714406, -0.004190},{1.004078, 1.714833, -0.005040}}],
    Polygon[{{1.003389, 1.713130, -0.004190},{1.003733, 1.712657, -0.003236},{
      1.005138, 1.714062, -0.003236},{1.004665, 1.714406, -0.004190}}],
    Polygon[{{1.003733, 1.712657, -0.003236},{1.003985, 1.712311, -0.002203},{
      1.005484, 1.713811, -0.002203},{1.005138, 1.714062, -0.003236}}],
    Polygon[{{1.003985, 1.712311, -0.002203},{1.004138, 1.712100, -0.001115},{
      1.005695, 1.713657, -0.001115},{1.005484, 1.713811, -0.002203}}],
    Polygon[{{1.004138, 1.712100, -0.001115},{1.004190, 1.712029, 0.000000},{
      1.005767, 1.713606, 0.000000},{1.005695, 1.713657, -0.001115}}],
    Polygon[{{1.004190, 1.712029, 0.000000},{1.004138, 1.712100, 0.001115},{
      1.005695, 1.713657, 0.001115},{1.005767, 1.713606, 0.000000}}],
    Polygon[{{1.004138, 1.712100, 0.001115},{1.003985, 1.712311, 0.002203},{
      1.005484, 1.713811, 0.002203},{1.005695, 1.713657, 0.001115}}],
    Polygon[{{1.003985, 1.712311, 0.002203},{1.003733, 1.712657, 0.003236},{
      1.005138, 1.714062, 0.003236},{1.005484, 1.713811, 0.002203}}],
    Polygon[{{1.003733, 1.712657, 0.003236},{1.003389, 1.713130, 0.004190},{
      1.004665, 1.714406, 0.004190},{1.005138, 1.714062, 0.003236}}],
    Polygon[{{1.003389, 1.713130, 0.004190},{1.002962, 1.713718, 0.005040},{
      1.004078, 1.714833, 0.005040},{1.004665, 1.714406, 0.004190}}],
    Polygon[{{1.002962, 1.713718, 0.005040},{1.002463, 1.714406, 0.005766},{
      1.003389, 1.715333, 0.005766},{1.004078, 1.714833, 0.005040}}],
    Polygon[{{1.002463, 1.714406, 0.005766},{1.001902, 1.715177, 0.006351},{
      1.002618, 1.715893, 0.006351},{1.003389, 1.715333, 0.005766}}],
    Polygon[{{1.001902, 1.715177, 0.006351},{1.001295, 1.716013, 0.006779},{
      1.001782, 1.716501, 0.006779},{1.002618, 1.715893, 0.006351}}],
    Polygon[{{1.001295, 1.716013, 0.006779},{1.000655, 1.716893, 0.007040},{
      1.000902, 1.717140, 0.007040},{1.001782, 1.716501, 0.006779}}],
    Polygon[{{1.000902, 1.717140, -0.007040},{1.001782, 1.716501, -0.006779},{
      1.002095, 1.717115, -0.006779},{1.001060, 1.717451, -0.007040}}],
    Polygon[{{1.001782, 1.716501, -0.006779},{1.002618, 1.715893, -0.006351},{
      1.003078, 1.716795, -0.006351},{1.002095, 1.717115, -0.006779}}],
    Polygon[{{1.002618, 1.715893, -0.006351},{1.003389, 1.715333, -0.005766},{
      1.003985, 1.716501, -0.005766},{1.003078, 1.716795, -0.006351}}],
    Polygon[{{1.003389, 1.715333, -0.005766},{1.004078, 1.714833, -0.005040},{
      1.004793, 1.716238, -0.005040},{1.003985, 1.716501, -0.005766}}],
    Polygon[{{1.004078, 1.714833, -0.005040},{1.004665, 1.714406, -0.004190},{
      1.005484, 1.716013, -0.004190},{1.004793, 1.716238, -0.005040}}],
    Polygon[{{1.004665, 1.714406, -0.004190},{1.005138, 1.714062, -0.003236},{
      1.006040, 1.715833, -0.003236},{1.005484, 1.716013, -0.004190}}],
    Polygon[{{1.005138, 1.714062, -0.003236},{1.005484, 1.713811, -0.002203},{
      1.006447, 1.715700, -0.002203},{1.006040, 1.715833, -0.003236}}],
    Polygon[{{1.005484, 1.713811, -0.002203},{1.005695, 1.713657, -0.001115},{
      1.006696, 1.715620, -0.001115},{1.006447, 1.715700, -0.002203}}],
    Polygon[{{1.005695, 1.713657, -0.001115},{1.005767, 1.713606, 0.000000},{
      1.006779, 1.715593, 0.000000},{1.006696, 1.715620, -0.001115}}],
    Polygon[{{1.005767, 1.713606, 0.000000},{1.005695, 1.713657, 0.001115},{
      1.006696, 1.715620, 0.001115},{1.006779, 1.715593, 0.000000}}],
    Polygon[{{1.005695, 1.713657, 0.001115},{1.005484, 1.713811, 0.002203},{
      1.006447, 1.715700, 0.002203},{1.006696, 1.715620, 0.001115}}],
    Polygon[{{1.005484, 1.713811, 0.002203},{1.005138, 1.714062, 0.003236},{
      1.006040, 1.715833, 0.003236},{1.006447, 1.715700, 0.002203}}],
    Polygon[{{1.005138, 1.714062, 0.003236},{1.004665, 1.714406, 0.004190},{
      1.005484, 1.716013, 0.004190},{1.006040, 1.715833, 0.003236}}],
    Polygon[{{1.004665, 1.714406, 0.004190},{1.004078, 1.714833, 0.005040},{
      1.004793, 1.716238, 0.005040},{1.005484, 1.716013, 0.004190}}],
    Polygon[{{1.004078, 1.714833, 0.005040},{1.003389, 1.715333, 0.005766},{
      1.003985, 1.716501, 0.005766},{1.004793, 1.716238, 0.005040}}],
    Polygon[{{1.003389, 1.715333, 0.005766},{1.002618, 1.715893, 0.006351},{
      1.003078, 1.716795, 0.006351},{1.003985, 1.716501, 0.005766}}],
    Polygon[{{1.002618, 1.715893, 0.006351},{1.001782, 1.716501, 0.006779},{
      1.002095, 1.717115, 0.006779},{1.003078, 1.716795, 0.006351}}],
    Polygon[{{1.001782, 1.716501, 0.006779},{1.000902, 1.717140, 0.007040},{
      1.001060, 1.717451, 0.007040},{1.002095, 1.717115, 0.006779}}],
    Polygon[{{1.001060, 1.717451, -0.007040},{1.002095, 1.717115, -0.006779},{
      1.002203, 1.717795, -0.006779},{1.001115, 1.717795, -0.007040}}],
    Polygon[{{1.002095, 1.717115, -0.006779},{1.003078, 1.716795, -0.006351},{
      1.003236, 1.717795, -0.006351},{1.002203, 1.717795, -0.006779}}],
    Polygon[{{1.003078, 1.716795, -0.006351},{1.003985, 1.716501, -0.005766},{
      1.004190, 1.717795, -0.005766},{1.003236, 1.717795, -0.006351}}],
    Polygon[{{1.003985, 1.716501, -0.005766},{1.004793, 1.716238, -0.005040},{
      1.005040, 1.717795, -0.005040},{1.004190, 1.717795, -0.005766}}],
    Polygon[{{1.004793, 1.716238, -0.005040},{1.005484, 1.716013, -0.004190},{
      1.005767, 1.717795, -0.004190},{1.005040, 1.717795, -0.005040}}],
    Polygon[{{1.005484, 1.716013, -0.004190},{1.006040, 1.715833, -0.003236},{
      1.006351, 1.717795, -0.003236},{1.005767, 1.717795, -0.004190}}],
    Polygon[{{1.006040, 1.715833, -0.003236},{1.006447, 1.715700, -0.002203},{
      1.006779, 1.717795, -0.002203},{1.006351, 1.717795, -0.003236}}],
    Polygon[{{1.006447, 1.715700, -0.002203},{1.006696, 1.715620, -0.001115},{
      1.007040, 1.717795, -0.001115},{1.006779, 1.717795, -0.002203}}],
    Polygon[{{1.006696, 1.715620, -0.001115},{1.006779, 1.715593, 0.000000},{
      1.007128, 1.717795, 0.000000},{1.007040, 1.717795, -0.001115}}],
    Polygon[{{1.006779, 1.715593, 0.000000},{1.006696, 1.715620, 0.001115},{
      1.007040, 1.717795, 0.001115},{1.007128, 1.717795, 0.000000}}],
    Polygon[{{1.006696, 1.715620, 0.001115},{1.006447, 1.715700, 0.002203},{
      1.006779, 1.717795, 0.002203},{1.007040, 1.717795, 0.001115}}],
    Polygon[{{1.006447, 1.715700, 0.002203},{1.006040, 1.715833, 0.003236},{
      1.006351, 1.717795, 0.003236},{1.006779, 1.717795, 0.002203}}],
    Polygon[{{1.006040, 1.715833, 0.003236},{1.005484, 1.716013, 0.004190},{
      1.005767, 1.717795, 0.004190},{1.006351, 1.717795, 0.003236}}],
    Polygon[{{1.005484, 1.716013, 0.004190},{1.004793, 1.716238, 0.005040},{
      1.005040, 1.717795, 0.005040},{1.005767, 1.717795, 0.004190}}],
    Polygon[{{1.004793, 1.716238, 0.005040},{1.003985, 1.716501, 0.005766},{
      1.004190, 1.717795, 0.005766},{1.005040, 1.717795, 0.005040}}],
    Polygon[{{1.003985, 1.716501, 0.005766},{1.003078, 1.716795, 0.006351},{
      1.003236, 1.717795, 0.006351},{1.004190, 1.717795, 0.005766}}],
    Polygon[{{1.003078, 1.716795, 0.006351},{1.002095, 1.717115, 0.006779},{
      1.002203, 1.717795, 0.006779},{1.003236, 1.717795, 0.006351}}],
    Polygon[{{1.002095, 1.717115, 0.006779},{1.001060, 1.717451, 0.007040},{
      1.001115, 1.717795, 0.007040},{1.002203, 1.717795, 0.006779}}],
    Polygon[{{0.976712, 1.672198, -0.008489},{0.978024, 1.672198, -0.008174},{
      0.977894, 1.673019, -0.008174},{0.976647, 1.672614, -0.008489}}],
    Polygon[{{0.978024, 1.672198, -0.008174},{0.979270, 1.672198, -0.007658},{
      0.979079, 1.673404, -0.007658},{0.977894, 1.673019, -0.008174}}],
    Polygon[{{0.979270, 1.672198, -0.007658},{0.980420, 1.672198, -0.006953},{
      0.980172, 1.673759, -0.006953},{0.979079, 1.673404, -0.007658}}],
    Polygon[{{0.980420, 1.672198, -0.006953},{0.981445, 1.672198, -0.006077},{
      0.981148, 1.674076, -0.006077},{0.980172, 1.673759, -0.006953}}],
    Polygon[{{0.981445, 1.672198, -0.006077},{0.982321, 1.672198, -0.005052},{
      0.981981, 1.674347, -0.005052},{0.981148, 1.674076, -0.006077}}],
    Polygon[{{0.982321, 1.672198, -0.005052},{0.983026, 1.672198, -0.003902},{
      0.982651, 1.674564, -0.003902},{0.981981, 1.674347, -0.005052}}],
    Polygon[{{0.983026, 1.672198, -0.003902},{0.983542, 1.672198, -0.002656},{
      0.983142, 1.674724, -0.002656},{0.982651, 1.674564, -0.003902}}],
    Polygon[{{0.983542, 1.672198, -0.002656},{0.983857, 1.672198, -0.001344},{
      0.983441, 1.674821, -0.001344},{0.983142, 1.674724, -0.002656}}],
    Polygon[{{0.983857, 1.672198, -0.001344},{0.983962, 1.672198, 0.000000},{
      0.983542, 1.674854, 0.000000},{0.983441, 1.674821, -0.001344}}],
    Polygon[{{0.983962, 1.672198, 0.000000},{0.983857, 1.672198, 0.001344},{
      0.983441, 1.674821, 0.001344},{0.983542, 1.674854, 0.000000}}],
    Polygon[{{0.983857, 1.672198, 0.001344},{0.983542, 1.672198, 0.002656},{
      0.983142, 1.674724, 0.002656},{0.983441, 1.674821, 0.001344}}],
    Polygon[{{0.983542, 1.672198, 0.002656},{0.983026, 1.672198, 0.003902},{
      0.982651, 1.674564, 0.003902},{0.983142, 1.674724, 0.002656}}],
    Polygon[{{0.983026, 1.672198, 0.003902},{0.982321, 1.672198, 0.005052},{
      0.981981, 1.674347, 0.005052},{0.982651, 1.674564, 0.003902}}],
    Polygon[{{0.982321, 1.672198, 0.005052},{0.981445, 1.672198, 0.006077},{
      0.981148, 1.674076, 0.006077},{0.981981, 1.674347, 0.005052}}],
    Polygon[{{0.981445, 1.672198, 0.006077},{0.980420, 1.672198, 0.006953},{
      0.980172, 1.673759, 0.006953},{0.981148, 1.674076, 0.006077}}],
    Polygon[{{0.980420, 1.672198, 0.006953},{0.979270, 1.672198, 0.007658},{
      0.979079, 1.673404, 0.007658},{0.980172, 1.673759, 0.006953}}],
    Polygon[{{0.979270, 1.672198, 0.007658},{0.978024, 1.672198, 0.008174},{
      0.977894, 1.673019, 0.008174},{0.979079, 1.673404, 0.007658}}],
    Polygon[{{0.978024, 1.672198, 0.008174},{0.976712, 1.672198, 0.008489},{
      0.976647, 1.672614, 0.008489},{0.977894, 1.673019, 0.008174}}],
    Polygon[{{0.976647, 1.672614, -0.008489},{0.977894, 1.673019, -0.008174},{
      0.977517, 1.673759, -0.008174},{0.976456, 1.672988, -0.008489}}],
    Polygon[{{0.977894, 1.673019, -0.008174},{0.979079, 1.673404, -0.007658},{
      0.978525, 1.674491, -0.007658},{0.977517, 1.673759, -0.008174}}],
    Polygon[{{0.979079, 1.673404, -0.007658},{0.980172, 1.673759, -0.006953},{
      0.979455, 1.675167, -0.006953},{0.978525, 1.674491, -0.007658}}],
    Polygon[{{0.980172, 1.673759, -0.006953},{0.981148, 1.674076, -0.006077},{
      0.980285, 1.675770, -0.006077},{0.979455, 1.675167, -0.006953}}],
    Polygon[{{0.981148, 1.674076, -0.006077},{0.981981, 1.674347, -0.005052},{
      0.980993, 1.676285, -0.005052},{0.980285, 1.675770, -0.006077}}],
    Polygon[{{0.981981, 1.674347, -0.005052},{0.982651, 1.674564, -0.003902},{
      0.981563, 1.676699, -0.003902},{0.980993, 1.676285, -0.005052}}],
    Polygon[{{0.982651, 1.674564, -0.003902},{0.983142, 1.674724, -0.002656},{
      0.981981, 1.677002, -0.002656},{0.981563, 1.676699, -0.003902}}],
    Polygon[{{0.983142, 1.674724, -0.002656},{0.983441, 1.674821, -0.001344},{
      0.982235, 1.677188, -0.001344},{0.981981, 1.677002, -0.002656}}],
    Polygon[{{0.983441, 1.674821, -0.001344},{0.983542, 1.674854, 0.000000},{
      0.982321, 1.677250, 0.000000},{0.982235, 1.677188, -0.001344}}],
    Polygon[{{0.983542, 1.674854, 0.000000},{0.983441, 1.674821, 0.001344},{
      0.982235, 1.677188, 0.001344},{0.982321, 1.677250, 0.000000}}],
    Polygon[{{0.983441, 1.674821, 0.001344},{0.983142, 1.674724, 0.002656},{
      0.981981, 1.677002, 0.002656},{0.982235, 1.677188, 0.001344}}],
    Polygon[{{0.983142, 1.674724, 0.002656},{0.982651, 1.674564, 0.003902},{
      0.981563, 1.676699, 0.003902},{0.981981, 1.677002, 0.002656}}],
    Polygon[{{0.982651, 1.674564, 0.003902},{0.981981, 1.674347, 0.005052},{
      0.980993, 1.676285, 0.005052},{0.981563, 1.676699, 0.003902}}],
    Polygon[{{0.981981, 1.674347, 0.005052},{0.981148, 1.674076, 0.006077},{
      0.980285, 1.675770, 0.006077},{0.980993, 1.676285, 0.005052}}],
    Polygon[{{0.981148, 1.674076, 0.006077},{0.980172, 1.673759, 0.006953},{
      0.979455, 1.675167, 0.006953},{0.980285, 1.675770, 0.006077}}],
    Polygon[{{0.980172, 1.673759, 0.006953},{0.979079, 1.673404, 0.007658},{
      0.978525, 1.674491, 0.007658},{0.979455, 1.675167, 0.006953}}],
    Polygon[{{0.979079, 1.673404, 0.007658},{0.977894, 1.673019, 0.008174},{
      0.977517, 1.673759, 0.008174},{0.978525, 1.674491, 0.007658}}],
    Polygon[{{0.977894, 1.673019, 0.008174},{0.976647, 1.672614, 0.008489},{
      0.976456, 1.672988, 0.008489},{0.977517, 1.673759, 0.008174}}],
    Polygon[{{0.976456, 1.672988, -0.008489},{0.977517, 1.673759, -0.008174},{
      0.976929, 1.674347, -0.008174},{0.976158, 1.673286, -0.008489}}],
    Polygon[{{0.977517, 1.673759, -0.008174},{0.978525, 1.674491, -0.007658},{
      0.977661, 1.675355, -0.007658},{0.976929, 1.674347, -0.008174}}],
    Polygon[{{0.978525, 1.674491, -0.007658},{0.979455, 1.675167, -0.006953},{
      0.978337, 1.676285, -0.006953},{0.977661, 1.675355, -0.007658}}],
    Polygon[{{0.979455, 1.675167, -0.006953},{0.980285, 1.675770, -0.006077},{
      0.978940, 1.677115, -0.006077},{0.978337, 1.676285, -0.006953}}],
    Polygon[{{0.980285, 1.675770, -0.006077},{0.980993, 1.676285, -0.005052},{
      0.979455, 1.677823, -0.005052},{0.978940, 1.677115, -0.006077}}],
    Polygon[{{0.980993, 1.676285, -0.005052},{0.981563, 1.676699, -0.003902},{
      0.979869, 1.678393, -0.003902},{0.979455, 1.677823, -0.005052}}],
    Polygon[{{0.981563, 1.676699, -0.003902},{0.981981, 1.677002, -0.002656},{
      0.980172, 1.678811, -0.002656},{0.979869, 1.678393, -0.003902}}],
    Polygon[{{0.981981, 1.677002, -0.002656},{0.982235, 1.677188, -0.001344},{
      0.980358, 1.679065, -0.001344},{0.980172, 1.678811, -0.002656}}],
    Polygon[{{0.982235, 1.677188, -0.001344},{0.982321, 1.677250, 0.000000},{
      0.980420, 1.679151, 0.000000},{0.980358, 1.679065, -0.001344}}],
    Polygon[{{0.982321, 1.677250, 0.000000},{0.982235, 1.677188, 0.001344},{
      0.980358, 1.679065, 0.001344},{0.980420, 1.679151, 0.000000}}],
    Polygon[{{0.982235, 1.677188, 0.001344},{0.981981, 1.677002, 0.002656},{
      0.980172, 1.678811, 0.002656},{0.980358, 1.679065, 0.001344}}],
    Polygon[{{0.981981, 1.677002, 0.002656},{0.981563, 1.676699, 0.003902},{
      0.979869, 1.678393, 0.003902},{0.980172, 1.678811, 0.002656}}],
    Polygon[{{0.981563, 1.676699, 0.003902},{0.980993, 1.676285, 0.005052},{
      0.979455, 1.677823, 0.005052},{0.979869, 1.678393, 0.003902}}],
    Polygon[{{0.980993, 1.676285, 0.005052},{0.980285, 1.675770, 0.006077},{
      0.978940, 1.677115, 0.006077},{0.979455, 1.677823, 0.005052}}],
    Polygon[{{0.980285, 1.675770, 0.006077},{0.979455, 1.675167, 0.006953},{
      0.978337, 1.676285, 0.006953},{0.978940, 1.677115, 0.006077}}],
    Polygon[{{0.979455, 1.675167, 0.006953},{0.978525, 1.674491, 0.007658},{
      0.977661, 1.675355, 0.007658},{0.978337, 1.676285, 0.006953}}],
    Polygon[{{0.978525, 1.674491, 0.007658},{0.977517, 1.673759, 0.008174},{
      0.976929, 1.674347, 0.008174},{0.977661, 1.675355, 0.007658}}],
    Polygon[{{0.977517, 1.673759, 0.008174},{0.976456, 1.672988, 0.008489},{
      0.976158, 1.673286, 0.008489},{0.976929, 1.674347, 0.008174}}],
    Polygon[{{0.976158, 1.673286, -0.008489},{0.976929, 1.674347, -0.008174},{
      0.976189, 1.674724, -0.008174},{0.975783, 1.673477, -0.008489}}],
    Polygon[{{0.976929, 1.674347, -0.008174},{0.977661, 1.675355, -0.007658},{
      0.976574, 1.675909, -0.007658},{0.976189, 1.674724, -0.008174}}],
    Polygon[{{0.977661, 1.675355, -0.007658},{0.978337, 1.676285, -0.006953},{
      0.976929, 1.677002, -0.006953},{0.976574, 1.675909, -0.007658}}],
    Polygon[{{0.978337, 1.676285, -0.006953},{0.978940, 1.677115, -0.006077},{
      0.977246, 1.677978, -0.006077},{0.976929, 1.677002, -0.006953}}],
    Polygon[{{0.978940, 1.677115, -0.006077},{0.979455, 1.677823, -0.005052},{
      0.977517, 1.678811, -0.005052},{0.977246, 1.677978, -0.006077}}],
    Polygon[{{0.979455, 1.677823, -0.005052},{0.979869, 1.678393, -0.003902},{
      0.977734, 1.679481, -0.003902},{0.977517, 1.678811, -0.005052}}],
    Polygon[{{0.979869, 1.678393, -0.003902},{0.980172, 1.678811, -0.002656},{
      0.977894, 1.679972, -0.002656},{0.977734, 1.679481, -0.003902}}],
    Polygon[{{0.980172, 1.678811, -0.002656},{0.980358, 1.679065, -0.001344},{
      0.977991, 1.680271, -0.001344},{0.977894, 1.679972, -0.002656}}],
    Polygon[{{0.980358, 1.679065, -0.001344},{0.980420, 1.679151, 0.000000},{
      0.978024, 1.680372, 0.000000},{0.977991, 1.680271, -0.001344}}],
    Polygon[{{0.980420, 1.679151, 0.000000},{0.980358, 1.679065, 0.001344},{
      0.977991, 1.680271, 0.001344},{0.978024, 1.680372, 0.000000}}],
    Polygon[{{0.980358, 1.679065, 0.001344},{0.980172, 1.678811, 0.002656},{
      0.977894, 1.679972, 0.002656},{0.977991, 1.680271, 0.001344}}],
    Polygon[{{0.980172, 1.678811, 0.002656},{0.979869, 1.678393, 0.003902},{
      0.977734, 1.679481, 0.003902},{0.977894, 1.679972, 0.002656}}],
    Polygon[{{0.979869, 1.678393, 0.003902},{0.979455, 1.677823, 0.005052},{
      0.977517, 1.678811, 0.005052},{0.977734, 1.679481, 0.003902}}],
    Polygon[{{0.979455, 1.677823, 0.005052},{0.978940, 1.677115, 0.006077},{
      0.977246, 1.677978, 0.006077},{0.977517, 1.678811, 0.005052}}],
    Polygon[{{0.978940, 1.677115, 0.006077},{0.978337, 1.676285, 0.006953},{
      0.976929, 1.677002, 0.006953},{0.977246, 1.677978, 0.006077}}],
    Polygon[{{0.978337, 1.676285, 0.006953},{0.977661, 1.675355, 0.007658},{
      0.976574, 1.675909, 0.007658},{0.976929, 1.677002, 0.006953}}],
    Polygon[{{0.977661, 1.675355, 0.007658},{0.976929, 1.674347, 0.008174},{
      0.976189, 1.674724, 0.008174},{0.976574, 1.675909, 0.007658}}],
    Polygon[{{0.976929, 1.674347, 0.008174},{0.976158, 1.673286, 0.008489},{
      0.975783, 1.673477, 0.008489},{0.976189, 1.674724, 0.008174}}],
    Polygon[{{0.975783, 1.673477, -0.008489},{0.976189, 1.674724, -0.008174},{
      0.975368, 1.674854, -0.008174},{0.975368, 1.673542, -0.008489}}],
    Polygon[{{0.976189, 1.674724, -0.008174},{0.976574, 1.675909, -0.007658},{
      0.975368, 1.676100, -0.007658},{0.975368, 1.674854, -0.008174}}],
    Polygon[{{0.976574, 1.675909, -0.007658},{0.976929, 1.677002, -0.006953},{
      0.975368, 1.677250, -0.006953},{0.975368, 1.676100, -0.007658}}],
    Polygon[{{0.976929, 1.677002, -0.006953},{0.977246, 1.677978, -0.006077},{
      0.975368, 1.678275, -0.006077},{0.975368, 1.677250, -0.006953}}],
    Polygon[{{0.977246, 1.677978, -0.006077},{0.977517, 1.678811, -0.005052},{
      0.975368, 1.679151, -0.005052},{0.975368, 1.678275, -0.006077}}],
    Polygon[{{0.977517, 1.678811, -0.005052},{0.977734, 1.679481, -0.003902},{
      0.975368, 1.679856, -0.003902},{0.975368, 1.679151, -0.005052}}],
    Polygon[{{0.977734, 1.679481, -0.003902},{0.977894, 1.679972, -0.002656},{
      0.975368, 1.680372, -0.002656},{0.975368, 1.679856, -0.003902}}],
    Polygon[{{0.977894, 1.679972, -0.002656},{0.977991, 1.680271, -0.001344},{
      0.975368, 1.680687, -0.001344},{0.975368, 1.680372, -0.002656}}],
    Polygon[{{0.977991, 1.680271, -0.001344},{0.978024, 1.680372, 0.000000},{
      0.975368, 1.680792, 0.000000},{0.975368, 1.680687, -0.001344}}],
    Polygon[{{0.978024, 1.680372, 0.000000},{0.977991, 1.680271, 0.001344},{
      0.975368, 1.680687, 0.001344},{0.975368, 1.680792, 0.000000}}],
    Polygon[{{0.977991, 1.680271, 0.001344},{0.977894, 1.679972, 0.002656},{
      0.975368, 1.680372, 0.002656},{0.975368, 1.680687, 0.001344}}],
    Polygon[{{0.977894, 1.679972, 0.002656},{0.977734, 1.679481, 0.003902},{
      0.975368, 1.679856, 0.003902},{0.975368, 1.680372, 0.002656}}],
    Polygon[{{0.977734, 1.679481, 0.003902},{0.977517, 1.678811, 0.005052},{
      0.975368, 1.679151, 0.005052},{0.975368, 1.679856, 0.003902}}],
    Polygon[{{0.977517, 1.678811, 0.005052},{0.977246, 1.677978, 0.006077},{
      0.975368, 1.678275, 0.006077},{0.975368, 1.679151, 0.005052}}],
    Polygon[{{0.977246, 1.677978, 0.006077},{0.976929, 1.677002, 0.006953},{
      0.975368, 1.677250, 0.006953},{0.975368, 1.678275, 0.006077}}],
    Polygon[{{0.976929, 1.677002, 0.006953},{0.976574, 1.675909, 0.007658},{
      0.975368, 1.676100, 0.007658},{0.975368, 1.677250, 0.006953}}],
    Polygon[{{0.976574, 1.675909, 0.007658},{0.976189, 1.674724, 0.008174},{
      0.975368, 1.674854, 0.008174},{0.975368, 1.676100, 0.007658}}],
    Polygon[{{0.976189, 1.674724, 0.008174},{0.975783, 1.673477, 0.008489},{
      0.975368, 1.673542, 0.008489},{0.975368, 1.674854, 0.008174}}],
    Polygon[{{0.975368, 1.673542, -0.008489},{0.975368, 1.674854, -0.008174},{
      0.974547, 1.674724, -0.008174},{0.974953, 1.673477, -0.008489}}],
    Polygon[{{0.975368, 1.674854, -0.008174},{0.975368, 1.676100, -0.007658},{
      0.974162, 1.675909, -0.007658},{0.974547, 1.674724, -0.008174}}],
    Polygon[{{0.975368, 1.676100, -0.007658},{0.975368, 1.677250, -0.006953},{
      0.973807, 1.677002, -0.006953},{0.974162, 1.675909, -0.007658}}],
    Polygon[{{0.975368, 1.677250, -0.006953},{0.975368, 1.678275, -0.006077},{
      0.973490, 1.677978, -0.006077},{0.973807, 1.677002, -0.006953}}],
    Polygon[{{0.975368, 1.678275, -0.006077},{0.975368, 1.679151, -0.005052},{
      0.973219, 1.678811, -0.005052},{0.973490, 1.677978, -0.006077}}],
    Polygon[{{0.975368, 1.679151, -0.005052},{0.975368, 1.679856, -0.003902},{
      0.973002, 1.679481, -0.003902},{0.973219, 1.678811, -0.005052}}],
    Polygon[{{0.975368, 1.679856, -0.003902},{0.975368, 1.680372, -0.002656},{
      0.972842, 1.679972, -0.002656},{0.973002, 1.679481, -0.003902}}],
    Polygon[{{0.975368, 1.680372, -0.002656},{0.975368, 1.680687, -0.001344},{
      0.972745, 1.680271, -0.001344},{0.972842, 1.679972, -0.002656}}],
    Polygon[{{0.975368, 1.680687, -0.001344},{0.975368, 1.680792, 0.000000},{
      0.972712, 1.680372, 0.000000},{0.972745, 1.680271, -0.001344}}],
    Polygon[{{0.975368, 1.680792, 0.000000},{0.975368, 1.680687, 0.001344},{
      0.972745, 1.680271, 0.001344},{0.972712, 1.680372, 0.000000}}],
    Polygon[{{0.975368, 1.680687, 0.001344},{0.975368, 1.680372, 0.002656},{
      0.972842, 1.679972, 0.002656},{0.972745, 1.680271, 0.001344}}],
    Polygon[{{0.975368, 1.680372, 0.002656},{0.975368, 1.679856, 0.003902},{
      0.973002, 1.679481, 0.003902},{0.972842, 1.679972, 0.002656}}],
    Polygon[{{0.975368, 1.679856, 0.003902},{0.975368, 1.679151, 0.005052},{
      0.973219, 1.678811, 0.005052},{0.973002, 1.679481, 0.003902}}],
    Polygon[{{0.975368, 1.679151, 0.005052},{0.975368, 1.678275, 0.006077},{
      0.973490, 1.677978, 0.006077},{0.973219, 1.678811, 0.005052}}],
    Polygon[{{0.975368, 1.678275, 0.006077},{0.975368, 1.677250, 0.006953},{
      0.973807, 1.677002, 0.006953},{0.973490, 1.677978, 0.006077}}],
    Polygon[{{0.975368, 1.677250, 0.006953},{0.975368, 1.676100, 0.007658},{
      0.974162, 1.675909, 0.007658},{0.973807, 1.677002, 0.006953}}],
    Polygon[{{0.975368, 1.676100, 0.007658},{0.975368, 1.674854, 0.008174},{
      0.974547, 1.674724, 0.008174},{0.974162, 1.675909, 0.007658}}],
    Polygon[{{0.975368, 1.674854, 0.008174},{0.975368, 1.673542, 0.008489},{
      0.974953, 1.673477, 0.008489},{0.974547, 1.674724, 0.008174}}],
    Polygon[{{0.974953, 1.673477, -0.008489},{0.974547, 1.674724, -0.008174},{
      0.973807, 1.674347, -0.008174},{0.974578, 1.673286, -0.008489}}],
    Polygon[{{0.974547, 1.674724, -0.008174},{0.974162, 1.675909, -0.007658},{
      0.973075, 1.675355, -0.007658},{0.973807, 1.674347, -0.008174}}],
    Polygon[{{0.974162, 1.675909, -0.007658},{0.973807, 1.677002, -0.006953},{
      0.972399, 1.676285, -0.006953},{0.973075, 1.675355, -0.007658}}],
    Polygon[{{0.973807, 1.677002, -0.006953},{0.973490, 1.677978, -0.006077},{
      0.971796, 1.677115, -0.006077},{0.972399, 1.676285, -0.006953}}],
    Polygon[{{0.973490, 1.677978, -0.006077},{0.973219, 1.678811, -0.005052},{
      0.971281, 1.677823, -0.005052},{0.971796, 1.677115, -0.006077}}],
    Polygon[{{0.973219, 1.678811, -0.005052},{0.973002, 1.679481, -0.003902},{
      0.970867, 1.678393, -0.003902},{0.971281, 1.677823, -0.005052}}],
    Polygon[{{0.973002, 1.679481, -0.003902},{0.972842, 1.679972, -0.002656},{
      0.970564, 1.678811, -0.002656},{0.970867, 1.678393, -0.003902}}],
    Polygon[{{0.972842, 1.679972, -0.002656},{0.972745, 1.680271, -0.001344},{
      0.970379, 1.679065, -0.001344},{0.970564, 1.678811, -0.002656}}],
    Polygon[{{0.972745, 1.680271, -0.001344},{0.972712, 1.680372, 0.000000},{
      0.970316, 1.679151, 0.000000},{0.970379, 1.679065, -0.001344}}],
    Polygon[{{0.972712, 1.680372, 0.000000},{0.972745, 1.680271, 0.001344},{
      0.970379, 1.679065, 0.001344},{0.970316, 1.679151, 0.000000}}],
    Polygon[{{0.972745, 1.680271, 0.001344},{0.972842, 1.679972, 0.002656},{
      0.970564, 1.678811, 0.002656},{0.970379, 1.679065, 0.001344}}],
    Polygon[{{0.972842, 1.679972, 0.002656},{0.973002, 1.679481, 0.003902},{
      0.970867, 1.678393, 0.003902},{0.970564, 1.678811, 0.002656}}],
    Polygon[{{0.973002, 1.679481, 0.003902},{0.973219, 1.678811, 0.005052},{
      0.971281, 1.677823, 0.005052},{0.970867, 1.678393, 0.003902}}],
    Polygon[{{0.973219, 1.678811, 0.005052},{0.973490, 1.677978, 0.006077},{
      0.971796, 1.677115, 0.006077},{0.971281, 1.677823, 0.005052}}],
    Polygon[{{0.973490, 1.677978, 0.006077},{0.973807, 1.677002, 0.006953},{
      0.972399, 1.676285, 0.006953},{0.971796, 1.677115, 0.006077}}],
    Polygon[{{0.973807, 1.677002, 0.006953},{0.974162, 1.675909, 0.007658},{
      0.973075, 1.675355, 0.007658},{0.972399, 1.676285, 0.006953}}],
    Polygon[{{0.974162, 1.675909, 0.007658},{0.974547, 1.674724, 0.008174},{
      0.973807, 1.674347, 0.008174},{0.973075, 1.675355, 0.007658}}],
    Polygon[{{0.974547, 1.674724, 0.008174},{0.974953, 1.673477, 0.008489},{
      0.974578, 1.673286, 0.008489},{0.973807, 1.674347, 0.008174}}],
    Polygon[{{0.974578, 1.673286, -0.008489},{0.973807, 1.674347, -0.008174},{
      0.973219, 1.673759, -0.008174},{0.974280, 1.672988, -0.008489}}],
    Polygon[{{0.973807, 1.674347, -0.008174},{0.973075, 1.675355, -0.007658},{
      0.972211, 1.674491, -0.007658},{0.973219, 1.673759, -0.008174}}],
    Polygon[{{0.973075, 1.675355, -0.007658},{0.972399, 1.676285, -0.006953},{
      0.971281, 1.675167, -0.006953},{0.972211, 1.674491, -0.007658}}],
    Polygon[{{0.972399, 1.676285, -0.006953},{0.971796, 1.677115, -0.006077},{
      0.970451, 1.675770, -0.006077},{0.971281, 1.675167, -0.006953}}],
    Polygon[{{0.971796, 1.677115, -0.006077},{0.971281, 1.677823, -0.005052},{
      0.969743, 1.676285, -0.005052},{0.970451, 1.675770, -0.006077}}],
    Polygon[{{0.971281, 1.677823, -0.005052},{0.970867, 1.678393, -0.003902},{
      0.969173, 1.676699, -0.003902},{0.969743, 1.676285, -0.005052}}],
    Polygon[{{0.970867, 1.678393, -0.003902},{0.970564, 1.678811, -0.002656},{
      0.968755, 1.677002, -0.002656},{0.969173, 1.676699, -0.003902}}],
    Polygon[{{0.970564, 1.678811, -0.002656},{0.970379, 1.679065, -0.001344},{
      0.968501, 1.677188, -0.001344},{0.968755, 1.677002, -0.002656}}],
    Polygon[{{0.970379, 1.679065, -0.001344},{0.970316, 1.679151, 0.000000},{
      0.968415, 1.677250, 0.000000},{0.968501, 1.677188, -0.001344}}],
    Polygon[{{0.970316, 1.679151, 0.000000},{0.970379, 1.679065, 0.001344},{
      0.968501, 1.677188, 0.001344},{0.968415, 1.677250, 0.000000}}],
    Polygon[{{0.970379, 1.679065, 0.001344},{0.970564, 1.678811, 0.002656},{
      0.968755, 1.677002, 0.002656},{0.968501, 1.677188, 0.001344}}],
    Polygon[{{0.970564, 1.678811, 0.002656},{0.970867, 1.678393, 0.003902},{
      0.969173, 1.676699, 0.003902},{0.968755, 1.677002, 0.002656}}],
    Polygon[{{0.970867, 1.678393, 0.003902},{0.971281, 1.677823, 0.005052},{
      0.969743, 1.676285, 0.005052},{0.969173, 1.676699, 0.003902}}],
    Polygon[{{0.971281, 1.677823, 0.005052},{0.971796, 1.677115, 0.006077},{
      0.970451, 1.675770, 0.006077},{0.969743, 1.676285, 0.005052}}],
    Polygon[{{0.971796, 1.677115, 0.006077},{0.972399, 1.676285, 0.006953},{
      0.971281, 1.675167, 0.006953},{0.970451, 1.675770, 0.006077}}],
    Polygon[{{0.972399, 1.676285, 0.006953},{0.973075, 1.675355, 0.007658},{
      0.972211, 1.674491, 0.007658},{0.971281, 1.675167, 0.006953}}],
    Polygon[{{0.973075, 1.675355, 0.007658},{0.973807, 1.674347, 0.008174},{
      0.973219, 1.673759, 0.008174},{0.972211, 1.674491, 0.007658}}],
    Polygon[{{0.973807, 1.674347, 0.008174},{0.974578, 1.673286, 0.008489},{
      0.974280, 1.672988, 0.008489},{0.973219, 1.673759, 0.008174}}],
    Polygon[{{0.974280, 1.672988, -0.008489},{0.973219, 1.673759, -0.008174},{
      0.972842, 1.673019, -0.008174},{0.974089, 1.672614, -0.008489}}],
    Polygon[{{0.973219, 1.673759, -0.008174},{0.972211, 1.674491, -0.007658},{
      0.971657, 1.673404, -0.007658},{0.972842, 1.673019, -0.008174}}],
    Polygon[{{0.972211, 1.674491, -0.007658},{0.971281, 1.675167, -0.006953},{
      0.970564, 1.673759, -0.006953},{0.971657, 1.673404, -0.007658}}],
    Polygon[{{0.971281, 1.675167, -0.006953},{0.970451, 1.675770, -0.006077},{
      0.969588, 1.674076, -0.006077},{0.970564, 1.673759, -0.006953}}],
    Polygon[{{0.970451, 1.675770, -0.006077},{0.969743, 1.676285, -0.005052},{
      0.968755, 1.674347, -0.005052},{0.969588, 1.674076, -0.006077}}],
    Polygon[{{0.969743, 1.676285, -0.005052},{0.969173, 1.676699, -0.003902},{
      0.968085, 1.674564, -0.003902},{0.968755, 1.674347, -0.005052}}],
    Polygon[{{0.969173, 1.676699, -0.003902},{0.968755, 1.677002, -0.002656},{
      0.967594, 1.674724, -0.002656},{0.968085, 1.674564, -0.003902}}],
    Polygon[{{0.968755, 1.677002, -0.002656},{0.968501, 1.677188, -0.001344},{
      0.967295, 1.674821, -0.001344},{0.967594, 1.674724, -0.002656}}],
    Polygon[{{0.968501, 1.677188, -0.001344},{0.968415, 1.677250, 0.000000},{
      0.967194, 1.674854, 0.000000},{0.967295, 1.674821, -0.001344}}],
    Polygon[{{0.968415, 1.677250, 0.000000},{0.968501, 1.677188, 0.001344},{
      0.967295, 1.674821, 0.001344},{0.967194, 1.674854, 0.000000}}],
    Polygon[{{0.968501, 1.677188, 0.001344},{0.968755, 1.677002, 0.002656},{
      0.967594, 1.674724, 0.002656},{0.967295, 1.674821, 0.001344}}],
    Polygon[{{0.968755, 1.677002, 0.002656},{0.969173, 1.676699, 0.003902},{
      0.968085, 1.674564, 0.003902},{0.967594, 1.674724, 0.002656}}],
    Polygon[{{0.969173, 1.676699, 0.003902},{0.969743, 1.676285, 0.005052},{
      0.968755, 1.674347, 0.005052},{0.968085, 1.674564, 0.003902}}],
    Polygon[{{0.969743, 1.676285, 0.005052},{0.970451, 1.675770, 0.006077},{
      0.969588, 1.674076, 0.006077},{0.968755, 1.674347, 0.005052}}],
    Polygon[{{0.970451, 1.675770, 0.006077},{0.971281, 1.675167, 0.006953},{
      0.970564, 1.673759, 0.006953},{0.969588, 1.674076, 0.006077}}],
    Polygon[{{0.971281, 1.675167, 0.006953},{0.972211, 1.674491, 0.007658},{
      0.971657, 1.673404, 0.007658},{0.970564, 1.673759, 0.006953}}],
    Polygon[{{0.972211, 1.674491, 0.007658},{0.973219, 1.673759, 0.008174},{
      0.972842, 1.673019, 0.008174},{0.971657, 1.673404, 0.007658}}],
    Polygon[{{0.973219, 1.673759, 0.008174},{0.974280, 1.672988, 0.008489},{
      0.974089, 1.672614, 0.008489},{0.972842, 1.673019, 0.008174}}],
    Polygon[{{0.974089, 1.672614, -0.008489},{0.972842, 1.673019, -0.008174},{
      0.972712, 1.672198, -0.008174},{0.974024, 1.672198, -0.008489}}],
    Polygon[{{0.972842, 1.673019, -0.008174},{0.971657, 1.673404, -0.007658},{
      0.971466, 1.672198, -0.007658},{0.972712, 1.672198, -0.008174}}],
    Polygon[{{0.971657, 1.673404, -0.007658},{0.970564, 1.673759, -0.006953},{
      0.970316, 1.672198, -0.006953},{0.971466, 1.672198, -0.007658}}],
    Polygon[{{0.970564, 1.673759, -0.006953},{0.969588, 1.674076, -0.006077},{
      0.969291, 1.672198, -0.006077},{0.970316, 1.672198, -0.006953}}],
    Polygon[{{0.969588, 1.674076, -0.006077},{0.968755, 1.674347, -0.005052},{
      0.968415, 1.672198, -0.005052},{0.969291, 1.672198, -0.006077}}],
    Polygon[{{0.968755, 1.674347, -0.005052},{0.968085, 1.674564, -0.003902},{
      0.967710, 1.672198, -0.003902},{0.968415, 1.672198, -0.005052}}],
    Polygon[{{0.968085, 1.674564, -0.003902},{0.967594, 1.674724, -0.002656},{
      0.967194, 1.672198, -0.002656},{0.967710, 1.672198, -0.003902}}],
    Polygon[{{0.967594, 1.674724, -0.002656},{0.967295, 1.674821, -0.001344},{
      0.966879, 1.672198, -0.001344},{0.967194, 1.672198, -0.002656}}],
    Polygon[{{0.967295, 1.674821, -0.001344},{0.967194, 1.674854, 0.000000},{
      0.966774, 1.672198, 0.000000},{0.966879, 1.672198, -0.001344}}],
    Polygon[{{0.967194, 1.674854, 0.000000},{0.967295, 1.674821, 0.001344},{
      0.966879, 1.672198, 0.001344},{0.966774, 1.672198, 0.000000}}],
    Polygon[{{0.967295, 1.674821, 0.001344},{0.967594, 1.674724, 0.002656},{
      0.967194, 1.672198, 0.002656},{0.966879, 1.672198, 0.001344}}],
    Polygon[{{0.967594, 1.674724, 0.002656},{0.968085, 1.674564, 0.003902},{
      0.967710, 1.672198, 0.003902},{0.967194, 1.672198, 0.002656}}],
    Polygon[{{0.968085, 1.674564, 0.003902},{0.968755, 1.674347, 0.005052},{
      0.968415, 1.672198, 0.005052},{0.967710, 1.672198, 0.003902}}],
    Polygon[{{0.968755, 1.674347, 0.005052},{0.969588, 1.674076, 0.006077},{
      0.969291, 1.672198, 0.006077},{0.968415, 1.672198, 0.005052}}],
    Polygon[{{0.969588, 1.674076, 0.006077},{0.970564, 1.673759, 0.006953},{
      0.970316, 1.672198, 0.006953},{0.969291, 1.672198, 0.006077}}],
    Polygon[{{0.970564, 1.673759, 0.006953},{0.971657, 1.673404, 0.007658},{
      0.971466, 1.672198, 0.007658},{0.970316, 1.672198, 0.006953}}],
    Polygon[{{0.971657, 1.673404, 0.007658},{0.972842, 1.673019, 0.008174},{
      0.972712, 1.672198, 0.008174},{0.971466, 1.672198, 0.007658}}],
    Polygon[{{0.972842, 1.673019, 0.008174},{0.974089, 1.672614, 0.008489},{
      0.974024, 1.672198, 0.008489},{0.972712, 1.672198, 0.008174}}],
    Polygon[{{0.974024, 1.672198, -0.008489},{0.972712, 1.672198, -0.008174},{
      0.972842, 1.671377, -0.008174},{0.974089, 1.671782, -0.008489}}],
    Polygon[{{0.972712, 1.672198, -0.008174},{0.971466, 1.672198, -0.007658},{
      0.971657, 1.670992, -0.007658},{0.972842, 1.671377, -0.008174}}],
    Polygon[{{0.971466, 1.672198, -0.007658},{0.970316, 1.672198, -0.006953},{
      0.970564, 1.670637, -0.006953},{0.971657, 1.670992, -0.007658}}],
    Polygon[{{0.970316, 1.672198, -0.006953},{0.969291, 1.672198, -0.006077},{
      0.969588, 1.670320, -0.006077},{0.970564, 1.670637, -0.006953}}],
    Polygon[{{0.969291, 1.672198, -0.006077},{0.968415, 1.672198, -0.005052},{
      0.968755, 1.670049, -0.005052},{0.969588, 1.670320, -0.006077}}],
    Polygon[{{0.968415, 1.672198, -0.005052},{0.967710, 1.672198, -0.003902},{
      0.968085, 1.669832, -0.003902},{0.968755, 1.670049, -0.005052}}],
    Polygon[{{0.967710, 1.672198, -0.003902},{0.967194, 1.672198, -0.002656},{
      0.967594, 1.669672, -0.002656},{0.968085, 1.669832, -0.003902}}],
    Polygon[{{0.967194, 1.672198, -0.002656},{0.966879, 1.672198, -0.001344},{
      0.967295, 1.669575, -0.001344},{0.967594, 1.669672, -0.002656}}],
    Polygon[{{0.966879, 1.672198, -0.001344},{0.966774, 1.672198, 0.000000},{
      0.967194, 1.669542, 0.000000},{0.967295, 1.669575, -0.001344}}],
    Polygon[{{0.966774, 1.672198, 0.000000},{0.966879, 1.672198, 0.001344},{
      0.967295, 1.669575, 0.001344},{0.967194, 1.669542, 0.000000}}],
    Polygon[{{0.966879, 1.672198, 0.001344},{0.967194, 1.672198, 0.002656},{
      0.967594, 1.669672, 0.002656},{0.967295, 1.669575, 0.001344}}],
    Polygon[{{0.967194, 1.672198, 0.002656},{0.967710, 1.672198, 0.003902},{
      0.968085, 1.669832, 0.003902},{0.967594, 1.669672, 0.002656}}],
    Polygon[{{0.967710, 1.672198, 0.003902},{0.968415, 1.672198, 0.005052},{
      0.968755, 1.670049, 0.005052},{0.968085, 1.669832, 0.003902}}],
    Polygon[{{0.968415, 1.672198, 0.005052},{0.969291, 1.672198, 0.006077},{
      0.969588, 1.670320, 0.006077},{0.968755, 1.670049, 0.005052}}],
    Polygon[{{0.969291, 1.672198, 0.006077},{0.970316, 1.672198, 0.006953},{
      0.970564, 1.670637, 0.006953},{0.969588, 1.670320, 0.006077}}],
    Polygon[{{0.970316, 1.672198, 0.006953},{0.971466, 1.672198, 0.007658},{
      0.971657, 1.670992, 0.007658},{0.970564, 1.670637, 0.006953}}],
    Polygon[{{0.971466, 1.672198, 0.007658},{0.972712, 1.672198, 0.008174},{
      0.972842, 1.671377, 0.008174},{0.971657, 1.670992, 0.007658}}],
    Polygon[{{0.972712, 1.672198, 0.008174},{0.974024, 1.672198, 0.008489},{
      0.974089, 1.671782, 0.008489},{0.972842, 1.671377, 0.008174}}],
    Polygon[{{0.974089, 1.671782, -0.008489},{0.972842, 1.671377, -0.008174},{
      0.973219, 1.670637, -0.008174},{0.974280, 1.671408, -0.008489}}],
    Polygon[{{0.972842, 1.671377, -0.008174},{0.971657, 1.670992, -0.007658},{
      0.972211, 1.669905, -0.007658},{0.973219, 1.670637, -0.008174}}],
    Polygon[{{0.971657, 1.670992, -0.007658},{0.970564, 1.670637, -0.006953},{
      0.971281, 1.669229, -0.006953},{0.972211, 1.669905, -0.007658}}],
    Polygon[{{0.970564, 1.670637, -0.006953},{0.969588, 1.670320, -0.006077},{
      0.970451, 1.668626, -0.006077},{0.971281, 1.669229, -0.006953}}],
    Polygon[{{0.969588, 1.670320, -0.006077},{0.968755, 1.670049, -0.005052},{
      0.969743, 1.668111, -0.005052},{0.970451, 1.668626, -0.006077}}],
    Polygon[{{0.968755, 1.670049, -0.005052},{0.968085, 1.669832, -0.003902},{
      0.969173, 1.667697, -0.003902},{0.969743, 1.668111, -0.005052}}],
    Polygon[{{0.968085, 1.669832, -0.003902},{0.967594, 1.669672, -0.002656},{
      0.968755, 1.667394, -0.002656},{0.969173, 1.667697, -0.003902}}],
    Polygon[{{0.967594, 1.669672, -0.002656},{0.967295, 1.669575, -0.001344},{
      0.968501, 1.667209, -0.001344},{0.968755, 1.667394, -0.002656}}],
    Polygon[{{0.967295, 1.669575, -0.001344},{0.967194, 1.669542, 0.000000},{
      0.968415, 1.667146, 0.000000},{0.968501, 1.667209, -0.001344}}],
    Polygon[{{0.967194, 1.669542, 0.000000},{0.967295, 1.669575, 0.001344},{
      0.968501, 1.667209, 0.001344},{0.968415, 1.667146, 0.000000}}],
    Polygon[{{0.967295, 1.669575, 0.001344},{0.967594, 1.669672, 0.002656},{
      0.968755, 1.667394, 0.002656},{0.968501, 1.667209, 0.001344}}],
    Polygon[{{0.967594, 1.669672, 0.002656},{0.968085, 1.669832, 0.003902},{
      0.969173, 1.667697, 0.003902},{0.968755, 1.667394, 0.002656}}],
    Polygon[{{0.968085, 1.669832, 0.003902},{0.968755, 1.670049, 0.005052},{
      0.969743, 1.668111, 0.005052},{0.969173, 1.667697, 0.003902}}],
    Polygon[{{0.968755, 1.670049, 0.005052},{0.969588, 1.670320, 0.006077},{
      0.970451, 1.668626, 0.006077},{0.969743, 1.668111, 0.005052}}],
    Polygon[{{0.969588, 1.670320, 0.006077},{0.970564, 1.670637, 0.006953},{
      0.971281, 1.669229, 0.006953},{0.970451, 1.668626, 0.006077}}],
    Polygon[{{0.970564, 1.670637, 0.006953},{0.971657, 1.670992, 0.007658},{
      0.972211, 1.669905, 0.007658},{0.971281, 1.669229, 0.006953}}],
    Polygon[{{0.971657, 1.670992, 0.007658},{0.972842, 1.671377, 0.008174},{
      0.973219, 1.670637, 0.008174},{0.972211, 1.669905, 0.007658}}],
    Polygon[{{0.972842, 1.671377, 0.008174},{0.974089, 1.671782, 0.008489},{
      0.974280, 1.671408, 0.008489},{0.973219, 1.670637, 0.008174}}],
    Polygon[{{0.974280, 1.671408, -0.008489},{0.973219, 1.670637, -0.008174},{
      0.973807, 1.670049, -0.008174},{0.974578, 1.671110, -0.008489}}],
    Polygon[{{0.973219, 1.670637, -0.008174},{0.972211, 1.669905, -0.007658},{
      0.973075, 1.669041, -0.007658},{0.973807, 1.670049, -0.008174}}],
    Polygon[{{0.972211, 1.669905, -0.007658},{0.971281, 1.669229, -0.006953},{
      0.972399, 1.668111, -0.006953},{0.973075, 1.669041, -0.007658}}],
    Polygon[{{0.971281, 1.669229, -0.006953},{0.970451, 1.668626, -0.006077},{
      0.971796, 1.667281, -0.006077},{0.972399, 1.668111, -0.006953}}],
    Polygon[{{0.970451, 1.668626, -0.006077},{0.969743, 1.668111, -0.005052},{
      0.971281, 1.666573, -0.005052},{0.971796, 1.667281, -0.006077}}],
    Polygon[{{0.969743, 1.668111, -0.005052},{0.969173, 1.667697, -0.003902},{
      0.970867, 1.666003, -0.003902},{0.971281, 1.666573, -0.005052}}],
    Polygon[{{0.969173, 1.667697, -0.003902},{0.968755, 1.667394, -0.002656},{
      0.970564, 1.665585, -0.002656},{0.970867, 1.666003, -0.003902}}],
    Polygon[{{0.968755, 1.667394, -0.002656},{0.968501, 1.667209, -0.001344},{
      0.970379, 1.665331, -0.001344},{0.970564, 1.665585, -0.002656}}],
    Polygon[{{0.968501, 1.667209, -0.001344},{0.968415, 1.667146, 0.000000},{
      0.970316, 1.665245, 0.000000},{0.970379, 1.665331, -0.001344}}],
    Polygon[{{0.968415, 1.667146, 0.000000},{0.968501, 1.667209, 0.001344},{
      0.970379, 1.665331, 0.001344},{0.970316, 1.665245, 0.000000}}],
    Polygon[{{0.968501, 1.667209, 0.001344},{0.968755, 1.667394, 0.002656},{
      0.970564, 1.665585, 0.002656},{0.970379, 1.665331, 0.001344}}],
    Polygon[{{0.968755, 1.667394, 0.002656},{0.969173, 1.667697, 0.003902},{
      0.970867, 1.666003, 0.003902},{0.970564, 1.665585, 0.002656}}],
    Polygon[{{0.969173, 1.667697, 0.003902},{0.969743, 1.668111, 0.005052},{
      0.971281, 1.666573, 0.005052},{0.970867, 1.666003, 0.003902}}],
    Polygon[{{0.969743, 1.668111, 0.005052},{0.970451, 1.668626, 0.006077},{
      0.971796, 1.667281, 0.006077},{0.971281, 1.666573, 0.005052}}],
    Polygon[{{0.970451, 1.668626, 0.006077},{0.971281, 1.669229, 0.006953},{
      0.972399, 1.668111, 0.006953},{0.971796, 1.667281, 0.006077}}],
    Polygon[{{0.971281, 1.669229, 0.006953},{0.972211, 1.669905, 0.007658},{
      0.973075, 1.669041, 0.007658},{0.972399, 1.668111, 0.006953}}],
    Polygon[{{0.972211, 1.669905, 0.007658},{0.973219, 1.670637, 0.008174},{
      0.973807, 1.670049, 0.008174},{0.973075, 1.669041, 0.007658}}],
    Polygon[{{0.973219, 1.670637, 0.008174},{0.974280, 1.671408, 0.008489},{
      0.974578, 1.671110, 0.008489},{0.973807, 1.670049, 0.008174}}],
    Polygon[{{0.974578, 1.671110, -0.008489},{0.973807, 1.670049, -0.008174},{
      0.974547, 1.669672, -0.008174},{0.974953, 1.670919, -0.008489}}],
    Polygon[{{0.973807, 1.670049, -0.008174},{0.973075, 1.669041, -0.007658},{
      0.974162, 1.668487, -0.007658},{0.974547, 1.669672, -0.008174}}],
    Polygon[{{0.973075, 1.669041, -0.007658},{0.972399, 1.668111, -0.006953},{
      0.973807, 1.667394, -0.006953},{0.974162, 1.668487, -0.007658}}],
    Polygon[{{0.972399, 1.668111, -0.006953},{0.971796, 1.667281, -0.006077},{
      0.973490, 1.666418, -0.006077},{0.973807, 1.667394, -0.006953}}],
    Polygon[{{0.971796, 1.667281, -0.006077},{0.971281, 1.666573, -0.005052},{
      0.973219, 1.665585, -0.005052},{0.973490, 1.666418, -0.006077}}],
    Polygon[{{0.971281, 1.666573, -0.005052},{0.970867, 1.666003, -0.003902},{
      0.973002, 1.664915, -0.003902},{0.973219, 1.665585, -0.005052}}],
    Polygon[{{0.970867, 1.666003, -0.003902},{0.970564, 1.665585, -0.002656},{
      0.972842, 1.664424, -0.002656},{0.973002, 1.664915, -0.003902}}],
    Polygon[{{0.970564, 1.665585, -0.002656},{0.970379, 1.665331, -0.001344},{
      0.972745, 1.664125, -0.001344},{0.972842, 1.664424, -0.002656}}],
    Polygon[{{0.970379, 1.665331, -0.001344},{0.970316, 1.665245, 0.000000},{
      0.972712, 1.664024, 0.000000},{0.972745, 1.664125, -0.001344}}],
    Polygon[{{0.970316, 1.665245, 0.000000},{0.970379, 1.665331, 0.001344},{
      0.972745, 1.664125, 0.001344},{0.972712, 1.664024, 0.000000}}],
    Polygon[{{0.970379, 1.665331, 0.001344},{0.970564, 1.665585, 0.002656},{
      0.972842, 1.664424, 0.002656},{0.972745, 1.664125, 0.001344}}],
    Polygon[{{0.970564, 1.665585, 0.002656},{0.970867, 1.666003, 0.003902},{
      0.973002, 1.664915, 0.003902},{0.972842, 1.664424, 0.002656}}],
    Polygon[{{0.970867, 1.666003, 0.003902},{0.971281, 1.666573, 0.005052},{
      0.973219, 1.665585, 0.005052},{0.973002, 1.664915, 0.003902}}],
    Polygon[{{0.971281, 1.666573, 0.005052},{0.971796, 1.667281, 0.006077},{
      0.973490, 1.666418, 0.006077},{0.973219, 1.665585, 0.005052}}],
    Polygon[{{0.971796, 1.667281, 0.006077},{0.972399, 1.668111, 0.006953},{
      0.973807, 1.667394, 0.006953},{0.973490, 1.666418, 0.006077}}],
    Polygon[{{0.972399, 1.668111, 0.006953},{0.973075, 1.669041, 0.007658},{
      0.974162, 1.668487, 0.007658},{0.973807, 1.667394, 0.006953}}],
    Polygon[{{0.973075, 1.669041, 0.007658},{0.973807, 1.670049, 0.008174},{
      0.974547, 1.669672, 0.008174},{0.974162, 1.668487, 0.007658}}],
    Polygon[{{0.973807, 1.670049, 0.008174},{0.974578, 1.671110, 0.008489},{
      0.974953, 1.670919, 0.008489},{0.974547, 1.669672, 0.008174}}],
    Polygon[{{0.974953, 1.670919, -0.008489},{0.974547, 1.669672, -0.008174},{
      0.975368, 1.669542, -0.008174},{0.975368, 1.670853, -0.008489}}],
    Polygon[{{0.974547, 1.669672, -0.008174},{0.974162, 1.668487, -0.007658},{
      0.975368, 1.668296, -0.007658},{0.975368, 1.669542, -0.008174}}],
    Polygon[{{0.974162, 1.668487, -0.007658},{0.973807, 1.667394, -0.006953},{
      0.975368, 1.667146, -0.006953},{0.975368, 1.668296, -0.007658}}],
    Polygon[{{0.973807, 1.667394, -0.006953},{0.973490, 1.666418, -0.006077},{
      0.975368, 1.666121, -0.006077},{0.975368, 1.667146, -0.006953}}],
    Polygon[{{0.973490, 1.666418, -0.006077},{0.973219, 1.665585, -0.005052},{
      0.975368, 1.665245, -0.005052},{0.975368, 1.666121, -0.006077}}],
    Polygon[{{0.973219, 1.665585, -0.005052},{0.973002, 1.664915, -0.003902},{
      0.975368, 1.664540, -0.003902},{0.975368, 1.665245, -0.005052}}],
    Polygon[{{0.973002, 1.664915, -0.003902},{0.972842, 1.664424, -0.002656},{
      0.975368, 1.664024, -0.002656},{0.975368, 1.664540, -0.003902}}],
    Polygon[{{0.972842, 1.664424, -0.002656},{0.972745, 1.664125, -0.001344},{
      0.975368, 1.663709, -0.001344},{0.975368, 1.664024, -0.002656}}],
    Polygon[{{0.972745, 1.664125, -0.001344},{0.972712, 1.664024, 0.000000},{
      0.975368, 1.663604, 0.000000},{0.975368, 1.663709, -0.001344}}],
    Polygon[{{0.972712, 1.664024, 0.000000},{0.972745, 1.664125, 0.001344},{
      0.975368, 1.663709, 0.001344},{0.975368, 1.663604, 0.000000}}],
    Polygon[{{0.972745, 1.664125, 0.001344},{0.972842, 1.664424, 0.002656},{
      0.975368, 1.664024, 0.002656},{0.975368, 1.663709, 0.001344}}],
    Polygon[{{0.972842, 1.664424, 0.002656},{0.973002, 1.664915, 0.003902},{
      0.975368, 1.664540, 0.003902},{0.975368, 1.664024, 0.002656}}],
    Polygon[{{0.973002, 1.664915, 0.003902},{0.973219, 1.665585, 0.005052},{
      0.975368, 1.665245, 0.005052},{0.975368, 1.664540, 0.003902}}],
    Polygon[{{0.973219, 1.665585, 0.005052},{0.973490, 1.666418, 0.006077},{
      0.975368, 1.666121, 0.006077},{0.975368, 1.665245, 0.005052}}],
    Polygon[{{0.973490, 1.666418, 0.006077},{0.973807, 1.667394, 0.006953},{
      0.975368, 1.667146, 0.006953},{0.975368, 1.666121, 0.006077}}],
    Polygon[{{0.973807, 1.667394, 0.006953},{0.974162, 1.668487, 0.007658},{
      0.975368, 1.668296, 0.007658},{0.975368, 1.667146, 0.006953}}],
    Polygon[{{0.974162, 1.668487, 0.007658},{0.974547, 1.669672, 0.008174},{
      0.975368, 1.669542, 0.008174},{0.975368, 1.668296, 0.007658}}],
    Polygon[{{0.974547, 1.669672, 0.008174},{0.974953, 1.670919, 0.008489},{
      0.975368, 1.670853, 0.008489},{0.975368, 1.669542, 0.008174}}],
    Polygon[{{0.975368, 1.670853, -0.008489},{0.975368, 1.669542, -0.008174},{
      0.976189, 1.669672, -0.008174},{0.975783, 1.670919, -0.008489}}],
    Polygon[{{0.975368, 1.669542, -0.008174},{0.975368, 1.668296, -0.007658},{
      0.976574, 1.668487, -0.007658},{0.976189, 1.669672, -0.008174}}],
    Polygon[{{0.975368, 1.668296, -0.007658},{0.975368, 1.667146, -0.006953},{
      0.976929, 1.667394, -0.006953},{0.976574, 1.668487, -0.007658}}],
    Polygon[{{0.975368, 1.667146, -0.006953},{0.975368, 1.666121, -0.006077},{
      0.977246, 1.666418, -0.006077},{0.976929, 1.667394, -0.006953}}],
    Polygon[{{0.975368, 1.666121, -0.006077},{0.975368, 1.665245, -0.005052},{
      0.977517, 1.665585, -0.005052},{0.977246, 1.666418, -0.006077}}],
    Polygon[{{0.975368, 1.665245, -0.005052},{0.975368, 1.664540, -0.003902},{
      0.977734, 1.664915, -0.003902},{0.977517, 1.665585, -0.005052}}],
    Polygon[{{0.975368, 1.664540, -0.003902},{0.975368, 1.664024, -0.002656},{
      0.977894, 1.664424, -0.002656},{0.977734, 1.664915, -0.003902}}],
    Polygon[{{0.975368, 1.664024, -0.002656},{0.975368, 1.663709, -0.001344},{
      0.977991, 1.664125, -0.001344},{0.977894, 1.664424, -0.002656}}],
    Polygon[{{0.975368, 1.663709, -0.001344},{0.975368, 1.663604, 0.000000},{
      0.978024, 1.664024, 0.000000},{0.977991, 1.664125, -0.001344}}],
    Polygon[{{0.975368, 1.663604, 0.000000},{0.975368, 1.663709, 0.001344},{
      0.977991, 1.664125, 0.001344},{0.978024, 1.664024, 0.000000}}],
    Polygon[{{0.975368, 1.663709, 0.001344},{0.975368, 1.664024, 0.002656},{
      0.977894, 1.664424, 0.002656},{0.977991, 1.664125, 0.001344}}],
    Polygon[{{0.975368, 1.664024, 0.002656},{0.975368, 1.664540, 0.003902},{
      0.977734, 1.664915, 0.003902},{0.977894, 1.664424, 0.002656}}],
    Polygon[{{0.975368, 1.664540, 0.003902},{0.975368, 1.665245, 0.005052},{
      0.977517, 1.665585, 0.005052},{0.977734, 1.664915, 0.003902}}],
    Polygon[{{0.975368, 1.665245, 0.005052},{0.975368, 1.666121, 0.006077},{
      0.977246, 1.666418, 0.006077},{0.977517, 1.665585, 0.005052}}],
    Polygon[{{0.975368, 1.666121, 0.006077},{0.975368, 1.667146, 0.006953},{
      0.976929, 1.667394, 0.006953},{0.977246, 1.666418, 0.006077}}],
    Polygon[{{0.975368, 1.667146, 0.006953},{0.975368, 1.668296, 0.007658},{
      0.976574, 1.668487, 0.007658},{0.976929, 1.667394, 0.006953}}],
    Polygon[{{0.975368, 1.668296, 0.007658},{0.975368, 1.669542, 0.008174},{
      0.976189, 1.669672, 0.008174},{0.976574, 1.668487, 0.007658}}],
    Polygon[{{0.975368, 1.669542, 0.008174},{0.975368, 1.670853, 0.008489},{
      0.975783, 1.670919, 0.008489},{0.976189, 1.669672, 0.008174}}],
    Polygon[{{0.975783, 1.670919, -0.008489},{0.976189, 1.669672, -0.008174},{
      0.976929, 1.670049, -0.008174},{0.976158, 1.671110, -0.008489}}],
    Polygon[{{0.976189, 1.669672, -0.008174},{0.976574, 1.668487, -0.007658},{
      0.977661, 1.669041, -0.007658},{0.976929, 1.670049, -0.008174}}],
    Polygon[{{0.976574, 1.668487, -0.007658},{0.976929, 1.667394, -0.006953},{
      0.978337, 1.668111, -0.006953},{0.977661, 1.669041, -0.007658}}],
    Polygon[{{0.976929, 1.667394, -0.006953},{0.977246, 1.666418, -0.006077},{
      0.978940, 1.667281, -0.006077},{0.978337, 1.668111, -0.006953}}],
    Polygon[{{0.977246, 1.666418, -0.006077},{0.977517, 1.665585, -0.005052},{
      0.979455, 1.666573, -0.005052},{0.978940, 1.667281, -0.006077}}],
    Polygon[{{0.977517, 1.665585, -0.005052},{0.977734, 1.664915, -0.003902},{
      0.979869, 1.666003, -0.003902},{0.979455, 1.666573, -0.005052}}],
    Polygon[{{0.977734, 1.664915, -0.003902},{0.977894, 1.664424, -0.002656},{
      0.980172, 1.665585, -0.002656},{0.979869, 1.666003, -0.003902}}],
    Polygon[{{0.977894, 1.664424, -0.002656},{0.977991, 1.664125, -0.001344},{
      0.980358, 1.665331, -0.001344},{0.980172, 1.665585, -0.002656}}],
    Polygon[{{0.977991, 1.664125, -0.001344},{0.978024, 1.664024, 0.000000},{
      0.980420, 1.665245, 0.000000},{0.980358, 1.665331, -0.001344}}],
    Polygon[{{0.978024, 1.664024, 0.000000},{0.977991, 1.664125, 0.001344},{
      0.980358, 1.665331, 0.001344},{0.980420, 1.665245, 0.000000}}],
    Polygon[{{0.977991, 1.664125, 0.001344},{0.977894, 1.664424, 0.002656},{
      0.980172, 1.665585, 0.002656},{0.980358, 1.665331, 0.001344}}],
    Polygon[{{0.977894, 1.664424, 0.002656},{0.977734, 1.664915, 0.003902},{
      0.979869, 1.666003, 0.003902},{0.980172, 1.665585, 0.002656}}],
    Polygon[{{0.977734, 1.664915, 0.003902},{0.977517, 1.665585, 0.005052},{
      0.979455, 1.666573, 0.005052},{0.979869, 1.666003, 0.003902}}],
    Polygon[{{0.977517, 1.665585, 0.005052},{0.977246, 1.666418, 0.006077},{
      0.978940, 1.667281, 0.006077},{0.979455, 1.666573, 0.005052}}],
    Polygon[{{0.977246, 1.666418, 0.006077},{0.976929, 1.667394, 0.006953},{
      0.978337, 1.668111, 0.006953},{0.978940, 1.667281, 0.006077}}],
    Polygon[{{0.976929, 1.667394, 0.006953},{0.976574, 1.668487, 0.007658},{
      0.977661, 1.669041, 0.007658},{0.978337, 1.668111, 0.006953}}],
    Polygon[{{0.976574, 1.668487, 0.007658},{0.976189, 1.669672, 0.008174},{
      0.976929, 1.670049, 0.008174},{0.977661, 1.669041, 0.007658}}],
    Polygon[{{0.976189, 1.669672, 0.008174},{0.975783, 1.670919, 0.008489},{
      0.976158, 1.671110, 0.008489},{0.976929, 1.670049, 0.008174}}],
    Polygon[{{0.976158, 1.671110, -0.008489},{0.976929, 1.670049, -0.008174},{
      0.977517, 1.670637, -0.008174},{0.976456, 1.671408, -0.008489}}],
    Polygon[{{0.976929, 1.670049, -0.008174},{0.977661, 1.669041, -0.007658},{
      0.978525, 1.669905, -0.007658},{0.977517, 1.670637, -0.008174}}],
    Polygon[{{0.977661, 1.669041, -0.007658},{0.978337, 1.668111, -0.006953},{
      0.979455, 1.669229, -0.006953},{0.978525, 1.669905, -0.007658}}],
    Polygon[{{0.978337, 1.668111, -0.006953},{0.978940, 1.667281, -0.006077},{
      0.980285, 1.668626, -0.006077},{0.979455, 1.669229, -0.006953}}],
    Polygon[{{0.978940, 1.667281, -0.006077},{0.979455, 1.666573, -0.005052},{
      0.980993, 1.668111, -0.005052},{0.980285, 1.668626, -0.006077}}],
    Polygon[{{0.979455, 1.666573, -0.005052},{0.979869, 1.666003, -0.003902},{
      0.981563, 1.667697, -0.003902},{0.980993, 1.668111, -0.005052}}],
    Polygon[{{0.979869, 1.666003, -0.003902},{0.980172, 1.665585, -0.002656},{
      0.981981, 1.667394, -0.002656},{0.981563, 1.667697, -0.003902}}],
    Polygon[{{0.980172, 1.665585, -0.002656},{0.980358, 1.665331, -0.001344},{
      0.982235, 1.667209, -0.001344},{0.981981, 1.667394, -0.002656}}],
    Polygon[{{0.980358, 1.665331, -0.001344},{0.980420, 1.665245, 0.000000},{
      0.982321, 1.667146, 0.000000},{0.982235, 1.667209, -0.001344}}],
    Polygon[{{0.980420, 1.665245, 0.000000},{0.980358, 1.665331, 0.001344},{
      0.982235, 1.667209, 0.001344},{0.982321, 1.667146, 0.000000}}],
    Polygon[{{0.980358, 1.665331, 0.001344},{0.980172, 1.665585, 0.002656},{
      0.981981, 1.667394, 0.002656},{0.982235, 1.667209, 0.001344}}],
    Polygon[{{0.980172, 1.665585, 0.002656},{0.979869, 1.666003, 0.003902},{
      0.981563, 1.667697, 0.003902},{0.981981, 1.667394, 0.002656}}],
    Polygon[{{0.979869, 1.666003, 0.003902},{0.979455, 1.666573, 0.005052},{
      0.980993, 1.668111, 0.005052},{0.981563, 1.667697, 0.003902}}],
    Polygon[{{0.979455, 1.666573, 0.005052},{0.978940, 1.667281, 0.006077},{
      0.980285, 1.668626, 0.006077},{0.980993, 1.668111, 0.005052}}],
    Polygon[{{0.978940, 1.667281, 0.006077},{0.978337, 1.668111, 0.006953},{
      0.979455, 1.669229, 0.006953},{0.980285, 1.668626, 0.006077}}],
    Polygon[{{0.978337, 1.668111, 0.006953},{0.977661, 1.669041, 0.007658},{
      0.978525, 1.669905, 0.007658},{0.979455, 1.669229, 0.006953}}],
    Polygon[{{0.977661, 1.669041, 0.007658},{0.976929, 1.670049, 0.008174},{
      0.977517, 1.670637, 0.008174},{0.978525, 1.669905, 0.007658}}],
    Polygon[{{0.976929, 1.670049, 0.008174},{0.976158, 1.671110, 0.008489},{
      0.976456, 1.671408, 0.008489},{0.977517, 1.670637, 0.008174}}],
    Polygon[{{0.976456, 1.671408, -0.008489},{0.977517, 1.670637, -0.008174},{
      0.977894, 1.671377, -0.008174},{0.976647, 1.671782, -0.008489}}],
    Polygon[{{0.977517, 1.670637, -0.008174},{0.978525, 1.669905, -0.007658},{
      0.979079, 1.670992, -0.007658},{0.977894, 1.671377, -0.008174}}],
    Polygon[{{0.978525, 1.669905, -0.007658},{0.979455, 1.669229, -0.006953},{
      0.980172, 1.670637, -0.006953},{0.979079, 1.670992, -0.007658}}],
    Polygon[{{0.979455, 1.669229, -0.006953},{0.980285, 1.668626, -0.006077},{
      0.981148, 1.670320, -0.006077},{0.980172, 1.670637, -0.006953}}],
    Polygon[{{0.980285, 1.668626, -0.006077},{0.980993, 1.668111, -0.005052},{
      0.981981, 1.670049, -0.005052},{0.981148, 1.670320, -0.006077}}],
    Polygon[{{0.980993, 1.668111, -0.005052},{0.981563, 1.667697, -0.003902},{
      0.982651, 1.669832, -0.003902},{0.981981, 1.670049, -0.005052}}],
    Polygon[{{0.981563, 1.667697, -0.003902},{0.981981, 1.667394, -0.002656},{
      0.983142, 1.669672, -0.002656},{0.982651, 1.669832, -0.003902}}],
    Polygon[{{0.981981, 1.667394, -0.002656},{0.982235, 1.667209, -0.001344},{
      0.983441, 1.669575, -0.001344},{0.983142, 1.669672, -0.002656}}],
    Polygon[{{0.982235, 1.667209, -0.001344},{0.982321, 1.667146, 0.000000},{
      0.983542, 1.669542, 0.000000},{0.983441, 1.669575, -0.001344}}],
    Polygon[{{0.982321, 1.667146, 0.000000},{0.982235, 1.667209, 0.001344},{
      0.983441, 1.669575, 0.001344},{0.983542, 1.669542, 0.000000}}],
    Polygon[{{0.982235, 1.667209, 0.001344},{0.981981, 1.667394, 0.002656},{
      0.983142, 1.669672, 0.002656},{0.983441, 1.669575, 0.001344}}],
    Polygon[{{0.981981, 1.667394, 0.002656},{0.981563, 1.667697, 0.003902},{
      0.982651, 1.669832, 0.003902},{0.983142, 1.669672, 0.002656}}],
    Polygon[{{0.981563, 1.667697, 0.003902},{0.980993, 1.668111, 0.005052},{
      0.981981, 1.670049, 0.005052},{0.982651, 1.669832, 0.003902}}],
    Polygon[{{0.980993, 1.668111, 0.005052},{0.980285, 1.668626, 0.006077},{
      0.981148, 1.670320, 0.006077},{0.981981, 1.670049, 0.005052}}],
    Polygon[{{0.980285, 1.668626, 0.006077},{0.979455, 1.669229, 0.006953},{
      0.980172, 1.670637, 0.006953},{0.981148, 1.670320, 0.006077}}],
    Polygon[{{0.979455, 1.669229, 0.006953},{0.978525, 1.669905, 0.007658},{
      0.979079, 1.670992, 0.007658},{0.980172, 1.670637, 0.006953}}],
    Polygon[{{0.978525, 1.669905, 0.007658},{0.977517, 1.670637, 0.008174},{
      0.977894, 1.671377, 0.008174},{0.979079, 1.670992, 0.007658}}],
    Polygon[{{0.977517, 1.670637, 0.008174},{0.976456, 1.671408, 0.008489},{
      0.976647, 1.671782, 0.008489},{0.977894, 1.671377, 0.008174}}],
    Polygon[{{0.976647, 1.671782, -0.008489},{0.977894, 1.671377, -0.008174},{
      0.978024, 1.672198, -0.008174},{0.976712, 1.672198, -0.008489}}],
    Polygon[{{0.977894, 1.671377, -0.008174},{0.979079, 1.670992, -0.007658},{
      0.979270, 1.672198, -0.007658},{0.978024, 1.672198, -0.008174}}],
    Polygon[{{0.979079, 1.670992, -0.007658},{0.980172, 1.670637, -0.006953},{
      0.980420, 1.672198, -0.006953},{0.979270, 1.672198, -0.007658}}],
    Polygon[{{0.980172, 1.670637, -0.006953},{0.981148, 1.670320, -0.006077},{
      0.981445, 1.672198, -0.006077},{0.980420, 1.672198, -0.006953}}],
    Polygon[{{0.981148, 1.670320, -0.006077},{0.981981, 1.670049, -0.005052},{
      0.982321, 1.672198, -0.005052},{0.981445, 1.672198, -0.006077}}],
    Polygon[{{0.981981, 1.670049, -0.005052},{0.982651, 1.669832, -0.003902},{
      0.983026, 1.672198, -0.003902},{0.982321, 1.672198, -0.005052}}],
    Polygon[{{0.982651, 1.669832, -0.003902},{0.983142, 1.669672, -0.002656},{
      0.983542, 1.672198, -0.002656},{0.983026, 1.672198, -0.003902}}],
    Polygon[{{0.983142, 1.669672, -0.002656},{0.983441, 1.669575, -0.001344},{
      0.983857, 1.672198, -0.001344},{0.983542, 1.672198, -0.002656}}],
    Polygon[{{0.983441, 1.669575, -0.001344},{0.983542, 1.669542, 0.000000},{
      0.983962, 1.672198, 0.000000},{0.983857, 1.672198, -0.001344}}],
    Polygon[{{0.983542, 1.669542, 0.000000},{0.983441, 1.669575, 0.001344},{
      0.983857, 1.672198, 0.001344},{0.983962, 1.672198, 0.000000}}],
    Polygon[{{0.983441, 1.669575, 0.001344},{0.983142, 1.669672, 0.002656},{
      0.983542, 1.672198, 0.002656},{0.983857, 1.672198, 0.001344}}],
    Polygon[{{0.983142, 1.669672, 0.002656},{0.982651, 1.669832, 0.003902},{
      0.983026, 1.672198, 0.003902},{0.983542, 1.672198, 0.002656}}],
    Polygon[{{0.982651, 1.669832, 0.003902},{0.981981, 1.670049, 0.005052},{
      0.982321, 1.672198, 0.005052},{0.983026, 1.672198, 0.003902}}],
    Polygon[{{0.981981, 1.670049, 0.005052},{0.981148, 1.670320, 0.006077},{
      0.981445, 1.672198, 0.006077},{0.982321, 1.672198, 0.005052}}],
    Polygon[{{0.981148, 1.670320, 0.006077},{0.980172, 1.670637, 0.006953},{
      0.980420, 1.672198, 0.006953},{0.981445, 1.672198, 0.006077}}],
    Polygon[{{0.980172, 1.670637, 0.006953},{0.979079, 1.670992, 0.007658},{
      0.979270, 1.672198, 0.007658},{0.980420, 1.672198, 0.006953}}],
    Polygon[{{0.979079, 1.670992, 0.007658},{0.977894, 1.671377, 0.008174},{
      0.978024, 1.672198, 0.008174},{0.979270, 1.672198, 0.007658}}],
    Polygon[{{0.977894, 1.671377, 0.008174},{0.976647, 1.671782, 0.008489},{
      0.976712, 1.672198, 0.008489},{0.978024, 1.672198, 0.008174}}],
    Polygon[{{1.025976, 1.672198, -0.008489},{1.027288, 1.672198, -0.008174},{
      1.027158, 1.673019, -0.008174},{1.025911, 1.672614, -0.008489}}],
    Polygon[{{1.027288, 1.672198, -0.008174},{1.028534, 1.672198, -0.007658},{
      1.028343, 1.673404, -0.007658},{1.027158, 1.673019, -0.008174}}],
    Polygon[{{1.028534, 1.672198, -0.007658},{1.029684, 1.672198, -0.006953},{
      1.029436, 1.673759, -0.006953},{1.028343, 1.673404, -0.007658}}],
    Polygon[{{1.029684, 1.672198, -0.006953},{1.030709, 1.672198, -0.006077},{
      1.030412, 1.674076, -0.006077},{1.029436, 1.673759, -0.006953}}],
    Polygon[{{1.030709, 1.672198, -0.006077},{1.031585, 1.672198, -0.005052},{
      1.031245, 1.674347, -0.005052},{1.030412, 1.674076, -0.006077}}],
    Polygon[{{1.031585, 1.672198, -0.005052},{1.032290, 1.672198, -0.003902},{
      1.031915, 1.674564, -0.003902},{1.031245, 1.674347, -0.005052}}],
    Polygon[{{1.032290, 1.672198, -0.003902},{1.032806, 1.672198, -0.002656},{
      1.032406, 1.674724, -0.002656},{1.031915, 1.674564, -0.003902}}],
    Polygon[{{1.032806, 1.672198, -0.002656},{1.033121, 1.672198, -0.001344},{
      1.032705, 1.674821, -0.001344},{1.032406, 1.674724, -0.002656}}],
    Polygon[{{1.033121, 1.672198, -0.001344},{1.033226, 1.672198, 0.000000},{
      1.032806, 1.674854, 0.000000},{1.032705, 1.674821, -0.001344}}],
    Polygon[{{1.033226, 1.672198, 0.000000},{1.033121, 1.672198, 0.001344},{
      1.032705, 1.674821, 0.001344},{1.032806, 1.674854, 0.000000}}],
    Polygon[{{1.033121, 1.672198, 0.001344},{1.032806, 1.672198, 0.002656},{
      1.032406, 1.674724, 0.002656},{1.032705, 1.674821, 0.001344}}],
    Polygon[{{1.032806, 1.672198, 0.002656},{1.032290, 1.672198, 0.003902},{
      1.031915, 1.674564, 0.003902},{1.032406, 1.674724, 0.002656}}],
    Polygon[{{1.032290, 1.672198, 0.003902},{1.031585, 1.672198, 0.005052},{
      1.031245, 1.674347, 0.005052},{1.031915, 1.674564, 0.003902}}],
    Polygon[{{1.031585, 1.672198, 0.005052},{1.030709, 1.672198, 0.006077},{
      1.030412, 1.674076, 0.006077},{1.031245, 1.674347, 0.005052}}],
    Polygon[{{1.030709, 1.672198, 0.006077},{1.029684, 1.672198, 0.006953},{
      1.029436, 1.673759, 0.006953},{1.030412, 1.674076, 0.006077}}],
    Polygon[{{1.029684, 1.672198, 0.006953},{1.028534, 1.672198, 0.007658},{
      1.028343, 1.673404, 0.007658},{1.029436, 1.673759, 0.006953}}],
    Polygon[{{1.028534, 1.672198, 0.007658},{1.027288, 1.672198, 0.008174},{
      1.027158, 1.673019, 0.008174},{1.028343, 1.673404, 0.007658}}],
    Polygon[{{1.027288, 1.672198, 0.008174},{1.025976, 1.672198, 0.008489},{
      1.025911, 1.672614, 0.008489},{1.027158, 1.673019, 0.008174}}],
    Polygon[{{1.025911, 1.672614, -0.008489},{1.027158, 1.673019, -0.008174},{
      1.026781, 1.673759, -0.008174},{1.025720, 1.672988, -0.008489}}],
    Polygon[{{1.027158, 1.673019, -0.008174},{1.028343, 1.673404, -0.007658},{
      1.027789, 1.674491, -0.007658},{1.026781, 1.673759, -0.008174}}],
    Polygon[{{1.028343, 1.673404, -0.007658},{1.029436, 1.673759, -0.006953},{
      1.028719, 1.675167, -0.006953},{1.027789, 1.674491, -0.007658}}],
    Polygon[{{1.029436, 1.673759, -0.006953},{1.030412, 1.674076, -0.006077},{
      1.029549, 1.675770, -0.006077},{1.028719, 1.675167, -0.006953}}],
    Polygon[{{1.030412, 1.674076, -0.006077},{1.031245, 1.674347, -0.005052},{
      1.030257, 1.676285, -0.005052},{1.029549, 1.675770, -0.006077}}],
    Polygon[{{1.031245, 1.674347, -0.005052},{1.031915, 1.674564, -0.003902},{
      1.030827, 1.676699, -0.003902},{1.030257, 1.676285, -0.005052}}],
    Polygon[{{1.031915, 1.674564, -0.003902},{1.032406, 1.674724, -0.002656},{
      1.031245, 1.677002, -0.002656},{1.030827, 1.676699, -0.003902}}],
    Polygon[{{1.032406, 1.674724, -0.002656},{1.032705, 1.674821, -0.001344},{
      1.031500, 1.677188, -0.001344},{1.031245, 1.677002, -0.002656}}],
    Polygon[{{1.032705, 1.674821, -0.001344},{1.032806, 1.674854, 0.000000},{
      1.031585, 1.677250, 0.000000},{1.031500, 1.677188, -0.001344}}],
    Polygon[{{1.032806, 1.674854, 0.000000},{1.032705, 1.674821, 0.001344},{
      1.031500, 1.677188, 0.001344},{1.031585, 1.677250, 0.000000}}],
    Polygon[{{1.032705, 1.674821, 0.001344},{1.032406, 1.674724, 0.002656},{
      1.031245, 1.677002, 0.002656},{1.031500, 1.677188, 0.001344}}],
    Polygon[{{1.032406, 1.674724, 0.002656},{1.031915, 1.674564, 0.003902},{
      1.030827, 1.676699, 0.003902},{1.031245, 1.677002, 0.002656}}],
    Polygon[{{1.031915, 1.674564, 0.003902},{1.031245, 1.674347, 0.005052},{
      1.030257, 1.676285, 0.005052},{1.030827, 1.676699, 0.003902}}],
    Polygon[{{1.031245, 1.674347, 0.005052},{1.030412, 1.674076, 0.006077},{
      1.029549, 1.675770, 0.006077},{1.030257, 1.676285, 0.005052}}],
    Polygon[{{1.030412, 1.674076, 0.006077},{1.029436, 1.673759, 0.006953},{
      1.028719, 1.675167, 0.006953},{1.029549, 1.675770, 0.006077}}],
    Polygon[{{1.029436, 1.673759, 0.006953},{1.028343, 1.673404, 0.007658},{
      1.027789, 1.674491, 0.007658},{1.028719, 1.675167, 0.006953}}],
    Polygon[{{1.028343, 1.673404, 0.007658},{1.027158, 1.673019, 0.008174},{
      1.026781, 1.673759, 0.008174},{1.027789, 1.674491, 0.007658}}],
    Polygon[{{1.027158, 1.673019, 0.008174},{1.025911, 1.672614, 0.008489},{
      1.025720, 1.672988, 0.008489},{1.026781, 1.673759, 0.008174}}],
    Polygon[{{1.025720, 1.672988, -0.008489},{1.026781, 1.673759, -0.008174},{
      1.026193, 1.674347, -0.008174},{1.025422, 1.673286, -0.008489}}],
    Polygon[{{1.026781, 1.673759, -0.008174},{1.027789, 1.674491, -0.007658},{
      1.026925, 1.675355, -0.007658},{1.026193, 1.674347, -0.008174}}],
    Polygon[{{1.027789, 1.674491, -0.007658},{1.028719, 1.675167, -0.006953},{
      1.027601, 1.676285, -0.006953},{1.026925, 1.675355, -0.007658}}],
    Polygon[{{1.028719, 1.675167, -0.006953},{1.029549, 1.675770, -0.006077},{
      1.028204, 1.677115, -0.006077},{1.027601, 1.676285, -0.006953}}],
    Polygon[{{1.029549, 1.675770, -0.006077},{1.030257, 1.676285, -0.005052},{
      1.028719, 1.677823, -0.005052},{1.028204, 1.677115, -0.006077}}],
    Polygon[{{1.030257, 1.676285, -0.005052},{1.030827, 1.676699, -0.003902},{
      1.029133, 1.678393, -0.003902},{1.028719, 1.677823, -0.005052}}],
    Polygon[{{1.030827, 1.676699, -0.003902},{1.031245, 1.677002, -0.002656},{
      1.029436, 1.678811, -0.002656},{1.029133, 1.678393, -0.003902}}],
    Polygon[{{1.031245, 1.677002, -0.002656},{1.031500, 1.677188, -0.001344},{
      1.029621, 1.679065, -0.001344},{1.029436, 1.678811, -0.002656}}],
    Polygon[{{1.031500, 1.677188, -0.001344},{1.031585, 1.677250, 0.000000},{
      1.029684, 1.679151, 0.000000},{1.029621, 1.679065, -0.001344}}],
    Polygon[{{1.031585, 1.677250, 0.000000},{1.031500, 1.677188, 0.001344},{
      1.029621, 1.679065, 0.001344},{1.029684, 1.679151, 0.000000}}],
    Polygon[{{1.031500, 1.677188, 0.001344},{1.031245, 1.677002, 0.002656},{
      1.029436, 1.678811, 0.002656},{1.029621, 1.679065, 0.001344}}],
    Polygon[{{1.031245, 1.677002, 0.002656},{1.030827, 1.676699, 0.003902},{
      1.029133, 1.678393, 0.003902},{1.029436, 1.678811, 0.002656}}],
    Polygon[{{1.030827, 1.676699, 0.003902},{1.030257, 1.676285, 0.005052},{
      1.028719, 1.677823, 0.005052},{1.029133, 1.678393, 0.003902}}],
    Polygon[{{1.030257, 1.676285, 0.005052},{1.029549, 1.675770, 0.006077},{
      1.028204, 1.677115, 0.006077},{1.028719, 1.677823, 0.005052}}],
    Polygon[{{1.029549, 1.675770, 0.006077},{1.028719, 1.675167, 0.006953},{
      1.027601, 1.676285, 0.006953},{1.028204, 1.677115, 0.006077}}],
    Polygon[{{1.028719, 1.675167, 0.006953},{1.027789, 1.674491, 0.007658},{
      1.026925, 1.675355, 0.007658},{1.027601, 1.676285, 0.006953}}],
    Polygon[{{1.027789, 1.674491, 0.007658},{1.026781, 1.673759, 0.008174},{
      1.026193, 1.674347, 0.008174},{1.026925, 1.675355, 0.007658}}],
    Polygon[{{1.026781, 1.673759, 0.008174},{1.025720, 1.672988, 0.008489},{
      1.025422, 1.673286, 0.008489},{1.026193, 1.674347, 0.008174}}],
    Polygon[{{1.025422, 1.673286, -0.008489},{1.026193, 1.674347, -0.008174},{
      1.025453, 1.674724, -0.008174},{1.025047, 1.673477, -0.008489}}],
    Polygon[{{1.026193, 1.674347, -0.008174},{1.026925, 1.675355, -0.007658},{
      1.025838, 1.675909, -0.007658},{1.025453, 1.674724, -0.008174}}],
    Polygon[{{1.026925, 1.675355, -0.007658},{1.027601, 1.676285, -0.006953},{
      1.026193, 1.677002, -0.006953},{1.025838, 1.675909, -0.007658}}],
    Polygon[{{1.027601, 1.676285, -0.006953},{1.028204, 1.677115, -0.006077},{
      1.026510, 1.677978, -0.006077},{1.026193, 1.677002, -0.006953}}],
    Polygon[{{1.028204, 1.677115, -0.006077},{1.028719, 1.677823, -0.005052},{
      1.026781, 1.678811, -0.005052},{1.026510, 1.677978, -0.006077}}],
    Polygon[{{1.028719, 1.677823, -0.005052},{1.029133, 1.678393, -0.003902},{
      1.026998, 1.679481, -0.003902},{1.026781, 1.678811, -0.005052}}],
    Polygon[{{1.029133, 1.678393, -0.003902},{1.029436, 1.678811, -0.002656},{
      1.027158, 1.679972, -0.002656},{1.026998, 1.679481, -0.003902}}],
    Polygon[{{1.029436, 1.678811, -0.002656},{1.029621, 1.679065, -0.001344},{
      1.027255, 1.680271, -0.001344},{1.027158, 1.679972, -0.002656}}],
    Polygon[{{1.029621, 1.679065, -0.001344},{1.029684, 1.679151, 0.000000},{
      1.027288, 1.680372, 0.000000},{1.027255, 1.680271, -0.001344}}],
    Polygon[{{1.029684, 1.679151, 0.000000},{1.029621, 1.679065, 0.001344},{
      1.027255, 1.680271, 0.001344},{1.027288, 1.680372, 0.000000}}],
    Polygon[{{1.029621, 1.679065, 0.001344},{1.029436, 1.678811, 0.002656},{
      1.027158, 1.679972, 0.002656},{1.027255, 1.680271, 0.001344}}],
    Polygon[{{1.029436, 1.678811, 0.002656},{1.029133, 1.678393, 0.003902},{
      1.026998, 1.679481, 0.003902},{1.027158, 1.679972, 0.002656}}],
    Polygon[{{1.029133, 1.678393, 0.003902},{1.028719, 1.677823, 0.005052},{
      1.026781, 1.678811, 0.005052},{1.026998, 1.679481, 0.003902}}],
    Polygon[{{1.028719, 1.677823, 0.005052},{1.028204, 1.677115, 0.006077},{
      1.026510, 1.677978, 0.006077},{1.026781, 1.678811, 0.005052}}],
    Polygon[{{1.028204, 1.677115, 0.006077},{1.027601, 1.676285, 0.006953},{
      1.026193, 1.677002, 0.006953},{1.026510, 1.677978, 0.006077}}],
    Polygon[{{1.027601, 1.676285, 0.006953},{1.026925, 1.675355, 0.007658},{
      1.025838, 1.675909, 0.007658},{1.026193, 1.677002, 0.006953}}],
    Polygon[{{1.026925, 1.675355, 0.007658},{1.026193, 1.674347, 0.008174},{
      1.025453, 1.674724, 0.008174},{1.025838, 1.675909, 0.007658}}],
    Polygon[{{1.026193, 1.674347, 0.008174},{1.025422, 1.673286, 0.008489},{
      1.025047, 1.673477, 0.008489},{1.025453, 1.674724, 0.008174}}],
    Polygon[{{1.025047, 1.673477, -0.008489},{1.025453, 1.674724, -0.008174},{
      1.024632, 1.674854, -0.008174},{1.024632, 1.673542, -0.008489}}],
    Polygon[{{1.025453, 1.674724, -0.008174},{1.025838, 1.675909, -0.007658},{
      1.024632, 1.676100, -0.007658},{1.024632, 1.674854, -0.008174}}],
    Polygon[{{1.025838, 1.675909, -0.007658},{1.026193, 1.677002, -0.006953},{
      1.024632, 1.677250, -0.006953},{1.024632, 1.676100, -0.007658}}],
    Polygon[{{1.026193, 1.677002, -0.006953},{1.026510, 1.677978, -0.006077},{
      1.024632, 1.678275, -0.006077},{1.024632, 1.677250, -0.006953}}],
    Polygon[{{1.026510, 1.677978, -0.006077},{1.026781, 1.678811, -0.005052},{
      1.024632, 1.679151, -0.005052},{1.024632, 1.678275, -0.006077}}],
    Polygon[{{1.026781, 1.678811, -0.005052},{1.026998, 1.679481, -0.003902},{
      1.024632, 1.679856, -0.003902},{1.024632, 1.679151, -0.005052}}],
    Polygon[{{1.026998, 1.679481, -0.003902},{1.027158, 1.679972, -0.002656},{
      1.024632, 1.680372, -0.002656},{1.024632, 1.679856, -0.003902}}],
    Polygon[{{1.027158, 1.679972, -0.002656},{1.027255, 1.680271, -0.001344},{
      1.024632, 1.680687, -0.001344},{1.024632, 1.680372, -0.002656}}],
    Polygon[{{1.027255, 1.680271, -0.001344},{1.027288, 1.680372, 0.000000},{
      1.024632, 1.680792, 0.000000},{1.024632, 1.680687, -0.001344}}],
    Polygon[{{1.027288, 1.680372, 0.000000},{1.027255, 1.680271, 0.001344},{
      1.024632, 1.680687, 0.001344},{1.024632, 1.680792, 0.000000}}],
    Polygon[{{1.027255, 1.680271, 0.001344},{1.027158, 1.679972, 0.002656},{
      1.024632, 1.680372, 0.002656},{1.024632, 1.680687, 0.001344}}],
    Polygon[{{1.027158, 1.679972, 0.002656},{1.026998, 1.679481, 0.003902},{
      1.024632, 1.679856, 0.003902},{1.024632, 1.680372, 0.002656}}],
    Polygon[{{1.026998, 1.679481, 0.003902},{1.026781, 1.678811, 0.005052},{
      1.024632, 1.679151, 0.005052},{1.024632, 1.679856, 0.003902}}],
    Polygon[{{1.026781, 1.678811, 0.005052},{1.026510, 1.677978, 0.006077},{
      1.024632, 1.678275, 0.006077},{1.024632, 1.679151, 0.005052}}],
    Polygon[{{1.026510, 1.677978, 0.006077},{1.026193, 1.677002, 0.006953},{
      1.024632, 1.677250, 0.006953},{1.024632, 1.678275, 0.006077}}],
    Polygon[{{1.026193, 1.677002, 0.006953},{1.025838, 1.675909, 0.007658},{
      1.024632, 1.676100, 0.007658},{1.024632, 1.677250, 0.006953}}],
    Polygon[{{1.025838, 1.675909, 0.007658},{1.025453, 1.674724, 0.008174},{
      1.024632, 1.674854, 0.008174},{1.024632, 1.676100, 0.007658}}],
    Polygon[{{1.025453, 1.674724, 0.008174},{1.025047, 1.673477, 0.008489},{
      1.024632, 1.673542, 0.008489},{1.024632, 1.674854, 0.008174}}],
    Polygon[{{1.024632, 1.673542, -0.008489},{1.024632, 1.674854, -0.008174},{
      1.023811, 1.674724, -0.008174},{1.024217, 1.673477, -0.008489}}],
    Polygon[{{1.024632, 1.674854, -0.008174},{1.024632, 1.676100, -0.007658},{
      1.023426, 1.675909, -0.007658},{1.023811, 1.674724, -0.008174}}],
    Polygon[{{1.024632, 1.676100, -0.007658},{1.024632, 1.677250, -0.006953},{
      1.023071, 1.677002, -0.006953},{1.023426, 1.675909, -0.007658}}],
    Polygon[{{1.024632, 1.677250, -0.006953},{1.024632, 1.678275, -0.006077},{
      1.022754, 1.677978, -0.006077},{1.023071, 1.677002, -0.006953}}],
    Polygon[{{1.024632, 1.678275, -0.006077},{1.024632, 1.679151, -0.005052},{
      1.022483, 1.678811, -0.005052},{1.022754, 1.677978, -0.006077}}],
    Polygon[{{1.024632, 1.679151, -0.005052},{1.024632, 1.679856, -0.003902},{
      1.022266, 1.679481, -0.003902},{1.022483, 1.678811, -0.005052}}],
    Polygon[{{1.024632, 1.679856, -0.003902},{1.024632, 1.680372, -0.002656},{
      1.022106, 1.679972, -0.002656},{1.022266, 1.679481, -0.003902}}],
    Polygon[{{1.024632, 1.680372, -0.002656},{1.024632, 1.680687, -0.001344},{
      1.022009, 1.680271, -0.001344},{1.022106, 1.679972, -0.002656}}],
    Polygon[{{1.024632, 1.680687, -0.001344},{1.024632, 1.680792, 0.000000},{
      1.021976, 1.680372, 0.000000},{1.022009, 1.680271, -0.001344}}],
    Polygon[{{1.024632, 1.680792, 0.000000},{1.024632, 1.680687, 0.001344},{
      1.022009, 1.680271, 0.001344},{1.021976, 1.680372, 0.000000}}],
    Polygon[{{1.024632, 1.680687, 0.001344},{1.024632, 1.680372, 0.002656},{
      1.022106, 1.679972, 0.002656},{1.022009, 1.680271, 0.001344}}],
    Polygon[{{1.024632, 1.680372, 0.002656},{1.024632, 1.679856, 0.003902},{
      1.022266, 1.679481, 0.003902},{1.022106, 1.679972, 0.002656}}],
    Polygon[{{1.024632, 1.679856, 0.003902},{1.024632, 1.679151, 0.005052},{
      1.022483, 1.678811, 0.005052},{1.022266, 1.679481, 0.003902}}],
    Polygon[{{1.024632, 1.679151, 0.005052},{1.024632, 1.678275, 0.006077},{
      1.022754, 1.677978, 0.006077},{1.022483, 1.678811, 0.005052}}],
    Polygon[{{1.024632, 1.678275, 0.006077},{1.024632, 1.677250, 0.006953},{
      1.023071, 1.677002, 0.006953},{1.022754, 1.677978, 0.006077}}],
    Polygon[{{1.024632, 1.677250, 0.006953},{1.024632, 1.676100, 0.007658},{
      1.023426, 1.675909, 0.007658},{1.023071, 1.677002, 0.006953}}],
    Polygon[{{1.024632, 1.676100, 0.007658},{1.024632, 1.674854, 0.008174},{
      1.023811, 1.674724, 0.008174},{1.023426, 1.675909, 0.007658}}],
    Polygon[{{1.024632, 1.674854, 0.008174},{1.024632, 1.673542, 0.008489},{
      1.024217, 1.673477, 0.008489},{1.023811, 1.674724, 0.008174}}],
    Polygon[{{1.024217, 1.673477, -0.008489},{1.023811, 1.674724, -0.008174},{
      1.023071, 1.674347, -0.008174},{1.023842, 1.673286, -0.008489}}],
    Polygon[{{1.023811, 1.674724, -0.008174},{1.023426, 1.675909, -0.007658},{
      1.022339, 1.675355, -0.007658},{1.023071, 1.674347, -0.008174}}],
    Polygon[{{1.023426, 1.675909, -0.007658},{1.023071, 1.677002, -0.006953},{
      1.021663, 1.676285, -0.006953},{1.022339, 1.675355, -0.007658}}],
    Polygon[{{1.023071, 1.677002, -0.006953},{1.022754, 1.677978, -0.006077},{
      1.021060, 1.677115, -0.006077},{1.021663, 1.676285, -0.006953}}],
    Polygon[{{1.022754, 1.677978, -0.006077},{1.022483, 1.678811, -0.005052},{
      1.020545, 1.677823, -0.005052},{1.021060, 1.677115, -0.006077}}],
    Polygon[{{1.022483, 1.678811, -0.005052},{1.022266, 1.679481, -0.003902},{
      1.020131, 1.678393, -0.003902},{1.020545, 1.677823, -0.005052}}],
    Polygon[{{1.022266, 1.679481, -0.003902},{1.022106, 1.679972, -0.002656},{
      1.019827, 1.678811, -0.002656},{1.020131, 1.678393, -0.003902}}],
    Polygon[{{1.022106, 1.679972, -0.002656},{1.022009, 1.680271, -0.001344},{
      1.019642, 1.679065, -0.001344},{1.019827, 1.678811, -0.002656}}],
    Polygon[{{1.022009, 1.680271, -0.001344},{1.021976, 1.680372, 0.000000},{
      1.019580, 1.679151, 0.000000},{1.019642, 1.679065, -0.001344}}],
    Polygon[{{1.021976, 1.680372, 0.000000},{1.022009, 1.680271, 0.001344},{
      1.019642, 1.679065, 0.001344},{1.019580, 1.679151, 0.000000}}],
    Polygon[{{1.022009, 1.680271, 0.001344},{1.022106, 1.679972, 0.002656},{
      1.019827, 1.678811, 0.002656},{1.019642, 1.679065, 0.001344}}],
    Polygon[{{1.022106, 1.679972, 0.002656},{1.022266, 1.679481, 0.003902},{
      1.020131, 1.678393, 0.003902},{1.019827, 1.678811, 0.002656}}],
    Polygon[{{1.022266, 1.679481, 0.003902},{1.022483, 1.678811, 0.005052},{
      1.020545, 1.677823, 0.005052},{1.020131, 1.678393, 0.003902}}],
    Polygon[{{1.022483, 1.678811, 0.005052},{1.022754, 1.677978, 0.006077},{
      1.021060, 1.677115, 0.006077},{1.020545, 1.677823, 0.005052}}],
    Polygon[{{1.022754, 1.677978, 0.006077},{1.023071, 1.677002, 0.006953},{
      1.021663, 1.676285, 0.006953},{1.021060, 1.677115, 0.006077}}],
    Polygon[{{1.023071, 1.677002, 0.006953},{1.023426, 1.675909, 0.007658},{
      1.022339, 1.675355, 0.007658},{1.021663, 1.676285, 0.006953}}],
    Polygon[{{1.023426, 1.675909, 0.007658},{1.023811, 1.674724, 0.008174},{
      1.023071, 1.674347, 0.008174},{1.022339, 1.675355, 0.007658}}],
    Polygon[{{1.023811, 1.674724, 0.008174},{1.024217, 1.673477, 0.008489},{
      1.023842, 1.673286, 0.008489},{1.023071, 1.674347, 0.008174}}],
    Polygon[{{1.023842, 1.673286, -0.008489},{1.023071, 1.674347, -0.008174},{
      1.022483, 1.673759, -0.008174},{1.023544, 1.672988, -0.008489}}],
    Polygon[{{1.023071, 1.674347, -0.008174},{1.022339, 1.675355, -0.007658},{
      1.021475, 1.674491, -0.007658},{1.022483, 1.673759, -0.008174}}],
    Polygon[{{1.022339, 1.675355, -0.007658},{1.021663, 1.676285, -0.006953},{
      1.020545, 1.675167, -0.006953},{1.021475, 1.674491, -0.007658}}],
    Polygon[{{1.021663, 1.676285, -0.006953},{1.021060, 1.677115, -0.006077},{
      1.019715, 1.675770, -0.006077},{1.020545, 1.675167, -0.006953}}],
    Polygon[{{1.021060, 1.677115, -0.006077},{1.020545, 1.677823, -0.005052},{
      1.019007, 1.676285, -0.005052},{1.019715, 1.675770, -0.006077}}],
    Polygon[{{1.020545, 1.677823, -0.005052},{1.020131, 1.678393, -0.003902},{
      1.018437, 1.676699, -0.003902},{1.019007, 1.676285, -0.005052}}],
    Polygon[{{1.020131, 1.678393, -0.003902},{1.019827, 1.678811, -0.002656},{
      1.018019, 1.677002, -0.002656},{1.018437, 1.676699, -0.003902}}],
    Polygon[{{1.019827, 1.678811, -0.002656},{1.019642, 1.679065, -0.001344},{
      1.017765, 1.677188, -0.001344},{1.018019, 1.677002, -0.002656}}],
    Polygon[{{1.019642, 1.679065, -0.001344},{1.019580, 1.679151, 0.000000},{
      1.017679, 1.677250, 0.000000},{1.017765, 1.677188, -0.001344}}],
    Polygon[{{1.019580, 1.679151, 0.000000},{1.019642, 1.679065, 0.001344},{
      1.017765, 1.677188, 0.001344},{1.017679, 1.677250, 0.000000}}],
    Polygon[{{1.019642, 1.679065, 0.001344},{1.019827, 1.678811, 0.002656},{
      1.018019, 1.677002, 0.002656},{1.017765, 1.677188, 0.001344}}],
    Polygon[{{1.019827, 1.678811, 0.002656},{1.020131, 1.678393, 0.003902},{
      1.018437, 1.676699, 0.003902},{1.018019, 1.677002, 0.002656}}],
    Polygon[{{1.020131, 1.678393, 0.003902},{1.020545, 1.677823, 0.005052},{
      1.019007, 1.676285, 0.005052},{1.018437, 1.676699, 0.003902}}],
    Polygon[{{1.020545, 1.677823, 0.005052},{1.021060, 1.677115, 0.006077},{
      1.019715, 1.675770, 0.006077},{1.019007, 1.676285, 0.005052}}],
    Polygon[{{1.021060, 1.677115, 0.006077},{1.021663, 1.676285, 0.006953},{
      1.020545, 1.675167, 0.006953},{1.019715, 1.675770, 0.006077}}],
    Polygon[{{1.021663, 1.676285, 0.006953},{1.022339, 1.675355, 0.007658},{
      1.021475, 1.674491, 0.007658},{1.020545, 1.675167, 0.006953}}],
    Polygon[{{1.022339, 1.675355, 0.007658},{1.023071, 1.674347, 0.008174},{
      1.022483, 1.673759, 0.008174},{1.021475, 1.674491, 0.007658}}],
    Polygon[{{1.023071, 1.674347, 0.008174},{1.023842, 1.673286, 0.008489},{
      1.023544, 1.672988, 0.008489},{1.022483, 1.673759, 0.008174}}],
    Polygon[{{1.023544, 1.672988, -0.008489},{1.022483, 1.673759, -0.008174},{
      1.022106, 1.673019, -0.008174},{1.023353, 1.672614, -0.008489}}],
    Polygon[{{1.022483, 1.673759, -0.008174},{1.021475, 1.674491, -0.007658},{
      1.020921, 1.673404, -0.007658},{1.022106, 1.673019, -0.008174}}],
    Polygon[{{1.021475, 1.674491, -0.007658},{1.020545, 1.675167, -0.006953},{
      1.019827, 1.673759, -0.006953},{1.020921, 1.673404, -0.007658}}],
    Polygon[{{1.020545, 1.675167, -0.006953},{1.019715, 1.675770, -0.006077},{
      1.018852, 1.674076, -0.006077},{1.019827, 1.673759, -0.006953}}],
    Polygon[{{1.019715, 1.675770, -0.006077},{1.019007, 1.676285, -0.005052},{
      1.018019, 1.674347, -0.005052},{1.018852, 1.674076, -0.006077}}],
    Polygon[{{1.019007, 1.676285, -0.005052},{1.018437, 1.676699, -0.003902},{
      1.017349, 1.674564, -0.003902},{1.018019, 1.674347, -0.005052}}],
    Polygon[{{1.018437, 1.676699, -0.003902},{1.018019, 1.677002, -0.002656},{
      1.016858, 1.674724, -0.002656},{1.017349, 1.674564, -0.003902}}],
    Polygon[{{1.018019, 1.677002, -0.002656},{1.017765, 1.677188, -0.001344},{
      1.016559, 1.674821, -0.001344},{1.016858, 1.674724, -0.002656}}],
    Polygon[{{1.017765, 1.677188, -0.001344},{1.017679, 1.677250, 0.000000},{
      1.016458, 1.674854, 0.000000},{1.016559, 1.674821, -0.001344}}],
    Polygon[{{1.017679, 1.677250, 0.000000},{1.017765, 1.677188, 0.001344},{
      1.016559, 1.674821, 0.001344},{1.016458, 1.674854, 0.000000}}],
    Polygon[{{1.017765, 1.677188, 0.001344},{1.018019, 1.677002, 0.002656},{
      1.016858, 1.674724, 0.002656},{1.016559, 1.674821, 0.001344}}],
    Polygon[{{1.018019, 1.677002, 0.002656},{1.018437, 1.676699, 0.003902},{
      1.017349, 1.674564, 0.003902},{1.016858, 1.674724, 0.002656}}],
    Polygon[{{1.018437, 1.676699, 0.003902},{1.019007, 1.676285, 0.005052},{
      1.018019, 1.674347, 0.005052},{1.017349, 1.674564, 0.003902}}],
    Polygon[{{1.019007, 1.676285, 0.005052},{1.019715, 1.675770, 0.006077},{
      1.018852, 1.674076, 0.006077},{1.018019, 1.674347, 0.005052}}],
    Polygon[{{1.019715, 1.675770, 0.006077},{1.020545, 1.675167, 0.006953},{
      1.019827, 1.673759, 0.006953},{1.018852, 1.674076, 0.006077}}],
    Polygon[{{1.020545, 1.675167, 0.006953},{1.021475, 1.674491, 0.007658},{
      1.020921, 1.673404, 0.007658},{1.019827, 1.673759, 0.006953}}],
    Polygon[{{1.021475, 1.674491, 0.007658},{1.022483, 1.673759, 0.008174},{
      1.022106, 1.673019, 0.008174},{1.020921, 1.673404, 0.007658}}],
    Polygon[{{1.022483, 1.673759, 0.008174},{1.023544, 1.672988, 0.008489},{
      1.023353, 1.672614, 0.008489},{1.022106, 1.673019, 0.008174}}],
    Polygon[{{1.023353, 1.672614, -0.008489},{1.022106, 1.673019, -0.008174},{
      1.021976, 1.672198, -0.008174},{1.023288, 1.672198, -0.008489}}],
    Polygon[{{1.022106, 1.673019, -0.008174},{1.020921, 1.673404, -0.007658},{
      1.020730, 1.672198, -0.007658},{1.021976, 1.672198, -0.008174}}],
    Polygon[{{1.020921, 1.673404, -0.007658},{1.019827, 1.673759, -0.006953},{
      1.019580, 1.672198, -0.006953},{1.020730, 1.672198, -0.007658}}],
    Polygon[{{1.019827, 1.673759, -0.006953},{1.018852, 1.674076, -0.006077},{
      1.018555, 1.672198, -0.006077},{1.019580, 1.672198, -0.006953}}],
    Polygon[{{1.018852, 1.674076, -0.006077},{1.018019, 1.674347, -0.005052},{
      1.017679, 1.672198, -0.005052},{1.018555, 1.672198, -0.006077}}],
    Polygon[{{1.018019, 1.674347, -0.005052},{1.017349, 1.674564, -0.003902},{
      1.016974, 1.672198, -0.003902},{1.017679, 1.672198, -0.005052}}],
    Polygon[{{1.017349, 1.674564, -0.003902},{1.016858, 1.674724, -0.002656},{
      1.016458, 1.672198, -0.002656},{1.016974, 1.672198, -0.003902}}],
    Polygon[{{1.016858, 1.674724, -0.002656},{1.016559, 1.674821, -0.001344},{
      1.016143, 1.672198, -0.001344},{1.016458, 1.672198, -0.002656}}],
    Polygon[{{1.016559, 1.674821, -0.001344},{1.016458, 1.674854, 0.000000},{
      1.016037, 1.672198, 0.000000},{1.016143, 1.672198, -0.001344}}],
    Polygon[{{1.016458, 1.674854, 0.000000},{1.016559, 1.674821, 0.001344},{
      1.016143, 1.672198, 0.001344},{1.016037, 1.672198, 0.000000}}],
    Polygon[{{1.016559, 1.674821, 0.001344},{1.016858, 1.674724, 0.002656},{
      1.016458, 1.672198, 0.002656},{1.016143, 1.672198, 0.001344}}],
    Polygon[{{1.016858, 1.674724, 0.002656},{1.017349, 1.674564, 0.003902},{
      1.016974, 1.672198, 0.003902},{1.016458, 1.672198, 0.002656}}],
    Polygon[{{1.017349, 1.674564, 0.003902},{1.018019, 1.674347, 0.005052},{
      1.017679, 1.672198, 0.005052},{1.016974, 1.672198, 0.003902}}],
    Polygon[{{1.018019, 1.674347, 0.005052},{1.018852, 1.674076, 0.006077},{
      1.018555, 1.672198, 0.006077},{1.017679, 1.672198, 0.005052}}],
    Polygon[{{1.018852, 1.674076, 0.006077},{1.019827, 1.673759, 0.006953},{
      1.019580, 1.672198, 0.006953},{1.018555, 1.672198, 0.006077}}],
    Polygon[{{1.019827, 1.673759, 0.006953},{1.020921, 1.673404, 0.007658},{
      1.020730, 1.672198, 0.007658},{1.019580, 1.672198, 0.006953}}],
    Polygon[{{1.020921, 1.673404, 0.007658},{1.022106, 1.673019, 0.008174},{
      1.021976, 1.672198, 0.008174},{1.020730, 1.672198, 0.007658}}],
    Polygon[{{1.022106, 1.673019, 0.008174},{1.023353, 1.672614, 0.008489},{
      1.023288, 1.672198, 0.008489},{1.021976, 1.672198, 0.008174}}],
    Polygon[{{1.023288, 1.672198, -0.008489},{1.021976, 1.672198, -0.008174},{
      1.022106, 1.671377, -0.008174},{1.023353, 1.671782, -0.008489}}],
    Polygon[{{1.021976, 1.672198, -0.008174},{1.020730, 1.672198, -0.007658},{
      1.020921, 1.670992, -0.007658},{1.022106, 1.671377, -0.008174}}],
    Polygon[{{1.020730, 1.672198, -0.007658},{1.019580, 1.672198, -0.006953},{
      1.019827, 1.670637, -0.006953},{1.020921, 1.670992, -0.007658}}],
    Polygon[{{1.019580, 1.672198, -0.006953},{1.018555, 1.672198, -0.006077},{
      1.018852, 1.670320, -0.006077},{1.019827, 1.670637, -0.006953}}],
    Polygon[{{1.018555, 1.672198, -0.006077},{1.017679, 1.672198, -0.005052},{
      1.018019, 1.670049, -0.005052},{1.018852, 1.670320, -0.006077}}],
    Polygon[{{1.017679, 1.672198, -0.005052},{1.016974, 1.672198, -0.003902},{
      1.017349, 1.669832, -0.003902},{1.018019, 1.670049, -0.005052}}],
    Polygon[{{1.016974, 1.672198, -0.003902},{1.016458, 1.672198, -0.002656},{
      1.016858, 1.669672, -0.002656},{1.017349, 1.669832, -0.003902}}],
    Polygon[{{1.016458, 1.672198, -0.002656},{1.016143, 1.672198, -0.001344},{
      1.016559, 1.669575, -0.001344},{1.016858, 1.669672, -0.002656}}],
    Polygon[{{1.016143, 1.672198, -0.001344},{1.016037, 1.672198, 0.000000},{
      1.016458, 1.669542, 0.000000},{1.016559, 1.669575, -0.001344}}],
    Polygon[{{1.016037, 1.672198, 0.000000},{1.016143, 1.672198, 0.001344},{
      1.016559, 1.669575, 0.001344},{1.016458, 1.669542, 0.000000}}],
    Polygon[{{1.016143, 1.672198, 0.001344},{1.016458, 1.672198, 0.002656},{
      1.016858, 1.669672, 0.002656},{1.016559, 1.669575, 0.001344}}],
    Polygon[{{1.016458, 1.672198, 0.002656},{1.016974, 1.672198, 0.003902},{
      1.017349, 1.669832, 0.003902},{1.016858, 1.669672, 0.002656}}],
    Polygon[{{1.016974, 1.672198, 0.003902},{1.017679, 1.672198, 0.005052},{
      1.018019, 1.670049, 0.005052},{1.017349, 1.669832, 0.003902}}],
    Polygon[{{1.017679, 1.672198, 0.005052},{1.018555, 1.672198, 0.006077},{
      1.018852, 1.670320, 0.006077},{1.018019, 1.670049, 0.005052}}],
    Polygon[{{1.018555, 1.672198, 0.006077},{1.019580, 1.672198, 0.006953},{
      1.019827, 1.670637, 0.006953},{1.018852, 1.670320, 0.006077}}],
    Polygon[{{1.019580, 1.672198, 0.006953},{1.020730, 1.672198, 0.007658},{
      1.020921, 1.670992, 0.007658},{1.019827, 1.670637, 0.006953}}],
    Polygon[{{1.020730, 1.672198, 0.007658},{1.021976, 1.672198, 0.008174},{
      1.022106, 1.671377, 0.008174},{1.020921, 1.670992, 0.007658}}],
    Polygon[{{1.021976, 1.672198, 0.008174},{1.023288, 1.672198, 0.008489},{
      1.023353, 1.671782, 0.008489},{1.022106, 1.671377, 0.008174}}],
    Polygon[{{1.023353, 1.671782, -0.008489},{1.022106, 1.671377, -0.008174},{
      1.022483, 1.670637, -0.008174},{1.023544, 1.671408, -0.008489}}],
    Polygon[{{1.022106, 1.671377, -0.008174},{1.020921, 1.670992, -0.007658},{
      1.021475, 1.669905, -0.007658},{1.022483, 1.670637, -0.008174}}],
    Polygon[{{1.020921, 1.670992, -0.007658},{1.019827, 1.670637, -0.006953},{
      1.020545, 1.669229, -0.006953},{1.021475, 1.669905, -0.007658}}],
    Polygon[{{1.019827, 1.670637, -0.006953},{1.018852, 1.670320, -0.006077},{
      1.019715, 1.668626, -0.006077},{1.020545, 1.669229, -0.006953}}],
    Polygon[{{1.018852, 1.670320, -0.006077},{1.018019, 1.670049, -0.005052},{
      1.019007, 1.668111, -0.005052},{1.019715, 1.668626, -0.006077}}],
    Polygon[{{1.018019, 1.670049, -0.005052},{1.017349, 1.669832, -0.003902},{
      1.018437, 1.667697, -0.003902},{1.019007, 1.668111, -0.005052}}],
    Polygon[{{1.017349, 1.669832, -0.003902},{1.016858, 1.669672, -0.002656},{
      1.018019, 1.667394, -0.002656},{1.018437, 1.667697, -0.003902}}],
    Polygon[{{1.016858, 1.669672, -0.002656},{1.016559, 1.669575, -0.001344},{
      1.017765, 1.667209, -0.001344},{1.018019, 1.667394, -0.002656}}],
    Polygon[{{1.016559, 1.669575, -0.001344},{1.016458, 1.669542, 0.000000},{
      1.017679, 1.667146, 0.000000},{1.017765, 1.667209, -0.001344}}],
    Polygon[{{1.016458, 1.669542, 0.000000},{1.016559, 1.669575, 0.001344},{
      1.017765, 1.667209, 0.001344},{1.017679, 1.667146, 0.000000}}],
    Polygon[{{1.016559, 1.669575, 0.001344},{1.016858, 1.669672, 0.002656},{
      1.018019, 1.667394, 0.002656},{1.017765, 1.667209, 0.001344}}],
    Polygon[{{1.016858, 1.669672, 0.002656},{1.017349, 1.669832, 0.003902},{
      1.018437, 1.667697, 0.003902},{1.018019, 1.667394, 0.002656}}],
    Polygon[{{1.017349, 1.669832, 0.003902},{1.018019, 1.670049, 0.005052},{
      1.019007, 1.668111, 0.005052},{1.018437, 1.667697, 0.003902}}],
    Polygon[{{1.018019, 1.670049, 0.005052},{1.018852, 1.670320, 0.006077},{
      1.019715, 1.668626, 0.006077},{1.019007, 1.668111, 0.005052}}],
    Polygon[{{1.018852, 1.670320, 0.006077},{1.019827, 1.670637, 0.006953},{
      1.020545, 1.669229, 0.006953},{1.019715, 1.668626, 0.006077}}],
    Polygon[{{1.019827, 1.670637, 0.006953},{1.020921, 1.670992, 0.007658},{
      1.021475, 1.669905, 0.007658},{1.020545, 1.669229, 0.006953}}],
    Polygon[{{1.020921, 1.670992, 0.007658},{1.022106, 1.671377, 0.008174},{
      1.022483, 1.670637, 0.008174},{1.021475, 1.669905, 0.007658}}],
    Polygon[{{1.022106, 1.671377, 0.008174},{1.023353, 1.671782, 0.008489},{
      1.023544, 1.671408, 0.008489},{1.022483, 1.670637, 0.008174}}],
    Polygon[{{1.023544, 1.671408, -0.008489},{1.022483, 1.670637, -0.008174},{
      1.023071, 1.670049, -0.008174},{1.023842, 1.671110, -0.008489}}],
    Polygon[{{1.022483, 1.670637, -0.008174},{1.021475, 1.669905, -0.007658},{
      1.022339, 1.669041, -0.007658},{1.023071, 1.670049, -0.008174}}],
    Polygon[{{1.021475, 1.669905, -0.007658},{1.020545, 1.669229, -0.006953},{
      1.021663, 1.668111, -0.006953},{1.022339, 1.669041, -0.007658}}],
    Polygon[{{1.020545, 1.669229, -0.006953},{1.019715, 1.668626, -0.006077},{
      1.021060, 1.667281, -0.006077},{1.021663, 1.668111, -0.006953}}],
    Polygon[{{1.019715, 1.668626, -0.006077},{1.019007, 1.668111, -0.005052},{
      1.020545, 1.666573, -0.005052},{1.021060, 1.667281, -0.006077}}],
    Polygon[{{1.019007, 1.668111, -0.005052},{1.018437, 1.667697, -0.003902},{
      1.020131, 1.666003, -0.003902},{1.020545, 1.666573, -0.005052}}],
    Polygon[{{1.018437, 1.667697, -0.003902},{1.018019, 1.667394, -0.002656},{
      1.019827, 1.665585, -0.002656},{1.020131, 1.666003, -0.003902}}],
    Polygon[{{1.018019, 1.667394, -0.002656},{1.017765, 1.667209, -0.001344},{
      1.019642, 1.665331, -0.001344},{1.019827, 1.665585, -0.002656}}],
    Polygon[{{1.017765, 1.667209, -0.001344},{1.017679, 1.667146, 0.000000},{
      1.019580, 1.665245, 0.000000},{1.019642, 1.665331, -0.001344}}],
    Polygon[{{1.017679, 1.667146, 0.000000},{1.017765, 1.667209, 0.001344},{
      1.019642, 1.665331, 0.001344},{1.019580, 1.665245, 0.000000}}],
    Polygon[{{1.017765, 1.667209, 0.001344},{1.018019, 1.667394, 0.002656},{
      1.019827, 1.665585, 0.002656},{1.019642, 1.665331, 0.001344}}],
    Polygon[{{1.018019, 1.667394, 0.002656},{1.018437, 1.667697, 0.003902},{
      1.020131, 1.666003, 0.003902},{1.019827, 1.665585, 0.002656}}],
    Polygon[{{1.018437, 1.667697, 0.003902},{1.019007, 1.668111, 0.005052},{
      1.020545, 1.666573, 0.005052},{1.020131, 1.666003, 0.003902}}],
    Polygon[{{1.019007, 1.668111, 0.005052},{1.019715, 1.668626, 0.006077},{
      1.021060, 1.667281, 0.006077},{1.020545, 1.666573, 0.005052}}],
    Polygon[{{1.019715, 1.668626, 0.006077},{1.020545, 1.669229, 0.006953},{
      1.021663, 1.668111, 0.006953},{1.021060, 1.667281, 0.006077}}],
    Polygon[{{1.020545, 1.669229, 0.006953},{1.021475, 1.669905, 0.007658},{
      1.022339, 1.669041, 0.007658},{1.021663, 1.668111, 0.006953}}],
    Polygon[{{1.021475, 1.669905, 0.007658},{1.022483, 1.670637, 0.008174},{
      1.023071, 1.670049, 0.008174},{1.022339, 1.669041, 0.007658}}],
    Polygon[{{1.022483, 1.670637, 0.008174},{1.023544, 1.671408, 0.008489},{
      1.023842, 1.671110, 0.008489},{1.023071, 1.670049, 0.008174}}],
    Polygon[{{1.023842, 1.671110, -0.008489},{1.023071, 1.670049, -0.008174},{
      1.023811, 1.669672, -0.008174},{1.024217, 1.670919, -0.008489}}],
    Polygon[{{1.023071, 1.670049, -0.008174},{1.022339, 1.669041, -0.007658},{
      1.023426, 1.668487, -0.007658},{1.023811, 1.669672, -0.008174}}],
    Polygon[{{1.022339, 1.669041, -0.007658},{1.021663, 1.668111, -0.006953},{
      1.023071, 1.667394, -0.006953},{1.023426, 1.668487, -0.007658}}],
    Polygon[{{1.021663, 1.668111, -0.006953},{1.021060, 1.667281, -0.006077},{
      1.022754, 1.666418, -0.006077},{1.023071, 1.667394, -0.006953}}],
    Polygon[{{1.021060, 1.667281, -0.006077},{1.020545, 1.666573, -0.005052},{
      1.022483, 1.665585, -0.005052},{1.022754, 1.666418, -0.006077}}],
    Polygon[{{1.020545, 1.666573, -0.005052},{1.020131, 1.666003, -0.003902},{
      1.022266, 1.664915, -0.003902},{1.022483, 1.665585, -0.005052}}],
    Polygon[{{1.020131, 1.666003, -0.003902},{1.019827, 1.665585, -0.002656},{
      1.022106, 1.664424, -0.002656},{1.022266, 1.664915, -0.003902}}],
    Polygon[{{1.019827, 1.665585, -0.002656},{1.019642, 1.665331, -0.001344},{
      1.022009, 1.664125, -0.001344},{1.022106, 1.664424, -0.002656}}],
    Polygon[{{1.019642, 1.665331, -0.001344},{1.019580, 1.665245, 0.000000},{
      1.021976, 1.664024, 0.000000},{1.022009, 1.664125, -0.001344}}],
    Polygon[{{1.019580, 1.665245, 0.000000},{1.019642, 1.665331, 0.001344},{
      1.022009, 1.664125, 0.001344},{1.021976, 1.664024, 0.000000}}],
    Polygon[{{1.019642, 1.665331, 0.001344},{1.019827, 1.665585, 0.002656},{
      1.022106, 1.664424, 0.002656},{1.022009, 1.664125, 0.001344}}],
    Polygon[{{1.019827, 1.665585, 0.002656},{1.020131, 1.666003, 0.003902},{
      1.022266, 1.664915, 0.003902},{1.022106, 1.664424, 0.002656}}],
    Polygon[{{1.020131, 1.666003, 0.003902},{1.020545, 1.666573, 0.005052},{
      1.022483, 1.665585, 0.005052},{1.022266, 1.664915, 0.003902}}],
    Polygon[{{1.020545, 1.666573, 0.005052},{1.021060, 1.667281, 0.006077},{
      1.022754, 1.666418, 0.006077},{1.022483, 1.665585, 0.005052}}],
    Polygon[{{1.021060, 1.667281, 0.006077},{1.021663, 1.668111, 0.006953},{
      1.023071, 1.667394, 0.006953},{1.022754, 1.666418, 0.006077}}],
    Polygon[{{1.021663, 1.668111, 0.006953},{1.022339, 1.669041, 0.007658},{
      1.023426, 1.668487, 0.007658},{1.023071, 1.667394, 0.006953}}],
    Polygon[{{1.022339, 1.669041, 0.007658},{1.023071, 1.670049, 0.008174},{
      1.023811, 1.669672, 0.008174},{1.023426, 1.668487, 0.007658}}],
    Polygon[{{1.023071, 1.670049, 0.008174},{1.023842, 1.671110, 0.008489},{
      1.024217, 1.670919, 0.008489},{1.023811, 1.669672, 0.008174}}],
    Polygon[{{1.024217, 1.670919, -0.008489},{1.023811, 1.669672, -0.008174},{
      1.024632, 1.669542, -0.008174},{1.024632, 1.670853, -0.008489}}],
    Polygon[{{1.023811, 1.669672, -0.008174},{1.023426, 1.668487, -0.007658},{
      1.024632, 1.668296, -0.007658},{1.024632, 1.669542, -0.008174}}],
    Polygon[{{1.023426, 1.668487, -0.007658},{1.023071, 1.667394, -0.006953},{
      1.024632, 1.667146, -0.006953},{1.024632, 1.668296, -0.007658}}],
    Polygon[{{1.023071, 1.667394, -0.006953},{1.022754, 1.666418, -0.006077},{
      1.024632, 1.666121, -0.006077},{1.024632, 1.667146, -0.006953}}],
    Polygon[{{1.022754, 1.666418, -0.006077},{1.022483, 1.665585, -0.005052},{
      1.024632, 1.665245, -0.005052},{1.024632, 1.666121, -0.006077}}],
    Polygon[{{1.022483, 1.665585, -0.005052},{1.022266, 1.664915, -0.003902},{
      1.024632, 1.664540, -0.003902},{1.024632, 1.665245, -0.005052}}],
    Polygon[{{1.022266, 1.664915, -0.003902},{1.022106, 1.664424, -0.002656},{
      1.024632, 1.664024, -0.002656},{1.024632, 1.664540, -0.003902}}],
    Polygon[{{1.022106, 1.664424, -0.002656},{1.022009, 1.664125, -0.001344},{
      1.024632, 1.663709, -0.001344},{1.024632, 1.664024, -0.002656}}],
    Polygon[{{1.022009, 1.664125, -0.001344},{1.021976, 1.664024, 0.000000},{
      1.024632, 1.663604, 0.000000},{1.024632, 1.663709, -0.001344}}],
    Polygon[{{1.021976, 1.664024, 0.000000},{1.022009, 1.664125, 0.001344},{
      1.024632, 1.663709, 0.001344},{1.024632, 1.663604, 0.000000}}],
    Polygon[{{1.022009, 1.664125, 0.001344},{1.022106, 1.664424, 0.002656},{
      1.024632, 1.664024, 0.002656},{1.024632, 1.663709, 0.001344}}],
    Polygon[{{1.022106, 1.664424, 0.002656},{1.022266, 1.664915, 0.003902},{
      1.024632, 1.664540, 0.003902},{1.024632, 1.664024, 0.002656}}],
    Polygon[{{1.022266, 1.664915, 0.003902},{1.022483, 1.665585, 0.005052},{
      1.024632, 1.665245, 0.005052},{1.024632, 1.664540, 0.003902}}],
    Polygon[{{1.022483, 1.665585, 0.005052},{1.022754, 1.666418, 0.006077},{
      1.024632, 1.666121, 0.006077},{1.024632, 1.665245, 0.005052}}],
    Polygon[{{1.022754, 1.666418, 0.006077},{1.023071, 1.667394, 0.006953},{
      1.024632, 1.667146, 0.006953},{1.024632, 1.666121, 0.006077}}],
    Polygon[{{1.023071, 1.667394, 0.006953},{1.023426, 1.668487, 0.007658},{
      1.024632, 1.668296, 0.007658},{1.024632, 1.667146, 0.006953}}],
    Polygon[{{1.023426, 1.668487, 0.007658},{1.023811, 1.669672, 0.008174},{
      1.024632, 1.669542, 0.008174},{1.024632, 1.668296, 0.007658}}],
    Polygon[{{1.023811, 1.669672, 0.008174},{1.024217, 1.670919, 0.008489},{
      1.024632, 1.670853, 0.008489},{1.024632, 1.669542, 0.008174}}],
    Polygon[{{1.024632, 1.670853, -0.008489},{1.024632, 1.669542, -0.008174},{
      1.025453, 1.669672, -0.008174},{1.025047, 1.670919, -0.008489}}],
    Polygon[{{1.024632, 1.669542, -0.008174},{1.024632, 1.668296, -0.007658},{
      1.025838, 1.668487, -0.007658},{1.025453, 1.669672, -0.008174}}],
    Polygon[{{1.024632, 1.668296, -0.007658},{1.024632, 1.667146, -0.006953},{
      1.026193, 1.667394, -0.006953},{1.025838, 1.668487, -0.007658}}],
    Polygon[{{1.024632, 1.667146, -0.006953},{1.024632, 1.666121, -0.006077},{
      1.026510, 1.666418, -0.006077},{1.026193, 1.667394, -0.006953}}],
    Polygon[{{1.024632, 1.666121, -0.006077},{1.024632, 1.665245, -0.005052},{
      1.026781, 1.665585, -0.005052},{1.026510, 1.666418, -0.006077}}],
    Polygon[{{1.024632, 1.665245, -0.005052},{1.024632, 1.664540, -0.003902},{
      1.026998, 1.664915, -0.003902},{1.026781, 1.665585, -0.005052}}],
    Polygon[{{1.024632, 1.664540, -0.003902},{1.024632, 1.664024, -0.002656},{
      1.027158, 1.664424, -0.002656},{1.026998, 1.664915, -0.003902}}],
    Polygon[{{1.024632, 1.664024, -0.002656},{1.024632, 1.663709, -0.001344},{
      1.027255, 1.664125, -0.001344},{1.027158, 1.664424, -0.002656}}],
    Polygon[{{1.024632, 1.663709, -0.001344},{1.024632, 1.663604, 0.000000},{
      1.027288, 1.664024, 0.000000},{1.027255, 1.664125, -0.001344}}],
    Polygon[{{1.024632, 1.663604, 0.000000},{1.024632, 1.663709, 0.001344},{
      1.027255, 1.664125, 0.001344},{1.027288, 1.664024, 0.000000}}],
    Polygon[{{1.024632, 1.663709, 0.001344},{1.024632, 1.664024, 0.002656},{
      1.027158, 1.664424, 0.002656},{1.027255, 1.664125, 0.001344}}],
    Polygon[{{1.024632, 1.664024, 0.002656},{1.024632, 1.664540, 0.003902},{
      1.026998, 1.664915, 0.003902},{1.027158, 1.664424, 0.002656}}],
    Polygon[{{1.024632, 1.664540, 0.003902},{1.024632, 1.665245, 0.005052},{
      1.026781, 1.665585, 0.005052},{1.026998, 1.664915, 0.003902}}],
    Polygon[{{1.024632, 1.665245, 0.005052},{1.024632, 1.666121, 0.006077},{
      1.026510, 1.666418, 0.006077},{1.026781, 1.665585, 0.005052}}],
    Polygon[{{1.024632, 1.666121, 0.006077},{1.024632, 1.667146, 0.006953},{
      1.026193, 1.667394, 0.006953},{1.026510, 1.666418, 0.006077}}],
    Polygon[{{1.024632, 1.667146, 0.006953},{1.024632, 1.668296, 0.007658},{
      1.025838, 1.668487, 0.007658},{1.026193, 1.667394, 0.006953}}],
    Polygon[{{1.024632, 1.668296, 0.007658},{1.024632, 1.669542, 0.008174},{
      1.025453, 1.669672, 0.008174},{1.025838, 1.668487, 0.007658}}],
    Polygon[{{1.024632, 1.669542, 0.008174},{1.024632, 1.670853, 0.008489},{
      1.025047, 1.670919, 0.008489},{1.025453, 1.669672, 0.008174}}],
    Polygon[{{1.025047, 1.670919, -0.008489},{1.025453, 1.669672, -0.008174},{
      1.026193, 1.670049, -0.008174},{1.025422, 1.671110, -0.008489}}],
    Polygon[{{1.025453, 1.669672, -0.008174},{1.025838, 1.668487, -0.007658},{
      1.026925, 1.669041, -0.007658},{1.026193, 1.670049, -0.008174}}],
    Polygon[{{1.025838, 1.668487, -0.007658},{1.026193, 1.667394, -0.006953},{
      1.027601, 1.668111, -0.006953},{1.026925, 1.669041, -0.007658}}],
    Polygon[{{1.026193, 1.667394, -0.006953},{1.026510, 1.666418, -0.006077},{
      1.028204, 1.667281, -0.006077},{1.027601, 1.668111, -0.006953}}],
    Polygon[{{1.026510, 1.666418, -0.006077},{1.026781, 1.665585, -0.005052},{
      1.028719, 1.666573, -0.005052},{1.028204, 1.667281, -0.006077}}],
    Polygon[{{1.026781, 1.665585, -0.005052},{1.026998, 1.664915, -0.003902},{
      1.029133, 1.666003, -0.003902},{1.028719, 1.666573, -0.005052}}],
    Polygon[{{1.026998, 1.664915, -0.003902},{1.027158, 1.664424, -0.002656},{
      1.029436, 1.665585, -0.002656},{1.029133, 1.666003, -0.003902}}],
    Polygon[{{1.027158, 1.664424, -0.002656},{1.027255, 1.664125, -0.001344},{
      1.029621, 1.665331, -0.001344},{1.029436, 1.665585, -0.002656}}],
    Polygon[{{1.027255, 1.664125, -0.001344},{1.027288, 1.664024, 0.000000},{
      1.029684, 1.665245, 0.000000},{1.029621, 1.665331, -0.001344}}],
    Polygon[{{1.027288, 1.664024, 0.000000},{1.027255, 1.664125, 0.001344},{
      1.029621, 1.665331, 0.001344},{1.029684, 1.665245, 0.000000}}],
    Polygon[{{1.027255, 1.664125, 0.001344},{1.027158, 1.664424, 0.002656},{
      1.029436, 1.665585, 0.002656},{1.029621, 1.665331, 0.001344}}],
    Polygon[{{1.027158, 1.664424, 0.002656},{1.026998, 1.664915, 0.003902},{
      1.029133, 1.666003, 0.003902},{1.029436, 1.665585, 0.002656}}],
    Polygon[{{1.026998, 1.664915, 0.003902},{1.026781, 1.665585, 0.005052},{
      1.028719, 1.666573, 0.005052},{1.029133, 1.666003, 0.003902}}],
    Polygon[{{1.026781, 1.665585, 0.005052},{1.026510, 1.666418, 0.006077},{
      1.028204, 1.667281, 0.006077},{1.028719, 1.666573, 0.005052}}],
    Polygon[{{1.026510, 1.666418, 0.006077},{1.026193, 1.667394, 0.006953},{
      1.027601, 1.668111, 0.006953},{1.028204, 1.667281, 0.006077}}],
    Polygon[{{1.026193, 1.667394, 0.006953},{1.025838, 1.668487, 0.007658},{
      1.026925, 1.669041, 0.007658},{1.027601, 1.668111, 0.006953}}],
    Polygon[{{1.025838, 1.668487, 0.007658},{1.025453, 1.669672, 0.008174},{
      1.026193, 1.670049, 0.008174},{1.026925, 1.669041, 0.007658}}],
    Polygon[{{1.025453, 1.669672, 0.008174},{1.025047, 1.670919, 0.008489},{
      1.025422, 1.671110, 0.008489},{1.026193, 1.670049, 0.008174}}],
    Polygon[{{1.025422, 1.671110, -0.008489},{1.026193, 1.670049, -0.008174},{
      1.026781, 1.670637, -0.008174},{1.025720, 1.671408, -0.008489}}],
    Polygon[{{1.026193, 1.670049, -0.008174},{1.026925, 1.669041, -0.007658},{
      1.027789, 1.669905, -0.007658},{1.026781, 1.670637, -0.008174}}],
    Polygon[{{1.026925, 1.669041, -0.007658},{1.027601, 1.668111, -0.006953},{
      1.028719, 1.669229, -0.006953},{1.027789, 1.669905, -0.007658}}],
    Polygon[{{1.027601, 1.668111, -0.006953},{1.028204, 1.667281, -0.006077},{
      1.029549, 1.668626, -0.006077},{1.028719, 1.669229, -0.006953}}],
    Polygon[{{1.028204, 1.667281, -0.006077},{1.028719, 1.666573, -0.005052},{
      1.030257, 1.668111, -0.005052},{1.029549, 1.668626, -0.006077}}],
    Polygon[{{1.028719, 1.666573, -0.005052},{1.029133, 1.666003, -0.003902},{
      1.030827, 1.667697, -0.003902},{1.030257, 1.668111, -0.005052}}],
    Polygon[{{1.029133, 1.666003, -0.003902},{1.029436, 1.665585, -0.002656},{
      1.031245, 1.667394, -0.002656},{1.030827, 1.667697, -0.003902}}],
    Polygon[{{1.029436, 1.665585, -0.002656},{1.029621, 1.665331, -0.001344},{
      1.031500, 1.667209, -0.001344},{1.031245, 1.667394, -0.002656}}],
    Polygon[{{1.029621, 1.665331, -0.001344},{1.029684, 1.665245, 0.000000},{
      1.031585, 1.667146, 0.000000},{1.031500, 1.667209, -0.001344}}],
    Polygon[{{1.029684, 1.665245, 0.000000},{1.029621, 1.665331, 0.001344},{
      1.031500, 1.667209, 0.001344},{1.031585, 1.667146, 0.000000}}],
    Polygon[{{1.029621, 1.665331, 0.001344},{1.029436, 1.665585, 0.002656},{
      1.031245, 1.667394, 0.002656},{1.031500, 1.667209, 0.001344}}],
    Polygon[{{1.029436, 1.665585, 0.002656},{1.029133, 1.666003, 0.003902},{
      1.030827, 1.667697, 0.003902},{1.031245, 1.667394, 0.002656}}],
    Polygon[{{1.029133, 1.666003, 0.003902},{1.028719, 1.666573, 0.005052},{
      1.030257, 1.668111, 0.005052},{1.030827, 1.667697, 0.003902}}],
    Polygon[{{1.028719, 1.666573, 0.005052},{1.028204, 1.667281, 0.006077},{
      1.029549, 1.668626, 0.006077},{1.030257, 1.668111, 0.005052}}],
    Polygon[{{1.028204, 1.667281, 0.006077},{1.027601, 1.668111, 0.006953},{
      1.028719, 1.669229, 0.006953},{1.029549, 1.668626, 0.006077}}],
    Polygon[{{1.027601, 1.668111, 0.006953},{1.026925, 1.669041, 0.007658},{
      1.027789, 1.669905, 0.007658},{1.028719, 1.669229, 0.006953}}],
    Polygon[{{1.026925, 1.669041, 0.007658},{1.026193, 1.670049, 0.008174},{
      1.026781, 1.670637, 0.008174},{1.027789, 1.669905, 0.007658}}],
    Polygon[{{1.026193, 1.670049, 0.008174},{1.025422, 1.671110, 0.008489},{
      1.025720, 1.671408, 0.008489},{1.026781, 1.670637, 0.008174}}],
    Polygon[{{1.025720, 1.671408, -0.008489},{1.026781, 1.670637, -0.008174},{
      1.027158, 1.671377, -0.008174},{1.025911, 1.671782, -0.008489}}],
    Polygon[{{1.026781, 1.670637, -0.008174},{1.027789, 1.669905, -0.007658},{
      1.028343, 1.670992, -0.007658},{1.027158, 1.671377, -0.008174}}],
    Polygon[{{1.027789, 1.669905, -0.007658},{1.028719, 1.669229, -0.006953},{
      1.029436, 1.670637, -0.006953},{1.028343, 1.670992, -0.007658}}],
    Polygon[{{1.028719, 1.669229, -0.006953},{1.029549, 1.668626, -0.006077},{
      1.030412, 1.670320, -0.006077},{1.029436, 1.670637, -0.006953}}],
    Polygon[{{1.029549, 1.668626, -0.006077},{1.030257, 1.668111, -0.005052},{
      1.031245, 1.670049, -0.005052},{1.030412, 1.670320, -0.006077}}],
    Polygon[{{1.030257, 1.668111, -0.005052},{1.030827, 1.667697, -0.003902},{
      1.031915, 1.669832, -0.003902},{1.031245, 1.670049, -0.005052}}],
    Polygon[{{1.030827, 1.667697, -0.003902},{1.031245, 1.667394, -0.002656},{
      1.032406, 1.669672, -0.002656},{1.031915, 1.669832, -0.003902}}],
    Polygon[{{1.031245, 1.667394, -0.002656},{1.031500, 1.667209, -0.001344},{
      1.032705, 1.669575, -0.001344},{1.032406, 1.669672, -0.002656}}],
    Polygon[{{1.031500, 1.667209, -0.001344},{1.031585, 1.667146, 0.000000},{
      1.032806, 1.669542, 0.000000},{1.032705, 1.669575, -0.001344}}],
    Polygon[{{1.031585, 1.667146, 0.000000},{1.031500, 1.667209, 0.001344},{
      1.032705, 1.669575, 0.001344},{1.032806, 1.669542, 0.000000}}],
    Polygon[{{1.031500, 1.667209, 0.001344},{1.031245, 1.667394, 0.002656},{
      1.032406, 1.669672, 0.002656},{1.032705, 1.669575, 0.001344}}],
    Polygon[{{1.031245, 1.667394, 0.002656},{1.030827, 1.667697, 0.003902},{
      1.031915, 1.669832, 0.003902},{1.032406, 1.669672, 0.002656}}],
    Polygon[{{1.030827, 1.667697, 0.003902},{1.030257, 1.668111, 0.005052},{
      1.031245, 1.670049, 0.005052},{1.031915, 1.669832, 0.003902}}],
    Polygon[{{1.030257, 1.668111, 0.005052},{1.029549, 1.668626, 0.006077},{
      1.030412, 1.670320, 0.006077},{1.031245, 1.670049, 0.005052}}],
    Polygon[{{1.029549, 1.668626, 0.006077},{1.028719, 1.669229, 0.006953},{
      1.029436, 1.670637, 0.006953},{1.030412, 1.670320, 0.006077}}],
    Polygon[{{1.028719, 1.669229, 0.006953},{1.027789, 1.669905, 0.007658},{
      1.028343, 1.670992, 0.007658},{1.029436, 1.670637, 0.006953}}],
    Polygon[{{1.027789, 1.669905, 0.007658},{1.026781, 1.670637, 0.008174},{
      1.027158, 1.671377, 0.008174},{1.028343, 1.670992, 0.007658}}],
    Polygon[{{1.026781, 1.670637, 0.008174},{1.025720, 1.671408, 0.008489},{
      1.025911, 1.671782, 0.008489},{1.027158, 1.671377, 0.008174}}],
    Polygon[{{1.025911, 1.671782, -0.008489},{1.027158, 1.671377, -0.008174},{
      1.027288, 1.672198, -0.008174},{1.025976, 1.672198, -0.008489}}],
    Polygon[{{1.027158, 1.671377, -0.008174},{1.028343, 1.670992, -0.007658},{
      1.028534, 1.672198, -0.007658},{1.027288, 1.672198, -0.008174}}],
    Polygon[{{1.028343, 1.670992, -0.007658},{1.029436, 1.670637, -0.006953},{
      1.029684, 1.672198, -0.006953},{1.028534, 1.672198, -0.007658}}],
    Polygon[{{1.029436, 1.670637, -0.006953},{1.030412, 1.670320, -0.006077},{
      1.030709, 1.672198, -0.006077},{1.029684, 1.672198, -0.006953}}],
    Polygon[{{1.030412, 1.670320, -0.006077},{1.031245, 1.670049, -0.005052},{
      1.031585, 1.672198, -0.005052},{1.030709, 1.672198, -0.006077}}],
    Polygon[{{1.031245, 1.670049, -0.005052},{1.031915, 1.669832, -0.003902},{
      1.032290, 1.672198, -0.003902},{1.031585, 1.672198, -0.005052}}],
    Polygon[{{1.031915, 1.669832, -0.003902},{1.032406, 1.669672, -0.002656},{
      1.032806, 1.672198, -0.002656},{1.032290, 1.672198, -0.003902}}],
    Polygon[{{1.032406, 1.669672, -0.002656},{1.032705, 1.669575, -0.001344},{
      1.033121, 1.672198, -0.001344},{1.032806, 1.672198, -0.002656}}],
    Polygon[{{1.032705, 1.669575, -0.001344},{1.032806, 1.669542, 0.000000},{
      1.033226, 1.672198, 0.000000},{1.033121, 1.672198, -0.001344}}],
    Polygon[{{1.032806, 1.669542, 0.000000},{1.032705, 1.669575, 0.001344},{
      1.033121, 1.672198, 0.001344},{1.033226, 1.672198, 0.000000}}],
    Polygon[{{1.032705, 1.669575, 0.001344},{1.032406, 1.669672, 0.002656},{
      1.032806, 1.672198, 0.002656},{1.033121, 1.672198, 0.001344}}],
    Polygon[{{1.032406, 1.669672, 0.002656},{1.031915, 1.669832, 0.003902},{
      1.032290, 1.672198, 0.003902},{1.032806, 1.672198, 0.002656}}],
    Polygon[{{1.031915, 1.669832, 0.003902},{1.031245, 1.670049, 0.005052},{
      1.031585, 1.672198, 0.005052},{1.032290, 1.672198, 0.003902}}],
    Polygon[{{1.031245, 1.670049, 0.005052},{1.030412, 1.670320, 0.006077},{
      1.030709, 1.672198, 0.006077},{1.031585, 1.672198, 0.005052}}],
    Polygon[{{1.030412, 1.670320, 0.006077},{1.029436, 1.670637, 0.006953},{
      1.029684, 1.672198, 0.006953},{1.030709, 1.672198, 0.006077}}],
    Polygon[{{1.029436, 1.670637, 0.006953},{1.028343, 1.670992, 0.007658},{
      1.028534, 1.672198, 0.007658},{1.029684, 1.672198, 0.006953}}],
    Polygon[{{1.028343, 1.670992, 0.007658},{1.027158, 1.671377, 0.008174},{
      1.027288, 1.672198, 0.008174},{1.028534, 1.672198, 0.007658}}],
    Polygon[{{1.027158, 1.671377, 0.008174},{1.025911, 1.671782, 0.008489},{
      1.025976, 1.672198, 0.008489},{1.027288, 1.672198, 0.008174}}],
    Polygon[{{0.930137, 1.552492, -0.025466},{0.934072, 1.552492, -0.024521},{
      0.933682, 1.554955, -0.024521},{0.929940, 1.553739, -0.025466}}],
    Polygon[{{0.934072, 1.552492, -0.024521},{0.937809, 1.552492, -0.022973},{
      0.937237, 1.556110, -0.022973},{0.933682, 1.554955, -0.024521}}],
    Polygon[{{0.937809, 1.552492, -0.022973},{0.941259, 1.552492, -0.020859},{
      0.940517, 1.557176, -0.020859},{0.937237, 1.556110, -0.022973}}],
    Polygon[{{0.941259, 1.552492, -0.020859},{0.944336, 1.552492, -0.018232},{
      0.943443, 1.558126, -0.018232},{0.940517, 1.557176, -0.020859}}],
    Polygon[{{0.944336, 1.552492, -0.018232},{0.946963, 1.552492, -0.015155},{
      0.945942, 1.558938, -0.015155},{0.943443, 1.558126, -0.018232}}],
    Polygon[{{0.946963, 1.552492, -0.015155},{0.949077, 1.552492, -0.011705},{
      0.947953, 1.559592, -0.011705},{0.945942, 1.558938, -0.015155}}],
    Polygon[{{0.949077, 1.552492, -0.011705},{0.950626, 1.552492, -0.007968},{
      0.949425, 1.560070, -0.007968},{0.947953, 1.559592, -0.011705}}],
    Polygon[{{0.950626, 1.552492, -0.007968},{0.951570, 1.552492, -0.004033},{
      0.950324, 1.560362, -0.004033},{0.949425, 1.560070, -0.007968}}],
    Polygon[{{0.951570, 1.552492, -0.004033},{0.951887, 1.552492, 0.000000},{
      0.950626, 1.560460, 0.000000},{0.950324, 1.560362, -0.004033}}],
    Polygon[{{0.951887, 1.552492, 0.000000},{0.951570, 1.552492, 0.004033},{
      0.950324, 1.560362, 0.004033},{0.950626, 1.560460, 0.000000}}],
    Polygon[{{0.951570, 1.552492, 0.004033},{0.950626, 1.552492, 0.007968},{
      0.949425, 1.560070, 0.007968},{0.950324, 1.560362, 0.004033}}],
    Polygon[{{0.950626, 1.552492, 0.007968},{0.949077, 1.552492, 0.011705},{
      0.947953, 1.559592, 0.011705},{0.949425, 1.560070, 0.007968}}],
    Polygon[{{0.949077, 1.552492, 0.011705},{0.946963, 1.552492, 0.015155},{
      0.945942, 1.558938, 0.015155},{0.947953, 1.559592, 0.011705}}],
    Polygon[{{0.946963, 1.552492, 0.015155},{0.944336, 1.552492, 0.018232},{
      0.943443, 1.558126, 0.018232},{0.945942, 1.558938, 0.015155}}],
    Polygon[{{0.944336, 1.552492, 0.018232},{0.941259, 1.552492, 0.020859},{
      0.940517, 1.557176, 0.020859},{0.943443, 1.558126, 0.018232}}],
    Polygon[{{0.941259, 1.552492, 0.020859},{0.937809, 1.552492, 0.022973},{
      0.937237, 1.556110, 0.022973},{0.940517, 1.557176, 0.020859}}],
    Polygon[{{0.937809, 1.552492, 0.022973},{0.934072, 1.552492, 0.024521},{
      0.933682, 1.554955, 0.024521},{0.937237, 1.556110, 0.022973}}],
    Polygon[{{0.934072, 1.552492, 0.024521},{0.930137, 1.552492, 0.025466},{
      0.929940, 1.553739, 0.025466},{0.933682, 1.554955, 0.024521}}],
    Polygon[{{0.929940, 1.553739, -0.025466},{0.933682, 1.554955, -0.024521},{
      0.932550, 1.557176, -0.024521},{0.929367, 1.554863, -0.025466}}],
    Polygon[{{0.933682, 1.554955, -0.024521},{0.937237, 1.556110, -0.022973},{
      0.935574, 1.559373, -0.022973},{0.932550, 1.557176, -0.024521}}],
    Polygon[{{0.937237, 1.556110, -0.022973},{0.940517, 1.557176, -0.020859},{
      0.938365, 1.561400, -0.020859},{0.935574, 1.559373, -0.022973}}],
    Polygon[{{0.940517, 1.557176, -0.020859},{0.943443, 1.558126, -0.018232},{
      0.940854, 1.563209, -0.018232},{0.938365, 1.561400, -0.020859}}],
    Polygon[{{0.943443, 1.558126, -0.018232},{0.945942, 1.558938, -0.015155},{
      0.942980, 1.564753, -0.015155},{0.940854, 1.563209, -0.018232}}],
    Polygon[{{0.945942, 1.558938, -0.015155},{0.947953, 1.559592, -0.011705},{
      0.944690, 1.565996, -0.011705},{0.942980, 1.564753, -0.015155}}],
    Polygon[{{0.947953, 1.559592, -0.011705},{0.949425, 1.560070, -0.007968},{
      0.945942, 1.566906, -0.007968},{0.944690, 1.565996, -0.011705}}],
    Polygon[{{0.949425, 1.560070, -0.007968},{0.950324, 1.560362, -0.004033},{
      0.946706, 1.567461, -0.004033},{0.945942, 1.566906, -0.007968}}],
    Polygon[{{0.950324, 1.560362, -0.004033},{0.950626, 1.560460, 0.000000},{
      0.946963, 1.567648, 0.000000},{0.946706, 1.567461, -0.004033}}],
    Polygon[{{0.950626, 1.560460, 0.000000},{0.950324, 1.560362, 0.004033},{
      0.946706, 1.567461, 0.004033},{0.946963, 1.567648, 0.000000}}],
    Polygon[{{0.950324, 1.560362, 0.004033},{0.949425, 1.560070, 0.007968},{
      0.945942, 1.566906, 0.007968},{0.946706, 1.567461, 0.004033}}],
    Polygon[{{0.949425, 1.560070, 0.007968},{0.947953, 1.559592, 0.011705},{
      0.944690, 1.565996, 0.011705},{0.945942, 1.566906, 0.007968}}],
    Polygon[{{0.947953, 1.559592, 0.011705},{0.945942, 1.558938, 0.015155},{
      0.942980, 1.564753, 0.015155},{0.944690, 1.565996, 0.011705}}],
    Polygon[{{0.945942, 1.558938, 0.015155},{0.943443, 1.558126, 0.018232},{
      0.940854, 1.563209, 0.018232},{0.942980, 1.564753, 0.015155}}],
    Polygon[{{0.943443, 1.558126, 0.018232},{0.940517, 1.557176, 0.020859},{
      0.938365, 1.561400, 0.020859},{0.940854, 1.563209, 0.018232}}],
    Polygon[{{0.940517, 1.557176, 0.020859},{0.937237, 1.556110, 0.022973},{
      0.935574, 1.559373, 0.022973},{0.938365, 1.561400, 0.020859}}],
    Polygon[{{0.937237, 1.556110, 0.022973},{0.933682, 1.554955, 0.024521},{
      0.932550, 1.557176, 0.024521},{0.935574, 1.559373, 0.022973}}],
    Polygon[{{0.933682, 1.554955, 0.024521},{0.929940, 1.553739, 0.025466},{
      0.929367, 1.554863, 0.025466},{0.932550, 1.557176, 0.024521}}],
    Polygon[{{0.929367, 1.554863, -0.025466},{0.932550, 1.557176, -0.024521},{
      0.930787, 1.558938, -0.024521},{0.928475, 1.555755, -0.025466}}],
    Polygon[{{0.932550, 1.557176, -0.024521},{0.935574, 1.559373, -0.022973},{
      0.932984, 1.561962, -0.022973},{0.930787, 1.558938, -0.024521}}],
    Polygon[{{0.935574, 1.559373, -0.022973},{0.938365, 1.561400, -0.020859},{
      0.935012, 1.564753, -0.020859},{0.932984, 1.561962, -0.022973}}],
    Polygon[{{0.938365, 1.561400, -0.020859},{0.940854, 1.563209, -0.018232},{
      0.936820, 1.567242, -0.018232},{0.935012, 1.564753, -0.020859}}],
    Polygon[{{0.940854, 1.563209, -0.018232},{0.942980, 1.564753, -0.015155},{
      0.938365, 1.569368, -0.015155},{0.936820, 1.567242, -0.018232}}],
    Polygon[{{0.942980, 1.564753, -0.015155},{0.944690, 1.565996, -0.011705},{
      0.939607, 1.571078, -0.011705},{0.938365, 1.569368, -0.015155}}],
    Polygon[{{0.944690, 1.565996, -0.011705},{0.945942, 1.566906, -0.007968},{
      0.940517, 1.572331, -0.007968},{0.939607, 1.571078, -0.011705}}],
    Polygon[{{0.945942, 1.566906, -0.007968},{0.946706, 1.567461, -0.004033},{
      0.941073, 1.573095, -0.004033},{0.940517, 1.572331, -0.007968}}],
    Polygon[{{0.946706, 1.567461, -0.004033},{0.946963, 1.567648, 0.000000},{
      0.941259, 1.573352, 0.000000},{0.941073, 1.573095, -0.004033}}],
    Polygon[{{0.946963, 1.567648, 0.000000},{0.946706, 1.567461, 0.004033},{
      0.941073, 1.573095, 0.004033},{0.941259, 1.573352, 0.000000}}],
    Polygon[{{0.946706, 1.567461, 0.004033},{0.945942, 1.566906, 0.007968},{
      0.940517, 1.572331, 0.007968},{0.941073, 1.573095, 0.004033}}],
    Polygon[{{0.945942, 1.566906, 0.007968},{0.944690, 1.565996, 0.011705},{
      0.939607, 1.571078, 0.011705},{0.940517, 1.572331, 0.007968}}],
    Polygon[{{0.944690, 1.565996, 0.011705},{0.942980, 1.564753, 0.015155},{
      0.938365, 1.569368, 0.015155},{0.939607, 1.571078, 0.011705}}],
    Polygon[{{0.942980, 1.564753, 0.015155},{0.940854, 1.563209, 0.018232},{
      0.936820, 1.567242, 0.018232},{0.938365, 1.569368, 0.015155}}],
    Polygon[{{0.940854, 1.563209, 0.018232},{0.938365, 1.561400, 0.020859},{
      0.935012, 1.564753, 0.020859},{0.936820, 1.567242, 0.018232}}],
    Polygon[{{0.938365, 1.561400, 0.020859},{0.935574, 1.559373, 0.022973},{
      0.932984, 1.561962, 0.022973},{0.935012, 1.564753, 0.020859}}],
    Polygon[{{0.935574, 1.559373, 0.022973},{0.932550, 1.557176, 0.024521},{
      0.930787, 1.558938, 0.024521},{0.932984, 1.561962, 0.022973}}],
    Polygon[{{0.932550, 1.557176, 0.024521},{0.929367, 1.554863, 0.025466},{
      0.928475, 1.555755, 0.025466},{0.930787, 1.558938, 0.024521}}],
    Polygon[{{0.928475, 1.555755, -0.025466},{0.930787, 1.558938, -0.024521},{
      0.928566, 1.560070, -0.024521},{0.927350, 1.556328, -0.025466}}],
    Polygon[{{0.930787, 1.558938, -0.024521},{0.932984, 1.561962, -0.022973},{
      0.929721, 1.563625, -0.022973},{0.928566, 1.560070, -0.024521}}],
    Polygon[{{0.932984, 1.561962, -0.022973},{0.935012, 1.564753, -0.020859},{
      0.930787, 1.566906, -0.020859},{0.929721, 1.563625, -0.022973}}],
    Polygon[{{0.935012, 1.564753, -0.020859},{0.936820, 1.567242, -0.018232},{
      0.931738, 1.569832, -0.018232},{0.930787, 1.566906, -0.020859}}],
    Polygon[{{0.936820, 1.567242, -0.018232},{0.938365, 1.569368, -0.015155},{
      0.932550, 1.572331, -0.015155},{0.931738, 1.569832, -0.018232}}],
    Polygon[{{0.938365, 1.569368, -0.015155},{0.939607, 1.571078, -0.011705},{
      0.933203, 1.574341, -0.011705},{0.932550, 1.572331, -0.015155}}],
    Polygon[{{0.939607, 1.571078, -0.011705},{0.940517, 1.572331, -0.007968},{
      0.933682, 1.575814, -0.007968},{0.933203, 1.574341, -0.011705}}],
    Polygon[{{0.940517, 1.572331, -0.007968},{0.941073, 1.573095, -0.004033},{
      0.933973, 1.576712, -0.004033},{0.933682, 1.575814, -0.007968}}],
    Polygon[{{0.941073, 1.573095, -0.004033},{0.941259, 1.573352, 0.000000},{
      0.934072, 1.577014, 0.000000},{0.933973, 1.576712, -0.004033}}],
    Polygon[{{0.941259, 1.573352, 0.000000},{0.941073, 1.573095, 0.004033},{
      0.933973, 1.576712, 0.004033},{0.934072, 1.577014, 0.000000}}],
    Polygon[{{0.941073, 1.573095, 0.004033},{0.940517, 1.572331, 0.007968},{
      0.933682, 1.575814, 0.007968},{0.933973, 1.576712, 0.004033}}],
    Polygon[{{0.940517, 1.572331, 0.007968},{0.939607, 1.571078, 0.011705},{
      0.933203, 1.574341, 0.011705},{0.933682, 1.575814, 0.007968}}],
    Polygon[{{0.939607, 1.571078, 0.011705},{0.938365, 1.569368, 0.015155},{
      0.932550, 1.572331, 0.015155},{0.933203, 1.574341, 0.011705}}],
    Polygon[{{0.938365, 1.569368, 0.015155},{0.936820, 1.567242, 0.018232},{
      0.931738, 1.569832, 0.018232},{0.932550, 1.572331, 0.015155}}],
    Polygon[{{0.936820, 1.567242, 0.018232},{0.935012, 1.564753, 0.020859},{
      0.930787, 1.566906, 0.020859},{0.931738, 1.569832, 0.018232}}],
    Polygon[{{0.935012, 1.564753, 0.020859},{0.932984, 1.561962, 0.022973},{
      0.929721, 1.563625, 0.022973},{0.930787, 1.566906, 0.020859}}],
    Polygon[{{0.932984, 1.561962, 0.022973},{0.930787, 1.558938, 0.024521},{
      0.928566, 1.560070, 0.024521},{0.929721, 1.563625, 0.022973}}],
    Polygon[{{0.930787, 1.558938, 0.024521},{0.928475, 1.555755, 0.025466},{
      0.927350, 1.556328, 0.025466},{0.928566, 1.560070, 0.024521}}],
    Polygon[{{0.927350, 1.556328, -0.025466},{0.928566, 1.560070, -0.024521},{
      0.926104, 1.560460, -0.024521},{0.926104, 1.556526, -0.025466}}],
    Polygon[{{0.928566, 1.560070, -0.024521},{0.929721, 1.563625, -0.022973},{
      0.926104, 1.564198, -0.022973},{0.926104, 1.560460, -0.024521}}],
    Polygon[{{0.929721, 1.563625, -0.022973},{0.930787, 1.566906, -0.020859},{
      0.926104, 1.567648, -0.020859},{0.926104, 1.564198, -0.022973}}],
    Polygon[{{0.930787, 1.566906, -0.020859},{0.931738, 1.569832, -0.018232},{
      0.926104, 1.570724, -0.018232},{0.926104, 1.567648, -0.020859}}],
    Polygon[{{0.931738, 1.569832, -0.018232},{0.932550, 1.572331, -0.015155},{
      0.926104, 1.573352, -0.015155},{0.926104, 1.570724, -0.018232}}],
    Polygon[{{0.932550, 1.572331, -0.015155},{0.933203, 1.574341, -0.011705},{
      0.926104, 1.575466, -0.011705},{0.926104, 1.573352, -0.015155}}],
    Polygon[{{0.933203, 1.574341, -0.011705},{0.933682, 1.575814, -0.007968},{
      0.926104, 1.577014, -0.007968},{0.926104, 1.575466, -0.011705}}],
    Polygon[{{0.933682, 1.575814, -0.007968},{0.933973, 1.576712, -0.004033},{
      0.926104, 1.577958, -0.004033},{0.926104, 1.577014, -0.007968}}],
    Polygon[{{0.933973, 1.576712, -0.004033},{0.934072, 1.577014, 0.000000},{
      0.926104, 1.578276, 0.000000},{0.926104, 1.577958, -0.004033}}],
    Polygon[{{0.934072, 1.577014, 0.000000},{0.933973, 1.576712, 0.004033},{
      0.926104, 1.577958, 0.004033},{0.926104, 1.578276, 0.000000}}],
    Polygon[{{0.933973, 1.576712, 0.004033},{0.933682, 1.575814, 0.007968},{
      0.926104, 1.577014, 0.007968},{0.926104, 1.577958, 0.004033}}],
    Polygon[{{0.933682, 1.575814, 0.007968},{0.933203, 1.574341, 0.011705},{
      0.926104, 1.575466, 0.011705},{0.926104, 1.577014, 0.007968}}],
    Polygon[{{0.933203, 1.574341, 0.011705},{0.932550, 1.572331, 0.015155},{
      0.926104, 1.573352, 0.015155},{0.926104, 1.575466, 0.011705}}],
    Polygon[{{0.932550, 1.572331, 0.015155},{0.931738, 1.569832, 0.018232},{
      0.926104, 1.570724, 0.018232},{0.926104, 1.573352, 0.015155}}],
    Polygon[{{0.931738, 1.569832, 0.018232},{0.930787, 1.566906, 0.020859},{
      0.926104, 1.567648, 0.020859},{0.926104, 1.570724, 0.018232}}],
    Polygon[{{0.930787, 1.566906, 0.020859},{0.929721, 1.563625, 0.022973},{
      0.926104, 1.564198, 0.022973},{0.926104, 1.567648, 0.020859}}],
    Polygon[{{0.929721, 1.563625, 0.022973},{0.928566, 1.560070, 0.024521},{
      0.926104, 1.560460, 0.024521},{0.926104, 1.564198, 0.022973}}],
    Polygon[{{0.928566, 1.560070, 0.024521},{0.927350, 1.556328, 0.025466},{
      0.926104, 1.556526, 0.025466},{0.926104, 1.560460, 0.024521}}],
    Polygon[{{0.926104, 1.556526, -0.025466},{0.926104, 1.560460, -0.024521},{
      0.923642, 1.560070, -0.024521},{0.924858, 1.556328, -0.025466}}],
    Polygon[{{0.926104, 1.560460, -0.024521},{0.926104, 1.564198, -0.022973},{
      0.922487, 1.563625, -0.022973},{0.923642, 1.560070, -0.024521}}],
    Polygon[{{0.926104, 1.564198, -0.022973},{0.926104, 1.567648, -0.020859},{
      0.921421, 1.566906, -0.020859},{0.922487, 1.563625, -0.022973}}],
    Polygon[{{0.926104, 1.567648, -0.020859},{0.926104, 1.570724, -0.018232},{
      0.920470, 1.569832, -0.018232},{0.921421, 1.566906, -0.020859}}],
    Polygon[{{0.926104, 1.570724, -0.018232},{0.926104, 1.573352, -0.015155},{
      0.919658, 1.572331, -0.015155},{0.920470, 1.569832, -0.018232}}],
    Polygon[{{0.926104, 1.573352, -0.015155},{0.926104, 1.575466, -0.011705},{
      0.919005, 1.574341, -0.011705},{0.919658, 1.572331, -0.015155}}],
    Polygon[{{0.926104, 1.575466, -0.011705},{0.926104, 1.577014, -0.007968},{
      0.918526, 1.575814, -0.007968},{0.919005, 1.574341, -0.011705}}],
    Polygon[{{0.926104, 1.577014, -0.007968},{0.926104, 1.577958, -0.004033},{
      0.918235, 1.576712, -0.004033},{0.918526, 1.575814, -0.007968}}],
    Polygon[{{0.926104, 1.577958, -0.004033},{0.926104, 1.578276, 0.000000},{
      0.918137, 1.577014, 0.000000},{0.918235, 1.576712, -0.004033}}],
    Polygon[{{0.926104, 1.578276, 0.000000},{0.926104, 1.577958, 0.004033},{
      0.918235, 1.576712, 0.004033},{0.918137, 1.577014, 0.000000}}],
    Polygon[{{0.926104, 1.577958, 0.004033},{0.926104, 1.577014, 0.007968},{
      0.918526, 1.575814, 0.007968},{0.918235, 1.576712, 0.004033}}],
    Polygon[{{0.926104, 1.577014, 0.007968},{0.926104, 1.575466, 0.011705},{
      0.919005, 1.574341, 0.011705},{0.918526, 1.575814, 0.007968}}],
    Polygon[{{0.926104, 1.575466, 0.011705},{0.926104, 1.573352, 0.015155},{
      0.919658, 1.572331, 0.015155},{0.919005, 1.574341, 0.011705}}],
    Polygon[{{0.926104, 1.573352, 0.015155},{0.926104, 1.570724, 0.018232},{
      0.920470, 1.569832, 0.018232},{0.919658, 1.572331, 0.015155}}],
    Polygon[{{0.926104, 1.570724, 0.018232},{0.926104, 1.567648, 0.020859},{
      0.921421, 1.566906, 0.020859},{0.920470, 1.569832, 0.018232}}],
    Polygon[{{0.926104, 1.567648, 0.020859},{0.926104, 1.564198, 0.022973},{
      0.922487, 1.563625, 0.022973},{0.921421, 1.566906, 0.020859}}],
    Polygon[{{0.926104, 1.564198, 0.022973},{0.926104, 1.560460, 0.024521},{
      0.923642, 1.560070, 0.024521},{0.922487, 1.563625, 0.022973}}],
    Polygon[{{0.926104, 1.560460, 0.024521},{0.926104, 1.556526, 0.025466},{
      0.924858, 1.556328, 0.025466},{0.923642, 1.560070, 0.024521}}],
    Polygon[{{0.924858, 1.556328, -0.025466},{0.923642, 1.560070, -0.024521},{
      0.921421, 1.558938, -0.024521},{0.923733, 1.555755, -0.025466}}],
    Polygon[{{0.923642, 1.560070, -0.024521},{0.922487, 1.563625, -0.022973},{
      0.919224, 1.561962, -0.022973},{0.921421, 1.558938, -0.024521}}],
    Polygon[{{0.922487, 1.563625, -0.022973},{0.921421, 1.566906, -0.020859},{
      0.917196, 1.564753, -0.020859},{0.919224, 1.561962, -0.022973}}],
    Polygon[{{0.921421, 1.566906, -0.020859},{0.920470, 1.569832, -0.018232},{
      0.915388, 1.567242, -0.018232},{0.917196, 1.564753, -0.020859}}],
    Polygon[{{0.920470, 1.569832, -0.018232},{0.919658, 1.572331, -0.015155},{
      0.913843, 1.569368, -0.015155},{0.915388, 1.567242, -0.018232}}],
    Polygon[{{0.919658, 1.572331, -0.015155},{0.919005, 1.574341, -0.011705},{
      0.912601, 1.571078, -0.011705},{0.913843, 1.569368, -0.015155}}],
    Polygon[{{0.919005, 1.574341, -0.011705},{0.918526, 1.575814, -0.007968},{
      0.911691, 1.572331, -0.007968},{0.912601, 1.571078, -0.011705}}],
    Polygon[{{0.918526, 1.575814, -0.007968},{0.918235, 1.576712, -0.004033},{
      0.911135, 1.573095, -0.004033},{0.911691, 1.572331, -0.007968}}],
    Polygon[{{0.918235, 1.576712, -0.004033},{0.918137, 1.577014, 0.000000},{
      0.910949, 1.573352, 0.000000},{0.911135, 1.573095, -0.004033}}],
    Polygon[{{0.918137, 1.577014, 0.000000},{0.918235, 1.576712, 0.004033},{
      0.911135, 1.573095, 0.004033},{0.910949, 1.573352, 0.000000}}],
    Polygon[{{0.918235, 1.576712, 0.004033},{0.918526, 1.575814, 0.007968},{
      0.911691, 1.572331, 0.007968},{0.911135, 1.573095, 0.004033}}],
    Polygon[{{0.918526, 1.575814, 0.007968},{0.919005, 1.574341, 0.011705},{
      0.912601, 1.571078, 0.011705},{0.911691, 1.572331, 0.007968}}],
    Polygon[{{0.919005, 1.574341, 0.011705},{0.919658, 1.572331, 0.015155},{
      0.913843, 1.569368, 0.015155},{0.912601, 1.571078, 0.011705}}],
    Polygon[{{0.919658, 1.572331, 0.015155},{0.920470, 1.569832, 0.018232},{
      0.915388, 1.567242, 0.018232},{0.913843, 1.569368, 0.015155}}],
    Polygon[{{0.920470, 1.569832, 0.018232},{0.921421, 1.566906, 0.020859},{
      0.917196, 1.564753, 0.020859},{0.915388, 1.567242, 0.018232}}],
    Polygon[{{0.921421, 1.566906, 0.020859},{0.922487, 1.563625, 0.022973},{
      0.919224, 1.561962, 0.022973},{0.917196, 1.564753, 0.020859}}],
    Polygon[{{0.922487, 1.563625, 0.022973},{0.923642, 1.560070, 0.024521},{
      0.921421, 1.558938, 0.024521},{0.919224, 1.561962, 0.022973}}],
    Polygon[{{0.923642, 1.560070, 0.024521},{0.924858, 1.556328, 0.025466},{
      0.923733, 1.555755, 0.025466},{0.921421, 1.558938, 0.024521}}],
    Polygon[{{0.923733, 1.555755, -0.025466},{0.921421, 1.558938, -0.024521},{
      0.919658, 1.557176, -0.024521},{0.922841, 1.554863, -0.025466}}],
    Polygon[{{0.921421, 1.558938, -0.024521},{0.919224, 1.561962, -0.022973},{
      0.916634, 1.559373, -0.022973},{0.919658, 1.557176, -0.024521}}],
    Polygon[{{0.919224, 1.561962, -0.022973},{0.917196, 1.564753, -0.020859},{
      0.913843, 1.561400, -0.020859},{0.916634, 1.559373, -0.022973}}],
    Polygon[{{0.917196, 1.564753, -0.020859},{0.915388, 1.567242, -0.018232},{
      0.911354, 1.563209, -0.018232},{0.913843, 1.561400, -0.020859}}],
    Polygon[{{0.915388, 1.567242, -0.018232},{0.913843, 1.569368, -0.015155},{
      0.909229, 1.564753, -0.015155},{0.911354, 1.563209, -0.018232}}],
    Polygon[{{0.913843, 1.569368, -0.015155},{0.912601, 1.571078, -0.011705},{
      0.907518, 1.565996, -0.011705},{0.909229, 1.564753, -0.015155}}],
    Polygon[{{0.912601, 1.571078, -0.011705},{0.911691, 1.572331, -0.007968},{
      0.906266, 1.566906, -0.007968},{0.907518, 1.565996, -0.011705}}],
    Polygon[{{0.911691, 1.572331, -0.007968},{0.911135, 1.573095, -0.004033},{
      0.905502, 1.567461, -0.004033},{0.906266, 1.566906, -0.007968}}],
    Polygon[{{0.911135, 1.573095, -0.004033},{0.910949, 1.573352, 0.000000},{
      0.905245, 1.567648, 0.000000},{0.905502, 1.567461, -0.004033}}],
    Polygon[{{0.910949, 1.573352, 0.000000},{0.911135, 1.573095, 0.004033},{
      0.905502, 1.567461, 0.004033},{0.905245, 1.567648, 0.000000}}],
    Polygon[{{0.911135, 1.573095, 0.004033},{0.911691, 1.572331, 0.007968},{
      0.906266, 1.566906, 0.007968},{0.905502, 1.567461, 0.004033}}],
    Polygon[{{0.911691, 1.572331, 0.007968},{0.912601, 1.571078, 0.011705},{
      0.907518, 1.565996, 0.011705},{0.906266, 1.566906, 0.007968}}],
    Polygon[{{0.912601, 1.571078, 0.011705},{0.913843, 1.569368, 0.015155},{
      0.909229, 1.564753, 0.015155},{0.907518, 1.565996, 0.011705}}],
    Polygon[{{0.913843, 1.569368, 0.015155},{0.915388, 1.567242, 0.018232},{
      0.911354, 1.563209, 0.018232},{0.909229, 1.564753, 0.015155}}],
    Polygon[{{0.915388, 1.567242, 0.018232},{0.917196, 1.564753, 0.020859},{
      0.913843, 1.561400, 0.020859},{0.911354, 1.563209, 0.018232}}],
    Polygon[{{0.917196, 1.564753, 0.020859},{0.919224, 1.561962, 0.022973},{
      0.916634, 1.559373, 0.022973},{0.913843, 1.561400, 0.020859}}],
    Polygon[{{0.919224, 1.561962, 0.022973},{0.921421, 1.558938, 0.024521},{
      0.919658, 1.557176, 0.024521},{0.916634, 1.559373, 0.022973}}],
    Polygon[{{0.921421, 1.558938, 0.024521},{0.923733, 1.555755, 0.025466},{
      0.922841, 1.554863, 0.025466},{0.919658, 1.557176, 0.024521}}],
    Polygon[{{0.922841, 1.554863, -0.025466},{0.919658, 1.557176, -0.024521},{
      0.918526, 1.554955, -0.024521},{0.922268, 1.553739, -0.025466}}],
    Polygon[{{0.919658, 1.557176, -0.024521},{0.916634, 1.559373, -0.022973},{
      0.914972, 1.556110, -0.022973},{0.918526, 1.554955, -0.024521}}],
    Polygon[{{0.916634, 1.559373, -0.022973},{0.913843, 1.561400, -0.020859},{
      0.911691, 1.557176, -0.020859},{0.914972, 1.556110, -0.022973}}],
    Polygon[{{0.913843, 1.561400, -0.020859},{0.911354, 1.563209, -0.018232},{
      0.908765, 1.558126, -0.018232},{0.911691, 1.557176, -0.020859}}],
    Polygon[{{0.911354, 1.563209, -0.018232},{0.909229, 1.564753, -0.015155},{
      0.906266, 1.558938, -0.015155},{0.908765, 1.558126, -0.018232}}],
    Polygon[{{0.909229, 1.564753, -0.015155},{0.907518, 1.565996, -0.011705},{
      0.904255, 1.559592, -0.011705},{0.906266, 1.558938, -0.015155}}],
    Polygon[{{0.907518, 1.565996, -0.011705},{0.906266, 1.566906, -0.007968},{
      0.902783, 1.560070, -0.007968},{0.904255, 1.559592, -0.011705}}],
    Polygon[{{0.906266, 1.566906, -0.007968},{0.905502, 1.567461, -0.004033},{
      0.901884, 1.560362, -0.004033},{0.902783, 1.560070, -0.007968}}],
    Polygon[{{0.905502, 1.567461, -0.004033},{0.905245, 1.567648, 0.000000},{
      0.901583, 1.560460, 0.000000},{0.901884, 1.560362, -0.004033}}],
    Polygon[{{0.905245, 1.567648, 0.000000},{0.905502, 1.567461, 0.004033},{
      0.901884, 1.560362, 0.004033},{0.901583, 1.560460, 0.000000}}],
    Polygon[{{0.905502, 1.567461, 0.004033},{0.906266, 1.566906, 0.007968},{
      0.902783, 1.560070, 0.007968},{0.901884, 1.560362, 0.004033}}],
    Polygon[{{0.906266, 1.566906, 0.007968},{0.907518, 1.565996, 0.011705},{
      0.904255, 1.559592, 0.011705},{0.902783, 1.560070, 0.007968}}],
    Polygon[{{0.907518, 1.565996, 0.011705},{0.909229, 1.564753, 0.015155},{
      0.906266, 1.558938, 0.015155},{0.904255, 1.559592, 0.011705}}],
    Polygon[{{0.909229, 1.564753, 0.015155},{0.911354, 1.563209, 0.018232},{
      0.908765, 1.558126, 0.018232},{0.906266, 1.558938, 0.015155}}],
    Polygon[{{0.911354, 1.563209, 0.018232},{0.913843, 1.561400, 0.020859},{
      0.911691, 1.557176, 0.020859},{0.908765, 1.558126, 0.018232}}],
    Polygon[{{0.913843, 1.561400, 0.020859},{0.916634, 1.559373, 0.022973},{
      0.914972, 1.556110, 0.022973},{0.911691, 1.557176, 0.020859}}],
    Polygon[{{0.916634, 1.559373, 0.022973},{0.919658, 1.557176, 0.024521},{
      0.918526, 1.554955, 0.024521},{0.914972, 1.556110, 0.022973}}],
    Polygon[{{0.919658, 1.557176, 0.024521},{0.922841, 1.554863, 0.025466},{
      0.922268, 1.553739, 0.025466},{0.918526, 1.554955, 0.024521}}],
    Polygon[{{0.922268, 1.553739, -0.025466},{0.918526, 1.554955, -0.024521},{
      0.918137, 1.552492, -0.024521},{0.922071, 1.552492, -0.025466}}],
    Polygon[{{0.918526, 1.554955, -0.024521},{0.914972, 1.556110, -0.022973},{
      0.914399, 1.552492, -0.022973},{0.918137, 1.552492, -0.024521}}],
    Polygon[{{0.914972, 1.556110, -0.022973},{0.911691, 1.557176, -0.020859},{
      0.910949, 1.552492, -0.020859},{0.914399, 1.552492, -0.022973}}],
    Polygon[{{0.911691, 1.557176, -0.020859},{0.908765, 1.558126, -0.018232},{
      0.907872, 1.552492, -0.018232},{0.910949, 1.552492, -0.020859}}],
    Polygon[{{0.908765, 1.558126, -0.018232},{0.906266, 1.558938, -0.015155},{
      0.905245, 1.552492, -0.015155},{0.907872, 1.552492, -0.018232}}],
    Polygon[{{0.906266, 1.558938, -0.015155},{0.904255, 1.559592, -0.011705},{
      0.903131, 1.552492, -0.011705},{0.905245, 1.552492, -0.015155}}],
    Polygon[{{0.904255, 1.559592, -0.011705},{0.902783, 1.560070, -0.007968},{
      0.901583, 1.552492, -0.007968},{0.903131, 1.552492, -0.011705}}],
    Polygon[{{0.902783, 1.560070, -0.007968},{0.901884, 1.560362, -0.004033},{
      0.900638, 1.552492, -0.004033},{0.901583, 1.552492, -0.007968}}],
    Polygon[{{0.901884, 1.560362, -0.004033},{0.901583, 1.560460, 0.000000},{
      0.900321, 1.552492, 0.000000},{0.900638, 1.552492, -0.004033}}],
    Polygon[{{0.901583, 1.560460, 0.000000},{0.901884, 1.560362, 0.004033},{
      0.900638, 1.552492, 0.004033},{0.900321, 1.552492, 0.000000}}],
    Polygon[{{0.901884, 1.560362, 0.004033},{0.902783, 1.560070, 0.007968},{
      0.901583, 1.552492, 0.007968},{0.900638, 1.552492, 0.004033}}],
    Polygon[{{0.902783, 1.560070, 0.007968},{0.904255, 1.559592, 0.011705},{
      0.903131, 1.552492, 0.011705},{0.901583, 1.552492, 0.007968}}],
    Polygon[{{0.904255, 1.559592, 0.011705},{0.906266, 1.558938, 0.015155},{
      0.905245, 1.552492, 0.015155},{0.903131, 1.552492, 0.011705}}],
    Polygon[{{0.906266, 1.558938, 0.015155},{0.908765, 1.558126, 0.018232},{
      0.907872, 1.552492, 0.018232},{0.905245, 1.552492, 0.015155}}],
    Polygon[{{0.908765, 1.558126, 0.018232},{0.911691, 1.557176, 0.020859},{
      0.910949, 1.552492, 0.020859},{0.907872, 1.552492, 0.018232}}],
    Polygon[{{0.911691, 1.557176, 0.020859},{0.914972, 1.556110, 0.022973},{
      0.914399, 1.552492, 0.022973},{0.910949, 1.552492, 0.020859}}],
    Polygon[{{0.914972, 1.556110, 0.022973},{0.918526, 1.554955, 0.024521},{
      0.918137, 1.552492, 0.024521},{0.914399, 1.552492, 0.022973}}],
    Polygon[{{0.918526, 1.554955, 0.024521},{0.922268, 1.553739, 0.025466},{
      0.922071, 1.552492, 0.025466},{0.918137, 1.552492, 0.024521}}],
    Polygon[{{0.922071, 1.552492, -0.025466},{0.918137, 1.552492, -0.024521},{
      0.918526, 1.550030, -0.024521},{0.922268, 1.551246, -0.025466}}],
    Polygon[{{0.918137, 1.552492, -0.024521},{0.914399, 1.552492, -0.022973},{
      0.914972, 1.548875, -0.022973},{0.918526, 1.550030, -0.024521}}],
    Polygon[{{0.914399, 1.552492, -0.022973},{0.910949, 1.552492, -0.020859},{
      0.911691, 1.547809, -0.020859},{0.914972, 1.548875, -0.022973}}],
    Polygon[{{0.910949, 1.552492, -0.020859},{0.907872, 1.552492, -0.018232},{
      0.908765, 1.546859, -0.018232},{0.911691, 1.547809, -0.020859}}],
    Polygon[{{0.907872, 1.552492, -0.018232},{0.905245, 1.552492, -0.015155},{
      0.906266, 1.546047, -0.015155},{0.908765, 1.546859, -0.018232}}],
    Polygon[{{0.905245, 1.552492, -0.015155},{0.903131, 1.552492, -0.011705},{
      0.904255, 1.545393, -0.011705},{0.906266, 1.546047, -0.015155}}],
    Polygon[{{0.903131, 1.552492, -0.011705},{0.901583, 1.552492, -0.007968},{
      0.902783, 1.544915, -0.007968},{0.904255, 1.545393, -0.011705}}],
    Polygon[{{0.901583, 1.552492, -0.007968},{0.900638, 1.552492, -0.004033},{
      0.901884, 1.544623, -0.004033},{0.902783, 1.544915, -0.007968}}],
    Polygon[{{0.900638, 1.552492, -0.004033},{0.900321, 1.552492, 0.000000},{
      0.901583, 1.544525, 0.000000},{0.901884, 1.544623, -0.004033}}],
    Polygon[{{0.900321, 1.552492, 0.000000},{0.900638, 1.552492, 0.004033},{
      0.901884, 1.544623, 0.004033},{0.901583, 1.544525, 0.000000}}],
    Polygon[{{0.900638, 1.552492, 0.004033},{0.901583, 1.552492, 0.007968},{
      0.902783, 1.544915, 0.007968},{0.901884, 1.544623, 0.004033}}],
    Polygon[{{0.901583, 1.552492, 0.007968},{0.903131, 1.552492, 0.011705},{
      0.904255, 1.545393, 0.011705},{0.902783, 1.544915, 0.007968}}],
    Polygon[{{0.903131, 1.552492, 0.011705},{0.905245, 1.552492, 0.015155},{
      0.906266, 1.546047, 0.015155},{0.904255, 1.545393, 0.011705}}],
    Polygon[{{0.905245, 1.552492, 0.015155},{0.907872, 1.552492, 0.018232},{
      0.908765, 1.546859, 0.018232},{0.906266, 1.546047, 0.015155}}],
    Polygon[{{0.907872, 1.552492, 0.018232},{0.910949, 1.552492, 0.020859},{
      0.911691, 1.547809, 0.020859},{0.908765, 1.546859, 0.018232}}],
    Polygon[{{0.910949, 1.552492, 0.020859},{0.914399, 1.552492, 0.022973},{
      0.914972, 1.548875, 0.022973},{0.911691, 1.547809, 0.020859}}],
    Polygon[{{0.914399, 1.552492, 0.022973},{0.918137, 1.552492, 0.024521},{
      0.918526, 1.550030, 0.024521},{0.914972, 1.548875, 0.022973}}],
    Polygon[{{0.918137, 1.552492, 0.024521},{0.922071, 1.552492, 0.025466},{
      0.922268, 1.551246, 0.025466},{0.918526, 1.550030, 0.024521}}],
    Polygon[{{0.922268, 1.551246, -0.025466},{0.918526, 1.550030, -0.024521},{
      0.919658, 1.547809, -0.024521},{0.922841, 1.550122, -0.025466}}],
    Polygon[{{0.918526, 1.550030, -0.024521},{0.914972, 1.548875, -0.022973},{
      0.916634, 1.545612, -0.022973},{0.919658, 1.547809, -0.024521}}],
    Polygon[{{0.914972, 1.548875, -0.022973},{0.911691, 1.547809, -0.020859},{
      0.913843, 1.543584, -0.020859},{0.916634, 1.545612, -0.022973}}],
    Polygon[{{0.911691, 1.547809, -0.020859},{0.908765, 1.546859, -0.018232},{
      0.911354, 1.541776, -0.018232},{0.913843, 1.543584, -0.020859}}],
    Polygon[{{0.908765, 1.546859, -0.018232},{0.906266, 1.546047, -0.015155},{
      0.909229, 1.540232, -0.015155},{0.911354, 1.541776, -0.018232}}],
    Polygon[{{0.906266, 1.546047, -0.015155},{0.904255, 1.545393, -0.011705},{
      0.907518, 1.538989, -0.011705},{0.909229, 1.540232, -0.015155}}],
    Polygon[{{0.904255, 1.545393, -0.011705},{0.902783, 1.544915, -0.007968},{
      0.906266, 1.538079, -0.007968},{0.907518, 1.538989, -0.011705}}],
    Polygon[{{0.902783, 1.544915, -0.007968},{0.901884, 1.544623, -0.004033},{
      0.905502, 1.537524, -0.004033},{0.906266, 1.538079, -0.007968}}],
    Polygon[{{0.901884, 1.544623, -0.004033},{0.901583, 1.544525, 0.000000},{
      0.905245, 1.537337, 0.000000},{0.905502, 1.537524, -0.004033}}],
    Polygon[{{0.901583, 1.544525, 0.000000},{0.901884, 1.544623, 0.004033},{
      0.905502, 1.537524, 0.004033},{0.905245, 1.537337, 0.000000}}],
    Polygon[{{0.901884, 1.544623, 0.004033},{0.902783, 1.544915, 0.007968},{
      0.906266, 1.538079, 0.007968},{0.905502, 1.537524, 0.004033}}],
    Polygon[{{0.902783, 1.544915, 0.007968},{0.904255, 1.545393, 0.011705},{
      0.907518, 1.538989, 0.011705},{0.906266, 1.538079, 0.007968}}],
    Polygon[{{0.904255, 1.545393, 0.011705},{0.906266, 1.546047, 0.015155},{
      0.909229, 1.540232, 0.015155},{0.907518, 1.538989, 0.011705}}],
    Polygon[{{0.906266, 1.546047, 0.015155},{0.908765, 1.546859, 0.018232},{
      0.911354, 1.541776, 0.018232},{0.909229, 1.540232, 0.015155}}],
    Polygon[{{0.908765, 1.546859, 0.018232},{0.911691, 1.547809, 0.020859},{
      0.913843, 1.543584, 0.020859},{0.911354, 1.541776, 0.018232}}],
    Polygon[{{0.911691, 1.547809, 0.020859},{0.914972, 1.548875, 0.022973},{
      0.916634, 1.545612, 0.022973},{0.913843, 1.543584, 0.020859}}],
    Polygon[{{0.914972, 1.548875, 0.022973},{0.918526, 1.550030, 0.024521},{
      0.919658, 1.547809, 0.024521},{0.916634, 1.545612, 0.022973}}],
    Polygon[{{0.918526, 1.550030, 0.024521},{0.922268, 1.551246, 0.025466},{
      0.922841, 1.550122, 0.025466},{0.919658, 1.547809, 0.024521}}],
    Polygon[{{0.922841, 1.550122, -0.025466},{0.919658, 1.547809, -0.024521},{
      0.921421, 1.546047, -0.024521},{0.923733, 1.549229, -0.025466}}],
    Polygon[{{0.919658, 1.547809, -0.024521},{0.916634, 1.545612, -0.022973},{
      0.919224, 1.543023, -0.022973},{0.921421, 1.546047, -0.024521}}],
    Polygon[{{0.916634, 1.545612, -0.022973},{0.913843, 1.543584, -0.020859},{
      0.917196, 1.540232, -0.020859},{0.919224, 1.543023, -0.022973}}],
    Polygon[{{0.913843, 1.543584, -0.020859},{0.911354, 1.541776, -0.018232},{
      0.915388, 1.537743, -0.018232},{0.917196, 1.540232, -0.020859}}],
    Polygon[{{0.911354, 1.541776, -0.018232},{0.909229, 1.540232, -0.015155},{
      0.913843, 1.535617, -0.015155},{0.915388, 1.537743, -0.018232}}],
    Polygon[{{0.909229, 1.540232, -0.015155},{0.907518, 1.538989, -0.011705},{
      0.912601, 1.533907, -0.011705},{0.913843, 1.535617, -0.015155}}],
    Polygon[{{0.907518, 1.538989, -0.011705},{0.906266, 1.538079, -0.007968},{
      0.911691, 1.532654, -0.007968},{0.912601, 1.533907, -0.011705}}],
    Polygon[{{0.906266, 1.538079, -0.007968},{0.905502, 1.537524, -0.004033},{
      0.911135, 1.531890, -0.004033},{0.911691, 1.532654, -0.007968}}],
    Polygon[{{0.905502, 1.537524, -0.004033},{0.905245, 1.537337, 0.000000},{
      0.910949, 1.531633, 0.000000},{0.911135, 1.531890, -0.004033}}],
    Polygon[{{0.905245, 1.537337, 0.000000},{0.905502, 1.537524, 0.004033},{
      0.911135, 1.531890, 0.004033},{0.910949, 1.531633, 0.000000}}],
    Polygon[{{0.905502, 1.537524, 0.004033},{0.906266, 1.538079, 0.007968},{
      0.911691, 1.532654, 0.007968},{0.911135, 1.531890, 0.004033}}],
    Polygon[{{0.906266, 1.538079, 0.007968},{0.907518, 1.538989, 0.011705},{
      0.912601, 1.533907, 0.011705},{0.911691, 1.532654, 0.007968}}],
    Polygon[{{0.907518, 1.538989, 0.011705},{0.909229, 1.540232, 0.015155},{
      0.913843, 1.535617, 0.015155},{0.912601, 1.533907, 0.011705}}],
    Polygon[{{0.909229, 1.540232, 0.015155},{0.911354, 1.541776, 0.018232},{
      0.915388, 1.537743, 0.018232},{0.913843, 1.535617, 0.015155}}],
    Polygon[{{0.911354, 1.541776, 0.018232},{0.913843, 1.543584, 0.020859},{
      0.917196, 1.540232, 0.020859},{0.915388, 1.537743, 0.018232}}],
    Polygon[{{0.913843, 1.543584, 0.020859},{0.916634, 1.545612, 0.022973},{
      0.919224, 1.543023, 0.022973},{0.917196, 1.540232, 0.020859}}],
    Polygon[{{0.916634, 1.545612, 0.022973},{0.919658, 1.547809, 0.024521},{
      0.921421, 1.546047, 0.024521},{0.919224, 1.543023, 0.022973}}],
    Polygon[{{0.919658, 1.547809, 0.024521},{0.922841, 1.550122, 0.025466},{
      0.923733, 1.549229, 0.025466},{0.921421, 1.546047, 0.024521}}],
    Polygon[{{0.923733, 1.549229, -0.025466},{0.921421, 1.546047, -0.024521},{
      0.923642, 1.544915, -0.024521},{0.924858, 1.548656, -0.025466}}],
    Polygon[{{0.921421, 1.546047, -0.024521},{0.919224, 1.543023, -0.022973},{
      0.922487, 1.541360, -0.022973},{0.923642, 1.544915, -0.024521}}],
    Polygon[{{0.919224, 1.543023, -0.022973},{0.917196, 1.540232, -0.020859},{
      0.921421, 1.538079, -0.020859},{0.922487, 1.541360, -0.022973}}],
    Polygon[{{0.917196, 1.540232, -0.020859},{0.915388, 1.537743, -0.018232},{
      0.920470, 1.535153, -0.018232},{0.921421, 1.538079, -0.020859}}],
    Polygon[{{0.915388, 1.537743, -0.018232},{0.913843, 1.535617, -0.015155},{
      0.919658, 1.532654, -0.015155},{0.920470, 1.535153, -0.018232}}],
    Polygon[{{0.913843, 1.535617, -0.015155},{0.912601, 1.533907, -0.011705},{
      0.919005, 1.530644, -0.011705},{0.919658, 1.532654, -0.015155}}],
    Polygon[{{0.912601, 1.533907, -0.011705},{0.911691, 1.532654, -0.007968},{
      0.918526, 1.529171, -0.007968},{0.919005, 1.530644, -0.011705}}],
    Polygon[{{0.911691, 1.532654, -0.007968},{0.911135, 1.531890, -0.004033},{
      0.918235, 1.528273, -0.004033},{0.918526, 1.529171, -0.007968}}],
    Polygon[{{0.911135, 1.531890, -0.004033},{0.910949, 1.531633, 0.000000},{
      0.918137, 1.527971, 0.000000},{0.918235, 1.528273, -0.004033}}],
    Polygon[{{0.910949, 1.531633, 0.000000},{0.911135, 1.531890, 0.004033},{
      0.918235, 1.528273, 0.004033},{0.918137, 1.527971, 0.000000}}],
    Polygon[{{0.911135, 1.531890, 0.004033},{0.911691, 1.532654, 0.007968},{
      0.918526, 1.529171, 0.007968},{0.918235, 1.528273, 0.004033}}],
    Polygon[{{0.911691, 1.532654, 0.007968},{0.912601, 1.533907, 0.011705},{
      0.919005, 1.530644, 0.011705},{0.918526, 1.529171, 0.007968}}],
    Polygon[{{0.912601, 1.533907, 0.011705},{0.913843, 1.535617, 0.015155},{
      0.919658, 1.532654, 0.015155},{0.919005, 1.530644, 0.011705}}],
    Polygon[{{0.913843, 1.535617, 0.015155},{0.915388, 1.537743, 0.018232},{
      0.920470, 1.535153, 0.018232},{0.919658, 1.532654, 0.015155}}],
    Polygon[{{0.915388, 1.537743, 0.018232},{0.917196, 1.540232, 0.020859},{
      0.921421, 1.538079, 0.020859},{0.920470, 1.535153, 0.018232}}],
    Polygon[{{0.917196, 1.540232, 0.020859},{0.919224, 1.543023, 0.022973},{
      0.922487, 1.541360, 0.022973},{0.921421, 1.538079, 0.020859}}],
    Polygon[{{0.919224, 1.543023, 0.022973},{0.921421, 1.546047, 0.024521},{
      0.923642, 1.544915, 0.024521},{0.922487, 1.541360, 0.022973}}],
    Polygon[{{0.921421, 1.546047, 0.024521},{0.923733, 1.549229, 0.025466},{
      0.924858, 1.548656, 0.025466},{0.923642, 1.544915, 0.024521}}],
    Polygon[{{0.924858, 1.548656, -0.025466},{0.923642, 1.544915, -0.024521},{
      0.926104, 1.544525, -0.024521},{0.926104, 1.548459, -0.025466}}],
    Polygon[{{0.923642, 1.544915, -0.024521},{0.922487, 1.541360, -0.022973},{
      0.926104, 1.540787, -0.022973},{0.926104, 1.544525, -0.024521}}],
    Polygon[{{0.922487, 1.541360, -0.022973},{0.921421, 1.538079, -0.020859},{
      0.926104, 1.537337, -0.020859},{0.926104, 1.540787, -0.022973}}],
    Polygon[{{0.921421, 1.538079, -0.020859},{0.920470, 1.535153, -0.018232},{
      0.926104, 1.534261, -0.018232},{0.926104, 1.537337, -0.020859}}],
    Polygon[{{0.920470, 1.535153, -0.018232},{0.919658, 1.532654, -0.015155},{
      0.926104, 1.531633, -0.015155},{0.926104, 1.534261, -0.018232}}],
    Polygon[{{0.919658, 1.532654, -0.015155},{0.919005, 1.530644, -0.011705},{
      0.926104, 1.529519, -0.011705},{0.926104, 1.531633, -0.015155}}],
    Polygon[{{0.919005, 1.530644, -0.011705},{0.918526, 1.529171, -0.007968},{
      0.926104, 1.527971, -0.007968},{0.926104, 1.529519, -0.011705}}],
    Polygon[{{0.918526, 1.529171, -0.007968},{0.918235, 1.528273, -0.004033},{
      0.926104, 1.527026, -0.004033},{0.926104, 1.527971, -0.007968}}],
    Polygon[{{0.918235, 1.528273, -0.004033},{0.918137, 1.527971, 0.000000},{
      0.926104, 1.526709, 0.000000},{0.926104, 1.527026, -0.004033}}],
    Polygon[{{0.918137, 1.527971, 0.000000},{0.918235, 1.528273, 0.004033},{
      0.926104, 1.527026, 0.004033},{0.926104, 1.526709, 0.000000}}],
    Polygon[{{0.918235, 1.528273, 0.004033},{0.918526, 1.529171, 0.007968},{
      0.926104, 1.527971, 0.007968},{0.926104, 1.527026, 0.004033}}],
    Polygon[{{0.918526, 1.529171, 0.007968},{0.919005, 1.530644, 0.011705},{
      0.926104, 1.529519, 0.011705},{0.926104, 1.527971, 0.007968}}],
    Polygon[{{0.919005, 1.530644, 0.011705},{0.919658, 1.532654, 0.015155},{
      0.926104, 1.531633, 0.015155},{0.926104, 1.529519, 0.011705}}],
    Polygon[{{0.919658, 1.532654, 0.015155},{0.920470, 1.535153, 0.018232},{
      0.926104, 1.534261, 0.018232},{0.926104, 1.531633, 0.015155}}],
    Polygon[{{0.920470, 1.535153, 0.018232},{0.921421, 1.538079, 0.020859},{
      0.926104, 1.537337, 0.020859},{0.926104, 1.534261, 0.018232}}],
    Polygon[{{0.921421, 1.538079, 0.020859},{0.922487, 1.541360, 0.022973},{
      0.926104, 1.540787, 0.022973},{0.926104, 1.537337, 0.020859}}],
    Polygon[{{0.922487, 1.541360, 0.022973},{0.923642, 1.544915, 0.024521},{
      0.926104, 1.544525, 0.024521},{0.926104, 1.540787, 0.022973}}],
    Polygon[{{0.923642, 1.544915, 0.024521},{0.924858, 1.548656, 0.025466},{
      0.926104, 1.548459, 0.025466},{0.926104, 1.544525, 0.024521}}],
    Polygon[{{0.926104, 1.548459, -0.025466},{0.926104, 1.544525, -0.024521},{
      0.928566, 1.544915, -0.024521},{0.927350, 1.548656, -0.025466}}],
    Polygon[{{0.926104, 1.544525, -0.024521},{0.926104, 1.540787, -0.022973},{
      0.929721, 1.541360, -0.022973},{0.928566, 1.544915, -0.024521}}],
    Polygon[{{0.926104, 1.540787, -0.022973},{0.926104, 1.537337, -0.020859},{
      0.930787, 1.538079, -0.020859},{0.929721, 1.541360, -0.022973}}],
    Polygon[{{0.926104, 1.537337, -0.020859},{0.926104, 1.534261, -0.018232},{
      0.931738, 1.535153, -0.018232},{0.930787, 1.538079, -0.020859}}],
    Polygon[{{0.926104, 1.534261, -0.018232},{0.926104, 1.531633, -0.015155},{
      0.932550, 1.532654, -0.015155},{0.931738, 1.535153, -0.018232}}],
    Polygon[{{0.926104, 1.531633, -0.015155},{0.926104, 1.529519, -0.011705},{
      0.933203, 1.530644, -0.011705},{0.932550, 1.532654, -0.015155}}],
    Polygon[{{0.926104, 1.529519, -0.011705},{0.926104, 1.527971, -0.007968},{
      0.933682, 1.529171, -0.007968},{0.933203, 1.530644, -0.011705}}],
    Polygon[{{0.926104, 1.527971, -0.007968},{0.926104, 1.527026, -0.004033},{
      0.933973, 1.528273, -0.004033},{0.933682, 1.529171, -0.007968}}],
    Polygon[{{0.926104, 1.527026, -0.004033},{0.926104, 1.526709, 0.000000},{
      0.934072, 1.527971, 0.000000},{0.933973, 1.528273, -0.004033}}],
    Polygon[{{0.926104, 1.526709, 0.000000},{0.926104, 1.527026, 0.004033},{
      0.933973, 1.528273, 0.004033},{0.934072, 1.527971, 0.000000}}],
    Polygon[{{0.926104, 1.527026, 0.004033},{0.926104, 1.527971, 0.007968},{
      0.933682, 1.529171, 0.007968},{0.933973, 1.528273, 0.004033}}],
    Polygon[{{0.926104, 1.527971, 0.007968},{0.926104, 1.529519, 0.011705},{
      0.933203, 1.530644, 0.011705},{0.933682, 1.529171, 0.007968}}],
    Polygon[{{0.926104, 1.529519, 0.011705},{0.926104, 1.531633, 0.015155},{
      0.932550, 1.532654, 0.015155},{0.933203, 1.530644, 0.011705}}],
    Polygon[{{0.926104, 1.531633, 0.015155},{0.926104, 1.534261, 0.018232},{
      0.931738, 1.535153, 0.018232},{0.932550, 1.532654, 0.015155}}],
    Polygon[{{0.926104, 1.534261, 0.018232},{0.926104, 1.537337, 0.020859},{
      0.930787, 1.538079, 0.020859},{0.931738, 1.535153, 0.018232}}],
    Polygon[{{0.926104, 1.537337, 0.020859},{0.926104, 1.540787, 0.022973},{
      0.929721, 1.541360, 0.022973},{0.930787, 1.538079, 0.020859}}],
    Polygon[{{0.926104, 1.540787, 0.022973},{0.926104, 1.544525, 0.024521},{
      0.928566, 1.544915, 0.024521},{0.929721, 1.541360, 0.022973}}],
    Polygon[{{0.926104, 1.544525, 0.024521},{0.926104, 1.548459, 0.025466},{
      0.927350, 1.548656, 0.025466},{0.928566, 1.544915, 0.024521}}],
    Polygon[{{0.927350, 1.548656, -0.025466},{0.928566, 1.544915, -0.024521},{
      0.930787, 1.546047, -0.024521},{0.928475, 1.549229, -0.025466}}],
    Polygon[{{0.928566, 1.544915, -0.024521},{0.929721, 1.541360, -0.022973},{
      0.932984, 1.543023, -0.022973},{0.930787, 1.546047, -0.024521}}],
    Polygon[{{0.929721, 1.541360, -0.022973},{0.930787, 1.538079, -0.020859},{
      0.935012, 1.540232, -0.020859},{0.932984, 1.543023, -0.022973}}],
    Polygon[{{0.930787, 1.538079, -0.020859},{0.931738, 1.535153, -0.018232},{
      0.936820, 1.537743, -0.018232},{0.935012, 1.540232, -0.020859}}],
    Polygon[{{0.931738, 1.535153, -0.018232},{0.932550, 1.532654, -0.015155},{
      0.938365, 1.535617, -0.015155},{0.936820, 1.537743, -0.018232}}],
    Polygon[{{0.932550, 1.532654, -0.015155},{0.933203, 1.530644, -0.011705},{
      0.939607, 1.533907, -0.011705},{0.938365, 1.535617, -0.015155}}],
    Polygon[{{0.933203, 1.530644, -0.011705},{0.933682, 1.529171, -0.007968},{
      0.940517, 1.532654, -0.007968},{0.939607, 1.533907, -0.011705}}],
    Polygon[{{0.933682, 1.529171, -0.007968},{0.933973, 1.528273, -0.004033},{
      0.941073, 1.531890, -0.004033},{0.940517, 1.532654, -0.007968}}],
    Polygon[{{0.933973, 1.528273, -0.004033},{0.934072, 1.527971, 0.000000},{
      0.941259, 1.531633, 0.000000},{0.941073, 1.531890, -0.004033}}],
    Polygon[{{0.934072, 1.527971, 0.000000},{0.933973, 1.528273, 0.004033},{
      0.941073, 1.531890, 0.004033},{0.941259, 1.531633, 0.000000}}],
    Polygon[{{0.933973, 1.528273, 0.004033},{0.933682, 1.529171, 0.007968},{
      0.940517, 1.532654, 0.007968},{0.941073, 1.531890, 0.004033}}],
    Polygon[{{0.933682, 1.529171, 0.007968},{0.933203, 1.530644, 0.011705},{
      0.939607, 1.533907, 0.011705},{0.940517, 1.532654, 0.007968}}],
    Polygon[{{0.933203, 1.530644, 0.011705},{0.932550, 1.532654, 0.015155},{
      0.938365, 1.535617, 0.015155},{0.939607, 1.533907, 0.011705}}],
    Polygon[{{0.932550, 1.532654, 0.015155},{0.931738, 1.535153, 0.018232},{
      0.936820, 1.537743, 0.018232},{0.938365, 1.535617, 0.015155}}],
    Polygon[{{0.931738, 1.535153, 0.018232},{0.930787, 1.538079, 0.020859},{
      0.935012, 1.540232, 0.020859},{0.936820, 1.537743, 0.018232}}],
    Polygon[{{0.930787, 1.538079, 0.020859},{0.929721, 1.541360, 0.022973},{
      0.932984, 1.543023, 0.022973},{0.935012, 1.540232, 0.020859}}],
    Polygon[{{0.929721, 1.541360, 0.022973},{0.928566, 1.544915, 0.024521},{
      0.930787, 1.546047, 0.024521},{0.932984, 1.543023, 0.022973}}],
    Polygon[{{0.928566, 1.544915, 0.024521},{0.927350, 1.548656, 0.025466},{
      0.928475, 1.549229, 0.025466},{0.930787, 1.546047, 0.024521}}],
    Polygon[{{0.928475, 1.549229, -0.025466},{0.930787, 1.546047, -0.024521},{
      0.932550, 1.547809, -0.024521},{0.929367, 1.550122, -0.025466}}],
    Polygon[{{0.930787, 1.546047, -0.024521},{0.932984, 1.543023, -0.022973},{
      0.935574, 1.545612, -0.022973},{0.932550, 1.547809, -0.024521}}],
    Polygon[{{0.932984, 1.543023, -0.022973},{0.935012, 1.540232, -0.020859},{
      0.938365, 1.543584, -0.020859},{0.935574, 1.545612, -0.022973}}],
    Polygon[{{0.935012, 1.540232, -0.020859},{0.936820, 1.537743, -0.018232},{
      0.940854, 1.541776, -0.018232},{0.938365, 1.543584, -0.020859}}],
    Polygon[{{0.936820, 1.537743, -0.018232},{0.938365, 1.535617, -0.015155},{
      0.942980, 1.540232, -0.015155},{0.940854, 1.541776, -0.018232}}],
    Polygon[{{0.938365, 1.535617, -0.015155},{0.939607, 1.533907, -0.011705},{
      0.944690, 1.538989, -0.011705},{0.942980, 1.540232, -0.015155}}],
    Polygon[{{0.939607, 1.533907, -0.011705},{0.940517, 1.532654, -0.007968},{
      0.945942, 1.538079, -0.007968},{0.944690, 1.538989, -0.011705}}],
    Polygon[{{0.940517, 1.532654, -0.007968},{0.941073, 1.531890, -0.004033},{
      0.946706, 1.537524, -0.004033},{0.945942, 1.538079, -0.007968}}],
    Polygon[{{0.941073, 1.531890, -0.004033},{0.941259, 1.531633, 0.000000},{
      0.946963, 1.537337, 0.000000},{0.946706, 1.537524, -0.004033}}],
    Polygon[{{0.941259, 1.531633, 0.000000},{0.941073, 1.531890, 0.004033},{
      0.946706, 1.537524, 0.004033},{0.946963, 1.537337, 0.000000}}],
    Polygon[{{0.941073, 1.531890, 0.004033},{0.940517, 1.532654, 0.007968},{
      0.945942, 1.538079, 0.007968},{0.946706, 1.537524, 0.004033}}],
    Polygon[{{0.940517, 1.532654, 0.007968},{0.939607, 1.533907, 0.011705},{
      0.944690, 1.538989, 0.011705},{0.945942, 1.538079, 0.007968}}],
    Polygon[{{0.939607, 1.533907, 0.011705},{0.938365, 1.535617, 0.015155},{
      0.942980, 1.540232, 0.015155},{0.944690, 1.538989, 0.011705}}],
    Polygon[{{0.938365, 1.535617, 0.015155},{0.936820, 1.537743, 0.018232},{
      0.940854, 1.541776, 0.018232},{0.942980, 1.540232, 0.015155}}],
    Polygon[{{0.936820, 1.537743, 0.018232},{0.935012, 1.540232, 0.020859},{
      0.938365, 1.543584, 0.020859},{0.940854, 1.541776, 0.018232}}],
    Polygon[{{0.935012, 1.540232, 0.020859},{0.932984, 1.543023, 0.022973},{
      0.935574, 1.545612, 0.022973},{0.938365, 1.543584, 0.020859}}],
    Polygon[{{0.932984, 1.543023, 0.022973},{0.930787, 1.546047, 0.024521},{
      0.932550, 1.547809, 0.024521},{0.935574, 1.545612, 0.022973}}],
    Polygon[{{0.930787, 1.546047, 0.024521},{0.928475, 1.549229, 0.025466},{
      0.929367, 1.550122, 0.025466},{0.932550, 1.547809, 0.024521}}],
    Polygon[{{0.929367, 1.550122, -0.025466},{0.932550, 1.547809, -0.024521},{
      0.933682, 1.550030, -0.024521},{0.929940, 1.551246, -0.025466}}],
    Polygon[{{0.932550, 1.547809, -0.024521},{0.935574, 1.545612, -0.022973},{
      0.937237, 1.548875, -0.022973},{0.933682, 1.550030, -0.024521}}],
    Polygon[{{0.935574, 1.545612, -0.022973},{0.938365, 1.543584, -0.020859},{
      0.940517, 1.547809, -0.020859},{0.937237, 1.548875, -0.022973}}],
    Polygon[{{0.938365, 1.543584, -0.020859},{0.940854, 1.541776, -0.018232},{
      0.943443, 1.546859, -0.018232},{0.940517, 1.547809, -0.020859}}],
    Polygon[{{0.940854, 1.541776, -0.018232},{0.942980, 1.540232, -0.015155},{
      0.945942, 1.546047, -0.015155},{0.943443, 1.546859, -0.018232}}],
    Polygon[{{0.942980, 1.540232, -0.015155},{0.944690, 1.538989, -0.011705},{
      0.947953, 1.545393, -0.011705},{0.945942, 1.546047, -0.015155}}],
    Polygon[{{0.944690, 1.538989, -0.011705},{0.945942, 1.538079, -0.007968},{
      0.949425, 1.544915, -0.007968},{0.947953, 1.545393, -0.011705}}],
    Polygon[{{0.945942, 1.538079, -0.007968},{0.946706, 1.537524, -0.004033},{
      0.950324, 1.544623, -0.004033},{0.949425, 1.544915, -0.007968}}],
    Polygon[{{0.946706, 1.537524, -0.004033},{0.946963, 1.537337, 0.000000},{
      0.950626, 1.544525, 0.000000},{0.950324, 1.544623, -0.004033}}],
    Polygon[{{0.946963, 1.537337, 0.000000},{0.946706, 1.537524, 0.004033},{
      0.950324, 1.544623, 0.004033},{0.950626, 1.544525, 0.000000}}],
    Polygon[{{0.946706, 1.537524, 0.004033},{0.945942, 1.538079, 0.007968},{
      0.949425, 1.544915, 0.007968},{0.950324, 1.544623, 0.004033}}],
    Polygon[{{0.945942, 1.538079, 0.007968},{0.944690, 1.538989, 0.011705},{
      0.947953, 1.545393, 0.011705},{0.949425, 1.544915, 0.007968}}],
    Polygon[{{0.944690, 1.538989, 0.011705},{0.942980, 1.540232, 0.015155},{
      0.945942, 1.546047, 0.015155},{0.947953, 1.545393, 0.011705}}],
    Polygon[{{0.942980, 1.540232, 0.015155},{0.940854, 1.541776, 0.018232},{
      0.943443, 1.546859, 0.018232},{0.945942, 1.546047, 0.015155}}],
    Polygon[{{0.940854, 1.541776, 0.018232},{0.938365, 1.543584, 0.020859},{
      0.940517, 1.547809, 0.020859},{0.943443, 1.546859, 0.018232}}],
    Polygon[{{0.938365, 1.543584, 0.020859},{0.935574, 1.545612, 0.022973},{
      0.937237, 1.548875, 0.022973},{0.940517, 1.547809, 0.020859}}],
    Polygon[{{0.935574, 1.545612, 0.022973},{0.932550, 1.547809, 0.024521},{
      0.933682, 1.550030, 0.024521},{0.937237, 1.548875, 0.022973}}],
    Polygon[{{0.932550, 1.547809, 0.024521},{0.929367, 1.550122, 0.025466},{
      0.929940, 1.551246, 0.025466},{0.933682, 1.550030, 0.024521}}],
    Polygon[{{0.929940, 1.551246, -0.025466},{0.933682, 1.550030, -0.024521},{
      0.934072, 1.552492, -0.024521},{0.930137, 1.552492, -0.025466}}],
    Polygon[{{0.933682, 1.550030, -0.024521},{0.937237, 1.548875, -0.022973},{
      0.937809, 1.552492, -0.022973},{0.934072, 1.552492, -0.024521}}],
    Polygon[{{0.937237, 1.548875, -0.022973},{0.940517, 1.547809, -0.020859},{
      0.941259, 1.552492, -0.020859},{0.937809, 1.552492, -0.022973}}],
    Polygon[{{0.940517, 1.547809, -0.020859},{0.943443, 1.546859, -0.018232},{
      0.944336, 1.552492, -0.018232},{0.941259, 1.552492, -0.020859}}],
    Polygon[{{0.943443, 1.546859, -0.018232},{0.945942, 1.546047, -0.015155},{
      0.946963, 1.552492, -0.015155},{0.944336, 1.552492, -0.018232}}],
    Polygon[{{0.945942, 1.546047, -0.015155},{0.947953, 1.545393, -0.011705},{
      0.949077, 1.552492, -0.011705},{0.946963, 1.552492, -0.015155}}],
    Polygon[{{0.947953, 1.545393, -0.011705},{0.949425, 1.544915, -0.007968},{
      0.950626, 1.552492, -0.007968},{0.949077, 1.552492, -0.011705}}],
    Polygon[{{0.949425, 1.544915, -0.007968},{0.950324, 1.544623, -0.004033},{
      0.951570, 1.552492, -0.004033},{0.950626, 1.552492, -0.007968}}],
    Polygon[{{0.950324, 1.544623, -0.004033},{0.950626, 1.544525, 0.000000},{
      0.951887, 1.552492, 0.000000},{0.951570, 1.552492, -0.004033}}],
    Polygon[{{0.950626, 1.544525, 0.000000},{0.950324, 1.544623, 0.004033},{
      0.951570, 1.552492, 0.004033},{0.951887, 1.552492, 0.000000}}],
    Polygon[{{0.950324, 1.544623, 0.004033},{0.949425, 1.544915, 0.007968},{
      0.950626, 1.552492, 0.007968},{0.951570, 1.552492, 0.004033}}],
    Polygon[{{0.949425, 1.544915, 0.007968},{0.947953, 1.545393, 0.011705},{
      0.949077, 1.552492, 0.011705},{0.950626, 1.552492, 0.007968}}],
    Polygon[{{0.947953, 1.545393, 0.011705},{0.945942, 1.546047, 0.015155},{
      0.946963, 1.552492, 0.015155},{0.949077, 1.552492, 0.011705}}],
    Polygon[{{0.945942, 1.546047, 0.015155},{0.943443, 1.546859, 0.018232},{
      0.944336, 1.552492, 0.018232},{0.946963, 1.552492, 0.015155}}],
    Polygon[{{0.943443, 1.546859, 0.018232},{0.940517, 1.547809, 0.020859},{
      0.941259, 1.552492, 0.020859},{0.944336, 1.552492, 0.018232}}],
    Polygon[{{0.940517, 1.547809, 0.020859},{0.937237, 1.548875, 0.022973},{
      0.937809, 1.552492, 0.022973},{0.941259, 1.552492, 0.020859}}],
    Polygon[{{0.937237, 1.548875, 0.022973},{0.933682, 1.550030, 0.024521},{
      0.934072, 1.552492, 0.024521},{0.937809, 1.552492, 0.022973}}],
    Polygon[{{0.933682, 1.550030, 0.024521},{0.929940, 1.551246, 0.025466},{
      0.930137, 1.552492, 0.025466},{0.934072, 1.552492, 0.024521}}],
    Polygon[{{0.899028, 1.525783, -0.013647},{0.901136, 1.525783, -0.013141},{
      0.900927, 1.527103, -0.013141},{0.898922, 1.526451, -0.013647}}],
    Polygon[{{0.901136, 1.525783, -0.013141},{0.903139, 1.525783, -0.012311},{
      0.902832, 1.527722, -0.012311},{0.900927, 1.527103, -0.013141}}],
    Polygon[{{0.903139, 1.525783, -0.012311},{0.904988, 1.525783, -0.011178},{
      0.904590, 1.528293, -0.011178},{0.902832, 1.527722, -0.012311}}],
    Polygon[{{0.904988, 1.525783, -0.011178},{0.906637, 1.525783, -0.009770},{
      0.906158, 1.528803, -0.009770},{0.904590, 1.528293, -0.011178}}],
    Polygon[{{0.906637, 1.525783, -0.009770},{0.908045, 1.525783, -0.008122},{
      0.907498, 1.529238, -0.008122},{0.906158, 1.528803, -0.009770}}],
    Polygon[{{0.908045, 1.525783, -0.008122},{0.909178, 1.525783, -0.006273},{
      0.908575, 1.529588, -0.006273},{0.907498, 1.529238, -0.008122}}],
    Polygon[{{0.909178, 1.525783, -0.006273},{0.910007, 1.525783, -0.004270},{
      0.909364, 1.529844, -0.004270},{0.908575, 1.529588, -0.006273}}],
    Polygon[{{0.910007, 1.525783, -0.004270},{0.910513, 1.525783, -0.002162},{
      0.909846, 1.530001, -0.002162},{0.909364, 1.529844, -0.004270}}],
    Polygon[{{0.910513, 1.525783, -0.002162},{0.910684, 1.525783, 0.000000},{
      0.910007, 1.530053, 0.000000},{0.909846, 1.530001, -0.002162}}],
    Polygon[{{0.910684, 1.525783, 0.000000},{0.910513, 1.525783, 0.002162},{
      0.909846, 1.530001, 0.002162},{0.910007, 1.530053, 0.000000}}],
    Polygon[{{0.910513, 1.525783, 0.002162},{0.910007, 1.525783, 0.004270},{
      0.909364, 1.529844, 0.004270},{0.909846, 1.530001, 0.002162}}],
    Polygon[{{0.910007, 1.525783, 0.004270},{0.909178, 1.525783, 0.006273},{
      0.908575, 1.529588, 0.006273},{0.909364, 1.529844, 0.004270}}],
    Polygon[{{0.909178, 1.525783, 0.006273},{0.908045, 1.525783, 0.008122},{
      0.907498, 1.529238, 0.008122},{0.908575, 1.529588, 0.006273}}],
    Polygon[{{0.908045, 1.525783, 0.008122},{0.906637, 1.525783, 0.009770},{
      0.906158, 1.528803, 0.009770},{0.907498, 1.529238, 0.008122}}],
    Polygon[{{0.906637, 1.525783, 0.009770},{0.904988, 1.525783, 0.011178},{
      0.904590, 1.528293, 0.011178},{0.906158, 1.528803, 0.009770}}],
    Polygon[{{0.904988, 1.525783, 0.011178},{0.903139, 1.525783, 0.012311},{
      0.902832, 1.527722, 0.012311},{0.904590, 1.528293, 0.011178}}],
    Polygon[{{0.903139, 1.525783, 0.012311},{0.901136, 1.525783, 0.013141},{
      0.900927, 1.527103, 0.013141},{0.902832, 1.527722, 0.012311}}],
    Polygon[{{0.901136, 1.525783, 0.013141},{0.899028, 1.525783, 0.013647},{
      0.898922, 1.526451, 0.013647},{0.900927, 1.527103, 0.013141}}],
    Polygon[{{0.898922, 1.526451, -0.013647},{0.900927, 1.527103, -0.013141},{
      0.900321, 1.528293, -0.013141},{0.898615, 1.527054, -0.013647}}],
    Polygon[{{0.900927, 1.527103, -0.013141},{0.902832, 1.527722, -0.012311},{
      0.901941, 1.529471, -0.012311},{0.900321, 1.528293, -0.013141}}],
    Polygon[{{0.902832, 1.527722, -0.012311},{0.904590, 1.528293, -0.011178},{
      0.903437, 1.530557, -0.011178},{0.901941, 1.529471, -0.012311}}],
    Polygon[{{0.904590, 1.528293, -0.011178},{0.906158, 1.528803, -0.009770},{
      0.904771, 1.531526, -0.009770},{0.903437, 1.530557, -0.011178}}],
    Polygon[{{0.906158, 1.528803, -0.009770},{0.907498, 1.529238, -0.008122},{
      0.905910, 1.532354, -0.008122},{0.904771, 1.531526, -0.009770}}],
    Polygon[{{0.907498, 1.529238, -0.008122},{0.908575, 1.529588, -0.006273},{
      0.906826, 1.533020, -0.006273},{0.905910, 1.532354, -0.008122}}],
    Polygon[{{0.908575, 1.529588, -0.006273},{0.909364, 1.529844, -0.004270},{
      0.907498, 1.533507, -0.004270},{0.906826, 1.533020, -0.006273}}],
    Polygon[{{0.909364, 1.529844, -0.004270},{0.909846, 1.530001, -0.002162},{
      0.907907, 1.533805, -0.002162},{0.907498, 1.533507, -0.004270}}],
    Polygon[{{0.909846, 1.530001, -0.002162},{0.910007, 1.530053, 0.000000},{
      0.908045, 1.533905, 0.000000},{0.907907, 1.533805, -0.002162}}],
    Polygon[{{0.910007, 1.530053, 0.000000},{0.909846, 1.530001, 0.002162},{
      0.907907, 1.533805, 0.002162},{0.908045, 1.533905, 0.000000}}],
    Polygon[{{0.909846, 1.530001, 0.002162},{0.909364, 1.529844, 0.004270},{
      0.907498, 1.533507, 0.004270},{0.907907, 1.533805, 0.002162}}],
    Polygon[{{0.909364, 1.529844, 0.004270},{0.908575, 1.529588, 0.006273},{
      0.906826, 1.533020, 0.006273},{0.907498, 1.533507, 0.004270}}],
    Polygon[{{0.908575, 1.529588, 0.006273},{0.907498, 1.529238, 0.008122},{
      0.905910, 1.532354, 0.008122},{0.906826, 1.533020, 0.006273}}],
    Polygon[{{0.907498, 1.529238, 0.008122},{0.906158, 1.528803, 0.009770},{
      0.904771, 1.531526, 0.009770},{0.905910, 1.532354, 0.008122}}],
    Polygon[{{0.906158, 1.528803, 0.009770},{0.904590, 1.528293, 0.011178},{
      0.903437, 1.530557, 0.011178},{0.904771, 1.531526, 0.009770}}],
    Polygon[{{0.904590, 1.528293, 0.011178},{0.902832, 1.527722, 0.012311},{
      0.901941, 1.529471, 0.012311},{0.903437, 1.530557, 0.011178}}],
    Polygon[{{0.902832, 1.527722, 0.012311},{0.900927, 1.527103, 0.013141},{
      0.900321, 1.528293, 0.013141},{0.901941, 1.529471, 0.012311}}],
    Polygon[{{0.900927, 1.527103, 0.013141},{0.898922, 1.526451, 0.013647},{
      0.898615, 1.527054, 0.013647},{0.900321, 1.528293, 0.013141}}],
    Polygon[{{0.898615, 1.527054, -0.013647},{0.900321, 1.528293, -0.013141},{
      0.899376, 1.529238, -0.013141},{0.898137, 1.527532, -0.013647}}],
    Polygon[{{0.900321, 1.528293, -0.013141},{0.901941, 1.529471, -0.012311},{
      0.900553, 1.530858, -0.012311},{0.899376, 1.529238, -0.013141}}],
    Polygon[{{0.901941, 1.529471, -0.012311},{0.903437, 1.530557, -0.011178},{
      0.901640, 1.532354, -0.011178},{0.900553, 1.530858, -0.012311}}],
    Polygon[{{0.903437, 1.530557, -0.011178},{0.904771, 1.531526, -0.009770},{
      0.902609, 1.533688, -0.009770},{0.901640, 1.532354, -0.011178}}],
    Polygon[{{0.904771, 1.531526, -0.009770},{0.905910, 1.532354, -0.008122},{
      0.903437, 1.534827, -0.008122},{0.902609, 1.533688, -0.009770}}],
    Polygon[{{0.905910, 1.532354, -0.008122},{0.906826, 1.533020, -0.006273},{
      0.904103, 1.535743, -0.006273},{0.903437, 1.534827, -0.008122}}],
    Polygon[{{0.906826, 1.533020, -0.006273},{0.907498, 1.533507, -0.004270},{
      0.904590, 1.536415, -0.004270},{0.904103, 1.535743, -0.006273}}],
    Polygon[{{0.907498, 1.533507, -0.004270},{0.907907, 1.533805, -0.002162},{
      0.904888, 1.536824, -0.002162},{0.904590, 1.536415, -0.004270}}],
    Polygon[{{0.907907, 1.533805, -0.002162},{0.908045, 1.533905, 0.000000},{
      0.904988, 1.536962, 0.000000},{0.904888, 1.536824, -0.002162}}],
    Polygon[{{0.908045, 1.533905, 0.000000},{0.907907, 1.533805, 0.002162},{
      0.904888, 1.536824, 0.002162},{0.904988, 1.536962, 0.000000}}],
    Polygon[{{0.907907, 1.533805, 0.002162},{0.907498, 1.533507, 0.004270},{
      0.904590, 1.536415, 0.004270},{0.904888, 1.536824, 0.002162}}],
    Polygon[{{0.907498, 1.533507, 0.004270},{0.906826, 1.533020, 0.006273},{
      0.904103, 1.535743, 0.006273},{0.904590, 1.536415, 0.004270}}],
    Polygon[{{0.906826, 1.533020, 0.006273},{0.905910, 1.532354, 0.008122},{
      0.903437, 1.534827, 0.008122},{0.904103, 1.535743, 0.006273}}],
    Polygon[{{0.905910, 1.532354, 0.008122},{0.904771, 1.531526, 0.009770},{
      0.902609, 1.533688, 0.009770},{0.903437, 1.534827, 0.008122}}],
    Polygon[{{0.904771, 1.531526, 0.009770},{0.903437, 1.530557, 0.011178},{
      0.901640, 1.532354, 0.011178},{0.902609, 1.533688, 0.009770}}],
    Polygon[{{0.903437, 1.530557, 0.011178},{0.901941, 1.529471, 0.012311},{
      0.900553, 1.530858, 0.012311},{0.901640, 1.532354, 0.011178}}],
    Polygon[{{0.901941, 1.529471, 0.012311},{0.900321, 1.528293, 0.013141},{
      0.899376, 1.529238, 0.013141},{0.900553, 1.530858, 0.012311}}],
    Polygon[{{0.900321, 1.528293, 0.013141},{0.898615, 1.527054, 0.013647},{
      0.898137, 1.527532, 0.013647},{0.899376, 1.529238, 0.013141}}],
    Polygon[{{0.898137, 1.527532, -0.013647},{0.899376, 1.529238, -0.013141},{
      0.898186, 1.529844, -0.013141},{0.897534, 1.527839, -0.013647}}],
    Polygon[{{0.899376, 1.529238, -0.013141},{0.900553, 1.530858, -0.012311},{
      0.898805, 1.531749, -0.012311},{0.898186, 1.529844, -0.013141}}],
    Polygon[{{0.900553, 1.530858, -0.012311},{0.901640, 1.532354, -0.011178},{
      0.899376, 1.533507, -0.011178},{0.898805, 1.531749, -0.012311}}],
    Polygon[{{0.901640, 1.532354, -0.011178},{0.902609, 1.533688, -0.009770},{
      0.899885, 1.535076, -0.009770},{0.899376, 1.533507, -0.011178}}],
    Polygon[{{0.902609, 1.533688, -0.009770},{0.903437, 1.534827, -0.008122},{
      0.900321, 1.536415, -0.008122},{0.899885, 1.535076, -0.009770}}],
    Polygon[{{0.903437, 1.534827, -0.008122},{0.904103, 1.535743, -0.006273},{
      0.900671, 1.537492, -0.006273},{0.900321, 1.536415, -0.008122}}],
    Polygon[{{0.904103, 1.535743, -0.006273},{0.904590, 1.536415, -0.004270},{
      0.900927, 1.538281, -0.004270},{0.900671, 1.537492, -0.006273}}],
    Polygon[{{0.904590, 1.536415, -0.004270},{0.904888, 1.536824, -0.002162},{
      0.901084, 1.538763, -0.002162},{0.900927, 1.538281, -0.004270}}],
    Polygon[{{0.904888, 1.536824, -0.002162},{0.904988, 1.536962, 0.000000},{
      0.901136, 1.538924, 0.000000},{0.901084, 1.538763, -0.002162}}],
    Polygon[{{0.904988, 1.536962, 0.000000},{0.904888, 1.536824, 0.002162},{
      0.901084, 1.538763, 0.002162},{0.901136, 1.538924, 0.000000}}],
    Polygon[{{0.904888, 1.536824, 0.002162},{0.904590, 1.536415, 0.004270},{
      0.900927, 1.538281, 0.004270},{0.901084, 1.538763, 0.002162}}],
    Polygon[{{0.904590, 1.536415, 0.004270},{0.904103, 1.535743, 0.006273},{
      0.900671, 1.537492, 0.006273},{0.900927, 1.538281, 0.004270}}],
    Polygon[{{0.904103, 1.535743, 0.006273},{0.903437, 1.534827, 0.008122},{
      0.900321, 1.536415, 0.008122},{0.900671, 1.537492, 0.006273}}],
    Polygon[{{0.903437, 1.534827, 0.008122},{0.902609, 1.533688, 0.009770},{
      0.899885, 1.535076, 0.009770},{0.900321, 1.536415, 0.008122}}],
    Polygon[{{0.902609, 1.533688, 0.009770},{0.901640, 1.532354, 0.011178},{
      0.899376, 1.533507, 0.011178},{0.899885, 1.535076, 0.009770}}],
    Polygon[{{0.901640, 1.532354, 0.011178},{0.900553, 1.530858, 0.012311},{
      0.898805, 1.531749, 0.012311},{0.899376, 1.533507, 0.011178}}],
    Polygon[{{0.900553, 1.530858, 0.012311},{0.899376, 1.529238, 0.013141},{
      0.898186, 1.529844, 0.013141},{0.898805, 1.531749, 0.012311}}],
    Polygon[{{0.899376, 1.529238, 0.013141},{0.898137, 1.527532, 0.013647},{
      0.897534, 1.527839, 0.013647},{0.898186, 1.529844, 0.013141}}],
    Polygon[{{0.897534, 1.527839, -0.013647},{0.898186, 1.529844, -0.013141},{
      0.896866, 1.530053, -0.013141},{0.896866, 1.527945, -0.013647}}],
    Polygon[{{0.898186, 1.529844, -0.013141},{0.898805, 1.531749, -0.012311},{
      0.896866, 1.532056, -0.012311},{0.896866, 1.530053, -0.013141}}],
    Polygon[{{0.898805, 1.531749, -0.012311},{0.899376, 1.533507, -0.011178},{
      0.896866, 1.533905, -0.011178},{0.896866, 1.532056, -0.012311}}],
    Polygon[{{0.899376, 1.533507, -0.011178},{0.899885, 1.535076, -0.009770},{
      0.896866, 1.535554, -0.009770},{0.896866, 1.533905, -0.011178}}],
    Polygon[{{0.899885, 1.535076, -0.009770},{0.900321, 1.536415, -0.008122},{
      0.896866, 1.536962, -0.008122},{0.896866, 1.535554, -0.009770}}],
    Polygon[{{0.900321, 1.536415, -0.008122},{0.900671, 1.537492, -0.006273},{
      0.896866, 1.538095, -0.006273},{0.896866, 1.536962, -0.008122}}],
    Polygon[{{0.900671, 1.537492, -0.006273},{0.900927, 1.538281, -0.004270},{
      0.896866, 1.538924, -0.004270},{0.896866, 1.538095, -0.006273}}],
    Polygon[{{0.900927, 1.538281, -0.004270},{0.901084, 1.538763, -0.002162},{
      0.896866, 1.539431, -0.002162},{0.896866, 1.538924, -0.004270}}],
    Polygon[{{0.901084, 1.538763, -0.002162},{0.901136, 1.538924, 0.000000},{
      0.896866, 1.539601, 0.000000},{0.896866, 1.539431, -0.002162}}],
    Polygon[{{0.901136, 1.538924, 0.000000},{0.901084, 1.538763, 0.002162},{
      0.896866, 1.539431, 0.002162},{0.896866, 1.539601, 0.000000}}],
    Polygon[{{0.901084, 1.538763, 0.002162},{0.900927, 1.538281, 0.004270},{
      0.896866, 1.538924, 0.004270},{0.896866, 1.539431, 0.002162}}],
    Polygon[{{0.900927, 1.538281, 0.004270},{0.900671, 1.537492, 0.006273},{
      0.896866, 1.538095, 0.006273},{0.896866, 1.538924, 0.004270}}],
    Polygon[{{0.900671, 1.537492, 0.006273},{0.900321, 1.536415, 0.008122},{
      0.896866, 1.536962, 0.008122},{0.896866, 1.538095, 0.006273}}],
    Polygon[{{0.900321, 1.536415, 0.008122},{0.899885, 1.535076, 0.009770},{
      0.896866, 1.535554, 0.009770},{0.896866, 1.536962, 0.008122}}],
    Polygon[{{0.899885, 1.535076, 0.009770},{0.899376, 1.533507, 0.011178},{
      0.896866, 1.533905, 0.011178},{0.896866, 1.535554, 0.009770}}],
    Polygon[{{0.899376, 1.533507, 0.011178},{0.898805, 1.531749, 0.012311},{
      0.896866, 1.532056, 0.012311},{0.896866, 1.533905, 0.011178}}],
    Polygon[{{0.898805, 1.531749, 0.012311},{0.898186, 1.529844, 0.013141},{
      0.896866, 1.530053, 0.013141},{0.896866, 1.532056, 0.012311}}],
    Polygon[{{0.898186, 1.529844, 0.013141},{0.897534, 1.527839, 0.013647},{
      0.896866, 1.527945, 0.013647},{0.896866, 1.530053, 0.013141}}],
    Polygon[{{0.896866, 1.527945, -0.013647},{0.896866, 1.530053, -0.013141},{
      0.895547, 1.529844, -0.013141},{0.896198, 1.527839, -0.013647}}],
    Polygon[{{0.896866, 1.530053, -0.013141},{0.896866, 1.532056, -0.012311},{
      0.894928, 1.531749, -0.012311},{0.895547, 1.529844, -0.013141}}],
    Polygon[{{0.896866, 1.532056, -0.012311},{0.896866, 1.533905, -0.011178},{
      0.894357, 1.533507, -0.011178},{0.894928, 1.531749, -0.012311}}],
    Polygon[{{0.896866, 1.533905, -0.011178},{0.896866, 1.535554, -0.009770},{
      0.893847, 1.535076, -0.009770},{0.894357, 1.533507, -0.011178}}],
    Polygon[{{0.896866, 1.535554, -0.009770},{0.896866, 1.536962, -0.008122},{
      0.893412, 1.536415, -0.008122},{0.893847, 1.535076, -0.009770}}],
    Polygon[{{0.896866, 1.536962, -0.008122},{0.896866, 1.538095, -0.006273},{
      0.893062, 1.537492, -0.006273},{0.893412, 1.536415, -0.008122}}],
    Polygon[{{0.896866, 1.538095, -0.006273},{0.896866, 1.538924, -0.004270},{
      0.892806, 1.538281, -0.004270},{0.893062, 1.537492, -0.006273}}],
    Polygon[{{0.896866, 1.538924, -0.004270},{0.896866, 1.539431, -0.002162},{
      0.892649, 1.538763, -0.002162},{0.892806, 1.538281, -0.004270}}],
    Polygon[{{0.896866, 1.539431, -0.002162},{0.896866, 1.539601, 0.000000},{
      0.892597, 1.538924, 0.000000},{0.892649, 1.538763, -0.002162}}],
    Polygon[{{0.896866, 1.539601, 0.000000},{0.896866, 1.539431, 0.002162},{
      0.892649, 1.538763, 0.002162},{0.892597, 1.538924, 0.000000}}],
    Polygon[{{0.896866, 1.539431, 0.002162},{0.896866, 1.538924, 0.004270},{
      0.892806, 1.538281, 0.004270},{0.892649, 1.538763, 0.002162}}],
    Polygon[{{0.896866, 1.538924, 0.004270},{0.896866, 1.538095, 0.006273},{
      0.893062, 1.537492, 0.006273},{0.892806, 1.538281, 0.004270}}],
    Polygon[{{0.896866, 1.538095, 0.006273},{0.896866, 1.536962, 0.008122},{
      0.893412, 1.536415, 0.008122},{0.893062, 1.537492, 0.006273}}],
    Polygon[{{0.896866, 1.536962, 0.008122},{0.896866, 1.535554, 0.009770},{
      0.893847, 1.535076, 0.009770},{0.893412, 1.536415, 0.008122}}],
    Polygon[{{0.896866, 1.535554, 0.009770},{0.896866, 1.533905, 0.011178},{
      0.894357, 1.533507, 0.011178},{0.893847, 1.535076, 0.009770}}],
    Polygon[{{0.896866, 1.533905, 0.011178},{0.896866, 1.532056, 0.012311},{
      0.894928, 1.531749, 0.012311},{0.894357, 1.533507, 0.011178}}],
    Polygon[{{0.896866, 1.532056, 0.012311},{0.896866, 1.530053, 0.013141},{
      0.895547, 1.529844, 0.013141},{0.894928, 1.531749, 0.012311}}],
    Polygon[{{0.896866, 1.530053, 0.013141},{0.896866, 1.527945, 0.013647},{
      0.896198, 1.527839, 0.013647},{0.895547, 1.529844, 0.013141}}],
    Polygon[{{0.896198, 1.527839, -0.013647},{0.895547, 1.529844, -0.013141},{
      0.894357, 1.529238, -0.013141},{0.895596, 1.527532, -0.013647}}],
    Polygon[{{0.895547, 1.529844, -0.013141},{0.894928, 1.531749, -0.012311},{
      0.893179, 1.530858, -0.012311},{0.894357, 1.529238, -0.013141}}],
    Polygon[{{0.894928, 1.531749, -0.012311},{0.894357, 1.533507, -0.011178},{
      0.892093, 1.532354, -0.011178},{0.893179, 1.530858, -0.012311}}],
    Polygon[{{0.894357, 1.533507, -0.011178},{0.893847, 1.535076, -0.009770},{
      0.891123, 1.533688, -0.009770},{0.892093, 1.532354, -0.011178}}],
    Polygon[{{0.893847, 1.535076, -0.009770},{0.893412, 1.536415, -0.008122},{
      0.890296, 1.534827, -0.008122},{0.891123, 1.533688, -0.009770}}],
    Polygon[{{0.893412, 1.536415, -0.008122},{0.893062, 1.537492, -0.006273},{
      0.889630, 1.535743, -0.006273},{0.890296, 1.534827, -0.008122}}],
    Polygon[{{0.893062, 1.537492, -0.006273},{0.892806, 1.538281, -0.004270},{
      0.889142, 1.536415, -0.004270},{0.889630, 1.535743, -0.006273}}],
    Polygon[{{0.892806, 1.538281, -0.004270},{0.892649, 1.538763, -0.002162},{
      0.888845, 1.536824, -0.002162},{0.889142, 1.536415, -0.004270}}],
    Polygon[{{0.892649, 1.538763, -0.002162},{0.892597, 1.538924, 0.000000},{
      0.888745, 1.536962, 0.000000},{0.888845, 1.536824, -0.002162}}],
    Polygon[{{0.892597, 1.538924, 0.000000},{0.892649, 1.538763, 0.002162},{
      0.888845, 1.536824, 0.002162},{0.888745, 1.536962, 0.000000}}],
    Polygon[{{0.892649, 1.538763, 0.002162},{0.892806, 1.538281, 0.004270},{
      0.889142, 1.536415, 0.004270},{0.888845, 1.536824, 0.002162}}],
    Polygon[{{0.892806, 1.538281, 0.004270},{0.893062, 1.537492, 0.006273},{
      0.889630, 1.535743, 0.006273},{0.889142, 1.536415, 0.004270}}],
    Polygon[{{0.893062, 1.537492, 0.006273},{0.893412, 1.536415, 0.008122},{
      0.890296, 1.534827, 0.008122},{0.889630, 1.535743, 0.006273}}],
    Polygon[{{0.893412, 1.536415, 0.008122},{0.893847, 1.535076, 0.009770},{
      0.891123, 1.533688, 0.009770},{0.890296, 1.534827, 0.008122}}],
    Polygon[{{0.893847, 1.535076, 0.009770},{0.894357, 1.533507, 0.011178},{
      0.892093, 1.532354, 0.011178},{0.891123, 1.533688, 0.009770}}],
    Polygon[{{0.894357, 1.533507, 0.011178},{0.894928, 1.531749, 0.012311},{
      0.893179, 1.530858, 0.012311},{0.892093, 1.532354, 0.011178}}],
    Polygon[{{0.894928, 1.531749, 0.012311},{0.895547, 1.529844, 0.013141},{
      0.894357, 1.529238, 0.013141},{0.893179, 1.530858, 0.012311}}],
    Polygon[{{0.895547, 1.529844, 0.013141},{0.896198, 1.527839, 0.013647},{
      0.895596, 1.527532, 0.013647},{0.894357, 1.529238, 0.013141}}],
    Polygon[{{0.895596, 1.527532, -0.013647},{0.894357, 1.529238, -0.013141},{
      0.893412, 1.528293, -0.013141},{0.895118, 1.527054, -0.013647}}],
    Polygon[{{0.894357, 1.529238, -0.013141},{0.893179, 1.530858, -0.012311},{
      0.891791, 1.529471, -0.012311},{0.893412, 1.528293, -0.013141}}],
    Polygon[{{0.893179, 1.530858, -0.012311},{0.892093, 1.532354, -0.011178},{
      0.890296, 1.530557, -0.011178},{0.891791, 1.529471, -0.012311}}],
    Polygon[{{0.892093, 1.532354, -0.011178},{0.891123, 1.533688, -0.009770},{
      0.888962, 1.531526, -0.009770},{0.890296, 1.530557, -0.011178}}],
    Polygon[{{0.891123, 1.533688, -0.009770},{0.890296, 1.534827, -0.008122},{
      0.887823, 1.532354, -0.008122},{0.888962, 1.531526, -0.009770}}],
    Polygon[{{0.890296, 1.534827, -0.008122},{0.889630, 1.535743, -0.006273},{
      0.886906, 1.533020, -0.006273},{0.887823, 1.532354, -0.008122}}],
    Polygon[{{0.889630, 1.535743, -0.006273},{0.889142, 1.536415, -0.004270},{
      0.886235, 1.533507, -0.004270},{0.886906, 1.533020, -0.006273}}],
    Polygon[{{0.889142, 1.536415, -0.004270},{0.888845, 1.536824, -0.002162},{
      0.885826, 1.533805, -0.002162},{0.886235, 1.533507, -0.004270}}],
    Polygon[{{0.888845, 1.536824, -0.002162},{0.888745, 1.536962, 0.000000},{
      0.885688, 1.533905, 0.000000},{0.885826, 1.533805, -0.002162}}],
    Polygon[{{0.888745, 1.536962, 0.000000},{0.888845, 1.536824, 0.002162},{
      0.885826, 1.533805, 0.002162},{0.885688, 1.533905, 0.000000}}],
    Polygon[{{0.888845, 1.536824, 0.002162},{0.889142, 1.536415, 0.004270},{
      0.886235, 1.533507, 0.004270},{0.885826, 1.533805, 0.002162}}],
    Polygon[{{0.889142, 1.536415, 0.004270},{0.889630, 1.535743, 0.006273},{
      0.886906, 1.533020, 0.006273},{0.886235, 1.533507, 0.004270}}],
    Polygon[{{0.889630, 1.535743, 0.006273},{0.890296, 1.534827, 0.008122},{
      0.887823, 1.532354, 0.008122},{0.886906, 1.533020, 0.006273}}],
    Polygon[{{0.890296, 1.534827, 0.008122},{0.891123, 1.533688, 0.009770},{
      0.888962, 1.531526, 0.009770},{0.887823, 1.532354, 0.008122}}],
    Polygon[{{0.891123, 1.533688, 0.009770},{0.892093, 1.532354, 0.011178},{
      0.890296, 1.530557, 0.011178},{0.888962, 1.531526, 0.009770}}],
    Polygon[{{0.892093, 1.532354, 0.011178},{0.893179, 1.530858, 0.012311},{
      0.891791, 1.529471, 0.012311},{0.890296, 1.530557, 0.011178}}],
    Polygon[{{0.893179, 1.530858, 0.012311},{0.894357, 1.529238, 0.013141},{
      0.893412, 1.528293, 0.013141},{0.891791, 1.529471, 0.012311}}],
    Polygon[{{0.894357, 1.529238, 0.013141},{0.895596, 1.527532, 0.013647},{
      0.895118, 1.527054, 0.013647},{0.893412, 1.528293, 0.013141}}],
    Polygon[{{0.895118, 1.527054, -0.013647},{0.893412, 1.528293, -0.013141},{
      0.892806, 1.527103, -0.013141},{0.894811, 1.526451, -0.013647}}],
    Polygon[{{0.893412, 1.528293, -0.013141},{0.891791, 1.529471, -0.012311},{
      0.890900, 1.527722, -0.012311},{0.892806, 1.527103, -0.013141}}],
    Polygon[{{0.891791, 1.529471, -0.012311},{0.890296, 1.530557, -0.011178},{
      0.889142, 1.528293, -0.011178},{0.890900, 1.527722, -0.012311}}],
    Polygon[{{0.890296, 1.530557, -0.011178},{0.888962, 1.531526, -0.009770},{
      0.887574, 1.528803, -0.009770},{0.889142, 1.528293, -0.011178}}],
    Polygon[{{0.888962, 1.531526, -0.009770},{0.887823, 1.532354, -0.008122},{
      0.886235, 1.529238, -0.008122},{0.887574, 1.528803, -0.009770}}],
    Polygon[{{0.887823, 1.532354, -0.008122},{0.886906, 1.533020, -0.006273},{
      0.885158, 1.529588, -0.006273},{0.886235, 1.529238, -0.008122}}],
    Polygon[{{0.886906, 1.533020, -0.006273},{0.886235, 1.533507, -0.004270},{
      0.884368, 1.529844, -0.004270},{0.885158, 1.529588, -0.006273}}],
    Polygon[{{0.886235, 1.533507, -0.004270},{0.885826, 1.533805, -0.002162},{
      0.883887, 1.530001, -0.002162},{0.884368, 1.529844, -0.004270}}],
    Polygon[{{0.885826, 1.533805, -0.002162},{0.885688, 1.533905, 0.000000},{
      0.883725, 1.530053, 0.000000},{0.883887, 1.530001, -0.002162}}],
    Polygon[{{0.885688, 1.533905, 0.000000},{0.885826, 1.533805, 0.002162},{
      0.883887, 1.530001, 0.002162},{0.883725, 1.530053, 0.000000}}],
    Polygon[{{0.885826, 1.533805, 0.002162},{0.886235, 1.533507, 0.004270},{
      0.884368, 1.529844, 0.004270},{0.883887, 1.530001, 0.002162}}],
    Polygon[{{0.886235, 1.533507, 0.004270},{0.886906, 1.533020, 0.006273},{
      0.885158, 1.529588, 0.006273},{0.884368, 1.529844, 0.004270}}],
    Polygon[{{0.886906, 1.533020, 0.006273},{0.887823, 1.532354, 0.008122},{
      0.886235, 1.529238, 0.008122},{0.885158, 1.529588, 0.006273}}],
    Polygon[{{0.887823, 1.532354, 0.008122},{0.888962, 1.531526, 0.009770},{
      0.887574, 1.528803, 0.009770},{0.886235, 1.529238, 0.008122}}],
    Polygon[{{0.888962, 1.531526, 0.009770},{0.890296, 1.530557, 0.011178},{
      0.889142, 1.528293, 0.011178},{0.887574, 1.528803, 0.009770}}],
    Polygon[{{0.890296, 1.530557, 0.011178},{0.891791, 1.529471, 0.012311},{
      0.890900, 1.527722, 0.012311},{0.889142, 1.528293, 0.011178}}],
    Polygon[{{0.891791, 1.529471, 0.012311},{0.893412, 1.528293, 0.013141},{
      0.892806, 1.527103, 0.013141},{0.890900, 1.527722, 0.012311}}],
    Polygon[{{0.893412, 1.528293, 0.013141},{0.895118, 1.527054, 0.013647},{
      0.894811, 1.526451, 0.013647},{0.892806, 1.527103, 0.013141}}],
    Polygon[{{0.894811, 1.526451, -0.013647},{0.892806, 1.527103, -0.013141},{
      0.892597, 1.525783, -0.013141},{0.894705, 1.525783, -0.013647}}],
    Polygon[{{0.892806, 1.527103, -0.013141},{0.890900, 1.527722, -0.012311},{
      0.890593, 1.525783, -0.012311},{0.892597, 1.525783, -0.013141}}],
    Polygon[{{0.890900, 1.527722, -0.012311},{0.889142, 1.528293, -0.011178},{
      0.888745, 1.525783, -0.011178},{0.890593, 1.525783, -0.012311}}],
    Polygon[{{0.889142, 1.528293, -0.011178},{0.887574, 1.528803, -0.009770},{
      0.887096, 1.525783, -0.009770},{0.888745, 1.525783, -0.011178}}],
    Polygon[{{0.887574, 1.528803, -0.009770},{0.886235, 1.529238, -0.008122},{
      0.885688, 1.525783, -0.008122},{0.887096, 1.525783, -0.009770}}],
    Polygon[{{0.886235, 1.529238, -0.008122},{0.885158, 1.529588, -0.006273},{
      0.884555, 1.525783, -0.006273},{0.885688, 1.525783, -0.008122}}],
    Polygon[{{0.885158, 1.529588, -0.006273},{0.884368, 1.529844, -0.004270},{
      0.883725, 1.525783, -0.004270},{0.884555, 1.525783, -0.006273}}],
    Polygon[{{0.884368, 1.529844, -0.004270},{0.883887, 1.530001, -0.002162},{
      0.883219, 1.525783, -0.002162},{0.883725, 1.525783, -0.004270}}],
    Polygon[{{0.883887, 1.530001, -0.002162},{0.883725, 1.530053, 0.000000},{
      0.883049, 1.525783, 0.000000},{0.883219, 1.525783, -0.002162}}],
    Polygon[{{0.883725, 1.530053, 0.000000},{0.883887, 1.530001, 0.002162},{
      0.883219, 1.525783, 0.002162},{0.883049, 1.525783, 0.000000}}],
    Polygon[{{0.883887, 1.530001, 0.002162},{0.884368, 1.529844, 0.004270},{
      0.883725, 1.525783, 0.004270},{0.883219, 1.525783, 0.002162}}],
    Polygon[{{0.884368, 1.529844, 0.004270},{0.885158, 1.529588, 0.006273},{
      0.884555, 1.525783, 0.006273},{0.883725, 1.525783, 0.004270}}],
    Polygon[{{0.885158, 1.529588, 0.006273},{0.886235, 1.529238, 0.008122},{
      0.885688, 1.525783, 0.008122},{0.884555, 1.525783, 0.006273}}],
    Polygon[{{0.886235, 1.529238, 0.008122},{0.887574, 1.528803, 0.009770},{
      0.887096, 1.525783, 0.009770},{0.885688, 1.525783, 0.008122}}],
    Polygon[{{0.887574, 1.528803, 0.009770},{0.889142, 1.528293, 0.011178},{
      0.888745, 1.525783, 0.011178},{0.887096, 1.525783, 0.009770}}],
    Polygon[{{0.889142, 1.528293, 0.011178},{0.890900, 1.527722, 0.012311},{
      0.890593, 1.525783, 0.012311},{0.888745, 1.525783, 0.011178}}],
    Polygon[{{0.890900, 1.527722, 0.012311},{0.892806, 1.527103, 0.013141},{
      0.892597, 1.525783, 0.013141},{0.890593, 1.525783, 0.012311}}],
    Polygon[{{0.892806, 1.527103, 0.013141},{0.894811, 1.526451, 0.013647},{
      0.894705, 1.525783, 0.013647},{0.892597, 1.525783, 0.013141}}],
    Polygon[{{0.894705, 1.525783, -0.013647},{0.892597, 1.525783, -0.013141},{
      0.892806, 1.524464, -0.013141},{0.894811, 1.525115, -0.013647}}],
    Polygon[{{0.892597, 1.525783, -0.013141},{0.890593, 1.525783, -0.012311},{
      0.890900, 1.523845, -0.012311},{0.892806, 1.524464, -0.013141}}],
    Polygon[{{0.890593, 1.525783, -0.012311},{0.888745, 1.525783, -0.011178},{
      0.889142, 1.523274, -0.011178},{0.890900, 1.523845, -0.012311}}],
    Polygon[{{0.888745, 1.525783, -0.011178},{0.887096, 1.525783, -0.009770},{
      0.887574, 1.522764, -0.009770},{0.889142, 1.523274, -0.011178}}],
    Polygon[{{0.887096, 1.525783, -0.009770},{0.885688, 1.525783, -0.008122},{
      0.886235, 1.522329, -0.008122},{0.887574, 1.522764, -0.009770}}],
    Polygon[{{0.885688, 1.525783, -0.008122},{0.884555, 1.525783, -0.006273},{
      0.885158, 1.521979, -0.006273},{0.886235, 1.522329, -0.008122}}],
    Polygon[{{0.884555, 1.525783, -0.006273},{0.883725, 1.525783, -0.004270},{
      0.884368, 1.521723, -0.004270},{0.885158, 1.521979, -0.006273}}],
    Polygon[{{0.883725, 1.525783, -0.004270},{0.883219, 1.525783, -0.002162},{
      0.883887, 1.521566, -0.002162},{0.884368, 1.521723, -0.004270}}],
    Polygon[{{0.883219, 1.525783, -0.002162},{0.883049, 1.525783, 0.000000},{
      0.883725, 1.521514, 0.000000},{0.883887, 1.521566, -0.002162}}],
    Polygon[{{0.883049, 1.525783, 0.000000},{0.883219, 1.525783, 0.002162},{
      0.883887, 1.521566, 0.002162},{0.883725, 1.521514, 0.000000}}],
    Polygon[{{0.883219, 1.525783, 0.002162},{0.883725, 1.525783, 0.004270},{
      0.884368, 1.521723, 0.004270},{0.883887, 1.521566, 0.002162}}],
    Polygon[{{0.883725, 1.525783, 0.004270},{0.884555, 1.525783, 0.006273},{
      0.885158, 1.521979, 0.006273},{0.884368, 1.521723, 0.004270}}],
    Polygon[{{0.884555, 1.525783, 0.006273},{0.885688, 1.525783, 0.008122},{
      0.886235, 1.522329, 0.008122},{0.885158, 1.521979, 0.006273}}],
    Polygon[{{0.885688, 1.525783, 0.008122},{0.887096, 1.525783, 0.009770},{
      0.887574, 1.522764, 0.009770},{0.886235, 1.522329, 0.008122}}],
    Polygon[{{0.887096, 1.525783, 0.009770},{0.888745, 1.525783, 0.011178},{
      0.889142, 1.523274, 0.011178},{0.887574, 1.522764, 0.009770}}],
    Polygon[{{0.888745, 1.525783, 0.011178},{0.890593, 1.525783, 0.012311},{
      0.890900, 1.523845, 0.012311},{0.889142, 1.523274, 0.011178}}],
    Polygon[{{0.890593, 1.525783, 0.012311},{0.892597, 1.525783, 0.013141},{
      0.892806, 1.524464, 0.013141},{0.890900, 1.523845, 0.012311}}],
    Polygon[{{0.892597, 1.525783, 0.013141},{0.894705, 1.525783, 0.013647},{
      0.894811, 1.525115, 0.013647},{0.892806, 1.524464, 0.013141}}],
    Polygon[{{0.894811, 1.525115, -0.013647},{0.892806, 1.524464, -0.013141},{
      0.893412, 1.523274, -0.013141},{0.895118, 1.524513, -0.013647}}],
    Polygon[{{0.892806, 1.524464, -0.013141},{0.890900, 1.523845, -0.012311},{
      0.891791, 1.522096, -0.012311},{0.893412, 1.523274, -0.013141}}],
    Polygon[{{0.890900, 1.523845, -0.012311},{0.889142, 1.523274, -0.011178},{
      0.890296, 1.521010, -0.011178},{0.891791, 1.522096, -0.012311}}],
    Polygon[{{0.889142, 1.523274, -0.011178},{0.887574, 1.522764, -0.009770},{
      0.888962, 1.520041, -0.009770},{0.890296, 1.521010, -0.011178}}],
    Polygon[{{0.887574, 1.522764, -0.009770},{0.886235, 1.522329, -0.008122},{
      0.887823, 1.519213, -0.008122},{0.888962, 1.520041, -0.009770}}],
    Polygon[{{0.886235, 1.522329, -0.008122},{0.885158, 1.521979, -0.006273},{
      0.886906, 1.518547, -0.006273},{0.887823, 1.519213, -0.008122}}],
    Polygon[{{0.885158, 1.521979, -0.006273},{0.884368, 1.521723, -0.004270},{
      0.886235, 1.518059, -0.004270},{0.886906, 1.518547, -0.006273}}],
    Polygon[{{0.884368, 1.521723, -0.004270},{0.883887, 1.521566, -0.002162},{
      0.885826, 1.517762, -0.002162},{0.886235, 1.518059, -0.004270}}],
    Polygon[{{0.883887, 1.521566, -0.002162},{0.883725, 1.521514, 0.000000},{
      0.885688, 1.517662, 0.000000},{0.885826, 1.517762, -0.002162}}],
    Polygon[{{0.883725, 1.521514, 0.000000},{0.883887, 1.521566, 0.002162},{
      0.885826, 1.517762, 0.002162},{0.885688, 1.517662, 0.000000}}],
    Polygon[{{0.883887, 1.521566, 0.002162},{0.884368, 1.521723, 0.004270},{
      0.886235, 1.518059, 0.004270},{0.885826, 1.517762, 0.002162}}],
    Polygon[{{0.884368, 1.521723, 0.004270},{0.885158, 1.521979, 0.006273},{
      0.886906, 1.518547, 0.006273},{0.886235, 1.518059, 0.004270}}],
    Polygon[{{0.885158, 1.521979, 0.006273},{0.886235, 1.522329, 0.008122},{
      0.887823, 1.519213, 0.008122},{0.886906, 1.518547, 0.006273}}],
    Polygon[{{0.886235, 1.522329, 0.008122},{0.887574, 1.522764, 0.009770},{
      0.888962, 1.520041, 0.009770},{0.887823, 1.519213, 0.008122}}],
    Polygon[{{0.887574, 1.522764, 0.009770},{0.889142, 1.523274, 0.011178},{
      0.890296, 1.521010, 0.011178},{0.888962, 1.520041, 0.009770}}],
    Polygon[{{0.889142, 1.523274, 0.011178},{0.890900, 1.523845, 0.012311},{
      0.891791, 1.522096, 0.012311},{0.890296, 1.521010, 0.011178}}],
    Polygon[{{0.890900, 1.523845, 0.012311},{0.892806, 1.524464, 0.013141},{
      0.893412, 1.523274, 0.013141},{0.891791, 1.522096, 0.012311}}],
    Polygon[{{0.892806, 1.524464, 0.013141},{0.894811, 1.525115, 0.013647},{
      0.895118, 1.524513, 0.013647},{0.893412, 1.523274, 0.013141}}],
    Polygon[{{0.895118, 1.524513, -0.013647},{0.893412, 1.523274, -0.013141},{
      0.894357, 1.522329, -0.013141},{0.895596, 1.524035, -0.013647}}],
    Polygon[{{0.893412, 1.523274, -0.013141},{0.891791, 1.522096, -0.012311},{
      0.893179, 1.520709, -0.012311},{0.894357, 1.522329, -0.013141}}],
    Polygon[{{0.891791, 1.522096, -0.012311},{0.890296, 1.521010, -0.011178},{
      0.892093, 1.519213, -0.011178},{0.893179, 1.520709, -0.012311}}],
    Polygon[{{0.890296, 1.521010, -0.011178},{0.888962, 1.520041, -0.009770},{
      0.891123, 1.517879, -0.009770},{0.892093, 1.519213, -0.011178}}],
    Polygon[{{0.888962, 1.520041, -0.009770},{0.887823, 1.519213, -0.008122},{
      0.890296, 1.516740, -0.008122},{0.891123, 1.517879, -0.009770}}],
    Polygon[{{0.887823, 1.519213, -0.008122},{0.886906, 1.518547, -0.006273},{
      0.889630, 1.515823, -0.006273},{0.890296, 1.516740, -0.008122}}],
    Polygon[{{0.886906, 1.518547, -0.006273},{0.886235, 1.518059, -0.004270},{
      0.889142, 1.515152, -0.004270},{0.889630, 1.515823, -0.006273}}],
    Polygon[{{0.886235, 1.518059, -0.004270},{0.885826, 1.517762, -0.002162},{
      0.888845, 1.514743, -0.002162},{0.889142, 1.515152, -0.004270}}],
    Polygon[{{0.885826, 1.517762, -0.002162},{0.885688, 1.517662, 0.000000},{
      0.888745, 1.514605, 0.000000},{0.888845, 1.514743, -0.002162}}],
    Polygon[{{0.885688, 1.517662, 0.000000},{0.885826, 1.517762, 0.002162},{
      0.888845, 1.514743, 0.002162},{0.888745, 1.514605, 0.000000}}],
    Polygon[{{0.885826, 1.517762, 0.002162},{0.886235, 1.518059, 0.004270},{
      0.889142, 1.515152, 0.004270},{0.888845, 1.514743, 0.002162}}],
    Polygon[{{0.886235, 1.518059, 0.004270},{0.886906, 1.518547, 0.006273},{
      0.889630, 1.515823, 0.006273},{0.889142, 1.515152, 0.004270}}],
    Polygon[{{0.886906, 1.518547, 0.006273},{0.887823, 1.519213, 0.008122},{
      0.890296, 1.516740, 0.008122},{0.889630, 1.515823, 0.006273}}],
    Polygon[{{0.887823, 1.519213, 0.008122},{0.888962, 1.520041, 0.009770},{
      0.891123, 1.517879, 0.009770},{0.890296, 1.516740, 0.008122}}],
    Polygon[{{0.888962, 1.520041, 0.009770},{0.890296, 1.521010, 0.011178},{
      0.892093, 1.519213, 0.011178},{0.891123, 1.517879, 0.009770}}],
    Polygon[{{0.890296, 1.521010, 0.011178},{0.891791, 1.522096, 0.012311},{
      0.893179, 1.520709, 0.012311},{0.892093, 1.519213, 0.011178}}],
    Polygon[{{0.891791, 1.522096, 0.012311},{0.893412, 1.523274, 0.013141},{
      0.894357, 1.522329, 0.013141},{0.893179, 1.520709, 0.012311}}],
    Polygon[{{0.893412, 1.523274, 0.013141},{0.895118, 1.524513, 0.013647},{
      0.895596, 1.524035, 0.013647},{0.894357, 1.522329, 0.013141}}],
    Polygon[{{0.895596, 1.524035, -0.013647},{0.894357, 1.522329, -0.013141},{
      0.895547, 1.521723, -0.013141},{0.896198, 1.523728, -0.013647}}],
    Polygon[{{0.894357, 1.522329, -0.013141},{0.893179, 1.520709, -0.012311},{
      0.894928, 1.519817, -0.012311},{0.895547, 1.521723, -0.013141}}],
    Polygon[{{0.893179, 1.520709, -0.012311},{0.892093, 1.519213, -0.011178},{
      0.894357, 1.518059, -0.011178},{0.894928, 1.519817, -0.012311}}],
    Polygon[{{0.892093, 1.519213, -0.011178},{0.891123, 1.517879, -0.009770},{
      0.893847, 1.516491, -0.009770},{0.894357, 1.518059, -0.011178}}],
    Polygon[{{0.891123, 1.517879, -0.009770},{0.890296, 1.516740, -0.008122},{
      0.893412, 1.515152, -0.008122},{0.893847, 1.516491, -0.009770}}],
    Polygon[{{0.890296, 1.516740, -0.008122},{0.889630, 1.515823, -0.006273},{
      0.893062, 1.514075, -0.006273},{0.893412, 1.515152, -0.008122}}],
    Polygon[{{0.889630, 1.515823, -0.006273},{0.889142, 1.515152, -0.004270},{
      0.892806, 1.513286, -0.004270},{0.893062, 1.514075, -0.006273}}],
    Polygon[{{0.889142, 1.515152, -0.004270},{0.888845, 1.514743, -0.002162},{
      0.892649, 1.512804, -0.002162},{0.892806, 1.513286, -0.004270}}],
    Polygon[{{0.888845, 1.514743, -0.002162},{0.888745, 1.514605, 0.000000},{
      0.892597, 1.512642, 0.000000},{0.892649, 1.512804, -0.002162}}],
    Polygon[{{0.888745, 1.514605, 0.000000},{0.888845, 1.514743, 0.002162},{
      0.892649, 1.512804, 0.002162},{0.892597, 1.512642, 0.000000}}],
    Polygon[{{0.888845, 1.514743, 0.002162},{0.889142, 1.515152, 0.004270},{
      0.892806, 1.513286, 0.004270},{0.892649, 1.512804, 0.002162}}],
    Polygon[{{0.889142, 1.515152, 0.004270},{0.889630, 1.515823, 0.006273},{
      0.893062, 1.514075, 0.006273},{0.892806, 1.513286, 0.004270}}],
    Polygon[{{0.889630, 1.515823, 0.006273},{0.890296, 1.516740, 0.008122},{
      0.893412, 1.515152, 0.008122},{0.893062, 1.514075, 0.006273}}],
    Polygon[{{0.890296, 1.516740, 0.008122},{0.891123, 1.517879, 0.009770},{
      0.893847, 1.516491, 0.009770},{0.893412, 1.515152, 0.008122}}],
    Polygon[{{0.891123, 1.517879, 0.009770},{0.892093, 1.519213, 0.011178},{
      0.894357, 1.518059, 0.011178},{0.893847, 1.516491, 0.009770}}],
    Polygon[{{0.892093, 1.519213, 0.011178},{0.893179, 1.520709, 0.012311},{
      0.894928, 1.519817, 0.012311},{0.894357, 1.518059, 0.011178}}],
    Polygon[{{0.893179, 1.520709, 0.012311},{0.894357, 1.522329, 0.013141},{
      0.895547, 1.521723, 0.013141},{0.894928, 1.519817, 0.012311}}],
    Polygon[{{0.894357, 1.522329, 0.013141},{0.895596, 1.524035, 0.013647},{
      0.896198, 1.523728, 0.013647},{0.895547, 1.521723, 0.013141}}],
    Polygon[{{0.896198, 1.523728, -0.013647},{0.895547, 1.521723, -0.013141},{
      0.896866, 1.521514, -0.013141},{0.896866, 1.523622, -0.013647}}],
    Polygon[{{0.895547, 1.521723, -0.013141},{0.894928, 1.519817, -0.012311},{
      0.896866, 1.519511, -0.012311},{0.896866, 1.521514, -0.013141}}],
    Polygon[{{0.894928, 1.519817, -0.012311},{0.894357, 1.518059, -0.011178},{
      0.896866, 1.517662, -0.011178},{0.896866, 1.519511, -0.012311}}],
    Polygon[{{0.894357, 1.518059, -0.011178},{0.893847, 1.516491, -0.009770},{
      0.896866, 1.516013, -0.009770},{0.896866, 1.517662, -0.011178}}],
    Polygon[{{0.893847, 1.516491, -0.009770},{0.893412, 1.515152, -0.008122},{
      0.896866, 1.514605, -0.008122},{0.896866, 1.516013, -0.009770}}],
    Polygon[{{0.893412, 1.515152, -0.008122},{0.893062, 1.514075, -0.006273},{
      0.896866, 1.513472, -0.006273},{0.896866, 1.514605, -0.008122}}],
    Polygon[{{0.893062, 1.514075, -0.006273},{0.892806, 1.513286, -0.004270},{
      0.896866, 1.512642, -0.004270},{0.896866, 1.513472, -0.006273}}],
    Polygon[{{0.892806, 1.513286, -0.004270},{0.892649, 1.512804, -0.002162},{
      0.896866, 1.512136, -0.002162},{0.896866, 1.512642, -0.004270}}],
    Polygon[{{0.892649, 1.512804, -0.002162},{0.892597, 1.512642, 0.000000},{
      0.896866, 1.511966, 0.000000},{0.896866, 1.512136, -0.002162}}],
    Polygon[{{0.892597, 1.512642, 0.000000},{0.892649, 1.512804, 0.002162},{
      0.896866, 1.512136, 0.002162},{0.896866, 1.511966, 0.000000}}],
    Polygon[{{0.892649, 1.512804, 0.002162},{0.892806, 1.513286, 0.004270},{
      0.896866, 1.512642, 0.004270},{0.896866, 1.512136, 0.002162}}],
    Polygon[{{0.892806, 1.513286, 0.004270},{0.893062, 1.514075, 0.006273},{
      0.896866, 1.513472, 0.006273},{0.896866, 1.512642, 0.004270}}],
    Polygon[{{0.893062, 1.514075, 0.006273},{0.893412, 1.515152, 0.008122},{
      0.896866, 1.514605, 0.008122},{0.896866, 1.513472, 0.006273}}],
    Polygon[{{0.893412, 1.515152, 0.008122},{0.893847, 1.516491, 0.009770},{
      0.896866, 1.516013, 0.009770},{0.896866, 1.514605, 0.008122}}],
    Polygon[{{0.893847, 1.516491, 0.009770},{0.894357, 1.518059, 0.011178},{
      0.896866, 1.517662, 0.011178},{0.896866, 1.516013, 0.009770}}],
    Polygon[{{0.894357, 1.518059, 0.011178},{0.894928, 1.519817, 0.012311},{
      0.896866, 1.519511, 0.012311},{0.896866, 1.517662, 0.011178}}],
    Polygon[{{0.894928, 1.519817, 0.012311},{0.895547, 1.521723, 0.013141},{
      0.896866, 1.521514, 0.013141},{0.896866, 1.519511, 0.012311}}],
    Polygon[{{0.895547, 1.521723, 0.013141},{0.896198, 1.523728, 0.013647},{
      0.896866, 1.523622, 0.013647},{0.896866, 1.521514, 0.013141}}],
    Polygon[{{0.896866, 1.523622, -0.013647},{0.896866, 1.521514, -0.013141},{
      0.898186, 1.521723, -0.013141},{0.897534, 1.523728, -0.013647}}],
    Polygon[{{0.896866, 1.521514, -0.013141},{0.896866, 1.519511, -0.012311},{
      0.898805, 1.519817, -0.012311},{0.898186, 1.521723, -0.013141}}],
    Polygon[{{0.896866, 1.519511, -0.012311},{0.896866, 1.517662, -0.011178},{
      0.899376, 1.518059, -0.011178},{0.898805, 1.519817, -0.012311}}],
    Polygon[{{0.896866, 1.517662, -0.011178},{0.896866, 1.516013, -0.009770},{
      0.899885, 1.516491, -0.009770},{0.899376, 1.518059, -0.011178}}],
    Polygon[{{0.896866, 1.516013, -0.009770},{0.896866, 1.514605, -0.008122},{
      0.900321, 1.515152, -0.008122},{0.899885, 1.516491, -0.009770}}],
    Polygon[{{0.896866, 1.514605, -0.008122},{0.896866, 1.513472, -0.006273},{
      0.900671, 1.514075, -0.006273},{0.900321, 1.515152, -0.008122}}],
    Polygon[{{0.896866, 1.513472, -0.006273},{0.896866, 1.512642, -0.004270},{
      0.900927, 1.513286, -0.004270},{0.900671, 1.514075, -0.006273}}],
    Polygon[{{0.896866, 1.512642, -0.004270},{0.896866, 1.512136, -0.002162},{
      0.901084, 1.512804, -0.002162},{0.900927, 1.513286, -0.004270}}],
    Polygon[{{0.896866, 1.512136, -0.002162},{0.896866, 1.511966, 0.000000},{
      0.901136, 1.512642, 0.000000},{0.901084, 1.512804, -0.002162}}],
    Polygon[{{0.896866, 1.511966, 0.000000},{0.896866, 1.512136, 0.002162},{
      0.901084, 1.512804, 0.002162},{0.901136, 1.512642, 0.000000}}],
    Polygon[{{0.896866, 1.512136, 0.002162},{0.896866, 1.512642, 0.004270},{
      0.900927, 1.513286, 0.004270},{0.901084, 1.512804, 0.002162}}],
    Polygon[{{0.896866, 1.512642, 0.004270},{0.896866, 1.513472, 0.006273},{
      0.900671, 1.514075, 0.006273},{0.900927, 1.513286, 0.004270}}],
    Polygon[{{0.896866, 1.513472, 0.006273},{0.896866, 1.514605, 0.008122},{
      0.900321, 1.515152, 0.008122},{0.900671, 1.514075, 0.006273}}],
    Polygon[{{0.896866, 1.514605, 0.008122},{0.896866, 1.516013, 0.009770},{
      0.899885, 1.516491, 0.009770},{0.900321, 1.515152, 0.008122}}],
    Polygon[{{0.896866, 1.516013, 0.009770},{0.896866, 1.517662, 0.011178},{
      0.899376, 1.518059, 0.011178},{0.899885, 1.516491, 0.009770}}],
    Polygon[{{0.896866, 1.517662, 0.011178},{0.896866, 1.519511, 0.012311},{
      0.898805, 1.519817, 0.012311},{0.899376, 1.518059, 0.011178}}],
    Polygon[{{0.896866, 1.519511, 0.012311},{0.896866, 1.521514, 0.013141},{
      0.898186, 1.521723, 0.013141},{0.898805, 1.519817, 0.012311}}],
    Polygon[{{0.896866, 1.521514, 0.013141},{0.896866, 1.523622, 0.013647},{
      0.897534, 1.523728, 0.013647},{0.898186, 1.521723, 0.013141}}],
    Polygon[{{0.897534, 1.523728, -0.013647},{0.898186, 1.521723, -0.013141},{
      0.899376, 1.522329, -0.013141},{0.898137, 1.524035, -0.013647}}],
    Polygon[{{0.898186, 1.521723, -0.013141},{0.898805, 1.519817, -0.012311},{
      0.900553, 1.520709, -0.012311},{0.899376, 1.522329, -0.013141}}],
    Polygon[{{0.898805, 1.519817, -0.012311},{0.899376, 1.518059, -0.011178},{
      0.901640, 1.519213, -0.011178},{0.900553, 1.520709, -0.012311}}],
    Polygon[{{0.899376, 1.518059, -0.011178},{0.899885, 1.516491, -0.009770},{
      0.902609, 1.517879, -0.009770},{0.901640, 1.519213, -0.011178}}],
    Polygon[{{0.899885, 1.516491, -0.009770},{0.900321, 1.515152, -0.008122},{
      0.903437, 1.516740, -0.008122},{0.902609, 1.517879, -0.009770}}],
    Polygon[{{0.900321, 1.515152, -0.008122},{0.900671, 1.514075, -0.006273},{
      0.904103, 1.515823, -0.006273},{0.903437, 1.516740, -0.008122}}],
    Polygon[{{0.900671, 1.514075, -0.006273},{0.900927, 1.513286, -0.004270},{
      0.904590, 1.515152, -0.004270},{0.904103, 1.515823, -0.006273}}],
    Polygon[{{0.900927, 1.513286, -0.004270},{0.901084, 1.512804, -0.002162},{
      0.904888, 1.514743, -0.002162},{0.904590, 1.515152, -0.004270}}],
    Polygon[{{0.901084, 1.512804, -0.002162},{0.901136, 1.512642, 0.000000},{
      0.904988, 1.514605, 0.000000},{0.904888, 1.514743, -0.002162}}],
    Polygon[{{0.901136, 1.512642, 0.000000},{0.901084, 1.512804, 0.002162},{
      0.904888, 1.514743, 0.002162},{0.904988, 1.514605, 0.000000}}],
    Polygon[{{0.901084, 1.512804, 0.002162},{0.900927, 1.513286, 0.004270},{
      0.904590, 1.515152, 0.004270},{0.904888, 1.514743, 0.002162}}],
    Polygon[{{0.900927, 1.513286, 0.004270},{0.900671, 1.514075, 0.006273},{
      0.904103, 1.515823, 0.006273},{0.904590, 1.515152, 0.004270}}],
    Polygon[{{0.900671, 1.514075, 0.006273},{0.900321, 1.515152, 0.008122},{
      0.903437, 1.516740, 0.008122},{0.904103, 1.515823, 0.006273}}],
    Polygon[{{0.900321, 1.515152, 0.008122},{0.899885, 1.516491, 0.009770},{
      0.902609, 1.517879, 0.009770},{0.903437, 1.516740, 0.008122}}],
    Polygon[{{0.899885, 1.516491, 0.009770},{0.899376, 1.518059, 0.011178},{
      0.901640, 1.519213, 0.011178},{0.902609, 1.517879, 0.009770}}],
    Polygon[{{0.899376, 1.518059, 0.011178},{0.898805, 1.519817, 0.012311},{
      0.900553, 1.520709, 0.012311},{0.901640, 1.519213, 0.011178}}],
    Polygon[{{0.898805, 1.519817, 0.012311},{0.898186, 1.521723, 0.013141},{
      0.899376, 1.522329, 0.013141},{0.900553, 1.520709, 0.012311}}],
    Polygon[{{0.898186, 1.521723, 0.013141},{0.897534, 1.523728, 0.013647},{
      0.898137, 1.524035, 0.013647},{0.899376, 1.522329, 0.013141}}],
    Polygon[{{0.898137, 1.524035, -0.013647},{0.899376, 1.522329, -0.013141},{
      0.900321, 1.523274, -0.013141},{0.898615, 1.524513, -0.013647}}],
    Polygon[{{0.899376, 1.522329, -0.013141},{0.900553, 1.520709, -0.012311},{
      0.901941, 1.522096, -0.012311},{0.900321, 1.523274, -0.013141}}],
    Polygon[{{0.900553, 1.520709, -0.012311},{0.901640, 1.519213, -0.011178},{
      0.903437, 1.521010, -0.011178},{0.901941, 1.522096, -0.012311}}],
    Polygon[{{0.901640, 1.519213, -0.011178},{0.902609, 1.517879, -0.009770},{
      0.904771, 1.520041, -0.009770},{0.903437, 1.521010, -0.011178}}],
    Polygon[{{0.902609, 1.517879, -0.009770},{0.903437, 1.516740, -0.008122},{
      0.905910, 1.519213, -0.008122},{0.904771, 1.520041, -0.009770}}],
    Polygon[{{0.903437, 1.516740, -0.008122},{0.904103, 1.515823, -0.006273},{
      0.906826, 1.518547, -0.006273},{0.905910, 1.519213, -0.008122}}],
    Polygon[{{0.904103, 1.515823, -0.006273},{0.904590, 1.515152, -0.004270},{
      0.907498, 1.518059, -0.004270},{0.906826, 1.518547, -0.006273}}],
    Polygon[{{0.904590, 1.515152, -0.004270},{0.904888, 1.514743, -0.002162},{
      0.907907, 1.517762, -0.002162},{0.907498, 1.518059, -0.004270}}],
    Polygon[{{0.904888, 1.514743, -0.002162},{0.904988, 1.514605, 0.000000},{
      0.908045, 1.517662, 0.000000},{0.907907, 1.517762, -0.002162}}],
    Polygon[{{0.904988, 1.514605, 0.000000},{0.904888, 1.514743, 0.002162},{
      0.907907, 1.517762, 0.002162},{0.908045, 1.517662, 0.000000}}],
    Polygon[{{0.904888, 1.514743, 0.002162},{0.904590, 1.515152, 0.004270},{
      0.907498, 1.518059, 0.004270},{0.907907, 1.517762, 0.002162}}],
    Polygon[{{0.904590, 1.515152, 0.004270},{0.904103, 1.515823, 0.006273},{
      0.906826, 1.518547, 0.006273},{0.907498, 1.518059, 0.004270}}],
    Polygon[{{0.904103, 1.515823, 0.006273},{0.903437, 1.516740, 0.008122},{
      0.905910, 1.519213, 0.008122},{0.906826, 1.518547, 0.006273}}],
    Polygon[{{0.903437, 1.516740, 0.008122},{0.902609, 1.517879, 0.009770},{
      0.904771, 1.520041, 0.009770},{0.905910, 1.519213, 0.008122}}],
    Polygon[{{0.902609, 1.517879, 0.009770},{0.901640, 1.519213, 0.011178},{
      0.903437, 1.521010, 0.011178},{0.904771, 1.520041, 0.009770}}],
    Polygon[{{0.901640, 1.519213, 0.011178},{0.900553, 1.520709, 0.012311},{
      0.901941, 1.522096, 0.012311},{0.903437, 1.521010, 0.011178}}],
    Polygon[{{0.900553, 1.520709, 0.012311},{0.899376, 1.522329, 0.013141},{
      0.900321, 1.523274, 0.013141},{0.901941, 1.522096, 0.012311}}],
    Polygon[{{0.899376, 1.522329, 0.013141},{0.898137, 1.524035, 0.013647},{
      0.898615, 1.524513, 0.013647},{0.900321, 1.523274, 0.013141}}],
    Polygon[{{0.898615, 1.524513, -0.013647},{0.900321, 1.523274, -0.013141},{
      0.900927, 1.524464, -0.013141},{0.898922, 1.525115, -0.013647}}],
    Polygon[{{0.900321, 1.523274, -0.013141},{0.901941, 1.522096, -0.012311},{
      0.902832, 1.523845, -0.012311},{0.900927, 1.524464, -0.013141}}],
    Polygon[{{0.901941, 1.522096, -0.012311},{0.903437, 1.521010, -0.011178},{
      0.904590, 1.523274, -0.011178},{0.902832, 1.523845, -0.012311}}],
    Polygon[{{0.903437, 1.521010, -0.011178},{0.904771, 1.520041, -0.009770},{
      0.906158, 1.522764, -0.009770},{0.904590, 1.523274, -0.011178}}],
    Polygon[{{0.904771, 1.520041, -0.009770},{0.905910, 1.519213, -0.008122},{
      0.907498, 1.522329, -0.008122},{0.906158, 1.522764, -0.009770}}],
    Polygon[{{0.905910, 1.519213, -0.008122},{0.906826, 1.518547, -0.006273},{
      0.908575, 1.521979, -0.006273},{0.907498, 1.522329, -0.008122}}],
    Polygon[{{0.906826, 1.518547, -0.006273},{0.907498, 1.518059, -0.004270},{
      0.909364, 1.521723, -0.004270},{0.908575, 1.521979, -0.006273}}],
    Polygon[{{0.907498, 1.518059, -0.004270},{0.907907, 1.517762, -0.002162},{
      0.909846, 1.521566, -0.002162},{0.909364, 1.521723, -0.004270}}],
    Polygon[{{0.907907, 1.517762, -0.002162},{0.908045, 1.517662, 0.000000},{
      0.910007, 1.521514, 0.000000},{0.909846, 1.521566, -0.002162}}],
    Polygon[{{0.908045, 1.517662, 0.000000},{0.907907, 1.517762, 0.002162},{
      0.909846, 1.521566, 0.002162},{0.910007, 1.521514, 0.000000}}],
    Polygon[{{0.907907, 1.517762, 0.002162},{0.907498, 1.518059, 0.004270},{
      0.909364, 1.521723, 0.004270},{0.909846, 1.521566, 0.002162}}],
    Polygon[{{0.907498, 1.518059, 0.004270},{0.906826, 1.518547, 0.006273},{
      0.908575, 1.521979, 0.006273},{0.909364, 1.521723, 0.004270}}],
    Polygon[{{0.906826, 1.518547, 0.006273},{0.905910, 1.519213, 0.008122},{
      0.907498, 1.522329, 0.008122},{0.908575, 1.521979, 0.006273}}],
    Polygon[{{0.905910, 1.519213, 0.008122},{0.904771, 1.520041, 0.009770},{
      0.906158, 1.522764, 0.009770},{0.907498, 1.522329, 0.008122}}],
    Polygon[{{0.904771, 1.520041, 0.009770},{0.903437, 1.521010, 0.011178},{
      0.904590, 1.523274, 0.011178},{0.906158, 1.522764, 0.009770}}],
    Polygon[{{0.903437, 1.521010, 0.011178},{0.901941, 1.522096, 0.012311},{
      0.902832, 1.523845, 0.012311},{0.904590, 1.523274, 0.011178}}],
    Polygon[{{0.901941, 1.522096, 0.012311},{0.900321, 1.523274, 0.013141},{
      0.900927, 1.524464, 0.013141},{0.902832, 1.523845, 0.012311}}],
    Polygon[{{0.900321, 1.523274, 0.013141},{0.898615, 1.524513, 0.013647},{
      0.898922, 1.525115, 0.013647},{0.900927, 1.524464, 0.013141}}],
    Polygon[{{0.898922, 1.525115, -0.013647},{0.900927, 1.524464, -0.013141},{
      0.901136, 1.525783, -0.013141},{0.899028, 1.525783, -0.013647}}],
    Polygon[{{0.900927, 1.524464, -0.013141},{0.902832, 1.523845, -0.012311},{
      0.903139, 1.525783, -0.012311},{0.901136, 1.525783, -0.013141}}],
    Polygon[{{0.902832, 1.523845, -0.012311},{0.904590, 1.523274, -0.011178},{
      0.904988, 1.525783, -0.011178},{0.903139, 1.525783, -0.012311}}],
    Polygon[{{0.904590, 1.523274, -0.011178},{0.906158, 1.522764, -0.009770},{
      0.906637, 1.525783, -0.009770},{0.904988, 1.525783, -0.011178}}],
    Polygon[{{0.906158, 1.522764, -0.009770},{0.907498, 1.522329, -0.008122},{
      0.908045, 1.525783, -0.008122},{0.906637, 1.525783, -0.009770}}],
    Polygon[{{0.907498, 1.522329, -0.008122},{0.908575, 1.521979, -0.006273},{
      0.909178, 1.525783, -0.006273},{0.908045, 1.525783, -0.008122}}],
    Polygon[{{0.908575, 1.521979, -0.006273},{0.909364, 1.521723, -0.004270},{
      0.910007, 1.525783, -0.004270},{0.909178, 1.525783, -0.006273}}],
    Polygon[{{0.909364, 1.521723, -0.004270},{0.909846, 1.521566, -0.002162},{
      0.910513, 1.525783, -0.002162},{0.910007, 1.525783, -0.004270}}],
    Polygon[{{0.909846, 1.521566, -0.002162},{0.910007, 1.521514, 0.000000},{
      0.910684, 1.525783, 0.000000},{0.910513, 1.525783, -0.002162}}],
    Polygon[{{0.910007, 1.521514, 0.000000},{0.909846, 1.521566, 0.002162},{
      0.910513, 1.525783, 0.002162},{0.910684, 1.525783, 0.000000}}],
    Polygon[{{0.909846, 1.521566, 0.002162},{0.909364, 1.521723, 0.004270},{
      0.910007, 1.525783, 0.004270},{0.910513, 1.525783, 0.002162}}],
    Polygon[{{0.909364, 1.521723, 0.004270},{0.908575, 1.521979, 0.006273},{
      0.909178, 1.525783, 0.006273},{0.910007, 1.525783, 0.004270}}],
    Polygon[{{0.908575, 1.521979, 0.006273},{0.907498, 1.522329, 0.008122},{
      0.908045, 1.525783, 0.008122},{0.909178, 1.525783, 0.006273}}],
    Polygon[{{0.907498, 1.522329, 0.008122},{0.906158, 1.522764, 0.009770},{
      0.906637, 1.525783, 0.009770},{0.908045, 1.525783, 0.008122}}],
    Polygon[{{0.906158, 1.522764, 0.009770},{0.904590, 1.523274, 0.011178},{
      0.904988, 1.525783, 0.011178},{0.906637, 1.525783, 0.009770}}],
    Polygon[{{0.904590, 1.523274, 0.011178},{0.902832, 1.523845, 0.012311},{
      0.903139, 1.525783, 0.012311},{0.904988, 1.525783, 0.011178}}],
    Polygon[{{0.902832, 1.523845, 0.012311},{0.900927, 1.524464, 0.013141},{
      0.901136, 1.525783, 0.013141},{0.903139, 1.525783, 0.012311}}],
    Polygon[{{0.900927, 1.524464, 0.013141},{0.898922, 1.525115, 0.013647},{
      0.899028, 1.525783, 0.013647},{0.901136, 1.525783, 0.013141}}],
    Polygon[{{0.929429, 1.587887, -0.009538},{0.930902, 1.587887, -0.009185},{
      0.930756, 1.588809, -0.009185},{0.929355, 1.588353, -0.009538}}],
    Polygon[{{0.930902, 1.587887, -0.009185},{0.932302, 1.587887, -0.008605},{
      0.932088, 1.589241, -0.008605},{0.930756, 1.588809, -0.009185}}],
    Polygon[{{0.932302, 1.587887, -0.008605},{0.933594, 1.587887, -0.007813},{
      0.933316, 1.589641, -0.007813},{0.932088, 1.589241, -0.008605}}],
    Polygon[{{0.933594, 1.587887, -0.007813},{0.934747, 1.587887, -0.006829},{
      0.934412, 1.589997, -0.006829},{0.933316, 1.589641, -0.007813}}],
    Polygon[{{0.934747, 1.587887, -0.006829},{0.935731, 1.587887, -0.005676},{
      0.935348, 1.590301, -0.005676},{0.934412, 1.589997, -0.006829}}],
    Polygon[{{0.935731, 1.587887, -0.005676},{0.936522, 1.587887, -0.004384},{
      0.936101, 1.590546, -0.004384},{0.935348, 1.590301, -0.005676}}],
    Polygon[{{0.936522, 1.587887, -0.004384},{0.937102, 1.587887, -0.002984},{
      0.936653, 1.590725, -0.002984},{0.936101, 1.590546, -0.004384}}],
    Polygon[{{0.937102, 1.587887, -0.002984},{0.937456, 1.587887, -0.001511},{
      0.936989, 1.590834, -0.001511},{0.936653, 1.590725, -0.002984}}],
    Polygon[{{0.937456, 1.587887, -0.001511},{0.937575, 1.587887, 0.000000},{
      0.937102, 1.590871, 0.000000},{0.936989, 1.590834, -0.001511}}],
    Polygon[{{0.937575, 1.587887, 0.000000},{0.937456, 1.587887, 0.001511},{
      0.936989, 1.590834, 0.001511},{0.937102, 1.590871, 0.000000}}],
    Polygon[{{0.937456, 1.587887, 0.001511},{0.937102, 1.587887, 0.002984},{
      0.936653, 1.590725, 0.002984},{0.936989, 1.590834, 0.001511}}],
    Polygon[{{0.937102, 1.587887, 0.002984},{0.936522, 1.587887, 0.004384},{
      0.936101, 1.590546, 0.004384},{0.936653, 1.590725, 0.002984}}],
    Polygon[{{0.936522, 1.587887, 0.004384},{0.935731, 1.587887, 0.005676},{
      0.935348, 1.590301, 0.005676},{0.936101, 1.590546, 0.004384}}],
    Polygon[{{0.935731, 1.587887, 0.005676},{0.934747, 1.587887, 0.006829},{
      0.934412, 1.589997, 0.006829},{0.935348, 1.590301, 0.005676}}],
    Polygon[{{0.934747, 1.587887, 0.006829},{0.933594, 1.587887, 0.007813},{
      0.933316, 1.589641, 0.007813},{0.934412, 1.589997, 0.006829}}],
    Polygon[{{0.933594, 1.587887, 0.007813},{0.932302, 1.587887, 0.008605},{
      0.932088, 1.589241, 0.008605},{0.933316, 1.589641, 0.007813}}],
    Polygon[{{0.932302, 1.587887, 0.008605},{0.930902, 1.587887, 0.009185},{
      0.930756, 1.588809, 0.009185},{0.932088, 1.589241, 0.008605}}],
    Polygon[{{0.930902, 1.587887, 0.009185},{0.929429, 1.587887, 0.009538},{
      0.929355, 1.588353, 0.009538},{0.930756, 1.588809, 0.009185}}],
    Polygon[{{0.929355, 1.588353, -0.009538},{0.930756, 1.588809, -0.009185},{
      0.930332, 1.589641, -0.009185},{0.929140, 1.588775, -0.009538}}],
    Polygon[{{0.930756, 1.588809, -0.009185},{0.932088, 1.589241, -0.008605},{
      0.931465, 1.590464, -0.008605},{0.930332, 1.589641, -0.009185}}],
    Polygon[{{0.932088, 1.589241, -0.008605},{0.933316, 1.589641, -0.007813},{
      0.932510, 1.591223, -0.007813},{0.931465, 1.590464, -0.008605}}],
    Polygon[{{0.933316, 1.589641, -0.007813},{0.934412, 1.589997, -0.006829},{
      0.933442, 1.591900, -0.006829},{0.932510, 1.591223, -0.007813}}],
    Polygon[{{0.934412, 1.589997, -0.006829},{0.935348, 1.590301, -0.005676},{
      0.934239, 1.592479, -0.005676},{0.933442, 1.591900, -0.006829}}],
    Polygon[{{0.935348, 1.590301, -0.005676},{0.936101, 1.590546, -0.004384},{
      0.934879, 1.592944, -0.004384},{0.934239, 1.592479, -0.005676}}],
    Polygon[{{0.936101, 1.590546, -0.004384},{0.936653, 1.590725, -0.002984},{
      0.935348, 1.593285, -0.002984},{0.934879, 1.592944, -0.004384}}],
    Polygon[{{0.936653, 1.590725, -0.002984},{0.936989, 1.590834, -0.001511},{
      0.935634, 1.593493, -0.001511},{0.935348, 1.593285, -0.002984}}],
    Polygon[{{0.936989, 1.590834, -0.001511},{0.937102, 1.590871, 0.000000},{
      0.935731, 1.593563, 0.000000},{0.935634, 1.593493, -0.001511}}],
    Polygon[{{0.937102, 1.590871, 0.000000},{0.936989, 1.590834, 0.001511},{
      0.935634, 1.593493, 0.001511},{0.935731, 1.593563, 0.000000}}],
    Polygon[{{0.936989, 1.590834, 0.001511},{0.936653, 1.590725, 0.002984},{
      0.935348, 1.593285, 0.002984},{0.935634, 1.593493, 0.001511}}],
    Polygon[{{0.936653, 1.590725, 0.002984},{0.936101, 1.590546, 0.004384},{
      0.934879, 1.592944, 0.004384},{0.935348, 1.593285, 0.002984}}],
    Polygon[{{0.936101, 1.590546, 0.004384},{0.935348, 1.590301, 0.005676},{
      0.934239, 1.592479, 0.005676},{0.934879, 1.592944, 0.004384}}],
    Polygon[{{0.935348, 1.590301, 0.005676},{0.934412, 1.589997, 0.006829},{
      0.933442, 1.591900, 0.006829},{0.934239, 1.592479, 0.005676}}],
    Polygon[{{0.934412, 1.589997, 0.006829},{0.933316, 1.589641, 0.007813},{
      0.932510, 1.591223, 0.007813},{0.933442, 1.591900, 0.006829}}],
    Polygon[{{0.933316, 1.589641, 0.007813},{0.932088, 1.589241, 0.008605},{
      0.931465, 1.590464, 0.008605},{0.932510, 1.591223, 0.007813}}],
    Polygon[{{0.932088, 1.589241, 0.008605},{0.930756, 1.588809, 0.009185},{
      0.930332, 1.589641, 0.009185},{0.931465, 1.590464, 0.008605}}],
    Polygon[{{0.930756, 1.588809, 0.009185},{0.929355, 1.588353, 0.009538},{
      0.929140, 1.588775, 0.009538},{0.930332, 1.589641, 0.009185}}],
    Polygon[{{0.929140, 1.588775, -0.009538},{0.930332, 1.589641, -0.009185},{
      0.929672, 1.590301, -0.009185},{0.928806, 1.589109, -0.009538}}],
    Polygon[{{0.930332, 1.589641, -0.009185},{0.931465, 1.590464, -0.008605},{
      0.930495, 1.591434, -0.008605},{0.929672, 1.590301, -0.009185}}],
    Polygon[{{0.931465, 1.590464, -0.008605},{0.932510, 1.591223, -0.007813},{
      0.931254, 1.592479, -0.007813},{0.930495, 1.591434, -0.008605}}],
    Polygon[{{0.932510, 1.591223, -0.007813},{0.933442, 1.591900, -0.006829},{
      0.931932, 1.593411, -0.006829},{0.931254, 1.592479, -0.007813}}],
    Polygon[{{0.933442, 1.591900, -0.006829},{0.934239, 1.592479, -0.005676},{
      0.932510, 1.594207, -0.005676},{0.931932, 1.593411, -0.006829}}],
    Polygon[{{0.934239, 1.592479, -0.005676},{0.934879, 1.592944, -0.004384},{
      0.932976, 1.594848, -0.004384},{0.932510, 1.594207, -0.005676}}],
    Polygon[{{0.934879, 1.592944, -0.004384},{0.935348, 1.593285, -0.002984},{
      0.933316, 1.595317, -0.002984},{0.932976, 1.594848, -0.004384}}],
    Polygon[{{0.935348, 1.593285, -0.002984},{0.935634, 1.593493, -0.001511},{
      0.933524, 1.595603, -0.001511},{0.933316, 1.595317, -0.002984}}],
    Polygon[{{0.935634, 1.593493, -0.001511},{0.935731, 1.593563, 0.000000},{
      0.933594, 1.595699, 0.000000},{0.933524, 1.595603, -0.001511}}],
    Polygon[{{0.935731, 1.593563, 0.000000},{0.935634, 1.593493, 0.001511},{
      0.933524, 1.595603, 0.001511},{0.933594, 1.595699, 0.000000}}],
    Polygon[{{0.935634, 1.593493, 0.001511},{0.935348, 1.593285, 0.002984},{
      0.933316, 1.595317, 0.002984},{0.933524, 1.595603, 0.001511}}],
    Polygon[{{0.935348, 1.593285, 0.002984},{0.934879, 1.592944, 0.004384},{
      0.932976, 1.594848, 0.004384},{0.933316, 1.595317, 0.002984}}],
    Polygon[{{0.934879, 1.592944, 0.004384},{0.934239, 1.592479, 0.005676},{
      0.932510, 1.594207, 0.005676},{0.932976, 1.594848, 0.004384}}],
    Polygon[{{0.934239, 1.592479, 0.005676},{0.933442, 1.591900, 0.006829},{
      0.931932, 1.593411, 0.006829},{0.932510, 1.594207, 0.005676}}],
    Polygon[{{0.933442, 1.591900, 0.006829},{0.932510, 1.591223, 0.007813},{
      0.931254, 1.592479, 0.007813},{0.931932, 1.593411, 0.006829}}],
    Polygon[{{0.932510, 1.591223, 0.007813},{0.931465, 1.590464, 0.008605},{
      0.930495, 1.591434, 0.008605},{0.931254, 1.592479, 0.007813}}],
    Polygon[{{0.931465, 1.590464, 0.008605},{0.930332, 1.589641, 0.009185},{
      0.929672, 1.590301, 0.009185},{0.930495, 1.591434, 0.008605}}],
    Polygon[{{0.930332, 1.589641, 0.009185},{0.929140, 1.588775, 0.009538},{
      0.928806, 1.589109, 0.009538},{0.929672, 1.590301, 0.009185}}],
    Polygon[{{0.928806, 1.589109, -0.009538},{0.929672, 1.590301, -0.009185},{
      0.928840, 1.590725, -0.009185},{0.928385, 1.589323, -0.009538}}],
    Polygon[{{0.929672, 1.590301, -0.009185},{0.930495, 1.591434, -0.008605},{
      0.929273, 1.592056, -0.008605},{0.928840, 1.590725, -0.009185}}],
    Polygon[{{0.930495, 1.591434, -0.008605},{0.931254, 1.592479, -0.007813},{
      0.929672, 1.593285, -0.007813},{0.929273, 1.592056, -0.008605}}],
    Polygon[{{0.931254, 1.592479, -0.007813},{0.931932, 1.593411, -0.006829},{
      0.930028, 1.594381, -0.006829},{0.929672, 1.593285, -0.007813}}],
    Polygon[{{0.931932, 1.593411, -0.006829},{0.932510, 1.594207, -0.005676},{
      0.930332, 1.595317, -0.005676},{0.930028, 1.594381, -0.006829}}],
    Polygon[{{0.932510, 1.594207, -0.005676},{0.932976, 1.594848, -0.004384},{
      0.930577, 1.596070, -0.004384},{0.930332, 1.595317, -0.005676}}],
    Polygon[{{0.932976, 1.594848, -0.004384},{0.933316, 1.595317, -0.002984},{
      0.930756, 1.596622, -0.002984},{0.930577, 1.596070, -0.004384}}],
    Polygon[{{0.933316, 1.595317, -0.002984},{0.933524, 1.595603, -0.001511},{
      0.930865, 1.596958, -0.001511},{0.930756, 1.596622, -0.002984}}],
    Polygon[{{0.933524, 1.595603, -0.001511},{0.933594, 1.595699, 0.000000},{
      0.930902, 1.597071, 0.000000},{0.930865, 1.596958, -0.001511}}],
    Polygon[{{0.933594, 1.595699, 0.000000},{0.933524, 1.595603, 0.001511},{
      0.930865, 1.596958, 0.001511},{0.930902, 1.597071, 0.000000}}],
    Polygon[{{0.933524, 1.595603, 0.001511},{0.933316, 1.595317, 0.002984},{
      0.930756, 1.596622, 0.002984},{0.930865, 1.596958, 0.001511}}],
    Polygon[{{0.933316, 1.595317, 0.002984},{0.932976, 1.594848, 0.004384},{
      0.930577, 1.596070, 0.004384},{0.930756, 1.596622, 0.002984}}],
    Polygon[{{0.932976, 1.594848, 0.004384},{0.932510, 1.594207, 0.005676},{
      0.930332, 1.595317, 0.005676},{0.930577, 1.596070, 0.004384}}],
    Polygon[{{0.932510, 1.594207, 0.005676},{0.931932, 1.593411, 0.006829},{
      0.930028, 1.594381, 0.006829},{0.930332, 1.595317, 0.005676}}],
    Polygon[{{0.931932, 1.593411, 0.006829},{0.931254, 1.592479, 0.007813},{
      0.929672, 1.593285, 0.007813},{0.930028, 1.594381, 0.006829}}],
    Polygon[{{0.931254, 1.592479, 0.007813},{0.930495, 1.591434, 0.008605},{
      0.929273, 1.592056, 0.008605},{0.929672, 1.593285, 0.007813}}],
    Polygon[{{0.930495, 1.591434, 0.008605},{0.929672, 1.590301, 0.009185},{
      0.928840, 1.590725, 0.009185},{0.929273, 1.592056, 0.008605}}],
    Polygon[{{0.929672, 1.590301, 0.009185},{0.928806, 1.589109, 0.009538},{
      0.928385, 1.589323, 0.009538},{0.928840, 1.590725, 0.009185}}],
    Polygon[{{0.928385, 1.589323, -0.009538},{0.928840, 1.590725, -0.009185},{
      0.927918, 1.590871, -0.009185},{0.927918, 1.589397, -0.009538}}],
    Polygon[{{0.928840, 1.590725, -0.009185},{0.929273, 1.592056, -0.008605},{
      0.927918, 1.592271, -0.008605},{0.927918, 1.590871, -0.009185}}],
    Polygon[{{0.929273, 1.592056, -0.008605},{0.929672, 1.593285, -0.007813},{
      0.927918, 1.593563, -0.007813},{0.927918, 1.592271, -0.008605}}],
    Polygon[{{0.929672, 1.593285, -0.007813},{0.930028, 1.594381, -0.006829},{
      0.927918, 1.594715, -0.006829},{0.927918, 1.593563, -0.007813}}],
    Polygon[{{0.930028, 1.594381, -0.006829},{0.930332, 1.595317, -0.005676},{
      0.927918, 1.595699, -0.005676},{0.927918, 1.594715, -0.006829}}],
    Polygon[{{0.930332, 1.595317, -0.005676},{0.930577, 1.596070, -0.004384},{
      0.927918, 1.596491, -0.004384},{0.927918, 1.595699, -0.005676}}],
    Polygon[{{0.930577, 1.596070, -0.004384},{0.930756, 1.596622, -0.002984},{
      0.927918, 1.597071, -0.002984},{0.927918, 1.596491, -0.004384}}],
    Polygon[{{0.930756, 1.596622, -0.002984},{0.930865, 1.596958, -0.001511},{
      0.927918, 1.597425, -0.001511},{0.927918, 1.597071, -0.002984}}],
    Polygon[{{0.930865, 1.596958, -0.001511},{0.930902, 1.597071, 0.000000},{
      0.927918, 1.597544, 0.000000},{0.927918, 1.597425, -0.001511}}],
    Polygon[{{0.930902, 1.597071, 0.000000},{0.930865, 1.596958, 0.001511},{
      0.927918, 1.597425, 0.001511},{0.927918, 1.597544, 0.000000}}],
    Polygon[{{0.930865, 1.596958, 0.001511},{0.930756, 1.596622, 0.002984},{
      0.927918, 1.597071, 0.002984},{0.927918, 1.597425, 0.001511}}],
    Polygon[{{0.930756, 1.596622, 0.002984},{0.930577, 1.596070, 0.004384},{
      0.927918, 1.596491, 0.004384},{0.927918, 1.597071, 0.002984}}],
    Polygon[{{0.930577, 1.596070, 0.004384},{0.930332, 1.595317, 0.005676},{
      0.927918, 1.595699, 0.005676},{0.927918, 1.596491, 0.004384}}],
    Polygon[{{0.930332, 1.595317, 0.005676},{0.930028, 1.594381, 0.006829},{
      0.927918, 1.594715, 0.006829},{0.927918, 1.595699, 0.005676}}],
    Polygon[{{0.930028, 1.594381, 0.006829},{0.929672, 1.593285, 0.007813},{
      0.927918, 1.593563, 0.007813},{0.927918, 1.594715, 0.006829}}],
    Polygon[{{0.929672, 1.593285, 0.007813},{0.929273, 1.592056, 0.008605},{
      0.927918, 1.592271, 0.008605},{0.927918, 1.593563, 0.007813}}],
    Polygon[{{0.929273, 1.592056, 0.008605},{0.928840, 1.590725, 0.009185},{
      0.927918, 1.590871, 0.009185},{0.927918, 1.592271, 0.008605}}],
    Polygon[{{0.928840, 1.590725, 0.009185},{0.928385, 1.589323, 0.009538},{
      0.927918, 1.589397, 0.009538},{0.927918, 1.590871, 0.009185}}],
    Polygon[{{0.927918, 1.589397, -0.009538},{0.927918, 1.590871, -0.009185},{
      0.926996, 1.590725, -0.009185},{0.927451, 1.589323, -0.009538}}],
    Polygon[{{0.927918, 1.590871, -0.009185},{0.927918, 1.592271, -0.008605},{
      0.926563, 1.592056, -0.008605},{0.926996, 1.590725, -0.009185}}],
    Polygon[{{0.927918, 1.592271, -0.008605},{0.927918, 1.593563, -0.007813},{
      0.926164, 1.593285, -0.007813},{0.926563, 1.592056, -0.008605}}],
    Polygon[{{0.927918, 1.593563, -0.007813},{0.927918, 1.594715, -0.006829},{
      0.925808, 1.594381, -0.006829},{0.926164, 1.593285, -0.007813}}],
    Polygon[{{0.927918, 1.594715, -0.006829},{0.927918, 1.595699, -0.005676},{
      0.925504, 1.595317, -0.005676},{0.925808, 1.594381, -0.006829}}],
    Polygon[{{0.927918, 1.595699, -0.005676},{0.927918, 1.596491, -0.004384},{
      0.925259, 1.596070, -0.004384},{0.925504, 1.595317, -0.005676}}],
    Polygon[{{0.927918, 1.596491, -0.004384},{0.927918, 1.597071, -0.002984},{
      0.925080, 1.596622, -0.002984},{0.925259, 1.596070, -0.004384}}],
    Polygon[{{0.927918, 1.597071, -0.002984},{0.927918, 1.597425, -0.001511},{
      0.924970, 1.596958, -0.001511},{0.925080, 1.596622, -0.002984}}],
    Polygon[{{0.927918, 1.597425, -0.001511},{0.927918, 1.597544, 0.000000},{
      0.924934, 1.597071, 0.000000},{0.924970, 1.596958, -0.001511}}],
    Polygon[{{0.927918, 1.597544, 0.000000},{0.927918, 1.597425, 0.001511},{
      0.924970, 1.596958, 0.001511},{0.924934, 1.597071, 0.000000}}],
    Polygon[{{0.927918, 1.597425, 0.001511},{0.927918, 1.597071, 0.002984},{
      0.925080, 1.596622, 0.002984},{0.924970, 1.596958, 0.001511}}],
    Polygon[{{0.927918, 1.597071, 0.002984},{0.927918, 1.596491, 0.004384},{
      0.925259, 1.596070, 0.004384},{0.925080, 1.596622, 0.002984}}],
    Polygon[{{0.927918, 1.596491, 0.004384},{0.927918, 1.595699, 0.005676},{
      0.925504, 1.595317, 0.005676},{0.925259, 1.596070, 0.004384}}],
    Polygon[{{0.927918, 1.595699, 0.005676},{0.927918, 1.594715, 0.006829},{
      0.925808, 1.594381, 0.006829},{0.925504, 1.595317, 0.005676}}],
    Polygon[{{0.927918, 1.594715, 0.006829},{0.927918, 1.593563, 0.007813},{
      0.926164, 1.593285, 0.007813},{0.925808, 1.594381, 0.006829}}],
    Polygon[{{0.927918, 1.593563, 0.007813},{0.927918, 1.592271, 0.008605},{
      0.926563, 1.592056, 0.008605},{0.926164, 1.593285, 0.007813}}],
    Polygon[{{0.927918, 1.592271, 0.008605},{0.927918, 1.590871, 0.009185},{
      0.926996, 1.590725, 0.009185},{0.926563, 1.592056, 0.008605}}],
    Polygon[{{0.927918, 1.590871, 0.009185},{0.927918, 1.589397, 0.009538},{
      0.927451, 1.589323, 0.009538},{0.926996, 1.590725, 0.009185}}],
    Polygon[{{0.927451, 1.589323, -0.009538},{0.926996, 1.590725, -0.009185},{
      0.926164, 1.590301, -0.009185},{0.927030, 1.589109, -0.009538}}],
    Polygon[{{0.926996, 1.590725, -0.009185},{0.926563, 1.592056, -0.008605},{
      0.925341, 1.591434, -0.008605},{0.926164, 1.590301, -0.009185}}],
    Polygon[{{0.926563, 1.592056, -0.008605},{0.926164, 1.593285, -0.007813},{
      0.924581, 1.592479, -0.007813},{0.925341, 1.591434, -0.008605}}],
    Polygon[{{0.926164, 1.593285, -0.007813},{0.925808, 1.594381, -0.006829},{
      0.923904, 1.593411, -0.006829},{0.924581, 1.592479, -0.007813}}],
    Polygon[{{0.925808, 1.594381, -0.006829},{0.925504, 1.595317, -0.005676},{
      0.923326, 1.594207, -0.005676},{0.923904, 1.593411, -0.006829}}],
    Polygon[{{0.925504, 1.595317, -0.005676},{0.925259, 1.596070, -0.004384},{
      0.922860, 1.594848, -0.004384},{0.923326, 1.594207, -0.005676}}],
    Polygon[{{0.925259, 1.596070, -0.004384},{0.925080, 1.596622, -0.002984},{
      0.922519, 1.595317, -0.002984},{0.922860, 1.594848, -0.004384}}],
    Polygon[{{0.925080, 1.596622, -0.002984},{0.924970, 1.596958, -0.001511},{
      0.922311, 1.595603, -0.001511},{0.922519, 1.595317, -0.002984}}],
    Polygon[{{0.924970, 1.596958, -0.001511},{0.924934, 1.597071, 0.000000},{
      0.922242, 1.595699, 0.000000},{0.922311, 1.595603, -0.001511}}],
    Polygon[{{0.924934, 1.597071, 0.000000},{0.924970, 1.596958, 0.001511},{
      0.922311, 1.595603, 0.001511},{0.922242, 1.595699, 0.000000}}],
    Polygon[{{0.924970, 1.596958, 0.001511},{0.925080, 1.596622, 0.002984},{
      0.922519, 1.595317, 0.002984},{0.922311, 1.595603, 0.001511}}],
    Polygon[{{0.925080, 1.596622, 0.002984},{0.925259, 1.596070, 0.004384},{
      0.922860, 1.594848, 0.004384},{0.922519, 1.595317, 0.002984}}],
    Polygon[{{0.925259, 1.596070, 0.004384},{0.925504, 1.595317, 0.005676},{
      0.923326, 1.594207, 0.005676},{0.922860, 1.594848, 0.004384}}],
    Polygon[{{0.925504, 1.595317, 0.005676},{0.925808, 1.594381, 0.006829},{
      0.923904, 1.593411, 0.006829},{0.923326, 1.594207, 0.005676}}],
    Polygon[{{0.925808, 1.594381, 0.006829},{0.926164, 1.593285, 0.007813},{
      0.924581, 1.592479, 0.007813},{0.923904, 1.593411, 0.006829}}],
    Polygon[{{0.926164, 1.593285, 0.007813},{0.926563, 1.592056, 0.008605},{
      0.925341, 1.591434, 0.008605},{0.924581, 1.592479, 0.007813}}],
    Polygon[{{0.926563, 1.592056, 0.008605},{0.926996, 1.590725, 0.009185},{
      0.926164, 1.590301, 0.009185},{0.925341, 1.591434, 0.008605}}],
    Polygon[{{0.926996, 1.590725, 0.009185},{0.927451, 1.589323, 0.009538},{
      0.927030, 1.589109, 0.009538},{0.926164, 1.590301, 0.009185}}],
    Polygon[{{0.927030, 1.589109, -0.009538},{0.926164, 1.590301, -0.009185},{
      0.925504, 1.589641, -0.009185},{0.926696, 1.588775, -0.009538}}],
    Polygon[{{0.926164, 1.590301, -0.009185},{0.925341, 1.591434, -0.008605},{
      0.924371, 1.590464, -0.008605},{0.925504, 1.589641, -0.009185}}],
    Polygon[{{0.925341, 1.591434, -0.008605},{0.924581, 1.592479, -0.007813},{
      0.923326, 1.591223, -0.007813},{0.924371, 1.590464, -0.008605}}],
    Polygon[{{0.924581, 1.592479, -0.007813},{0.923904, 1.593411, -0.006829},{
      0.922393, 1.591900, -0.006829},{0.923326, 1.591223, -0.007813}}],
    Polygon[{{0.923904, 1.593411, -0.006829},{0.923326, 1.594207, -0.005676},{
      0.921597, 1.592479, -0.005676},{0.922393, 1.591900, -0.006829}}],
    Polygon[{{0.923326, 1.594207, -0.005676},{0.922860, 1.594848, -0.004384},{
      0.920957, 1.592944, -0.004384},{0.921597, 1.592479, -0.005676}}],
    Polygon[{{0.922860, 1.594848, -0.004384},{0.922519, 1.595317, -0.002984},{
      0.920487, 1.593285, -0.002984},{0.920957, 1.592944, -0.004384}}],
    Polygon[{{0.922519, 1.595317, -0.002984},{0.922311, 1.595603, -0.001511},{
      0.920201, 1.593493, -0.001511},{0.920487, 1.593285, -0.002984}}],
    Polygon[{{0.922311, 1.595603, -0.001511},{0.922242, 1.595699, 0.000000},{
      0.920105, 1.593563, 0.000000},{0.920201, 1.593493, -0.001511}}],
    Polygon[{{0.922242, 1.595699, 0.000000},{0.922311, 1.595603, 0.001511},{
      0.920201, 1.593493, 0.001511},{0.920105, 1.593563, 0.000000}}],
    Polygon[{{0.922311, 1.595603, 0.001511},{0.922519, 1.595317, 0.002984},{
      0.920487, 1.593285, 0.002984},{0.920201, 1.593493, 0.001511}}],
    Polygon[{{0.922519, 1.595317, 0.002984},{0.922860, 1.594848, 0.004384},{
      0.920957, 1.592944, 0.004384},{0.920487, 1.593285, 0.002984}}],
    Polygon[{{0.922860, 1.594848, 0.004384},{0.923326, 1.594207, 0.005676},{
      0.921597, 1.592479, 0.005676},{0.920957, 1.592944, 0.004384}}],
    Polygon[{{0.923326, 1.594207, 0.005676},{0.923904, 1.593411, 0.006829},{
      0.922393, 1.591900, 0.006829},{0.921597, 1.592479, 0.005676}}],
    Polygon[{{0.923904, 1.593411, 0.006829},{0.924581, 1.592479, 0.007813},{
      0.923326, 1.591223, 0.007813},{0.922393, 1.591900, 0.006829}}],
    Polygon[{{0.924581, 1.592479, 0.007813},{0.925341, 1.591434, 0.008605},{
      0.924371, 1.590464, 0.008605},{0.923326, 1.591223, 0.007813}}],
    Polygon[{{0.925341, 1.591434, 0.008605},{0.926164, 1.590301, 0.009185},{
      0.925504, 1.589641, 0.009185},{0.924371, 1.590464, 0.008605}}],
    Polygon[{{0.926164, 1.590301, 0.009185},{0.927030, 1.589109, 0.009538},{
      0.926696, 1.588775, 0.009538},{0.925504, 1.589641, 0.009185}}],
    Polygon[{{0.926696, 1.588775, -0.009538},{0.925504, 1.589641, -0.009185},{
      0.925080, 1.588809, -0.009185},{0.926481, 1.588353, -0.009538}}],
    Polygon[{{0.925504, 1.589641, -0.009185},{0.924371, 1.590464, -0.008605},{
      0.923748, 1.589241, -0.008605},{0.925080, 1.588809, -0.009185}}],
    Polygon[{{0.924371, 1.590464, -0.008605},{0.923326, 1.591223, -0.007813},{
      0.922519, 1.589641, -0.007813},{0.923748, 1.589241, -0.008605}}],
    Polygon[{{0.923326, 1.591223, -0.007813},{0.922393, 1.591900, -0.006829},{
      0.921423, 1.589997, -0.006829},{0.922519, 1.589641, -0.007813}}],
    Polygon[{{0.922393, 1.591900, -0.006829},{0.921597, 1.592479, -0.005676},{
      0.920487, 1.590301, -0.005676},{0.921423, 1.589997, -0.006829}}],
    Polygon[{{0.921597, 1.592479, -0.005676},{0.920957, 1.592944, -0.004384},{
      0.919734, 1.590546, -0.004384},{0.920487, 1.590301, -0.005676}}],
    Polygon[{{0.920957, 1.592944, -0.004384},{0.920487, 1.593285, -0.002984},{
      0.919183, 1.590725, -0.002984},{0.919734, 1.590546, -0.004384}}],
    Polygon[{{0.920487, 1.593285, -0.002984},{0.920201, 1.593493, -0.001511},{
      0.918846, 1.590834, -0.001511},{0.919183, 1.590725, -0.002984}}],
    Polygon[{{0.920201, 1.593493, -0.001511},{0.920105, 1.593563, 0.000000},{
      0.918733, 1.590871, 0.000000},{0.918846, 1.590834, -0.001511}}],
    Polygon[{{0.920105, 1.593563, 0.000000},{0.920201, 1.593493, 0.001511},{
      0.918846, 1.590834, 0.001511},{0.918733, 1.590871, 0.000000}}],
    Polygon[{{0.920201, 1.593493, 0.001511},{0.920487, 1.593285, 0.002984},{
      0.919183, 1.590725, 0.002984},{0.918846, 1.590834, 0.001511}}],
    Polygon[{{0.920487, 1.593285, 0.002984},{0.920957, 1.592944, 0.004384},{
      0.919734, 1.590546, 0.004384},{0.919183, 1.590725, 0.002984}}],
    Polygon[{{0.920957, 1.592944, 0.004384},{0.921597, 1.592479, 0.005676},{
      0.920487, 1.590301, 0.005676},{0.919734, 1.590546, 0.004384}}],
    Polygon[{{0.921597, 1.592479, 0.005676},{0.922393, 1.591900, 0.006829},{
      0.921423, 1.589997, 0.006829},{0.920487, 1.590301, 0.005676}}],
    Polygon[{{0.922393, 1.591900, 0.006829},{0.923326, 1.591223, 0.007813},{
      0.922519, 1.589641, 0.007813},{0.921423, 1.589997, 0.006829}}],
    Polygon[{{0.923326, 1.591223, 0.007813},{0.924371, 1.590464, 0.008605},{
      0.923748, 1.589241, 0.008605},{0.922519, 1.589641, 0.007813}}],
    Polygon[{{0.924371, 1.590464, 0.008605},{0.925504, 1.589641, 0.009185},{
      0.925080, 1.588809, 0.009185},{0.923748, 1.589241, 0.008605}}],
    Polygon[{{0.925504, 1.589641, 0.009185},{0.926696, 1.588775, 0.009538},{
      0.926481, 1.588353, 0.009538},{0.925080, 1.588809, 0.009185}}],
    Polygon[{{0.926481, 1.588353, -0.009538},{0.925080, 1.588809, -0.009185},{
      0.924934, 1.587887, -0.009185},{0.926407, 1.587887, -0.009538}}],
    Polygon[{{0.925080, 1.588809, -0.009185},{0.923748, 1.589241, -0.008605},{
      0.923534, 1.587887, -0.008605},{0.924934, 1.587887, -0.009185}}],
    Polygon[{{0.923748, 1.589241, -0.008605},{0.922519, 1.589641, -0.007813},{
      0.922242, 1.587887, -0.007813},{0.923534, 1.587887, -0.008605}}],
    Polygon[{{0.922519, 1.589641, -0.007813},{0.921423, 1.589997, -0.006829},{
      0.921089, 1.587887, -0.006829},{0.922242, 1.587887, -0.007813}}],
    Polygon[{{0.921423, 1.589997, -0.006829},{0.920487, 1.590301, -0.005676},{
      0.920105, 1.587887, -0.005676},{0.921089, 1.587887, -0.006829}}],
    Polygon[{{0.920487, 1.590301, -0.005676},{0.919734, 1.590546, -0.004384},{
      0.919313, 1.587887, -0.004384},{0.920105, 1.587887, -0.005676}}],
    Polygon[{{0.919734, 1.590546, -0.004384},{0.919183, 1.590725, -0.002984},{
      0.918733, 1.587887, -0.002984},{0.919313, 1.587887, -0.004384}}],
    Polygon[{{0.919183, 1.590725, -0.002984},{0.918846, 1.590834, -0.001511},{
      0.918380, 1.587887, -0.001511},{0.918733, 1.587887, -0.002984}}],
    Polygon[{{0.918846, 1.590834, -0.001511},{0.918733, 1.590871, 0.000000},{
      0.918261, 1.587887, 0.000000},{0.918380, 1.587887, -0.001511}}],
    Polygon[{{0.918733, 1.590871, 0.000000},{0.918846, 1.590834, 0.001511},{
      0.918380, 1.587887, 0.001511},{0.918261, 1.587887, 0.000000}}],
    Polygon[{{0.918846, 1.590834, 0.001511},{0.919183, 1.590725, 0.002984},{
      0.918733, 1.587887, 0.002984},{0.918380, 1.587887, 0.001511}}],
    Polygon[{{0.919183, 1.590725, 0.002984},{0.919734, 1.590546, 0.004384},{
      0.919313, 1.587887, 0.004384},{0.918733, 1.587887, 0.002984}}],
    Polygon[{{0.919734, 1.590546, 0.004384},{0.920487, 1.590301, 0.005676},{
      0.920105, 1.587887, 0.005676},{0.919313, 1.587887, 0.004384}}],
    Polygon[{{0.920487, 1.590301, 0.005676},{0.921423, 1.589997, 0.006829},{
      0.921089, 1.587887, 0.006829},{0.920105, 1.587887, 0.005676}}],
    Polygon[{{0.921423, 1.589997, 0.006829},{0.922519, 1.589641, 0.007813},{
      0.922242, 1.587887, 0.007813},{0.921089, 1.587887, 0.006829}}],
    Polygon[{{0.922519, 1.589641, 0.007813},{0.923748, 1.589241, 0.008605},{
      0.923534, 1.587887, 0.008605},{0.922242, 1.587887, 0.007813}}],
    Polygon[{{0.923748, 1.589241, 0.008605},{0.925080, 1.588809, 0.009185},{
      0.924934, 1.587887, 0.009185},{0.923534, 1.587887, 0.008605}}],
    Polygon[{{0.925080, 1.588809, 0.009185},{0.926481, 1.588353, 0.009538},{
      0.926407, 1.587887, 0.009538},{0.924934, 1.587887, 0.009185}}],
    Polygon[{{0.926407, 1.587887, -0.009538},{0.924934, 1.587887, -0.009185},{
      0.925080, 1.586964, -0.009185},{0.926481, 1.587420, -0.009538}}],
    Polygon[{{0.924934, 1.587887, -0.009185},{0.923534, 1.587887, -0.008605},{
      0.923748, 1.586532, -0.008605},{0.925080, 1.586964, -0.009185}}],
    Polygon[{{0.923534, 1.587887, -0.008605},{0.922242, 1.587887, -0.007813},{
      0.922519, 1.586133, -0.007813},{0.923748, 1.586532, -0.008605}}],
    Polygon[{{0.922242, 1.587887, -0.007813},{0.921089, 1.587887, -0.006829},{
      0.921423, 1.585776, -0.006829},{0.922519, 1.586133, -0.007813}}],
    Polygon[{{0.921089, 1.587887, -0.006829},{0.920105, 1.587887, -0.005676},{
      0.920487, 1.585472, -0.005676},{0.921423, 1.585776, -0.006829}}],
    Polygon[{{0.920105, 1.587887, -0.005676},{0.919313, 1.587887, -0.004384},{
      0.919734, 1.585228, -0.004384},{0.920487, 1.585472, -0.005676}}],
    Polygon[{{0.919313, 1.587887, -0.004384},{0.918733, 1.587887, -0.002984},{
      0.919183, 1.585048, -0.002984},{0.919734, 1.585228, -0.004384}}],
    Polygon[{{0.918733, 1.587887, -0.002984},{0.918380, 1.587887, -0.001511},{
      0.918846, 1.584939, -0.001511},{0.919183, 1.585048, -0.002984}}],
    Polygon[{{0.918380, 1.587887, -0.001511},{0.918261, 1.587887, 0.000000},{
      0.918733, 1.584902, 0.000000},{0.918846, 1.584939, -0.001511}}],
    Polygon[{{0.918261, 1.587887, 0.000000},{0.918380, 1.587887, 0.001511},{
      0.918846, 1.584939, 0.001511},{0.918733, 1.584902, 0.000000}}],
    Polygon[{{0.918380, 1.587887, 0.001511},{0.918733, 1.587887, 0.002984},{
      0.919183, 1.585048, 0.002984},{0.918846, 1.584939, 0.001511}}],
    Polygon[{{0.918733, 1.587887, 0.002984},{0.919313, 1.587887, 0.004384},{
      0.919734, 1.585228, 0.004384},{0.919183, 1.585048, 0.002984}}],
    Polygon[{{0.919313, 1.587887, 0.004384},{0.920105, 1.587887, 0.005676},{
      0.920487, 1.585472, 0.005676},{0.919734, 1.585228, 0.004384}}],
    Polygon[{{0.920105, 1.587887, 0.005676},{0.921089, 1.587887, 0.006829},{
      0.921423, 1.585776, 0.006829},{0.920487, 1.585472, 0.005676}}],
    Polygon[{{0.921089, 1.587887, 0.006829},{0.922242, 1.587887, 0.007813},{
      0.922519, 1.586133, 0.007813},{0.921423, 1.585776, 0.006829}}],
    Polygon[{{0.922242, 1.587887, 0.007813},{0.923534, 1.587887, 0.008605},{
      0.923748, 1.586532, 0.008605},{0.922519, 1.586133, 0.007813}}],
    Polygon[{{0.923534, 1.587887, 0.008605},{0.924934, 1.587887, 0.009185},{
      0.925080, 1.586964, 0.009185},{0.923748, 1.586532, 0.008605}}],
    Polygon[{{0.924934, 1.587887, 0.009185},{0.926407, 1.587887, 0.009538},{
      0.926481, 1.587420, 0.009538},{0.925080, 1.586964, 0.009185}}],
    Polygon[{{0.926481, 1.587420, -0.009538},{0.925080, 1.586964, -0.009185},{
      0.925504, 1.586133, -0.009185},{0.926696, 1.586999, -0.009538}}],
    Polygon[{{0.925080, 1.586964, -0.009185},{0.923748, 1.586532, -0.008605},{
      0.924371, 1.585310, -0.008605},{0.925504, 1.586133, -0.009185}}],
    Polygon[{{0.923748, 1.586532, -0.008605},{0.922519, 1.586133, -0.007813},{
      0.923326, 1.584550, -0.007813},{0.924371, 1.585310, -0.008605}}],
    Polygon[{{0.922519, 1.586133, -0.007813},{0.921423, 1.585776, -0.006829},{
      0.922393, 1.583873, -0.006829},{0.923326, 1.584550, -0.007813}}],
    Polygon[{{0.921423, 1.585776, -0.006829},{0.920487, 1.585472, -0.005676},{
      0.921597, 1.583294, -0.005676},{0.922393, 1.583873, -0.006829}}],
    Polygon[{{0.920487, 1.585472, -0.005676},{0.919734, 1.585228, -0.004384},{
      0.920957, 1.582829, -0.004384},{0.921597, 1.583294, -0.005676}}],
    Polygon[{{0.919734, 1.585228, -0.004384},{0.919183, 1.585048, -0.002984},{
      0.920487, 1.582488, -0.002984},{0.920957, 1.582829, -0.004384}}],
    Polygon[{{0.919183, 1.585048, -0.002984},{0.918846, 1.584939, -0.001511},{
      0.920201, 1.582280, -0.001511},{0.920487, 1.582488, -0.002984}}],
    Polygon[{{0.918846, 1.584939, -0.001511},{0.918733, 1.584902, 0.000000},{
      0.920105, 1.582210, 0.000000},{0.920201, 1.582280, -0.001511}}],
    Polygon[{{0.918733, 1.584902, 0.000000},{0.918846, 1.584939, 0.001511},{
      0.920201, 1.582280, 0.001511},{0.920105, 1.582210, 0.000000}}],
    Polygon[{{0.918846, 1.584939, 0.001511},{0.919183, 1.585048, 0.002984},{
      0.920487, 1.582488, 0.002984},{0.920201, 1.582280, 0.001511}}],
    Polygon[{{0.919183, 1.585048, 0.002984},{0.919734, 1.585228, 0.004384},{
      0.920957, 1.582829, 0.004384},{0.920487, 1.582488, 0.002984}}],
    Polygon[{{0.919734, 1.585228, 0.004384},{0.920487, 1.585472, 0.005676},{
      0.921597, 1.583294, 0.005676},{0.920957, 1.582829, 0.004384}}],
    Polygon[{{0.920487, 1.585472, 0.005676},{0.921423, 1.585776, 0.006829},{
      0.922393, 1.583873, 0.006829},{0.921597, 1.583294, 0.005676}}],
    Polygon[{{0.921423, 1.585776, 0.006829},{0.922519, 1.586133, 0.007813},{
      0.923326, 1.584550, 0.007813},{0.922393, 1.583873, 0.006829}}],
    Polygon[{{0.922519, 1.586133, 0.007813},{0.923748, 1.586532, 0.008605},{
      0.924371, 1.585310, 0.008605},{0.923326, 1.584550, 0.007813}}],
    Polygon[{{0.923748, 1.586532, 0.008605},{0.925080, 1.586964, 0.009185},{
      0.925504, 1.586133, 0.009185},{0.924371, 1.585310, 0.008605}}],
    Polygon[{{0.925080, 1.586964, 0.009185},{0.926481, 1.587420, 0.009538},{
      0.926696, 1.586999, 0.009538},{0.925504, 1.586133, 0.009185}}],
    Polygon[{{0.926696, 1.586999, -0.009538},{0.925504, 1.586133, -0.009185},{
      0.926164, 1.585472, -0.009185},{0.927030, 1.586664, -0.009538}}],
    Polygon[{{0.925504, 1.586133, -0.009185},{0.924371, 1.585310, -0.008605},{
      0.925341, 1.584340, -0.008605},{0.926164, 1.585472, -0.009185}}],
    Polygon[{{0.924371, 1.585310, -0.008605},{0.923326, 1.584550, -0.007813},{
      0.924581, 1.583294, -0.007813},{0.925341, 1.584340, -0.008605}}],
    Polygon[{{0.923326, 1.584550, -0.007813},{0.922393, 1.583873, -0.006829},{
      0.923904, 1.582362, -0.006829},{0.924581, 1.583294, -0.007813}}],
    Polygon[{{0.922393, 1.583873, -0.006829},{0.921597, 1.583294, -0.005676},{
      0.923326, 1.581566, -0.005676},{0.923904, 1.582362, -0.006829}}],
    Polygon[{{0.921597, 1.583294, -0.005676},{0.920957, 1.582829, -0.004384},{
      0.922860, 1.580925, -0.004384},{0.923326, 1.581566, -0.005676}}],
    Polygon[{{0.920957, 1.582829, -0.004384},{0.920487, 1.582488, -0.002984},{
      0.922519, 1.580456, -0.002984},{0.922860, 1.580925, -0.004384}}],
    Polygon[{{0.920487, 1.582488, -0.002984},{0.920201, 1.582280, -0.001511},{
      0.922311, 1.580170, -0.001511},{0.922519, 1.580456, -0.002984}}],
    Polygon[{{0.920201, 1.582280, -0.001511},{0.920105, 1.582210, 0.000000},{
      0.922242, 1.580074, 0.000000},{0.922311, 1.580170, -0.001511}}],
    Polygon[{{0.920105, 1.582210, 0.000000},{0.920201, 1.582280, 0.001511},{
      0.922311, 1.580170, 0.001511},{0.922242, 1.580074, 0.000000}}],
    Polygon[{{0.920201, 1.582280, 0.001511},{0.920487, 1.582488, 0.002984},{
      0.922519, 1.580456, 0.002984},{0.922311, 1.580170, 0.001511}}],
    Polygon[{{0.920487, 1.582488, 0.002984},{0.920957, 1.582829, 0.004384},{
      0.922860, 1.580925, 0.004384},{0.922519, 1.580456, 0.002984}}],
    Polygon[{{0.920957, 1.582829, 0.004384},{0.921597, 1.583294, 0.005676},{
      0.923326, 1.581566, 0.005676},{0.922860, 1.580925, 0.004384}}],
    Polygon[{{0.921597, 1.583294, 0.005676},{0.922393, 1.583873, 0.006829},{
      0.923904, 1.582362, 0.006829},{0.923326, 1.581566, 0.005676}}],
    Polygon[{{0.922393, 1.583873, 0.006829},{0.923326, 1.584550, 0.007813},{
      0.924581, 1.583294, 0.007813},{0.923904, 1.582362, 0.006829}}],
    Polygon[{{0.923326, 1.584550, 0.007813},{0.924371, 1.585310, 0.008605},{
      0.925341, 1.584340, 0.008605},{0.924581, 1.583294, 0.007813}}],
    Polygon[{{0.924371, 1.585310, 0.008605},{0.925504, 1.586133, 0.009185},{
      0.926164, 1.585472, 0.009185},{0.925341, 1.584340, 0.008605}}],
    Polygon[{{0.925504, 1.586133, 0.009185},{0.926696, 1.586999, 0.009538},{
      0.927030, 1.586664, 0.009538},{0.926164, 1.585472, 0.009185}}],
    Polygon[{{0.927030, 1.586664, -0.009538},{0.926164, 1.585472, -0.009185},{
      0.926996, 1.585048, -0.009185},{0.927451, 1.586450, -0.009538}}],
    Polygon[{{0.926164, 1.585472, -0.009185},{0.925341, 1.584340, -0.008605},{
      0.926563, 1.583717, -0.008605},{0.926996, 1.585048, -0.009185}}],
    Polygon[{{0.925341, 1.584340, -0.008605},{0.924581, 1.583294, -0.007813},{
      0.926164, 1.582488, -0.007813},{0.926563, 1.583717, -0.008605}}],
    Polygon[{{0.924581, 1.583294, -0.007813},{0.923904, 1.582362, -0.006829},{
      0.925808, 1.581392, -0.006829},{0.926164, 1.582488, -0.007813}}],
    Polygon[{{0.923904, 1.582362, -0.006829},{0.923326, 1.581566, -0.005676},{
      0.925504, 1.580456, -0.005676},{0.925808, 1.581392, -0.006829}}],
    Polygon[{{0.923326, 1.581566, -0.005676},{0.922860, 1.580925, -0.004384},{
      0.925259, 1.579703, -0.004384},{0.925504, 1.580456, -0.005676}}],
    Polygon[{{0.922860, 1.580925, -0.004384},{0.922519, 1.580456, -0.002984},{
      0.925080, 1.579152, -0.002984},{0.925259, 1.579703, -0.004384}}],
    Polygon[{{0.922519, 1.580456, -0.002984},{0.922311, 1.580170, -0.001511},{
      0.924970, 1.578815, -0.001511},{0.925080, 1.579152, -0.002984}}],
    Polygon[{{0.922311, 1.580170, -0.001511},{0.922242, 1.580074, 0.000000},{
      0.924934, 1.578702, 0.000000},{0.924970, 1.578815, -0.001511}}],
    Polygon[{{0.922242, 1.580074, 0.000000},{0.922311, 1.580170, 0.001511},{
      0.924970, 1.578815, 0.001511},{0.924934, 1.578702, 0.000000}}],
    Polygon[{{0.922311, 1.580170, 0.001511},{0.922519, 1.580456, 0.002984},{
      0.925080, 1.579152, 0.002984},{0.924970, 1.578815, 0.001511}}],
    Polygon[{{0.922519, 1.580456, 0.002984},{0.922860, 1.580925, 0.004384},{
      0.925259, 1.579703, 0.004384},{0.925080, 1.579152, 0.002984}}],
    Polygon[{{0.922860, 1.580925, 0.004384},{0.923326, 1.581566, 0.005676},{
      0.925504, 1.580456, 0.005676},{0.925259, 1.579703, 0.004384}}],
    Polygon[{{0.923326, 1.581566, 0.005676},{0.923904, 1.582362, 0.006829},{
      0.925808, 1.581392, 0.006829},{0.925504, 1.580456, 0.005676}}],
    Polygon[{{0.923904, 1.582362, 0.006829},{0.924581, 1.583294, 0.007813},{
      0.926164, 1.582488, 0.007813},{0.925808, 1.581392, 0.006829}}],
    Polygon[{{0.924581, 1.583294, 0.007813},{0.925341, 1.584340, 0.008605},{
      0.926563, 1.583717, 0.008605},{0.926164, 1.582488, 0.007813}}],
    Polygon[{{0.925341, 1.584340, 0.008605},{0.926164, 1.585472, 0.009185},{
      0.926996, 1.585048, 0.009185},{0.926563, 1.583717, 0.008605}}],
    Polygon[{{0.926164, 1.585472, 0.009185},{0.927030, 1.586664, 0.009538},{
      0.927451, 1.586450, 0.009538},{0.926996, 1.585048, 0.009185}}],
    Polygon[{{0.927451, 1.586450, -0.009538},{0.926996, 1.585048, -0.009185},{
      0.927918, 1.584902, -0.009185},{0.927918, 1.586376, -0.009538}}],
    Polygon[{{0.926996, 1.585048, -0.009185},{0.926563, 1.583717, -0.008605},{
      0.927918, 1.583502, -0.008605},{0.927918, 1.584902, -0.009185}}],
    Polygon[{{0.926563, 1.583717, -0.008605},{0.926164, 1.582488, -0.007813},{
      0.927918, 1.582210, -0.007813},{0.927918, 1.583502, -0.008605}}],
    Polygon[{{0.926164, 1.582488, -0.007813},{0.925808, 1.581392, -0.006829},{
      0.927918, 1.581058, -0.006829},{0.927918, 1.582210, -0.007813}}],
    Polygon[{{0.925808, 1.581392, -0.006829},{0.925504, 1.580456, -0.005676},{
      0.927918, 1.580074, -0.005676},{0.927918, 1.581058, -0.006829}}],
    Polygon[{{0.925504, 1.580456, -0.005676},{0.925259, 1.579703, -0.004384},{
      0.927918, 1.579282, -0.004384},{0.927918, 1.580074, -0.005676}}],
    Polygon[{{0.925259, 1.579703, -0.004384},{0.925080, 1.579152, -0.002984},{
      0.927918, 1.578702, -0.002984},{0.927918, 1.579282, -0.004384}}],
    Polygon[{{0.925080, 1.579152, -0.002984},{0.924970, 1.578815, -0.001511},{
      0.927918, 1.578348, -0.001511},{0.927918, 1.578702, -0.002984}}],
    Polygon[{{0.924970, 1.578815, -0.001511},{0.924934, 1.578702, 0.000000},{
      0.927918, 1.578229, 0.000000},{0.927918, 1.578348, -0.001511}}],
    Polygon[{{0.924934, 1.578702, 0.000000},{0.924970, 1.578815, 0.001511},{
      0.927918, 1.578348, 0.001511},{0.927918, 1.578229, 0.000000}}],
    Polygon[{{0.924970, 1.578815, 0.001511},{0.925080, 1.579152, 0.002984},{
      0.927918, 1.578702, 0.002984},{0.927918, 1.578348, 0.001511}}],
    Polygon[{{0.925080, 1.579152, 0.002984},{0.925259, 1.579703, 0.004384},{
      0.927918, 1.579282, 0.004384},{0.927918, 1.578702, 0.002984}}],
    Polygon[{{0.925259, 1.579703, 0.004384},{0.925504, 1.580456, 0.005676},{
      0.927918, 1.580074, 0.005676},{0.927918, 1.579282, 0.004384}}],
    Polygon[{{0.925504, 1.580456, 0.005676},{0.925808, 1.581392, 0.006829},{
      0.927918, 1.581058, 0.006829},{0.927918, 1.580074, 0.005676}}],
    Polygon[{{0.925808, 1.581392, 0.006829},{0.926164, 1.582488, 0.007813},{
      0.927918, 1.582210, 0.007813},{0.927918, 1.581058, 0.006829}}],
    Polygon[{{0.926164, 1.582488, 0.007813},{0.926563, 1.583717, 0.008605},{
      0.927918, 1.583502, 0.008605},{0.927918, 1.582210, 0.007813}}],
    Polygon[{{0.926563, 1.583717, 0.008605},{0.926996, 1.585048, 0.009185},{
      0.927918, 1.584902, 0.009185},{0.927918, 1.583502, 0.008605}}],
    Polygon[{{0.926996, 1.585048, 0.009185},{0.927451, 1.586450, 0.009538},{
      0.927918, 1.586376, 0.009538},{0.927918, 1.584902, 0.009185}}],
    Polygon[{{0.927918, 1.586376, -0.009538},{0.927918, 1.584902, -0.009185},{
      0.928840, 1.585048, -0.009185},{0.928385, 1.586450, -0.009538}}],
    Polygon[{{0.927918, 1.584902, -0.009185},{0.927918, 1.583502, -0.008605},{
      0.929273, 1.583717, -0.008605},{0.928840, 1.585048, -0.009185}}],
    Polygon[{{0.927918, 1.583502, -0.008605},{0.927918, 1.582210, -0.007813},{
      0.929672, 1.582488, -0.007813},{0.929273, 1.583717, -0.008605}}],
    Polygon[{{0.927918, 1.582210, -0.007813},{0.927918, 1.581058, -0.006829},{
      0.930028, 1.581392, -0.006829},{0.929672, 1.582488, -0.007813}}],
    Polygon[{{0.927918, 1.581058, -0.006829},{0.927918, 1.580074, -0.005676},{
      0.930332, 1.580456, -0.005676},{0.930028, 1.581392, -0.006829}}],
    Polygon[{{0.927918, 1.580074, -0.005676},{0.927918, 1.579282, -0.004384},{
      0.930577, 1.579703, -0.004384},{0.930332, 1.580456, -0.005676}}],
    Polygon[{{0.927918, 1.579282, -0.004384},{0.927918, 1.578702, -0.002984},{
      0.930756, 1.579152, -0.002984},{0.930577, 1.579703, -0.004384}}],
    Polygon[{{0.927918, 1.578702, -0.002984},{0.927918, 1.578348, -0.001511},{
      0.930865, 1.578815, -0.001511},{0.930756, 1.579152, -0.002984}}],
    Polygon[{{0.927918, 1.578348, -0.001511},{0.927918, 1.578229, 0.000000},{
      0.930902, 1.578702, 0.000000},{0.930865, 1.578815, -0.001511}}],
    Polygon[{{0.927918, 1.578229, 0.000000},{0.927918, 1.578348, 0.001511},{
      0.930865, 1.578815, 0.001511},{0.930902, 1.578702, 0.000000}}],
    Polygon[{{0.927918, 1.578348, 0.001511},{0.927918, 1.578702, 0.002984},{
      0.930756, 1.579152, 0.002984},{0.930865, 1.578815, 0.001511}}],
    Polygon[{{0.927918, 1.578702, 0.002984},{0.927918, 1.579282, 0.004384},{
      0.930577, 1.579703, 0.004384},{0.930756, 1.579152, 0.002984}}],
    Polygon[{{0.927918, 1.579282, 0.004384},{0.927918, 1.580074, 0.005676},{
      0.930332, 1.580456, 0.005676},{0.930577, 1.579703, 0.004384}}],
    Polygon[{{0.927918, 1.580074, 0.005676},{0.927918, 1.581058, 0.006829},{
      0.930028, 1.581392, 0.006829},{0.930332, 1.580456, 0.005676}}],
    Polygon[{{0.927918, 1.581058, 0.006829},{0.927918, 1.582210, 0.007813},{
      0.929672, 1.582488, 0.007813},{0.930028, 1.581392, 0.006829}}],
    Polygon[{{0.927918, 1.582210, 0.007813},{0.927918, 1.583502, 0.008605},{
      0.929273, 1.583717, 0.008605},{0.929672, 1.582488, 0.007813}}],
    Polygon[{{0.927918, 1.583502, 0.008605},{0.927918, 1.584902, 0.009185},{
      0.928840, 1.585048, 0.009185},{0.929273, 1.583717, 0.008605}}],
    Polygon[{{0.927918, 1.584902, 0.009185},{0.927918, 1.586376, 0.009538},{
      0.928385, 1.586450, 0.009538},{0.928840, 1.585048, 0.009185}}],
    Polygon[{{0.928385, 1.586450, -0.009538},{0.928840, 1.585048, -0.009185},{
      0.929672, 1.585472, -0.009185},{0.928806, 1.586664, -0.009538}}],
    Polygon[{{0.928840, 1.585048, -0.009185},{0.929273, 1.583717, -0.008605},{
      0.930495, 1.584340, -0.008605},{0.929672, 1.585472, -0.009185}}],
    Polygon[{{0.929273, 1.583717, -0.008605},{0.929672, 1.582488, -0.007813},{
      0.931254, 1.583294, -0.007813},{0.930495, 1.584340, -0.008605}}],
    Polygon[{{0.929672, 1.582488, -0.007813},{0.930028, 1.581392, -0.006829},{
      0.931932, 1.582362, -0.006829},{0.931254, 1.583294, -0.007813}}],
    Polygon[{{0.930028, 1.581392, -0.006829},{0.930332, 1.580456, -0.005676},{
      0.932510, 1.581566, -0.005676},{0.931932, 1.582362, -0.006829}}],
    Polygon[{{0.930332, 1.580456, -0.005676},{0.930577, 1.579703, -0.004384},{
      0.932976, 1.580925, -0.004384},{0.932510, 1.581566, -0.005676}}],
    Polygon[{{0.930577, 1.579703, -0.004384},{0.930756, 1.579152, -0.002984},{
      0.933316, 1.580456, -0.002984},{0.932976, 1.580925, -0.004384}}],
    Polygon[{{0.930756, 1.579152, -0.002984},{0.930865, 1.578815, -0.001511},{
      0.933524, 1.580170, -0.001511},{0.933316, 1.580456, -0.002984}}],
    Polygon[{{0.930865, 1.578815, -0.001511},{0.930902, 1.578702, 0.000000},{
      0.933594, 1.580074, 0.000000},{0.933524, 1.580170, -0.001511}}],
    Polygon[{{0.930902, 1.578702, 0.000000},{0.930865, 1.578815, 0.001511},{
      0.933524, 1.580170, 0.001511},{0.933594, 1.580074, 0.000000}}],
    Polygon[{{0.930865, 1.578815, 0.001511},{0.930756, 1.579152, 0.002984},{
      0.933316, 1.580456, 0.002984},{0.933524, 1.580170, 0.001511}}],
    Polygon[{{0.930756, 1.579152, 0.002984},{0.930577, 1.579703, 0.004384},{
      0.932976, 1.580925, 0.004384},{0.933316, 1.580456, 0.002984}}],
    Polygon[{{0.930577, 1.579703, 0.004384},{0.930332, 1.580456, 0.005676},{
      0.932510, 1.581566, 0.005676},{0.932976, 1.580925, 0.004384}}],
    Polygon[{{0.930332, 1.580456, 0.005676},{0.930028, 1.581392, 0.006829},{
      0.931932, 1.582362, 0.006829},{0.932510, 1.581566, 0.005676}}],
    Polygon[{{0.930028, 1.581392, 0.006829},{0.929672, 1.582488, 0.007813},{
      0.931254, 1.583294, 0.007813},{0.931932, 1.582362, 0.006829}}],
    Polygon[{{0.929672, 1.582488, 0.007813},{0.929273, 1.583717, 0.008605},{
      0.930495, 1.584340, 0.008605},{0.931254, 1.583294, 0.007813}}],
    Polygon[{{0.929273, 1.583717, 0.008605},{0.928840, 1.585048, 0.009185},{
      0.929672, 1.585472, 0.009185},{0.930495, 1.584340, 0.008605}}],
    Polygon[{{0.928840, 1.585048, 0.009185},{0.928385, 1.586450, 0.009538},{
      0.928806, 1.586664, 0.009538},{0.929672, 1.585472, 0.009185}}],
    Polygon[{{0.928806, 1.586664, -0.009538},{0.929672, 1.585472, -0.009185},{
      0.930332, 1.586133, -0.009185},{0.929140, 1.586999, -0.009538}}],
    Polygon[{{0.929672, 1.585472, -0.009185},{0.930495, 1.584340, -0.008605},{
      0.931465, 1.585310, -0.008605},{0.930332, 1.586133, -0.009185}}],
    Polygon[{{0.930495, 1.584340, -0.008605},{0.931254, 1.583294, -0.007813},{
      0.932510, 1.584550, -0.007813},{0.931465, 1.585310, -0.008605}}],
    Polygon[{{0.931254, 1.583294, -0.007813},{0.931932, 1.582362, -0.006829},{
      0.933442, 1.583873, -0.006829},{0.932510, 1.584550, -0.007813}}],
    Polygon[{{0.931932, 1.582362, -0.006829},{0.932510, 1.581566, -0.005676},{
      0.934239, 1.583294, -0.005676},{0.933442, 1.583873, -0.006829}}],
    Polygon[{{0.932510, 1.581566, -0.005676},{0.932976, 1.580925, -0.004384},{
      0.934879, 1.582829, -0.004384},{0.934239, 1.583294, -0.005676}}],
    Polygon[{{0.932976, 1.580925, -0.004384},{0.933316, 1.580456, -0.002984},{
      0.935348, 1.582488, -0.002984},{0.934879, 1.582829, -0.004384}}],
    Polygon[{{0.933316, 1.580456, -0.002984},{0.933524, 1.580170, -0.001511},{
      0.935634, 1.582280, -0.001511},{0.935348, 1.582488, -0.002984}}],
    Polygon[{{0.933524, 1.580170, -0.001511},{0.933594, 1.580074, 0.000000},{
      0.935731, 1.582210, 0.000000},{0.935634, 1.582280, -0.001511}}],
    Polygon[{{0.933594, 1.580074, 0.000000},{0.933524, 1.580170, 0.001511},{
      0.935634, 1.582280, 0.001511},{0.935731, 1.582210, 0.000000}}],
    Polygon[{{0.933524, 1.580170, 0.001511},{0.933316, 1.580456, 0.002984},{
      0.935348, 1.582488, 0.002984},{0.935634, 1.582280, 0.001511}}],
    Polygon[{{0.933316, 1.580456, 0.002984},{0.932976, 1.580925, 0.004384},{
      0.934879, 1.582829, 0.004384},{0.935348, 1.582488, 0.002984}}],
    Polygon[{{0.932976, 1.580925, 0.004384},{0.932510, 1.581566, 0.005676},{
      0.934239, 1.583294, 0.005676},{0.934879, 1.582829, 0.004384}}],
    Polygon[{{0.932510, 1.581566, 0.005676},{0.931932, 1.582362, 0.006829},{
      0.933442, 1.583873, 0.006829},{0.934239, 1.583294, 0.005676}}],
    Polygon[{{0.931932, 1.582362, 0.006829},{0.931254, 1.583294, 0.007813},{
      0.932510, 1.584550, 0.007813},{0.933442, 1.583873, 0.006829}}],
    Polygon[{{0.931254, 1.583294, 0.007813},{0.930495, 1.584340, 0.008605},{
      0.931465, 1.585310, 0.008605},{0.932510, 1.584550, 0.007813}}],
    Polygon[{{0.930495, 1.584340, 0.008605},{0.929672, 1.585472, 0.009185},{
      0.930332, 1.586133, 0.009185},{0.931465, 1.585310, 0.008605}}],
    Polygon[{{0.929672, 1.585472, 0.009185},{0.928806, 1.586664, 0.009538},{
      0.929140, 1.586999, 0.009538},{0.930332, 1.586133, 0.009185}}],
    Polygon[{{0.929140, 1.586999, -0.009538},{0.930332, 1.586133, -0.009185},{
      0.930756, 1.586964, -0.009185},{0.929355, 1.587420, -0.009538}}],
    Polygon[{{0.930332, 1.586133, -0.009185},{0.931465, 1.585310, -0.008605},{
      0.932088, 1.586532, -0.008605},{0.930756, 1.586964, -0.009185}}],
    Polygon[{{0.931465, 1.585310, -0.008605},{0.932510, 1.584550, -0.007813},{
      0.933316, 1.586133, -0.007813},{0.932088, 1.586532, -0.008605}}],
    Polygon[{{0.932510, 1.584550, -0.007813},{0.933442, 1.583873, -0.006829},{
      0.934412, 1.585776, -0.006829},{0.933316, 1.586133, -0.007813}}],
    Polygon[{{0.933442, 1.583873, -0.006829},{0.934239, 1.583294, -0.005676},{
      0.935348, 1.585472, -0.005676},{0.934412, 1.585776, -0.006829}}],
    Polygon[{{0.934239, 1.583294, -0.005676},{0.934879, 1.582829, -0.004384},{
      0.936101, 1.585228, -0.004384},{0.935348, 1.585472, -0.005676}}],
    Polygon[{{0.934879, 1.582829, -0.004384},{0.935348, 1.582488, -0.002984},{
      0.936653, 1.585048, -0.002984},{0.936101, 1.585228, -0.004384}}],
    Polygon[{{0.935348, 1.582488, -0.002984},{0.935634, 1.582280, -0.001511},{
      0.936989, 1.584939, -0.001511},{0.936653, 1.585048, -0.002984}}],
    Polygon[{{0.935634, 1.582280, -0.001511},{0.935731, 1.582210, 0.000000},{
      0.937102, 1.584902, 0.000000},{0.936989, 1.584939, -0.001511}}],
    Polygon[{{0.935731, 1.582210, 0.000000},{0.935634, 1.582280, 0.001511},{
      0.936989, 1.584939, 0.001511},{0.937102, 1.584902, 0.000000}}],
    Polygon[{{0.935634, 1.582280, 0.001511},{0.935348, 1.582488, 0.002984},{
      0.936653, 1.585048, 0.002984},{0.936989, 1.584939, 0.001511}}],
    Polygon[{{0.935348, 1.582488, 0.002984},{0.934879, 1.582829, 0.004384},{
      0.936101, 1.585228, 0.004384},{0.936653, 1.585048, 0.002984}}],
    Polygon[{{0.934879, 1.582829, 0.004384},{0.934239, 1.583294, 0.005676},{
      0.935348, 1.585472, 0.005676},{0.936101, 1.585228, 0.004384}}],
    Polygon[{{0.934239, 1.583294, 0.005676},{0.933442, 1.583873, 0.006829},{
      0.934412, 1.585776, 0.006829},{0.935348, 1.585472, 0.005676}}],
    Polygon[{{0.933442, 1.583873, 0.006829},{0.932510, 1.584550, 0.007813},{
      0.933316, 1.586133, 0.007813},{0.934412, 1.585776, 0.006829}}],
    Polygon[{{0.932510, 1.584550, 0.007813},{0.931465, 1.585310, 0.008605},{
      0.932088, 1.586532, 0.008605},{0.933316, 1.586133, 0.007813}}],
    Polygon[{{0.931465, 1.585310, 0.008605},{0.930332, 1.586133, 0.009185},{
      0.930756, 1.586964, 0.009185},{0.932088, 1.586532, 0.008605}}],
    Polygon[{{0.930332, 1.586133, 0.009185},{0.929140, 1.586999, 0.009538},{
      0.929355, 1.587420, 0.009538},{0.930756, 1.586964, 0.009185}}],
    Polygon[{{0.929355, 1.587420, -0.009538},{0.930756, 1.586964, -0.009185},{
      0.930902, 1.587887, -0.009185},{0.929429, 1.587887, -0.009538}}],
    Polygon[{{0.930756, 1.586964, -0.009185},{0.932088, 1.586532, -0.008605},{
      0.932302, 1.587887, -0.008605},{0.930902, 1.587887, -0.009185}}],
    Polygon[{{0.932088, 1.586532, -0.008605},{0.933316, 1.586133, -0.007813},{
      0.933594, 1.587887, -0.007813},{0.932302, 1.587887, -0.008605}}],
    Polygon[{{0.933316, 1.586133, -0.007813},{0.934412, 1.585776, -0.006829},{
      0.934747, 1.587887, -0.006829},{0.933594, 1.587887, -0.007813}}],
    Polygon[{{0.934412, 1.585776, -0.006829},{0.935348, 1.585472, -0.005676},{
      0.935731, 1.587887, -0.005676},{0.934747, 1.587887, -0.006829}}],
    Polygon[{{0.935348, 1.585472, -0.005676},{0.936101, 1.585228, -0.004384},{
      0.936522, 1.587887, -0.004384},{0.935731, 1.587887, -0.005676}}],
    Polygon[{{0.936101, 1.585228, -0.004384},{0.936653, 1.585048, -0.002984},{
      0.937102, 1.587887, -0.002984},{0.936522, 1.587887, -0.004384}}],
    Polygon[{{0.936653, 1.585048, -0.002984},{0.936989, 1.584939, -0.001511},{
      0.937456, 1.587887, -0.001511},{0.937102, 1.587887, -0.002984}}],
    Polygon[{{0.936989, 1.584939, -0.001511},{0.937102, 1.584902, 0.000000},{
      0.937575, 1.587887, 0.000000},{0.937456, 1.587887, -0.001511}}],
    Polygon[{{0.937102, 1.584902, 0.000000},{0.936989, 1.584939, 0.001511},{
      0.937456, 1.587887, 0.001511},{0.937575, 1.587887, 0.000000}}],
    Polygon[{{0.936989, 1.584939, 0.001511},{0.936653, 1.585048, 0.002984},{
      0.937102, 1.587887, 0.002984},{0.937456, 1.587887, 0.001511}}],
    Polygon[{{0.936653, 1.585048, 0.002984},{0.936101, 1.585228, 0.004384},{
      0.936522, 1.587887, 0.004384},{0.937102, 1.587887, 0.002984}}],
    Polygon[{{0.936101, 1.585228, 0.004384},{0.935348, 1.585472, 0.005676},{
      0.935731, 1.587887, 0.005676},{0.936522, 1.587887, 0.004384}}],
    Polygon[{{0.935348, 1.585472, 0.005676},{0.934412, 1.585776, 0.006829},{
      0.934747, 1.587887, 0.006829},{0.935731, 1.587887, 0.005676}}],
    Polygon[{{0.934412, 1.585776, 0.006829},{0.933316, 1.586133, 0.007813},{
      0.933594, 1.587887, 0.007813},{0.934747, 1.587887, 0.006829}}],
    Polygon[{{0.933316, 1.586133, 0.007813},{0.932088, 1.586532, 0.008605},{
      0.932302, 1.587887, 0.008605},{0.933594, 1.587887, 0.007813}}],
    Polygon[{{0.932088, 1.586532, 0.008605},{0.930756, 1.586964, 0.009185},{
      0.930902, 1.587887, 0.009185},{0.932302, 1.587887, 0.008605}}],
    Polygon[{{0.930756, 1.586964, 0.009185},{0.929355, 1.587420, 0.009538},{
      0.929429, 1.587887, 0.009538},{0.930902, 1.587887, 0.009185}}],
    Polygon[{{0.960470, 1.543797, -0.008290},{0.961750, 1.543797, -0.007983},{
      0.961623, 1.544599, -0.007983},{0.960405, 1.544203, -0.008290}}],
    Polygon[{{0.961750, 1.543797, -0.007983},{0.962967, 1.543797, -0.007479},{
      0.962781, 1.544975, -0.007479},{0.961623, 1.544599, -0.007983}}],
    Polygon[{{0.962967, 1.543797, -0.007479},{0.964090, 1.543797, -0.006791},{
      0.963849, 1.545322, -0.006791},{0.962781, 1.544975, -0.007479}}],
    Polygon[{{0.964090, 1.543797, -0.006791},{0.965092, 1.543797, -0.005935},{
      0.964801, 1.545632, -0.005935},{0.963849, 1.545322, -0.006791}}],
    Polygon[{{0.965092, 1.543797, -0.005935},{0.965947, 1.543797, -0.004934},{
      0.965615, 1.545896, -0.004934},{0.964801, 1.545632, -0.005935}}],
    Polygon[{{0.965947, 1.543797, -0.004934},{0.966635, 1.543797, -0.003811},{
      0.966269, 1.546109, -0.003811},{0.965615, 1.545896, -0.004934}}],
    Polygon[{{0.966635, 1.543797, -0.003811},{0.967139, 1.543797, -0.002594},{
      0.966749, 1.546264, -0.002594},{0.966269, 1.546109, -0.003811}}],
    Polygon[{{0.967139, 1.543797, -0.002594},{0.967447, 1.543797, -0.001313},{
      0.967041, 1.546359, -0.001313},{0.966749, 1.546264, -0.002594}}],
    Polygon[{{0.967447, 1.543797, -0.001313},{0.967550, 1.543797, 0.000000},{
      0.967139, 1.546391, 0.000000},{0.967041, 1.546359, -0.001313}}],
    Polygon[{{0.967550, 1.543797, 0.000000},{0.967447, 1.543797, 0.001313},{
      0.967041, 1.546359, 0.001313},{0.967139, 1.546391, 0.000000}}],
    Polygon[{{0.967447, 1.543797, 0.001313},{0.967139, 1.543797, 0.002594},{
      0.966749, 1.546264, 0.002594},{0.967041, 1.546359, 0.001313}}],
    Polygon[{{0.967139, 1.543797, 0.002594},{0.966635, 1.543797, 0.003811},{
      0.966269, 1.546109, 0.003811},{0.966749, 1.546264, 0.002594}}],
    Polygon[{{0.966635, 1.543797, 0.003811},{0.965947, 1.543797, 0.004934},{
      0.965615, 1.545896, 0.004934},{0.966269, 1.546109, 0.003811}}],
    Polygon[{{0.965947, 1.543797, 0.004934},{0.965092, 1.543797, 0.005935},{
      0.964801, 1.545632, 0.005935},{0.965615, 1.545896, 0.004934}}],
    Polygon[{{0.965092, 1.543797, 0.005935},{0.964090, 1.543797, 0.006791},{
      0.963849, 1.545322, 0.006791},{0.964801, 1.545632, 0.005935}}],
    Polygon[{{0.964090, 1.543797, 0.006791},{0.962967, 1.543797, 0.007479},{
      0.962781, 1.544975, 0.007479},{0.963849, 1.545322, 0.006791}}],
    Polygon[{{0.962967, 1.543797, 0.007479},{0.961750, 1.543797, 0.007983},{
      0.961623, 1.544599, 0.007983},{0.962781, 1.544975, 0.007479}}],
    Polygon[{{0.961750, 1.543797, 0.007983},{0.960470, 1.543797, 0.008290},{
      0.960405, 1.544203, 0.008290},{0.961623, 1.544599, 0.007983}}],
    Polygon[{{0.960405, 1.544203, -0.008290},{0.961623, 1.544599, -0.007983},{
      0.961255, 1.545322, -0.007983},{0.960219, 1.544569, -0.008290}}],
    Polygon[{{0.961623, 1.544599, -0.007983},{0.962781, 1.544975, -0.007479},{
      0.962239, 1.546037, -0.007479},{0.961255, 1.545322, -0.007983}}],
    Polygon[{{0.962781, 1.544975, -0.007479},{0.963849, 1.545322, -0.006791},{
      0.963148, 1.546697, -0.006791},{0.962239, 1.546037, -0.007479}}],
    Polygon[{{0.963849, 1.545322, -0.006791},{0.964801, 1.545632, -0.005935},{
      0.963958, 1.547286, -0.005935},{0.963148, 1.546697, -0.006791}}],
    Polygon[{{0.964801, 1.545632, -0.005935},{0.965615, 1.545896, -0.004934},{
      0.964650, 1.547789, -0.004934},{0.963958, 1.547286, -0.005935}}],
    Polygon[{{0.965615, 1.545896, -0.004934},{0.966269, 1.546109, -0.003811},{
      0.965207, 1.548193, -0.003811},{0.964650, 1.547789, -0.004934}}],
    Polygon[{{0.966269, 1.546109, -0.003811},{0.966749, 1.546264, -0.002594},{
      0.965615, 1.548490, -0.002594},{0.965207, 1.548193, -0.003811}}],
    Polygon[{{0.966749, 1.546264, -0.002594},{0.967041, 1.546359, -0.001313},{
      0.965864, 1.548670, -0.001313},{0.965615, 1.548490, -0.002594}}],
    Polygon[{{0.967041, 1.546359, -0.001313},{0.967139, 1.546391, 0.000000},{
      0.965947, 1.548731, 0.000000},{0.965864, 1.548670, -0.001313}}],
    Polygon[{{0.967139, 1.546391, 0.000000},{0.967041, 1.546359, 0.001313},{
      0.965864, 1.548670, 0.001313},{0.965947, 1.548731, 0.000000}}],
    Polygon[{{0.967041, 1.546359, 0.001313},{0.966749, 1.546264, 0.002594},{
      0.965615, 1.548490, 0.002594},{0.965864, 1.548670, 0.001313}}],
    Polygon[{{0.966749, 1.546264, 0.002594},{0.966269, 1.546109, 0.003811},{
      0.965207, 1.548193, 0.003811},{0.965615, 1.548490, 0.002594}}],
    Polygon[{{0.966269, 1.546109, 0.003811},{0.965615, 1.545896, 0.004934},{
      0.964650, 1.547789, 0.004934},{0.965207, 1.548193, 0.003811}}],
    Polygon[{{0.965615, 1.545896, 0.004934},{0.964801, 1.545632, 0.005935},{
      0.963958, 1.547286, 0.005935},{0.964650, 1.547789, 0.004934}}],
    Polygon[{{0.964801, 1.545632, 0.005935},{0.963849, 1.545322, 0.006791},{
      0.963148, 1.546697, 0.006791},{0.963958, 1.547286, 0.005935}}],
    Polygon[{{0.963849, 1.545322, 0.006791},{0.962781, 1.544975, 0.007479},{
      0.962239, 1.546037, 0.007479},{0.963148, 1.546697, 0.006791}}],
    Polygon[{{0.962781, 1.544975, 0.007479},{0.961623, 1.544599, 0.007983},{
      0.961255, 1.545322, 0.007983},{0.962239, 1.546037, 0.007479}}],
    Polygon[{{0.961623, 1.544599, 0.007983},{0.960405, 1.544203, 0.008290},{
      0.960219, 1.544569, 0.008290},{0.961255, 1.545322, 0.007983}}],
    Polygon[{{0.960219, 1.544569, -0.008290},{0.961255, 1.545322, -0.007983},{
      0.960681, 1.545896, -0.007983},{0.959928, 1.544860, -0.008290}}],
    Polygon[{{0.961255, 1.545322, -0.007983},{0.962239, 1.546037, -0.007479},{
      0.961396, 1.546880, -0.007479},{0.960681, 1.545896, -0.007983}}],
    Polygon[{{0.962239, 1.546037, -0.007479},{0.963148, 1.546697, -0.006791},{
      0.962056, 1.547789, -0.006791},{0.961396, 1.546880, -0.007479}}],
    Polygon[{{0.963148, 1.546697, -0.006791},{0.963958, 1.547286, -0.005935},{
      0.962645, 1.548599, -0.005935},{0.962056, 1.547789, -0.006791}}],
    Polygon[{{0.963958, 1.547286, -0.005935},{0.964650, 1.547789, -0.004934},{
      0.963148, 1.549291, -0.004934},{0.962645, 1.548599, -0.005935}}],
    Polygon[{{0.964650, 1.547789, -0.004934},{0.965207, 1.548193, -0.003811},{
      0.963552, 1.549848, -0.003811},{0.963148, 1.549291, -0.004934}}],
    Polygon[{{0.965207, 1.548193, -0.003811},{0.965615, 1.548490, -0.002594},{
      0.963849, 1.550256, -0.002594},{0.963552, 1.549848, -0.003811}}],
    Polygon[{{0.965615, 1.548490, -0.002594},{0.965864, 1.548670, -0.001313},{
      0.964029, 1.550504, -0.001313},{0.963849, 1.550256, -0.002594}}],
    Polygon[{{0.965864, 1.548670, -0.001313},{0.965947, 1.548731, 0.000000},{
      0.964090, 1.550588, 0.000000},{0.964029, 1.550504, -0.001313}}],
    Polygon[{{0.965947, 1.548731, 0.000000},{0.965864, 1.548670, 0.001313},{
      0.964029, 1.550504, 0.001313},{0.964090, 1.550588, 0.000000}}],
    Polygon[{{0.965864, 1.548670, 0.001313},{0.965615, 1.548490, 0.002594},{
      0.963849, 1.550256, 0.002594},{0.964029, 1.550504, 0.001313}}],
    Polygon[{{0.965615, 1.548490, 0.002594},{0.965207, 1.548193, 0.003811},{
      0.963552, 1.549848, 0.003811},{0.963849, 1.550256, 0.002594}}],
    Polygon[{{0.965207, 1.548193, 0.003811},{0.964650, 1.547789, 0.004934},{
      0.963148, 1.549291, 0.004934},{0.963552, 1.549848, 0.003811}}],
    Polygon[{{0.964650, 1.547789, 0.004934},{0.963958, 1.547286, 0.005935},{
      0.962645, 1.548599, 0.005935},{0.963148, 1.549291, 0.004934}}],
    Polygon[{{0.963958, 1.547286, 0.005935},{0.963148, 1.546697, 0.006791},{
      0.962056, 1.547789, 0.006791},{0.962645, 1.548599, 0.005935}}],
    Polygon[{{0.963148, 1.546697, 0.006791},{0.962239, 1.546037, 0.007479},{
      0.961396, 1.546880, 0.007479},{0.962056, 1.547789, 0.006791}}],
    Polygon[{{0.962239, 1.546037, 0.007479},{0.961255, 1.545322, 0.007983},{
      0.960681, 1.545896, 0.007983},{0.961396, 1.546880, 0.007479}}],
    Polygon[{{0.961255, 1.545322, 0.007983},{0.960219, 1.544569, 0.008290},{
      0.959928, 1.544860, 0.008290},{0.960681, 1.545896, 0.007983}}],
    Polygon[{{0.959928, 1.544860, -0.008290},{0.960681, 1.545896, -0.007983},{
      0.959958, 1.546264, -0.007983},{0.959562, 1.545046, -0.008290}}],
    Polygon[{{0.960681, 1.545896, -0.007983},{0.961396, 1.546880, -0.007479},{
      0.960334, 1.547422, -0.007479},{0.959958, 1.546264, -0.007983}}],
    Polygon[{{0.961396, 1.546880, -0.007479},{0.962056, 1.547789, -0.006791},{
      0.960681, 1.548490, -0.006791},{0.960334, 1.547422, -0.007479}}],
    Polygon[{{0.962056, 1.547789, -0.006791},{0.962645, 1.548599, -0.005935},{
      0.960991, 1.549442, -0.005935},{0.960681, 1.548490, -0.006791}}],
    Polygon[{{0.962645, 1.548599, -0.005935},{0.963148, 1.549291, -0.004934},{
      0.961255, 1.550256, -0.004934},{0.960991, 1.549442, -0.005935}}],
    Polygon[{{0.963148, 1.549291, -0.004934},{0.963552, 1.549848, -0.003811},{
      0.961468, 1.550910, -0.003811},{0.961255, 1.550256, -0.004934}}],
    Polygon[{{0.963552, 1.549848, -0.003811},{0.963849, 1.550256, -0.002594},{
      0.961623, 1.551390, -0.002594},{0.961468, 1.550910, -0.003811}}],
    Polygon[{{0.963849, 1.550256, -0.002594},{0.964029, 1.550504, -0.001313},{
      0.961718, 1.551682, -0.001313},{0.961623, 1.551390, -0.002594}}],
    Polygon[{{0.964029, 1.550504, -0.001313},{0.964090, 1.550588, 0.000000},{
      0.961750, 1.551780, 0.000000},{0.961718, 1.551682, -0.001313}}],
    Polygon[{{0.964090, 1.550588, 0.000000},{0.964029, 1.550504, 0.001313},{
      0.961718, 1.551682, 0.001313},{0.961750, 1.551780, 0.000000}}],
    Polygon[{{0.964029, 1.550504, 0.001313},{0.963849, 1.550256, 0.002594},{
      0.961623, 1.551390, 0.002594},{0.961718, 1.551682, 0.001313}}],
    Polygon[{{0.963849, 1.550256, 0.002594},{0.963552, 1.549848, 0.003811},{
      0.961468, 1.550910, 0.003811},{0.961623, 1.551390, 0.002594}}],
    Polygon[{{0.963552, 1.549848, 0.003811},{0.963148, 1.549291, 0.004934},{
      0.961255, 1.550256, 0.004934},{0.961468, 1.550910, 0.003811}}],
    Polygon[{{0.963148, 1.549291, 0.004934},{0.962645, 1.548599, 0.005935},{
      0.960991, 1.549442, 0.005935},{0.961255, 1.550256, 0.004934}}],
    Polygon[{{0.962645, 1.548599, 0.005935},{0.962056, 1.547789, 0.006791},{
      0.960681, 1.548490, 0.006791},{0.960991, 1.549442, 0.005935}}],
    Polygon[{{0.962056, 1.547789, 0.006791},{0.961396, 1.546880, 0.007479},{
      0.960334, 1.547422, 0.007479},{0.960681, 1.548490, 0.006791}}],
    Polygon[{{0.961396, 1.546880, 0.007479},{0.960681, 1.545896, 0.007983},{
      0.959958, 1.546264, 0.007983},{0.960334, 1.547422, 0.007479}}],
    Polygon[{{0.960681, 1.545896, 0.007983},{0.959928, 1.544860, 0.008290},{
      0.959562, 1.545046, 0.008290},{0.959958, 1.546264, 0.007983}}],
    Polygon[{{0.959562, 1.545046, -0.008290},{0.959958, 1.546264, -0.007983},{
      0.959157, 1.546391, -0.007983},{0.959157, 1.545111, -0.008290}}],
    Polygon[{{0.959958, 1.546264, -0.007983},{0.960334, 1.547422, -0.007479},{
      0.959157, 1.547608, -0.007479},{0.959157, 1.546391, -0.007983}}],
    Polygon[{{0.960334, 1.547422, -0.007479},{0.960681, 1.548490, -0.006791},{
      0.959157, 1.548731, -0.006791},{0.959157, 1.547608, -0.007479}}],
    Polygon[{{0.960681, 1.548490, -0.006791},{0.960991, 1.549442, -0.005935},{
      0.959157, 1.549733, -0.005935},{0.959157, 1.548731, -0.006791}}],
    Polygon[{{0.960991, 1.549442, -0.005935},{0.961255, 1.550256, -0.004934},{
      0.959157, 1.550588, -0.004934},{0.959157, 1.549733, -0.005935}}],
    Polygon[{{0.961255, 1.550256, -0.004934},{0.961468, 1.550910, -0.003811},{
      0.959157, 1.551276, -0.003811},{0.959157, 1.550588, -0.004934}}],
    Polygon[{{0.961468, 1.550910, -0.003811},{0.961623, 1.551390, -0.002594},{
      0.959157, 1.551780, -0.002594},{0.959157, 1.551276, -0.003811}}],
    Polygon[{{0.961623, 1.551390, -0.002594},{0.961718, 1.551682, -0.001313},{
      0.959157, 1.552088, -0.001313},{0.959157, 1.551780, -0.002594}}],
    Polygon[{{0.961718, 1.551682, -0.001313},{0.961750, 1.551780, 0.000000},{
      0.959157, 1.552191, 0.000000},{0.959157, 1.552088, -0.001313}}],
    Polygon[{{0.961750, 1.551780, 0.000000},{0.961718, 1.551682, 0.001313},{
      0.959157, 1.552088, 0.001313},{0.959157, 1.552191, 0.000000}}],
    Polygon[{{0.961718, 1.551682, 0.001313},{0.961623, 1.551390, 0.002594},{
      0.959157, 1.551780, 0.002594},{0.959157, 1.552088, 0.001313}}],
    Polygon[{{0.961623, 1.551390, 0.002594},{0.961468, 1.550910, 0.003811},{
      0.959157, 1.551276, 0.003811},{0.959157, 1.551780, 0.002594}}],
    Polygon[{{0.961468, 1.550910, 0.003811},{0.961255, 1.550256, 0.004934},{
      0.959157, 1.550588, 0.004934},{0.959157, 1.551276, 0.003811}}],
    Polygon[{{0.961255, 1.550256, 0.004934},{0.960991, 1.549442, 0.005935},{
      0.959157, 1.549733, 0.005935},{0.959157, 1.550588, 0.004934}}],
    Polygon[{{0.960991, 1.549442, 0.005935},{0.960681, 1.548490, 0.006791},{
      0.959157, 1.548731, 0.006791},{0.959157, 1.549733, 0.005935}}],
    Polygon[{{0.960681, 1.548490, 0.006791},{0.960334, 1.547422, 0.007479},{
      0.959157, 1.547608, 0.007479},{0.959157, 1.548731, 0.006791}}],
    Polygon[{{0.960334, 1.547422, 0.007479},{0.959958, 1.546264, 0.007983},{
      0.959157, 1.546391, 0.007983},{0.959157, 1.547608, 0.007479}}],
    Polygon[{{0.959958, 1.546264, 0.007983},{0.959562, 1.545046, 0.008290},{
      0.959157, 1.545111, 0.008290},{0.959157, 1.546391, 0.007983}}],
    Polygon[{{0.959157, 1.545111, -0.008290},{0.959157, 1.546391, -0.007983},{
      0.958355, 1.546264, -0.007983},{0.958751, 1.545046, -0.008290}}],
    Polygon[{{0.959157, 1.546391, -0.007983},{0.959157, 1.547608, -0.007479},{
      0.957979, 1.547422, -0.007479},{0.958355, 1.546264, -0.007983}}],
    Polygon[{{0.959157, 1.547608, -0.007479},{0.959157, 1.548731, -0.006791},{
      0.957632, 1.548490, -0.006791},{0.957979, 1.547422, -0.007479}}],
    Polygon[{{0.959157, 1.548731, -0.006791},{0.959157, 1.549733, -0.005935},{
      0.957322, 1.549442, -0.005935},{0.957632, 1.548490, -0.006791}}],
    Polygon[{{0.959157, 1.549733, -0.005935},{0.959157, 1.550588, -0.004934},{
      0.957058, 1.550256, -0.004934},{0.957322, 1.549442, -0.005935}}],
    Polygon[{{0.959157, 1.550588, -0.004934},{0.959157, 1.551276, -0.003811},{
      0.956845, 1.550910, -0.003811},{0.957058, 1.550256, -0.004934}}],
    Polygon[{{0.959157, 1.551276, -0.003811},{0.959157, 1.551780, -0.002594},{
      0.956690, 1.551390, -0.002594},{0.956845, 1.550910, -0.003811}}],
    Polygon[{{0.959157, 1.551780, -0.002594},{0.959157, 1.552088, -0.001313},{
      0.956595, 1.551682, -0.001313},{0.956690, 1.551390, -0.002594}}],
    Polygon[{{0.959157, 1.552088, -0.001313},{0.959157, 1.552191, 0.000000},{
      0.956563, 1.551780, 0.000000},{0.956595, 1.551682, -0.001313}}],
    Polygon[{{0.959157, 1.552191, 0.000000},{0.959157, 1.552088, 0.001313},{
      0.956595, 1.551682, 0.001313},{0.956563, 1.551780, 0.000000}}],
    Polygon[{{0.959157, 1.552088, 0.001313},{0.959157, 1.551780, 0.002594},{
      0.956690, 1.551390, 0.002594},{0.956595, 1.551682, 0.001313}}],
    Polygon[{{0.959157, 1.551780, 0.002594},{0.959157, 1.551276, 0.003811},{
      0.956845, 1.550910, 0.003811},{0.956690, 1.551390, 0.002594}}],
    Polygon[{{0.959157, 1.551276, 0.003811},{0.959157, 1.550588, 0.004934},{
      0.957058, 1.550256, 0.004934},{0.956845, 1.550910, 0.003811}}],
    Polygon[{{0.959157, 1.550588, 0.004934},{0.959157, 1.549733, 0.005935},{
      0.957322, 1.549442, 0.005935},{0.957058, 1.550256, 0.004934}}],
    Polygon[{{0.959157, 1.549733, 0.005935},{0.959157, 1.548731, 0.006791},{
      0.957632, 1.548490, 0.006791},{0.957322, 1.549442, 0.005935}}],
    Polygon[{{0.959157, 1.548731, 0.006791},{0.959157, 1.547608, 0.007479},{
      0.957979, 1.547422, 0.007479},{0.957632, 1.548490, 0.006791}}],
    Polygon[{{0.959157, 1.547608, 0.007479},{0.959157, 1.546391, 0.007983},{
      0.958355, 1.546264, 0.007983},{0.957979, 1.547422, 0.007479}}],
    Polygon[{{0.959157, 1.546391, 0.007983},{0.959157, 1.545111, 0.008290},{
      0.958751, 1.545046, 0.008290},{0.958355, 1.546264, 0.007983}}],
    Polygon[{{0.958751, 1.545046, -0.008290},{0.958355, 1.546264, -0.007983},{
      0.957632, 1.545896, -0.007983},{0.958385, 1.544860, -0.008290}}],
    Polygon[{{0.958355, 1.546264, -0.007983},{0.957979, 1.547422, -0.007479},{
      0.956917, 1.546880, -0.007479},{0.957632, 1.545896, -0.007983}}],
    Polygon[{{0.957979, 1.547422, -0.007479},{0.957632, 1.548490, -0.006791},{
      0.956257, 1.547789, -0.006791},{0.956917, 1.546880, -0.007479}}],
    Polygon[{{0.957632, 1.548490, -0.006791},{0.957322, 1.549442, -0.005935},{
      0.955668, 1.548599, -0.005935},{0.956257, 1.547789, -0.006791}}],
    Polygon[{{0.957322, 1.549442, -0.005935},{0.957058, 1.550256, -0.004934},{
      0.955165, 1.549291, -0.004934},{0.955668, 1.548599, -0.005935}}],
    Polygon[{{0.957058, 1.550256, -0.004934},{0.956845, 1.550910, -0.003811},{
      0.954761, 1.549848, -0.003811},{0.955165, 1.549291, -0.004934}}],
    Polygon[{{0.956845, 1.550910, -0.003811},{0.956690, 1.551390, -0.002594},{
      0.954464, 1.550256, -0.002594},{0.954761, 1.549848, -0.003811}}],
    Polygon[{{0.956690, 1.551390, -0.002594},{0.956595, 1.551682, -0.001313},{
      0.954284, 1.550504, -0.001313},{0.954464, 1.550256, -0.002594}}],
    Polygon[{{0.956595, 1.551682, -0.001313},{0.956563, 1.551780, 0.000000},{
      0.954223, 1.550588, 0.000000},{0.954284, 1.550504, -0.001313}}],
    Polygon[{{0.956563, 1.551780, 0.000000},{0.956595, 1.551682, 0.001313},{
      0.954284, 1.550504, 0.001313},{0.954223, 1.550588, 0.000000}}],
    Polygon[{{0.956595, 1.551682, 0.001313},{0.956690, 1.551390, 0.002594},{
      0.954464, 1.550256, 0.002594},{0.954284, 1.550504, 0.001313}}],
    Polygon[{{0.956690, 1.551390, 0.002594},{0.956845, 1.550910, 0.003811},{
      0.954761, 1.549848, 0.003811},{0.954464, 1.550256, 0.002594}}],
    Polygon[{{0.956845, 1.550910, 0.003811},{0.957058, 1.550256, 0.004934},{
      0.955165, 1.549291, 0.004934},{0.954761, 1.549848, 0.003811}}],
    Polygon[{{0.957058, 1.550256, 0.004934},{0.957322, 1.549442, 0.005935},{
      0.955668, 1.548599, 0.005935},{0.955165, 1.549291, 0.004934}}],
    Polygon[{{0.957322, 1.549442, 0.005935},{0.957632, 1.548490, 0.006791},{
      0.956257, 1.547789, 0.006791},{0.955668, 1.548599, 0.005935}}],
    Polygon[{{0.957632, 1.548490, 0.006791},{0.957979, 1.547422, 0.007479},{
      0.956917, 1.546880, 0.007479},{0.956257, 1.547789, 0.006791}}],
    Polygon[{{0.957979, 1.547422, 0.007479},{0.958355, 1.546264, 0.007983},{
      0.957632, 1.545896, 0.007983},{0.956917, 1.546880, 0.007479}}],
    Polygon[{{0.958355, 1.546264, 0.007983},{0.958751, 1.545046, 0.008290},{
      0.958385, 1.544860, 0.008290},{0.957632, 1.545896, 0.007983}}],
    Polygon[{{0.958385, 1.544860, -0.008290},{0.957632, 1.545896, -0.007983},{
      0.957058, 1.545322, -0.007983},{0.958094, 1.544569, -0.008290}}],
    Polygon[{{0.957632, 1.545896, -0.007983},{0.956917, 1.546880, -0.007479},{
      0.956074, 1.546037, -0.007479},{0.957058, 1.545322, -0.007983}}],
    Polygon[{{0.956917, 1.546880, -0.007479},{0.956257, 1.547789, -0.006791},{
      0.955165, 1.546697, -0.006791},{0.956074, 1.546037, -0.007479}}],
    Polygon[{{0.956257, 1.547789, -0.006791},{0.955668, 1.548599, -0.005935},{
      0.954355, 1.547286, -0.005935},{0.955165, 1.546697, -0.006791}}],
    Polygon[{{0.955668, 1.548599, -0.005935},{0.955165, 1.549291, -0.004934},{
      0.953663, 1.547789, -0.004934},{0.954355, 1.547286, -0.005935}}],
    Polygon[{{0.955165, 1.549291, -0.004934},{0.954761, 1.549848, -0.003811},{
      0.953106, 1.548193, -0.003811},{0.953663, 1.547789, -0.004934}}],
    Polygon[{{0.954761, 1.549848, -0.003811},{0.954464, 1.550256, -0.002594},{
      0.952698, 1.548490, -0.002594},{0.953106, 1.548193, -0.003811}}],
    Polygon[{{0.954464, 1.550256, -0.002594},{0.954284, 1.550504, -0.001313},{
      0.952450, 1.548670, -0.001313},{0.952698, 1.548490, -0.002594}}],
    Polygon[{{0.954284, 1.550504, -0.001313},{0.954223, 1.550588, 0.000000},{
      0.952366, 1.548731, 0.000000},{0.952450, 1.548670, -0.001313}}],
    Polygon[{{0.954223, 1.550588, 0.000000},{0.954284, 1.550504, 0.001313},{
      0.952450, 1.548670, 0.001313},{0.952366, 1.548731, 0.000000}}],
    Polygon[{{0.954284, 1.550504, 0.001313},{0.954464, 1.550256, 0.002594},{
      0.952698, 1.548490, 0.002594},{0.952450, 1.548670, 0.001313}}],
    Polygon[{{0.954464, 1.550256, 0.002594},{0.954761, 1.549848, 0.003811},{
      0.953106, 1.548193, 0.003811},{0.952698, 1.548490, 0.002594}}],
    Polygon[{{0.954761, 1.549848, 0.003811},{0.955165, 1.549291, 0.004934},{
      0.953663, 1.547789, 0.004934},{0.953106, 1.548193, 0.003811}}],
    Polygon[{{0.955165, 1.549291, 0.004934},{0.955668, 1.548599, 0.005935},{
      0.954355, 1.547286, 0.005935},{0.953663, 1.547789, 0.004934}}],
    Polygon[{{0.955668, 1.548599, 0.005935},{0.956257, 1.547789, 0.006791},{
      0.955165, 1.546697, 0.006791},{0.954355, 1.547286, 0.005935}}],
    Polygon[{{0.956257, 1.547789, 0.006791},{0.956917, 1.546880, 0.007479},{
      0.956074, 1.546037, 0.007479},{0.955165, 1.546697, 0.006791}}],
    Polygon[{{0.956917, 1.546880, 0.007479},{0.957632, 1.545896, 0.007983},{
      0.957058, 1.545322, 0.007983},{0.956074, 1.546037, 0.007479}}],
    Polygon[{{0.957632, 1.545896, 0.007983},{0.958385, 1.544860, 0.008290},{
      0.958094, 1.544569, 0.008290},{0.957058, 1.545322, 0.007983}}],
    Polygon[{{0.958094, 1.544569, -0.008290},{0.957058, 1.545322, -0.007983},{
      0.956690, 1.544599, -0.007983},{0.957908, 1.544203, -0.008290}}],
    Polygon[{{0.957058, 1.545322, -0.007983},{0.956074, 1.546037, -0.007479},{
      0.955532, 1.544975, -0.007479},{0.956690, 1.544599, -0.007983}}],
    Polygon[{{0.956074, 1.546037, -0.007479},{0.955165, 1.546697, -0.006791},{
      0.954464, 1.545322, -0.006791},{0.955532, 1.544975, -0.007479}}],
    Polygon[{{0.955165, 1.546697, -0.006791},{0.954355, 1.547286, -0.005935},{
      0.953512, 1.545632, -0.005935},{0.954464, 1.545322, -0.006791}}],
    Polygon[{{0.954355, 1.547286, -0.005935},{0.953663, 1.547789, -0.004934},{
      0.952698, 1.545896, -0.004934},{0.953512, 1.545632, -0.005935}}],
    Polygon[{{0.953663, 1.547789, -0.004934},{0.953106, 1.548193, -0.003811},{
      0.952044, 1.546109, -0.003811},{0.952698, 1.545896, -0.004934}}],
    Polygon[{{0.953106, 1.548193, -0.003811},{0.952698, 1.548490, -0.002594},{
      0.951564, 1.546264, -0.002594},{0.952044, 1.546109, -0.003811}}],
    Polygon[{{0.952698, 1.548490, -0.002594},{0.952450, 1.548670, -0.001313},{
      0.951272, 1.546359, -0.001313},{0.951564, 1.546264, -0.002594}}],
    Polygon[{{0.952450, 1.548670, -0.001313},{0.952366, 1.548731, 0.000000},{
      0.951174, 1.546391, 0.000000},{0.951272, 1.546359, -0.001313}}],
    Polygon[{{0.952366, 1.548731, 0.000000},{0.952450, 1.548670, 0.001313},{
      0.951272, 1.546359, 0.001313},{0.951174, 1.546391, 0.000000}}],
    Polygon[{{0.952450, 1.548670, 0.001313},{0.952698, 1.548490, 0.002594},{
      0.951564, 1.546264, 0.002594},{0.951272, 1.546359, 0.001313}}],
    Polygon[{{0.952698, 1.548490, 0.002594},{0.953106, 1.548193, 0.003811},{
      0.952044, 1.546109, 0.003811},{0.951564, 1.546264, 0.002594}}],
    Polygon[{{0.953106, 1.548193, 0.003811},{0.953663, 1.547789, 0.004934},{
      0.952698, 1.545896, 0.004934},{0.952044, 1.546109, 0.003811}}],
    Polygon[{{0.953663, 1.547789, 0.004934},{0.954355, 1.547286, 0.005935},{
      0.953512, 1.545632, 0.005935},{0.952698, 1.545896, 0.004934}}],
    Polygon[{{0.954355, 1.547286, 0.005935},{0.955165, 1.546697, 0.006791},{
      0.954464, 1.545322, 0.006791},{0.953512, 1.545632, 0.005935}}],
    Polygon[{{0.955165, 1.546697, 0.006791},{0.956074, 1.546037, 0.007479},{
      0.955532, 1.544975, 0.007479},{0.954464, 1.545322, 0.006791}}],
    Polygon[{{0.956074, 1.546037, 0.007479},{0.957058, 1.545322, 0.007983},{
      0.956690, 1.544599, 0.007983},{0.955532, 1.544975, 0.007479}}],
    Polygon[{{0.957058, 1.545322, 0.007983},{0.958094, 1.544569, 0.008290},{
      0.957908, 1.544203, 0.008290},{0.956690, 1.544599, 0.007983}}],
    Polygon[{{0.957908, 1.544203, -0.008290},{0.956690, 1.544599, -0.007983},{
      0.956563, 1.543797, -0.007983},{0.957843, 1.543797, -0.008290}}],
    Polygon[{{0.956690, 1.544599, -0.007983},{0.955532, 1.544975, -0.007479},{
      0.955346, 1.543797, -0.007479},{0.956563, 1.543797, -0.007983}}],
    Polygon[{{0.955532, 1.544975, -0.007479},{0.954464, 1.545322, -0.006791},{
      0.954223, 1.543797, -0.006791},{0.955346, 1.543797, -0.007479}}],
    Polygon[{{0.954464, 1.545322, -0.006791},{0.953512, 1.545632, -0.005935},{
      0.953221, 1.543797, -0.005935},{0.954223, 1.543797, -0.006791}}],
    Polygon[{{0.953512, 1.545632, -0.005935},{0.952698, 1.545896, -0.004934},{
      0.952366, 1.543797, -0.004934},{0.953221, 1.543797, -0.005935}}],
    Polygon[{{0.952698, 1.545896, -0.004934},{0.952044, 1.546109, -0.003811},{
      0.951678, 1.543797, -0.003811},{0.952366, 1.543797, -0.004934}}],
    Polygon[{{0.952044, 1.546109, -0.003811},{0.951564, 1.546264, -0.002594},{
      0.951174, 1.543797, -0.002594},{0.951678, 1.543797, -0.003811}}],
    Polygon[{{0.951564, 1.546264, -0.002594},{0.951272, 1.546359, -0.001313},{
      0.950866, 1.543797, -0.001313},{0.951174, 1.543797, -0.002594}}],
    Polygon[{{0.951272, 1.546359, -0.001313},{0.951174, 1.546391, 0.000000},{
      0.950763, 1.543797, 0.000000},{0.950866, 1.543797, -0.001313}}],
    Polygon[{{0.951174, 1.546391, 0.000000},{0.951272, 1.546359, 0.001313},{
      0.950866, 1.543797, 0.001313},{0.950763, 1.543797, 0.000000}}],
    Polygon[{{0.951272, 1.546359, 0.001313},{0.951564, 1.546264, 0.002594},{
      0.951174, 1.543797, 0.002594},{0.950866, 1.543797, 0.001313}}],
    Polygon[{{0.951564, 1.546264, 0.002594},{0.952044, 1.546109, 0.003811},{
      0.951678, 1.543797, 0.003811},{0.951174, 1.543797, 0.002594}}],
    Polygon[{{0.952044, 1.546109, 0.003811},{0.952698, 1.545896, 0.004934},{
      0.952366, 1.543797, 0.004934},{0.951678, 1.543797, 0.003811}}],
    Polygon[{{0.952698, 1.545896, 0.004934},{0.953512, 1.545632, 0.005935},{
      0.953221, 1.543797, 0.005935},{0.952366, 1.543797, 0.004934}}],
    Polygon[{{0.953512, 1.545632, 0.005935},{0.954464, 1.545322, 0.006791},{
      0.954223, 1.543797, 0.006791},{0.953221, 1.543797, 0.005935}}],
    Polygon[{{0.954464, 1.545322, 0.006791},{0.955532, 1.544975, 0.007479},{
      0.955346, 1.543797, 0.007479},{0.954223, 1.543797, 0.006791}}],
    Polygon[{{0.955532, 1.544975, 0.007479},{0.956690, 1.544599, 0.007983},{
      0.956563, 1.543797, 0.007983},{0.955346, 1.543797, 0.007479}}],
    Polygon[{{0.956690, 1.544599, 0.007983},{0.957908, 1.544203, 0.008290},{
      0.957843, 1.543797, 0.008290},{0.956563, 1.543797, 0.007983}}],
    Polygon[{{0.957843, 1.543797, -0.008290},{0.956563, 1.543797, -0.007983},{
      0.956690, 1.542996, -0.007983},{0.957908, 1.543392, -0.008290}}],
    Polygon[{{0.956563, 1.543797, -0.007983},{0.955346, 1.543797, -0.007479},{
      0.955532, 1.542620, -0.007479},{0.956690, 1.542996, -0.007983}}],
    Polygon[{{0.955346, 1.543797, -0.007479},{0.954223, 1.543797, -0.006791},{
      0.954464, 1.542273, -0.006791},{0.955532, 1.542620, -0.007479}}],
    Polygon[{{0.954223, 1.543797, -0.006791},{0.953221, 1.543797, -0.005935},{
      0.953512, 1.541963, -0.005935},{0.954464, 1.542273, -0.006791}}],
    Polygon[{{0.953221, 1.543797, -0.005935},{0.952366, 1.543797, -0.004934},{
      0.952698, 1.541699, -0.004934},{0.953512, 1.541963, -0.005935}}],
    Polygon[{{0.952366, 1.543797, -0.004934},{0.951678, 1.543797, -0.003811},{
      0.952044, 1.541487, -0.003811},{0.952698, 1.541699, -0.004934}}],
    Polygon[{{0.951678, 1.543797, -0.003811},{0.951174, 1.543797, -0.002594},{
      0.951564, 1.541331, -0.002594},{0.952044, 1.541487, -0.003811}}],
    Polygon[{{0.951174, 1.543797, -0.002594},{0.950866, 1.543797, -0.001313},{
      0.951272, 1.541236, -0.001313},{0.951564, 1.541331, -0.002594}}],
    Polygon[{{0.950866, 1.543797, -0.001313},{0.950763, 1.543797, 0.000000},{
      0.951174, 1.541204, 0.000000},{0.951272, 1.541236, -0.001313}}],
    Polygon[{{0.950763, 1.543797, 0.000000},{0.950866, 1.543797, 0.001313},{
      0.951272, 1.541236, 0.001313},{0.951174, 1.541204, 0.000000}}],
    Polygon[{{0.950866, 1.543797, 0.001313},{0.951174, 1.543797, 0.002594},{
      0.951564, 1.541331, 0.002594},{0.951272, 1.541236, 0.001313}}],
    Polygon[{{0.951174, 1.543797, 0.002594},{0.951678, 1.543797, 0.003811},{
      0.952044, 1.541487, 0.003811},{0.951564, 1.541331, 0.002594}}],
    Polygon[{{0.951678, 1.543797, 0.003811},{0.952366, 1.543797, 0.004934},{
      0.952698, 1.541699, 0.004934},{0.952044, 1.541487, 0.003811}}],
    Polygon[{{0.952366, 1.543797, 0.004934},{0.953221, 1.543797, 0.005935},{
      0.953512, 1.541963, 0.005935},{0.952698, 1.541699, 0.004934}}],
    Polygon[{{0.953221, 1.543797, 0.005935},{0.954223, 1.543797, 0.006791},{
      0.954464, 1.542273, 0.006791},{0.953512, 1.541963, 0.005935}}],
    Polygon[{{0.954223, 1.543797, 0.006791},{0.955346, 1.543797, 0.007479},{
      0.955532, 1.542620, 0.007479},{0.954464, 1.542273, 0.006791}}],
    Polygon[{{0.955346, 1.543797, 0.007479},{0.956563, 1.543797, 0.007983},{
      0.956690, 1.542996, 0.007983},{0.955532, 1.542620, 0.007479}}],
    Polygon[{{0.956563, 1.543797, 0.007983},{0.957843, 1.543797, 0.008290},{
      0.957908, 1.543392, 0.008290},{0.956690, 1.542996, 0.007983}}],
    Polygon[{{0.957908, 1.543392, -0.008290},{0.956690, 1.542996, -0.007983},{
      0.957058, 1.542273, -0.007983},{0.958094, 1.543026, -0.008290}}],
    Polygon[{{0.956690, 1.542996, -0.007983},{0.955532, 1.542620, -0.007479},{
      0.956074, 1.541558, -0.007479},{0.957058, 1.542273, -0.007983}}],
    Polygon[{{0.955532, 1.542620, -0.007479},{0.954464, 1.542273, -0.006791},{
      0.955165, 1.540898, -0.006791},{0.956074, 1.541558, -0.007479}}],
    Polygon[{{0.954464, 1.542273, -0.006791},{0.953512, 1.541963, -0.005935},{
      0.954355, 1.540309, -0.005935},{0.955165, 1.540898, -0.006791}}],
    Polygon[{{0.953512, 1.541963, -0.005935},{0.952698, 1.541699, -0.004934},{
      0.953663, 1.539806, -0.004934},{0.954355, 1.540309, -0.005935}}],
    Polygon[{{0.952698, 1.541699, -0.004934},{0.952044, 1.541487, -0.003811},{
      0.953106, 1.539402, -0.003811},{0.953663, 1.539806, -0.004934}}],
    Polygon[{{0.952044, 1.541487, -0.003811},{0.951564, 1.541331, -0.002594},{
      0.952698, 1.539105, -0.002594},{0.953106, 1.539402, -0.003811}}],
    Polygon[{{0.951564, 1.541331, -0.002594},{0.951272, 1.541236, -0.001313},{
      0.952450, 1.538925, -0.001313},{0.952698, 1.539105, -0.002594}}],
    Polygon[{{0.951272, 1.541236, -0.001313},{0.951174, 1.541204, 0.000000},{
      0.952366, 1.538864, 0.000000},{0.952450, 1.538925, -0.001313}}],
    Polygon[{{0.951174, 1.541204, 0.000000},{0.951272, 1.541236, 0.001313},{
      0.952450, 1.538925, 0.001313},{0.952366, 1.538864, 0.000000}}],
    Polygon[{{0.951272, 1.541236, 0.001313},{0.951564, 1.541331, 0.002594},{
      0.952698, 1.539105, 0.002594},{0.952450, 1.538925, 0.001313}}],
    Polygon[{{0.951564, 1.541331, 0.002594},{0.952044, 1.541487, 0.003811},{
      0.953106, 1.539402, 0.003811},{0.952698, 1.539105, 0.002594}}],
    Polygon[{{0.952044, 1.541487, 0.003811},{0.952698, 1.541699, 0.004934},{
      0.953663, 1.539806, 0.004934},{0.953106, 1.539402, 0.003811}}],
    Polygon[{{0.952698, 1.541699, 0.004934},{0.953512, 1.541963, 0.005935},{
      0.954355, 1.540309, 0.005935},{0.953663, 1.539806, 0.004934}}],
    Polygon[{{0.953512, 1.541963, 0.005935},{0.954464, 1.542273, 0.006791},{
      0.955165, 1.540898, 0.006791},{0.954355, 1.540309, 0.005935}}],
    Polygon[{{0.954464, 1.542273, 0.006791},{0.955532, 1.542620, 0.007479},{
      0.956074, 1.541558, 0.007479},{0.955165, 1.540898, 0.006791}}],
    Polygon[{{0.955532, 1.542620, 0.007479},{0.956690, 1.542996, 0.007983},{
      0.957058, 1.542273, 0.007983},{0.956074, 1.541558, 0.007479}}],
    Polygon[{{0.956690, 1.542996, 0.007983},{0.957908, 1.543392, 0.008290},{
      0.958094, 1.543026, 0.008290},{0.957058, 1.542273, 0.007983}}],
    Polygon[{{0.958094, 1.543026, -0.008290},{0.957058, 1.542273, -0.007983},{
      0.957632, 1.541699, -0.007983},{0.958385, 1.542735, -0.008290}}],
    Polygon[{{0.957058, 1.542273, -0.007983},{0.956074, 1.541558, -0.007479},{
      0.956917, 1.540715, -0.007479},{0.957632, 1.541699, -0.007983}}],
    Polygon[{{0.956074, 1.541558, -0.007479},{0.955165, 1.540898, -0.006791},{
      0.956257, 1.539806, -0.006791},{0.956917, 1.540715, -0.007479}}],
    Polygon[{{0.955165, 1.540898, -0.006791},{0.954355, 1.540309, -0.005935},{
      0.955668, 1.538996, -0.005935},{0.956257, 1.539806, -0.006791}}],
    Polygon[{{0.954355, 1.540309, -0.005935},{0.953663, 1.539806, -0.004934},{
      0.955165, 1.538304, -0.004934},{0.955668, 1.538996, -0.005935}}],
    Polygon[{{0.953663, 1.539806, -0.004934},{0.953106, 1.539402, -0.003811},{
      0.954761, 1.537747, -0.003811},{0.955165, 1.538304, -0.004934}}],
    Polygon[{{0.953106, 1.539402, -0.003811},{0.952698, 1.539105, -0.002594},{
      0.954464, 1.537339, -0.002594},{0.954761, 1.537747, -0.003811}}],
    Polygon[{{0.952698, 1.539105, -0.002594},{0.952450, 1.538925, -0.001313},{
      0.954284, 1.537091, -0.001313},{0.954464, 1.537339, -0.002594}}],
    Polygon[{{0.952450, 1.538925, -0.001313},{0.952366, 1.538864, 0.000000},{
      0.954223, 1.537007, 0.000000},{0.954284, 1.537091, -0.001313}}],
    Polygon[{{0.952366, 1.538864, 0.000000},{0.952450, 1.538925, 0.001313},{
      0.954284, 1.537091, 0.001313},{0.954223, 1.537007, 0.000000}}],
    Polygon[{{0.952450, 1.538925, 0.001313},{0.952698, 1.539105, 0.002594},{
      0.954464, 1.537339, 0.002594},{0.954284, 1.537091, 0.001313}}],
    Polygon[{{0.952698, 1.539105, 0.002594},{0.953106, 1.539402, 0.003811},{
      0.954761, 1.537747, 0.003811},{0.954464, 1.537339, 0.002594}}],
    Polygon[{{0.953106, 1.539402, 0.003811},{0.953663, 1.539806, 0.004934},{
      0.955165, 1.538304, 0.004934},{0.954761, 1.537747, 0.003811}}],
    Polygon[{{0.953663, 1.539806, 0.004934},{0.954355, 1.540309, 0.005935},{
      0.955668, 1.538996, 0.005935},{0.955165, 1.538304, 0.004934}}],
    Polygon[{{0.954355, 1.540309, 0.005935},{0.955165, 1.540898, 0.006791},{
      0.956257, 1.539806, 0.006791},{0.955668, 1.538996, 0.005935}}],
    Polygon[{{0.955165, 1.540898, 0.006791},{0.956074, 1.541558, 0.007479},{
      0.956917, 1.540715, 0.007479},{0.956257, 1.539806, 0.006791}}],
    Polygon[{{0.956074, 1.541558, 0.007479},{0.957058, 1.542273, 0.007983},{
      0.957632, 1.541699, 0.007983},{0.956917, 1.540715, 0.007479}}],
    Polygon[{{0.957058, 1.542273, 0.007983},{0.958094, 1.543026, 0.008290},{
      0.958385, 1.542735, 0.008290},{0.957632, 1.541699, 0.007983}}],
    Polygon[{{0.958385, 1.542735, -0.008290},{0.957632, 1.541699, -0.007983},{
      0.958355, 1.541331, -0.007983},{0.958751, 1.542549, -0.008290}}],
    Polygon[{{0.957632, 1.541699, -0.007983},{0.956917, 1.540715, -0.007479},{
      0.957979, 1.540173, -0.007479},{0.958355, 1.541331, -0.007983}}],
    Polygon[{{0.956917, 1.540715, -0.007479},{0.956257, 1.539806, -0.006791},{
      0.957632, 1.539105, -0.006791},{0.957979, 1.540173, -0.007479}}],
    Polygon[{{0.956257, 1.539806, -0.006791},{0.955668, 1.538996, -0.005935},{
      0.957322, 1.538153, -0.005935},{0.957632, 1.539105, -0.006791}}],
    Polygon[{{0.955668, 1.538996, -0.005935},{0.955165, 1.538304, -0.004934},{
      0.957058, 1.537339, -0.004934},{0.957322, 1.538153, -0.005935}}],
    Polygon[{{0.955165, 1.538304, -0.004934},{0.954761, 1.537747, -0.003811},{
      0.956845, 1.536685, -0.003811},{0.957058, 1.537339, -0.004934}}],
    Polygon[{{0.954761, 1.537747, -0.003811},{0.954464, 1.537339, -0.002594},{
      0.956690, 1.536205, -0.002594},{0.956845, 1.536685, -0.003811}}],
    Polygon[{{0.954464, 1.537339, -0.002594},{0.954284, 1.537091, -0.001313},{
      0.956595, 1.535913, -0.001313},{0.956690, 1.536205, -0.002594}}],
    Polygon[{{0.954284, 1.537091, -0.001313},{0.954223, 1.537007, 0.000000},{
      0.956563, 1.535815, 0.000000},{0.956595, 1.535913, -0.001313}}],
    Polygon[{{0.954223, 1.537007, 0.000000},{0.954284, 1.537091, 0.001313},{
      0.956595, 1.535913, 0.001313},{0.956563, 1.535815, 0.000000}}],
    Polygon[{{0.954284, 1.537091, 0.001313},{0.954464, 1.537339, 0.002594},{
      0.956690, 1.536205, 0.002594},{0.956595, 1.535913, 0.001313}}],
    Polygon[{{0.954464, 1.537339, 0.002594},{0.954761, 1.537747, 0.003811},{
      0.956845, 1.536685, 0.003811},{0.956690, 1.536205, 0.002594}}],
    Polygon[{{0.954761, 1.537747, 0.003811},{0.955165, 1.538304, 0.004934},{
      0.957058, 1.537339, 0.004934},{0.956845, 1.536685, 0.003811}}],
    Polygon[{{0.955165, 1.538304, 0.004934},{0.955668, 1.538996, 0.005935},{
      0.957322, 1.538153, 0.005935},{0.957058, 1.537339, 0.004934}}],
    Polygon[{{0.955668, 1.538996, 0.005935},{0.956257, 1.539806, 0.006791},{
      0.957632, 1.539105, 0.006791},{0.957322, 1.538153, 0.005935}}],
    Polygon[{{0.956257, 1.539806, 0.006791},{0.956917, 1.540715, 0.007479},{
      0.957979, 1.540173, 0.007479},{0.957632, 1.539105, 0.006791}}],
    Polygon[{{0.956917, 1.540715, 0.007479},{0.957632, 1.541699, 0.007983},{
      0.958355, 1.541331, 0.007983},{0.957979, 1.540173, 0.007479}}],
    Polygon[{{0.957632, 1.541699, 0.007983},{0.958385, 1.542735, 0.008290},{
      0.958751, 1.542549, 0.008290},{0.958355, 1.541331, 0.007983}}],
    Polygon[{{0.958751, 1.542549, -0.008290},{0.958355, 1.541331, -0.007983},{
      0.959157, 1.541204, -0.007983},{0.959157, 1.542485, -0.008290}}],
    Polygon[{{0.958355, 1.541331, -0.007983},{0.957979, 1.540173, -0.007479},{
      0.959157, 1.539987, -0.007479},{0.959157, 1.541204, -0.007983}}],
    Polygon[{{0.957979, 1.540173, -0.007479},{0.957632, 1.539105, -0.006791},{
      0.959157, 1.538864, -0.006791},{0.959157, 1.539987, -0.007479}}],
    Polygon[{{0.957632, 1.539105, -0.006791},{0.957322, 1.538153, -0.005935},{
      0.959157, 1.537862, -0.005935},{0.959157, 1.538864, -0.006791}}],
    Polygon[{{0.957322, 1.538153, -0.005935},{0.957058, 1.537339, -0.004934},{
      0.959157, 1.537007, -0.004934},{0.959157, 1.537862, -0.005935}}],
    Polygon[{{0.957058, 1.537339, -0.004934},{0.956845, 1.536685, -0.003811},{
      0.959157, 1.536319, -0.003811},{0.959157, 1.537007, -0.004934}}],
    Polygon[{{0.956845, 1.536685, -0.003811},{0.956690, 1.536205, -0.002594},{
      0.959157, 1.535815, -0.002594},{0.959157, 1.536319, -0.003811}}],
    Polygon[{{0.956690, 1.536205, -0.002594},{0.956595, 1.535913, -0.001313},{
      0.959157, 1.535507, -0.001313},{0.959157, 1.535815, -0.002594}}],
    Polygon[{{0.956595, 1.535913, -0.001313},{0.956563, 1.535815, 0.000000},{
      0.959157, 1.535404, 0.000000},{0.959157, 1.535507, -0.001313}}],
    Polygon[{{0.956563, 1.535815, 0.000000},{0.956595, 1.535913, 0.001313},{
      0.959157, 1.535507, 0.001313},{0.959157, 1.535404, 0.000000}}],
    Polygon[{{0.956595, 1.535913, 0.001313},{0.956690, 1.536205, 0.002594},{
      0.959157, 1.535815, 0.002594},{0.959157, 1.535507, 0.001313}}],
    Polygon[{{0.956690, 1.536205, 0.002594},{0.956845, 1.536685, 0.003811},{
      0.959157, 1.536319, 0.003811},{0.959157, 1.535815, 0.002594}}],
    Polygon[{{0.956845, 1.536685, 0.003811},{0.957058, 1.537339, 0.004934},{
      0.959157, 1.537007, 0.004934},{0.959157, 1.536319, 0.003811}}],
    Polygon[{{0.957058, 1.537339, 0.004934},{0.957322, 1.538153, 0.005935},{
      0.959157, 1.537862, 0.005935},{0.959157, 1.537007, 0.004934}}],
    Polygon[{{0.957322, 1.538153, 0.005935},{0.957632, 1.539105, 0.006791},{
      0.959157, 1.538864, 0.006791},{0.959157, 1.537862, 0.005935}}],
    Polygon[{{0.957632, 1.539105, 0.006791},{0.957979, 1.540173, 0.007479},{
      0.959157, 1.539987, 0.007479},{0.959157, 1.538864, 0.006791}}],
    Polygon[{{0.957979, 1.540173, 0.007479},{0.958355, 1.541331, 0.007983},{
      0.959157, 1.541204, 0.007983},{0.959157, 1.539987, 0.007479}}],
    Polygon[{{0.958355, 1.541331, 0.007983},{0.958751, 1.542549, 0.008290},{
      0.959157, 1.542485, 0.008290},{0.959157, 1.541204, 0.007983}}],
    Polygon[{{0.959157, 1.542485, -0.008290},{0.959157, 1.541204, -0.007983},{
      0.959958, 1.541331, -0.007983},{0.959562, 1.542549, -0.008290}}],
    Polygon[{{0.959157, 1.541204, -0.007983},{0.959157, 1.539987, -0.007479},{
      0.960334, 1.540173, -0.007479},{0.959958, 1.541331, -0.007983}}],
    Polygon[{{0.959157, 1.539987, -0.007479},{0.959157, 1.538864, -0.006791},{
      0.960681, 1.539105, -0.006791},{0.960334, 1.540173, -0.007479}}],
    Polygon[{{0.959157, 1.538864, -0.006791},{0.959157, 1.537862, -0.005935},{
      0.960991, 1.538153, -0.005935},{0.960681, 1.539105, -0.006791}}],
    Polygon[{{0.959157, 1.537862, -0.005935},{0.959157, 1.537007, -0.004934},{
      0.961255, 1.537339, -0.004934},{0.960991, 1.538153, -0.005935}}],
    Polygon[{{0.959157, 1.537007, -0.004934},{0.959157, 1.536319, -0.003811},{
      0.961468, 1.536685, -0.003811},{0.961255, 1.537339, -0.004934}}],
    Polygon[{{0.959157, 1.536319, -0.003811},{0.959157, 1.535815, -0.002594},{
      0.961623, 1.536205, -0.002594},{0.961468, 1.536685, -0.003811}}],
    Polygon[{{0.959157, 1.535815, -0.002594},{0.959157, 1.535507, -0.001313},{
      0.961718, 1.535913, -0.001313},{0.961623, 1.536205, -0.002594}}],
    Polygon[{{0.959157, 1.535507, -0.001313},{0.959157, 1.535404, 0.000000},{
      0.961750, 1.535815, 0.000000},{0.961718, 1.535913, -0.001313}}],
    Polygon[{{0.959157, 1.535404, 0.000000},{0.959157, 1.535507, 0.001313},{
      0.961718, 1.535913, 0.001313},{0.961750, 1.535815, 0.000000}}],
    Polygon[{{0.959157, 1.535507, 0.001313},{0.959157, 1.535815, 0.002594},{
      0.961623, 1.536205, 0.002594},{0.961718, 1.535913, 0.001313}}],
    Polygon[{{0.959157, 1.535815, 0.002594},{0.959157, 1.536319, 0.003811},{
      0.961468, 1.536685, 0.003811},{0.961623, 1.536205, 0.002594}}],
    Polygon[{{0.959157, 1.536319, 0.003811},{0.959157, 1.537007, 0.004934},{
      0.961255, 1.537339, 0.004934},{0.961468, 1.536685, 0.003811}}],
    Polygon[{{0.959157, 1.537007, 0.004934},{0.959157, 1.537862, 0.005935},{
      0.960991, 1.538153, 0.005935},{0.961255, 1.537339, 0.004934}}],
    Polygon[{{0.959157, 1.537862, 0.005935},{0.959157, 1.538864, 0.006791},{
      0.960681, 1.539105, 0.006791},{0.960991, 1.538153, 0.005935}}],
    Polygon[{{0.959157, 1.538864, 0.006791},{0.959157, 1.539987, 0.007479},{
      0.960334, 1.540173, 0.007479},{0.960681, 1.539105, 0.006791}}],
    Polygon[{{0.959157, 1.539987, 0.007479},{0.959157, 1.541204, 0.007983},{
      0.959958, 1.541331, 0.007983},{0.960334, 1.540173, 0.007479}}],
    Polygon[{{0.959157, 1.541204, 0.007983},{0.959157, 1.542485, 0.008290},{
      0.959562, 1.542549, 0.008290},{0.959958, 1.541331, 0.007983}}],
    Polygon[{{0.959562, 1.542549, -0.008290},{0.959958, 1.541331, -0.007983},{
      0.960681, 1.541699, -0.007983},{0.959928, 1.542735, -0.008290}}],
    Polygon[{{0.959958, 1.541331, -0.007983},{0.960334, 1.540173, -0.007479},{
      0.961396, 1.540715, -0.007479},{0.960681, 1.541699, -0.007983}}],
    Polygon[{{0.960334, 1.540173, -0.007479},{0.960681, 1.539105, -0.006791},{
      0.962056, 1.539806, -0.006791},{0.961396, 1.540715, -0.007479}}],
    Polygon[{{0.960681, 1.539105, -0.006791},{0.960991, 1.538153, -0.005935},{
      0.962645, 1.538996, -0.005935},{0.962056, 1.539806, -0.006791}}],
    Polygon[{{0.960991, 1.538153, -0.005935},{0.961255, 1.537339, -0.004934},{
      0.963148, 1.538304, -0.004934},{0.962645, 1.538996, -0.005935}}],
    Polygon[{{0.961255, 1.537339, -0.004934},{0.961468, 1.536685, -0.003811},{
      0.963552, 1.537747, -0.003811},{0.963148, 1.538304, -0.004934}}],
    Polygon[{{0.961468, 1.536685, -0.003811},{0.961623, 1.536205, -0.002594},{
      0.963849, 1.537339, -0.002594},{0.963552, 1.537747, -0.003811}}],
    Polygon[{{0.961623, 1.536205, -0.002594},{0.961718, 1.535913, -0.001313},{
      0.964029, 1.537091, -0.001313},{0.963849, 1.537339, -0.002594}}],
    Polygon[{{0.961718, 1.535913, -0.001313},{0.961750, 1.535815, 0.000000},{
      0.964090, 1.537007, 0.000000},{0.964029, 1.537091, -0.001313}}],
    Polygon[{{0.961750, 1.535815, 0.000000},{0.961718, 1.535913, 0.001313},{
      0.964029, 1.537091, 0.001313},{0.964090, 1.537007, 0.000000}}],
    Polygon[{{0.961718, 1.535913, 0.001313},{0.961623, 1.536205, 0.002594},{
      0.963849, 1.537339, 0.002594},{0.964029, 1.537091, 0.001313}}],
    Polygon[{{0.961623, 1.536205, 0.002594},{0.961468, 1.536685, 0.003811},{
      0.963552, 1.537747, 0.003811},{0.963849, 1.537339, 0.002594}}],
    Polygon[{{0.961468, 1.536685, 0.003811},{0.961255, 1.537339, 0.004934},{
      0.963148, 1.538304, 0.004934},{0.963552, 1.537747, 0.003811}}],
    Polygon[{{0.961255, 1.537339, 0.004934},{0.960991, 1.538153, 0.005935},{
      0.962645, 1.538996, 0.005935},{0.963148, 1.538304, 0.004934}}],
    Polygon[{{0.960991, 1.538153, 0.005935},{0.960681, 1.539105, 0.006791},{
      0.962056, 1.539806, 0.006791},{0.962645, 1.538996, 0.005935}}],
    Polygon[{{0.960681, 1.539105, 0.006791},{0.960334, 1.540173, 0.007479},{
      0.961396, 1.540715, 0.007479},{0.962056, 1.539806, 0.006791}}],
    Polygon[{{0.960334, 1.540173, 0.007479},{0.959958, 1.541331, 0.007983},{
      0.960681, 1.541699, 0.007983},{0.961396, 1.540715, 0.007479}}],
    Polygon[{{0.959958, 1.541331, 0.007983},{0.959562, 1.542549, 0.008290},{
      0.959928, 1.542735, 0.008290},{0.960681, 1.541699, 0.007983}}],
    Polygon[{{0.959928, 1.542735, -0.008290},{0.960681, 1.541699, -0.007983},{
      0.961255, 1.542273, -0.007983},{0.960219, 1.543026, -0.008290}}],
    Polygon[{{0.960681, 1.541699, -0.007983},{0.961396, 1.540715, -0.007479},{
      0.962239, 1.541558, -0.007479},{0.961255, 1.542273, -0.007983}}],
    Polygon[{{0.961396, 1.540715, -0.007479},{0.962056, 1.539806, -0.006791},{
      0.963148, 1.540898, -0.006791},{0.962239, 1.541558, -0.007479}}],
    Polygon[{{0.962056, 1.539806, -0.006791},{0.962645, 1.538996, -0.005935},{
      0.963958, 1.540309, -0.005935},{0.963148, 1.540898, -0.006791}}],
    Polygon[{{0.962645, 1.538996, -0.005935},{0.963148, 1.538304, -0.004934},{
      0.964650, 1.539806, -0.004934},{0.963958, 1.540309, -0.005935}}],
    Polygon[{{0.963148, 1.538304, -0.004934},{0.963552, 1.537747, -0.003811},{
      0.965207, 1.539402, -0.003811},{0.964650, 1.539806, -0.004934}}],
    Polygon[{{0.963552, 1.537747, -0.003811},{0.963849, 1.537339, -0.002594},{
      0.965615, 1.539105, -0.002594},{0.965207, 1.539402, -0.003811}}],
    Polygon[{{0.963849, 1.537339, -0.002594},{0.964029, 1.537091, -0.001313},{
      0.965864, 1.538925, -0.001313},{0.965615, 1.539105, -0.002594}}],
    Polygon[{{0.964029, 1.537091, -0.001313},{0.964090, 1.537007, 0.000000},{
      0.965947, 1.538864, 0.000000},{0.965864, 1.538925, -0.001313}}],
    Polygon[{{0.964090, 1.537007, 0.000000},{0.964029, 1.537091, 0.001313},{
      0.965864, 1.538925, 0.001313},{0.965947, 1.538864, 0.000000}}],
    Polygon[{{0.964029, 1.537091, 0.001313},{0.963849, 1.537339, 0.002594},{
      0.965615, 1.539105, 0.002594},{0.965864, 1.538925, 0.001313}}],
    Polygon[{{0.963849, 1.537339, 0.002594},{0.963552, 1.537747, 0.003811},{
      0.965207, 1.539402, 0.003811},{0.965615, 1.539105, 0.002594}}],
    Polygon[{{0.963552, 1.537747, 0.003811},{0.963148, 1.538304, 0.004934},{
      0.964650, 1.539806, 0.004934},{0.965207, 1.539402, 0.003811}}],
    Polygon[{{0.963148, 1.538304, 0.004934},{0.962645, 1.538996, 0.005935},{
      0.963958, 1.540309, 0.005935},{0.964650, 1.539806, 0.004934}}],
    Polygon[{{0.962645, 1.538996, 0.005935},{0.962056, 1.539806, 0.006791},{
      0.963148, 1.540898, 0.006791},{0.963958, 1.540309, 0.005935}}],
    Polygon[{{0.962056, 1.539806, 0.006791},{0.961396, 1.540715, 0.007479},{
      0.962239, 1.541558, 0.007479},{0.963148, 1.540898, 0.006791}}],
    Polygon[{{0.961396, 1.540715, 0.007479},{0.960681, 1.541699, 0.007983},{
      0.961255, 1.542273, 0.007983},{0.962239, 1.541558, 0.007479}}],
    Polygon[{{0.960681, 1.541699, 0.007983},{0.959928, 1.542735, 0.008290},{
      0.960219, 1.543026, 0.008290},{0.961255, 1.542273, 0.007983}}],
    Polygon[{{0.960219, 1.543026, -0.008290},{0.961255, 1.542273, -0.007983},{
      0.961623, 1.542996, -0.007983},{0.960405, 1.543392, -0.008290}}],
    Polygon[{{0.961255, 1.542273, -0.007983},{0.962239, 1.541558, -0.007479},{
      0.962781, 1.542620, -0.007479},{0.961623, 1.542996, -0.007983}}],
    Polygon[{{0.962239, 1.541558, -0.007479},{0.963148, 1.540898, -0.006791},{
      0.963849, 1.542273, -0.006791},{0.962781, 1.542620, -0.007479}}],
    Polygon[{{0.963148, 1.540898, -0.006791},{0.963958, 1.540309, -0.005935},{
      0.964801, 1.541963, -0.005935},{0.963849, 1.542273, -0.006791}}],
    Polygon[{{0.963958, 1.540309, -0.005935},{0.964650, 1.539806, -0.004934},{
      0.965615, 1.541699, -0.004934},{0.964801, 1.541963, -0.005935}}],
    Polygon[{{0.964650, 1.539806, -0.004934},{0.965207, 1.539402, -0.003811},{
      0.966269, 1.541487, -0.003811},{0.965615, 1.541699, -0.004934}}],
    Polygon[{{0.965207, 1.539402, -0.003811},{0.965615, 1.539105, -0.002594},{
      0.966749, 1.541331, -0.002594},{0.966269, 1.541487, -0.003811}}],
    Polygon[{{0.965615, 1.539105, -0.002594},{0.965864, 1.538925, -0.001313},{
      0.967041, 1.541236, -0.001313},{0.966749, 1.541331, -0.002594}}],
    Polygon[{{0.965864, 1.538925, -0.001313},{0.965947, 1.538864, 0.000000},{
      0.967139, 1.541204, 0.000000},{0.967041, 1.541236, -0.001313}}],
    Polygon[{{0.965947, 1.538864, 0.000000},{0.965864, 1.538925, 0.001313},{
      0.967041, 1.541236, 0.001313},{0.967139, 1.541204, 0.000000}}],
    Polygon[{{0.965864, 1.538925, 0.001313},{0.965615, 1.539105, 0.002594},{
      0.966749, 1.541331, 0.002594},{0.967041, 1.541236, 0.001313}}],
    Polygon[{{0.965615, 1.539105, 0.002594},{0.965207, 1.539402, 0.003811},{
      0.966269, 1.541487, 0.003811},{0.966749, 1.541331, 0.002594}}],
    Polygon[{{0.965207, 1.539402, 0.003811},{0.964650, 1.539806, 0.004934},{
      0.965615, 1.541699, 0.004934},{0.966269, 1.541487, 0.003811}}],
    Polygon[{{0.964650, 1.539806, 0.004934},{0.963958, 1.540309, 0.005935},{
      0.964801, 1.541963, 0.005935},{0.965615, 1.541699, 0.004934}}],
    Polygon[{{0.963958, 1.540309, 0.005935},{0.963148, 1.540898, 0.006791},{
      0.963849, 1.542273, 0.006791},{0.964801, 1.541963, 0.005935}}],
    Polygon[{{0.963148, 1.540898, 0.006791},{0.962239, 1.541558, 0.007479},{
      0.962781, 1.542620, 0.007479},{0.963849, 1.542273, 0.006791}}],
    Polygon[{{0.962239, 1.541558, 0.007479},{0.961255, 1.542273, 0.007983},{
      0.961623, 1.542996, 0.007983},{0.962781, 1.542620, 0.007479}}],
    Polygon[{{0.961255, 1.542273, 0.007983},{0.960219, 1.543026, 0.008290},{
      0.960405, 1.543392, 0.008290},{0.961623, 1.542996, 0.007983}}],
    Polygon[{{0.960405, 1.543392, -0.008290},{0.961623, 1.542996, -0.007983},{
      0.961750, 1.543797, -0.007983},{0.960470, 1.543797, -0.008290}}],
    Polygon[{{0.961623, 1.542996, -0.007983},{0.962781, 1.542620, -0.007479},{
      0.962967, 1.543797, -0.007479},{0.961750, 1.543797, -0.007983}}],
    Polygon[{{0.962781, 1.542620, -0.007479},{0.963849, 1.542273, -0.006791},{
      0.964090, 1.543797, -0.006791},{0.962967, 1.543797, -0.007479}}],
    Polygon[{{0.963849, 1.542273, -0.006791},{0.964801, 1.541963, -0.005935},{
      0.965092, 1.543797, -0.005935},{0.964090, 1.543797, -0.006791}}],
    Polygon[{{0.964801, 1.541963, -0.005935},{0.965615, 1.541699, -0.004934},{
      0.965947, 1.543797, -0.004934},{0.965092, 1.543797, -0.005935}}],
    Polygon[{{0.965615, 1.541699, -0.004934},{0.966269, 1.541487, -0.003811},{
      0.966635, 1.543797, -0.003811},{0.965947, 1.543797, -0.004934}}],
    Polygon[{{0.966269, 1.541487, -0.003811},{0.966749, 1.541331, -0.002594},{
      0.967139, 1.543797, -0.002594},{0.966635, 1.543797, -0.003811}}],
    Polygon[{{0.966749, 1.541331, -0.002594},{0.967041, 1.541236, -0.001313},{
      0.967447, 1.543797, -0.001313},{0.967139, 1.543797, -0.002594}}],
    Polygon[{{0.967041, 1.541236, -0.001313},{0.967139, 1.541204, 0.000000},{
      0.967550, 1.543797, 0.000000},{0.967447, 1.543797, -0.001313}}],
    Polygon[{{0.967139, 1.541204, 0.000000},{0.967041, 1.541236, 0.001313},{
      0.967447, 1.543797, 0.001313},{0.967550, 1.543797, 0.000000}}],
    Polygon[{{0.967041, 1.541236, 0.001313},{0.966749, 1.541331, 0.002594},{
      0.967139, 1.543797, 0.002594},{0.967447, 1.543797, 0.001313}}],
    Polygon[{{0.966749, 1.541331, 0.002594},{0.966269, 1.541487, 0.003811},{
      0.966635, 1.543797, 0.003811},{0.967139, 1.543797, 0.002594}}],
    Polygon[{{0.966269, 1.541487, 0.003811},{0.965615, 1.541699, 0.004934},{
      0.965947, 1.543797, 0.004934},{0.966635, 1.543797, 0.003811}}],
    Polygon[{{0.965615, 1.541699, 0.004934},{0.964801, 1.541963, 0.005935},{
      0.965092, 1.543797, 0.005935},{0.965947, 1.543797, 0.004934}}],
    Polygon[{{0.964801, 1.541963, 0.005935},{0.963849, 1.542273, 0.006791},{
      0.964090, 1.543797, 0.006791},{0.965092, 1.543797, 0.005935}}],
    Polygon[{{0.963849, 1.542273, 0.006791},{0.962781, 1.542620, 0.007479},{
      0.962967, 1.543797, 0.007479},{0.964090, 1.543797, 0.006791}}],
    Polygon[{{0.962781, 1.542620, 0.007479},{0.961623, 1.542996, 0.007983},{
      0.961750, 1.543797, 0.007983},{0.962967, 1.543797, 0.007479}}],
    Polygon[{{0.961623, 1.542996, 0.007983},{0.960405, 1.543392, 0.008290},{
      0.960470, 1.543797, 0.008290},{0.961750, 1.543797, 0.007983}}],
    Polygon[{{1.077929, 1.552492, -0.025466},{1.081863, 1.552492, -0.024521},{
      1.081473, 1.554955, -0.024521},{1.077732, 1.553739, -0.025466}}],
    Polygon[{{1.081863, 1.552492, -0.024521},{1.085601, 1.552492, -0.022973},{
      1.085029, 1.556110, -0.022973},{1.081473, 1.554955, -0.024521}}],
    Polygon[{{1.085601, 1.552492, -0.022973},{1.089051, 1.552492, -0.020859},{
      1.088309, 1.557176, -0.020859},{1.085029, 1.556110, -0.022973}}],
    Polygon[{{1.089051, 1.552492, -0.020859},{1.092128, 1.552492, -0.018232},{
      1.091235, 1.558126, -0.018232},{1.088309, 1.557176, -0.020859}}],
    Polygon[{{1.092128, 1.552492, -0.018232},{1.094755, 1.552492, -0.015155},{
      1.093734, 1.558938, -0.015155},{1.091235, 1.558126, -0.018232}}],
    Polygon[{{1.094755, 1.552492, -0.015155},{1.096869, 1.552492, -0.011705},{
      1.095745, 1.559592, -0.011705},{1.093734, 1.558938, -0.015155}}],
    Polygon[{{1.096869, 1.552492, -0.011705},{1.098417, 1.552492, -0.007968},{
      1.097217, 1.560070, -0.007968},{1.095745, 1.559592, -0.011705}}],
    Polygon[{{1.098417, 1.552492, -0.007968},{1.099362, 1.552492, -0.004033},{
      1.098116, 1.560362, -0.004033},{1.097217, 1.560070, -0.007968}}],
    Polygon[{{1.099362, 1.552492, -0.004033},{1.099679, 1.552492, 0.000000},{
      1.098417, 1.560460, 0.000000},{1.098116, 1.560362, -0.004033}}],
    Polygon[{{1.099679, 1.552492, 0.000000},{1.099362, 1.552492, 0.004033},{
      1.098116, 1.560362, 0.004033},{1.098417, 1.560460, 0.000000}}],
    Polygon[{{1.099362, 1.552492, 0.004033},{1.098417, 1.552492, 0.007968},{
      1.097217, 1.560070, 0.007968},{1.098116, 1.560362, 0.004033}}],
    Polygon[{{1.098417, 1.552492, 0.007968},{1.096869, 1.552492, 0.011705},{
      1.095745, 1.559592, 0.011705},{1.097217, 1.560070, 0.007968}}],
    Polygon[{{1.096869, 1.552492, 0.011705},{1.094755, 1.552492, 0.015155},{
      1.093734, 1.558938, 0.015155},{1.095745, 1.559592, 0.011705}}],
    Polygon[{{1.094755, 1.552492, 0.015155},{1.092128, 1.552492, 0.018232},{
      1.091235, 1.558126, 0.018232},{1.093734, 1.558938, 0.015155}}],
    Polygon[{{1.092128, 1.552492, 0.018232},{1.089051, 1.552492, 0.020859},{
      1.088309, 1.557176, 0.020859},{1.091235, 1.558126, 0.018232}}],
    Polygon[{{1.089051, 1.552492, 0.020859},{1.085601, 1.552492, 0.022973},{
      1.085029, 1.556110, 0.022973},{1.088309, 1.557176, 0.020859}}],
    Polygon[{{1.085601, 1.552492, 0.022973},{1.081863, 1.552492, 0.024521},{
      1.081473, 1.554955, 0.024521},{1.085029, 1.556110, 0.022973}}],
    Polygon[{{1.081863, 1.552492, 0.024521},{1.077929, 1.552492, 0.025466},{
      1.077732, 1.553739, 0.025466},{1.081473, 1.554955, 0.024521}}],
    Polygon[{{1.077732, 1.553739, -0.025466},{1.081473, 1.554955, -0.024521},{
      1.080342, 1.557176, -0.024521},{1.077159, 1.554863, -0.025466}}],
    Polygon[{{1.081473, 1.554955, -0.024521},{1.085029, 1.556110, -0.022973},{
      1.083366, 1.559373, -0.022973},{1.080342, 1.557176, -0.024521}}],
    Polygon[{{1.085029, 1.556110, -0.022973},{1.088309, 1.557176, -0.020859},{
      1.086157, 1.561400, -0.020859},{1.083366, 1.559373, -0.022973}}],
    Polygon[{{1.088309, 1.557176, -0.020859},{1.091235, 1.558126, -0.018232},{
      1.088646, 1.563209, -0.018232},{1.086157, 1.561400, -0.020859}}],
    Polygon[{{1.091235, 1.558126, -0.018232},{1.093734, 1.558938, -0.015155},{
      1.090771, 1.564753, -0.015155},{1.088646, 1.563209, -0.018232}}],
    Polygon[{{1.093734, 1.558938, -0.015155},{1.095745, 1.559592, -0.011705},{
      1.092482, 1.565996, -0.011705},{1.090771, 1.564753, -0.015155}}],
    Polygon[{{1.095745, 1.559592, -0.011705},{1.097217, 1.560070, -0.007968},{
      1.093734, 1.566906, -0.007968},{1.092482, 1.565996, -0.011705}}],
    Polygon[{{1.097217, 1.560070, -0.007968},{1.098116, 1.560362, -0.004033},{
      1.094498, 1.567461, -0.004033},{1.093734, 1.566906, -0.007968}}],
    Polygon[{{1.098116, 1.560362, -0.004033},{1.098417, 1.560460, 0.000000},{
      1.094755, 1.567648, 0.000000},{1.094498, 1.567461, -0.004033}}],
    Polygon[{{1.098417, 1.560460, 0.000000},{1.098116, 1.560362, 0.004033},{
      1.094498, 1.567461, 0.004033},{1.094755, 1.567648, 0.000000}}],
    Polygon[{{1.098116, 1.560362, 0.004033},{1.097217, 1.560070, 0.007968},{
      1.093734, 1.566906, 0.007968},{1.094498, 1.567461, 0.004033}}],
    Polygon[{{1.097217, 1.560070, 0.007968},{1.095745, 1.559592, 0.011705},{
      1.092482, 1.565996, 0.011705},{1.093734, 1.566906, 0.007968}}],
    Polygon[{{1.095745, 1.559592, 0.011705},{1.093734, 1.558938, 0.015155},{
      1.090771, 1.564753, 0.015155},{1.092482, 1.565996, 0.011705}}],
    Polygon[{{1.093734, 1.558938, 0.015155},{1.091235, 1.558126, 0.018232},{
      1.088646, 1.563209, 0.018232},{1.090771, 1.564753, 0.015155}}],
    Polygon[{{1.091235, 1.558126, 0.018232},{1.088309, 1.557176, 0.020859},{
      1.086157, 1.561400, 0.020859},{1.088646, 1.563209, 0.018232}}],
    Polygon[{{1.088309, 1.557176, 0.020859},{1.085029, 1.556110, 0.022973},{
      1.083366, 1.559373, 0.022973},{1.086157, 1.561400, 0.020859}}],
    Polygon[{{1.085029, 1.556110, 0.022973},{1.081473, 1.554955, 0.024521},{
      1.080342, 1.557176, 0.024521},{1.083366, 1.559373, 0.022973}}],
    Polygon[{{1.081473, 1.554955, 0.024521},{1.077732, 1.553739, 0.025466},{
      1.077159, 1.554863, 0.025466},{1.080342, 1.557176, 0.024521}}],
    Polygon[{{1.077159, 1.554863, -0.025466},{1.080342, 1.557176, -0.024521},{
      1.078579, 1.558938, -0.024521},{1.076267, 1.555755, -0.025466}}],
    Polygon[{{1.080342, 1.557176, -0.024521},{1.083366, 1.559373, -0.022973},{
      1.080776, 1.561962, -0.022973},{1.078579, 1.558938, -0.024521}}],
    Polygon[{{1.083366, 1.559373, -0.022973},{1.086157, 1.561400, -0.020859},{
      1.082804, 1.564753, -0.020859},{1.080776, 1.561962, -0.022973}}],
    Polygon[{{1.086157, 1.561400, -0.020859},{1.088646, 1.563209, -0.018232},{
      1.084612, 1.567242, -0.018232},{1.082804, 1.564753, -0.020859}}],
    Polygon[{{1.088646, 1.563209, -0.018232},{1.090771, 1.564753, -0.015155},{
      1.086157, 1.569368, -0.015155},{1.084612, 1.567242, -0.018232}}],
    Polygon[{{1.090771, 1.564753, -0.015155},{1.092482, 1.565996, -0.011705},{
      1.087399, 1.571078, -0.011705},{1.086157, 1.569368, -0.015155}}],
    Polygon[{{1.092482, 1.565996, -0.011705},{1.093734, 1.566906, -0.007968},{
      1.088309, 1.572331, -0.007968},{1.087399, 1.571078, -0.011705}}],
    Polygon[{{1.093734, 1.566906, -0.007968},{1.094498, 1.567461, -0.004033},{
      1.088864, 1.573095, -0.004033},{1.088309, 1.572331, -0.007968}}],
    Polygon[{{1.094498, 1.567461, -0.004033},{1.094755, 1.567648, 0.000000},{
      1.089051, 1.573352, 0.000000},{1.088864, 1.573095, -0.004033}}],
    Polygon[{{1.094755, 1.567648, 0.000000},{1.094498, 1.567461, 0.004033},{
      1.088864, 1.573095, 0.004033},{1.089051, 1.573352, 0.000000}}],
    Polygon[{{1.094498, 1.567461, 0.004033},{1.093734, 1.566906, 0.007968},{
      1.088309, 1.572331, 0.007968},{1.088864, 1.573095, 0.004033}}],
    Polygon[{{1.093734, 1.566906, 0.007968},{1.092482, 1.565996, 0.011705},{
      1.087399, 1.571078, 0.011705},{1.088309, 1.572331, 0.007968}}],
    Polygon[{{1.092482, 1.565996, 0.011705},{1.090771, 1.564753, 0.015155},{
      1.086157, 1.569368, 0.015155},{1.087399, 1.571078, 0.011705}}],
    Polygon[{{1.090771, 1.564753, 0.015155},{1.088646, 1.563209, 0.018232},{
      1.084612, 1.567242, 0.018232},{1.086157, 1.569368, 0.015155}}],
    Polygon[{{1.088646, 1.563209, 0.018232},{1.086157, 1.561400, 0.020859},{
      1.082804, 1.564753, 0.020859},{1.084612, 1.567242, 0.018232}}],
    Polygon[{{1.086157, 1.561400, 0.020859},{1.083366, 1.559373, 0.022973},{
      1.080776, 1.561962, 0.022973},{1.082804, 1.564753, 0.020859}}],
    Polygon[{{1.083366, 1.559373, 0.022973},{1.080342, 1.557176, 0.024521},{
      1.078579, 1.558938, 0.024521},{1.080776, 1.561962, 0.022973}}],
    Polygon[{{1.080342, 1.557176, 0.024521},{1.077159, 1.554863, 0.025466},{
      1.076267, 1.555755, 0.025466},{1.078579, 1.558938, 0.024521}}],
    Polygon[{{1.076267, 1.555755, -0.025466},{1.078579, 1.558938, -0.024521},{
      1.076358, 1.560070, -0.024521},{1.075142, 1.556328, -0.025466}}],
    Polygon[{{1.078579, 1.558938, -0.024521},{1.080776, 1.561962, -0.022973},{
      1.077513, 1.563625, -0.022973},{1.076358, 1.560070, -0.024521}}],
    Polygon[{{1.080776, 1.561962, -0.022973},{1.082804, 1.564753, -0.020859},{
      1.078579, 1.566906, -0.020859},{1.077513, 1.563625, -0.022973}}],
    Polygon[{{1.082804, 1.564753, -0.020859},{1.084612, 1.567242, -0.018232},{
      1.079530, 1.569832, -0.018232},{1.078579, 1.566906, -0.020859}}],
    Polygon[{{1.084612, 1.567242, -0.018232},{1.086157, 1.569368, -0.015155},{
      1.080342, 1.572331, -0.015155},{1.079530, 1.569832, -0.018232}}],
    Polygon[{{1.086157, 1.569368, -0.015155},{1.087399, 1.571078, -0.011705},{
      1.080995, 1.574341, -0.011705},{1.080342, 1.572331, -0.015155}}],
    Polygon[{{1.087399, 1.571078, -0.011705},{1.088309, 1.572331, -0.007968},{
      1.081473, 1.575814, -0.007968},{1.080995, 1.574341, -0.011705}}],
    Polygon[{{1.088309, 1.572331, -0.007968},{1.088864, 1.573095, -0.004033},{
      1.081765, 1.576712, -0.004033},{1.081473, 1.575814, -0.007968}}],
    Polygon[{{1.088864, 1.573095, -0.004033},{1.089051, 1.573352, 0.000000},{
      1.081863, 1.577014, 0.000000},{1.081765, 1.576712, -0.004033}}],
    Polygon[{{1.089051, 1.573352, 0.000000},{1.088864, 1.573095, 0.004033},{
      1.081765, 1.576712, 0.004033},{1.081863, 1.577014, 0.000000}}],
    Polygon[{{1.088864, 1.573095, 0.004033},{1.088309, 1.572331, 0.007968},{
      1.081473, 1.575814, 0.007968},{1.081765, 1.576712, 0.004033}}],
    Polygon[{{1.088309, 1.572331, 0.007968},{1.087399, 1.571078, 0.011705},{
      1.080995, 1.574341, 0.011705},{1.081473, 1.575814, 0.007968}}],
    Polygon[{{1.087399, 1.571078, 0.011705},{1.086157, 1.569368, 0.015155},{
      1.080342, 1.572331, 0.015155},{1.080995, 1.574341, 0.011705}}],
    Polygon[{{1.086157, 1.569368, 0.015155},{1.084612, 1.567242, 0.018232},{
      1.079530, 1.569832, 0.018232},{1.080342, 1.572331, 0.015155}}],
    Polygon[{{1.084612, 1.567242, 0.018232},{1.082804, 1.564753, 0.020859},{
      1.078579, 1.566906, 0.020859},{1.079530, 1.569832, 0.018232}}],
    Polygon[{{1.082804, 1.564753, 0.020859},{1.080776, 1.561962, 0.022973},{
      1.077513, 1.563625, 0.022973},{1.078579, 1.566906, 0.020859}}],
    Polygon[{{1.080776, 1.561962, 0.022973},{1.078579, 1.558938, 0.024521},{
      1.076358, 1.560070, 0.024521},{1.077513, 1.563625, 0.022973}}],
    Polygon[{{1.078579, 1.558938, 0.024521},{1.076267, 1.555755, 0.025466},{
      1.075142, 1.556328, 0.025466},{1.076358, 1.560070, 0.024521}}],
    Polygon[{{1.075142, 1.556328, -0.025466},{1.076358, 1.560070, -0.024521},{
      1.073896, 1.560460, -0.024521},{1.073896, 1.556526, -0.025466}}],
    Polygon[{{1.076358, 1.560070, -0.024521},{1.077513, 1.563625, -0.022973},{
      1.073896, 1.564198, -0.022973},{1.073896, 1.560460, -0.024521}}],
    Polygon[{{1.077513, 1.563625, -0.022973},{1.078579, 1.566906, -0.020859},{
      1.073896, 1.567648, -0.020859},{1.073896, 1.564198, -0.022973}}],
    Polygon[{{1.078579, 1.566906, -0.020859},{1.079530, 1.569832, -0.018232},{
      1.073896, 1.570724, -0.018232},{1.073896, 1.567648, -0.020859}}],
    Polygon[{{1.079530, 1.569832, -0.018232},{1.080342, 1.572331, -0.015155},{
      1.073896, 1.573352, -0.015155},{1.073896, 1.570724, -0.018232}}],
    Polygon[{{1.080342, 1.572331, -0.015155},{1.080995, 1.574341, -0.011705},{
      1.073896, 1.575466, -0.011705},{1.073896, 1.573352, -0.015155}}],
    Polygon[{{1.080995, 1.574341, -0.011705},{1.081473, 1.575814, -0.007968},{
      1.073896, 1.577014, -0.007968},{1.073896, 1.575466, -0.011705}}],
    Polygon[{{1.081473, 1.575814, -0.007968},{1.081765, 1.576712, -0.004033},{
      1.073896, 1.577958, -0.004033},{1.073896, 1.577014, -0.007968}}],
    Polygon[{{1.081765, 1.576712, -0.004033},{1.081863, 1.577014, 0.000000},{
      1.073896, 1.578276, 0.000000},{1.073896, 1.577958, -0.004033}}],
    Polygon[{{1.081863, 1.577014, 0.000000},{1.081765, 1.576712, 0.004033},{
      1.073896, 1.577958, 0.004033},{1.073896, 1.578276, 0.000000}}],
    Polygon[{{1.081765, 1.576712, 0.004033},{1.081473, 1.575814, 0.007968},{
      1.073896, 1.577014, 0.007968},{1.073896, 1.577958, 0.004033}}],
    Polygon[{{1.081473, 1.575814, 0.007968},{1.080995, 1.574341, 0.011705},{
      1.073896, 1.575466, 0.011705},{1.073896, 1.577014, 0.007968}}],
    Polygon[{{1.080995, 1.574341, 0.011705},{1.080342, 1.572331, 0.015155},{
      1.073896, 1.573352, 0.015155},{1.073896, 1.575466, 0.011705}}],
    Polygon[{{1.080342, 1.572331, 0.015155},{1.079530, 1.569832, 0.018232},{
      1.073896, 1.570724, 0.018232},{1.073896, 1.573352, 0.015155}}],
    Polygon[{{1.079530, 1.569832, 0.018232},{1.078579, 1.566906, 0.020859},{
      1.073896, 1.567648, 0.020859},{1.073896, 1.570724, 0.018232}}],
    Polygon[{{1.078579, 1.566906, 0.020859},{1.077513, 1.563625, 0.022973},{
      1.073896, 1.564198, 0.022973},{1.073896, 1.567648, 0.020859}}],
    Polygon[{{1.077513, 1.563625, 0.022973},{1.076358, 1.560070, 0.024521},{
      1.073896, 1.560460, 0.024521},{1.073896, 1.564198, 0.022973}}],
    Polygon[{{1.076358, 1.560070, 0.024521},{1.075142, 1.556328, 0.025466},{
      1.073896, 1.556526, 0.025466},{1.073896, 1.560460, 0.024521}}],
    Polygon[{{1.073896, 1.556526, -0.025466},{1.073896, 1.560460, -0.024521},{
      1.071434, 1.560070, -0.024521},{1.072650, 1.556328, -0.025466}}],
    Polygon[{{1.073896, 1.560460, -0.024521},{1.073896, 1.564198, -0.022973},{
      1.070279, 1.563625, -0.022973},{1.071434, 1.560070, -0.024521}}],
    Polygon[{{1.073896, 1.564198, -0.022973},{1.073896, 1.567648, -0.020859},{
      1.069213, 1.566906, -0.020859},{1.070279, 1.563625, -0.022973}}],
    Polygon[{{1.073896, 1.567648, -0.020859},{1.073896, 1.570724, -0.018232},{
      1.068262, 1.569832, -0.018232},{1.069213, 1.566906, -0.020859}}],
    Polygon[{{1.073896, 1.570724, -0.018232},{1.073896, 1.573352, -0.015155},{
      1.067450, 1.572331, -0.015155},{1.068262, 1.569832, -0.018232}}],
    Polygon[{{1.073896, 1.573352, -0.015155},{1.073896, 1.575466, -0.011705},{
      1.066797, 1.574341, -0.011705},{1.067450, 1.572331, -0.015155}}],
    Polygon[{{1.073896, 1.575466, -0.011705},{1.073896, 1.577014, -0.007968},{
      1.066318, 1.575814, -0.007968},{1.066797, 1.574341, -0.011705}}],
    Polygon[{{1.073896, 1.577014, -0.007968},{1.073896, 1.577958, -0.004033},{
      1.066027, 1.576712, -0.004033},{1.066318, 1.575814, -0.007968}}],
    Polygon[{{1.073896, 1.577958, -0.004033},{1.073896, 1.578276, 0.000000},{
      1.065928, 1.577014, 0.000000},{1.066027, 1.576712, -0.004033}}],
    Polygon[{{1.073896, 1.578276, 0.000000},{1.073896, 1.577958, 0.004033},{
      1.066027, 1.576712, 0.004033},{1.065928, 1.577014, 0.000000}}],
    Polygon[{{1.073896, 1.577958, 0.004033},{1.073896, 1.577014, 0.007968},{
      1.066318, 1.575814, 0.007968},{1.066027, 1.576712, 0.004033}}],
    Polygon[{{1.073896, 1.577014, 0.007968},{1.073896, 1.575466, 0.011705},{
      1.066797, 1.574341, 0.011705},{1.066318, 1.575814, 0.007968}}],
    Polygon[{{1.073896, 1.575466, 0.011705},{1.073896, 1.573352, 0.015155},{
      1.067450, 1.572331, 0.015155},{1.066797, 1.574341, 0.011705}}],
    Polygon[{{1.073896, 1.573352, 0.015155},{1.073896, 1.570724, 0.018232},{
      1.068262, 1.569832, 0.018232},{1.067450, 1.572331, 0.015155}}],
    Polygon[{{1.073896, 1.570724, 0.018232},{1.073896, 1.567648, 0.020859},{
      1.069213, 1.566906, 0.020859},{1.068262, 1.569832, 0.018232}}],
    Polygon[{{1.073896, 1.567648, 0.020859},{1.073896, 1.564198, 0.022973},{
      1.070279, 1.563625, 0.022973},{1.069213, 1.566906, 0.020859}}],
    Polygon[{{1.073896, 1.564198, 0.022973},{1.073896, 1.560460, 0.024521},{
      1.071434, 1.560070, 0.024521},{1.070279, 1.563625, 0.022973}}],
    Polygon[{{1.073896, 1.560460, 0.024521},{1.073896, 1.556526, 0.025466},{
      1.072650, 1.556328, 0.025466},{1.071434, 1.560070, 0.024521}}],
    Polygon[{{1.072650, 1.556328, -0.025466},{1.071434, 1.560070, -0.024521},{
      1.069213, 1.558938, -0.024521},{1.071525, 1.555755, -0.025466}}],
    Polygon[{{1.071434, 1.560070, -0.024521},{1.070279, 1.563625, -0.022973},{
      1.067016, 1.561962, -0.022973},{1.069213, 1.558938, -0.024521}}],
    Polygon[{{1.070279, 1.563625, -0.022973},{1.069213, 1.566906, -0.020859},{
      1.064988, 1.564753, -0.020859},{1.067016, 1.561962, -0.022973}}],
    Polygon[{{1.069213, 1.566906, -0.020859},{1.068262, 1.569832, -0.018232},{
      1.063180, 1.567242, -0.018232},{1.064988, 1.564753, -0.020859}}],
    Polygon[{{1.068262, 1.569832, -0.018232},{1.067450, 1.572331, -0.015155},{
      1.061635, 1.569368, -0.015155},{1.063180, 1.567242, -0.018232}}],
    Polygon[{{1.067450, 1.572331, -0.015155},{1.066797, 1.574341, -0.011705},{
      1.060393, 1.571078, -0.011705},{1.061635, 1.569368, -0.015155}}],
    Polygon[{{1.066797, 1.574341, -0.011705},{1.066318, 1.575814, -0.007968},{
      1.059483, 1.572331, -0.007968},{1.060393, 1.571078, -0.011705}}],
    Polygon[{{1.066318, 1.575814, -0.007968},{1.066027, 1.576712, -0.004033},{
      1.058927, 1.573095, -0.004033},{1.059483, 1.572331, -0.007968}}],
    Polygon[{{1.066027, 1.576712, -0.004033},{1.065928, 1.577014, 0.000000},{
      1.058741, 1.573352, 0.000000},{1.058927, 1.573095, -0.004033}}],
    Polygon[{{1.065928, 1.577014, 0.000000},{1.066027, 1.576712, 0.004033},{
      1.058927, 1.573095, 0.004033},{1.058741, 1.573352, 0.000000}}],
    Polygon[{{1.066027, 1.576712, 0.004033},{1.066318, 1.575814, 0.007968},{
      1.059483, 1.572331, 0.007968},{1.058927, 1.573095, 0.004033}}],
    Polygon[{{1.066318, 1.575814, 0.007968},{1.066797, 1.574341, 0.011705},{
      1.060393, 1.571078, 0.011705},{1.059483, 1.572331, 0.007968}}],
    Polygon[{{1.066797, 1.574341, 0.011705},{1.067450, 1.572331, 0.015155},{
      1.061635, 1.569368, 0.015155},{1.060393, 1.571078, 0.011705}}],
    Polygon[{{1.067450, 1.572331, 0.015155},{1.068262, 1.569832, 0.018232},{
      1.063180, 1.567242, 0.018232},{1.061635, 1.569368, 0.015155}}],
    Polygon[{{1.068262, 1.569832, 0.018232},{1.069213, 1.566906, 0.020859},{
      1.064988, 1.564753, 0.020859},{1.063180, 1.567242, 0.018232}}],
    Polygon[{{1.069213, 1.566906, 0.020859},{1.070279, 1.563625, 0.022973},{
      1.067016, 1.561962, 0.022973},{1.064988, 1.564753, 0.020859}}],
    Polygon[{{1.070279, 1.563625, 0.022973},{1.071434, 1.560070, 0.024521},{
      1.069213, 1.558938, 0.024521},{1.067016, 1.561962, 0.022973}}],
    Polygon[{{1.071434, 1.560070, 0.024521},{1.072650, 1.556328, 0.025466},{
      1.071525, 1.555755, 0.025466},{1.069213, 1.558938, 0.024521}}],
    Polygon[{{1.071525, 1.555755, -0.025466},{1.069213, 1.558938, -0.024521},{
      1.067450, 1.557176, -0.024521},{1.070633, 1.554863, -0.025466}}],
    Polygon[{{1.069213, 1.558938, -0.024521},{1.067016, 1.561962, -0.022973},{
      1.064426, 1.559373, -0.022973},{1.067450, 1.557176, -0.024521}}],
    Polygon[{{1.067016, 1.561962, -0.022973},{1.064988, 1.564753, -0.020859},{
      1.061635, 1.561400, -0.020859},{1.064426, 1.559373, -0.022973}}],
    Polygon[{{1.064988, 1.564753, -0.020859},{1.063180, 1.567242, -0.018232},{
      1.059146, 1.563209, -0.018232},{1.061635, 1.561400, -0.020859}}],
    Polygon[{{1.063180, 1.567242, -0.018232},{1.061635, 1.569368, -0.015155},{
      1.057020, 1.564753, -0.015155},{1.059146, 1.563209, -0.018232}}],
    Polygon[{{1.061635, 1.569368, -0.015155},{1.060393, 1.571078, -0.011705},{
      1.055310, 1.565996, -0.011705},{1.057020, 1.564753, -0.015155}}],
    Polygon[{{1.060393, 1.571078, -0.011705},{1.059483, 1.572331, -0.007968},{
      1.054058, 1.566906, -0.007968},{1.055310, 1.565996, -0.011705}}],
    Polygon[{{1.059483, 1.572331, -0.007968},{1.058927, 1.573095, -0.004033},{
      1.053294, 1.567461, -0.004033},{1.054058, 1.566906, -0.007968}}],
    Polygon[{{1.058927, 1.573095, -0.004033},{1.058741, 1.573352, 0.000000},{
      1.053037, 1.567648, 0.000000},{1.053294, 1.567461, -0.004033}}],
    Polygon[{{1.058741, 1.573352, 0.000000},{1.058927, 1.573095, 0.004033},{
      1.053294, 1.567461, 0.004033},{1.053037, 1.567648, 0.000000}}],
    Polygon[{{1.058927, 1.573095, 0.004033},{1.059483, 1.572331, 0.007968},{
      1.054058, 1.566906, 0.007968},{1.053294, 1.567461, 0.004033}}],
    Polygon[{{1.059483, 1.572331, 0.007968},{1.060393, 1.571078, 0.011705},{
      1.055310, 1.565996, 0.011705},{1.054058, 1.566906, 0.007968}}],
    Polygon[{{1.060393, 1.571078, 0.011705},{1.061635, 1.569368, 0.015155},{
      1.057020, 1.564753, 0.015155},{1.055310, 1.565996, 0.011705}}],
    Polygon[{{1.061635, 1.569368, 0.015155},{1.063180, 1.567242, 0.018232},{
      1.059146, 1.563209, 0.018232},{1.057020, 1.564753, 0.015155}}],
    Polygon[{{1.063180, 1.567242, 0.018232},{1.064988, 1.564753, 0.020859},{
      1.061635, 1.561400, 0.020859},{1.059146, 1.563209, 0.018232}}],
    Polygon[{{1.064988, 1.564753, 0.020859},{1.067016, 1.561962, 0.022973},{
      1.064426, 1.559373, 0.022973},{1.061635, 1.561400, 0.020859}}],
    Polygon[{{1.067016, 1.561962, 0.022973},{1.069213, 1.558938, 0.024521},{
      1.067450, 1.557176, 0.024521},{1.064426, 1.559373, 0.022973}}],
    Polygon[{{1.069213, 1.558938, 0.024521},{1.071525, 1.555755, 0.025466},{
      1.070633, 1.554863, 0.025466},{1.067450, 1.557176, 0.024521}}],
    Polygon[{{1.070633, 1.554863, -0.025466},{1.067450, 1.557176, -0.024521},{
      1.066318, 1.554955, -0.024521},{1.070060, 1.553739, -0.025466}}],
    Polygon[{{1.067450, 1.557176, -0.024521},{1.064426, 1.559373, -0.022973},{
      1.062763, 1.556110, -0.022973},{1.066318, 1.554955, -0.024521}}],
    Polygon[{{1.064426, 1.559373, -0.022973},{1.061635, 1.561400, -0.020859},{
      1.059483, 1.557176, -0.020859},{1.062763, 1.556110, -0.022973}}],
    Polygon[{{1.061635, 1.561400, -0.020859},{1.059146, 1.563209, -0.018232},{
      1.056557, 1.558126, -0.018232},{1.059483, 1.557176, -0.020859}}],
    Polygon[{{1.059146, 1.563209, -0.018232},{1.057020, 1.564753, -0.015155},{
      1.054058, 1.558938, -0.015155},{1.056557, 1.558126, -0.018232}}],
    Polygon[{{1.057020, 1.564753, -0.015155},{1.055310, 1.565996, -0.011705},{
      1.052047, 1.559592, -0.011705},{1.054058, 1.558938, -0.015155}}],
    Polygon[{{1.055310, 1.565996, -0.011705},{1.054058, 1.566906, -0.007968},{
      1.050575, 1.560070, -0.007968},{1.052047, 1.559592, -0.011705}}],
    Polygon[{{1.054058, 1.566906, -0.007968},{1.053294, 1.567461, -0.004033},{
      1.049676, 1.560362, -0.004033},{1.050575, 1.560070, -0.007968}}],
    Polygon[{{1.053294, 1.567461, -0.004033},{1.053037, 1.567648, 0.000000},{
      1.049374, 1.560460, 0.000000},{1.049676, 1.560362, -0.004033}}],
    Polygon[{{1.053037, 1.567648, 0.000000},{1.053294, 1.567461, 0.004033},{
      1.049676, 1.560362, 0.004033},{1.049374, 1.560460, 0.000000}}],
    Polygon[{{1.053294, 1.567461, 0.004033},{1.054058, 1.566906, 0.007968},{
      1.050575, 1.560070, 0.007968},{1.049676, 1.560362, 0.004033}}],
    Polygon[{{1.054058, 1.566906, 0.007968},{1.055310, 1.565996, 0.011705},{
      1.052047, 1.559592, 0.011705},{1.050575, 1.560070, 0.007968}}],
    Polygon[{{1.055310, 1.565996, 0.011705},{1.057020, 1.564753, 0.015155},{
      1.054058, 1.558938, 0.015155},{1.052047, 1.559592, 0.011705}}],
    Polygon[{{1.057020, 1.564753, 0.015155},{1.059146, 1.563209, 0.018232},{
      1.056557, 1.558126, 0.018232},{1.054058, 1.558938, 0.015155}}],
    Polygon[{{1.059146, 1.563209, 0.018232},{1.061635, 1.561400, 0.020859},{
      1.059483, 1.557176, 0.020859},{1.056557, 1.558126, 0.018232}}],
    Polygon[{{1.061635, 1.561400, 0.020859},{1.064426, 1.559373, 0.022973},{
      1.062763, 1.556110, 0.022973},{1.059483, 1.557176, 0.020859}}],
    Polygon[{{1.064426, 1.559373, 0.022973},{1.067450, 1.557176, 0.024521},{
      1.066318, 1.554955, 0.024521},{1.062763, 1.556110, 0.022973}}],
    Polygon[{{1.067450, 1.557176, 0.024521},{1.070633, 1.554863, 0.025466},{
      1.070060, 1.553739, 0.025466},{1.066318, 1.554955, 0.024521}}],
    Polygon[{{1.070060, 1.553739, -0.025466},{1.066318, 1.554955, -0.024521},{
      1.065928, 1.552492, -0.024521},{1.069862, 1.552492, -0.025466}}],
    Polygon[{{1.066318, 1.554955, -0.024521},{1.062763, 1.556110, -0.022973},{
      1.062191, 1.552492, -0.022973},{1.065928, 1.552492, -0.024521}}],
    Polygon[{{1.062763, 1.556110, -0.022973},{1.059483, 1.557176, -0.020859},{
      1.058741, 1.552492, -0.020859},{1.062191, 1.552492, -0.022973}}],
    Polygon[{{1.059483, 1.557176, -0.020859},{1.056557, 1.558126, -0.018232},{
      1.055664, 1.552492, -0.018232},{1.058741, 1.552492, -0.020859}}],
    Polygon[{{1.056557, 1.558126, -0.018232},{1.054058, 1.558938, -0.015155},{
      1.053037, 1.552492, -0.015155},{1.055664, 1.552492, -0.018232}}],
    Polygon[{{1.054058, 1.558938, -0.015155},{1.052047, 1.559592, -0.011705},{
      1.050923, 1.552492, -0.011705},{1.053037, 1.552492, -0.015155}}],
    Polygon[{{1.052047, 1.559592, -0.011705},{1.050575, 1.560070, -0.007968},{
      1.049374, 1.552492, -0.007968},{1.050923, 1.552492, -0.011705}}],
    Polygon[{{1.050575, 1.560070, -0.007968},{1.049676, 1.560362, -0.004033},{
      1.048430, 1.552492, -0.004033},{1.049374, 1.552492, -0.007968}}],
    Polygon[{{1.049676, 1.560362, -0.004033},{1.049374, 1.560460, 0.000000},{
      1.048113, 1.552492, 0.000000},{1.048430, 1.552492, -0.004033}}],
    Polygon[{{1.049374, 1.560460, 0.000000},{1.049676, 1.560362, 0.004033},{
      1.048430, 1.552492, 0.004033},{1.048113, 1.552492, 0.000000}}],
    Polygon[{{1.049676, 1.560362, 0.004033},{1.050575, 1.560070, 0.007968},{
      1.049374, 1.552492, 0.007968},{1.048430, 1.552492, 0.004033}}],
    Polygon[{{1.050575, 1.560070, 0.007968},{1.052047, 1.559592, 0.011705},{
      1.050923, 1.552492, 0.011705},{1.049374, 1.552492, 0.007968}}],
    Polygon[{{1.052047, 1.559592, 0.011705},{1.054058, 1.558938, 0.015155},{
      1.053037, 1.552492, 0.015155},{1.050923, 1.552492, 0.011705}}],
    Polygon[{{1.054058, 1.558938, 0.015155},{1.056557, 1.558126, 0.018232},{
      1.055664, 1.552492, 0.018232},{1.053037, 1.552492, 0.015155}}],
    Polygon[{{1.056557, 1.558126, 0.018232},{1.059483, 1.557176, 0.020859},{
      1.058741, 1.552492, 0.020859},{1.055664, 1.552492, 0.018232}}],
    Polygon[{{1.059483, 1.557176, 0.020859},{1.062763, 1.556110, 0.022973},{
      1.062191, 1.552492, 0.022973},{1.058741, 1.552492, 0.020859}}],
    Polygon[{{1.062763, 1.556110, 0.022973},{1.066318, 1.554955, 0.024521},{
      1.065928, 1.552492, 0.024521},{1.062191, 1.552492, 0.022973}}],
    Polygon[{{1.066318, 1.554955, 0.024521},{1.070060, 1.553739, 0.025466},{
      1.069862, 1.552492, 0.025466},{1.065928, 1.552492, 0.024521}}],
    Polygon[{{1.069862, 1.552492, -0.025466},{1.065928, 1.552492, -0.024521},{
      1.066318, 1.550030, -0.024521},{1.070060, 1.551246, -0.025466}}],
    Polygon[{{1.065928, 1.552492, -0.024521},{1.062191, 1.552492, -0.022973},{
      1.062763, 1.548875, -0.022973},{1.066318, 1.550030, -0.024521}}],
    Polygon[{{1.062191, 1.552492, -0.022973},{1.058741, 1.552492, -0.020859},{
      1.059483, 1.547809, -0.020859},{1.062763, 1.548875, -0.022973}}],
    Polygon[{{1.058741, 1.552492, -0.020859},{1.055664, 1.552492, -0.018232},{
      1.056557, 1.546859, -0.018232},{1.059483, 1.547809, -0.020859}}],
    Polygon[{{1.055664, 1.552492, -0.018232},{1.053037, 1.552492, -0.015155},{
      1.054058, 1.546047, -0.015155},{1.056557, 1.546859, -0.018232}}],
    Polygon[{{1.053037, 1.552492, -0.015155},{1.050923, 1.552492, -0.011705},{
      1.052047, 1.545393, -0.011705},{1.054058, 1.546047, -0.015155}}],
    Polygon[{{1.050923, 1.552492, -0.011705},{1.049374, 1.552492, -0.007968},{
      1.050575, 1.544915, -0.007968},{1.052047, 1.545393, -0.011705}}],
    Polygon[{{1.049374, 1.552492, -0.007968},{1.048430, 1.552492, -0.004033},{
      1.049676, 1.544623, -0.004033},{1.050575, 1.544915, -0.007968}}],
    Polygon[{{1.048430, 1.552492, -0.004033},{1.048113, 1.552492, 0.000000},{
      1.049374, 1.544525, 0.000000},{1.049676, 1.544623, -0.004033}}],
    Polygon[{{1.048113, 1.552492, 0.000000},{1.048430, 1.552492, 0.004033},{
      1.049676, 1.544623, 0.004033},{1.049374, 1.544525, 0.000000}}],
    Polygon[{{1.048430, 1.552492, 0.004033},{1.049374, 1.552492, 0.007968},{
      1.050575, 1.544915, 0.007968},{1.049676, 1.544623, 0.004033}}],
    Polygon[{{1.049374, 1.552492, 0.007968},{1.050923, 1.552492, 0.011705},{
      1.052047, 1.545393, 0.011705},{1.050575, 1.544915, 0.007968}}],
    Polygon[{{1.050923, 1.552492, 0.011705},{1.053037, 1.552492, 0.015155},{
      1.054058, 1.546047, 0.015155},{1.052047, 1.545393, 0.011705}}],
    Polygon[{{1.053037, 1.552492, 0.015155},{1.055664, 1.552492, 0.018232},{
      1.056557, 1.546859, 0.018232},{1.054058, 1.546047, 0.015155}}],
    Polygon[{{1.055664, 1.552492, 0.018232},{1.058741, 1.552492, 0.020859},{
      1.059483, 1.547809, 0.020859},{1.056557, 1.546859, 0.018232}}],
    Polygon[{{1.058741, 1.552492, 0.020859},{1.062191, 1.552492, 0.022973},{
      1.062763, 1.548875, 0.022973},{1.059483, 1.547809, 0.020859}}],
    Polygon[{{1.062191, 1.552492, 0.022973},{1.065928, 1.552492, 0.024521},{
      1.066318, 1.550030, 0.024521},{1.062763, 1.548875, 0.022973}}],
    Polygon[{{1.065928, 1.552492, 0.024521},{1.069862, 1.552492, 0.025466},{
      1.070060, 1.551246, 0.025466},{1.066318, 1.550030, 0.024521}}],
    Polygon[{{1.070060, 1.551246, -0.025466},{1.066318, 1.550030, -0.024521},{
      1.067450, 1.547809, -0.024521},{1.070633, 1.550122, -0.025466}}],
    Polygon[{{1.066318, 1.550030, -0.024521},{1.062763, 1.548875, -0.022973},{
      1.064426, 1.545612, -0.022973},{1.067450, 1.547809, -0.024521}}],
    Polygon[{{1.062763, 1.548875, -0.022973},{1.059483, 1.547809, -0.020859},{
      1.061635, 1.543584, -0.020859},{1.064426, 1.545612, -0.022973}}],
    Polygon[{{1.059483, 1.547809, -0.020859},{1.056557, 1.546859, -0.018232},{
      1.059146, 1.541776, -0.018232},{1.061635, 1.543584, -0.020859}}],
    Polygon[{{1.056557, 1.546859, -0.018232},{1.054058, 1.546047, -0.015155},{
      1.057020, 1.540232, -0.015155},{1.059146, 1.541776, -0.018232}}],
    Polygon[{{1.054058, 1.546047, -0.015155},{1.052047, 1.545393, -0.011705},{
      1.055310, 1.538989, -0.011705},{1.057020, 1.540232, -0.015155}}],
    Polygon[{{1.052047, 1.545393, -0.011705},{1.050575, 1.544915, -0.007968},{
      1.054058, 1.538079, -0.007968},{1.055310, 1.538989, -0.011705}}],
    Polygon[{{1.050575, 1.544915, -0.007968},{1.049676, 1.544623, -0.004033},{
      1.053294, 1.537524, -0.004033},{1.054058, 1.538079, -0.007968}}],
    Polygon[{{1.049676, 1.544623, -0.004033},{1.049374, 1.544525, 0.000000},{
      1.053037, 1.537337, 0.000000},{1.053294, 1.537524, -0.004033}}],
    Polygon[{{1.049374, 1.544525, 0.000000},{1.049676, 1.544623, 0.004033},{
      1.053294, 1.537524, 0.004033},{1.053037, 1.537337, 0.000000}}],
    Polygon[{{1.049676, 1.544623, 0.004033},{1.050575, 1.544915, 0.007968},{
      1.054058, 1.538079, 0.007968},{1.053294, 1.537524, 0.004033}}],
    Polygon[{{1.050575, 1.544915, 0.007968},{1.052047, 1.545393, 0.011705},{
      1.055310, 1.538989, 0.011705},{1.054058, 1.538079, 0.007968}}],
    Polygon[{{1.052047, 1.545393, 0.011705},{1.054058, 1.546047, 0.015155},{
      1.057020, 1.540232, 0.015155},{1.055310, 1.538989, 0.011705}}],
    Polygon[{{1.054058, 1.546047, 0.015155},{1.056557, 1.546859, 0.018232},{
      1.059146, 1.541776, 0.018232},{1.057020, 1.540232, 0.015155}}],
    Polygon[{{1.056557, 1.546859, 0.018232},{1.059483, 1.547809, 0.020859},{
      1.061635, 1.543584, 0.020859},{1.059146, 1.541776, 0.018232}}],
    Polygon[{{1.059483, 1.547809, 0.020859},{1.062763, 1.548875, 0.022973},{
      1.064426, 1.545612, 0.022973},{1.061635, 1.543584, 0.020859}}],
    Polygon[{{1.062763, 1.548875, 0.022973},{1.066318, 1.550030, 0.024521},{
      1.067450, 1.547809, 0.024521},{1.064426, 1.545612, 0.022973}}],
    Polygon[{{1.066318, 1.550030, 0.024521},{1.070060, 1.551246, 0.025466},{
      1.070633, 1.550122, 0.025466},{1.067450, 1.547809, 0.024521}}],
    Polygon[{{1.070633, 1.550122, -0.025466},{1.067450, 1.547809, -0.024521},{
      1.069213, 1.546047, -0.024521},{1.071525, 1.549229, -0.025466}}],
    Polygon[{{1.067450, 1.547809, -0.024521},{1.064426, 1.545612, -0.022973},{
      1.067016, 1.543023, -0.022973},{1.069213, 1.546047, -0.024521}}],
    Polygon[{{1.064426, 1.545612, -0.022973},{1.061635, 1.543584, -0.020859},{
      1.064988, 1.540232, -0.020859},{1.067016, 1.543023, -0.022973}}],
    Polygon[{{1.061635, 1.543584, -0.020859},{1.059146, 1.541776, -0.018232},{
      1.063180, 1.537743, -0.018232},{1.064988, 1.540232, -0.020859}}],
    Polygon[{{1.059146, 1.541776, -0.018232},{1.057020, 1.540232, -0.015155},{
      1.061635, 1.535617, -0.015155},{1.063180, 1.537743, -0.018232}}],
    Polygon[{{1.057020, 1.540232, -0.015155},{1.055310, 1.538989, -0.011705},{
      1.060393, 1.533907, -0.011705},{1.061635, 1.535617, -0.015155}}],
    Polygon[{{1.055310, 1.538989, -0.011705},{1.054058, 1.538079, -0.007968},{
      1.059483, 1.532654, -0.007968},{1.060393, 1.533907, -0.011705}}],
    Polygon[{{1.054058, 1.538079, -0.007968},{1.053294, 1.537524, -0.004033},{
      1.058927, 1.531890, -0.004033},{1.059483, 1.532654, -0.007968}}],
    Polygon[{{1.053294, 1.537524, -0.004033},{1.053037, 1.537337, 0.000000},{
      1.058741, 1.531633, 0.000000},{1.058927, 1.531890, -0.004033}}],
    Polygon[{{1.053037, 1.537337, 0.000000},{1.053294, 1.537524, 0.004033},{
      1.058927, 1.531890, 0.004033},{1.058741, 1.531633, 0.000000}}],
    Polygon[{{1.053294, 1.537524, 0.004033},{1.054058, 1.538079, 0.007968},{
      1.059483, 1.532654, 0.007968},{1.058927, 1.531890, 0.004033}}],
    Polygon[{{1.054058, 1.538079, 0.007968},{1.055310, 1.538989, 0.011705},{
      1.060393, 1.533907, 0.011705},{1.059483, 1.532654, 0.007968}}],
    Polygon[{{1.055310, 1.538989, 0.011705},{1.057020, 1.540232, 0.015155},{
      1.061635, 1.535617, 0.015155},{1.060393, 1.533907, 0.011705}}],
    Polygon[{{1.057020, 1.540232, 0.015155},{1.059146, 1.541776, 0.018232},{
      1.063180, 1.537743, 0.018232},{1.061635, 1.535617, 0.015155}}],
    Polygon[{{1.059146, 1.541776, 0.018232},{1.061635, 1.543584, 0.020859},{
      1.064988, 1.540232, 0.020859},{1.063180, 1.537743, 0.018232}}],
    Polygon[{{1.061635, 1.543584, 0.020859},{1.064426, 1.545612, 0.022973},{
      1.067016, 1.543023, 0.022973},{1.064988, 1.540232, 0.020859}}],
    Polygon[{{1.064426, 1.545612, 0.022973},{1.067450, 1.547809, 0.024521},{
      1.069213, 1.546047, 0.024521},{1.067016, 1.543023, 0.022973}}],
    Polygon[{{1.067450, 1.547809, 0.024521},{1.070633, 1.550122, 0.025466},{
      1.071525, 1.549229, 0.025466},{1.069213, 1.546047, 0.024521}}],
    Polygon[{{1.071525, 1.549229, -0.025466},{1.069213, 1.546047, -0.024521},{
      1.071434, 1.544915, -0.024521},{1.072650, 1.548656, -0.025466}}],
    Polygon[{{1.069213, 1.546047, -0.024521},{1.067016, 1.543023, -0.022973},{
      1.070279, 1.541360, -0.022973},{1.071434, 1.544915, -0.024521}}],
    Polygon[{{1.067016, 1.543023, -0.022973},{1.064988, 1.540232, -0.020859},{
      1.069213, 1.538079, -0.020859},{1.070279, 1.541360, -0.022973}}],
    Polygon[{{1.064988, 1.540232, -0.020859},{1.063180, 1.537743, -0.018232},{
      1.068262, 1.535153, -0.018232},{1.069213, 1.538079, -0.020859}}],
    Polygon[{{1.063180, 1.537743, -0.018232},{1.061635, 1.535617, -0.015155},{
      1.067450, 1.532654, -0.015155},{1.068262, 1.535153, -0.018232}}],
    Polygon[{{1.061635, 1.535617, -0.015155},{1.060393, 1.533907, -0.011705},{
      1.066797, 1.530644, -0.011705},{1.067450, 1.532654, -0.015155}}],
    Polygon[{{1.060393, 1.533907, -0.011705},{1.059483, 1.532654, -0.007968},{
      1.066318, 1.529171, -0.007968},{1.066797, 1.530644, -0.011705}}],
    Polygon[{{1.059483, 1.532654, -0.007968},{1.058927, 1.531890, -0.004033},{
      1.066027, 1.528273, -0.004033},{1.066318, 1.529171, -0.007968}}],
    Polygon[{{1.058927, 1.531890, -0.004033},{1.058741, 1.531633, 0.000000},{
      1.065928, 1.527971, 0.000000},{1.066027, 1.528273, -0.004033}}],
    Polygon[{{1.058741, 1.531633, 0.000000},{1.058927, 1.531890, 0.004033},{
      1.066027, 1.528273, 0.004033},{1.065928, 1.527971, 0.000000}}],
    Polygon[{{1.058927, 1.531890, 0.004033},{1.059483, 1.532654, 0.007968},{
      1.066318, 1.529171, 0.007968},{1.066027, 1.528273, 0.004033}}],
    Polygon[{{1.059483, 1.532654, 0.007968},{1.060393, 1.533907, 0.011705},{
      1.066797, 1.530644, 0.011705},{1.066318, 1.529171, 0.007968}}],
    Polygon[{{1.060393, 1.533907, 0.011705},{1.061635, 1.535617, 0.015155},{
      1.067450, 1.532654, 0.015155},{1.066797, 1.530644, 0.011705}}],
    Polygon[{{1.061635, 1.535617, 0.015155},{1.063180, 1.537743, 0.018232},{
      1.068262, 1.535153, 0.018232},{1.067450, 1.532654, 0.015155}}],
    Polygon[{{1.063180, 1.537743, 0.018232},{1.064988, 1.540232, 0.020859},{
      1.069213, 1.538079, 0.020859},{1.068262, 1.535153, 0.018232}}],
    Polygon[{{1.064988, 1.540232, 0.020859},{1.067016, 1.543023, 0.022973},{
      1.070279, 1.541360, 0.022973},{1.069213, 1.538079, 0.020859}}],
    Polygon[{{1.067016, 1.543023, 0.022973},{1.069213, 1.546047, 0.024521},{
      1.071434, 1.544915, 0.024521},{1.070279, 1.541360, 0.022973}}],
    Polygon[{{1.069213, 1.546047, 0.024521},{1.071525, 1.549229, 0.025466},{
      1.072650, 1.548656, 0.025466},{1.071434, 1.544915, 0.024521}}],
    Polygon[{{1.072650, 1.548656, -0.025466},{1.071434, 1.544915, -0.024521},{
      1.073896, 1.544525, -0.024521},{1.073896, 1.548459, -0.025466}}],
    Polygon[{{1.071434, 1.544915, -0.024521},{1.070279, 1.541360, -0.022973},{
      1.073896, 1.540787, -0.022973},{1.073896, 1.544525, -0.024521}}],
    Polygon[{{1.070279, 1.541360, -0.022973},{1.069213, 1.538079, -0.020859},{
      1.073896, 1.537337, -0.020859},{1.073896, 1.540787, -0.022973}}],
    Polygon[{{1.069213, 1.538079, -0.020859},{1.068262, 1.535153, -0.018232},{
      1.073896, 1.534261, -0.018232},{1.073896, 1.537337, -0.020859}}],
    Polygon[{{1.068262, 1.535153, -0.018232},{1.067450, 1.532654, -0.015155},{
      1.073896, 1.531633, -0.015155},{1.073896, 1.534261, -0.018232}}],
    Polygon[{{1.067450, 1.532654, -0.015155},{1.066797, 1.530644, -0.011705},{
      1.073896, 1.529519, -0.011705},{1.073896, 1.531633, -0.015155}}],
    Polygon[{{1.066797, 1.530644, -0.011705},{1.066318, 1.529171, -0.007968},{
      1.073896, 1.527971, -0.007968},{1.073896, 1.529519, -0.011705}}],
    Polygon[{{1.066318, 1.529171, -0.007968},{1.066027, 1.528273, -0.004033},{
      1.073896, 1.527026, -0.004033},{1.073896, 1.527971, -0.007968}}],
    Polygon[{{1.066027, 1.528273, -0.004033},{1.065928, 1.527971, 0.000000},{
      1.073896, 1.526709, 0.000000},{1.073896, 1.527026, -0.004033}}],
    Polygon[{{1.065928, 1.527971, 0.000000},{1.066027, 1.528273, 0.004033},{
      1.073896, 1.527026, 0.004033},{1.073896, 1.526709, 0.000000}}],
    Polygon[{{1.066027, 1.528273, 0.004033},{1.066318, 1.529171, 0.007968},{
      1.073896, 1.527971, 0.007968},{1.073896, 1.527026, 0.004033}}],
    Polygon[{{1.066318, 1.529171, 0.007968},{1.066797, 1.530644, 0.011705},{
      1.073896, 1.529519, 0.011705},{1.073896, 1.527971, 0.007968}}],
    Polygon[{{1.066797, 1.530644, 0.011705},{1.067450, 1.532654, 0.015155},{
      1.073896, 1.531633, 0.015155},{1.073896, 1.529519, 0.011705}}],
    Polygon[{{1.067450, 1.532654, 0.015155},{1.068262, 1.535153, 0.018232},{
      1.073896, 1.534261, 0.018232},{1.073896, 1.531633, 0.015155}}],
    Polygon[{{1.068262, 1.535153, 0.018232},{1.069213, 1.538079, 0.020859},{
      1.073896, 1.537337, 0.020859},{1.073896, 1.534261, 0.018232}}],
    Polygon[{{1.069213, 1.538079, 0.020859},{1.070279, 1.541360, 0.022973},{
      1.073896, 1.540787, 0.022973},{1.073896, 1.537337, 0.020859}}],
    Polygon[{{1.070279, 1.541360, 0.022973},{1.071434, 1.544915, 0.024521},{
      1.073896, 1.544525, 0.024521},{1.073896, 1.540787, 0.022973}}],
    Polygon[{{1.071434, 1.544915, 0.024521},{1.072650, 1.548656, 0.025466},{
      1.073896, 1.548459, 0.025466},{1.073896, 1.544525, 0.024521}}],
    Polygon[{{1.073896, 1.548459, -0.025466},{1.073896, 1.544525, -0.024521},{
      1.076358, 1.544915, -0.024521},{1.075142, 1.548656, -0.025466}}],
    Polygon[{{1.073896, 1.544525, -0.024521},{1.073896, 1.540787, -0.022973},{
      1.077513, 1.541360, -0.022973},{1.076358, 1.544915, -0.024521}}],
    Polygon[{{1.073896, 1.540787, -0.022973},{1.073896, 1.537337, -0.020859},{
      1.078579, 1.538079, -0.020859},{1.077513, 1.541360, -0.022973}}],
    Polygon[{{1.073896, 1.537337, -0.020859},{1.073896, 1.534261, -0.018232},{
      1.079530, 1.535153, -0.018232},{1.078579, 1.538079, -0.020859}}],
    Polygon[{{1.073896, 1.534261, -0.018232},{1.073896, 1.531633, -0.015155},{
      1.080342, 1.532654, -0.015155},{1.079530, 1.535153, -0.018232}}],
    Polygon[{{1.073896, 1.531633, -0.015155},{1.073896, 1.529519, -0.011705},{
      1.080995, 1.530644, -0.011705},{1.080342, 1.532654, -0.015155}}],
    Polygon[{{1.073896, 1.529519, -0.011705},{1.073896, 1.527971, -0.007968},{
      1.081473, 1.529171, -0.007968},{1.080995, 1.530644, -0.011705}}],
    Polygon[{{1.073896, 1.527971, -0.007968},{1.073896, 1.527026, -0.004033},{
      1.081765, 1.528273, -0.004033},{1.081473, 1.529171, -0.007968}}],
    Polygon[{{1.073896, 1.527026, -0.004033},{1.073896, 1.526709, 0.000000},{
      1.081863, 1.527971, 0.000000},{1.081765, 1.528273, -0.004033}}],
    Polygon[{{1.073896, 1.526709, 0.000000},{1.073896, 1.527026, 0.004033},{
      1.081765, 1.528273, 0.004033},{1.081863, 1.527971, 0.000000}}],
    Polygon[{{1.073896, 1.527026, 0.004033},{1.073896, 1.527971, 0.007968},{
      1.081473, 1.529171, 0.007968},{1.081765, 1.528273, 0.004033}}],
    Polygon[{{1.073896, 1.527971, 0.007968},{1.073896, 1.529519, 0.011705},{
      1.080995, 1.530644, 0.011705},{1.081473, 1.529171, 0.007968}}],
    Polygon[{{1.073896, 1.529519, 0.011705},{1.073896, 1.531633, 0.015155},{
      1.080342, 1.532654, 0.015155},{1.080995, 1.530644, 0.011705}}],
    Polygon[{{1.073896, 1.531633, 0.015155},{1.073896, 1.534261, 0.018232},{
      1.079530, 1.535153, 0.018232},{1.080342, 1.532654, 0.015155}}],
    Polygon[{{1.073896, 1.534261, 0.018232},{1.073896, 1.537337, 0.020859},{
      1.078579, 1.538079, 0.020859},{1.079530, 1.535153, 0.018232}}],
    Polygon[{{1.073896, 1.537337, 0.020859},{1.073896, 1.540787, 0.022973},{
      1.077513, 1.541360, 0.022973},{1.078579, 1.538079, 0.020859}}],
    Polygon[{{1.073896, 1.540787, 0.022973},{1.073896, 1.544525, 0.024521},{
      1.076358, 1.544915, 0.024521},{1.077513, 1.541360, 0.022973}}],
    Polygon[{{1.073896, 1.544525, 0.024521},{1.073896, 1.548459, 0.025466},{
      1.075142, 1.548656, 0.025466},{1.076358, 1.544915, 0.024521}}],
    Polygon[{{1.075142, 1.548656, -0.025466},{1.076358, 1.544915, -0.024521},{
      1.078579, 1.546047, -0.024521},{1.076267, 1.549229, -0.025466}}],
    Polygon[{{1.076358, 1.544915, -0.024521},{1.077513, 1.541360, -0.022973},{
      1.080776, 1.543023, -0.022973},{1.078579, 1.546047, -0.024521}}],
    Polygon[{{1.077513, 1.541360, -0.022973},{1.078579, 1.538079, -0.020859},{
      1.082804, 1.540232, -0.020859},{1.080776, 1.543023, -0.022973}}],
    Polygon[{{1.078579, 1.538079, -0.020859},{1.079530, 1.535153, -0.018232},{
      1.084612, 1.537743, -0.018232},{1.082804, 1.540232, -0.020859}}],
    Polygon[{{1.079530, 1.535153, -0.018232},{1.080342, 1.532654, -0.015155},{
      1.086157, 1.535617, -0.015155},{1.084612, 1.537743, -0.018232}}],
    Polygon[{{1.080342, 1.532654, -0.015155},{1.080995, 1.530644, -0.011705},{
      1.087399, 1.533907, -0.011705},{1.086157, 1.535617, -0.015155}}],
    Polygon[{{1.080995, 1.530644, -0.011705},{1.081473, 1.529171, -0.007968},{
      1.088309, 1.532654, -0.007968},{1.087399, 1.533907, -0.011705}}],
    Polygon[{{1.081473, 1.529171, -0.007968},{1.081765, 1.528273, -0.004033},{
      1.088864, 1.531890, -0.004033},{1.088309, 1.532654, -0.007968}}],
    Polygon[{{1.081765, 1.528273, -0.004033},{1.081863, 1.527971, 0.000000},{
      1.089051, 1.531633, 0.000000},{1.088864, 1.531890, -0.004033}}],
    Polygon[{{1.081863, 1.527971, 0.000000},{1.081765, 1.528273, 0.004033},{
      1.088864, 1.531890, 0.004033},{1.089051, 1.531633, 0.000000}}],
    Polygon[{{1.081765, 1.528273, 0.004033},{1.081473, 1.529171, 0.007968},{
      1.088309, 1.532654, 0.007968},{1.088864, 1.531890, 0.004033}}],
    Polygon[{{1.081473, 1.529171, 0.007968},{1.080995, 1.530644, 0.011705},{
      1.087399, 1.533907, 0.011705},{1.088309, 1.532654, 0.007968}}],
    Polygon[{{1.080995, 1.530644, 0.011705},{1.080342, 1.532654, 0.015155},{
      1.086157, 1.535617, 0.015155},{1.087399, 1.533907, 0.011705}}],
    Polygon[{{1.080342, 1.532654, 0.015155},{1.079530, 1.535153, 0.018232},{
      1.084612, 1.537743, 0.018232},{1.086157, 1.535617, 0.015155}}],
    Polygon[{{1.079530, 1.535153, 0.018232},{1.078579, 1.538079, 0.020859},{
      1.082804, 1.540232, 0.020859},{1.084612, 1.537743, 0.018232}}],
    Polygon[{{1.078579, 1.538079, 0.020859},{1.077513, 1.541360, 0.022973},{
      1.080776, 1.543023, 0.022973},{1.082804, 1.540232, 0.020859}}],
    Polygon[{{1.077513, 1.541360, 0.022973},{1.076358, 1.544915, 0.024521},{
      1.078579, 1.546047, 0.024521},{1.080776, 1.543023, 0.022973}}],
    Polygon[{{1.076358, 1.544915, 0.024521},{1.075142, 1.548656, 0.025466},{
      1.076267, 1.549229, 0.025466},{1.078579, 1.546047, 0.024521}}],
    Polygon[{{1.076267, 1.549229, -0.025466},{1.078579, 1.546047, -0.024521},{
      1.080342, 1.547809, -0.024521},{1.077159, 1.550122, -0.025466}}],
    Polygon[{{1.078579, 1.546047, -0.024521},{1.080776, 1.543023, -0.022973},{
      1.083366, 1.545612, -0.022973},{1.080342, 1.547809, -0.024521}}],
    Polygon[{{1.080776, 1.543023, -0.022973},{1.082804, 1.540232, -0.020859},{
      1.086157, 1.543584, -0.020859},{1.083366, 1.545612, -0.022973}}],
    Polygon[{{1.082804, 1.540232, -0.020859},{1.084612, 1.537743, -0.018232},{
      1.088646, 1.541776, -0.018232},{1.086157, 1.543584, -0.020859}}],
    Polygon[{{1.084612, 1.537743, -0.018232},{1.086157, 1.535617, -0.015155},{
      1.090771, 1.540232, -0.015155},{1.088646, 1.541776, -0.018232}}],
    Polygon[{{1.086157, 1.535617, -0.015155},{1.087399, 1.533907, -0.011705},{
      1.092482, 1.538989, -0.011705},{1.090771, 1.540232, -0.015155}}],
    Polygon[{{1.087399, 1.533907, -0.011705},{1.088309, 1.532654, -0.007968},{
      1.093734, 1.538079, -0.007968},{1.092482, 1.538989, -0.011705}}],
    Polygon[{{1.088309, 1.532654, -0.007968},{1.088864, 1.531890, -0.004033},{
      1.094498, 1.537524, -0.004033},{1.093734, 1.538079, -0.007968}}],
    Polygon[{{1.088864, 1.531890, -0.004033},{1.089051, 1.531633, 0.000000},{
      1.094755, 1.537337, 0.000000},{1.094498, 1.537524, -0.004033}}],
    Polygon[{{1.089051, 1.531633, 0.000000},{1.088864, 1.531890, 0.004033},{
      1.094498, 1.537524, 0.004033},{1.094755, 1.537337, 0.000000}}],
    Polygon[{{1.088864, 1.531890, 0.004033},{1.088309, 1.532654, 0.007968},{
      1.093734, 1.538079, 0.007968},{1.094498, 1.537524, 0.004033}}],
    Polygon[{{1.088309, 1.532654, 0.007968},{1.087399, 1.533907, 0.011705},{
      1.092482, 1.538989, 0.011705},{1.093734, 1.538079, 0.007968}}],
    Polygon[{{1.087399, 1.533907, 0.011705},{1.086157, 1.535617, 0.015155},{
      1.090771, 1.540232, 0.015155},{1.092482, 1.538989, 0.011705}}],
    Polygon[{{1.086157, 1.535617, 0.015155},{1.084612, 1.537743, 0.018232},{
      1.088646, 1.541776, 0.018232},{1.090771, 1.540232, 0.015155}}],
    Polygon[{{1.084612, 1.537743, 0.018232},{1.082804, 1.540232, 0.020859},{
      1.086157, 1.543584, 0.020859},{1.088646, 1.541776, 0.018232}}],
    Polygon[{{1.082804, 1.540232, 0.020859},{1.080776, 1.543023, 0.022973},{
      1.083366, 1.545612, 0.022973},{1.086157, 1.543584, 0.020859}}],
    Polygon[{{1.080776, 1.543023, 0.022973},{1.078579, 1.546047, 0.024521},{
      1.080342, 1.547809, 0.024521},{1.083366, 1.545612, 0.022973}}],
    Polygon[{{1.078579, 1.546047, 0.024521},{1.076267, 1.549229, 0.025466},{
      1.077159, 1.550122, 0.025466},{1.080342, 1.547809, 0.024521}}],
    Polygon[{{1.077159, 1.550122, -0.025466},{1.080342, 1.547809, -0.024521},{
      1.081473, 1.550030, -0.024521},{1.077732, 1.551246, -0.025466}}],
    Polygon[{{1.080342, 1.547809, -0.024521},{1.083366, 1.545612, -0.022973},{
      1.085029, 1.548875, -0.022973},{1.081473, 1.550030, -0.024521}}],
    Polygon[{{1.083366, 1.545612, -0.022973},{1.086157, 1.543584, -0.020859},{
      1.088309, 1.547809, -0.020859},{1.085029, 1.548875, -0.022973}}],
    Polygon[{{1.086157, 1.543584, -0.020859},{1.088646, 1.541776, -0.018232},{
      1.091235, 1.546859, -0.018232},{1.088309, 1.547809, -0.020859}}],
    Polygon[{{1.088646, 1.541776, -0.018232},{1.090771, 1.540232, -0.015155},{
      1.093734, 1.546047, -0.015155},{1.091235, 1.546859, -0.018232}}],
    Polygon[{{1.090771, 1.540232, -0.015155},{1.092482, 1.538989, -0.011705},{
      1.095745, 1.545393, -0.011705},{1.093734, 1.546047, -0.015155}}],
    Polygon[{{1.092482, 1.538989, -0.011705},{1.093734, 1.538079, -0.007968},{
      1.097217, 1.544915, -0.007968},{1.095745, 1.545393, -0.011705}}],
    Polygon[{{1.093734, 1.538079, -0.007968},{1.094498, 1.537524, -0.004033},{
      1.098116, 1.544623, -0.004033},{1.097217, 1.544915, -0.007968}}],
    Polygon[{{1.094498, 1.537524, -0.004033},{1.094755, 1.537337, 0.000000},{
      1.098417, 1.544525, 0.000000},{1.098116, 1.544623, -0.004033}}],
    Polygon[{{1.094755, 1.537337, 0.000000},{1.094498, 1.537524, 0.004033},{
      1.098116, 1.544623, 0.004033},{1.098417, 1.544525, 0.000000}}],
    Polygon[{{1.094498, 1.537524, 0.004033},{1.093734, 1.538079, 0.007968},{
      1.097217, 1.544915, 0.007968},{1.098116, 1.544623, 0.004033}}],
    Polygon[{{1.093734, 1.538079, 0.007968},{1.092482, 1.538989, 0.011705},{
      1.095745, 1.545393, 0.011705},{1.097217, 1.544915, 0.007968}}],
    Polygon[{{1.092482, 1.538989, 0.011705},{1.090771, 1.540232, 0.015155},{
      1.093734, 1.546047, 0.015155},{1.095745, 1.545393, 0.011705}}],
    Polygon[{{1.090771, 1.540232, 0.015155},{1.088646, 1.541776, 0.018232},{
      1.091235, 1.546859, 0.018232},{1.093734, 1.546047, 0.015155}}],
    Polygon[{{1.088646, 1.541776, 0.018232},{1.086157, 1.543584, 0.020859},{
      1.088309, 1.547809, 0.020859},{1.091235, 1.546859, 0.018232}}],
    Polygon[{{1.086157, 1.543584, 0.020859},{1.083366, 1.545612, 0.022973},{
      1.085029, 1.548875, 0.022973},{1.088309, 1.547809, 0.020859}}],
    Polygon[{{1.083366, 1.545612, 0.022973},{1.080342, 1.547809, 0.024521},{
      1.081473, 1.550030, 0.024521},{1.085029, 1.548875, 0.022973}}],
    Polygon[{{1.080342, 1.547809, 0.024521},{1.077159, 1.550122, 0.025466},{
      1.077732, 1.551246, 0.025466},{1.081473, 1.550030, 0.024521}}],
    Polygon[{{1.077732, 1.551246, -0.025466},{1.081473, 1.550030, -0.024521},{
      1.081863, 1.552492, -0.024521},{1.077929, 1.552492, -0.025466}}],
    Polygon[{{1.081473, 1.550030, -0.024521},{1.085029, 1.548875, -0.022973},{
      1.085601, 1.552492, -0.022973},{1.081863, 1.552492, -0.024521}}],
    Polygon[{{1.085029, 1.548875, -0.022973},{1.088309, 1.547809, -0.020859},{
      1.089051, 1.552492, -0.020859},{1.085601, 1.552492, -0.022973}}],
    Polygon[{{1.088309, 1.547809, -0.020859},{1.091235, 1.546859, -0.018232},{
      1.092128, 1.552492, -0.018232},{1.089051, 1.552492, -0.020859}}],
    Polygon[{{1.091235, 1.546859, -0.018232},{1.093734, 1.546047, -0.015155},{
      1.094755, 1.552492, -0.015155},{1.092128, 1.552492, -0.018232}}],
    Polygon[{{1.093734, 1.546047, -0.015155},{1.095745, 1.545393, -0.011705},{
      1.096869, 1.552492, -0.011705},{1.094755, 1.552492, -0.015155}}],
    Polygon[{{1.095745, 1.545393, -0.011705},{1.097217, 1.544915, -0.007968},{
      1.098417, 1.552492, -0.007968},{1.096869, 1.552492, -0.011705}}],
    Polygon[{{1.097217, 1.544915, -0.007968},{1.098116, 1.544623, -0.004033},{
      1.099362, 1.552492, -0.004033},{1.098417, 1.552492, -0.007968}}],
    Polygon[{{1.098116, 1.544623, -0.004033},{1.098417, 1.544525, 0.000000},{
      1.099679, 1.552492, 0.000000},{1.099362, 1.552492, -0.004033}}],
    Polygon[{{1.098417, 1.544525, 0.000000},{1.098116, 1.544623, 0.004033},{
      1.099362, 1.552492, 0.004033},{1.099679, 1.552492, 0.000000}}],
    Polygon[{{1.098116, 1.544623, 0.004033},{1.097217, 1.544915, 0.007968},{
      1.098417, 1.552492, 0.007968},{1.099362, 1.552492, 0.004033}}],
    Polygon[{{1.097217, 1.544915, 0.007968},{1.095745, 1.545393, 0.011705},{
      1.096869, 1.552492, 0.011705},{1.098417, 1.552492, 0.007968}}],
    Polygon[{{1.095745, 1.545393, 0.011705},{1.093734, 1.546047, 0.015155},{
      1.094755, 1.552492, 0.015155},{1.096869, 1.552492, 0.011705}}],
    Polygon[{{1.093734, 1.546047, 0.015155},{1.091235, 1.546859, 0.018232},{
      1.092128, 1.552492, 0.018232},{1.094755, 1.552492, 0.015155}}],
    Polygon[{{1.091235, 1.546859, 0.018232},{1.088309, 1.547809, 0.020859},{
      1.089051, 1.552492, 0.020859},{1.092128, 1.552492, 0.018232}}],
    Polygon[{{1.088309, 1.547809, 0.020859},{1.085029, 1.548875, 0.022973},{
      1.085601, 1.552492, 0.022973},{1.089051, 1.552492, 0.020859}}],
    Polygon[{{1.085029, 1.548875, 0.022973},{1.081473, 1.550030, 0.024521},{
      1.081863, 1.552492, 0.024521},{1.085601, 1.552492, 0.022973}}],
    Polygon[{{1.081473, 1.550030, 0.024521},{1.077732, 1.551246, 0.025466},{
      1.077929, 1.552492, 0.025466},{1.081863, 1.552492, 0.024521}}],
    Polygon[{{1.105295, 1.525783, -0.013647},{1.107404, 1.525783, -0.013141},{
      1.107195, 1.527103, -0.013141},{1.105189, 1.526451, -0.013647}}],
    Polygon[{{1.107404, 1.525783, -0.013141},{1.109407, 1.525783, -0.012311},{
      1.109100, 1.527722, -0.012311},{1.107195, 1.527103, -0.013141}}],
    Polygon[{{1.109407, 1.525783, -0.012311},{1.111255, 1.525783, -0.011178},{
      1.110858, 1.528293, -0.011178},{1.109100, 1.527722, -0.012311}}],
    Polygon[{{1.111255, 1.525783, -0.011178},{1.112904, 1.525783, -0.009770},{
      1.112426, 1.528803, -0.009770},{1.110858, 1.528293, -0.011178}}],
    Polygon[{{1.112904, 1.525783, -0.009770},{1.114312, 1.525783, -0.008122},{
      1.113765, 1.529238, -0.008122},{1.112426, 1.528803, -0.009770}}],
    Polygon[{{1.114312, 1.525783, -0.008122},{1.115445, 1.525783, -0.006273},{
      1.114842, 1.529588, -0.006273},{1.113765, 1.529238, -0.008122}}],
    Polygon[{{1.115445, 1.525783, -0.006273},{1.116275, 1.525783, -0.004270},{
      1.115632, 1.529844, -0.004270},{1.114842, 1.529588, -0.006273}}],
    Polygon[{{1.116275, 1.525783, -0.004270},{1.116781, 1.525783, -0.002162},{
      1.116113, 1.530001, -0.002162},{1.115632, 1.529844, -0.004270}}],
    Polygon[{{1.116781, 1.525783, -0.002162},{1.116951, 1.525783, 0.000000},{
      1.116275, 1.530053, 0.000000},{1.116113, 1.530001, -0.002162}}],
    Polygon[{{1.116951, 1.525783, 0.000000},{1.116781, 1.525783, 0.002162},{
      1.116113, 1.530001, 0.002162},{1.116275, 1.530053, 0.000000}}],
    Polygon[{{1.116781, 1.525783, 0.002162},{1.116275, 1.525783, 0.004270},{
      1.115632, 1.529844, 0.004270},{1.116113, 1.530001, 0.002162}}],
    Polygon[{{1.116275, 1.525783, 0.004270},{1.115445, 1.525783, 0.006273},{
      1.114842, 1.529588, 0.006273},{1.115632, 1.529844, 0.004270}}],
    Polygon[{{1.115445, 1.525783, 0.006273},{1.114312, 1.525783, 0.008122},{
      1.113765, 1.529238, 0.008122},{1.114842, 1.529588, 0.006273}}],
    Polygon[{{1.114312, 1.525783, 0.008122},{1.112904, 1.525783, 0.009770},{
      1.112426, 1.528803, 0.009770},{1.113765, 1.529238, 0.008122}}],
    Polygon[{{1.112904, 1.525783, 0.009770},{1.111255, 1.525783, 0.011178},{
      1.110858, 1.528293, 0.011178},{1.112426, 1.528803, 0.009770}}],
    Polygon[{{1.111255, 1.525783, 0.011178},{1.109407, 1.525783, 0.012311},{
      1.109100, 1.527722, 0.012311},{1.110858, 1.528293, 0.011178}}],
    Polygon[{{1.109407, 1.525783, 0.012311},{1.107404, 1.525783, 0.013141},{
      1.107195, 1.527103, 0.013141},{1.109100, 1.527722, 0.012311}}],
    Polygon[{{1.107404, 1.525783, 0.013141},{1.105295, 1.525783, 0.013647},{
      1.105189, 1.526451, 0.013647},{1.107195, 1.527103, 0.013141}}],
    Polygon[{{1.105189, 1.526451, -0.013647},{1.107195, 1.527103, -0.013141},{
      1.106588, 1.528293, -0.013141},{1.104882, 1.527054, -0.013647}}],
    Polygon[{{1.107195, 1.527103, -0.013141},{1.109100, 1.527722, -0.012311},{
      1.108209, 1.529471, -0.012311},{1.106588, 1.528293, -0.013141}}],
    Polygon[{{1.109100, 1.527722, -0.012311},{1.110858, 1.528293, -0.011178},{
      1.109704, 1.530557, -0.011178},{1.108209, 1.529471, -0.012311}}],
    Polygon[{{1.110858, 1.528293, -0.011178},{1.112426, 1.528803, -0.009770},{
      1.111038, 1.531526, -0.009770},{1.109704, 1.530557, -0.011178}}],
    Polygon[{{1.112426, 1.528803, -0.009770},{1.113765, 1.529238, -0.008122},{
      1.112177, 1.532354, -0.008122},{1.111038, 1.531526, -0.009770}}],
    Polygon[{{1.113765, 1.529238, -0.008122},{1.114842, 1.529588, -0.006273},{
      1.113094, 1.533020, -0.006273},{1.112177, 1.532354, -0.008122}}],
    Polygon[{{1.114842, 1.529588, -0.006273},{1.115632, 1.529844, -0.004270},{
      1.113765, 1.533507, -0.004270},{1.113094, 1.533020, -0.006273}}],
    Polygon[{{1.115632, 1.529844, -0.004270},{1.116113, 1.530001, -0.002162},{
      1.114174, 1.533805, -0.002162},{1.113765, 1.533507, -0.004270}}],
    Polygon[{{1.116113, 1.530001, -0.002162},{1.116275, 1.530053, 0.000000},{
      1.114312, 1.533905, 0.000000},{1.114174, 1.533805, -0.002162}}],
    Polygon[{{1.116275, 1.530053, 0.000000},{1.116113, 1.530001, 0.002162},{
      1.114174, 1.533805, 0.002162},{1.114312, 1.533905, 0.000000}}],
    Polygon[{{1.116113, 1.530001, 0.002162},{1.115632, 1.529844, 0.004270},{
      1.113765, 1.533507, 0.004270},{1.114174, 1.533805, 0.002162}}],
    Polygon[{{1.115632, 1.529844, 0.004270},{1.114842, 1.529588, 0.006273},{
      1.113094, 1.533020, 0.006273},{1.113765, 1.533507, 0.004270}}],
    Polygon[{{1.114842, 1.529588, 0.006273},{1.113765, 1.529238, 0.008122},{
      1.112177, 1.532354, 0.008122},{1.113094, 1.533020, 0.006273}}],
    Polygon[{{1.113765, 1.529238, 0.008122},{1.112426, 1.528803, 0.009770},{
      1.111038, 1.531526, 0.009770},{1.112177, 1.532354, 0.008122}}],
    Polygon[{{1.112426, 1.528803, 0.009770},{1.110858, 1.528293, 0.011178},{
      1.109704, 1.530557, 0.011178},{1.111038, 1.531526, 0.009770}}],
    Polygon[{{1.110858, 1.528293, 0.011178},{1.109100, 1.527722, 0.012311},{
      1.108209, 1.529471, 0.012311},{1.109704, 1.530557, 0.011178}}],
    Polygon[{{1.109100, 1.527722, 0.012311},{1.107195, 1.527103, 0.013141},{
      1.106588, 1.528293, 0.013141},{1.108209, 1.529471, 0.012311}}],
    Polygon[{{1.107195, 1.527103, 0.013141},{1.105189, 1.526451, 0.013647},{
      1.104882, 1.527054, 0.013647},{1.106588, 1.528293, 0.013141}}],
    Polygon[{{1.104882, 1.527054, -0.013647},{1.106588, 1.528293, -0.013141},{
      1.105643, 1.529238, -0.013141},{1.104404, 1.527532, -0.013647}}],
    Polygon[{{1.106588, 1.528293, -0.013141},{1.108209, 1.529471, -0.012311},{
      1.106821, 1.530858, -0.012311},{1.105643, 1.529238, -0.013141}}],
    Polygon[{{1.108209, 1.529471, -0.012311},{1.109704, 1.530557, -0.011178},{
      1.107907, 1.532354, -0.011178},{1.106821, 1.530858, -0.012311}}],
    Polygon[{{1.109704, 1.530557, -0.011178},{1.111038, 1.531526, -0.009770},{
      1.108877, 1.533688, -0.009770},{1.107907, 1.532354, -0.011178}}],
    Polygon[{{1.111038, 1.531526, -0.009770},{1.112177, 1.532354, -0.008122},{
      1.109704, 1.534827, -0.008122},{1.108877, 1.533688, -0.009770}}],
    Polygon[{{1.112177, 1.532354, -0.008122},{1.113094, 1.533020, -0.006273},{
      1.110370, 1.535743, -0.006273},{1.109704, 1.534827, -0.008122}}],
    Polygon[{{1.113094, 1.533020, -0.006273},{1.113765, 1.533507, -0.004270},{
      1.110858, 1.536415, -0.004270},{1.110370, 1.535743, -0.006273}}],
    Polygon[{{1.113765, 1.533507, -0.004270},{1.114174, 1.533805, -0.002162},{
      1.111155, 1.536824, -0.002162},{1.110858, 1.536415, -0.004270}}],
    Polygon[{{1.114174, 1.533805, -0.002162},{1.114312, 1.533905, 0.000000},{
      1.111255, 1.536962, 0.000000},{1.111155, 1.536824, -0.002162}}],
    Polygon[{{1.114312, 1.533905, 0.000000},{1.114174, 1.533805, 0.002162},{
      1.111155, 1.536824, 0.002162},{1.111255, 1.536962, 0.000000}}],
    Polygon[{{1.114174, 1.533805, 0.002162},{1.113765, 1.533507, 0.004270},{
      1.110858, 1.536415, 0.004270},{1.111155, 1.536824, 0.002162}}],
    Polygon[{{1.113765, 1.533507, 0.004270},{1.113094, 1.533020, 0.006273},{
      1.110370, 1.535743, 0.006273},{1.110858, 1.536415, 0.004270}}],
    Polygon[{{1.113094, 1.533020, 0.006273},{1.112177, 1.532354, 0.008122},{
      1.109704, 1.534827, 0.008122},{1.110370, 1.535743, 0.006273}}],
    Polygon[{{1.112177, 1.532354, 0.008122},{1.111038, 1.531526, 0.009770},{
      1.108877, 1.533688, 0.009770},{1.109704, 1.534827, 0.008122}}],
    Polygon[{{1.111038, 1.531526, 0.009770},{1.109704, 1.530557, 0.011178},{
      1.107907, 1.532354, 0.011178},{1.108877, 1.533688, 0.009770}}],
    Polygon[{{1.109704, 1.530557, 0.011178},{1.108209, 1.529471, 0.012311},{
      1.106821, 1.530858, 0.012311},{1.107907, 1.532354, 0.011178}}],
    Polygon[{{1.108209, 1.529471, 0.012311},{1.106588, 1.528293, 0.013141},{
      1.105643, 1.529238, 0.013141},{1.106821, 1.530858, 0.012311}}],
    Polygon[{{1.106588, 1.528293, 0.013141},{1.104882, 1.527054, 0.013647},{
      1.104404, 1.527532, 0.013647},{1.105643, 1.529238, 0.013141}}],
    Polygon[{{1.104404, 1.527532, -0.013647},{1.105643, 1.529238, -0.013141},{
      1.104453, 1.529844, -0.013141},{1.103802, 1.527839, -0.013647}}],
    Polygon[{{1.105643, 1.529238, -0.013141},{1.106821, 1.530858, -0.012311},{
      1.105072, 1.531749, -0.012311},{1.104453, 1.529844, -0.013141}}],
    Polygon[{{1.106821, 1.530858, -0.012311},{1.107907, 1.532354, -0.011178},{
      1.105643, 1.533507, -0.011178},{1.105072, 1.531749, -0.012311}}],
    Polygon[{{1.107907, 1.532354, -0.011178},{1.108877, 1.533688, -0.009770},{
      1.106153, 1.535076, -0.009770},{1.105643, 1.533507, -0.011178}}],
    Polygon[{{1.108877, 1.533688, -0.009770},{1.109704, 1.534827, -0.008122},{
      1.106588, 1.536415, -0.008122},{1.106153, 1.535076, -0.009770}}],
    Polygon[{{1.109704, 1.534827, -0.008122},{1.110370, 1.535743, -0.006273},{
      1.106938, 1.537492, -0.006273},{1.106588, 1.536415, -0.008122}}],
    Polygon[{{1.110370, 1.535743, -0.006273},{1.110858, 1.536415, -0.004270},{
      1.107195, 1.538281, -0.004270},{1.106938, 1.537492, -0.006273}}],
    Polygon[{{1.110858, 1.536415, -0.004270},{1.111155, 1.536824, -0.002162},{
      1.107351, 1.538763, -0.002162},{1.107195, 1.538281, -0.004270}}],
    Polygon[{{1.111155, 1.536824, -0.002162},{1.111255, 1.536962, 0.000000},{
      1.107404, 1.538924, 0.000000},{1.107351, 1.538763, -0.002162}}],
    Polygon[{{1.111255, 1.536962, 0.000000},{1.111155, 1.536824, 0.002162},{
      1.107351, 1.538763, 0.002162},{1.107404, 1.538924, 0.000000}}],
    Polygon[{{1.111155, 1.536824, 0.002162},{1.110858, 1.536415, 0.004270},{
      1.107195, 1.538281, 0.004270},{1.107351, 1.538763, 0.002162}}],
    Polygon[{{1.110858, 1.536415, 0.004270},{1.110370, 1.535743, 0.006273},{
      1.106938, 1.537492, 0.006273},{1.107195, 1.538281, 0.004270}}],
    Polygon[{{1.110370, 1.535743, 0.006273},{1.109704, 1.534827, 0.008122},{
      1.106588, 1.536415, 0.008122},{1.106938, 1.537492, 0.006273}}],
    Polygon[{{1.109704, 1.534827, 0.008122},{1.108877, 1.533688, 0.009770},{
      1.106153, 1.535076, 0.009770},{1.106588, 1.536415, 0.008122}}],
    Polygon[{{1.108877, 1.533688, 0.009770},{1.107907, 1.532354, 0.011178},{
      1.105643, 1.533507, 0.011178},{1.106153, 1.535076, 0.009770}}],
    Polygon[{{1.107907, 1.532354, 0.011178},{1.106821, 1.530858, 0.012311},{
      1.105072, 1.531749, 0.012311},{1.105643, 1.533507, 0.011178}}],
    Polygon[{{1.106821, 1.530858, 0.012311},{1.105643, 1.529238, 0.013141},{
      1.104453, 1.529844, 0.013141},{1.105072, 1.531749, 0.012311}}],
    Polygon[{{1.105643, 1.529238, 0.013141},{1.104404, 1.527532, 0.013647},{
      1.103802, 1.527839, 0.013647},{1.104453, 1.529844, 0.013141}}],
    Polygon[{{1.103802, 1.527839, -0.013647},{1.104453, 1.529844, -0.013141},{
      1.103134, 1.530053, -0.013141},{1.103134, 1.527945, -0.013647}}],
    Polygon[{{1.104453, 1.529844, -0.013141},{1.105072, 1.531749, -0.012311},{
      1.103134, 1.532056, -0.012311},{1.103134, 1.530053, -0.013141}}],
    Polygon[{{1.105072, 1.531749, -0.012311},{1.105643, 1.533507, -0.011178},{
      1.103134, 1.533905, -0.011178},{1.103134, 1.532056, -0.012311}}],
    Polygon[{{1.105643, 1.533507, -0.011178},{1.106153, 1.535076, -0.009770},{
      1.103134, 1.535554, -0.009770},{1.103134, 1.533905, -0.011178}}],
    Polygon[{{1.106153, 1.535076, -0.009770},{1.106588, 1.536415, -0.008122},{
      1.103134, 1.536962, -0.008122},{1.103134, 1.535554, -0.009770}}],
    Polygon[{{1.106588, 1.536415, -0.008122},{1.106938, 1.537492, -0.006273},{
      1.103134, 1.538095, -0.006273},{1.103134, 1.536962, -0.008122}}],
    Polygon[{{1.106938, 1.537492, -0.006273},{1.107195, 1.538281, -0.004270},{
      1.103134, 1.538924, -0.004270},{1.103134, 1.538095, -0.006273}}],
    Polygon[{{1.107195, 1.538281, -0.004270},{1.107351, 1.538763, -0.002162},{
      1.103134, 1.539431, -0.002162},{1.103134, 1.538924, -0.004270}}],
    Polygon[{{1.107351, 1.538763, -0.002162},{1.107404, 1.538924, 0.000000},{
      1.103134, 1.539601, 0.000000},{1.103134, 1.539431, -0.002162}}],
    Polygon[{{1.107404, 1.538924, 0.000000},{1.107351, 1.538763, 0.002162},{
      1.103134, 1.539431, 0.002162},{1.103134, 1.539601, 0.000000}}],
    Polygon[{{1.107351, 1.538763, 0.002162},{1.107195, 1.538281, 0.004270},{
      1.103134, 1.538924, 0.004270},{1.103134, 1.539431, 0.002162}}],
    Polygon[{{1.107195, 1.538281, 0.004270},{1.106938, 1.537492, 0.006273},{
      1.103134, 1.538095, 0.006273},{1.103134, 1.538924, 0.004270}}],
    Polygon[{{1.106938, 1.537492, 0.006273},{1.106588, 1.536415, 0.008122},{
      1.103134, 1.536962, 0.008122},{1.103134, 1.538095, 0.006273}}],
    Polygon[{{1.106588, 1.536415, 0.008122},{1.106153, 1.535076, 0.009770},{
      1.103134, 1.535554, 0.009770},{1.103134, 1.536962, 0.008122}}],
    Polygon[{{1.106153, 1.535076, 0.009770},{1.105643, 1.533507, 0.011178},{
      1.103134, 1.533905, 0.011178},{1.103134, 1.535554, 0.009770}}],
    Polygon[{{1.105643, 1.533507, 0.011178},{1.105072, 1.531749, 0.012311},{
      1.103134, 1.532056, 0.012311},{1.103134, 1.533905, 0.011178}}],
    Polygon[{{1.105072, 1.531749, 0.012311},{1.104453, 1.529844, 0.013141},{
      1.103134, 1.530053, 0.013141},{1.103134, 1.532056, 0.012311}}],
    Polygon[{{1.104453, 1.529844, 0.013141},{1.103802, 1.527839, 0.013647},{
      1.103134, 1.527945, 0.013647},{1.103134, 1.530053, 0.013141}}],
    Polygon[{{1.103134, 1.527945, -0.013647},{1.103134, 1.530053, -0.013141},{
      1.101814, 1.529844, -0.013141},{1.102466, 1.527839, -0.013647}}],
    Polygon[{{1.103134, 1.530053, -0.013141},{1.103134, 1.532056, -0.012311},{
      1.101195, 1.531749, -0.012311},{1.101814, 1.529844, -0.013141}}],
    Polygon[{{1.103134, 1.532056, -0.012311},{1.103134, 1.533905, -0.011178},{
      1.100624, 1.533507, -0.011178},{1.101195, 1.531749, -0.012311}}],
    Polygon[{{1.103134, 1.533905, -0.011178},{1.103134, 1.535554, -0.009770},{
      1.100114, 1.535076, -0.009770},{1.100624, 1.533507, -0.011178}}],
    Polygon[{{1.103134, 1.535554, -0.009770},{1.103134, 1.536962, -0.008122},{
      1.099679, 1.536415, -0.008122},{1.100114, 1.535076, -0.009770}}],
    Polygon[{{1.103134, 1.536962, -0.008122},{1.103134, 1.538095, -0.006273},{
      1.099329, 1.537492, -0.006273},{1.099679, 1.536415, -0.008122}}],
    Polygon[{{1.103134, 1.538095, -0.006273},{1.103134, 1.538924, -0.004270},{
      1.099073, 1.538281, -0.004270},{1.099329, 1.537492, -0.006273}}],
    Polygon[{{1.103134, 1.538924, -0.004270},{1.103134, 1.539431, -0.002162},{
      1.098917, 1.538763, -0.002162},{1.099073, 1.538281, -0.004270}}],
    Polygon[{{1.103134, 1.539431, -0.002162},{1.103134, 1.539601, 0.000000},{
      1.098864, 1.538924, 0.000000},{1.098917, 1.538763, -0.002162}}],
    Polygon[{{1.103134, 1.539601, 0.000000},{1.103134, 1.539431, 0.002162},{
      1.098917, 1.538763, 0.002162},{1.098864, 1.538924, 0.000000}}],
    Polygon[{{1.103134, 1.539431, 0.002162},{1.103134, 1.538924, 0.004270},{
      1.099073, 1.538281, 0.004270},{1.098917, 1.538763, 0.002162}}],
    Polygon[{{1.103134, 1.538924, 0.004270},{1.103134, 1.538095, 0.006273},{
      1.099329, 1.537492, 0.006273},{1.099073, 1.538281, 0.004270}}],
    Polygon[{{1.103134, 1.538095, 0.006273},{1.103134, 1.536962, 0.008122},{
      1.099679, 1.536415, 0.008122},{1.099329, 1.537492, 0.006273}}],
    Polygon[{{1.103134, 1.536962, 0.008122},{1.103134, 1.535554, 0.009770},{
      1.100114, 1.535076, 0.009770},{1.099679, 1.536415, 0.008122}}],
    Polygon[{{1.103134, 1.535554, 0.009770},{1.103134, 1.533905, 0.011178},{
      1.100624, 1.533507, 0.011178},{1.100114, 1.535076, 0.009770}}],
    Polygon[{{1.103134, 1.533905, 0.011178},{1.103134, 1.532056, 0.012311},{
      1.101195, 1.531749, 0.012311},{1.100624, 1.533507, 0.011178}}],
    Polygon[{{1.103134, 1.532056, 0.012311},{1.103134, 1.530053, 0.013141},{
      1.101814, 1.529844, 0.013141},{1.101195, 1.531749, 0.012311}}],
    Polygon[{{1.103134, 1.530053, 0.013141},{1.103134, 1.527945, 0.013647},{
      1.102466, 1.527839, 0.013647},{1.101814, 1.529844, 0.013141}}],
    Polygon[{{1.102466, 1.527839, -0.013647},{1.101814, 1.529844, -0.013141},{
      1.100624, 1.529238, -0.013141},{1.101863, 1.527532, -0.013647}}],
    Polygon[{{1.101814, 1.529844, -0.013141},{1.101195, 1.531749, -0.012311},{
      1.099447, 1.530858, -0.012311},{1.100624, 1.529238, -0.013141}}],
    Polygon[{{1.101195, 1.531749, -0.012311},{1.100624, 1.533507, -0.011178},{
      1.098360, 1.532354, -0.011178},{1.099447, 1.530858, -0.012311}}],
    Polygon[{{1.100624, 1.533507, -0.011178},{1.100114, 1.535076, -0.009770},{
      1.097391, 1.533688, -0.009770},{1.098360, 1.532354, -0.011178}}],
    Polygon[{{1.100114, 1.535076, -0.009770},{1.099679, 1.536415, -0.008122},{
      1.096563, 1.534827, -0.008122},{1.097391, 1.533688, -0.009770}}],
    Polygon[{{1.099679, 1.536415, -0.008122},{1.099329, 1.537492, -0.006273},{
      1.095897, 1.535743, -0.006273},{1.096563, 1.534827, -0.008122}}],
    Polygon[{{1.099329, 1.537492, -0.006273},{1.099073, 1.538281, -0.004270},{
      1.095410, 1.536415, -0.004270},{1.095897, 1.535743, -0.006273}}],
    Polygon[{{1.099073, 1.538281, -0.004270},{1.098917, 1.538763, -0.002162},{
      1.095112, 1.536824, -0.002162},{1.095410, 1.536415, -0.004270}}],
    Polygon[{{1.098917, 1.538763, -0.002162},{1.098864, 1.538924, 0.000000},{
      1.095012, 1.536962, 0.000000},{1.095112, 1.536824, -0.002162}}],
    Polygon[{{1.098864, 1.538924, 0.000000},{1.098917, 1.538763, 0.002162},{
      1.095112, 1.536824, 0.002162},{1.095012, 1.536962, 0.000000}}],
    Polygon[{{1.098917, 1.538763, 0.002162},{1.099073, 1.538281, 0.004270},{
      1.095410, 1.536415, 0.004270},{1.095112, 1.536824, 0.002162}}],
    Polygon[{{1.099073, 1.538281, 0.004270},{1.099329, 1.537492, 0.006273},{
      1.095897, 1.535743, 0.006273},{1.095410, 1.536415, 0.004270}}],
    Polygon[{{1.099329, 1.537492, 0.006273},{1.099679, 1.536415, 0.008122},{
      1.096563, 1.534827, 0.008122},{1.095897, 1.535743, 0.006273}}],
    Polygon[{{1.099679, 1.536415, 0.008122},{1.100114, 1.535076, 0.009770},{
      1.097391, 1.533688, 0.009770},{1.096563, 1.534827, 0.008122}}],
    Polygon[{{1.100114, 1.535076, 0.009770},{1.100624, 1.533507, 0.011178},{
      1.098360, 1.532354, 0.011178},{1.097391, 1.533688, 0.009770}}],
    Polygon[{{1.100624, 1.533507, 0.011178},{1.101195, 1.531749, 0.012311},{
      1.099447, 1.530858, 0.012311},{1.098360, 1.532354, 0.011178}}],
    Polygon[{{1.101195, 1.531749, 0.012311},{1.101814, 1.529844, 0.013141},{
      1.100624, 1.529238, 0.013141},{1.099447, 1.530858, 0.012311}}],
    Polygon[{{1.101814, 1.529844, 0.013141},{1.102466, 1.527839, 0.013647},{
      1.101863, 1.527532, 0.013647},{1.100624, 1.529238, 0.013141}}],
    Polygon[{{1.101863, 1.527532, -0.013647},{1.100624, 1.529238, -0.013141},{
      1.099679, 1.528293, -0.013141},{1.101385, 1.527054, -0.013647}}],
    Polygon[{{1.100624, 1.529238, -0.013141},{1.099447, 1.530858, -0.012311},{
      1.098059, 1.529471, -0.012311},{1.099679, 1.528293, -0.013141}}],
    Polygon[{{1.099447, 1.530858, -0.012311},{1.098360, 1.532354, -0.011178},{
      1.096563, 1.530557, -0.011178},{1.098059, 1.529471, -0.012311}}],
    Polygon[{{1.098360, 1.532354, -0.011178},{1.097391, 1.533688, -0.009770},{
      1.095229, 1.531526, -0.009770},{1.096563, 1.530557, -0.011178}}],
    Polygon[{{1.097391, 1.533688, -0.009770},{1.096563, 1.534827, -0.008122},{
      1.094090, 1.532354, -0.008122},{1.095229, 1.531526, -0.009770}}],
    Polygon[{{1.096563, 1.534827, -0.008122},{1.095897, 1.535743, -0.006273},{
      1.093174, 1.533020, -0.006273},{1.094090, 1.532354, -0.008122}}],
    Polygon[{{1.095897, 1.535743, -0.006273},{1.095410, 1.536415, -0.004270},{
      1.092502, 1.533507, -0.004270},{1.093174, 1.533020, -0.006273}}],
    Polygon[{{1.095410, 1.536415, -0.004270},{1.095112, 1.536824, -0.002162},{
      1.092093, 1.533805, -0.002162},{1.092502, 1.533507, -0.004270}}],
    Polygon[{{1.095112, 1.536824, -0.002162},{1.095012, 1.536962, 0.000000},{
      1.091955, 1.533905, 0.000000},{1.092093, 1.533805, -0.002162}}],
    Polygon[{{1.095012, 1.536962, 0.000000},{1.095112, 1.536824, 0.002162},{
      1.092093, 1.533805, 0.002162},{1.091955, 1.533905, 0.000000}}],
    Polygon[{{1.095112, 1.536824, 0.002162},{1.095410, 1.536415, 0.004270},{
      1.092502, 1.533507, 0.004270},{1.092093, 1.533805, 0.002162}}],
    Polygon[{{1.095410, 1.536415, 0.004270},{1.095897, 1.535743, 0.006273},{
      1.093174, 1.533020, 0.006273},{1.092502, 1.533507, 0.004270}}],
    Polygon[{{1.095897, 1.535743, 0.006273},{1.096563, 1.534827, 0.008122},{
      1.094090, 1.532354, 0.008122},{1.093174, 1.533020, 0.006273}}],
    Polygon[{{1.096563, 1.534827, 0.008122},{1.097391, 1.533688, 0.009770},{
      1.095229, 1.531526, 0.009770},{1.094090, 1.532354, 0.008122}}],
    Polygon[{{1.097391, 1.533688, 0.009770},{1.098360, 1.532354, 0.011178},{
      1.096563, 1.530557, 0.011178},{1.095229, 1.531526, 0.009770}}],
    Polygon[{{1.098360, 1.532354, 0.011178},{1.099447, 1.530858, 0.012311},{
      1.098059, 1.529471, 0.012311},{1.096563, 1.530557, 0.011178}}],
    Polygon[{{1.099447, 1.530858, 0.012311},{1.100624, 1.529238, 0.013141},{
      1.099679, 1.528293, 0.013141},{1.098059, 1.529471, 0.012311}}],
    Polygon[{{1.100624, 1.529238, 0.013141},{1.101863, 1.527532, 0.013647},{
      1.101385, 1.527054, 0.013647},{1.099679, 1.528293, 0.013141}}],
    Polygon[{{1.101385, 1.527054, -0.013647},{1.099679, 1.528293, -0.013141},{
      1.099073, 1.527103, -0.013141},{1.101078, 1.526451, -0.013647}}],
    Polygon[{{1.099679, 1.528293, -0.013141},{1.098059, 1.529471, -0.012311},{
      1.097168, 1.527722, -0.012311},{1.099073, 1.527103, -0.013141}}],
    Polygon[{{1.098059, 1.529471, -0.012311},{1.096563, 1.530557, -0.011178},{
      1.095410, 1.528293, -0.011178},{1.097168, 1.527722, -0.012311}}],
    Polygon[{{1.096563, 1.530557, -0.011178},{1.095229, 1.531526, -0.009770},{
      1.093842, 1.528803, -0.009770},{1.095410, 1.528293, -0.011178}}],
    Polygon[{{1.095229, 1.531526, -0.009770},{1.094090, 1.532354, -0.008122},{
      1.092502, 1.529238, -0.008122},{1.093842, 1.528803, -0.009770}}],
    Polygon[{{1.094090, 1.532354, -0.008122},{1.093174, 1.533020, -0.006273},{
      1.091425, 1.529588, -0.006273},{1.092502, 1.529238, -0.008122}}],
    Polygon[{{1.093174, 1.533020, -0.006273},{1.092502, 1.533507, -0.004270},{
      1.090636, 1.529844, -0.004270},{1.091425, 1.529588, -0.006273}}],
    Polygon[{{1.092502, 1.533507, -0.004270},{1.092093, 1.533805, -0.002162},{
      1.090154, 1.530001, -0.002162},{1.090636, 1.529844, -0.004270}}],
    Polygon[{{1.092093, 1.533805, -0.002162},{1.091955, 1.533905, 0.000000},{
      1.089993, 1.530053, 0.000000},{1.090154, 1.530001, -0.002162}}],
    Polygon[{{1.091955, 1.533905, 0.000000},{1.092093, 1.533805, 0.002162},{
      1.090154, 1.530001, 0.002162},{1.089993, 1.530053, 0.000000}}],
    Polygon[{{1.092093, 1.533805, 0.002162},{1.092502, 1.533507, 0.004270},{
      1.090636, 1.529844, 0.004270},{1.090154, 1.530001, 0.002162}}],
    Polygon[{{1.092502, 1.533507, 0.004270},{1.093174, 1.533020, 0.006273},{
      1.091425, 1.529588, 0.006273},{1.090636, 1.529844, 0.004270}}],
    Polygon[{{1.093174, 1.533020, 0.006273},{1.094090, 1.532354, 0.008122},{
      1.092502, 1.529238, 0.008122},{1.091425, 1.529588, 0.006273}}],
    Polygon[{{1.094090, 1.532354, 0.008122},{1.095229, 1.531526, 0.009770},{
      1.093842, 1.528803, 0.009770},{1.092502, 1.529238, 0.008122}}],
    Polygon[{{1.095229, 1.531526, 0.009770},{1.096563, 1.530557, 0.011178},{
      1.095410, 1.528293, 0.011178},{1.093842, 1.528803, 0.009770}}],
    Polygon[{{1.096563, 1.530557, 0.011178},{1.098059, 1.529471, 0.012311},{
      1.097168, 1.527722, 0.012311},{1.095410, 1.528293, 0.011178}}],
    Polygon[{{1.098059, 1.529471, 0.012311},{1.099679, 1.528293, 0.013141},{
      1.099073, 1.527103, 0.013141},{1.097168, 1.527722, 0.012311}}],
    Polygon[{{1.099679, 1.528293, 0.013141},{1.101385, 1.527054, 0.013647},{
      1.101078, 1.526451, 0.013647},{1.099073, 1.527103, 0.013141}}],
    Polygon[{{1.101078, 1.526451, -0.013647},{1.099073, 1.527103, -0.013141},{
      1.098864, 1.525783, -0.013141},{1.100972, 1.525783, -0.013647}}],
    Polygon[{{1.099073, 1.527103, -0.013141},{1.097168, 1.527722, -0.012311},{
      1.096861, 1.525783, -0.012311},{1.098864, 1.525783, -0.013141}}],
    Polygon[{{1.097168, 1.527722, -0.012311},{1.095410, 1.528293, -0.011178},{
      1.095012, 1.525783, -0.011178},{1.096861, 1.525783, -0.012311}}],
    Polygon[{{1.095410, 1.528293, -0.011178},{1.093842, 1.528803, -0.009770},{
      1.093363, 1.525783, -0.009770},{1.095012, 1.525783, -0.011178}}],
    Polygon[{{1.093842, 1.528803, -0.009770},{1.092502, 1.529238, -0.008122},{
      1.091955, 1.525783, -0.008122},{1.093363, 1.525783, -0.009770}}],
    Polygon[{{1.092502, 1.529238, -0.008122},{1.091425, 1.529588, -0.006273},{
      1.090822, 1.525783, -0.006273},{1.091955, 1.525783, -0.008122}}],
    Polygon[{{1.091425, 1.529588, -0.006273},{1.090636, 1.529844, -0.004270},{
      1.089993, 1.525783, -0.004270},{1.090822, 1.525783, -0.006273}}],
    Polygon[{{1.090636, 1.529844, -0.004270},{1.090154, 1.530001, -0.002162},{
      1.089486, 1.525783, -0.002162},{1.089993, 1.525783, -0.004270}}],
    Polygon[{{1.090154, 1.530001, -0.002162},{1.089993, 1.530053, 0.000000},{
      1.089316, 1.525783, 0.000000},{1.089486, 1.525783, -0.002162}}],
    Polygon[{{1.089993, 1.530053, 0.000000},{1.090154, 1.530001, 0.002162},{
      1.089486, 1.525783, 0.002162},{1.089316, 1.525783, 0.000000}}],
    Polygon[{{1.090154, 1.530001, 0.002162},{1.090636, 1.529844, 0.004270},{
      1.089993, 1.525783, 0.004270},{1.089486, 1.525783, 0.002162}}],
    Polygon[{{1.090636, 1.529844, 0.004270},{1.091425, 1.529588, 0.006273},{
      1.090822, 1.525783, 0.006273},{1.089993, 1.525783, 0.004270}}],
    Polygon[{{1.091425, 1.529588, 0.006273},{1.092502, 1.529238, 0.008122},{
      1.091955, 1.525783, 0.008122},{1.090822, 1.525783, 0.006273}}],
    Polygon[{{1.092502, 1.529238, 0.008122},{1.093842, 1.528803, 0.009770},{
      1.093363, 1.525783, 0.009770},{1.091955, 1.525783, 0.008122}}],
    Polygon[{{1.093842, 1.528803, 0.009770},{1.095410, 1.528293, 0.011178},{
      1.095012, 1.525783, 0.011178},{1.093363, 1.525783, 0.009770}}],
    Polygon[{{1.095410, 1.528293, 0.011178},{1.097168, 1.527722, 0.012311},{
      1.096861, 1.525783, 0.012311},{1.095012, 1.525783, 0.011178}}],
    Polygon[{{1.097168, 1.527722, 0.012311},{1.099073, 1.527103, 0.013141},{
      1.098864, 1.525783, 0.013141},{1.096861, 1.525783, 0.012311}}],
    Polygon[{{1.099073, 1.527103, 0.013141},{1.101078, 1.526451, 0.013647},{
      1.100972, 1.525783, 0.013647},{1.098864, 1.525783, 0.013141}}],
    Polygon[{{1.100972, 1.525783, -0.013647},{1.098864, 1.525783, -0.013141},{
      1.099073, 1.524464, -0.013141},{1.101078, 1.525115, -0.013647}}],
    Polygon[{{1.098864, 1.525783, -0.013141},{1.096861, 1.525783, -0.012311},{
      1.097168, 1.523845, -0.012311},{1.099073, 1.524464, -0.013141}}],
    Polygon[{{1.096861, 1.525783, -0.012311},{1.095012, 1.525783, -0.011178},{
      1.095410, 1.523274, -0.011178},{1.097168, 1.523845, -0.012311}}],
    Polygon[{{1.095012, 1.525783, -0.011178},{1.093363, 1.525783, -0.009770},{
      1.093842, 1.522764, -0.009770},{1.095410, 1.523274, -0.011178}}],
    Polygon[{{1.093363, 1.525783, -0.009770},{1.091955, 1.525783, -0.008122},{
      1.092502, 1.522329, -0.008122},{1.093842, 1.522764, -0.009770}}],
    Polygon[{{1.091955, 1.525783, -0.008122},{1.090822, 1.525783, -0.006273},{
      1.091425, 1.521979, -0.006273},{1.092502, 1.522329, -0.008122}}],
    Polygon[{{1.090822, 1.525783, -0.006273},{1.089993, 1.525783, -0.004270},{
      1.090636, 1.521723, -0.004270},{1.091425, 1.521979, -0.006273}}],
    Polygon[{{1.089993, 1.525783, -0.004270},{1.089486, 1.525783, -0.002162},{
      1.090154, 1.521566, -0.002162},{1.090636, 1.521723, -0.004270}}],
    Polygon[{{1.089486, 1.525783, -0.002162},{1.089316, 1.525783, 0.000000},{
      1.089993, 1.521514, 0.000000},{1.090154, 1.521566, -0.002162}}],
    Polygon[{{1.089316, 1.525783, 0.000000},{1.089486, 1.525783, 0.002162},{
      1.090154, 1.521566, 0.002162},{1.089993, 1.521514, 0.000000}}],
    Polygon[{{1.089486, 1.525783, 0.002162},{1.089993, 1.525783, 0.004270},{
      1.090636, 1.521723, 0.004270},{1.090154, 1.521566, 0.002162}}],
    Polygon[{{1.089993, 1.525783, 0.004270},{1.090822, 1.525783, 0.006273},{
      1.091425, 1.521979, 0.006273},{1.090636, 1.521723, 0.004270}}],
    Polygon[{{1.090822, 1.525783, 0.006273},{1.091955, 1.525783, 0.008122},{
      1.092502, 1.522329, 0.008122},{1.091425, 1.521979, 0.006273}}],
    Polygon[{{1.091955, 1.525783, 0.008122},{1.093363, 1.525783, 0.009770},{
      1.093842, 1.522764, 0.009770},{1.092502, 1.522329, 0.008122}}],
    Polygon[{{1.093363, 1.525783, 0.009770},{1.095012, 1.525783, 0.011178},{
      1.095410, 1.523274, 0.011178},{1.093842, 1.522764, 0.009770}}],
    Polygon[{{1.095012, 1.525783, 0.011178},{1.096861, 1.525783, 0.012311},{
      1.097168, 1.523845, 0.012311},{1.095410, 1.523274, 0.011178}}],
    Polygon[{{1.096861, 1.525783, 0.012311},{1.098864, 1.525783, 0.013141},{
      1.099073, 1.524464, 0.013141},{1.097168, 1.523845, 0.012311}}],
    Polygon[{{1.098864, 1.525783, 0.013141},{1.100972, 1.525783, 0.013647},{
      1.101078, 1.525115, 0.013647},{1.099073, 1.524464, 0.013141}}],
    Polygon[{{1.101078, 1.525115, -0.013647},{1.099073, 1.524464, -0.013141},{
      1.099679, 1.523274, -0.013141},{1.101385, 1.524513, -0.013647}}],
    Polygon[{{1.099073, 1.524464, -0.013141},{1.097168, 1.523845, -0.012311},{
      1.098059, 1.522096, -0.012311},{1.099679, 1.523274, -0.013141}}],
    Polygon[{{1.097168, 1.523845, -0.012311},{1.095410, 1.523274, -0.011178},{
      1.096563, 1.521010, -0.011178},{1.098059, 1.522096, -0.012311}}],
    Polygon[{{1.095410, 1.523274, -0.011178},{1.093842, 1.522764, -0.009770},{
      1.095229, 1.520041, -0.009770},{1.096563, 1.521010, -0.011178}}],
    Polygon[{{1.093842, 1.522764, -0.009770},{1.092502, 1.522329, -0.008122},{
      1.094090, 1.519213, -0.008122},{1.095229, 1.520041, -0.009770}}],
    Polygon[{{1.092502, 1.522329, -0.008122},{1.091425, 1.521979, -0.006273},{
      1.093174, 1.518547, -0.006273},{1.094090, 1.519213, -0.008122}}],
    Polygon[{{1.091425, 1.521979, -0.006273},{1.090636, 1.521723, -0.004270},{
      1.092502, 1.518059, -0.004270},{1.093174, 1.518547, -0.006273}}],
    Polygon[{{1.090636, 1.521723, -0.004270},{1.090154, 1.521566, -0.002162},{
      1.092093, 1.517762, -0.002162},{1.092502, 1.518059, -0.004270}}],
    Polygon[{{1.090154, 1.521566, -0.002162},{1.089993, 1.521514, 0.000000},{
      1.091955, 1.517662, 0.000000},{1.092093, 1.517762, -0.002162}}],
    Polygon[{{1.089993, 1.521514, 0.000000},{1.090154, 1.521566, 0.002162},{
      1.092093, 1.517762, 0.002162},{1.091955, 1.517662, 0.000000}}],
    Polygon[{{1.090154, 1.521566, 0.002162},{1.090636, 1.521723, 0.004270},{
      1.092502, 1.518059, 0.004270},{1.092093, 1.517762, 0.002162}}],
    Polygon[{{1.090636, 1.521723, 0.004270},{1.091425, 1.521979, 0.006273},{
      1.093174, 1.518547, 0.006273},{1.092502, 1.518059, 0.004270}}],
    Polygon[{{1.091425, 1.521979, 0.006273},{1.092502, 1.522329, 0.008122},{
      1.094090, 1.519213, 0.008122},{1.093174, 1.518547, 0.006273}}],
    Polygon[{{1.092502, 1.522329, 0.008122},{1.093842, 1.522764, 0.009770},{
      1.095229, 1.520041, 0.009770},{1.094090, 1.519213, 0.008122}}],
    Polygon[{{1.093842, 1.522764, 0.009770},{1.095410, 1.523274, 0.011178},{
      1.096563, 1.521010, 0.011178},{1.095229, 1.520041, 0.009770}}],
    Polygon[{{1.095410, 1.523274, 0.011178},{1.097168, 1.523845, 0.012311},{
      1.098059, 1.522096, 0.012311},{1.096563, 1.521010, 0.011178}}],
    Polygon[{{1.097168, 1.523845, 0.012311},{1.099073, 1.524464, 0.013141},{
      1.099679, 1.523274, 0.013141},{1.098059, 1.522096, 0.012311}}],
    Polygon[{{1.099073, 1.524464, 0.013141},{1.101078, 1.525115, 0.013647},{
      1.101385, 1.524513, 0.013647},{1.099679, 1.523274, 0.013141}}],
    Polygon[{{1.101385, 1.524513, -0.013647},{1.099679, 1.523274, -0.013141},{
      1.100624, 1.522329, -0.013141},{1.101863, 1.524035, -0.013647}}],
    Polygon[{{1.099679, 1.523274, -0.013141},{1.098059, 1.522096, -0.012311},{
      1.099447, 1.520709, -0.012311},{1.100624, 1.522329, -0.013141}}],
    Polygon[{{1.098059, 1.522096, -0.012311},{1.096563, 1.521010, -0.011178},{
      1.098360, 1.519213, -0.011178},{1.099447, 1.520709, -0.012311}}],
    Polygon[{{1.096563, 1.521010, -0.011178},{1.095229, 1.520041, -0.009770},{
      1.097391, 1.517879, -0.009770},{1.098360, 1.519213, -0.011178}}],
    Polygon[{{1.095229, 1.520041, -0.009770},{1.094090, 1.519213, -0.008122},{
      1.096563, 1.516740, -0.008122},{1.097391, 1.517879, -0.009770}}],
    Polygon[{{1.094090, 1.519213, -0.008122},{1.093174, 1.518547, -0.006273},{
      1.095897, 1.515823, -0.006273},{1.096563, 1.516740, -0.008122}}],
    Polygon[{{1.093174, 1.518547, -0.006273},{1.092502, 1.518059, -0.004270},{
      1.095410, 1.515152, -0.004270},{1.095897, 1.515823, -0.006273}}],
    Polygon[{{1.092502, 1.518059, -0.004270},{1.092093, 1.517762, -0.002162},{
      1.095112, 1.514743, -0.002162},{1.095410, 1.515152, -0.004270}}],
    Polygon[{{1.092093, 1.517762, -0.002162},{1.091955, 1.517662, 0.000000},{
      1.095012, 1.514605, 0.000000},{1.095112, 1.514743, -0.002162}}],
    Polygon[{{1.091955, 1.517662, 0.000000},{1.092093, 1.517762, 0.002162},{
      1.095112, 1.514743, 0.002162},{1.095012, 1.514605, 0.000000}}],
    Polygon[{{1.092093, 1.517762, 0.002162},{1.092502, 1.518059, 0.004270},{
      1.095410, 1.515152, 0.004270},{1.095112, 1.514743, 0.002162}}],
    Polygon[{{1.092502, 1.518059, 0.004270},{1.093174, 1.518547, 0.006273},{
      1.095897, 1.515823, 0.006273},{1.095410, 1.515152, 0.004270}}],
    Polygon[{{1.093174, 1.518547, 0.006273},{1.094090, 1.519213, 0.008122},{
      1.096563, 1.516740, 0.008122},{1.095897, 1.515823, 0.006273}}],
    Polygon[{{1.094090, 1.519213, 0.008122},{1.095229, 1.520041, 0.009770},{
      1.097391, 1.517879, 0.009770},{1.096563, 1.516740, 0.008122}}],
    Polygon[{{1.095229, 1.520041, 0.009770},{1.096563, 1.521010, 0.011178},{
      1.098360, 1.519213, 0.011178},{1.097391, 1.517879, 0.009770}}],
    Polygon[{{1.096563, 1.521010, 0.011178},{1.098059, 1.522096, 0.012311},{
      1.099447, 1.520709, 0.012311},{1.098360, 1.519213, 0.011178}}],
    Polygon[{{1.098059, 1.522096, 0.012311},{1.099679, 1.523274, 0.013141},{
      1.100624, 1.522329, 0.013141},{1.099447, 1.520709, 0.012311}}],
    Polygon[{{1.099679, 1.523274, 0.013141},{1.101385, 1.524513, 0.013647},{
      1.101863, 1.524035, 0.013647},{1.100624, 1.522329, 0.013141}}],
    Polygon[{{1.101863, 1.524035, -0.013647},{1.100624, 1.522329, -0.013141},{
      1.101814, 1.521723, -0.013141},{1.102466, 1.523728, -0.013647}}],
    Polygon[{{1.100624, 1.522329, -0.013141},{1.099447, 1.520709, -0.012311},{
      1.101195, 1.519817, -0.012311},{1.101814, 1.521723, -0.013141}}],
    Polygon[{{1.099447, 1.520709, -0.012311},{1.098360, 1.519213, -0.011178},{
      1.100624, 1.518059, -0.011178},{1.101195, 1.519817, -0.012311}}],
    Polygon[{{1.098360, 1.519213, -0.011178},{1.097391, 1.517879, -0.009770},{
      1.100114, 1.516491, -0.009770},{1.100624, 1.518059, -0.011178}}],
    Polygon[{{1.097391, 1.517879, -0.009770},{1.096563, 1.516740, -0.008122},{
      1.099679, 1.515152, -0.008122},{1.100114, 1.516491, -0.009770}}],
    Polygon[{{1.096563, 1.516740, -0.008122},{1.095897, 1.515823, -0.006273},{
      1.099329, 1.514075, -0.006273},{1.099679, 1.515152, -0.008122}}],
    Polygon[{{1.095897, 1.515823, -0.006273},{1.095410, 1.515152, -0.004270},{
      1.099073, 1.513286, -0.004270},{1.099329, 1.514075, -0.006273}}],
    Polygon[{{1.095410, 1.515152, -0.004270},{1.095112, 1.514743, -0.002162},{
      1.098917, 1.512804, -0.002162},{1.099073, 1.513286, -0.004270}}],
    Polygon[{{1.095112, 1.514743, -0.002162},{1.095012, 1.514605, 0.000000},{
      1.098864, 1.512642, 0.000000},{1.098917, 1.512804, -0.002162}}],
    Polygon[{{1.095012, 1.514605, 0.000000},{1.095112, 1.514743, 0.002162},{
      1.098917, 1.512804, 0.002162},{1.098864, 1.512642, 0.000000}}],
    Polygon[{{1.095112, 1.514743, 0.002162},{1.095410, 1.515152, 0.004270},{
      1.099073, 1.513286, 0.004270},{1.098917, 1.512804, 0.002162}}],
    Polygon[{{1.095410, 1.515152, 0.004270},{1.095897, 1.515823, 0.006273},{
      1.099329, 1.514075, 0.006273},{1.099073, 1.513286, 0.004270}}],
    Polygon[{{1.095897, 1.515823, 0.006273},{1.096563, 1.516740, 0.008122},{
      1.099679, 1.515152, 0.008122},{1.099329, 1.514075, 0.006273}}],
    Polygon[{{1.096563, 1.516740, 0.008122},{1.097391, 1.517879, 0.009770},{
      1.100114, 1.516491, 0.009770},{1.099679, 1.515152, 0.008122}}],
    Polygon[{{1.097391, 1.517879, 0.009770},{1.098360, 1.519213, 0.011178},{
      1.100624, 1.518059, 0.011178},{1.100114, 1.516491, 0.009770}}],
    Polygon[{{1.098360, 1.519213, 0.011178},{1.099447, 1.520709, 0.012311},{
      1.101195, 1.519817, 0.012311},{1.100624, 1.518059, 0.011178}}],
    Polygon[{{1.099447, 1.520709, 0.012311},{1.100624, 1.522329, 0.013141},{
      1.101814, 1.521723, 0.013141},{1.101195, 1.519817, 0.012311}}],
    Polygon[{{1.100624, 1.522329, 0.013141},{1.101863, 1.524035, 0.013647},{
      1.102466, 1.523728, 0.013647},{1.101814, 1.521723, 0.013141}}],
    Polygon[{{1.102466, 1.523728, -0.013647},{1.101814, 1.521723, -0.013141},{
      1.103134, 1.521514, -0.013141},{1.103134, 1.523622, -0.013647}}],
    Polygon[{{1.101814, 1.521723, -0.013141},{1.101195, 1.519817, -0.012311},{
      1.103134, 1.519511, -0.012311},{1.103134, 1.521514, -0.013141}}],
    Polygon[{{1.101195, 1.519817, -0.012311},{1.100624, 1.518059, -0.011178},{
      1.103134, 1.517662, -0.011178},{1.103134, 1.519511, -0.012311}}],
    Polygon[{{1.100624, 1.518059, -0.011178},{1.100114, 1.516491, -0.009770},{
      1.103134, 1.516013, -0.009770},{1.103134, 1.517662, -0.011178}}],
    Polygon[{{1.100114, 1.516491, -0.009770},{1.099679, 1.515152, -0.008122},{
      1.103134, 1.514605, -0.008122},{1.103134, 1.516013, -0.009770}}],
    Polygon[{{1.099679, 1.515152, -0.008122},{1.099329, 1.514075, -0.006273},{
      1.103134, 1.513472, -0.006273},{1.103134, 1.514605, -0.008122}}],
    Polygon[{{1.099329, 1.514075, -0.006273},{1.099073, 1.513286, -0.004270},{
      1.103134, 1.512642, -0.004270},{1.103134, 1.513472, -0.006273}}],
    Polygon[{{1.099073, 1.513286, -0.004270},{1.098917, 1.512804, -0.002162},{
      1.103134, 1.512136, -0.002162},{1.103134, 1.512642, -0.004270}}],
    Polygon[{{1.098917, 1.512804, -0.002162},{1.098864, 1.512642, 0.000000},{
      1.103134, 1.511966, 0.000000},{1.103134, 1.512136, -0.002162}}],
    Polygon[{{1.098864, 1.512642, 0.000000},{1.098917, 1.512804, 0.002162},{
      1.103134, 1.512136, 0.002162},{1.103134, 1.511966, 0.000000}}],
    Polygon[{{1.098917, 1.512804, 0.002162},{1.099073, 1.513286, 0.004270},{
      1.103134, 1.512642, 0.004270},{1.103134, 1.512136, 0.002162}}],
    Polygon[{{1.099073, 1.513286, 0.004270},{1.099329, 1.514075, 0.006273},{
      1.103134, 1.513472, 0.006273},{1.103134, 1.512642, 0.004270}}],
    Polygon[{{1.099329, 1.514075, 0.006273},{1.099679, 1.515152, 0.008122},{
      1.103134, 1.514605, 0.008122},{1.103134, 1.513472, 0.006273}}],
    Polygon[{{1.099679, 1.515152, 0.008122},{1.100114, 1.516491, 0.009770},{
      1.103134, 1.516013, 0.009770},{1.103134, 1.514605, 0.008122}}],
    Polygon[{{1.100114, 1.516491, 0.009770},{1.100624, 1.518059, 0.011178},{
      1.103134, 1.517662, 0.011178},{1.103134, 1.516013, 0.009770}}],
    Polygon[{{1.100624, 1.518059, 0.011178},{1.101195, 1.519817, 0.012311},{
      1.103134, 1.519511, 0.012311},{1.103134, 1.517662, 0.011178}}],
    Polygon[{{1.101195, 1.519817, 0.012311},{1.101814, 1.521723, 0.013141},{
      1.103134, 1.521514, 0.013141},{1.103134, 1.519511, 0.012311}}],
    Polygon[{{1.101814, 1.521723, 0.013141},{1.102466, 1.523728, 0.013647},{
      1.103134, 1.523622, 0.013647},{1.103134, 1.521514, 0.013141}}],
    Polygon[{{1.103134, 1.523622, -0.013647},{1.103134, 1.521514, -0.013141},{
      1.104453, 1.521723, -0.013141},{1.103802, 1.523728, -0.013647}}],
    Polygon[{{1.103134, 1.521514, -0.013141},{1.103134, 1.519511, -0.012311},{
      1.105072, 1.519817, -0.012311},{1.104453, 1.521723, -0.013141}}],
    Polygon[{{1.103134, 1.519511, -0.012311},{1.103134, 1.517662, -0.011178},{
      1.105643, 1.518059, -0.011178},{1.105072, 1.519817, -0.012311}}],
    Polygon[{{1.103134, 1.517662, -0.011178},{1.103134, 1.516013, -0.009770},{
      1.106153, 1.516491, -0.009770},{1.105643, 1.518059, -0.011178}}],
    Polygon[{{1.103134, 1.516013, -0.009770},{1.103134, 1.514605, -0.008122},{
      1.106588, 1.515152, -0.008122},{1.106153, 1.516491, -0.009770}}],
    Polygon[{{1.103134, 1.514605, -0.008122},{1.103134, 1.513472, -0.006273},{
      1.106938, 1.514075, -0.006273},{1.106588, 1.515152, -0.008122}}],
    Polygon[{{1.103134, 1.513472, -0.006273},{1.103134, 1.512642, -0.004270},{
      1.107195, 1.513286, -0.004270},{1.106938, 1.514075, -0.006273}}],
    Polygon[{{1.103134, 1.512642, -0.004270},{1.103134, 1.512136, -0.002162},{
      1.107351, 1.512804, -0.002162},{1.107195, 1.513286, -0.004270}}],
    Polygon[{{1.103134, 1.512136, -0.002162},{1.103134, 1.511966, 0.000000},{
      1.107404, 1.512642, 0.000000},{1.107351, 1.512804, -0.002162}}],
    Polygon[{{1.103134, 1.511966, 0.000000},{1.103134, 1.512136, 0.002162},{
      1.107351, 1.512804, 0.002162},{1.107404, 1.512642, 0.000000}}],
    Polygon[{{1.103134, 1.512136, 0.002162},{1.103134, 1.512642, 0.004270},{
      1.107195, 1.513286, 0.004270},{1.107351, 1.512804, 0.002162}}],
    Polygon[{{1.103134, 1.512642, 0.004270},{1.103134, 1.513472, 0.006273},{
      1.106938, 1.514075, 0.006273},{1.107195, 1.513286, 0.004270}}],
    Polygon[{{1.103134, 1.513472, 0.006273},{1.103134, 1.514605, 0.008122},{
      1.106588, 1.515152, 0.008122},{1.106938, 1.514075, 0.006273}}],
    Polygon[{{1.103134, 1.514605, 0.008122},{1.103134, 1.516013, 0.009770},{
      1.106153, 1.516491, 0.009770},{1.106588, 1.515152, 0.008122}}],
    Polygon[{{1.103134, 1.516013, 0.009770},{1.103134, 1.517662, 0.011178},{
      1.105643, 1.518059, 0.011178},{1.106153, 1.516491, 0.009770}}],
    Polygon[{{1.103134, 1.517662, 0.011178},{1.103134, 1.519511, 0.012311},{
      1.105072, 1.519817, 0.012311},{1.105643, 1.518059, 0.011178}}],
    Polygon[{{1.103134, 1.519511, 0.012311},{1.103134, 1.521514, 0.013141},{
      1.104453, 1.521723, 0.013141},{1.105072, 1.519817, 0.012311}}],
    Polygon[{{1.103134, 1.521514, 0.013141},{1.103134, 1.523622, 0.013647},{
      1.103802, 1.523728, 0.013647},{1.104453, 1.521723, 0.013141}}],
    Polygon[{{1.103802, 1.523728, -0.013647},{1.104453, 1.521723, -0.013141},{
      1.105643, 1.522329, -0.013141},{1.104404, 1.524035, -0.013647}}],
    Polygon[{{1.104453, 1.521723, -0.013141},{1.105072, 1.519817, -0.012311},{
      1.106821, 1.520709, -0.012311},{1.105643, 1.522329, -0.013141}}],
    Polygon[{{1.105072, 1.519817, -0.012311},{1.105643, 1.518059, -0.011178},{
      1.107907, 1.519213, -0.011178},{1.106821, 1.520709, -0.012311}}],
    Polygon[{{1.105643, 1.518059, -0.011178},{1.106153, 1.516491, -0.009770},{
      1.108877, 1.517879, -0.009770},{1.107907, 1.519213, -0.011178}}],
    Polygon[{{1.106153, 1.516491, -0.009770},{1.106588, 1.515152, -0.008122},{
      1.109704, 1.516740, -0.008122},{1.108877, 1.517879, -0.009770}}],
    Polygon[{{1.106588, 1.515152, -0.008122},{1.106938, 1.514075, -0.006273},{
      1.110370, 1.515823, -0.006273},{1.109704, 1.516740, -0.008122}}],
    Polygon[{{1.106938, 1.514075, -0.006273},{1.107195, 1.513286, -0.004270},{
      1.110858, 1.515152, -0.004270},{1.110370, 1.515823, -0.006273}}],
    Polygon[{{1.107195, 1.513286, -0.004270},{1.107351, 1.512804, -0.002162},{
      1.111155, 1.514743, -0.002162},{1.110858, 1.515152, -0.004270}}],
    Polygon[{{1.107351, 1.512804, -0.002162},{1.107404, 1.512642, 0.000000},{
      1.111255, 1.514605, 0.000000},{1.111155, 1.514743, -0.002162}}],
    Polygon[{{1.107404, 1.512642, 0.000000},{1.107351, 1.512804, 0.002162},{
      1.111155, 1.514743, 0.002162},{1.111255, 1.514605, 0.000000}}],
    Polygon[{{1.107351, 1.512804, 0.002162},{1.107195, 1.513286, 0.004270},{
      1.110858, 1.515152, 0.004270},{1.111155, 1.514743, 0.002162}}],
    Polygon[{{1.107195, 1.513286, 0.004270},{1.106938, 1.514075, 0.006273},{
      1.110370, 1.515823, 0.006273},{1.110858, 1.515152, 0.004270}}],
    Polygon[{{1.106938, 1.514075, 0.006273},{1.106588, 1.515152, 0.008122},{
      1.109704, 1.516740, 0.008122},{1.110370, 1.515823, 0.006273}}],
    Polygon[{{1.106588, 1.515152, 0.008122},{1.106153, 1.516491, 0.009770},{
      1.108877, 1.517879, 0.009770},{1.109704, 1.516740, 0.008122}}],
    Polygon[{{1.106153, 1.516491, 0.009770},{1.105643, 1.518059, 0.011178},{
      1.107907, 1.519213, 0.011178},{1.108877, 1.517879, 0.009770}}],
    Polygon[{{1.105643, 1.518059, 0.011178},{1.105072, 1.519817, 0.012311},{
      1.106821, 1.520709, 0.012311},{1.107907, 1.519213, 0.011178}}],
    Polygon[{{1.105072, 1.519817, 0.012311},{1.104453, 1.521723, 0.013141},{
      1.105643, 1.522329, 0.013141},{1.106821, 1.520709, 0.012311}}],
    Polygon[{{1.104453, 1.521723, 0.013141},{1.103802, 1.523728, 0.013647},{
      1.104404, 1.524035, 0.013647},{1.105643, 1.522329, 0.013141}}],
    Polygon[{{1.104404, 1.524035, -0.013647},{1.105643, 1.522329, -0.013141},{
      1.106588, 1.523274, -0.013141},{1.104882, 1.524513, -0.013647}}],
    Polygon[{{1.105643, 1.522329, -0.013141},{1.106821, 1.520709, -0.012311},{
      1.108209, 1.522096, -0.012311},{1.106588, 1.523274, -0.013141}}],
    Polygon[{{1.106821, 1.520709, -0.012311},{1.107907, 1.519213, -0.011178},{
      1.109704, 1.521010, -0.011178},{1.108209, 1.522096, -0.012311}}],
    Polygon[{{1.107907, 1.519213, -0.011178},{1.108877, 1.517879, -0.009770},{
      1.111038, 1.520041, -0.009770},{1.109704, 1.521010, -0.011178}}],
    Polygon[{{1.108877, 1.517879, -0.009770},{1.109704, 1.516740, -0.008122},{
      1.112177, 1.519213, -0.008122},{1.111038, 1.520041, -0.009770}}],
    Polygon[{{1.109704, 1.516740, -0.008122},{1.110370, 1.515823, -0.006273},{
      1.113094, 1.518547, -0.006273},{1.112177, 1.519213, -0.008122}}],
    Polygon[{{1.110370, 1.515823, -0.006273},{1.110858, 1.515152, -0.004270},{
      1.113765, 1.518059, -0.004270},{1.113094, 1.518547, -0.006273}}],
    Polygon[{{1.110858, 1.515152, -0.004270},{1.111155, 1.514743, -0.002162},{
      1.114174, 1.517762, -0.002162},{1.113765, 1.518059, -0.004270}}],
    Polygon[{{1.111155, 1.514743, -0.002162},{1.111255, 1.514605, 0.000000},{
      1.114312, 1.517662, 0.000000},{1.114174, 1.517762, -0.002162}}],
    Polygon[{{1.111255, 1.514605, 0.000000},{1.111155, 1.514743, 0.002162},{
      1.114174, 1.517762, 0.002162},{1.114312, 1.517662, 0.000000}}],
    Polygon[{{1.111155, 1.514743, 0.002162},{1.110858, 1.515152, 0.004270},{
      1.113765, 1.518059, 0.004270},{1.114174, 1.517762, 0.002162}}],
    Polygon[{{1.110858, 1.515152, 0.004270},{1.110370, 1.515823, 0.006273},{
      1.113094, 1.518547, 0.006273},{1.113765, 1.518059, 0.004270}}],
    Polygon[{{1.110370, 1.515823, 0.006273},{1.109704, 1.516740, 0.008122},{
      1.112177, 1.519213, 0.008122},{1.113094, 1.518547, 0.006273}}],
    Polygon[{{1.109704, 1.516740, 0.008122},{1.108877, 1.517879, 0.009770},{
      1.111038, 1.520041, 0.009770},{1.112177, 1.519213, 0.008122}}],
    Polygon[{{1.108877, 1.517879, 0.009770},{1.107907, 1.519213, 0.011178},{
      1.109704, 1.521010, 0.011178},{1.111038, 1.520041, 0.009770}}],
    Polygon[{{1.107907, 1.519213, 0.011178},{1.106821, 1.520709, 0.012311},{
      1.108209, 1.522096, 0.012311},{1.109704, 1.521010, 0.011178}}],
    Polygon[{{1.106821, 1.520709, 0.012311},{1.105643, 1.522329, 0.013141},{
      1.106588, 1.523274, 0.013141},{1.108209, 1.522096, 0.012311}}],
    Polygon[{{1.105643, 1.522329, 0.013141},{1.104404, 1.524035, 0.013647},{
      1.104882, 1.524513, 0.013647},{1.106588, 1.523274, 0.013141}}],
    Polygon[{{1.104882, 1.524513, -0.013647},{1.106588, 1.523274, -0.013141},{
      1.107195, 1.524464, -0.013141},{1.105189, 1.525115, -0.013647}}],
    Polygon[{{1.106588, 1.523274, -0.013141},{1.108209, 1.522096, -0.012311},{
      1.109100, 1.523845, -0.012311},{1.107195, 1.524464, -0.013141}}],
    Polygon[{{1.108209, 1.522096, -0.012311},{1.109704, 1.521010, -0.011178},{
      1.110858, 1.523274, -0.011178},{1.109100, 1.523845, -0.012311}}],
    Polygon[{{1.109704, 1.521010, -0.011178},{1.111038, 1.520041, -0.009770},{
      1.112426, 1.522764, -0.009770},{1.110858, 1.523274, -0.011178}}],
    Polygon[{{1.111038, 1.520041, -0.009770},{1.112177, 1.519213, -0.008122},{
      1.113765, 1.522329, -0.008122},{1.112426, 1.522764, -0.009770}}],
    Polygon[{{1.112177, 1.519213, -0.008122},{1.113094, 1.518547, -0.006273},{
      1.114842, 1.521979, -0.006273},{1.113765, 1.522329, -0.008122}}],
    Polygon[{{1.113094, 1.518547, -0.006273},{1.113765, 1.518059, -0.004270},{
      1.115632, 1.521723, -0.004270},{1.114842, 1.521979, -0.006273}}],
    Polygon[{{1.113765, 1.518059, -0.004270},{1.114174, 1.517762, -0.002162},{
      1.116113, 1.521566, -0.002162},{1.115632, 1.521723, -0.004270}}],
    Polygon[{{1.114174, 1.517762, -0.002162},{1.114312, 1.517662, 0.000000},{
      1.116275, 1.521514, 0.000000},{1.116113, 1.521566, -0.002162}}],
    Polygon[{{1.114312, 1.517662, 0.000000},{1.114174, 1.517762, 0.002162},{
      1.116113, 1.521566, 0.002162},{1.116275, 1.521514, 0.000000}}],
    Polygon[{{1.114174, 1.517762, 0.002162},{1.113765, 1.518059, 0.004270},{
      1.115632, 1.521723, 0.004270},{1.116113, 1.521566, 0.002162}}],
    Polygon[{{1.113765, 1.518059, 0.004270},{1.113094, 1.518547, 0.006273},{
      1.114842, 1.521979, 0.006273},{1.115632, 1.521723, 0.004270}}],
    Polygon[{{1.113094, 1.518547, 0.006273},{1.112177, 1.519213, 0.008122},{
      1.113765, 1.522329, 0.008122},{1.114842, 1.521979, 0.006273}}],
    Polygon[{{1.112177, 1.519213, 0.008122},{1.111038, 1.520041, 0.009770},{
      1.112426, 1.522764, 0.009770},{1.113765, 1.522329, 0.008122}}],
    Polygon[{{1.111038, 1.520041, 0.009770},{1.109704, 1.521010, 0.011178},{
      1.110858, 1.523274, 0.011178},{1.112426, 1.522764, 0.009770}}],
    Polygon[{{1.109704, 1.521010, 0.011178},{1.108209, 1.522096, 0.012311},{
      1.109100, 1.523845, 0.012311},{1.110858, 1.523274, 0.011178}}],
    Polygon[{{1.108209, 1.522096, 0.012311},{1.106588, 1.523274, 0.013141},{
      1.107195, 1.524464, 0.013141},{1.109100, 1.523845, 0.012311}}],
    Polygon[{{1.106588, 1.523274, 0.013141},{1.104882, 1.524513, 0.013647},{
      1.105189, 1.525115, 0.013647},{1.107195, 1.524464, 0.013141}}],
    Polygon[{{1.105189, 1.525115, -0.013647},{1.107195, 1.524464, -0.013141},{
      1.107404, 1.525783, -0.013141},{1.105295, 1.525783, -0.013647}}],
    Polygon[{{1.107195, 1.524464, -0.013141},{1.109100, 1.523845, -0.012311},{
      1.109407, 1.525783, -0.012311},{1.107404, 1.525783, -0.013141}}],
    Polygon[{{1.109100, 1.523845, -0.012311},{1.110858, 1.523274, -0.011178},{
      1.111255, 1.525783, -0.011178},{1.109407, 1.525783, -0.012311}}],
    Polygon[{{1.110858, 1.523274, -0.011178},{1.112426, 1.522764, -0.009770},{
      1.112904, 1.525783, -0.009770},{1.111255, 1.525783, -0.011178}}],
    Polygon[{{1.112426, 1.522764, -0.009770},{1.113765, 1.522329, -0.008122},{
      1.114312, 1.525783, -0.008122},{1.112904, 1.525783, -0.009770}}],
    Polygon[{{1.113765, 1.522329, -0.008122},{1.114842, 1.521979, -0.006273},{
      1.115445, 1.525783, -0.006273},{1.114312, 1.525783, -0.008122}}],
    Polygon[{{1.114842, 1.521979, -0.006273},{1.115632, 1.521723, -0.004270},{
      1.116275, 1.525783, -0.004270},{1.115445, 1.525783, -0.006273}}],
    Polygon[{{1.115632, 1.521723, -0.004270},{1.116113, 1.521566, -0.002162},{
      1.116781, 1.525783, -0.002162},{1.116275, 1.525783, -0.004270}}],
    Polygon[{{1.116113, 1.521566, -0.002162},{1.116275, 1.521514, 0.000000},{
      1.116951, 1.525783, 0.000000},{1.116781, 1.525783, -0.002162}}],
    Polygon[{{1.116275, 1.521514, 0.000000},{1.116113, 1.521566, 0.002162},{
      1.116781, 1.525783, 0.002162},{1.116951, 1.525783, 0.000000}}],
    Polygon[{{1.116113, 1.521566, 0.002162},{1.115632, 1.521723, 0.004270},{
      1.116275, 1.525783, 0.004270},{1.116781, 1.525783, 0.002162}}],
    Polygon[{{1.115632, 1.521723, 0.004270},{1.114842, 1.521979, 0.006273},{
      1.115445, 1.525783, 0.006273},{1.116275, 1.525783, 0.004270}}],
    Polygon[{{1.114842, 1.521979, 0.006273},{1.113765, 1.522329, 0.008122},{
      1.114312, 1.525783, 0.008122},{1.115445, 1.525783, 0.006273}}],
    Polygon[{{1.113765, 1.522329, 0.008122},{1.112426, 1.522764, 0.009770},{
      1.112904, 1.525783, 0.009770},{1.114312, 1.525783, 0.008122}}],
    Polygon[{{1.112426, 1.522764, 0.009770},{1.110858, 1.523274, 0.011178},{
      1.111255, 1.525783, 0.011178},{1.112904, 1.525783, 0.009770}}],
    Polygon[{{1.110858, 1.523274, 0.011178},{1.109100, 1.523845, 0.012311},{
      1.109407, 1.525783, 0.012311},{1.111255, 1.525783, 0.011178}}],
    Polygon[{{1.109100, 1.523845, 0.012311},{1.107195, 1.524464, 0.013141},{
      1.107404, 1.525783, 0.013141},{1.109407, 1.525783, 0.012311}}],
    Polygon[{{1.107195, 1.524464, 0.013141},{1.105189, 1.525115, 0.013647},{
      1.105295, 1.525783, 0.013647},{1.107404, 1.525783, 0.013141}}],
    Polygon[{{1.073593, 1.587887, -0.009538},{1.075066, 1.587887, -0.009185},{
      1.074920, 1.588809, -0.009185},{1.073519, 1.588353, -0.009538}}],
    Polygon[{{1.075066, 1.587887, -0.009185},{1.076466, 1.587887, -0.008605},{
      1.076252, 1.589241, -0.008605},{1.074920, 1.588809, -0.009185}}],
    Polygon[{{1.076466, 1.587887, -0.008605},{1.077758, 1.587887, -0.007813},{
      1.077481, 1.589641, -0.007813},{1.076252, 1.589241, -0.008605}}],
    Polygon[{{1.077758, 1.587887, -0.007813},{1.078911, 1.587887, -0.006829},{
      1.078577, 1.589997, -0.006829},{1.077481, 1.589641, -0.007813}}],
    Polygon[{{1.078911, 1.587887, -0.006829},{1.079895, 1.587887, -0.005676},{
      1.079513, 1.590301, -0.005676},{1.078577, 1.589997, -0.006829}}],
    Polygon[{{1.079895, 1.587887, -0.005676},{1.080687, 1.587887, -0.004384},{
      1.080266, 1.590546, -0.004384},{1.079513, 1.590301, -0.005676}}],
    Polygon[{{1.080687, 1.587887, -0.004384},{1.081267, 1.587887, -0.002984},{
      1.080817, 1.590725, -0.002984},{1.080266, 1.590546, -0.004384}}],
    Polygon[{{1.081267, 1.587887, -0.002984},{1.081620, 1.587887, -0.001511},{
      1.081154, 1.590834, -0.001511},{1.080817, 1.590725, -0.002984}}],
    Polygon[{{1.081620, 1.587887, -0.001511},{1.081739, 1.587887, 0.000000},{
      1.081267, 1.590871, 0.000000},{1.081154, 1.590834, -0.001511}}],
    Polygon[{{1.081739, 1.587887, 0.000000},{1.081620, 1.587887, 0.001511},{
      1.081154, 1.590834, 0.001511},{1.081267, 1.590871, 0.000000}}],
    Polygon[{{1.081620, 1.587887, 0.001511},{1.081267, 1.587887, 0.002984},{
      1.080817, 1.590725, 0.002984},{1.081154, 1.590834, 0.001511}}],
    Polygon[{{1.081267, 1.587887, 0.002984},{1.080687, 1.587887, 0.004384},{
      1.080266, 1.590546, 0.004384},{1.080817, 1.590725, 0.002984}}],
    Polygon[{{1.080687, 1.587887, 0.004384},{1.079895, 1.587887, 0.005676},{
      1.079513, 1.590301, 0.005676},{1.080266, 1.590546, 0.004384}}],
    Polygon[{{1.079895, 1.587887, 0.005676},{1.078911, 1.587887, 0.006829},{
      1.078577, 1.589997, 0.006829},{1.079513, 1.590301, 0.005676}}],
    Polygon[{{1.078911, 1.587887, 0.006829},{1.077758, 1.587887, 0.007813},{
      1.077481, 1.589641, 0.007813},{1.078577, 1.589997, 0.006829}}],
    Polygon[{{1.077758, 1.587887, 0.007813},{1.076466, 1.587887, 0.008605},{
      1.076252, 1.589241, 0.008605},{1.077481, 1.589641, 0.007813}}],
    Polygon[{{1.076466, 1.587887, 0.008605},{1.075066, 1.587887, 0.009185},{
      1.074920, 1.588809, 0.009185},{1.076252, 1.589241, 0.008605}}],
    Polygon[{{1.075066, 1.587887, 0.009185},{1.073593, 1.587887, 0.009538},{
      1.073519, 1.588353, 0.009538},{1.074920, 1.588809, 0.009185}}],
    Polygon[{{1.073519, 1.588353, -0.009538},{1.074920, 1.588809, -0.009185},{
      1.074496, 1.589641, -0.009185},{1.073304, 1.588775, -0.009538}}],
    Polygon[{{1.074920, 1.588809, -0.009185},{1.076252, 1.589241, -0.008605},{
      1.075629, 1.590464, -0.008605},{1.074496, 1.589641, -0.009185}}],
    Polygon[{{1.076252, 1.589241, -0.008605},{1.077481, 1.589641, -0.007813},{
      1.076674, 1.591223, -0.007813},{1.075629, 1.590464, -0.008605}}],
    Polygon[{{1.077481, 1.589641, -0.007813},{1.078577, 1.589997, -0.006829},{
      1.077607, 1.591900, -0.006829},{1.076674, 1.591223, -0.007813}}],
    Polygon[{{1.078577, 1.589997, -0.006829},{1.079513, 1.590301, -0.005676},{
      1.078403, 1.592479, -0.005676},{1.077607, 1.591900, -0.006829}}],
    Polygon[{{1.079513, 1.590301, -0.005676},{1.080266, 1.590546, -0.004384},{
      1.079043, 1.592944, -0.004384},{1.078403, 1.592479, -0.005676}}],
    Polygon[{{1.080266, 1.590546, -0.004384},{1.080817, 1.590725, -0.002984},{
      1.079513, 1.593285, -0.002984},{1.079043, 1.592944, -0.004384}}],
    Polygon[{{1.080817, 1.590725, -0.002984},{1.081154, 1.590834, -0.001511},{
      1.079799, 1.593493, -0.001511},{1.079513, 1.593285, -0.002984}}],
    Polygon[{{1.081154, 1.590834, -0.001511},{1.081267, 1.590871, 0.000000},{
      1.079895, 1.593563, 0.000000},{1.079799, 1.593493, -0.001511}}],
    Polygon[{{1.081267, 1.590871, 0.000000},{1.081154, 1.590834, 0.001511},{
      1.079799, 1.593493, 0.001511},{1.079895, 1.593563, 0.000000}}],
    Polygon[{{1.081154, 1.590834, 0.001511},{1.080817, 1.590725, 0.002984},{
      1.079513, 1.593285, 0.002984},{1.079799, 1.593493, 0.001511}}],
    Polygon[{{1.080817, 1.590725, 0.002984},{1.080266, 1.590546, 0.004384},{
      1.079043, 1.592944, 0.004384},{1.079513, 1.593285, 0.002984}}],
    Polygon[{{1.080266, 1.590546, 0.004384},{1.079513, 1.590301, 0.005676},{
      1.078403, 1.592479, 0.005676},{1.079043, 1.592944, 0.004384}}],
    Polygon[{{1.079513, 1.590301, 0.005676},{1.078577, 1.589997, 0.006829},{
      1.077607, 1.591900, 0.006829},{1.078403, 1.592479, 0.005676}}],
    Polygon[{{1.078577, 1.589997, 0.006829},{1.077481, 1.589641, 0.007813},{
      1.076674, 1.591223, 0.007813},{1.077607, 1.591900, 0.006829}}],
    Polygon[{{1.077481, 1.589641, 0.007813},{1.076252, 1.589241, 0.008605},{
      1.075629, 1.590464, 0.008605},{1.076674, 1.591223, 0.007813}}],
    Polygon[{{1.076252, 1.589241, 0.008605},{1.074920, 1.588809, 0.009185},{
      1.074496, 1.589641, 0.009185},{1.075629, 1.590464, 0.008605}}],
    Polygon[{{1.074920, 1.588809, 0.009185},{1.073519, 1.588353, 0.009538},{
      1.073304, 1.588775, 0.009538},{1.074496, 1.589641, 0.009185}}],
    Polygon[{{1.073304, 1.588775, -0.009538},{1.074496, 1.589641, -0.009185},{
      1.073836, 1.590301, -0.009185},{1.072970, 1.589109, -0.009538}}],
    Polygon[{{1.074496, 1.589641, -0.009185},{1.075629, 1.590464, -0.008605},{
      1.074659, 1.591434, -0.008605},{1.073836, 1.590301, -0.009185}}],
    Polygon[{{1.075629, 1.590464, -0.008605},{1.076674, 1.591223, -0.007813},{
      1.075419, 1.592479, -0.007813},{1.074659, 1.591434, -0.008605}}],
    Polygon[{{1.076674, 1.591223, -0.007813},{1.077607, 1.591900, -0.006829},{
      1.076096, 1.593411, -0.006829},{1.075419, 1.592479, -0.007813}}],
    Polygon[{{1.077607, 1.591900, -0.006829},{1.078403, 1.592479, -0.005676},{
      1.076674, 1.594207, -0.005676},{1.076096, 1.593411, -0.006829}}],
    Polygon[{{1.078403, 1.592479, -0.005676},{1.079043, 1.592944, -0.004384},{
      1.077140, 1.594848, -0.004384},{1.076674, 1.594207, -0.005676}}],
    Polygon[{{1.079043, 1.592944, -0.004384},{1.079513, 1.593285, -0.002984},{
      1.077481, 1.595317, -0.002984},{1.077140, 1.594848, -0.004384}}],
    Polygon[{{1.079513, 1.593285, -0.002984},{1.079799, 1.593493, -0.001511},{
      1.077689, 1.595603, -0.001511},{1.077481, 1.595317, -0.002984}}],
    Polygon[{{1.079799, 1.593493, -0.001511},{1.079895, 1.593563, 0.000000},{
      1.077758, 1.595699, 0.000000},{1.077689, 1.595603, -0.001511}}],
    Polygon[{{1.079895, 1.593563, 0.000000},{1.079799, 1.593493, 0.001511},{
      1.077689, 1.595603, 0.001511},{1.077758, 1.595699, 0.000000}}],
    Polygon[{{1.079799, 1.593493, 0.001511},{1.079513, 1.593285, 0.002984},{
      1.077481, 1.595317, 0.002984},{1.077689, 1.595603, 0.001511}}],
    Polygon[{{1.079513, 1.593285, 0.002984},{1.079043, 1.592944, 0.004384},{
      1.077140, 1.594848, 0.004384},{1.077481, 1.595317, 0.002984}}],
    Polygon[{{1.079043, 1.592944, 0.004384},{1.078403, 1.592479, 0.005676},{
      1.076674, 1.594207, 0.005676},{1.077140, 1.594848, 0.004384}}],
    Polygon[{{1.078403, 1.592479, 0.005676},{1.077607, 1.591900, 0.006829},{
      1.076096, 1.593411, 0.006829},{1.076674, 1.594207, 0.005676}}],
    Polygon[{{1.077607, 1.591900, 0.006829},{1.076674, 1.591223, 0.007813},{
      1.075419, 1.592479, 0.007813},{1.076096, 1.593411, 0.006829}}],
    Polygon[{{1.076674, 1.591223, 0.007813},{1.075629, 1.590464, 0.008605},{
      1.074659, 1.591434, 0.008605},{1.075419, 1.592479, 0.007813}}],
    Polygon[{{1.075629, 1.590464, 0.008605},{1.074496, 1.589641, 0.009185},{
      1.073836, 1.590301, 0.009185},{1.074659, 1.591434, 0.008605}}],
    Polygon[{{1.074496, 1.589641, 0.009185},{1.073304, 1.588775, 0.009538},{
      1.072970, 1.589109, 0.009538},{1.073836, 1.590301, 0.009185}}],
    Polygon[{{1.072970, 1.589109, -0.009538},{1.073836, 1.590301, -0.009185},{
      1.073004, 1.590725, -0.009185},{1.072549, 1.589323, -0.009538}}],
    Polygon[{{1.073836, 1.590301, -0.009185},{1.074659, 1.591434, -0.008605},{
      1.073437, 1.592056, -0.008605},{1.073004, 1.590725, -0.009185}}],
    Polygon[{{1.074659, 1.591434, -0.008605},{1.075419, 1.592479, -0.007813},{
      1.073836, 1.593285, -0.007813},{1.073437, 1.592056, -0.008605}}],
    Polygon[{{1.075419, 1.592479, -0.007813},{1.076096, 1.593411, -0.006829},{
      1.074192, 1.594381, -0.006829},{1.073836, 1.593285, -0.007813}}],
    Polygon[{{1.076096, 1.593411, -0.006829},{1.076674, 1.594207, -0.005676},{
      1.074496, 1.595317, -0.005676},{1.074192, 1.594381, -0.006829}}],
    Polygon[{{1.076674, 1.594207, -0.005676},{1.077140, 1.594848, -0.004384},{
      1.074741, 1.596070, -0.004384},{1.074496, 1.595317, -0.005676}}],
    Polygon[{{1.077140, 1.594848, -0.004384},{1.077481, 1.595317, -0.002984},{
      1.074920, 1.596622, -0.002984},{1.074741, 1.596070, -0.004384}}],
    Polygon[{{1.077481, 1.595317, -0.002984},{1.077689, 1.595603, -0.001511},{
      1.075030, 1.596958, -0.001511},{1.074920, 1.596622, -0.002984}}],
    Polygon[{{1.077689, 1.595603, -0.001511},{1.077758, 1.595699, 0.000000},{
      1.075066, 1.597071, 0.000000},{1.075030, 1.596958, -0.001511}}],
    Polygon[{{1.077758, 1.595699, 0.000000},{1.077689, 1.595603, 0.001511},{
      1.075030, 1.596958, 0.001511},{1.075066, 1.597071, 0.000000}}],
    Polygon[{{1.077689, 1.595603, 0.001511},{1.077481, 1.595317, 0.002984},{
      1.074920, 1.596622, 0.002984},{1.075030, 1.596958, 0.001511}}],
    Polygon[{{1.077481, 1.595317, 0.002984},{1.077140, 1.594848, 0.004384},{
      1.074741, 1.596070, 0.004384},{1.074920, 1.596622, 0.002984}}],
    Polygon[{{1.077140, 1.594848, 0.004384},{1.076674, 1.594207, 0.005676},{
      1.074496, 1.595317, 0.005676},{1.074741, 1.596070, 0.004384}}],
    Polygon[{{1.076674, 1.594207, 0.005676},{1.076096, 1.593411, 0.006829},{
      1.074192, 1.594381, 0.006829},{1.074496, 1.595317, 0.005676}}],
    Polygon[{{1.076096, 1.593411, 0.006829},{1.075419, 1.592479, 0.007813},{
      1.073836, 1.593285, 0.007813},{1.074192, 1.594381, 0.006829}}],
    Polygon[{{1.075419, 1.592479, 0.007813},{1.074659, 1.591434, 0.008605},{
      1.073437, 1.592056, 0.008605},{1.073836, 1.593285, 0.007813}}],
    Polygon[{{1.074659, 1.591434, 0.008605},{1.073836, 1.590301, 0.009185},{
      1.073004, 1.590725, 0.009185},{1.073437, 1.592056, 0.008605}}],
    Polygon[{{1.073836, 1.590301, 0.009185},{1.072970, 1.589109, 0.009538},{
      1.072549, 1.589323, 0.009538},{1.073004, 1.590725, 0.009185}}],
    Polygon[{{1.072549, 1.589323, -0.009538},{1.073004, 1.590725, -0.009185},{
      1.072082, 1.590871, -0.009185},{1.072082, 1.589397, -0.009538}}],
    Polygon[{{1.073004, 1.590725, -0.009185},{1.073437, 1.592056, -0.008605},{
      1.072082, 1.592271, -0.008605},{1.072082, 1.590871, -0.009185}}],
    Polygon[{{1.073437, 1.592056, -0.008605},{1.073836, 1.593285, -0.007813},{
      1.072082, 1.593563, -0.007813},{1.072082, 1.592271, -0.008605}}],
    Polygon[{{1.073836, 1.593285, -0.007813},{1.074192, 1.594381, -0.006829},{
      1.072082, 1.594715, -0.006829},{1.072082, 1.593563, -0.007813}}],
    Polygon[{{1.074192, 1.594381, -0.006829},{1.074496, 1.595317, -0.005676},{
      1.072082, 1.595699, -0.005676},{1.072082, 1.594715, -0.006829}}],
    Polygon[{{1.074496, 1.595317, -0.005676},{1.074741, 1.596070, -0.004384},{
      1.072082, 1.596491, -0.004384},{1.072082, 1.595699, -0.005676}}],
    Polygon[{{1.074741, 1.596070, -0.004384},{1.074920, 1.596622, -0.002984},{
      1.072082, 1.597071, -0.002984},{1.072082, 1.596491, -0.004384}}],
    Polygon[{{1.074920, 1.596622, -0.002984},{1.075030, 1.596958, -0.001511},{
      1.072082, 1.597425, -0.001511},{1.072082, 1.597071, -0.002984}}],
    Polygon[{{1.075030, 1.596958, -0.001511},{1.075066, 1.597071, 0.000000},{
      1.072082, 1.597544, 0.000000},{1.072082, 1.597425, -0.001511}}],
    Polygon[{{1.075066, 1.597071, 0.000000},{1.075030, 1.596958, 0.001511},{
      1.072082, 1.597425, 0.001511},{1.072082, 1.597544, 0.000000}}],
    Polygon[{{1.075030, 1.596958, 0.001511},{1.074920, 1.596622, 0.002984},{
      1.072082, 1.597071, 0.002984},{1.072082, 1.597425, 0.001511}}],
    Polygon[{{1.074920, 1.596622, 0.002984},{1.074741, 1.596070, 0.004384},{
      1.072082, 1.596491, 0.004384},{1.072082, 1.597071, 0.002984}}],
    Polygon[{{1.074741, 1.596070, 0.004384},{1.074496, 1.595317, 0.005676},{
      1.072082, 1.595699, 0.005676},{1.072082, 1.596491, 0.004384}}],
    Polygon[{{1.074496, 1.595317, 0.005676},{1.074192, 1.594381, 0.006829},{
      1.072082, 1.594715, 0.006829},{1.072082, 1.595699, 0.005676}}],
    Polygon[{{1.074192, 1.594381, 0.006829},{1.073836, 1.593285, 0.007813},{
      1.072082, 1.593563, 0.007813},{1.072082, 1.594715, 0.006829}}],
    Polygon[{{1.073836, 1.593285, 0.007813},{1.073437, 1.592056, 0.008605},{
      1.072082, 1.592271, 0.008605},{1.072082, 1.593563, 0.007813}}],
    Polygon[{{1.073437, 1.592056, 0.008605},{1.073004, 1.590725, 0.009185},{
      1.072082, 1.590871, 0.009185},{1.072082, 1.592271, 0.008605}}],
    Polygon[{{1.073004, 1.590725, 0.009185},{1.072549, 1.589323, 0.009538},{
      1.072082, 1.589397, 0.009538},{1.072082, 1.590871, 0.009185}}],
    Polygon[{{1.072082, 1.589397, -0.009538},{1.072082, 1.590871, -0.009185},{
      1.071160, 1.590725, -0.009185},{1.071615, 1.589323, -0.009538}}],
    Polygon[{{1.072082, 1.590871, -0.009185},{1.072082, 1.592271, -0.008605},{
      1.070727, 1.592056, -0.008605},{1.071160, 1.590725, -0.009185}}],
    Polygon[{{1.072082, 1.592271, -0.008605},{1.072082, 1.593563, -0.007813},{
      1.070328, 1.593285, -0.007813},{1.070727, 1.592056, -0.008605}}],
    Polygon[{{1.072082, 1.593563, -0.007813},{1.072082, 1.594715, -0.006829},{
      1.069972, 1.594381, -0.006829},{1.070328, 1.593285, -0.007813}}],
    Polygon[{{1.072082, 1.594715, -0.006829},{1.072082, 1.595699, -0.005676},{
      1.069668, 1.595317, -0.005676},{1.069972, 1.594381, -0.006829}}],
    Polygon[{{1.072082, 1.595699, -0.005676},{1.072082, 1.596491, -0.004384},{
      1.069423, 1.596070, -0.004384},{1.069668, 1.595317, -0.005676}}],
    Polygon[{{1.072082, 1.596491, -0.004384},{1.072082, 1.597071, -0.002984},{
      1.069244, 1.596622, -0.002984},{1.069423, 1.596070, -0.004384}}],
    Polygon[{{1.072082, 1.597071, -0.002984},{1.072082, 1.597425, -0.001511},{
      1.069135, 1.596958, -0.001511},{1.069244, 1.596622, -0.002984}}],
    Polygon[{{1.072082, 1.597425, -0.001511},{1.072082, 1.597544, 0.000000},{
      1.069098, 1.597071, 0.000000},{1.069135, 1.596958, -0.001511}}],
    Polygon[{{1.072082, 1.597544, 0.000000},{1.072082, 1.597425, 0.001511},{
      1.069135, 1.596958, 0.001511},{1.069098, 1.597071, 0.000000}}],
    Polygon[{{1.072082, 1.597425, 0.001511},{1.072082, 1.597071, 0.002984},{
      1.069244, 1.596622, 0.002984},{1.069135, 1.596958, 0.001511}}],
    Polygon[{{1.072082, 1.597071, 0.002984},{1.072082, 1.596491, 0.004384},{
      1.069423, 1.596070, 0.004384},{1.069244, 1.596622, 0.002984}}],
    Polygon[{{1.072082, 1.596491, 0.004384},{1.072082, 1.595699, 0.005676},{
      1.069668, 1.595317, 0.005676},{1.069423, 1.596070, 0.004384}}],
    Polygon[{{1.072082, 1.595699, 0.005676},{1.072082, 1.594715, 0.006829},{
      1.069972, 1.594381, 0.006829},{1.069668, 1.595317, 0.005676}}],
    Polygon[{{1.072082, 1.594715, 0.006829},{1.072082, 1.593563, 0.007813},{
      1.070328, 1.593285, 0.007813},{1.069972, 1.594381, 0.006829}}],
    Polygon[{{1.072082, 1.593563, 0.007813},{1.072082, 1.592271, 0.008605},{
      1.070727, 1.592056, 0.008605},{1.070328, 1.593285, 0.007813}}],
    Polygon[{{1.072082, 1.592271, 0.008605},{1.072082, 1.590871, 0.009185},{
      1.071160, 1.590725, 0.009185},{1.070727, 1.592056, 0.008605}}],
    Polygon[{{1.072082, 1.590871, 0.009185},{1.072082, 1.589397, 0.009538},{
      1.071615, 1.589323, 0.009538},{1.071160, 1.590725, 0.009185}}],
    Polygon[{{1.071615, 1.589323, -0.009538},{1.071160, 1.590725, -0.009185},{
      1.070328, 1.590301, -0.009185},{1.071194, 1.589109, -0.009538}}],
    Polygon[{{1.071160, 1.590725, -0.009185},{1.070727, 1.592056, -0.008605},{
      1.069505, 1.591434, -0.008605},{1.070328, 1.590301, -0.009185}}],
    Polygon[{{1.070727, 1.592056, -0.008605},{1.070328, 1.593285, -0.007813},{
      1.068746, 1.592479, -0.007813},{1.069505, 1.591434, -0.008605}}],
    Polygon[{{1.070328, 1.593285, -0.007813},{1.069972, 1.594381, -0.006829},{
      1.068068, 1.593411, -0.006829},{1.068746, 1.592479, -0.007813}}],
    Polygon[{{1.069972, 1.594381, -0.006829},{1.069668, 1.595317, -0.005676},{
      1.067490, 1.594207, -0.005676},{1.068068, 1.593411, -0.006829}}],
    Polygon[{{1.069668, 1.595317, -0.005676},{1.069423, 1.596070, -0.004384},{
      1.067024, 1.594848, -0.004384},{1.067490, 1.594207, -0.005676}}],
    Polygon[{{1.069423, 1.596070, -0.004384},{1.069244, 1.596622, -0.002984},{
      1.066684, 1.595317, -0.002984},{1.067024, 1.594848, -0.004384}}],
    Polygon[{{1.069244, 1.596622, -0.002984},{1.069135, 1.596958, -0.001511},{
      1.066476, 1.595603, -0.001511},{1.066684, 1.595317, -0.002984}}],
    Polygon[{{1.069135, 1.596958, -0.001511},{1.069098, 1.597071, 0.000000},{
      1.066406, 1.595699, 0.000000},{1.066476, 1.595603, -0.001511}}],
    Polygon[{{1.069098, 1.597071, 0.000000},{1.069135, 1.596958, 0.001511},{
      1.066476, 1.595603, 0.001511},{1.066406, 1.595699, 0.000000}}],
    Polygon[{{1.069135, 1.596958, 0.001511},{1.069244, 1.596622, 0.002984},{
      1.066684, 1.595317, 0.002984},{1.066476, 1.595603, 0.001511}}],
    Polygon[{{1.069244, 1.596622, 0.002984},{1.069423, 1.596070, 0.004384},{
      1.067024, 1.594848, 0.004384},{1.066684, 1.595317, 0.002984}}],
    Polygon[{{1.069423, 1.596070, 0.004384},{1.069668, 1.595317, 0.005676},{
      1.067490, 1.594207, 0.005676},{1.067024, 1.594848, 0.004384}}],
    Polygon[{{1.069668, 1.595317, 0.005676},{1.069972, 1.594381, 0.006829},{
      1.068068, 1.593411, 0.006829},{1.067490, 1.594207, 0.005676}}],
    Polygon[{{1.069972, 1.594381, 0.006829},{1.070328, 1.593285, 0.007813},{
      1.068746, 1.592479, 0.007813},{1.068068, 1.593411, 0.006829}}],
    Polygon[{{1.070328, 1.593285, 0.007813},{1.070727, 1.592056, 0.008605},{
      1.069505, 1.591434, 0.008605},{1.068746, 1.592479, 0.007813}}],
    Polygon[{{1.070727, 1.592056, 0.008605},{1.071160, 1.590725, 0.009185},{
      1.070328, 1.590301, 0.009185},{1.069505, 1.591434, 0.008605}}],
    Polygon[{{1.071160, 1.590725, 0.009185},{1.071615, 1.589323, 0.009538},{
      1.071194, 1.589109, 0.009538},{1.070328, 1.590301, 0.009185}}],
    Polygon[{{1.071194, 1.589109, -0.009538},{1.070328, 1.590301, -0.009185},{
      1.069668, 1.589641, -0.009185},{1.070860, 1.588775, -0.009538}}],
    Polygon[{{1.070328, 1.590301, -0.009185},{1.069505, 1.591434, -0.008605},{
      1.068535, 1.590464, -0.008605},{1.069668, 1.589641, -0.009185}}],
    Polygon[{{1.069505, 1.591434, -0.008605},{1.068746, 1.592479, -0.007813},{
      1.067490, 1.591223, -0.007813},{1.068535, 1.590464, -0.008605}}],
    Polygon[{{1.068746, 1.592479, -0.007813},{1.068068, 1.593411, -0.006829},{
      1.066558, 1.591900, -0.006829},{1.067490, 1.591223, -0.007813}}],
    Polygon[{{1.068068, 1.593411, -0.006829},{1.067490, 1.594207, -0.005676},{
      1.065761, 1.592479, -0.005676},{1.066558, 1.591900, -0.006829}}],
    Polygon[{{1.067490, 1.594207, -0.005676},{1.067024, 1.594848, -0.004384},{
      1.065121, 1.592944, -0.004384},{1.065761, 1.592479, -0.005676}}],
    Polygon[{{1.067024, 1.594848, -0.004384},{1.066684, 1.595317, -0.002984},{
      1.064652, 1.593285, -0.002984},{1.065121, 1.592944, -0.004384}}],
    Polygon[{{1.066684, 1.595317, -0.002984},{1.066476, 1.595603, -0.001511},{
      1.064366, 1.593493, -0.001511},{1.064652, 1.593285, -0.002984}}],
    Polygon[{{1.066476, 1.595603, -0.001511},{1.066406, 1.595699, 0.000000},{
      1.064269, 1.593563, 0.000000},{1.064366, 1.593493, -0.001511}}],
    Polygon[{{1.066406, 1.595699, 0.000000},{1.066476, 1.595603, 0.001511},{
      1.064366, 1.593493, 0.001511},{1.064269, 1.593563, 0.000000}}],
    Polygon[{{1.066476, 1.595603, 0.001511},{1.066684, 1.595317, 0.002984},{
      1.064652, 1.593285, 0.002984},{1.064366, 1.593493, 0.001511}}],
    Polygon[{{1.066684, 1.595317, 0.002984},{1.067024, 1.594848, 0.004384},{
      1.065121, 1.592944, 0.004384},{1.064652, 1.593285, 0.002984}}],
    Polygon[{{1.067024, 1.594848, 0.004384},{1.067490, 1.594207, 0.005676},{
      1.065761, 1.592479, 0.005676},{1.065121, 1.592944, 0.004384}}],
    Polygon[{{1.067490, 1.594207, 0.005676},{1.068068, 1.593411, 0.006829},{
      1.066558, 1.591900, 0.006829},{1.065761, 1.592479, 0.005676}}],
    Polygon[{{1.068068, 1.593411, 0.006829},{1.068746, 1.592479, 0.007813},{
      1.067490, 1.591223, 0.007813},{1.066558, 1.591900, 0.006829}}],
    Polygon[{{1.068746, 1.592479, 0.007813},{1.069505, 1.591434, 0.008605},{
      1.068535, 1.590464, 0.008605},{1.067490, 1.591223, 0.007813}}],
    Polygon[{{1.069505, 1.591434, 0.008605},{1.070328, 1.590301, 0.009185},{
      1.069668, 1.589641, 0.009185},{1.068535, 1.590464, 0.008605}}],
    Polygon[{{1.070328, 1.590301, 0.009185},{1.071194, 1.589109, 0.009538},{
      1.070860, 1.588775, 0.009538},{1.069668, 1.589641, 0.009185}}],
    Polygon[{{1.070860, 1.588775, -0.009538},{1.069668, 1.589641, -0.009185},{
      1.069244, 1.588809, -0.009185},{1.070645, 1.588353, -0.009538}}],
    Polygon[{{1.069668, 1.589641, -0.009185},{1.068535, 1.590464, -0.008605},{
      1.067912, 1.589241, -0.008605},{1.069244, 1.588809, -0.009185}}],
    Polygon[{{1.068535, 1.590464, -0.008605},{1.067490, 1.591223, -0.007813},{
      1.066684, 1.589641, -0.007813},{1.067912, 1.589241, -0.008605}}],
    Polygon[{{1.067490, 1.591223, -0.007813},{1.066558, 1.591900, -0.006829},{
      1.065588, 1.589997, -0.006829},{1.066684, 1.589641, -0.007813}}],
    Polygon[{{1.066558, 1.591900, -0.006829},{1.065761, 1.592479, -0.005676},{
      1.064652, 1.590301, -0.005676},{1.065588, 1.589997, -0.006829}}],
    Polygon[{{1.065761, 1.592479, -0.005676},{1.065121, 1.592944, -0.004384},{
      1.063899, 1.590546, -0.004384},{1.064652, 1.590301, -0.005676}}],
    Polygon[{{1.065121, 1.592944, -0.004384},{1.064652, 1.593285, -0.002984},{
      1.063347, 1.590725, -0.002984},{1.063899, 1.590546, -0.004384}}],
    Polygon[{{1.064652, 1.593285, -0.002984},{1.064366, 1.593493, -0.001511},{
      1.063011, 1.590834, -0.001511},{1.063347, 1.590725, -0.002984}}],
    Polygon[{{1.064366, 1.593493, -0.001511},{1.064269, 1.593563, 0.000000},{
      1.062898, 1.590871, 0.000000},{1.063011, 1.590834, -0.001511}}],
    Polygon[{{1.064269, 1.593563, 0.000000},{1.064366, 1.593493, 0.001511},{
      1.063011, 1.590834, 0.001511},{1.062898, 1.590871, 0.000000}}],
    Polygon[{{1.064366, 1.593493, 0.001511},{1.064652, 1.593285, 0.002984},{
      1.063347, 1.590725, 0.002984},{1.063011, 1.590834, 0.001511}}],
    Polygon[{{1.064652, 1.593285, 0.002984},{1.065121, 1.592944, 0.004384},{
      1.063899, 1.590546, 0.004384},{1.063347, 1.590725, 0.002984}}],
    Polygon[{{1.065121, 1.592944, 0.004384},{1.065761, 1.592479, 0.005676},{
      1.064652, 1.590301, 0.005676},{1.063899, 1.590546, 0.004384}}],
    Polygon[{{1.065761, 1.592479, 0.005676},{1.066558, 1.591900, 0.006829},{
      1.065588, 1.589997, 0.006829},{1.064652, 1.590301, 0.005676}}],
    Polygon[{{1.066558, 1.591900, 0.006829},{1.067490, 1.591223, 0.007813},{
      1.066684, 1.589641, 0.007813},{1.065588, 1.589997, 0.006829}}],
    Polygon[{{1.067490, 1.591223, 0.007813},{1.068535, 1.590464, 0.008605},{
      1.067912, 1.589241, 0.008605},{1.066684, 1.589641, 0.007813}}],
    Polygon[{{1.068535, 1.590464, 0.008605},{1.069668, 1.589641, 0.009185},{
      1.069244, 1.588809, 0.009185},{1.067912, 1.589241, 0.008605}}],
    Polygon[{{1.069668, 1.589641, 0.009185},{1.070860, 1.588775, 0.009538},{
      1.070645, 1.588353, 0.009538},{1.069244, 1.588809, 0.009185}}],
    Polygon[{{1.070645, 1.588353, -0.009538},{1.069244, 1.588809, -0.009185},{
      1.069098, 1.587887, -0.009185},{1.070571, 1.587887, -0.009538}}],
    Polygon[{{1.069244, 1.588809, -0.009185},{1.067912, 1.589241, -0.008605},{
      1.067698, 1.587887, -0.008605},{1.069098, 1.587887, -0.009185}}],
    Polygon[{{1.067912, 1.589241, -0.008605},{1.066684, 1.589641, -0.007813},{
      1.066406, 1.587887, -0.007813},{1.067698, 1.587887, -0.008605}}],
    Polygon[{{1.066684, 1.589641, -0.007813},{1.065588, 1.589997, -0.006829},{
      1.065253, 1.587887, -0.006829},{1.066406, 1.587887, -0.007813}}],
    Polygon[{{1.065588, 1.589997, -0.006829},{1.064652, 1.590301, -0.005676},{
      1.064269, 1.587887, -0.005676},{1.065253, 1.587887, -0.006829}}],
    Polygon[{{1.064652, 1.590301, -0.005676},{1.063899, 1.590546, -0.004384},{
      1.063478, 1.587887, -0.004384},{1.064269, 1.587887, -0.005676}}],
    Polygon[{{1.063899, 1.590546, -0.004384},{1.063347, 1.590725, -0.002984},{
      1.062898, 1.587887, -0.002984},{1.063478, 1.587887, -0.004384}}],
    Polygon[{{1.063347, 1.590725, -0.002984},{1.063011, 1.590834, -0.001511},{
      1.062544, 1.587887, -0.001511},{1.062898, 1.587887, -0.002984}}],
    Polygon[{{1.063011, 1.590834, -0.001511},{1.062898, 1.590871, 0.000000},{
      1.062425, 1.587887, 0.000000},{1.062544, 1.587887, -0.001511}}],
    Polygon[{{1.062898, 1.590871, 0.000000},{1.063011, 1.590834, 0.001511},{
      1.062544, 1.587887, 0.001511},{1.062425, 1.587887, 0.000000}}],
    Polygon[{{1.063011, 1.590834, 0.001511},{1.063347, 1.590725, 0.002984},{
      1.062898, 1.587887, 0.002984},{1.062544, 1.587887, 0.001511}}],
    Polygon[{{1.063347, 1.590725, 0.002984},{1.063899, 1.590546, 0.004384},{
      1.063478, 1.587887, 0.004384},{1.062898, 1.587887, 0.002984}}],
    Polygon[{{1.063899, 1.590546, 0.004384},{1.064652, 1.590301, 0.005676},{
      1.064269, 1.587887, 0.005676},{1.063478, 1.587887, 0.004384}}],
    Polygon[{{1.064652, 1.590301, 0.005676},{1.065588, 1.589997, 0.006829},{
      1.065253, 1.587887, 0.006829},{1.064269, 1.587887, 0.005676}}],
    Polygon[{{1.065588, 1.589997, 0.006829},{1.066684, 1.589641, 0.007813},{
      1.066406, 1.587887, 0.007813},{1.065253, 1.587887, 0.006829}}],
    Polygon[{{1.066684, 1.589641, 0.007813},{1.067912, 1.589241, 0.008605},{
      1.067698, 1.587887, 0.008605},{1.066406, 1.587887, 0.007813}}],
    Polygon[{{1.067912, 1.589241, 0.008605},{1.069244, 1.588809, 0.009185},{
      1.069098, 1.587887, 0.009185},{1.067698, 1.587887, 0.008605}}],
    Polygon[{{1.069244, 1.588809, 0.009185},{1.070645, 1.588353, 0.009538},{
      1.070571, 1.587887, 0.009538},{1.069098, 1.587887, 0.009185}}],
    Polygon[{{1.070571, 1.587887, -0.009538},{1.069098, 1.587887, -0.009185},{
      1.069244, 1.586964, -0.009185},{1.070645, 1.587420, -0.009538}}],
    Polygon[{{1.069098, 1.587887, -0.009185},{1.067698, 1.587887, -0.008605},{
      1.067912, 1.586532, -0.008605},{1.069244, 1.586964, -0.009185}}],
    Polygon[{{1.067698, 1.587887, -0.008605},{1.066406, 1.587887, -0.007813},{
      1.066684, 1.586133, -0.007813},{1.067912, 1.586532, -0.008605}}],
    Polygon[{{1.066406, 1.587887, -0.007813},{1.065253, 1.587887, -0.006829},{
      1.065588, 1.585776, -0.006829},{1.066684, 1.586133, -0.007813}}],
    Polygon[{{1.065253, 1.587887, -0.006829},{1.064269, 1.587887, -0.005676},{
      1.064652, 1.585472, -0.005676},{1.065588, 1.585776, -0.006829}}],
    Polygon[{{1.064269, 1.587887, -0.005676},{1.063478, 1.587887, -0.004384},{
      1.063899, 1.585228, -0.004384},{1.064652, 1.585472, -0.005676}}],
    Polygon[{{1.063478, 1.587887, -0.004384},{1.062898, 1.587887, -0.002984},{
      1.063347, 1.585048, -0.002984},{1.063899, 1.585228, -0.004384}}],
    Polygon[{{1.062898, 1.587887, -0.002984},{1.062544, 1.587887, -0.001511},{
      1.063011, 1.584939, -0.001511},{1.063347, 1.585048, -0.002984}}],
    Polygon[{{1.062544, 1.587887, -0.001511},{1.062425, 1.587887, 0.000000},{
      1.062898, 1.584902, 0.000000},{1.063011, 1.584939, -0.001511}}],
    Polygon[{{1.062425, 1.587887, 0.000000},{1.062544, 1.587887, 0.001511},{
      1.063011, 1.584939, 0.001511},{1.062898, 1.584902, 0.000000}}],
    Polygon[{{1.062544, 1.587887, 0.001511},{1.062898, 1.587887, 0.002984},{
      1.063347, 1.585048, 0.002984},{1.063011, 1.584939, 0.001511}}],
    Polygon[{{1.062898, 1.587887, 0.002984},{1.063478, 1.587887, 0.004384},{
      1.063899, 1.585228, 0.004384},{1.063347, 1.585048, 0.002984}}],
    Polygon[{{1.063478, 1.587887, 0.004384},{1.064269, 1.587887, 0.005676},{
      1.064652, 1.585472, 0.005676},{1.063899, 1.585228, 0.004384}}],
    Polygon[{{1.064269, 1.587887, 0.005676},{1.065253, 1.587887, 0.006829},{
      1.065588, 1.585776, 0.006829},{1.064652, 1.585472, 0.005676}}],
    Polygon[{{1.065253, 1.587887, 0.006829},{1.066406, 1.587887, 0.007813},{
      1.066684, 1.586133, 0.007813},{1.065588, 1.585776, 0.006829}}],
    Polygon[{{1.066406, 1.587887, 0.007813},{1.067698, 1.587887, 0.008605},{
      1.067912, 1.586532, 0.008605},{1.066684, 1.586133, 0.007813}}],
    Polygon[{{1.067698, 1.587887, 0.008605},{1.069098, 1.587887, 0.009185},{
      1.069244, 1.586964, 0.009185},{1.067912, 1.586532, 0.008605}}],
    Polygon[{{1.069098, 1.587887, 0.009185},{1.070571, 1.587887, 0.009538},{
      1.070645, 1.587420, 0.009538},{1.069244, 1.586964, 0.009185}}],
    Polygon[{{1.070645, 1.587420, -0.009538},{1.069244, 1.586964, -0.009185},{
      1.069668, 1.586133, -0.009185},{1.070860, 1.586999, -0.009538}}],
    Polygon[{{1.069244, 1.586964, -0.009185},{1.067912, 1.586532, -0.008605},{
      1.068535, 1.585310, -0.008605},{1.069668, 1.586133, -0.009185}}],
    Polygon[{{1.067912, 1.586532, -0.008605},{1.066684, 1.586133, -0.007813},{
      1.067490, 1.584550, -0.007813},{1.068535, 1.585310, -0.008605}}],
    Polygon[{{1.066684, 1.586133, -0.007813},{1.065588, 1.585776, -0.006829},{
      1.066558, 1.583873, -0.006829},{1.067490, 1.584550, -0.007813}}],
    Polygon[{{1.065588, 1.585776, -0.006829},{1.064652, 1.585472, -0.005676},{
      1.065761, 1.583294, -0.005676},{1.066558, 1.583873, -0.006829}}],
    Polygon[{{1.064652, 1.585472, -0.005676},{1.063899, 1.585228, -0.004384},{
      1.065121, 1.582829, -0.004384},{1.065761, 1.583294, -0.005676}}],
    Polygon[{{1.063899, 1.585228, -0.004384},{1.063347, 1.585048, -0.002984},{
      1.064652, 1.582488, -0.002984},{1.065121, 1.582829, -0.004384}}],
    Polygon[{{1.063347, 1.585048, -0.002984},{1.063011, 1.584939, -0.001511},{
      1.064366, 1.582280, -0.001511},{1.064652, 1.582488, -0.002984}}],
    Polygon[{{1.063011, 1.584939, -0.001511},{1.062898, 1.584902, 0.000000},{
      1.064269, 1.582210, 0.000000},{1.064366, 1.582280, -0.001511}}],
    Polygon[{{1.062898, 1.584902, 0.000000},{1.063011, 1.584939, 0.001511},{
      1.064366, 1.582280, 0.001511},{1.064269, 1.582210, 0.000000}}],
    Polygon[{{1.063011, 1.584939, 0.001511},{1.063347, 1.585048, 0.002984},{
      1.064652, 1.582488, 0.002984},{1.064366, 1.582280, 0.001511}}],
    Polygon[{{1.063347, 1.585048, 0.002984},{1.063899, 1.585228, 0.004384},{
      1.065121, 1.582829, 0.004384},{1.064652, 1.582488, 0.002984}}],
    Polygon[{{1.063899, 1.585228, 0.004384},{1.064652, 1.585472, 0.005676},{
      1.065761, 1.583294, 0.005676},{1.065121, 1.582829, 0.004384}}],
    Polygon[{{1.064652, 1.585472, 0.005676},{1.065588, 1.585776, 0.006829},{
      1.066558, 1.583873, 0.006829},{1.065761, 1.583294, 0.005676}}],
    Polygon[{{1.065588, 1.585776, 0.006829},{1.066684, 1.586133, 0.007813},{
      1.067490, 1.584550, 0.007813},{1.066558, 1.583873, 0.006829}}],
    Polygon[{{1.066684, 1.586133, 0.007813},{1.067912, 1.586532, 0.008605},{
      1.068535, 1.585310, 0.008605},{1.067490, 1.584550, 0.007813}}],
    Polygon[{{1.067912, 1.586532, 0.008605},{1.069244, 1.586964, 0.009185},{
      1.069668, 1.586133, 0.009185},{1.068535, 1.585310, 0.008605}}],
    Polygon[{{1.069244, 1.586964, 0.009185},{1.070645, 1.587420, 0.009538},{
      1.070860, 1.586999, 0.009538},{1.069668, 1.586133, 0.009185}}],
    Polygon[{{1.070860, 1.586999, -0.009538},{1.069668, 1.586133, -0.009185},{
      1.070328, 1.585472, -0.009185},{1.071194, 1.586664, -0.009538}}],
    Polygon[{{1.069668, 1.586133, -0.009185},{1.068535, 1.585310, -0.008605},{
      1.069505, 1.584340, -0.008605},{1.070328, 1.585472, -0.009185}}],
    Polygon[{{1.068535, 1.585310, -0.008605},{1.067490, 1.584550, -0.007813},{
      1.068746, 1.583294, -0.007813},{1.069505, 1.584340, -0.008605}}],
    Polygon[{{1.067490, 1.584550, -0.007813},{1.066558, 1.583873, -0.006829},{
      1.068068, 1.582362, -0.006829},{1.068746, 1.583294, -0.007813}}],
    Polygon[{{1.066558, 1.583873, -0.006829},{1.065761, 1.583294, -0.005676},{
      1.067490, 1.581566, -0.005676},{1.068068, 1.582362, -0.006829}}],
    Polygon[{{1.065761, 1.583294, -0.005676},{1.065121, 1.582829, -0.004384},{
      1.067024, 1.580925, -0.004384},{1.067490, 1.581566, -0.005676}}],
    Polygon[{{1.065121, 1.582829, -0.004384},{1.064652, 1.582488, -0.002984},{
      1.066684, 1.580456, -0.002984},{1.067024, 1.580925, -0.004384}}],
    Polygon[{{1.064652, 1.582488, -0.002984},{1.064366, 1.582280, -0.001511},{
      1.066476, 1.580170, -0.001511},{1.066684, 1.580456, -0.002984}}],
    Polygon[{{1.064366, 1.582280, -0.001511},{1.064269, 1.582210, 0.000000},{
      1.066406, 1.580074, 0.000000},{1.066476, 1.580170, -0.001511}}],
    Polygon[{{1.064269, 1.582210, 0.000000},{1.064366, 1.582280, 0.001511},{
      1.066476, 1.580170, 0.001511},{1.066406, 1.580074, 0.000000}}],
    Polygon[{{1.064366, 1.582280, 0.001511},{1.064652, 1.582488, 0.002984},{
      1.066684, 1.580456, 0.002984},{1.066476, 1.580170, 0.001511}}],
    Polygon[{{1.064652, 1.582488, 0.002984},{1.065121, 1.582829, 0.004384},{
      1.067024, 1.580925, 0.004384},{1.066684, 1.580456, 0.002984}}],
    Polygon[{{1.065121, 1.582829, 0.004384},{1.065761, 1.583294, 0.005676},{
      1.067490, 1.581566, 0.005676},{1.067024, 1.580925, 0.004384}}],
    Polygon[{{1.065761, 1.583294, 0.005676},{1.066558, 1.583873, 0.006829},{
      1.068068, 1.582362, 0.006829},{1.067490, 1.581566, 0.005676}}],
    Polygon[{{1.066558, 1.583873, 0.006829},{1.067490, 1.584550, 0.007813},{
      1.068746, 1.583294, 0.007813},{1.068068, 1.582362, 0.006829}}],
    Polygon[{{1.067490, 1.584550, 0.007813},{1.068535, 1.585310, 0.008605},{
      1.069505, 1.584340, 0.008605},{1.068746, 1.583294, 0.007813}}],
    Polygon[{{1.068535, 1.585310, 0.008605},{1.069668, 1.586133, 0.009185},{
      1.070328, 1.585472, 0.009185},{1.069505, 1.584340, 0.008605}}],
    Polygon[{{1.069668, 1.586133, 0.009185},{1.070860, 1.586999, 0.009538},{
      1.071194, 1.586664, 0.009538},{1.070328, 1.585472, 0.009185}}],
    Polygon[{{1.071194, 1.586664, -0.009538},{1.070328, 1.585472, -0.009185},{
      1.071160, 1.585048, -0.009185},{1.071615, 1.586450, -0.009538}}],
    Polygon[{{1.070328, 1.585472, -0.009185},{1.069505, 1.584340, -0.008605},{
      1.070727, 1.583717, -0.008605},{1.071160, 1.585048, -0.009185}}],
    Polygon[{{1.069505, 1.584340, -0.008605},{1.068746, 1.583294, -0.007813},{
      1.070328, 1.582488, -0.007813},{1.070727, 1.583717, -0.008605}}],
    Polygon[{{1.068746, 1.583294, -0.007813},{1.068068, 1.582362, -0.006829},{
      1.069972, 1.581392, -0.006829},{1.070328, 1.582488, -0.007813}}],
    Polygon[{{1.068068, 1.582362, -0.006829},{1.067490, 1.581566, -0.005676},{
      1.069668, 1.580456, -0.005676},{1.069972, 1.581392, -0.006829}}],
    Polygon[{{1.067490, 1.581566, -0.005676},{1.067024, 1.580925, -0.004384},{
      1.069423, 1.579703, -0.004384},{1.069668, 1.580456, -0.005676}}],
    Polygon[{{1.067024, 1.580925, -0.004384},{1.066684, 1.580456, -0.002984},{
      1.069244, 1.579152, -0.002984},{1.069423, 1.579703, -0.004384}}],
    Polygon[{{1.066684, 1.580456, -0.002984},{1.066476, 1.580170, -0.001511},{
      1.069135, 1.578815, -0.001511},{1.069244, 1.579152, -0.002984}}],
    Polygon[{{1.066476, 1.580170, -0.001511},{1.066406, 1.580074, 0.000000},{
      1.069098, 1.578702, 0.000000},{1.069135, 1.578815, -0.001511}}],
    Polygon[{{1.066406, 1.580074, 0.000000},{1.066476, 1.580170, 0.001511},{
      1.069135, 1.578815, 0.001511},{1.069098, 1.578702, 0.000000}}],
    Polygon[{{1.066476, 1.580170, 0.001511},{1.066684, 1.580456, 0.002984},{
      1.069244, 1.579152, 0.002984},{1.069135, 1.578815, 0.001511}}],
    Polygon[{{1.066684, 1.580456, 0.002984},{1.067024, 1.580925, 0.004384},{
      1.069423, 1.579703, 0.004384},{1.069244, 1.579152, 0.002984}}],
    Polygon[{{1.067024, 1.580925, 0.004384},{1.067490, 1.581566, 0.005676},{
      1.069668, 1.580456, 0.005676},{1.069423, 1.579703, 0.004384}}],
    Polygon[{{1.067490, 1.581566, 0.005676},{1.068068, 1.582362, 0.006829},{
      1.069972, 1.581392, 0.006829},{1.069668, 1.580456, 0.005676}}],
    Polygon[{{1.068068, 1.582362, 0.006829},{1.068746, 1.583294, 0.007813},{
      1.070328, 1.582488, 0.007813},{1.069972, 1.581392, 0.006829}}],
    Polygon[{{1.068746, 1.583294, 0.007813},{1.069505, 1.584340, 0.008605},{
      1.070727, 1.583717, 0.008605},{1.070328, 1.582488, 0.007813}}],
    Polygon[{{1.069505, 1.584340, 0.008605},{1.070328, 1.585472, 0.009185},{
      1.071160, 1.585048, 0.009185},{1.070727, 1.583717, 0.008605}}],
    Polygon[{{1.070328, 1.585472, 0.009185},{1.071194, 1.586664, 0.009538},{
      1.071615, 1.586450, 0.009538},{1.071160, 1.585048, 0.009185}}],
    Polygon[{{1.071615, 1.586450, -0.009538},{1.071160, 1.585048, -0.009185},{
      1.072082, 1.584902, -0.009185},{1.072082, 1.586376, -0.009538}}],
    Polygon[{{1.071160, 1.585048, -0.009185},{1.070727, 1.583717, -0.008605},{
      1.072082, 1.583502, -0.008605},{1.072082, 1.584902, -0.009185}}],
    Polygon[{{1.070727, 1.583717, -0.008605},{1.070328, 1.582488, -0.007813},{
      1.072082, 1.582210, -0.007813},{1.072082, 1.583502, -0.008605}}],
    Polygon[{{1.070328, 1.582488, -0.007813},{1.069972, 1.581392, -0.006829},{
      1.072082, 1.581058, -0.006829},{1.072082, 1.582210, -0.007813}}],
    Polygon[{{1.069972, 1.581392, -0.006829},{1.069668, 1.580456, -0.005676},{
      1.072082, 1.580074, -0.005676},{1.072082, 1.581058, -0.006829}}],
    Polygon[{{1.069668, 1.580456, -0.005676},{1.069423, 1.579703, -0.004384},{
      1.072082, 1.579282, -0.004384},{1.072082, 1.580074, -0.005676}}],
    Polygon[{{1.069423, 1.579703, -0.004384},{1.069244, 1.579152, -0.002984},{
      1.072082, 1.578702, -0.002984},{1.072082, 1.579282, -0.004384}}],
    Polygon[{{1.069244, 1.579152, -0.002984},{1.069135, 1.578815, -0.001511},{
      1.072082, 1.578348, -0.001511},{1.072082, 1.578702, -0.002984}}],
    Polygon[{{1.069135, 1.578815, -0.001511},{1.069098, 1.578702, 0.000000},{
      1.072082, 1.578229, 0.000000},{1.072082, 1.578348, -0.001511}}],
    Polygon[{{1.069098, 1.578702, 0.000000},{1.069135, 1.578815, 0.001511},{
      1.072082, 1.578348, 0.001511},{1.072082, 1.578229, 0.000000}}],
    Polygon[{{1.069135, 1.578815, 0.001511},{1.069244, 1.579152, 0.002984},{
      1.072082, 1.578702, 0.002984},{1.072082, 1.578348, 0.001511}}],
    Polygon[{{1.069244, 1.579152, 0.002984},{1.069423, 1.579703, 0.004384},{
      1.072082, 1.579282, 0.004384},{1.072082, 1.578702, 0.002984}}],
    Polygon[{{1.069423, 1.579703, 0.004384},{1.069668, 1.580456, 0.005676},{
      1.072082, 1.580074, 0.005676},{1.072082, 1.579282, 0.004384}}],
    Polygon[{{1.069668, 1.580456, 0.005676},{1.069972, 1.581392, 0.006829},{
      1.072082, 1.581058, 0.006829},{1.072082, 1.580074, 0.005676}}],
    Polygon[{{1.069972, 1.581392, 0.006829},{1.070328, 1.582488, 0.007813},{
      1.072082, 1.582210, 0.007813},{1.072082, 1.581058, 0.006829}}],
    Polygon[{{1.070328, 1.582488, 0.007813},{1.070727, 1.583717, 0.008605},{
      1.072082, 1.583502, 0.008605},{1.072082, 1.582210, 0.007813}}],
    Polygon[{{1.070727, 1.583717, 0.008605},{1.071160, 1.585048, 0.009185},{
      1.072082, 1.584902, 0.009185},{1.072082, 1.583502, 0.008605}}],
    Polygon[{{1.071160, 1.585048, 0.009185},{1.071615, 1.586450, 0.009538},{
      1.072082, 1.586376, 0.009538},{1.072082, 1.584902, 0.009185}}],
    Polygon[{{1.072082, 1.586376, -0.009538},{1.072082, 1.584902, -0.009185},{
      1.073004, 1.585048, -0.009185},{1.072549, 1.586450, -0.009538}}],
    Polygon[{{1.072082, 1.584902, -0.009185},{1.072082, 1.583502, -0.008605},{
      1.073437, 1.583717, -0.008605},{1.073004, 1.585048, -0.009185}}],
    Polygon[{{1.072082, 1.583502, -0.008605},{1.072082, 1.582210, -0.007813},{
      1.073836, 1.582488, -0.007813},{1.073437, 1.583717, -0.008605}}],
    Polygon[{{1.072082, 1.582210, -0.007813},{1.072082, 1.581058, -0.006829},{
      1.074192, 1.581392, -0.006829},{1.073836, 1.582488, -0.007813}}],
    Polygon[{{1.072082, 1.581058, -0.006829},{1.072082, 1.580074, -0.005676},{
      1.074496, 1.580456, -0.005676},{1.074192, 1.581392, -0.006829}}],
    Polygon[{{1.072082, 1.580074, -0.005676},{1.072082, 1.579282, -0.004384},{
      1.074741, 1.579703, -0.004384},{1.074496, 1.580456, -0.005676}}],
    Polygon[{{1.072082, 1.579282, -0.004384},{1.072082, 1.578702, -0.002984},{
      1.074920, 1.579152, -0.002984},{1.074741, 1.579703, -0.004384}}],
    Polygon[{{1.072082, 1.578702, -0.002984},{1.072082, 1.578348, -0.001511},{
      1.075030, 1.578815, -0.001511},{1.074920, 1.579152, -0.002984}}],
    Polygon[{{1.072082, 1.578348, -0.001511},{1.072082, 1.578229, 0.000000},{
      1.075066, 1.578702, 0.000000},{1.075030, 1.578815, -0.001511}}],
    Polygon[{{1.072082, 1.578229, 0.000000},{1.072082, 1.578348, 0.001511},{
      1.075030, 1.578815, 0.001511},{1.075066, 1.578702, 0.000000}}],
    Polygon[{{1.072082, 1.578348, 0.001511},{1.072082, 1.578702, 0.002984},{
      1.074920, 1.579152, 0.002984},{1.075030, 1.578815, 0.001511}}],
    Polygon[{{1.072082, 1.578702, 0.002984},{1.072082, 1.579282, 0.004384},{
      1.074741, 1.579703, 0.004384},{1.074920, 1.579152, 0.002984}}],
    Polygon[{{1.072082, 1.579282, 0.004384},{1.072082, 1.580074, 0.005676},{
      1.074496, 1.580456, 0.005676},{1.074741, 1.579703, 0.004384}}],
    Polygon[{{1.072082, 1.580074, 0.005676},{1.072082, 1.581058, 0.006829},{
      1.074192, 1.581392, 0.006829},{1.074496, 1.580456, 0.005676}}],
    Polygon[{{1.072082, 1.581058, 0.006829},{1.072082, 1.582210, 0.007813},{
      1.073836, 1.582488, 0.007813},{1.074192, 1.581392, 0.006829}}],
    Polygon[{{1.072082, 1.582210, 0.007813},{1.072082, 1.583502, 0.008605},{
      1.073437, 1.583717, 0.008605},{1.073836, 1.582488, 0.007813}}],
    Polygon[{{1.072082, 1.583502, 0.008605},{1.072082, 1.584902, 0.009185},{
      1.073004, 1.585048, 0.009185},{1.073437, 1.583717, 0.008605}}],
    Polygon[{{1.072082, 1.584902, 0.009185},{1.072082, 1.586376, 0.009538},{
      1.072549, 1.586450, 0.009538},{1.073004, 1.585048, 0.009185}}],
    Polygon[{{1.072549, 1.586450, -0.009538},{1.073004, 1.585048, -0.009185},{
      1.073836, 1.585472, -0.009185},{1.072970, 1.586664, -0.009538}}],
    Polygon[{{1.073004, 1.585048, -0.009185},{1.073437, 1.583717, -0.008605},{
      1.074659, 1.584340, -0.008605},{1.073836, 1.585472, -0.009185}}],
    Polygon[{{1.073437, 1.583717, -0.008605},{1.073836, 1.582488, -0.007813},{
      1.075419, 1.583294, -0.007813},{1.074659, 1.584340, -0.008605}}],
    Polygon[{{1.073836, 1.582488, -0.007813},{1.074192, 1.581392, -0.006829},{
      1.076096, 1.582362, -0.006829},{1.075419, 1.583294, -0.007813}}],
    Polygon[{{1.074192, 1.581392, -0.006829},{1.074496, 1.580456, -0.005676},{
      1.076674, 1.581566, -0.005676},{1.076096, 1.582362, -0.006829}}],
    Polygon[{{1.074496, 1.580456, -0.005676},{1.074741, 1.579703, -0.004384},{
      1.077140, 1.580925, -0.004384},{1.076674, 1.581566, -0.005676}}],
    Polygon[{{1.074741, 1.579703, -0.004384},{1.074920, 1.579152, -0.002984},{
      1.077481, 1.580456, -0.002984},{1.077140, 1.580925, -0.004384}}],
    Polygon[{{1.074920, 1.579152, -0.002984},{1.075030, 1.578815, -0.001511},{
      1.077689, 1.580170, -0.001511},{1.077481, 1.580456, -0.002984}}],
    Polygon[{{1.075030, 1.578815, -0.001511},{1.075066, 1.578702, 0.000000},{
      1.077758, 1.580074, 0.000000},{1.077689, 1.580170, -0.001511}}],
    Polygon[{{1.075066, 1.578702, 0.000000},{1.075030, 1.578815, 0.001511},{
      1.077689, 1.580170, 0.001511},{1.077758, 1.580074, 0.000000}}],
    Polygon[{{1.075030, 1.578815, 0.001511},{1.074920, 1.579152, 0.002984},{
      1.077481, 1.580456, 0.002984},{1.077689, 1.580170, 0.001511}}],
    Polygon[{{1.074920, 1.579152, 0.002984},{1.074741, 1.579703, 0.004384},{
      1.077140, 1.580925, 0.004384},{1.077481, 1.580456, 0.002984}}],
    Polygon[{{1.074741, 1.579703, 0.004384},{1.074496, 1.580456, 0.005676},{
      1.076674, 1.581566, 0.005676},{1.077140, 1.580925, 0.004384}}],
    Polygon[{{1.074496, 1.580456, 0.005676},{1.074192, 1.581392, 0.006829},{
      1.076096, 1.582362, 0.006829},{1.076674, 1.581566, 0.005676}}],
    Polygon[{{1.074192, 1.581392, 0.006829},{1.073836, 1.582488, 0.007813},{
      1.075419, 1.583294, 0.007813},{1.076096, 1.582362, 0.006829}}],
    Polygon[{{1.073836, 1.582488, 0.007813},{1.073437, 1.583717, 0.008605},{
      1.074659, 1.584340, 0.008605},{1.075419, 1.583294, 0.007813}}],
    Polygon[{{1.073437, 1.583717, 0.008605},{1.073004, 1.585048, 0.009185},{
      1.073836, 1.585472, 0.009185},{1.074659, 1.584340, 0.008605}}],
    Polygon[{{1.073004, 1.585048, 0.009185},{1.072549, 1.586450, 0.009538},{
      1.072970, 1.586664, 0.009538},{1.073836, 1.585472, 0.009185}}],
    Polygon[{{1.072970, 1.586664, -0.009538},{1.073836, 1.585472, -0.009185},{
      1.074496, 1.586133, -0.009185},{1.073304, 1.586999, -0.009538}}],
    Polygon[{{1.073836, 1.585472, -0.009185},{1.074659, 1.584340, -0.008605},{
      1.075629, 1.585310, -0.008605},{1.074496, 1.586133, -0.009185}}],
    Polygon[{{1.074659, 1.584340, -0.008605},{1.075419, 1.583294, -0.007813},{
      1.076674, 1.584550, -0.007813},{1.075629, 1.585310, -0.008605}}],
    Polygon[{{1.075419, 1.583294, -0.007813},{1.076096, 1.582362, -0.006829},{
      1.077607, 1.583873, -0.006829},{1.076674, 1.584550, -0.007813}}],
    Polygon[{{1.076096, 1.582362, -0.006829},{1.076674, 1.581566, -0.005676},{
      1.078403, 1.583294, -0.005676},{1.077607, 1.583873, -0.006829}}],
    Polygon[{{1.076674, 1.581566, -0.005676},{1.077140, 1.580925, -0.004384},{
      1.079043, 1.582829, -0.004384},{1.078403, 1.583294, -0.005676}}],
    Polygon[{{1.077140, 1.580925, -0.004384},{1.077481, 1.580456, -0.002984},{
      1.079513, 1.582488, -0.002984},{1.079043, 1.582829, -0.004384}}],
    Polygon[{{1.077481, 1.580456, -0.002984},{1.077689, 1.580170, -0.001511},{
      1.079799, 1.582280, -0.001511},{1.079513, 1.582488, -0.002984}}],
    Polygon[{{1.077689, 1.580170, -0.001511},{1.077758, 1.580074, 0.000000},{
      1.079895, 1.582210, 0.000000},{1.079799, 1.582280, -0.001511}}],
    Polygon[{{1.077758, 1.580074, 0.000000},{1.077689, 1.580170, 0.001511},{
      1.079799, 1.582280, 0.001511},{1.079895, 1.582210, 0.000000}}],
    Polygon[{{1.077689, 1.580170, 0.001511},{1.077481, 1.580456, 0.002984},{
      1.079513, 1.582488, 0.002984},{1.079799, 1.582280, 0.001511}}],
    Polygon[{{1.077481, 1.580456, 0.002984},{1.077140, 1.580925, 0.004384},{
      1.079043, 1.582829, 0.004384},{1.079513, 1.582488, 0.002984}}],
    Polygon[{{1.077140, 1.580925, 0.004384},{1.076674, 1.581566, 0.005676},{
      1.078403, 1.583294, 0.005676},{1.079043, 1.582829, 0.004384}}],
    Polygon[{{1.076674, 1.581566, 0.005676},{1.076096, 1.582362, 0.006829},{
      1.077607, 1.583873, 0.006829},{1.078403, 1.583294, 0.005676}}],
    Polygon[{{1.076096, 1.582362, 0.006829},{1.075419, 1.583294, 0.007813},{
      1.076674, 1.584550, 0.007813},{1.077607, 1.583873, 0.006829}}],
    Polygon[{{1.075419, 1.583294, 0.007813},{1.074659, 1.584340, 0.008605},{
      1.075629, 1.585310, 0.008605},{1.076674, 1.584550, 0.007813}}],
    Polygon[{{1.074659, 1.584340, 0.008605},{1.073836, 1.585472, 0.009185},{
      1.074496, 1.586133, 0.009185},{1.075629, 1.585310, 0.008605}}],
    Polygon[{{1.073836, 1.585472, 0.009185},{1.072970, 1.586664, 0.009538},{
      1.073304, 1.586999, 0.009538},{1.074496, 1.586133, 0.009185}}],
    Polygon[{{1.073304, 1.586999, -0.009538},{1.074496, 1.586133, -0.009185},{
      1.074920, 1.586964, -0.009185},{1.073519, 1.587420, -0.009538}}],
    Polygon[{{1.074496, 1.586133, -0.009185},{1.075629, 1.585310, -0.008605},{
      1.076252, 1.586532, -0.008605},{1.074920, 1.586964, -0.009185}}],
    Polygon[{{1.075629, 1.585310, -0.008605},{1.076674, 1.584550, -0.007813},{
      1.077481, 1.586133, -0.007813},{1.076252, 1.586532, -0.008605}}],
    Polygon[{{1.076674, 1.584550, -0.007813},{1.077607, 1.583873, -0.006829},{
      1.078577, 1.585776, -0.006829},{1.077481, 1.586133, -0.007813}}],
    Polygon[{{1.077607, 1.583873, -0.006829},{1.078403, 1.583294, -0.005676},{
      1.079513, 1.585472, -0.005676},{1.078577, 1.585776, -0.006829}}],
    Polygon[{{1.078403, 1.583294, -0.005676},{1.079043, 1.582829, -0.004384},{
      1.080266, 1.585228, -0.004384},{1.079513, 1.585472, -0.005676}}],
    Polygon[{{1.079043, 1.582829, -0.004384},{1.079513, 1.582488, -0.002984},{
      1.080817, 1.585048, -0.002984},{1.080266, 1.585228, -0.004384}}],
    Polygon[{{1.079513, 1.582488, -0.002984},{1.079799, 1.582280, -0.001511},{
      1.081154, 1.584939, -0.001511},{1.080817, 1.585048, -0.002984}}],
    Polygon[{{1.079799, 1.582280, -0.001511},{1.079895, 1.582210, 0.000000},{
      1.081267, 1.584902, 0.000000},{1.081154, 1.584939, -0.001511}}],
    Polygon[{{1.079895, 1.582210, 0.000000},{1.079799, 1.582280, 0.001511},{
      1.081154, 1.584939, 0.001511},{1.081267, 1.584902, 0.000000}}],
    Polygon[{{1.079799, 1.582280, 0.001511},{1.079513, 1.582488, 0.002984},{
      1.080817, 1.585048, 0.002984},{1.081154, 1.584939, 0.001511}}],
    Polygon[{{1.079513, 1.582488, 0.002984},{1.079043, 1.582829, 0.004384},{
      1.080266, 1.585228, 0.004384},{1.080817, 1.585048, 0.002984}}],
    Polygon[{{1.079043, 1.582829, 0.004384},{1.078403, 1.583294, 0.005676},{
      1.079513, 1.585472, 0.005676},{1.080266, 1.585228, 0.004384}}],
    Polygon[{{1.078403, 1.583294, 0.005676},{1.077607, 1.583873, 0.006829},{
      1.078577, 1.585776, 0.006829},{1.079513, 1.585472, 0.005676}}],
    Polygon[{{1.077607, 1.583873, 0.006829},{1.076674, 1.584550, 0.007813},{
      1.077481, 1.586133, 0.007813},{1.078577, 1.585776, 0.006829}}],
    Polygon[{{1.076674, 1.584550, 0.007813},{1.075629, 1.585310, 0.008605},{
      1.076252, 1.586532, 0.008605},{1.077481, 1.586133, 0.007813}}],
    Polygon[{{1.075629, 1.585310, 0.008605},{1.074496, 1.586133, 0.009185},{
      1.074920, 1.586964, 0.009185},{1.076252, 1.586532, 0.008605}}],
    Polygon[{{1.074496, 1.586133, 0.009185},{1.073304, 1.586999, 0.009538},{
      1.073519, 1.587420, 0.009538},{1.074920, 1.586964, 0.009185}}],
    Polygon[{{1.073519, 1.587420, -0.009538},{1.074920, 1.586964, -0.009185},{
      1.075066, 1.587887, -0.009185},{1.073593, 1.587887, -0.009538}}],
    Polygon[{{1.074920, 1.586964, -0.009185},{1.076252, 1.586532, -0.008605},{
      1.076466, 1.587887, -0.008605},{1.075066, 1.587887, -0.009185}}],
    Polygon[{{1.076252, 1.586532, -0.008605},{1.077481, 1.586133, -0.007813},{
      1.077758, 1.587887, -0.007813},{1.076466, 1.587887, -0.008605}}],
    Polygon[{{1.077481, 1.586133, -0.007813},{1.078577, 1.585776, -0.006829},{
      1.078911, 1.587887, -0.006829},{1.077758, 1.587887, -0.007813}}],
    Polygon[{{1.078577, 1.585776, -0.006829},{1.079513, 1.585472, -0.005676},{
      1.079895, 1.587887, -0.005676},{1.078911, 1.587887, -0.006829}}],
    Polygon[{{1.079513, 1.585472, -0.005676},{1.080266, 1.585228, -0.004384},{
      1.080687, 1.587887, -0.004384},{1.079895, 1.587887, -0.005676}}],
    Polygon[{{1.080266, 1.585228, -0.004384},{1.080817, 1.585048, -0.002984},{
      1.081267, 1.587887, -0.002984},{1.080687, 1.587887, -0.004384}}],
    Polygon[{{1.080817, 1.585048, -0.002984},{1.081154, 1.584939, -0.001511},{
      1.081620, 1.587887, -0.001511},{1.081267, 1.587887, -0.002984}}],
    Polygon[{{1.081154, 1.584939, -0.001511},{1.081267, 1.584902, 0.000000},{
      1.081739, 1.587887, 0.000000},{1.081620, 1.587887, -0.001511}}],
    Polygon[{{1.081267, 1.584902, 0.000000},{1.081154, 1.584939, 0.001511},{
      1.081620, 1.587887, 0.001511},{1.081739, 1.587887, 0.000000}}],
    Polygon[{{1.081154, 1.584939, 0.001511},{1.080817, 1.585048, 0.002984},{
      1.081267, 1.587887, 0.002984},{1.081620, 1.587887, 0.001511}}],
    Polygon[{{1.080817, 1.585048, 0.002984},{1.080266, 1.585228, 0.004384},{
      1.080687, 1.587887, 0.004384},{1.081267, 1.587887, 0.002984}}],
    Polygon[{{1.080266, 1.585228, 0.004384},{1.079513, 1.585472, 0.005676},{
      1.079895, 1.587887, 0.005676},{1.080687, 1.587887, 0.004384}}],
    Polygon[{{1.079513, 1.585472, 0.005676},{1.078577, 1.585776, 0.006829},{
      1.078911, 1.587887, 0.006829},{1.079895, 1.587887, 0.005676}}],
    Polygon[{{1.078577, 1.585776, 0.006829},{1.077481, 1.586133, 0.007813},{
      1.077758, 1.587887, 0.007813},{1.078911, 1.587887, 0.006829}}],
    Polygon[{{1.077481, 1.586133, 0.007813},{1.076252, 1.586532, 0.008605},{
      1.076466, 1.587887, 0.008605},{1.077758, 1.587887, 0.007813}}],
    Polygon[{{1.076252, 1.586532, 0.008605},{1.074920, 1.586964, 0.009185},{
      1.075066, 1.587887, 0.009185},{1.076466, 1.587887, 0.008605}}],
    Polygon[{{1.074920, 1.586964, 0.009185},{1.073519, 1.587420, 0.009538},{
      1.073593, 1.587887, 0.009538},{1.075066, 1.587887, 0.009185}}],
    Polygon[{{1.042156, 1.543797, -0.008290},{1.043437, 1.543797, -0.007983},{
      1.043310, 1.544599, -0.007983},{1.042092, 1.544203, -0.008290}}],
    Polygon[{{1.043437, 1.543797, -0.007983},{1.044654, 1.543797, -0.007479},{
      1.044468, 1.544975, -0.007479},{1.043310, 1.544599, -0.007983}}],
    Polygon[{{1.044654, 1.543797, -0.007479},{1.045777, 1.543797, -0.006791},{
      1.045536, 1.545322, -0.006791},{1.044468, 1.544975, -0.007479}}],
    Polygon[{{1.045777, 1.543797, -0.006791},{1.046779, 1.543797, -0.005935},{
      1.046488, 1.545632, -0.005935},{1.045536, 1.545322, -0.006791}}],
    Polygon[{{1.046779, 1.543797, -0.005935},{1.047634, 1.543797, -0.004934},{
      1.047302, 1.545896, -0.004934},{1.046488, 1.545632, -0.005935}}],
    Polygon[{{1.047634, 1.543797, -0.004934},{1.048322, 1.543797, -0.003811},{
      1.047956, 1.546109, -0.003811},{1.047302, 1.545896, -0.004934}}],
    Polygon[{{1.048322, 1.543797, -0.003811},{1.048826, 1.543797, -0.002594},{
      1.048436, 1.546264, -0.002594},{1.047956, 1.546109, -0.003811}}],
    Polygon[{{1.048826, 1.543797, -0.002594},{1.049134, 1.543797, -0.001313},{
      1.048728, 1.546359, -0.001313},{1.048436, 1.546264, -0.002594}}],
    Polygon[{{1.049134, 1.543797, -0.001313},{1.049237, 1.543797, 0.000000},{
      1.048826, 1.546391, 0.000000},{1.048728, 1.546359, -0.001313}}],
    Polygon[{{1.049237, 1.543797, 0.000000},{1.049134, 1.543797, 0.001313},{
      1.048728, 1.546359, 0.001313},{1.048826, 1.546391, 0.000000}}],
    Polygon[{{1.049134, 1.543797, 0.001313},{1.048826, 1.543797, 0.002594},{
      1.048436, 1.546264, 0.002594},{1.048728, 1.546359, 0.001313}}],
    Polygon[{{1.048826, 1.543797, 0.002594},{1.048322, 1.543797, 0.003811},{
      1.047956, 1.546109, 0.003811},{1.048436, 1.546264, 0.002594}}],
    Polygon[{{1.048322, 1.543797, 0.003811},{1.047634, 1.543797, 0.004934},{
      1.047302, 1.545896, 0.004934},{1.047956, 1.546109, 0.003811}}],
    Polygon[{{1.047634, 1.543797, 0.004934},{1.046779, 1.543797, 0.005935},{
      1.046488, 1.545632, 0.005935},{1.047302, 1.545896, 0.004934}}],
    Polygon[{{1.046779, 1.543797, 0.005935},{1.045777, 1.543797, 0.006791},{
      1.045536, 1.545322, 0.006791},{1.046488, 1.545632, 0.005935}}],
    Polygon[{{1.045777, 1.543797, 0.006791},{1.044654, 1.543797, 0.007479},{
      1.044468, 1.544975, 0.007479},{1.045536, 1.545322, 0.006791}}],
    Polygon[{{1.044654, 1.543797, 0.007479},{1.043437, 1.543797, 0.007983},{
      1.043310, 1.544599, 0.007983},{1.044468, 1.544975, 0.007479}}],
    Polygon[{{1.043437, 1.543797, 0.007983},{1.042156, 1.543797, 0.008290},{
      1.042092, 1.544203, 0.008290},{1.043310, 1.544599, 0.007983}}],
    Polygon[{{1.042092, 1.544203, -0.008290},{1.043310, 1.544599, -0.007983},{
      1.042942, 1.545322, -0.007983},{1.041906, 1.544569, -0.008290}}],
    Polygon[{{1.043310, 1.544599, -0.007983},{1.044468, 1.544975, -0.007479},{
      1.043926, 1.546037, -0.007479},{1.042942, 1.545322, -0.007983}}],
    Polygon[{{1.044468, 1.544975, -0.007479},{1.045536, 1.545322, -0.006791},{
      1.044835, 1.546697, -0.006791},{1.043926, 1.546037, -0.007479}}],
    Polygon[{{1.045536, 1.545322, -0.006791},{1.046488, 1.545632, -0.005935},{
      1.045645, 1.547286, -0.005935},{1.044835, 1.546697, -0.006791}}],
    Polygon[{{1.046488, 1.545632, -0.005935},{1.047302, 1.545896, -0.004934},{
      1.046337, 1.547789, -0.004934},{1.045645, 1.547286, -0.005935}}],
    Polygon[{{1.047302, 1.545896, -0.004934},{1.047956, 1.546109, -0.003811},{
      1.046894, 1.548193, -0.003811},{1.046337, 1.547789, -0.004934}}],
    Polygon[{{1.047956, 1.546109, -0.003811},{1.048436, 1.546264, -0.002594},{
      1.047302, 1.548490, -0.002594},{1.046894, 1.548193, -0.003811}}],
    Polygon[{{1.048436, 1.546264, -0.002594},{1.048728, 1.546359, -0.001313},{
      1.047550, 1.548670, -0.001313},{1.047302, 1.548490, -0.002594}}],
    Polygon[{{1.048728, 1.546359, -0.001313},{1.048826, 1.546391, 0.000000},{
      1.047634, 1.548731, 0.000000},{1.047550, 1.548670, -0.001313}}],
    Polygon[{{1.048826, 1.546391, 0.000000},{1.048728, 1.546359, 0.001313},{
      1.047550, 1.548670, 0.001313},{1.047634, 1.548731, 0.000000}}],
    Polygon[{{1.048728, 1.546359, 0.001313},{1.048436, 1.546264, 0.002594},{
      1.047302, 1.548490, 0.002594},{1.047550, 1.548670, 0.001313}}],
    Polygon[{{1.048436, 1.546264, 0.002594},{1.047956, 1.546109, 0.003811},{
      1.046894, 1.548193, 0.003811},{1.047302, 1.548490, 0.002594}}],
    Polygon[{{1.047956, 1.546109, 0.003811},{1.047302, 1.545896, 0.004934},{
      1.046337, 1.547789, 0.004934},{1.046894, 1.548193, 0.003811}}],
    Polygon[{{1.047302, 1.545896, 0.004934},{1.046488, 1.545632, 0.005935},{
      1.045645, 1.547286, 0.005935},{1.046337, 1.547789, 0.004934}}],
    Polygon[{{1.046488, 1.545632, 0.005935},{1.045536, 1.545322, 0.006791},{
      1.044835, 1.546697, 0.006791},{1.045645, 1.547286, 0.005935}}],
    Polygon[{{1.045536, 1.545322, 0.006791},{1.044468, 1.544975, 0.007479},{
      1.043926, 1.546037, 0.007479},{1.044835, 1.546697, 0.006791}}],
    Polygon[{{1.044468, 1.544975, 0.007479},{1.043310, 1.544599, 0.007983},{
      1.042942, 1.545322, 0.007983},{1.043926, 1.546037, 0.007479}}],
    Polygon[{{1.043310, 1.544599, 0.007983},{1.042092, 1.544203, 0.008290},{
      1.041906, 1.544569, 0.008290},{1.042942, 1.545322, 0.007983}}],
    Polygon[{{1.041906, 1.544569, -0.008290},{1.042942, 1.545322, -0.007983},{
      1.042368, 1.545896, -0.007983},{1.041615, 1.544860, -0.008290}}],
    Polygon[{{1.042942, 1.545322, -0.007983},{1.043926, 1.546037, -0.007479},{
      1.043083, 1.546880, -0.007479},{1.042368, 1.545896, -0.007983}}],
    Polygon[{{1.043926, 1.546037, -0.007479},{1.044835, 1.546697, -0.006791},{
      1.043743, 1.547789, -0.006791},{1.043083, 1.546880, -0.007479}}],
    Polygon[{{1.044835, 1.546697, -0.006791},{1.045645, 1.547286, -0.005935},{
      1.044332, 1.548599, -0.005935},{1.043743, 1.547789, -0.006791}}],
    Polygon[{{1.045645, 1.547286, -0.005935},{1.046337, 1.547789, -0.004934},{
      1.044835, 1.549291, -0.004934},{1.044332, 1.548599, -0.005935}}],
    Polygon[{{1.046337, 1.547789, -0.004934},{1.046894, 1.548193, -0.003811},{
      1.045239, 1.549848, -0.003811},{1.044835, 1.549291, -0.004934}}],
    Polygon[{{1.046894, 1.548193, -0.003811},{1.047302, 1.548490, -0.002594},{
      1.045536, 1.550256, -0.002594},{1.045239, 1.549848, -0.003811}}],
    Polygon[{{1.047302, 1.548490, -0.002594},{1.047550, 1.548670, -0.001313},{
      1.045716, 1.550504, -0.001313},{1.045536, 1.550256, -0.002594}}],
    Polygon[{{1.047550, 1.548670, -0.001313},{1.047634, 1.548731, 0.000000},{
      1.045777, 1.550588, 0.000000},{1.045716, 1.550504, -0.001313}}],
    Polygon[{{1.047634, 1.548731, 0.000000},{1.047550, 1.548670, 0.001313},{
      1.045716, 1.550504, 0.001313},{1.045777, 1.550588, 0.000000}}],
    Polygon[{{1.047550, 1.548670, 0.001313},{1.047302, 1.548490, 0.002594},{
      1.045536, 1.550256, 0.002594},{1.045716, 1.550504, 0.001313}}],
    Polygon[{{1.047302, 1.548490, 0.002594},{1.046894, 1.548193, 0.003811},{
      1.045239, 1.549848, 0.003811},{1.045536, 1.550256, 0.002594}}],
    Polygon[{{1.046894, 1.548193, 0.003811},{1.046337, 1.547789, 0.004934},{
      1.044835, 1.549291, 0.004934},{1.045239, 1.549848, 0.003811}}],
    Polygon[{{1.046337, 1.547789, 0.004934},{1.045645, 1.547286, 0.005935},{
      1.044332, 1.548599, 0.005935},{1.044835, 1.549291, 0.004934}}],
    Polygon[{{1.045645, 1.547286, 0.005935},{1.044835, 1.546697, 0.006791},{
      1.043743, 1.547789, 0.006791},{1.044332, 1.548599, 0.005935}}],
    Polygon[{{1.044835, 1.546697, 0.006791},{1.043926, 1.546037, 0.007479},{
      1.043083, 1.546880, 0.007479},{1.043743, 1.547789, 0.006791}}],
    Polygon[{{1.043926, 1.546037, 0.007479},{1.042942, 1.545322, 0.007983},{
      1.042368, 1.545896, 0.007983},{1.043083, 1.546880, 0.007479}}],
    Polygon[{{1.042942, 1.545322, 0.007983},{1.041906, 1.544569, 0.008290},{
      1.041615, 1.544860, 0.008290},{1.042368, 1.545896, 0.007983}}],
    Polygon[{{1.041615, 1.544860, -0.008290},{1.042368, 1.545896, -0.007983},{
      1.041645, 1.546264, -0.007983},{1.041249, 1.545046, -0.008290}}],
    Polygon[{{1.042368, 1.545896, -0.007983},{1.043083, 1.546880, -0.007479},{
      1.042021, 1.547422, -0.007479},{1.041645, 1.546264, -0.007983}}],
    Polygon[{{1.043083, 1.546880, -0.007479},{1.043743, 1.547789, -0.006791},{
      1.042368, 1.548490, -0.006791},{1.042021, 1.547422, -0.007479}}],
    Polygon[{{1.043743, 1.547789, -0.006791},{1.044332, 1.548599, -0.005935},{
      1.042678, 1.549442, -0.005935},{1.042368, 1.548490, -0.006791}}],
    Polygon[{{1.044332, 1.548599, -0.005935},{1.044835, 1.549291, -0.004934},{
      1.042942, 1.550256, -0.004934},{1.042678, 1.549442, -0.005935}}],
    Polygon[{{1.044835, 1.549291, -0.004934},{1.045239, 1.549848, -0.003811},{
      1.043154, 1.550910, -0.003811},{1.042942, 1.550256, -0.004934}}],
    Polygon[{{1.045239, 1.549848, -0.003811},{1.045536, 1.550256, -0.002594},{
      1.043310, 1.551390, -0.002594},{1.043154, 1.550910, -0.003811}}],
    Polygon[{{1.045536, 1.550256, -0.002594},{1.045716, 1.550504, -0.001313},{
      1.043405, 1.551682, -0.001313},{1.043310, 1.551390, -0.002594}}],
    Polygon[{{1.045716, 1.550504, -0.001313},{1.045777, 1.550588, 0.000000},{
      1.043437, 1.551780, 0.000000},{1.043405, 1.551682, -0.001313}}],
    Polygon[{{1.045777, 1.550588, 0.000000},{1.045716, 1.550504, 0.001313},{
      1.043405, 1.551682, 0.001313},{1.043437, 1.551780, 0.000000}}],
    Polygon[{{1.045716, 1.550504, 0.001313},{1.045536, 1.550256, 0.002594},{
      1.043310, 1.551390, 0.002594},{1.043405, 1.551682, 0.001313}}],
    Polygon[{{1.045536, 1.550256, 0.002594},{1.045239, 1.549848, 0.003811},{
      1.043154, 1.550910, 0.003811},{1.043310, 1.551390, 0.002594}}],
    Polygon[{{1.045239, 1.549848, 0.003811},{1.044835, 1.549291, 0.004934},{
      1.042942, 1.550256, 0.004934},{1.043154, 1.550910, 0.003811}}],
    Polygon[{{1.044835, 1.549291, 0.004934},{1.044332, 1.548599, 0.005935},{
      1.042678, 1.549442, 0.005935},{1.042942, 1.550256, 0.004934}}],
    Polygon[{{1.044332, 1.548599, 0.005935},{1.043743, 1.547789, 0.006791},{
      1.042368, 1.548490, 0.006791},{1.042678, 1.549442, 0.005935}}],
    Polygon[{{1.043743, 1.547789, 0.006791},{1.043083, 1.546880, 0.007479},{
      1.042021, 1.547422, 0.007479},{1.042368, 1.548490, 0.006791}}],
    Polygon[{{1.043083, 1.546880, 0.007479},{1.042368, 1.545896, 0.007983},{
      1.041645, 1.546264, 0.007983},{1.042021, 1.547422, 0.007479}}],
    Polygon[{{1.042368, 1.545896, 0.007983},{1.041615, 1.544860, 0.008290},{
      1.041249, 1.545046, 0.008290},{1.041645, 1.546264, 0.007983}}],
    Polygon[{{1.041249, 1.545046, -0.008290},{1.041645, 1.546264, -0.007983},{
      1.040843, 1.546391, -0.007983},{1.040843, 1.545111, -0.008290}}],
    Polygon[{{1.041645, 1.546264, -0.007983},{1.042021, 1.547422, -0.007479},{
      1.040843, 1.547608, -0.007479},{1.040843, 1.546391, -0.007983}}],
    Polygon[{{1.042021, 1.547422, -0.007479},{1.042368, 1.548490, -0.006791},{
      1.040843, 1.548731, -0.006791},{1.040843, 1.547608, -0.007479}}],
    Polygon[{{1.042368, 1.548490, -0.006791},{1.042678, 1.549442, -0.005935},{
      1.040843, 1.549733, -0.005935},{1.040843, 1.548731, -0.006791}}],
    Polygon[{{1.042678, 1.549442, -0.005935},{1.042942, 1.550256, -0.004934},{
      1.040843, 1.550588, -0.004934},{1.040843, 1.549733, -0.005935}}],
    Polygon[{{1.042942, 1.550256, -0.004934},{1.043154, 1.550910, -0.003811},{
      1.040843, 1.551276, -0.003811},{1.040843, 1.550588, -0.004934}}],
    Polygon[{{1.043154, 1.550910, -0.003811},{1.043310, 1.551390, -0.002594},{
      1.040843, 1.551780, -0.002594},{1.040843, 1.551276, -0.003811}}],
    Polygon[{{1.043310, 1.551390, -0.002594},{1.043405, 1.551682, -0.001313},{
      1.040843, 1.552088, -0.001313},{1.040843, 1.551780, -0.002594}}],
    Polygon[{{1.043405, 1.551682, -0.001313},{1.043437, 1.551780, 0.000000},{
      1.040843, 1.552191, 0.000000},{1.040843, 1.552088, -0.001313}}],
    Polygon[{{1.043437, 1.551780, 0.000000},{1.043405, 1.551682, 0.001313},{
      1.040843, 1.552088, 0.001313},{1.040843, 1.552191, 0.000000}}],
    Polygon[{{1.043405, 1.551682, 0.001313},{1.043310, 1.551390, 0.002594},{
      1.040843, 1.551780, 0.002594},{1.040843, 1.552088, 0.001313}}],
    Polygon[{{1.043310, 1.551390, 0.002594},{1.043154, 1.550910, 0.003811},{
      1.040843, 1.551276, 0.003811},{1.040843, 1.551780, 0.002594}}],
    Polygon[{{1.043154, 1.550910, 0.003811},{1.042942, 1.550256, 0.004934},{
      1.040843, 1.550588, 0.004934},{1.040843, 1.551276, 0.003811}}],
    Polygon[{{1.042942, 1.550256, 0.004934},{1.042678, 1.549442, 0.005935},{
      1.040843, 1.549733, 0.005935},{1.040843, 1.550588, 0.004934}}],
    Polygon[{{1.042678, 1.549442, 0.005935},{1.042368, 1.548490, 0.006791},{
      1.040843, 1.548731, 0.006791},{1.040843, 1.549733, 0.005935}}],
    Polygon[{{1.042368, 1.548490, 0.006791},{1.042021, 1.547422, 0.007479},{
      1.040843, 1.547608, 0.007479},{1.040843, 1.548731, 0.006791}}],
    Polygon[{{1.042021, 1.547422, 0.007479},{1.041645, 1.546264, 0.007983},{
      1.040843, 1.546391, 0.007983},{1.040843, 1.547608, 0.007479}}],
    Polygon[{{1.041645, 1.546264, 0.007983},{1.041249, 1.545046, 0.008290},{
      1.040843, 1.545111, 0.008290},{1.040843, 1.546391, 0.007983}}],
    Polygon[{{1.040843, 1.545111, -0.008290},{1.040843, 1.546391, -0.007983},{
      1.040042, 1.546264, -0.007983},{1.040438, 1.545046, -0.008290}}],
    Polygon[{{1.040843, 1.546391, -0.007983},{1.040843, 1.547608, -0.007479},{
      1.039666, 1.547422, -0.007479},{1.040042, 1.546264, -0.007983}}],
    Polygon[{{1.040843, 1.547608, -0.007479},{1.040843, 1.548731, -0.006791},{
      1.039319, 1.548490, -0.006791},{1.039666, 1.547422, -0.007479}}],
    Polygon[{{1.040843, 1.548731, -0.006791},{1.040843, 1.549733, -0.005935},{
      1.039009, 1.549442, -0.005935},{1.039319, 1.548490, -0.006791}}],
    Polygon[{{1.040843, 1.549733, -0.005935},{1.040843, 1.550588, -0.004934},{
      1.038745, 1.550256, -0.004934},{1.039009, 1.549442, -0.005935}}],
    Polygon[{{1.040843, 1.550588, -0.004934},{1.040843, 1.551276, -0.003811},{
      1.038532, 1.550910, -0.003811},{1.038745, 1.550256, -0.004934}}],
    Polygon[{{1.040843, 1.551276, -0.003811},{1.040843, 1.551780, -0.002594},{
      1.038377, 1.551390, -0.002594},{1.038532, 1.550910, -0.003811}}],
    Polygon[{{1.040843, 1.551780, -0.002594},{1.040843, 1.552088, -0.001313},{
      1.038282, 1.551682, -0.001313},{1.038377, 1.551390, -0.002594}}],
    Polygon[{{1.040843, 1.552088, -0.001313},{1.040843, 1.552191, 0.000000},{
      1.038250, 1.551780, 0.000000},{1.038282, 1.551682, -0.001313}}],
    Polygon[{{1.040843, 1.552191, 0.000000},{1.040843, 1.552088, 0.001313},{
      1.038282, 1.551682, 0.001313},{1.038250, 1.551780, 0.000000}}],
    Polygon[{{1.040843, 1.552088, 0.001313},{1.040843, 1.551780, 0.002594},{
      1.038377, 1.551390, 0.002594},{1.038282, 1.551682, 0.001313}}],
    Polygon[{{1.040843, 1.551780, 0.002594},{1.040843, 1.551276, 0.003811},{
      1.038532, 1.550910, 0.003811},{1.038377, 1.551390, 0.002594}}],
    Polygon[{{1.040843, 1.551276, 0.003811},{1.040843, 1.550588, 0.004934},{
      1.038745, 1.550256, 0.004934},{1.038532, 1.550910, 0.003811}}],
    Polygon[{{1.040843, 1.550588, 0.004934},{1.040843, 1.549733, 0.005935},{
      1.039009, 1.549442, 0.005935},{1.038745, 1.550256, 0.004934}}],
    Polygon[{{1.040843, 1.549733, 0.005935},{1.040843, 1.548731, 0.006791},{
      1.039319, 1.548490, 0.006791},{1.039009, 1.549442, 0.005935}}],
    Polygon[{{1.040843, 1.548731, 0.006791},{1.040843, 1.547608, 0.007479},{
      1.039666, 1.547422, 0.007479},{1.039319, 1.548490, 0.006791}}],
    Polygon[{{1.040843, 1.547608, 0.007479},{1.040843, 1.546391, 0.007983},{
      1.040042, 1.546264, 0.007983},{1.039666, 1.547422, 0.007479}}],
    Polygon[{{1.040843, 1.546391, 0.007983},{1.040843, 1.545111, 0.008290},{
      1.040438, 1.545046, 0.008290},{1.040042, 1.546264, 0.007983}}],
    Polygon[{{1.040438, 1.545046, -0.008290},{1.040042, 1.546264, -0.007983},{
      1.039319, 1.545896, -0.007983},{1.040072, 1.544860, -0.008290}}],
    Polygon[{{1.040042, 1.546264, -0.007983},{1.039666, 1.547422, -0.007479},{
      1.038604, 1.546880, -0.007479},{1.039319, 1.545896, -0.007983}}],
    Polygon[{{1.039666, 1.547422, -0.007479},{1.039319, 1.548490, -0.006791},{
      1.037943, 1.547789, -0.006791},{1.038604, 1.546880, -0.007479}}],
    Polygon[{{1.039319, 1.548490, -0.006791},{1.039009, 1.549442, -0.005935},{
      1.037355, 1.548599, -0.005935},{1.037943, 1.547789, -0.006791}}],
    Polygon[{{1.039009, 1.549442, -0.005935},{1.038745, 1.550256, -0.004934},{
      1.036852, 1.549291, -0.004934},{1.037355, 1.548599, -0.005935}}],
    Polygon[{{1.038745, 1.550256, -0.004934},{1.038532, 1.550910, -0.003811},{
      1.036448, 1.549848, -0.003811},{1.036852, 1.549291, -0.004934}}],
    Polygon[{{1.038532, 1.550910, -0.003811},{1.038377, 1.551390, -0.002594},{
      1.036151, 1.550256, -0.002594},{1.036448, 1.549848, -0.003811}}],
    Polygon[{{1.038377, 1.551390, -0.002594},{1.038282, 1.551682, -0.001313},{
      1.035971, 1.550504, -0.001313},{1.036151, 1.550256, -0.002594}}],
    Polygon[{{1.038282, 1.551682, -0.001313},{1.038250, 1.551780, 0.000000},{
      1.035910, 1.550588, 0.000000},{1.035971, 1.550504, -0.001313}}],
    Polygon[{{1.038250, 1.551780, 0.000000},{1.038282, 1.551682, 0.001313},{
      1.035971, 1.550504, 0.001313},{1.035910, 1.550588, 0.000000}}],
    Polygon[{{1.038282, 1.551682, 0.001313},{1.038377, 1.551390, 0.002594},{
      1.036151, 1.550256, 0.002594},{1.035971, 1.550504, 0.001313}}],
    Polygon[{{1.038377, 1.551390, 0.002594},{1.038532, 1.550910, 0.003811},{
      1.036448, 1.549848, 0.003811},{1.036151, 1.550256, 0.002594}}],
    Polygon[{{1.038532, 1.550910, 0.003811},{1.038745, 1.550256, 0.004934},{
      1.036852, 1.549291, 0.004934},{1.036448, 1.549848, 0.003811}}],
    Polygon[{{1.038745, 1.550256, 0.004934},{1.039009, 1.549442, 0.005935},{
      1.037355, 1.548599, 0.005935},{1.036852, 1.549291, 0.004934}}],
    Polygon[{{1.039009, 1.549442, 0.005935},{1.039319, 1.548490, 0.006791},{
      1.037943, 1.547789, 0.006791},{1.037355, 1.548599, 0.005935}}],
    Polygon[{{1.039319, 1.548490, 0.006791},{1.039666, 1.547422, 0.007479},{
      1.038604, 1.546880, 0.007479},{1.037943, 1.547789, 0.006791}}],
    Polygon[{{1.039666, 1.547422, 0.007479},{1.040042, 1.546264, 0.007983},{
      1.039319, 1.545896, 0.007983},{1.038604, 1.546880, 0.007479}}],
    Polygon[{{1.040042, 1.546264, 0.007983},{1.040438, 1.545046, 0.008290},{
      1.040072, 1.544860, 0.008290},{1.039319, 1.545896, 0.007983}}],
    Polygon[{{1.040072, 1.544860, -0.008290},{1.039319, 1.545896, -0.007983},{
      1.038745, 1.545322, -0.007983},{1.039781, 1.544569, -0.008290}}],
    Polygon[{{1.039319, 1.545896, -0.007983},{1.038604, 1.546880, -0.007479},{
      1.037761, 1.546037, -0.007479},{1.038745, 1.545322, -0.007983}}],
    Polygon[{{1.038604, 1.546880, -0.007479},{1.037943, 1.547789, -0.006791},{
      1.036852, 1.546697, -0.006791},{1.037761, 1.546037, -0.007479}}],
    Polygon[{{1.037943, 1.547789, -0.006791},{1.037355, 1.548599, -0.005935},{
      1.036042, 1.547286, -0.005935},{1.036852, 1.546697, -0.006791}}],
    Polygon[{{1.037355, 1.548599, -0.005935},{1.036852, 1.549291, -0.004934},{
      1.035350, 1.547789, -0.004934},{1.036042, 1.547286, -0.005935}}],
    Polygon[{{1.036852, 1.549291, -0.004934},{1.036448, 1.549848, -0.003811},{
      1.034793, 1.548193, -0.003811},{1.035350, 1.547789, -0.004934}}],
    Polygon[{{1.036448, 1.549848, -0.003811},{1.036151, 1.550256, -0.002594},{
      1.034385, 1.548490, -0.002594},{1.034793, 1.548193, -0.003811}}],
    Polygon[{{1.036151, 1.550256, -0.002594},{1.035971, 1.550504, -0.001313},{
      1.034137, 1.548670, -0.001313},{1.034385, 1.548490, -0.002594}}],
    Polygon[{{1.035971, 1.550504, -0.001313},{1.035910, 1.550588, 0.000000},{
      1.034053, 1.548731, 0.000000},{1.034137, 1.548670, -0.001313}}],
    Polygon[{{1.035910, 1.550588, 0.000000},{1.035971, 1.550504, 0.001313},{
      1.034137, 1.548670, 0.001313},{1.034053, 1.548731, 0.000000}}],
    Polygon[{{1.035971, 1.550504, 0.001313},{1.036151, 1.550256, 0.002594},{
      1.034385, 1.548490, 0.002594},{1.034137, 1.548670, 0.001313}}],
    Polygon[{{1.036151, 1.550256, 0.002594},{1.036448, 1.549848, 0.003811},{
      1.034793, 1.548193, 0.003811},{1.034385, 1.548490, 0.002594}}],
    Polygon[{{1.036448, 1.549848, 0.003811},{1.036852, 1.549291, 0.004934},{
      1.035350, 1.547789, 0.004934},{1.034793, 1.548193, 0.003811}}],
    Polygon[{{1.036852, 1.549291, 0.004934},{1.037355, 1.548599, 0.005935},{
      1.036042, 1.547286, 0.005935},{1.035350, 1.547789, 0.004934}}],
    Polygon[{{1.037355, 1.548599, 0.005935},{1.037943, 1.547789, 0.006791},{
      1.036852, 1.546697, 0.006791},{1.036042, 1.547286, 0.005935}}],
    Polygon[{{1.037943, 1.547789, 0.006791},{1.038604, 1.546880, 0.007479},{
      1.037761, 1.546037, 0.007479},{1.036852, 1.546697, 0.006791}}],
    Polygon[{{1.038604, 1.546880, 0.007479},{1.039319, 1.545896, 0.007983},{
      1.038745, 1.545322, 0.007983},{1.037761, 1.546037, 0.007479}}],
    Polygon[{{1.039319, 1.545896, 0.007983},{1.040072, 1.544860, 0.008290},{
      1.039781, 1.544569, 0.008290},{1.038745, 1.545322, 0.007983}}],
    Polygon[{{1.039781, 1.544569, -0.008290},{1.038745, 1.545322, -0.007983},{
      1.038377, 1.544599, -0.007983},{1.039595, 1.544203, -0.008290}}],
    Polygon[{{1.038745, 1.545322, -0.007983},{1.037761, 1.546037, -0.007479},{
      1.037219, 1.544975, -0.007479},{1.038377, 1.544599, -0.007983}}],
    Polygon[{{1.037761, 1.546037, -0.007479},{1.036852, 1.546697, -0.006791},{
      1.036151, 1.545322, -0.006791},{1.037219, 1.544975, -0.007479}}],
    Polygon[{{1.036852, 1.546697, -0.006791},{1.036042, 1.547286, -0.005935},{
      1.035199, 1.545632, -0.005935},{1.036151, 1.545322, -0.006791}}],
    Polygon[{{1.036042, 1.547286, -0.005935},{1.035350, 1.547789, -0.004934},{
      1.034385, 1.545896, -0.004934},{1.035199, 1.545632, -0.005935}}],
    Polygon[{{1.035350, 1.547789, -0.004934},{1.034793, 1.548193, -0.003811},{
      1.033731, 1.546109, -0.003811},{1.034385, 1.545896, -0.004934}}],
    Polygon[{{1.034793, 1.548193, -0.003811},{1.034385, 1.548490, -0.002594},{
      1.033251, 1.546264, -0.002594},{1.033731, 1.546109, -0.003811}}],
    Polygon[{{1.034385, 1.548490, -0.002594},{1.034137, 1.548670, -0.001313},{
      1.032959, 1.546359, -0.001313},{1.033251, 1.546264, -0.002594}}],
    Polygon[{{1.034137, 1.548670, -0.001313},{1.034053, 1.548731, 0.000000},{
      1.032861, 1.546391, 0.000000},{1.032959, 1.546359, -0.001313}}],
    Polygon[{{1.034053, 1.548731, 0.000000},{1.034137, 1.548670, 0.001313},{
      1.032959, 1.546359, 0.001313},{1.032861, 1.546391, 0.000000}}],
    Polygon[{{1.034137, 1.548670, 0.001313},{1.034385, 1.548490, 0.002594},{
      1.033251, 1.546264, 0.002594},{1.032959, 1.546359, 0.001313}}],
    Polygon[{{1.034385, 1.548490, 0.002594},{1.034793, 1.548193, 0.003811},{
      1.033731, 1.546109, 0.003811},{1.033251, 1.546264, 0.002594}}],
    Polygon[{{1.034793, 1.548193, 0.003811},{1.035350, 1.547789, 0.004934},{
      1.034385, 1.545896, 0.004934},{1.033731, 1.546109, 0.003811}}],
    Polygon[{{1.035350, 1.547789, 0.004934},{1.036042, 1.547286, 0.005935},{
      1.035199, 1.545632, 0.005935},{1.034385, 1.545896, 0.004934}}],
    Polygon[{{1.036042, 1.547286, 0.005935},{1.036852, 1.546697, 0.006791},{
      1.036151, 1.545322, 0.006791},{1.035199, 1.545632, 0.005935}}],
    Polygon[{{1.036852, 1.546697, 0.006791},{1.037761, 1.546037, 0.007479},{
      1.037219, 1.544975, 0.007479},{1.036151, 1.545322, 0.006791}}],
    Polygon[{{1.037761, 1.546037, 0.007479},{1.038745, 1.545322, 0.007983},{
      1.038377, 1.544599, 0.007983},{1.037219, 1.544975, 0.007479}}],
    Polygon[{{1.038745, 1.545322, 0.007983},{1.039781, 1.544569, 0.008290},{
      1.039595, 1.544203, 0.008290},{1.038377, 1.544599, 0.007983}}],
    Polygon[{{1.039595, 1.544203, -0.008290},{1.038377, 1.544599, -0.007983},{
      1.038250, 1.543797, -0.007983},{1.039530, 1.543797, -0.008290}}],
    Polygon[{{1.038377, 1.544599, -0.007983},{1.037219, 1.544975, -0.007479},{
      1.037033, 1.543797, -0.007479},{1.038250, 1.543797, -0.007983}}],
    Polygon[{{1.037219, 1.544975, -0.007479},{1.036151, 1.545322, -0.006791},{
      1.035910, 1.543797, -0.006791},{1.037033, 1.543797, -0.007479}}],
    Polygon[{{1.036151, 1.545322, -0.006791},{1.035199, 1.545632, -0.005935},{
      1.034908, 1.543797, -0.005935},{1.035910, 1.543797, -0.006791}}],
    Polygon[{{1.035199, 1.545632, -0.005935},{1.034385, 1.545896, -0.004934},{
      1.034053, 1.543797, -0.004934},{1.034908, 1.543797, -0.005935}}],
    Polygon[{{1.034385, 1.545896, -0.004934},{1.033731, 1.546109, -0.003811},{
      1.033365, 1.543797, -0.003811},{1.034053, 1.543797, -0.004934}}],
    Polygon[{{1.033731, 1.546109, -0.003811},{1.033251, 1.546264, -0.002594},{
      1.032861, 1.543797, -0.002594},{1.033365, 1.543797, -0.003811}}],
    Polygon[{{1.033251, 1.546264, -0.002594},{1.032959, 1.546359, -0.001313},{
      1.032553, 1.543797, -0.001313},{1.032861, 1.543797, -0.002594}}],
    Polygon[{{1.032959, 1.546359, -0.001313},{1.032861, 1.546391, 0.000000},{
      1.032450, 1.543797, 0.000000},{1.032553, 1.543797, -0.001313}}],
    Polygon[{{1.032861, 1.546391, 0.000000},{1.032959, 1.546359, 0.001313},{
      1.032553, 1.543797, 0.001313},{1.032450, 1.543797, 0.000000}}],
    Polygon[{{1.032959, 1.546359, 0.001313},{1.033251, 1.546264, 0.002594},{
      1.032861, 1.543797, 0.002594},{1.032553, 1.543797, 0.001313}}],
    Polygon[{{1.033251, 1.546264, 0.002594},{1.033731, 1.546109, 0.003811},{
      1.033365, 1.543797, 0.003811},{1.032861, 1.543797, 0.002594}}],
    Polygon[{{1.033731, 1.546109, 0.003811},{1.034385, 1.545896, 0.004934},{
      1.034053, 1.543797, 0.004934},{1.033365, 1.543797, 0.003811}}],
    Polygon[{{1.034385, 1.545896, 0.004934},{1.035199, 1.545632, 0.005935},{
      1.034908, 1.543797, 0.005935},{1.034053, 1.543797, 0.004934}}],
    Polygon[{{1.035199, 1.545632, 0.005935},{1.036151, 1.545322, 0.006791},{
      1.035910, 1.543797, 0.006791},{1.034908, 1.543797, 0.005935}}],
    Polygon[{{1.036151, 1.545322, 0.006791},{1.037219, 1.544975, 0.007479},{
      1.037033, 1.543797, 0.007479},{1.035910, 1.543797, 0.006791}}],
    Polygon[{{1.037219, 1.544975, 0.007479},{1.038377, 1.544599, 0.007983},{
      1.038250, 1.543797, 0.007983},{1.037033, 1.543797, 0.007479}}],
    Polygon[{{1.038377, 1.544599, 0.007983},{1.039595, 1.544203, 0.008290},{
      1.039530, 1.543797, 0.008290},{1.038250, 1.543797, 0.007983}}],
    Polygon[{{1.039530, 1.543797, -0.008290},{1.038250, 1.543797, -0.007983},{
      1.038377, 1.542996, -0.007983},{1.039595, 1.543392, -0.008290}}],
    Polygon[{{1.038250, 1.543797, -0.007983},{1.037033, 1.543797, -0.007479},{
      1.037219, 1.542620, -0.007479},{1.038377, 1.542996, -0.007983}}],
    Polygon[{{1.037033, 1.543797, -0.007479},{1.035910, 1.543797, -0.006791},{
      1.036151, 1.542273, -0.006791},{1.037219, 1.542620, -0.007479}}],
    Polygon[{{1.035910, 1.543797, -0.006791},{1.034908, 1.543797, -0.005935},{
      1.035199, 1.541963, -0.005935},{1.036151, 1.542273, -0.006791}}],
    Polygon[{{1.034908, 1.543797, -0.005935},{1.034053, 1.543797, -0.004934},{
      1.034385, 1.541699, -0.004934},{1.035199, 1.541963, -0.005935}}],
    Polygon[{{1.034053, 1.543797, -0.004934},{1.033365, 1.543797, -0.003811},{
      1.033731, 1.541487, -0.003811},{1.034385, 1.541699, -0.004934}}],
    Polygon[{{1.033365, 1.543797, -0.003811},{1.032861, 1.543797, -0.002594},{
      1.033251, 1.541331, -0.002594},{1.033731, 1.541487, -0.003811}}],
    Polygon[{{1.032861, 1.543797, -0.002594},{1.032553, 1.543797, -0.001313},{
      1.032959, 1.541236, -0.001313},{1.033251, 1.541331, -0.002594}}],
    Polygon[{{1.032553, 1.543797, -0.001313},{1.032450, 1.543797, 0.000000},{
      1.032861, 1.541204, 0.000000},{1.032959, 1.541236, -0.001313}}],
    Polygon[{{1.032450, 1.543797, 0.000000},{1.032553, 1.543797, 0.001313},{
      1.032959, 1.541236, 0.001313},{1.032861, 1.541204, 0.000000}}],
    Polygon[{{1.032553, 1.543797, 0.001313},{1.032861, 1.543797, 0.002594},{
      1.033251, 1.541331, 0.002594},{1.032959, 1.541236, 0.001313}}],
    Polygon[{{1.032861, 1.543797, 0.002594},{1.033365, 1.543797, 0.003811},{
      1.033731, 1.541487, 0.003811},{1.033251, 1.541331, 0.002594}}],
    Polygon[{{1.033365, 1.543797, 0.003811},{1.034053, 1.543797, 0.004934},{
      1.034385, 1.541699, 0.004934},{1.033731, 1.541487, 0.003811}}],
    Polygon[{{1.034053, 1.543797, 0.004934},{1.034908, 1.543797, 0.005935},{
      1.035199, 1.541963, 0.005935},{1.034385, 1.541699, 0.004934}}],
    Polygon[{{1.034908, 1.543797, 0.005935},{1.035910, 1.543797, 0.006791},{
      1.036151, 1.542273, 0.006791},{1.035199, 1.541963, 0.005935}}],
    Polygon[{{1.035910, 1.543797, 0.006791},{1.037033, 1.543797, 0.007479},{
      1.037219, 1.542620, 0.007479},{1.036151, 1.542273, 0.006791}}],
    Polygon[{{1.037033, 1.543797, 0.007479},{1.038250, 1.543797, 0.007983},{
      1.038377, 1.542996, 0.007983},{1.037219, 1.542620, 0.007479}}],
    Polygon[{{1.038250, 1.543797, 0.007983},{1.039530, 1.543797, 0.008290},{
      1.039595, 1.543392, 0.008290},{1.038377, 1.542996, 0.007983}}],
    Polygon[{{1.039595, 1.543392, -0.008290},{1.038377, 1.542996, -0.007983},{
      1.038745, 1.542273, -0.007983},{1.039781, 1.543026, -0.008290}}],
    Polygon[{{1.038377, 1.542996, -0.007983},{1.037219, 1.542620, -0.007479},{
      1.037761, 1.541558, -0.007479},{1.038745, 1.542273, -0.007983}}],
    Polygon[{{1.037219, 1.542620, -0.007479},{1.036151, 1.542273, -0.006791},{
      1.036852, 1.540898, -0.006791},{1.037761, 1.541558, -0.007479}}],
    Polygon[{{1.036151, 1.542273, -0.006791},{1.035199, 1.541963, -0.005935},{
      1.036042, 1.540309, -0.005935},{1.036852, 1.540898, -0.006791}}],
    Polygon[{{1.035199, 1.541963, -0.005935},{1.034385, 1.541699, -0.004934},{
      1.035350, 1.539806, -0.004934},{1.036042, 1.540309, -0.005935}}],
    Polygon[{{1.034385, 1.541699, -0.004934},{1.033731, 1.541487, -0.003811},{
      1.034793, 1.539402, -0.003811},{1.035350, 1.539806, -0.004934}}],
    Polygon[{{1.033731, 1.541487, -0.003811},{1.033251, 1.541331, -0.002594},{
      1.034385, 1.539105, -0.002594},{1.034793, 1.539402, -0.003811}}],
    Polygon[{{1.033251, 1.541331, -0.002594},{1.032959, 1.541236, -0.001313},{
      1.034137, 1.538925, -0.001313},{1.034385, 1.539105, -0.002594}}],
    Polygon[{{1.032959, 1.541236, -0.001313},{1.032861, 1.541204, 0.000000},{
      1.034053, 1.538864, 0.000000},{1.034137, 1.538925, -0.001313}}],
    Polygon[{{1.032861, 1.541204, 0.000000},{1.032959, 1.541236, 0.001313},{
      1.034137, 1.538925, 0.001313},{1.034053, 1.538864, 0.000000}}],
    Polygon[{{1.032959, 1.541236, 0.001313},{1.033251, 1.541331, 0.002594},{
      1.034385, 1.539105, 0.002594},{1.034137, 1.538925, 0.001313}}],
    Polygon[{{1.033251, 1.541331, 0.002594},{1.033731, 1.541487, 0.003811},{
      1.034793, 1.539402, 0.003811},{1.034385, 1.539105, 0.002594}}],
    Polygon[{{1.033731, 1.541487, 0.003811},{1.034385, 1.541699, 0.004934},{
      1.035350, 1.539806, 0.004934},{1.034793, 1.539402, 0.003811}}],
    Polygon[{{1.034385, 1.541699, 0.004934},{1.035199, 1.541963, 0.005935},{
      1.036042, 1.540309, 0.005935},{1.035350, 1.539806, 0.004934}}],
    Polygon[{{1.035199, 1.541963, 0.005935},{1.036151, 1.542273, 0.006791},{
      1.036852, 1.540898, 0.006791},{1.036042, 1.540309, 0.005935}}],
    Polygon[{{1.036151, 1.542273, 0.006791},{1.037219, 1.542620, 0.007479},{
      1.037761, 1.541558, 0.007479},{1.036852, 1.540898, 0.006791}}],
    Polygon[{{1.037219, 1.542620, 0.007479},{1.038377, 1.542996, 0.007983},{
      1.038745, 1.542273, 0.007983},{1.037761, 1.541558, 0.007479}}],
    Polygon[{{1.038377, 1.542996, 0.007983},{1.039595, 1.543392, 0.008290},{
      1.039781, 1.543026, 0.008290},{1.038745, 1.542273, 0.007983}}],
    Polygon[{{1.039781, 1.543026, -0.008290},{1.038745, 1.542273, -0.007983},{
      1.039319, 1.541699, -0.007983},{1.040072, 1.542735, -0.008290}}],
    Polygon[{{1.038745, 1.542273, -0.007983},{1.037761, 1.541558, -0.007479},{
      1.038604, 1.540715, -0.007479},{1.039319, 1.541699, -0.007983}}],
    Polygon[{{1.037761, 1.541558, -0.007479},{1.036852, 1.540898, -0.006791},{
      1.037943, 1.539806, -0.006791},{1.038604, 1.540715, -0.007479}}],
    Polygon[{{1.036852, 1.540898, -0.006791},{1.036042, 1.540309, -0.005935},{
      1.037355, 1.538996, -0.005935},{1.037943, 1.539806, -0.006791}}],
    Polygon[{{1.036042, 1.540309, -0.005935},{1.035350, 1.539806, -0.004934},{
      1.036852, 1.538304, -0.004934},{1.037355, 1.538996, -0.005935}}],
    Polygon[{{1.035350, 1.539806, -0.004934},{1.034793, 1.539402, -0.003811},{
      1.036448, 1.537747, -0.003811},{1.036852, 1.538304, -0.004934}}],
    Polygon[{{1.034793, 1.539402, -0.003811},{1.034385, 1.539105, -0.002594},{
      1.036151, 1.537339, -0.002594},{1.036448, 1.537747, -0.003811}}],
    Polygon[{{1.034385, 1.539105, -0.002594},{1.034137, 1.538925, -0.001313},{
      1.035971, 1.537091, -0.001313},{1.036151, 1.537339, -0.002594}}],
    Polygon[{{1.034137, 1.538925, -0.001313},{1.034053, 1.538864, 0.000000},{
      1.035910, 1.537007, 0.000000},{1.035971, 1.537091, -0.001313}}],
    Polygon[{{1.034053, 1.538864, 0.000000},{1.034137, 1.538925, 0.001313},{
      1.035971, 1.537091, 0.001313},{1.035910, 1.537007, 0.000000}}],
    Polygon[{{1.034137, 1.538925, 0.001313},{1.034385, 1.539105, 0.002594},{
      1.036151, 1.537339, 0.002594},{1.035971, 1.537091, 0.001313}}],
    Polygon[{{1.034385, 1.539105, 0.002594},{1.034793, 1.539402, 0.003811},{
      1.036448, 1.537747, 0.003811},{1.036151, 1.537339, 0.002594}}],
    Polygon[{{1.034793, 1.539402, 0.003811},{1.035350, 1.539806, 0.004934},{
      1.036852, 1.538304, 0.004934},{1.036448, 1.537747, 0.003811}}],
    Polygon[{{1.035350, 1.539806, 0.004934},{1.036042, 1.540309, 0.005935},{
      1.037355, 1.538996, 0.005935},{1.036852, 1.538304, 0.004934}}],
    Polygon[{{1.036042, 1.540309, 0.005935},{1.036852, 1.540898, 0.006791},{
      1.037943, 1.539806, 0.006791},{1.037355, 1.538996, 0.005935}}],
    Polygon[{{1.036852, 1.540898, 0.006791},{1.037761, 1.541558, 0.007479},{
      1.038604, 1.540715, 0.007479},{1.037943, 1.539806, 0.006791}}],
    Polygon[{{1.037761, 1.541558, 0.007479},{1.038745, 1.542273, 0.007983},{
      1.039319, 1.541699, 0.007983},{1.038604, 1.540715, 0.007479}}],
    Polygon[{{1.038745, 1.542273, 0.007983},{1.039781, 1.543026, 0.008290},{
      1.040072, 1.542735, 0.008290},{1.039319, 1.541699, 0.007983}}],
    Polygon[{{1.040072, 1.542735, -0.008290},{1.039319, 1.541699, -0.007983},{
      1.040042, 1.541331, -0.007983},{1.040438, 1.542549, -0.008290}}],
    Polygon[{{1.039319, 1.541699, -0.007983},{1.038604, 1.540715, -0.007479},{
      1.039666, 1.540173, -0.007479},{1.040042, 1.541331, -0.007983}}],
    Polygon[{{1.038604, 1.540715, -0.007479},{1.037943, 1.539806, -0.006791},{
      1.039319, 1.539105, -0.006791},{1.039666, 1.540173, -0.007479}}],
    Polygon[{{1.037943, 1.539806, -0.006791},{1.037355, 1.538996, -0.005935},{
      1.039009, 1.538153, -0.005935},{1.039319, 1.539105, -0.006791}}],
    Polygon[{{1.037355, 1.538996, -0.005935},{1.036852, 1.538304, -0.004934},{
      1.038745, 1.537339, -0.004934},{1.039009, 1.538153, -0.005935}}],
    Polygon[{{1.036852, 1.538304, -0.004934},{1.036448, 1.537747, -0.003811},{
      1.038532, 1.536685, -0.003811},{1.038745, 1.537339, -0.004934}}],
    Polygon[{{1.036448, 1.537747, -0.003811},{1.036151, 1.537339, -0.002594},{
      1.038377, 1.536205, -0.002594},{1.038532, 1.536685, -0.003811}}],
    Polygon[{{1.036151, 1.537339, -0.002594},{1.035971, 1.537091, -0.001313},{
      1.038282, 1.535913, -0.001313},{1.038377, 1.536205, -0.002594}}],
    Polygon[{{1.035971, 1.537091, -0.001313},{1.035910, 1.537007, 0.000000},{
      1.038250, 1.535815, 0.000000},{1.038282, 1.535913, -0.001313}}],
    Polygon[{{1.035910, 1.537007, 0.000000},{1.035971, 1.537091, 0.001313},{
      1.038282, 1.535913, 0.001313},{1.038250, 1.535815, 0.000000}}],
    Polygon[{{1.035971, 1.537091, 0.001313},{1.036151, 1.537339, 0.002594},{
      1.038377, 1.536205, 0.002594},{1.038282, 1.535913, 0.001313}}],
    Polygon[{{1.036151, 1.537339, 0.002594},{1.036448, 1.537747, 0.003811},{
      1.038532, 1.536685, 0.003811},{1.038377, 1.536205, 0.002594}}],
    Polygon[{{1.036448, 1.537747, 0.003811},{1.036852, 1.538304, 0.004934},{
      1.038745, 1.537339, 0.004934},{1.038532, 1.536685, 0.003811}}],
    Polygon[{{1.036852, 1.538304, 0.004934},{1.037355, 1.538996, 0.005935},{
      1.039009, 1.538153, 0.005935},{1.038745, 1.537339, 0.004934}}],
    Polygon[{{1.037355, 1.538996, 0.005935},{1.037943, 1.539806, 0.006791},{
      1.039319, 1.539105, 0.006791},{1.039009, 1.538153, 0.005935}}],
    Polygon[{{1.037943, 1.539806, 0.006791},{1.038604, 1.540715, 0.007479},{
      1.039666, 1.540173, 0.007479},{1.039319, 1.539105, 0.006791}}],
    Polygon[{{1.038604, 1.540715, 0.007479},{1.039319, 1.541699, 0.007983},{
      1.040042, 1.541331, 0.007983},{1.039666, 1.540173, 0.007479}}],
    Polygon[{{1.039319, 1.541699, 0.007983},{1.040072, 1.542735, 0.008290},{
      1.040438, 1.542549, 0.008290},{1.040042, 1.541331, 0.007983}}],
    Polygon[{{1.040438, 1.542549, -0.008290},{1.040042, 1.541331, -0.007983},{
      1.040843, 1.541204, -0.007983},{1.040843, 1.542485, -0.008290}}],
    Polygon[{{1.040042, 1.541331, -0.007983},{1.039666, 1.540173, -0.007479},{
      1.040843, 1.539987, -0.007479},{1.040843, 1.541204, -0.007983}}],
    Polygon[{{1.039666, 1.540173, -0.007479},{1.039319, 1.539105, -0.006791},{
      1.040843, 1.538864, -0.006791},{1.040843, 1.539987, -0.007479}}],
    Polygon[{{1.039319, 1.539105, -0.006791},{1.039009, 1.538153, -0.005935},{
      1.040843, 1.537862, -0.005935},{1.040843, 1.538864, -0.006791}}],
    Polygon[{{1.039009, 1.538153, -0.005935},{1.038745, 1.537339, -0.004934},{
      1.040843, 1.537007, -0.004934},{1.040843, 1.537862, -0.005935}}],
    Polygon[{{1.038745, 1.537339, -0.004934},{1.038532, 1.536685, -0.003811},{
      1.040843, 1.536319, -0.003811},{1.040843, 1.537007, -0.004934}}],
    Polygon[{{1.038532, 1.536685, -0.003811},{1.038377, 1.536205, -0.002594},{
      1.040843, 1.535815, -0.002594},{1.040843, 1.536319, -0.003811}}],
    Polygon[{{1.038377, 1.536205, -0.002594},{1.038282, 1.535913, -0.001313},{
      1.040843, 1.535507, -0.001313},{1.040843, 1.535815, -0.002594}}],
    Polygon[{{1.038282, 1.535913, -0.001313},{1.038250, 1.535815, 0.000000},{
      1.040843, 1.535404, 0.000000},{1.040843, 1.535507, -0.001313}}],
    Polygon[{{1.038250, 1.535815, 0.000000},{1.038282, 1.535913, 0.001313},{
      1.040843, 1.535507, 0.001313},{1.040843, 1.535404, 0.000000}}],
    Polygon[{{1.038282, 1.535913, 0.001313},{1.038377, 1.536205, 0.002594},{
      1.040843, 1.535815, 0.002594},{1.040843, 1.535507, 0.001313}}],
    Polygon[{{1.038377, 1.536205, 0.002594},{1.038532, 1.536685, 0.003811},{
      1.040843, 1.536319, 0.003811},{1.040843, 1.535815, 0.002594}}],
    Polygon[{{1.038532, 1.536685, 0.003811},{1.038745, 1.537339, 0.004934},{
      1.040843, 1.537007, 0.004934},{1.040843, 1.536319, 0.003811}}],
    Polygon[{{1.038745, 1.537339, 0.004934},{1.039009, 1.538153, 0.005935},{
      1.040843, 1.537862, 0.005935},{1.040843, 1.537007, 0.004934}}],
    Polygon[{{1.039009, 1.538153, 0.005935},{1.039319, 1.539105, 0.006791},{
      1.040843, 1.538864, 0.006791},{1.040843, 1.537862, 0.005935}}],
    Polygon[{{1.039319, 1.539105, 0.006791},{1.039666, 1.540173, 0.007479},{
      1.040843, 1.539987, 0.007479},{1.040843, 1.538864, 0.006791}}],
    Polygon[{{1.039666, 1.540173, 0.007479},{1.040042, 1.541331, 0.007983},{
      1.040843, 1.541204, 0.007983},{1.040843, 1.539987, 0.007479}}],
    Polygon[{{1.040042, 1.541331, 0.007983},{1.040438, 1.542549, 0.008290},{
      1.040843, 1.542485, 0.008290},{1.040843, 1.541204, 0.007983}}],
    Polygon[{{1.040843, 1.542485, -0.008290},{1.040843, 1.541204, -0.007983},{
      1.041645, 1.541331, -0.007983},{1.041249, 1.542549, -0.008290}}],
    Polygon[{{1.040843, 1.541204, -0.007983},{1.040843, 1.539987, -0.007479},{
      1.042021, 1.540173, -0.007479},{1.041645, 1.541331, -0.007983}}],
    Polygon[{{1.040843, 1.539987, -0.007479},{1.040843, 1.538864, -0.006791},{
      1.042368, 1.539105, -0.006791},{1.042021, 1.540173, -0.007479}}],
    Polygon[{{1.040843, 1.538864, -0.006791},{1.040843, 1.537862, -0.005935},{
      1.042678, 1.538153, -0.005935},{1.042368, 1.539105, -0.006791}}],
    Polygon[{{1.040843, 1.537862, -0.005935},{1.040843, 1.537007, -0.004934},{
      1.042942, 1.537339, -0.004934},{1.042678, 1.538153, -0.005935}}],
    Polygon[{{1.040843, 1.537007, -0.004934},{1.040843, 1.536319, -0.003811},{
      1.043154, 1.536685, -0.003811},{1.042942, 1.537339, -0.004934}}],
    Polygon[{{1.040843, 1.536319, -0.003811},{1.040843, 1.535815, -0.002594},{
      1.043310, 1.536205, -0.002594},{1.043154, 1.536685, -0.003811}}],
    Polygon[{{1.040843, 1.535815, -0.002594},{1.040843, 1.535507, -0.001313},{
      1.043405, 1.535913, -0.001313},{1.043310, 1.536205, -0.002594}}],
    Polygon[{{1.040843, 1.535507, -0.001313},{1.040843, 1.535404, 0.000000},{
      1.043437, 1.535815, 0.000000},{1.043405, 1.535913, -0.001313}}],
    Polygon[{{1.040843, 1.535404, 0.000000},{1.040843, 1.535507, 0.001313},{
      1.043405, 1.535913, 0.001313},{1.043437, 1.535815, 0.000000}}],
    Polygon[{{1.040843, 1.535507, 0.001313},{1.040843, 1.535815, 0.002594},{
      1.043310, 1.536205, 0.002594},{1.043405, 1.535913, 0.001313}}],
    Polygon[{{1.040843, 1.535815, 0.002594},{1.040843, 1.536319, 0.003811},{
      1.043154, 1.536685, 0.003811},{1.043310, 1.536205, 0.002594}}],
    Polygon[{{1.040843, 1.536319, 0.003811},{1.040843, 1.537007, 0.004934},{
      1.042942, 1.537339, 0.004934},{1.043154, 1.536685, 0.003811}}],
    Polygon[{{1.040843, 1.537007, 0.004934},{1.040843, 1.537862, 0.005935},{
      1.042678, 1.538153, 0.005935},{1.042942, 1.537339, 0.004934}}],
    Polygon[{{1.040843, 1.537862, 0.005935},{1.040843, 1.538864, 0.006791},{
      1.042368, 1.539105, 0.006791},{1.042678, 1.538153, 0.005935}}],
    Polygon[{{1.040843, 1.538864, 0.006791},{1.040843, 1.539987, 0.007479},{
      1.042021, 1.540173, 0.007479},{1.042368, 1.539105, 0.006791}}],
    Polygon[{{1.040843, 1.539987, 0.007479},{1.040843, 1.541204, 0.007983},{
      1.041645, 1.541331, 0.007983},{1.042021, 1.540173, 0.007479}}],
    Polygon[{{1.040843, 1.541204, 0.007983},{1.040843, 1.542485, 0.008290},{
      1.041249, 1.542549, 0.008290},{1.041645, 1.541331, 0.007983}}],
    Polygon[{{1.041249, 1.542549, -0.008290},{1.041645, 1.541331, -0.007983},{
      1.042368, 1.541699, -0.007983},{1.041615, 1.542735, -0.008290}}],
    Polygon[{{1.041645, 1.541331, -0.007983},{1.042021, 1.540173, -0.007479},{
      1.043083, 1.540715, -0.007479},{1.042368, 1.541699, -0.007983}}],
    Polygon[{{1.042021, 1.540173, -0.007479},{1.042368, 1.539105, -0.006791},{
      1.043743, 1.539806, -0.006791},{1.043083, 1.540715, -0.007479}}],
    Polygon[{{1.042368, 1.539105, -0.006791},{1.042678, 1.538153, -0.005935},{
      1.044332, 1.538996, -0.005935},{1.043743, 1.539806, -0.006791}}],
    Polygon[{{1.042678, 1.538153, -0.005935},{1.042942, 1.537339, -0.004934},{
      1.044835, 1.538304, -0.004934},{1.044332, 1.538996, -0.005935}}],
    Polygon[{{1.042942, 1.537339, -0.004934},{1.043154, 1.536685, -0.003811},{
      1.045239, 1.537747, -0.003811},{1.044835, 1.538304, -0.004934}}],
    Polygon[{{1.043154, 1.536685, -0.003811},{1.043310, 1.536205, -0.002594},{
      1.045536, 1.537339, -0.002594},{1.045239, 1.537747, -0.003811}}],
    Polygon[{{1.043310, 1.536205, -0.002594},{1.043405, 1.535913, -0.001313},{
      1.045716, 1.537091, -0.001313},{1.045536, 1.537339, -0.002594}}],
    Polygon[{{1.043405, 1.535913, -0.001313},{1.043437, 1.535815, 0.000000},{
      1.045777, 1.537007, 0.000000},{1.045716, 1.537091, -0.001313}}],
    Polygon[{{1.043437, 1.535815, 0.000000},{1.043405, 1.535913, 0.001313},{
      1.045716, 1.537091, 0.001313},{1.045777, 1.537007, 0.000000}}],
    Polygon[{{1.043405, 1.535913, 0.001313},{1.043310, 1.536205, 0.002594},{
      1.045536, 1.537339, 0.002594},{1.045716, 1.537091, 0.001313}}],
    Polygon[{{1.043310, 1.536205, 0.002594},{1.043154, 1.536685, 0.003811},{
      1.045239, 1.537747, 0.003811},{1.045536, 1.537339, 0.002594}}],
    Polygon[{{1.043154, 1.536685, 0.003811},{1.042942, 1.537339, 0.004934},{
      1.044835, 1.538304, 0.004934},{1.045239, 1.537747, 0.003811}}],
    Polygon[{{1.042942, 1.537339, 0.004934},{1.042678, 1.538153, 0.005935},{
      1.044332, 1.538996, 0.005935},{1.044835, 1.538304, 0.004934}}],
    Polygon[{{1.042678, 1.538153, 0.005935},{1.042368, 1.539105, 0.006791},{
      1.043743, 1.539806, 0.006791},{1.044332, 1.538996, 0.005935}}],
    Polygon[{{1.042368, 1.539105, 0.006791},{1.042021, 1.540173, 0.007479},{
      1.043083, 1.540715, 0.007479},{1.043743, 1.539806, 0.006791}}],
    Polygon[{{1.042021, 1.540173, 0.007479},{1.041645, 1.541331, 0.007983},{
      1.042368, 1.541699, 0.007983},{1.043083, 1.540715, 0.007479}}],
    Polygon[{{1.041645, 1.541331, 0.007983},{1.041249, 1.542549, 0.008290},{
      1.041615, 1.542735, 0.008290},{1.042368, 1.541699, 0.007983}}],
    Polygon[{{1.041615, 1.542735, -0.008290},{1.042368, 1.541699, -0.007983},{
      1.042942, 1.542273, -0.007983},{1.041906, 1.543026, -0.008290}}],
    Polygon[{{1.042368, 1.541699, -0.007983},{1.043083, 1.540715, -0.007479},{
      1.043926, 1.541558, -0.007479},{1.042942, 1.542273, -0.007983}}],
    Polygon[{{1.043083, 1.540715, -0.007479},{1.043743, 1.539806, -0.006791},{
      1.044835, 1.540898, -0.006791},{1.043926, 1.541558, -0.007479}}],
    Polygon[{{1.043743, 1.539806, -0.006791},{1.044332, 1.538996, -0.005935},{
      1.045645, 1.540309, -0.005935},{1.044835, 1.540898, -0.006791}}],
    Polygon[{{1.044332, 1.538996, -0.005935},{1.044835, 1.538304, -0.004934},{
      1.046337, 1.539806, -0.004934},{1.045645, 1.540309, -0.005935}}],
    Polygon[{{1.044835, 1.538304, -0.004934},{1.045239, 1.537747, -0.003811},{
      1.046894, 1.539402, -0.003811},{1.046337, 1.539806, -0.004934}}],
    Polygon[{{1.045239, 1.537747, -0.003811},{1.045536, 1.537339, -0.002594},{
      1.047302, 1.539105, -0.002594},{1.046894, 1.539402, -0.003811}}],
    Polygon[{{1.045536, 1.537339, -0.002594},{1.045716, 1.537091, -0.001313},{
      1.047550, 1.538925, -0.001313},{1.047302, 1.539105, -0.002594}}],
    Polygon[{{1.045716, 1.537091, -0.001313},{1.045777, 1.537007, 0.000000},{
      1.047634, 1.538864, 0.000000},{1.047550, 1.538925, -0.001313}}],
    Polygon[{{1.045777, 1.537007, 0.000000},{1.045716, 1.537091, 0.001313},{
      1.047550, 1.538925, 0.001313},{1.047634, 1.538864, 0.000000}}],
    Polygon[{{1.045716, 1.537091, 0.001313},{1.045536, 1.537339, 0.002594},{
      1.047302, 1.539105, 0.002594},{1.047550, 1.538925, 0.001313}}],
    Polygon[{{1.045536, 1.537339, 0.002594},{1.045239, 1.537747, 0.003811},{
      1.046894, 1.539402, 0.003811},{1.047302, 1.539105, 0.002594}}],
    Polygon[{{1.045239, 1.537747, 0.003811},{1.044835, 1.538304, 0.004934},{
      1.046337, 1.539806, 0.004934},{1.046894, 1.539402, 0.003811}}],
    Polygon[{{1.044835, 1.538304, 0.004934},{1.044332, 1.538996, 0.005935},{
      1.045645, 1.540309, 0.005935},{1.046337, 1.539806, 0.004934}}],
    Polygon[{{1.044332, 1.538996, 0.005935},{1.043743, 1.539806, 0.006791},{
      1.044835, 1.540898, 0.006791},{1.045645, 1.540309, 0.005935}}],
    Polygon[{{1.043743, 1.539806, 0.006791},{1.043083, 1.540715, 0.007479},{
      1.043926, 1.541558, 0.007479},{1.044835, 1.540898, 0.006791}}],
    Polygon[{{1.043083, 1.540715, 0.007479},{1.042368, 1.541699, 0.007983},{
      1.042942, 1.542273, 0.007983},{1.043926, 1.541558, 0.007479}}],
    Polygon[{{1.042368, 1.541699, 0.007983},{1.041615, 1.542735, 0.008290},{
      1.041906, 1.543026, 0.008290},{1.042942, 1.542273, 0.007983}}],
    Polygon[{{1.041906, 1.543026, -0.008290},{1.042942, 1.542273, -0.007983},{
      1.043310, 1.542996, -0.007983},{1.042092, 1.543392, -0.008290}}],
    Polygon[{{1.042942, 1.542273, -0.007983},{1.043926, 1.541558, -0.007479},{
      1.044468, 1.542620, -0.007479},{1.043310, 1.542996, -0.007983}}],
    Polygon[{{1.043926, 1.541558, -0.007479},{1.044835, 1.540898, -0.006791},{
      1.045536, 1.542273, -0.006791},{1.044468, 1.542620, -0.007479}}],
    Polygon[{{1.044835, 1.540898, -0.006791},{1.045645, 1.540309, -0.005935},{
      1.046488, 1.541963, -0.005935},{1.045536, 1.542273, -0.006791}}],
    Polygon[{{1.045645, 1.540309, -0.005935},{1.046337, 1.539806, -0.004934},{
      1.047302, 1.541699, -0.004934},{1.046488, 1.541963, -0.005935}}],
    Polygon[{{1.046337, 1.539806, -0.004934},{1.046894, 1.539402, -0.003811},{
      1.047956, 1.541487, -0.003811},{1.047302, 1.541699, -0.004934}}],
    Polygon[{{1.046894, 1.539402, -0.003811},{1.047302, 1.539105, -0.002594},{
      1.048436, 1.541331, -0.002594},{1.047956, 1.541487, -0.003811}}],
    Polygon[{{1.047302, 1.539105, -0.002594},{1.047550, 1.538925, -0.001313},{
      1.048728, 1.541236, -0.001313},{1.048436, 1.541331, -0.002594}}],
    Polygon[{{1.047550, 1.538925, -0.001313},{1.047634, 1.538864, 0.000000},{
      1.048826, 1.541204, 0.000000},{1.048728, 1.541236, -0.001313}}],
    Polygon[{{1.047634, 1.538864, 0.000000},{1.047550, 1.538925, 0.001313},{
      1.048728, 1.541236, 0.001313},{1.048826, 1.541204, 0.000000}}],
    Polygon[{{1.047550, 1.538925, 0.001313},{1.047302, 1.539105, 0.002594},{
      1.048436, 1.541331, 0.002594},{1.048728, 1.541236, 0.001313}}],
    Polygon[{{1.047302, 1.539105, 0.002594},{1.046894, 1.539402, 0.003811},{
      1.047956, 1.541487, 0.003811},{1.048436, 1.541331, 0.002594}}],
    Polygon[{{1.046894, 1.539402, 0.003811},{1.046337, 1.539806, 0.004934},{
      1.047302, 1.541699, 0.004934},{1.047956, 1.541487, 0.003811}}],
    Polygon[{{1.046337, 1.539806, 0.004934},{1.045645, 1.540309, 0.005935},{
      1.046488, 1.541963, 0.005935},{1.047302, 1.541699, 0.004934}}],
    Polygon[{{1.045645, 1.540309, 0.005935},{1.044835, 1.540898, 0.006791},{
      1.045536, 1.542273, 0.006791},{1.046488, 1.541963, 0.005935}}],
    Polygon[{{1.044835, 1.540898, 0.006791},{1.043926, 1.541558, 0.007479},{
      1.044468, 1.542620, 0.007479},{1.045536, 1.542273, 0.006791}}],
    Polygon[{{1.043926, 1.541558, 0.007479},{1.042942, 1.542273, 0.007983},{
      1.043310, 1.542996, 0.007983},{1.044468, 1.542620, 0.007479}}],
    Polygon[{{1.042942, 1.542273, 0.007983},{1.041906, 1.543026, 0.008290},{
      1.042092, 1.543392, 0.008290},{1.043310, 1.542996, 0.007983}}],
    Polygon[{{1.042092, 1.543392, -0.008290},{1.043310, 1.542996, -0.007983},{
      1.043437, 1.543797, -0.007983},{1.042156, 1.543797, -0.008290}}],
    Polygon[{{1.043310, 1.542996, -0.007983},{1.044468, 1.542620, -0.007479},{
      1.044654, 1.543797, -0.007479},{1.043437, 1.543797, -0.007983}}],
    Polygon[{{1.044468, 1.542620, -0.007479},{1.045536, 1.542273, -0.006791},{
      1.045777, 1.543797, -0.006791},{1.044654, 1.543797, -0.007479}}],
    Polygon[{{1.045536, 1.542273, -0.006791},{1.046488, 1.541963, -0.005935},{
      1.046779, 1.543797, -0.005935},{1.045777, 1.543797, -0.006791}}],
    Polygon[{{1.046488, 1.541963, -0.005935},{1.047302, 1.541699, -0.004934},{
      1.047634, 1.543797, -0.004934},{1.046779, 1.543797, -0.005935}}],
    Polygon[{{1.047302, 1.541699, -0.004934},{1.047956, 1.541487, -0.003811},{
      1.048322, 1.543797, -0.003811},{1.047634, 1.543797, -0.004934}}],
    Polygon[{{1.047956, 1.541487, -0.003811},{1.048436, 1.541331, -0.002594},{
      1.048826, 1.543797, -0.002594},{1.048322, 1.543797, -0.003811}}],
    Polygon[{{1.048436, 1.541331, -0.002594},{1.048728, 1.541236, -0.001313},{
      1.049134, 1.543797, -0.001313},{1.048826, 1.543797, -0.002594}}],
    Polygon[{{1.048728, 1.541236, -0.001313},{1.048826, 1.541204, 0.000000},{
      1.049237, 1.543797, 0.000000},{1.049134, 1.543797, -0.001313}}],
    Polygon[{{1.048826, 1.541204, 0.000000},{1.048728, 1.541236, 0.001313},{
      1.049134, 1.543797, 0.001313},{1.049237, 1.543797, 0.000000}}],
    Polygon[{{1.048728, 1.541236, 0.001313},{1.048436, 1.541331, 0.002594},{
      1.048826, 1.543797, 0.002594},{1.049134, 1.543797, 0.001313}}],
    Polygon[{{1.048436, 1.541331, 0.002594},{1.047956, 1.541487, 0.003811},{
      1.048322, 1.543797, 0.003811},{1.048826, 1.543797, 0.002594}}],
    Polygon[{{1.047956, 1.541487, 0.003811},{1.047302, 1.541699, 0.004934},{
      1.047634, 1.543797, 0.004934},{1.048322, 1.543797, 0.003811}}],
    Polygon[{{1.047302, 1.541699, 0.004934},{1.046488, 1.541963, 0.005935},{
      1.046779, 1.543797, 0.005935},{1.047634, 1.543797, 0.004934}}],
    Polygon[{{1.046488, 1.541963, 0.005935},{1.045536, 1.542273, 0.006791},{
      1.045777, 1.543797, 0.006791},{1.046779, 1.543797, 0.005935}}],
    Polygon[{{1.045536, 1.542273, 0.006791},{1.044468, 1.542620, 0.007479},{
      1.044654, 1.543797, 0.007479},{1.045777, 1.543797, 0.006791}}],
    Polygon[{{1.044468, 1.542620, 0.007479},{1.043310, 1.542996, 0.007983},{
      1.043437, 1.543797, 0.007983},{1.044654, 1.543797, 0.007479}}],
    Polygon[{{1.043310, 1.542996, 0.007983},{1.042092, 1.543392, 0.008290},{
      1.042156, 1.543797, 0.008290},{1.043437, 1.543797, 0.007983}}],
    Polygon[{{0.790412, 1.193376, -0.076398},{0.802215, 1.193376, -0.073564},{
      0.801045, 1.200762, -0.073564},{0.789820, 1.197115, -0.076398}}],
    Polygon[{{0.802215, 1.193376, -0.073564},{0.813428, 1.193376, -0.068920},{
      0.811710, 1.204227, -0.068920},{0.801045, 1.200762, -0.073564}}],
    Polygon[{{0.813428, 1.193376, -0.068920},{0.823777, 1.193376, -0.062578},{
      0.821552, 1.207425, -0.062578},{0.811710, 1.204227, -0.068920}}],
    Polygon[{{0.823777, 1.193376, -0.062578},{0.833007, 1.193376, -0.054695},{
      0.830330, 1.210277, -0.054695},{0.821552, 1.207425, -0.062578}}],
    Polygon[{{0.833007, 1.193376, -0.054695},{0.840890, 1.193376, -0.045465},{
      0.837827, 1.212713, -0.045465},{0.830330, 1.210277, -0.054695}}],
    Polygon[{{0.840890, 1.193376, -0.045465},{0.847232, 1.193376, -0.035116},{
      0.843859, 1.214673, -0.035116},{0.837827, 1.212713, -0.045465}}],
    Polygon[{{0.847232, 1.193376, -0.035116},{0.851877, 1.193376, -0.023903},{
      0.848276, 1.216108, -0.023903},{0.843859, 1.214673, -0.035116}}],
    Polygon[{{0.851877, 1.193376, -0.023903},{0.854710, 1.193376, -0.012100},{
      0.850971, 1.216984, -0.012100},{0.848276, 1.216108, -0.023903}}],
    Polygon[{{0.854710, 1.193376, -0.012100},{0.855662, 1.193376, 0.000000},{
      0.851877, 1.217278, 0.000000},{0.850971, 1.216984, -0.012100}}],
    Polygon[{{0.855662, 1.193376, 0.000000},{0.854710, 1.193376, 0.012100},{
      0.850971, 1.216984, 0.012100},{0.851877, 1.217278, 0.000000}}],
    Polygon[{{0.854710, 1.193376, 0.012100},{0.851877, 1.193376, 0.023903},{
      0.848276, 1.216108, 0.023903},{0.850971, 1.216984, 0.012100}}],
    Polygon[{{0.851877, 1.193376, 0.023903},{0.847232, 1.193376, 0.035116},{
      0.843859, 1.214673, 0.035116},{0.848276, 1.216108, 0.023903}}],
    Polygon[{{0.847232, 1.193376, 0.035116},{0.840890, 1.193376, 0.045465},{
      0.837827, 1.212713, 0.045465},{0.843859, 1.214673, 0.035116}}],
    Polygon[{{0.840890, 1.193376, 0.045465},{0.833007, 1.193376, 0.054695},{
      0.830330, 1.210277, 0.054695},{0.837827, 1.212713, 0.045465}}],
    Polygon[{{0.833007, 1.193376, 0.054695},{0.823777, 1.193376, 0.062578},{
      0.821552, 1.207425, 0.062578},{0.830330, 1.210277, 0.054695}}],
    Polygon[{{0.823777, 1.193376, 0.062578},{0.813428, 1.193376, 0.068920},{
      0.811710, 1.204227, 0.068920},{0.821552, 1.207425, 0.062578}}],
    Polygon[{{0.813428, 1.193376, 0.068920},{0.802215, 1.193376, 0.073564},{
      0.801045, 1.200762, 0.073564},{0.811710, 1.204227, 0.068920}}],
    Polygon[{{0.802215, 1.193376, 0.073564},{0.790412, 1.193376, 0.076398},{
      0.789820, 1.197115, 0.076398},{0.801045, 1.200762, 0.073564}}],
    Polygon[{{0.789820, 1.197115, -0.076398},{0.801045, 1.200762, -0.073564},{
      0.797650, 1.207425, -0.073564},{0.788101, 1.200488, -0.076398}}],
    Polygon[{{0.801045, 1.200762, -0.073564},{0.811710, 1.204227, -0.068920},{
      0.806722, 1.214017, -0.068920},{0.797650, 1.207425, -0.073564}}],
    Polygon[{{0.811710, 1.204227, -0.068920},{0.821552, 1.207425, -0.062578},{
      0.815094, 1.220100, -0.062578},{0.806722, 1.214017, -0.068920}}],
    Polygon[{{0.821552, 1.207425, -0.062578},{0.830330, 1.210277, -0.054695},{
      0.822561, 1.225525, -0.054695},{0.815094, 1.220100, -0.062578}}],
    Polygon[{{0.830330, 1.210277, -0.054695},{0.837827, 1.212713, -0.045465},{
      0.828939, 1.230158, -0.045465},{0.822561, 1.225525, -0.054695}}],
    Polygon[{{0.837827, 1.212713, -0.045465},{0.843859, 1.214673, -0.035116},{
      0.834069, 1.233886, -0.035116},{0.828939, 1.230158, -0.045465}}],
    Polygon[{{0.843859, 1.214673, -0.035116},{0.848276, 1.216108, -0.023903},{
      0.837827, 1.236616, -0.023903},{0.834069, 1.233886, -0.035116}}],
    Polygon[{{0.848276, 1.216108, -0.023903},{0.850971, 1.216984, -0.012100},{
      0.840119, 1.238281, -0.012100},{0.837827, 1.236616, -0.023903}}],
    Polygon[{{0.850971, 1.216984, -0.012100},{0.851877, 1.217278, 0.000000},{
      0.840890, 1.238841, 0.000000},{0.840119, 1.238281, -0.012100}}],
    Polygon[{{0.851877, 1.217278, 0.000000},{0.850971, 1.216984, 0.012100},{
      0.840119, 1.238281, 0.012100},{0.840890, 1.238841, 0.000000}}],
    Polygon[{{0.850971, 1.216984, 0.012100},{0.848276, 1.216108, 0.023903},{
      0.837827, 1.236616, 0.023903},{0.840119, 1.238281, 0.012100}}],
    Polygon[{{0.848276, 1.216108, 0.023903},{0.843859, 1.214673, 0.035116},{
      0.834069, 1.233886, 0.035116},{0.837827, 1.236616, 0.023903}}],
    Polygon[{{0.843859, 1.214673, 0.035116},{0.837827, 1.212713, 0.045465},{
      0.828939, 1.230158, 0.045465},{0.834069, 1.233886, 0.035116}}],
    Polygon[{{0.837827, 1.212713, 0.045465},{0.830330, 1.210277, 0.054695},{
      0.822561, 1.225525, 0.054695},{0.828939, 1.230158, 0.045465}}],
    Polygon[{{0.830330, 1.210277, 0.054695},{0.821552, 1.207425, 0.062578},{
      0.815094, 1.220100, 0.062578},{0.822561, 1.225525, 0.054695}}],
    Polygon[{{0.821552, 1.207425, 0.062578},{0.811710, 1.204227, 0.068920},{
      0.806722, 1.214017, 0.068920},{0.815094, 1.220100, 0.062578}}],
    Polygon[{{0.811710, 1.204227, 0.068920},{0.801045, 1.200762, 0.073564},{
      0.797650, 1.207425, 0.073564},{0.806722, 1.214017, 0.068920}}],
    Polygon[{{0.801045, 1.200762, 0.073564},{0.789820, 1.197115, 0.076398},{
      0.788101, 1.200488, 0.076398},{0.797650, 1.207425, 0.073564}}],
    Polygon[{{0.788101, 1.200488, -0.076398},{0.797650, 1.207425, -0.073564},{
      0.792362, 1.212713, -0.073564},{0.785425, 1.203165, -0.076398}}],
    Polygon[{{0.797650, 1.207425, -0.073564},{0.806722, 1.214017, -0.068920},{
      0.798953, 1.221785, -0.068920},{0.792362, 1.212713, -0.073564}}],
    Polygon[{{0.806722, 1.214017, -0.068920},{0.815094, 1.220100, -0.062578},{
      0.805036, 1.230158, -0.062578},{0.798953, 1.221785, -0.068920}}],
    Polygon[{{0.815094, 1.220100, -0.062578},{0.822561, 1.225525, -0.054695},{
      0.810461, 1.237625, -0.054695},{0.805036, 1.230158, -0.062578}}],
    Polygon[{{0.822561, 1.225525, -0.054695},{0.828939, 1.230158, -0.045465},{
      0.815094, 1.244002, -0.045465},{0.810461, 1.237625, -0.054695}}],
    Polygon[{{0.828939, 1.230158, -0.045465},{0.834069, 1.233886, -0.035116},{
      0.818822, 1.249133, -0.035116},{0.815094, 1.244002, -0.045465}}],
    Polygon[{{0.834069, 1.233886, -0.035116},{0.837827, 1.236616, -0.023903},{
      0.821552, 1.252891, -0.023903},{0.818822, 1.249133, -0.035116}}],
    Polygon[{{0.837827, 1.236616, -0.023903},{0.840119, 1.238281, -0.012100},{
      0.823218, 1.255183, -0.012100},{0.821552, 1.252891, -0.023903}}],
    Polygon[{{0.840119, 1.238281, -0.012100},{0.840890, 1.238841, 0.000000},{
      0.823777, 1.255953, 0.000000},{0.823218, 1.255183, -0.012100}}],
    Polygon[{{0.840890, 1.238841, 0.000000},{0.840119, 1.238281, 0.012100},{
      0.823218, 1.255183, 0.012100},{0.823777, 1.255953, 0.000000}}],
    Polygon[{{0.840119, 1.238281, 0.012100},{0.837827, 1.236616, 0.023903},{
      0.821552, 1.252891, 0.023903},{0.823218, 1.255183, 0.012100}}],
    Polygon[{{0.837827, 1.236616, 0.023903},{0.834069, 1.233886, 0.035116},{
      0.818822, 1.249133, 0.035116},{0.821552, 1.252891, 0.023903}}],
    Polygon[{{0.834069, 1.233886, 0.035116},{0.828939, 1.230158, 0.045465},{
      0.815094, 1.244002, 0.045465},{0.818822, 1.249133, 0.035116}}],
    Polygon[{{0.828939, 1.230158, 0.045465},{0.822561, 1.225525, 0.054695},{
      0.810461, 1.237625, 0.054695},{0.815094, 1.244002, 0.045465}}],
    Polygon[{{0.822561, 1.225525, 0.054695},{0.815094, 1.220100, 0.062578},{
      0.805036, 1.230158, 0.062578},{0.810461, 1.237625, 0.054695}}],
    Polygon[{{0.815094, 1.220100, 0.062578},{0.806722, 1.214017, 0.068920},{
      0.798953, 1.221785, 0.068920},{0.805036, 1.230158, 0.062578}}],
    Polygon[{{0.806722, 1.214017, 0.068920},{0.797650, 1.207425, 0.073564},{
      0.792362, 1.212713, 0.073564},{0.798953, 1.221785, 0.068920}}],
    Polygon[{{0.797650, 1.207425, 0.073564},{0.788101, 1.200488, 0.076398},{
      0.785425, 1.203165, 0.076398},{0.792362, 1.212713, 0.073564}}],
    Polygon[{{0.785425, 1.203165, -0.076398},{0.792362, 1.212713, -0.073564},{
      0.785698, 1.216108, -0.073564},{0.782051, 1.204884, -0.076398}}],
    Polygon[{{0.792362, 1.212713, -0.073564},{0.798953, 1.221785, -0.068920},{
      0.789164, 1.226773, -0.068920},{0.785698, 1.216108, -0.073564}}],
    Polygon[{{0.798953, 1.221785, -0.068920},{0.805036, 1.230158, -0.062578},{
      0.792362, 1.236616, -0.062578},{0.789164, 1.226773, -0.068920}}],
    Polygon[{{0.805036, 1.230158, -0.062578},{0.810461, 1.237625, -0.054695},{
      0.795214, 1.245394, -0.054695},{0.792362, 1.236616, -0.062578}}],
    Polygon[{{0.810461, 1.237625, -0.054695},{0.815094, 1.244002, -0.045465},{
      0.797650, 1.252891, -0.045465},{0.795214, 1.245394, -0.054695}}],
    Polygon[{{0.815094, 1.244002, -0.045465},{0.818822, 1.249133, -0.035116},{
      0.799609, 1.258922, -0.035116},{0.797650, 1.252891, -0.045465}}],
    Polygon[{{0.818822, 1.249133, -0.035116},{0.821552, 1.252891, -0.023903},{
      0.801045, 1.263340, -0.023903},{0.799609, 1.258922, -0.035116}}],
    Polygon[{{0.821552, 1.252891, -0.023903},{0.823218, 1.255183, -0.012100},{
      0.801920, 1.266034, -0.012100},{0.801045, 1.263340, -0.023903}}],
    Polygon[{{0.823218, 1.255183, -0.012100},{0.823777, 1.255953, 0.000000},{
      0.802215, 1.266940, 0.000000},{0.801920, 1.266034, -0.012100}}],
    Polygon[{{0.823777, 1.255953, 0.000000},{0.823218, 1.255183, 0.012100},{
      0.801920, 1.266034, 0.012100},{0.802215, 1.266940, 0.000000}}],
    Polygon[{{0.823218, 1.255183, 0.012100},{0.821552, 1.252891, 0.023903},{
      0.801045, 1.263340, 0.023903},{0.801920, 1.266034, 0.012100}}],
    Polygon[{{0.821552, 1.252891, 0.023903},{0.818822, 1.249133, 0.035116},{
      0.799609, 1.258922, 0.035116},{0.801045, 1.263340, 0.023903}}],
    Polygon[{{0.818822, 1.249133, 0.035116},{0.815094, 1.244002, 0.045465},{
      0.797650, 1.252891, 0.045465},{0.799609, 1.258922, 0.035116}}],
    Polygon[{{0.815094, 1.244002, 0.045465},{0.810461, 1.237625, 0.054695},{
      0.795214, 1.245394, 0.054695},{0.797650, 1.252891, 0.045465}}],
    Polygon[{{0.810461, 1.237625, 0.054695},{0.805036, 1.230158, 0.062578},{
      0.792362, 1.236616, 0.062578},{0.795214, 1.245394, 0.054695}}],
    Polygon[{{0.805036, 1.230158, 0.062578},{0.798953, 1.221785, 0.068920},{
      0.789164, 1.226773, 0.068920},{0.792362, 1.236616, 0.062578}}],
    Polygon[{{0.798953, 1.221785, 0.068920},{0.792362, 1.212713, 0.073564},{
      0.785698, 1.216108, 0.073564},{0.789164, 1.226773, 0.068920}}],
    Polygon[{{0.792362, 1.212713, 0.073564},{0.785425, 1.203165, 0.076398},{
      0.782051, 1.204884, 0.076398},{0.785698, 1.216108, 0.073564}}],
    Polygon[{{0.782051, 1.204884, -0.076398},{0.785698, 1.216108, -0.073564},{
      0.778312, 1.217278, -0.073564},{0.778312, 1.205476, -0.076398}}],
    Polygon[{{0.785698, 1.216108, -0.073564},{0.789164, 1.226773, -0.068920},{
      0.778312, 1.228492, -0.068920},{0.778312, 1.217278, -0.073564}}],
    Polygon[{{0.789164, 1.226773, -0.068920},{0.792362, 1.236616, -0.062578},{
      0.778312, 1.238841, -0.062578},{0.778312, 1.228492, -0.068920}}],
    Polygon[{{0.792362, 1.236616, -0.062578},{0.795214, 1.245394, -0.054695},{
      0.778312, 1.248071, -0.054695},{0.778312, 1.238841, -0.062578}}],
    Polygon[{{0.795214, 1.245394, -0.054695},{0.797650, 1.252891, -0.045465},{
      0.778312, 1.255953, -0.045465},{0.778312, 1.248071, -0.054695}}],
    Polygon[{{0.797650, 1.252891, -0.045465},{0.799609, 1.258922, -0.035116},{
      0.778312, 1.262295, -0.035116},{0.778312, 1.255953, -0.045465}}],
    Polygon[{{0.799609, 1.258922, -0.035116},{0.801045, 1.263340, -0.023903},{
      0.778312, 1.266940, -0.023903},{0.778312, 1.262295, -0.035116}}],
    Polygon[{{0.801045, 1.263340, -0.023903},{0.801920, 1.266034, -0.012100},{
      0.778312, 1.269774, -0.012100},{0.778312, 1.266940, -0.023903}}],
    Polygon[{{0.801920, 1.266034, -0.012100},{0.802215, 1.266940, 0.000000},{
      0.778312, 1.270726, 0.000000},{0.778312, 1.269774, -0.012100}}],
    Polygon[{{0.802215, 1.266940, 0.000000},{0.801920, 1.266034, 0.012100},{
      0.778312, 1.269774, 0.012100},{0.778312, 1.270726, 0.000000}}],
    Polygon[{{0.801920, 1.266034, 0.012100},{0.801045, 1.263340, 0.023903},{
      0.778312, 1.266940, 0.023903},{0.778312, 1.269774, 0.012100}}],
    Polygon[{{0.801045, 1.263340, 0.023903},{0.799609, 1.258922, 0.035116},{
      0.778312, 1.262295, 0.035116},{0.778312, 1.266940, 0.023903}}],
    Polygon[{{0.799609, 1.258922, 0.035116},{0.797650, 1.252891, 0.045465},{
      0.778312, 1.255953, 0.045465},{0.778312, 1.262295, 0.035116}}],
    Polygon[{{0.797650, 1.252891, 0.045465},{0.795214, 1.245394, 0.054695},{
      0.778312, 1.248071, 0.054695},{0.778312, 1.255953, 0.045465}}],
    Polygon[{{0.795214, 1.245394, 0.054695},{0.792362, 1.236616, 0.062578},{
      0.778312, 1.238841, 0.062578},{0.778312, 1.248071, 0.054695}}],
    Polygon[{{0.792362, 1.236616, 0.062578},{0.789164, 1.226773, 0.068920},{
      0.778312, 1.228492, 0.068920},{0.778312, 1.238841, 0.062578}}],
    Polygon[{{0.789164, 1.226773, 0.068920},{0.785698, 1.216108, 0.073564},{
      0.778312, 1.217278, 0.073564},{0.778312, 1.228492, 0.068920}}],
    Polygon[{{0.785698, 1.216108, 0.073564},{0.782051, 1.204884, 0.076398},{
      0.778312, 1.205476, 0.076398},{0.778312, 1.217278, 0.073564}}],
    Polygon[{{0.778312, 1.205476, -0.076398},{0.778312, 1.217278, -0.073564},{
      0.770926, 1.216108, -0.073564},{0.774573, 1.204884, -0.076398}}],
    Polygon[{{0.778312, 1.217278, -0.073564},{0.778312, 1.228492, -0.068920},{
      0.767461, 1.226773, -0.068920},{0.770926, 1.216108, -0.073564}}],
    Polygon[{{0.778312, 1.228492, -0.068920},{0.778312, 1.238841, -0.062578},{
      0.764263, 1.236616, -0.062578},{0.767461, 1.226773, -0.068920}}],
    Polygon[{{0.778312, 1.238841, -0.062578},{0.778312, 1.248071, -0.054695},{
      0.761411, 1.245394, -0.054695},{0.764263, 1.236616, -0.062578}}],
    Polygon[{{0.778312, 1.248071, -0.054695},{0.778312, 1.255953, -0.045465},{
      0.758975, 1.252891, -0.045465},{0.761411, 1.245394, -0.054695}}],
    Polygon[{{0.778312, 1.255953, -0.045465},{0.778312, 1.262295, -0.035116},{
      0.757015, 1.258922, -0.035116},{0.758975, 1.252891, -0.045465}}],
    Polygon[{{0.778312, 1.262295, -0.035116},{0.778312, 1.266940, -0.023903},{
      0.755579, 1.263340, -0.023903},{0.757015, 1.258922, -0.035116}}],
    Polygon[{{0.778312, 1.266940, -0.023903},{0.778312, 1.269774, -0.012100},{
      0.754704, 1.266034, -0.012100},{0.755579, 1.263340, -0.023903}}],
    Polygon[{{0.778312, 1.269774, -0.012100},{0.778312, 1.270726, 0.000000},{
      0.754410, 1.266940, 0.000000},{0.754704, 1.266034, -0.012100}}],
    Polygon[{{0.778312, 1.270726, 0.000000},{0.778312, 1.269774, 0.012100},{
      0.754704, 1.266034, 0.012100},{0.754410, 1.266940, 0.000000}}],
    Polygon[{{0.778312, 1.269774, 0.012100},{0.778312, 1.266940, 0.023903},{
      0.755579, 1.263340, 0.023903},{0.754704, 1.266034, 0.012100}}],
    Polygon[{{0.778312, 1.266940, 0.023903},{0.778312, 1.262295, 0.035116},{
      0.757015, 1.258922, 0.035116},{0.755579, 1.263340, 0.023903}}],
    Polygon[{{0.778312, 1.262295, 0.035116},{0.778312, 1.255953, 0.045465},{
      0.758975, 1.252891, 0.045465},{0.757015, 1.258922, 0.035116}}],
    Polygon[{{0.778312, 1.255953, 0.045465},{0.778312, 1.248071, 0.054695},{
      0.761411, 1.245394, 0.054695},{0.758975, 1.252891, 0.045465}}],
    Polygon[{{0.778312, 1.248071, 0.054695},{0.778312, 1.238841, 0.062578},{
      0.764263, 1.236616, 0.062578},{0.761411, 1.245394, 0.054695}}],
    Polygon[{{0.778312, 1.238841, 0.062578},{0.778312, 1.228492, 0.068920},{
      0.767461, 1.226773, 0.068920},{0.764263, 1.236616, 0.062578}}],
    Polygon[{{0.778312, 1.228492, 0.068920},{0.778312, 1.217278, 0.073564},{
      0.770926, 1.216108, 0.073564},{0.767461, 1.226773, 0.068920}}],
    Polygon[{{0.778312, 1.217278, 0.073564},{0.778312, 1.205476, 0.076398},{
      0.774573, 1.204884, 0.076398},{0.770926, 1.216108, 0.073564}}],
    Polygon[{{0.774573, 1.204884, -0.076398},{0.770926, 1.216108, -0.073564},{
      0.764263, 1.212713, -0.073564},{0.771200, 1.203165, -0.076398}}],
    Polygon[{{0.770926, 1.216108, -0.073564},{0.767461, 1.226773, -0.068920},{
      0.757671, 1.221785, -0.068920},{0.764263, 1.212713, -0.073564}}],
    Polygon[{{0.767461, 1.226773, -0.068920},{0.764263, 1.236616, -0.062578},{
      0.751588, 1.230158, -0.062578},{0.757671, 1.221785, -0.068920}}],
    Polygon[{{0.764263, 1.236616, -0.062578},{0.761411, 1.245394, -0.054695},{
      0.746163, 1.237625, -0.054695},{0.751588, 1.230158, -0.062578}}],
    Polygon[{{0.761411, 1.245394, -0.054695},{0.758975, 1.252891, -0.045465},{
      0.741530, 1.244002, -0.045465},{0.746163, 1.237625, -0.054695}}],
    Polygon[{{0.758975, 1.252891, -0.045465},{0.757015, 1.258922, -0.035116},{
      0.737802, 1.249133, -0.035116},{0.741530, 1.244002, -0.045465}}],
    Polygon[{{0.757015, 1.258922, -0.035116},{0.755579, 1.263340, -0.023903},{
      0.735072, 1.252891, -0.023903},{0.737802, 1.249133, -0.035116}}],
    Polygon[{{0.755579, 1.263340, -0.023903},{0.754704, 1.266034, -0.012100},{
      0.733407, 1.255183, -0.012100},{0.735072, 1.252891, -0.023903}}],
    Polygon[{{0.754704, 1.266034, -0.012100},{0.754410, 1.266940, 0.000000},{
      0.732847, 1.255953, 0.000000},{0.733407, 1.255183, -0.012100}}],
    Polygon[{{0.754410, 1.266940, 0.000000},{0.754704, 1.266034, 0.012100},{
      0.733407, 1.255183, 0.012100},{0.732847, 1.255953, 0.000000}}],
    Polygon[{{0.754704, 1.266034, 0.012100},{0.755579, 1.263340, 0.023903},{
      0.735072, 1.252891, 0.023903},{0.733407, 1.255183, 0.012100}}],
    Polygon[{{0.755579, 1.263340, 0.023903},{0.757015, 1.258922, 0.035116},{
      0.737802, 1.249133, 0.035116},{0.735072, 1.252891, 0.023903}}],
    Polygon[{{0.757015, 1.258922, 0.035116},{0.758975, 1.252891, 0.045465},{
      0.741530, 1.244002, 0.045465},{0.737802, 1.249133, 0.035116}}],
    Polygon[{{0.758975, 1.252891, 0.045465},{0.761411, 1.245394, 0.054695},{
      0.746163, 1.237625, 0.054695},{0.741530, 1.244002, 0.045465}}],
    Polygon[{{0.761411, 1.245394, 0.054695},{0.764263, 1.236616, 0.062578},{
      0.751588, 1.230158, 0.062578},{0.746163, 1.237625, 0.054695}}],
    Polygon[{{0.764263, 1.236616, 0.062578},{0.767461, 1.226773, 0.068920},{
      0.757671, 1.221785, 0.068920},{0.751588, 1.230158, 0.062578}}],
    Polygon[{{0.767461, 1.226773, 0.068920},{0.770926, 1.216108, 0.073564},{
      0.764263, 1.212713, 0.073564},{0.757671, 1.221785, 0.068920}}],
    Polygon[{{0.770926, 1.216108, 0.073564},{0.774573, 1.204884, 0.076398},{
      0.771200, 1.203165, 0.076398},{0.764263, 1.212713, 0.073564}}],
    Polygon[{{0.771200, 1.203165, -0.076398},{0.764263, 1.212713, -0.073564},{
      0.758975, 1.207425, -0.073564},{0.768523, 1.200488, -0.076398}}],
    Polygon[{{0.764263, 1.212713, -0.073564},{0.757671, 1.221785, -0.068920},{
      0.749902, 1.214017, -0.068920},{0.758975, 1.207425, -0.073564}}],
    Polygon[{{0.757671, 1.221785, -0.068920},{0.751588, 1.230158, -0.062578},{
      0.741530, 1.220100, -0.062578},{0.749902, 1.214017, -0.068920}}],
    Polygon[{{0.751588, 1.230158, -0.062578},{0.746163, 1.237625, -0.054695},{
      0.734063, 1.225525, -0.054695},{0.741530, 1.220100, -0.062578}}],
    Polygon[{{0.746163, 1.237625, -0.054695},{0.741530, 1.244002, -0.045465},{
      0.727686, 1.230158, -0.045465},{0.734063, 1.225525, -0.054695}}],
    Polygon[{{0.741530, 1.244002, -0.045465},{0.737802, 1.249133, -0.035116},{
      0.722555, 1.233886, -0.035116},{0.727686, 1.230158, -0.045465}}],
    Polygon[{{0.737802, 1.249133, -0.035116},{0.735072, 1.252891, -0.023903},{
      0.718797, 1.236616, -0.023903},{0.722555, 1.233886, -0.035116}}],
    Polygon[{{0.735072, 1.252891, -0.023903},{0.733407, 1.255183, -0.012100},{
      0.716505, 1.238281, -0.012100},{0.718797, 1.236616, -0.023903}}],
    Polygon[{{0.733407, 1.255183, -0.012100},{0.732847, 1.255953, 0.000000},{
      0.715734, 1.238841, 0.000000},{0.716505, 1.238281, -0.012100}}],
    Polygon[{{0.732847, 1.255953, 0.000000},{0.733407, 1.255183, 0.012100},{
      0.716505, 1.238281, 0.012100},{0.715734, 1.238841, 0.000000}}],
    Polygon[{{0.733407, 1.255183, 0.012100},{0.735072, 1.252891, 0.023903},{
      0.718797, 1.236616, 0.023903},{0.716505, 1.238281, 0.012100}}],
    Polygon[{{0.735072, 1.252891, 0.023903},{0.737802, 1.249133, 0.035116},{
      0.722555, 1.233886, 0.035116},{0.718797, 1.236616, 0.023903}}],
    Polygon[{{0.737802, 1.249133, 0.035116},{0.741530, 1.244002, 0.045465},{
      0.727686, 1.230158, 0.045465},{0.722555, 1.233886, 0.035116}}],
    Polygon[{{0.741530, 1.244002, 0.045465},{0.746163, 1.237625, 0.054695},{
      0.734063, 1.225525, 0.054695},{0.727686, 1.230158, 0.045465}}],
    Polygon[{{0.746163, 1.237625, 0.054695},{0.751588, 1.230158, 0.062578},{
      0.741530, 1.220100, 0.062578},{0.734063, 1.225525, 0.054695}}],
    Polygon[{{0.751588, 1.230158, 0.062578},{0.757671, 1.221785, 0.068920},{
      0.749902, 1.214017, 0.068920},{0.741530, 1.220100, 0.062578}}],
    Polygon[{{0.757671, 1.221785, 0.068920},{0.764263, 1.212713, 0.073564},{
      0.758975, 1.207425, 0.073564},{0.749902, 1.214017, 0.068920}}],
    Polygon[{{0.764263, 1.212713, 0.073564},{0.771200, 1.203165, 0.076398},{
      0.768523, 1.200488, 0.076398},{0.758975, 1.207425, 0.073564}}],
    Polygon[{{0.768523, 1.200488, -0.076398},{0.758975, 1.207425, -0.073564},{
      0.755579, 1.200762, -0.073564},{0.766804, 1.197115, -0.076398}}],
    Polygon[{{0.758975, 1.207425, -0.073564},{0.749902, 1.214017, -0.068920},{
      0.744915, 1.204227, -0.068920},{0.755579, 1.200762, -0.073564}}],
    Polygon[{{0.749902, 1.214017, -0.068920},{0.741530, 1.220100, -0.062578},{
      0.735072, 1.207425, -0.062578},{0.744915, 1.204227, -0.068920}}],
    Polygon[{{0.741530, 1.220100, -0.062578},{0.734063, 1.225525, -0.054695},{
      0.726294, 1.210277, -0.054695},{0.735072, 1.207425, -0.062578}}],
    Polygon[{{0.734063, 1.225525, -0.054695},{0.727686, 1.230158, -0.045465},{
      0.718797, 1.212713, -0.045465},{0.726294, 1.210277, -0.054695}}],
    Polygon[{{0.727686, 1.230158, -0.045465},{0.722555, 1.233886, -0.035116},{
      0.712766, 1.214673, -0.035116},{0.718797, 1.212713, -0.045465}}],
    Polygon[{{0.722555, 1.233886, -0.035116},{0.718797, 1.236616, -0.023903},{
      0.708348, 1.216108, -0.023903},{0.712766, 1.214673, -0.035116}}],
    Polygon[{{0.718797, 1.236616, -0.023903},{0.716505, 1.238281, -0.012100},{
      0.705653, 1.216984, -0.012100},{0.708348, 1.216108, -0.023903}}],
    Polygon[{{0.716505, 1.238281, -0.012100},{0.715734, 1.238841, 0.000000},{
      0.704748, 1.217278, 0.000000},{0.705653, 1.216984, -0.012100}}],
    Polygon[{{0.715734, 1.238841, 0.000000},{0.716505, 1.238281, 0.012100},{
      0.705653, 1.216984, 0.012100},{0.704748, 1.217278, 0.000000}}],
    Polygon[{{0.716505, 1.238281, 0.012100},{0.718797, 1.236616, 0.023903},{
      0.708348, 1.216108, 0.023903},{0.705653, 1.216984, 0.012100}}],
    Polygon[{{0.718797, 1.236616, 0.023903},{0.722555, 1.233886, 0.035116},{
      0.712766, 1.214673, 0.035116},{0.708348, 1.216108, 0.023903}}],
    Polygon[{{0.722555, 1.233886, 0.035116},{0.727686, 1.230158, 0.045465},{
      0.718797, 1.212713, 0.045465},{0.712766, 1.214673, 0.035116}}],
    Polygon[{{0.727686, 1.230158, 0.045465},{0.734063, 1.225525, 0.054695},{
      0.726294, 1.210277, 0.054695},{0.718797, 1.212713, 0.045465}}],
    Polygon[{{0.734063, 1.225525, 0.054695},{0.741530, 1.220100, 0.062578},{
      0.735072, 1.207425, 0.062578},{0.726294, 1.210277, 0.054695}}],
    Polygon[{{0.741530, 1.220100, 0.062578},{0.749902, 1.214017, 0.068920},{
      0.744915, 1.204227, 0.068920},{0.735072, 1.207425, 0.062578}}],
    Polygon[{{0.749902, 1.214017, 0.068920},{0.758975, 1.207425, 0.073564},{
      0.755579, 1.200762, 0.073564},{0.744915, 1.204227, 0.068920}}],
    Polygon[{{0.758975, 1.207425, 0.073564},{0.768523, 1.200488, 0.076398},{
      0.766804, 1.197115, 0.076398},{0.755579, 1.200762, 0.073564}}],
    Polygon[{{0.766804, 1.197115, -0.076398},{0.755579, 1.200762, -0.073564},{
      0.754410, 1.193376, -0.073564},{0.766212, 1.193376, -0.076398}}],
    Polygon[{{0.755579, 1.200762, -0.073564},{0.744915, 1.204227, -0.068920},{
      0.743196, 1.193376, -0.068920},{0.754410, 1.193376, -0.073564}}],
    Polygon[{{0.744915, 1.204227, -0.068920},{0.735072, 1.207425, -0.062578},{
      0.732847, 1.193376, -0.062578},{0.743196, 1.193376, -0.068920}}],
    Polygon[{{0.735072, 1.207425, -0.062578},{0.726294, 1.210277, -0.054695},{
      0.723617, 1.193376, -0.054695},{0.732847, 1.193376, -0.062578}}],
    Polygon[{{0.726294, 1.210277, -0.054695},{0.718797, 1.212713, -0.045465},{
      0.715734, 1.193376, -0.045465},{0.723617, 1.193376, -0.054695}}],
    Polygon[{{0.718797, 1.212713, -0.045465},{0.712766, 1.214673, -0.035116},{
      0.709393, 1.193376, -0.035116},{0.715734, 1.193376, -0.045465}}],
    Polygon[{{0.712766, 1.214673, -0.035116},{0.708348, 1.216108, -0.023903},{
      0.704748, 1.193376, -0.023903},{0.709393, 1.193376, -0.035116}}],
    Polygon[{{0.708348, 1.216108, -0.023903},{0.705653, 1.216984, -0.012100},{
      0.701914, 1.193376, -0.012100},{0.704748, 1.193376, -0.023903}}],
    Polygon[{{0.705653, 1.216984, -0.012100},{0.704748, 1.217278, 0.000000},{
      0.700962, 1.193376, 0.000000},{0.701914, 1.193376, -0.012100}}],
    Polygon[{{0.704748, 1.217278, 0.000000},{0.705653, 1.216984, 0.012100},{
      0.701914, 1.193376, 0.012100},{0.700962, 1.193376, 0.000000}}],
    Polygon[{{0.705653, 1.216984, 0.012100},{0.708348, 1.216108, 0.023903},{
      0.704748, 1.193376, 0.023903},{0.701914, 1.193376, 0.012100}}],
    Polygon[{{0.708348, 1.216108, 0.023903},{0.712766, 1.214673, 0.035116},{
      0.709393, 1.193376, 0.035116},{0.704748, 1.193376, 0.023903}}],
    Polygon[{{0.712766, 1.214673, 0.035116},{0.718797, 1.212713, 0.045465},{
      0.715734, 1.193376, 0.045465},{0.709393, 1.193376, 0.035116}}],
    Polygon[{{0.718797, 1.212713, 0.045465},{0.726294, 1.210277, 0.054695},{
      0.723617, 1.193376, 0.054695},{0.715734, 1.193376, 0.045465}}],
    Polygon[{{0.726294, 1.210277, 0.054695},{0.735072, 1.207425, 0.062578},{
      0.732847, 1.193376, 0.062578},{0.723617, 1.193376, 0.054695}}],
    Polygon[{{0.735072, 1.207425, 0.062578},{0.744915, 1.204227, 0.068920},{
      0.743196, 1.193376, 0.068920},{0.732847, 1.193376, 0.062578}}],
    Polygon[{{0.744915, 1.204227, 0.068920},{0.755579, 1.200762, 0.073564},{
      0.754410, 1.193376, 0.073564},{0.743196, 1.193376, 0.068920}}],
    Polygon[{{0.755579, 1.200762, 0.073564},{0.766804, 1.197115, 0.076398},{
      0.766212, 1.193376, 0.076398},{0.754410, 1.193376, 0.073564}}],
    Polygon[{{0.766212, 1.193376, -0.076398},{0.754410, 1.193376, -0.073564},{
      0.755579, 1.185989, -0.073564},{0.766804, 1.189636, -0.076398}}],
    Polygon[{{0.754410, 1.193376, -0.073564},{0.743196, 1.193376, -0.068920},{
      0.744915, 1.182524, -0.068920},{0.755579, 1.185989, -0.073564}}],
    Polygon[{{0.743196, 1.193376, -0.068920},{0.732847, 1.193376, -0.062578},{
      0.735072, 1.179326, -0.062578},{0.744915, 1.182524, -0.068920}}],
    Polygon[{{0.732847, 1.193376, -0.062578},{0.723617, 1.193376, -0.054695},{
      0.726294, 1.176474, -0.054695},{0.735072, 1.179326, -0.062578}}],
    Polygon[{{0.723617, 1.193376, -0.054695},{0.715734, 1.193376, -0.045465},{
      0.718797, 1.174038, -0.045465},{0.726294, 1.176474, -0.054695}}],
    Polygon[{{0.715734, 1.193376, -0.045465},{0.709393, 1.193376, -0.035116},{
      0.712766, 1.172078, -0.035116},{0.718797, 1.174038, -0.045465}}],
    Polygon[{{0.709393, 1.193376, -0.035116},{0.704748, 1.193376, -0.023903},{
      0.708348, 1.170643, -0.023903},{0.712766, 1.172078, -0.035116}}],
    Polygon[{{0.704748, 1.193376, -0.023903},{0.701914, 1.193376, -0.012100},{
      0.705653, 1.169767, -0.012100},{0.708348, 1.170643, -0.023903}}],
    Polygon[{{0.701914, 1.193376, -0.012100},{0.700962, 1.193376, 0.000000},{
      0.704748, 1.169473, 0.000000},{0.705653, 1.169767, -0.012100}}],
    Polygon[{{0.700962, 1.193376, 0.000000},{0.701914, 1.193376, 0.012100},{
      0.705653, 1.169767, 0.012100},{0.704748, 1.169473, 0.000000}}],
    Polygon[{{0.701914, 1.193376, 0.012100},{0.704748, 1.193376, 0.023903},{
      0.708348, 1.170643, 0.023903},{0.705653, 1.169767, 0.012100}}],
    Polygon[{{0.704748, 1.193376, 0.023903},{0.709393, 1.193376, 0.035116},{
      0.712766, 1.172078, 0.035116},{0.708348, 1.170643, 0.023903}}],
    Polygon[{{0.709393, 1.193376, 0.035116},{0.715734, 1.193376, 0.045465},{
      0.718797, 1.174038, 0.045465},{0.712766, 1.172078, 0.035116}}],
    Polygon[{{0.715734, 1.193376, 0.045465},{0.723617, 1.193376, 0.054695},{
      0.726294, 1.176474, 0.054695},{0.718797, 1.174038, 0.045465}}],
    Polygon[{{0.723617, 1.193376, 0.054695},{0.732847, 1.193376, 0.062578},{
      0.735072, 1.179326, 0.062578},{0.726294, 1.176474, 0.054695}}],
    Polygon[{{0.732847, 1.193376, 0.062578},{0.743196, 1.193376, 0.068920},{
      0.744915, 1.182524, 0.068920},{0.735072, 1.179326, 0.062578}}],
    Polygon[{{0.743196, 1.193376, 0.068920},{0.754410, 1.193376, 0.073564},{
      0.755579, 1.185989, 0.073564},{0.744915, 1.182524, 0.068920}}],
    Polygon[{{0.754410, 1.193376, 0.073564},{0.766212, 1.193376, 0.076398},{
      0.766804, 1.189636, 0.076398},{0.755579, 1.185989, 0.073564}}],
    Polygon[{{0.766804, 1.189636, -0.076398},{0.755579, 1.185989, -0.073564},{
      0.758975, 1.179326, -0.073564},{0.768523, 1.186263, -0.076398}}],
    Polygon[{{0.755579, 1.185989, -0.073564},{0.744915, 1.182524, -0.068920},{
      0.749902, 1.172735, -0.068920},{0.758975, 1.179326, -0.073564}}],
    Polygon[{{0.744915, 1.182524, -0.068920},{0.735072, 1.179326, -0.062578},{
      0.741530, 1.166652, -0.062578},{0.749902, 1.172735, -0.068920}}],
    Polygon[{{0.735072, 1.179326, -0.062578},{0.726294, 1.176474, -0.054695},{
      0.734063, 1.161227, -0.054695},{0.741530, 1.166652, -0.062578}}],
    Polygon[{{0.726294, 1.176474, -0.054695},{0.718797, 1.174038, -0.045465},{
      0.727686, 1.156593, -0.045465},{0.734063, 1.161227, -0.054695}}],
    Polygon[{{0.718797, 1.174038, -0.045465},{0.712766, 1.172078, -0.035116},{
      0.722555, 1.152866, -0.035116},{0.727686, 1.156593, -0.045465}}],
    Polygon[{{0.712766, 1.172078, -0.035116},{0.708348, 1.170643, -0.023903},{
      0.718797, 1.150136, -0.023903},{0.722555, 1.152866, -0.035116}}],
    Polygon[{{0.708348, 1.170643, -0.023903},{0.705653, 1.169767, -0.012100},{
      0.716505, 1.148470, -0.012100},{0.718797, 1.150136, -0.023903}}],
    Polygon[{{0.705653, 1.169767, -0.012100},{0.704748, 1.169473, 0.000000},{
      0.715734, 1.147910, 0.000000},{0.716505, 1.148470, -0.012100}}],
    Polygon[{{0.704748, 1.169473, 0.000000},{0.705653, 1.169767, 0.012100},{
      0.716505, 1.148470, 0.012100},{0.715734, 1.147910, 0.000000}}],
    Polygon[{{0.705653, 1.169767, 0.012100},{0.708348, 1.170643, 0.023903},{
      0.718797, 1.150136, 0.023903},{0.716505, 1.148470, 0.012100}}],
    Polygon[{{0.708348, 1.170643, 0.023903},{0.712766, 1.172078, 0.035116},{
      0.722555, 1.152866, 0.035116},{0.718797, 1.150136, 0.023903}}],
    Polygon[{{0.712766, 1.172078, 0.035116},{0.718797, 1.174038, 0.045465},{
      0.727686, 1.156593, 0.045465},{0.722555, 1.152866, 0.035116}}],
    Polygon[{{0.718797, 1.174038, 0.045465},{0.726294, 1.176474, 0.054695},{
      0.734063, 1.161227, 0.054695},{0.727686, 1.156593, 0.045465}}],
    Polygon[{{0.726294, 1.176474, 0.054695},{0.735072, 1.179326, 0.062578},{
      0.741530, 1.166652, 0.062578},{0.734063, 1.161227, 0.054695}}],
    Polygon[{{0.735072, 1.179326, 0.062578},{0.744915, 1.182524, 0.068920},{
      0.749902, 1.172735, 0.068920},{0.741530, 1.166652, 0.062578}}],
    Polygon[{{0.744915, 1.182524, 0.068920},{0.755579, 1.185989, 0.073564},{
      0.758975, 1.179326, 0.073564},{0.749902, 1.172735, 0.068920}}],
    Polygon[{{0.755579, 1.185989, 0.073564},{0.766804, 1.189636, 0.076398},{
      0.768523, 1.186263, 0.076398},{0.758975, 1.179326, 0.073564}}],
    Polygon[{{0.768523, 1.186263, -0.076398},{0.758975, 1.179326, -0.073564},{
      0.764263, 1.174038, -0.073564},{0.771200, 1.183586, -0.076398}}],
    Polygon[{{0.758975, 1.179326, -0.073564},{0.749902, 1.172735, -0.068920},{
      0.757671, 1.164966, -0.068920},{0.764263, 1.174038, -0.073564}}],
    Polygon[{{0.749902, 1.172735, -0.068920},{0.741530, 1.166652, -0.062578},{
      0.751588, 1.156593, -0.062578},{0.757671, 1.164966, -0.068920}}],
    Polygon[{{0.741530, 1.166652, -0.062578},{0.734063, 1.161227, -0.054695},{
      0.746163, 1.149127, -0.054695},{0.751588, 1.156593, -0.062578}}],
    Polygon[{{0.734063, 1.161227, -0.054695},{0.727686, 1.156593, -0.045465},{
      0.741530, 1.142749, -0.045465},{0.746163, 1.149127, -0.054695}}],
    Polygon[{{0.727686, 1.156593, -0.045465},{0.722555, 1.152866, -0.035116},{
      0.737802, 1.137619, -0.035116},{0.741530, 1.142749, -0.045465}}],
    Polygon[{{0.722555, 1.152866, -0.035116},{0.718797, 1.150136, -0.023903},{
      0.735072, 1.133861, -0.023903},{0.737802, 1.137619, -0.035116}}],
    Polygon[{{0.718797, 1.150136, -0.023903},{0.716505, 1.148470, -0.012100},{
      0.733407, 1.131568, -0.012100},{0.735072, 1.133861, -0.023903}}],
    Polygon[{{0.716505, 1.148470, -0.012100},{0.715734, 1.147910, 0.000000},{
      0.732847, 1.130798, 0.000000},{0.733407, 1.131568, -0.012100}}],
    Polygon[{{0.715734, 1.147910, 0.000000},{0.716505, 1.148470, 0.012100},{
      0.733407, 1.131568, 0.012100},{0.732847, 1.130798, 0.000000}}],
    Polygon[{{0.716505, 1.148470, 0.012100},{0.718797, 1.150136, 0.023903},{
      0.735072, 1.133861, 0.023903},{0.733407, 1.131568, 0.012100}}],
    Polygon[{{0.718797, 1.150136, 0.023903},{0.722555, 1.152866, 0.035116},{
      0.737802, 1.137619, 0.035116},{0.735072, 1.133861, 0.023903}}],
    Polygon[{{0.722555, 1.152866, 0.035116},{0.727686, 1.156593, 0.045465},{
      0.741530, 1.142749, 0.045465},{0.737802, 1.137619, 0.035116}}],
    Polygon[{{0.727686, 1.156593, 0.045465},{0.734063, 1.161227, 0.054695},{
      0.746163, 1.149127, 0.054695},{0.741530, 1.142749, 0.045465}}],
    Polygon[{{0.734063, 1.161227, 0.054695},{0.741530, 1.166652, 0.062578},{
      0.751588, 1.156593, 0.062578},{0.746163, 1.149127, 0.054695}}],
    Polygon[{{0.741530, 1.166652, 0.062578},{0.749902, 1.172735, 0.068920},{
      0.757671, 1.164966, 0.068920},{0.751588, 1.156593, 0.062578}}],
    Polygon[{{0.749902, 1.172735, 0.068920},{0.758975, 1.179326, 0.073564},{
      0.764263, 1.174038, 0.073564},{0.757671, 1.164966, 0.068920}}],
    Polygon[{{0.758975, 1.179326, 0.073564},{0.768523, 1.186263, 0.076398},{
      0.771200, 1.183586, 0.076398},{0.764263, 1.174038, 0.073564}}],
    Polygon[{{0.771200, 1.183586, -0.076398},{0.764263, 1.174038, -0.073564},{
      0.770926, 1.170643, -0.073564},{0.774573, 1.181868, -0.076398}}],
    Polygon[{{0.764263, 1.174038, -0.073564},{0.757671, 1.164966, -0.068920},{
      0.767461, 1.159978, -0.068920},{0.770926, 1.170643, -0.073564}}],
    Polygon[{{0.757671, 1.164966, -0.068920},{0.751588, 1.156593, -0.062578},{
      0.764263, 1.150136, -0.062578},{0.767461, 1.159978, -0.068920}}],
    Polygon[{{0.751588, 1.156593, -0.062578},{0.746163, 1.149127, -0.054695},{
      0.761411, 1.141358, -0.054695},{0.764263, 1.150136, -0.062578}}],
    Polygon[{{0.746163, 1.149127, -0.054695},{0.741530, 1.142749, -0.045465},{
      0.758975, 1.133861, -0.045465},{0.761411, 1.141358, -0.054695}}],
    Polygon[{{0.741530, 1.142749, -0.045465},{0.737802, 1.137619, -0.035116},{
      0.757015, 1.127829, -0.035116},{0.758975, 1.133861, -0.045465}}],
    Polygon[{{0.737802, 1.137619, -0.035116},{0.735072, 1.133861, -0.023903},{
      0.755579, 1.123412, -0.023903},{0.757015, 1.127829, -0.035116}}],
    Polygon[{{0.735072, 1.133861, -0.023903},{0.733407, 1.131568, -0.012100},{
      0.754704, 1.120717, -0.012100},{0.755579, 1.123412, -0.023903}}],
    Polygon[{{0.733407, 1.131568, -0.012100},{0.732847, 1.130798, 0.000000},{
      0.754410, 1.119811, 0.000000},{0.754704, 1.120717, -0.012100}}],
    Polygon[{{0.732847, 1.130798, 0.000000},{0.733407, 1.131568, 0.012100},{
      0.754704, 1.120717, 0.012100},{0.754410, 1.119811, 0.000000}}],
    Polygon[{{0.733407, 1.131568, 0.012100},{0.735072, 1.133861, 0.023903},{
      0.755579, 1.123412, 0.023903},{0.754704, 1.120717, 0.012100}}],
    Polygon[{{0.735072, 1.133861, 0.023903},{0.737802, 1.137619, 0.035116},{
      0.757015, 1.127829, 0.035116},{0.755579, 1.123412, 0.023903}}],
    Polygon[{{0.737802, 1.137619, 0.035116},{0.741530, 1.142749, 0.045465},{
      0.758975, 1.133861, 0.045465},{0.757015, 1.127829, 0.035116}}],
    Polygon[{{0.741530, 1.142749, 0.045465},{0.746163, 1.149127, 0.054695},{
      0.761411, 1.141358, 0.054695},{0.758975, 1.133861, 0.045465}}],
    Polygon[{{0.746163, 1.149127, 0.054695},{0.751588, 1.156593, 0.062578},{
      0.764263, 1.150136, 0.062578},{0.761411, 1.141358, 0.054695}}],
    Polygon[{{0.751588, 1.156593, 0.062578},{0.757671, 1.164966, 0.068920},{
      0.767461, 1.159978, 0.068920},{0.764263, 1.150136, 0.062578}}],
    Polygon[{{0.757671, 1.164966, 0.068920},{0.764263, 1.174038, 0.073564},{
      0.770926, 1.170643, 0.073564},{0.767461, 1.159978, 0.068920}}],
    Polygon[{{0.764263, 1.174038, 0.073564},{0.771200, 1.183586, 0.076398},{
      0.774573, 1.181868, 0.076398},{0.770926, 1.170643, 0.073564}}],
    Polygon[{{0.774573, 1.181868, -0.076398},{0.770926, 1.170643, -0.073564},{
      0.778312, 1.169473, -0.073564},{0.778312, 1.181275, -0.076398}}],
    Polygon[{{0.770926, 1.170643, -0.073564},{0.767461, 1.159978, -0.068920},{
      0.778312, 1.158259, -0.068920},{0.778312, 1.169473, -0.073564}}],
    Polygon[{{0.767461, 1.159978, -0.068920},{0.764263, 1.150136, -0.062578},{
      0.778312, 1.147910, -0.062578},{0.778312, 1.158259, -0.068920}}],
    Polygon[{{0.764263, 1.150136, -0.062578},{0.761411, 1.141358, -0.054695},{
      0.778312, 1.138681, -0.054695},{0.778312, 1.147910, -0.062578}}],
    Polygon[{{0.761411, 1.141358, -0.054695},{0.758975, 1.133861, -0.045465},{
      0.778312, 1.130798, -0.045465},{0.778312, 1.138681, -0.054695}}],
    Polygon[{{0.758975, 1.133861, -0.045465},{0.757015, 1.127829, -0.035116},{
      0.778312, 1.124456, -0.035116},{0.778312, 1.130798, -0.045465}}],
    Polygon[{{0.757015, 1.127829, -0.035116},{0.755579, 1.123412, -0.023903},{
      0.778312, 1.119811, -0.023903},{0.778312, 1.124456, -0.035116}}],
    Polygon[{{0.755579, 1.123412, -0.023903},{0.754704, 1.120717, -0.012100},{
      0.778312, 1.116978, -0.012100},{0.778312, 1.119811, -0.023903}}],
    Polygon[{{0.754704, 1.120717, -0.012100},{0.754410, 1.119811, 0.000000},{
      0.778312, 1.116025, 0.000000},{0.778312, 1.116978, -0.012100}}],
    Polygon[{{0.754410, 1.119811, 0.000000},{0.754704, 1.120717, 0.012100},{
      0.778312, 1.116978, 0.012100},{0.778312, 1.116025, 0.000000}}],
    Polygon[{{0.754704, 1.120717, 0.012100},{0.755579, 1.123412, 0.023903},{
      0.778312, 1.119811, 0.023903},{0.778312, 1.116978, 0.012100}}],
    Polygon[{{0.755579, 1.123412, 0.023903},{0.757015, 1.127829, 0.035116},{
      0.778312, 1.124456, 0.035116},{0.778312, 1.119811, 0.023903}}],
    Polygon[{{0.757015, 1.127829, 0.035116},{0.758975, 1.133861, 0.045465},{
      0.778312, 1.130798, 0.045465},{0.778312, 1.124456, 0.035116}}],
    Polygon[{{0.758975, 1.133861, 0.045465},{0.761411, 1.141358, 0.054695},{
      0.778312, 1.138681, 0.054695},{0.778312, 1.130798, 0.045465}}],
    Polygon[{{0.761411, 1.141358, 0.054695},{0.764263, 1.150136, 0.062578},{
      0.778312, 1.147910, 0.062578},{0.778312, 1.138681, 0.054695}}],
    Polygon[{{0.764263, 1.150136, 0.062578},{0.767461, 1.159978, 0.068920},{
      0.778312, 1.158259, 0.068920},{0.778312, 1.147910, 0.062578}}],
    Polygon[{{0.767461, 1.159978, 0.068920},{0.770926, 1.170643, 0.073564},{
      0.778312, 1.169473, 0.073564},{0.778312, 1.158259, 0.068920}}],
    Polygon[{{0.770926, 1.170643, 0.073564},{0.774573, 1.181868, 0.076398},{
      0.778312, 1.181275, 0.076398},{0.778312, 1.169473, 0.073564}}],
    Polygon[{{0.778312, 1.181275, -0.076398},{0.778312, 1.169473, -0.073564},{
      0.785698, 1.170643, -0.073564},{0.782051, 1.181868, -0.076398}}],
    Polygon[{{0.778312, 1.169473, -0.073564},{0.778312, 1.158259, -0.068920},{
      0.789164, 1.159978, -0.068920},{0.785698, 1.170643, -0.073564}}],
    Polygon[{{0.778312, 1.158259, -0.068920},{0.778312, 1.147910, -0.062578},{
      0.792362, 1.150136, -0.062578},{0.789164, 1.159978, -0.068920}}],
    Polygon[{{0.778312, 1.147910, -0.062578},{0.778312, 1.138681, -0.054695},{
      0.795214, 1.141358, -0.054695},{0.792362, 1.150136, -0.062578}}],
    Polygon[{{0.778312, 1.138681, -0.054695},{0.778312, 1.130798, -0.045465},{
      0.797650, 1.133861, -0.045465},{0.795214, 1.141358, -0.054695}}],
    Polygon[{{0.778312, 1.130798, -0.045465},{0.778312, 1.124456, -0.035116},{
      0.799609, 1.127829, -0.035116},{0.797650, 1.133861, -0.045465}}],
    Polygon[{{0.778312, 1.124456, -0.035116},{0.778312, 1.119811, -0.023903},{
      0.801045, 1.123412, -0.023903},{0.799609, 1.127829, -0.035116}}],
    Polygon[{{0.778312, 1.119811, -0.023903},{0.778312, 1.116978, -0.012100},{
      0.801920, 1.120717, -0.012100},{0.801045, 1.123412, -0.023903}}],
    Polygon[{{0.778312, 1.116978, -0.012100},{0.778312, 1.116025, 0.000000},{
      0.802215, 1.119811, 0.000000},{0.801920, 1.120717, -0.012100}}],
    Polygon[{{0.778312, 1.116025, 0.000000},{0.778312, 1.116978, 0.012100},{
      0.801920, 1.120717, 0.012100},{0.802215, 1.119811, 0.000000}}],
    Polygon[{{0.778312, 1.116978, 0.012100},{0.778312, 1.119811, 0.023903},{
      0.801045, 1.123412, 0.023903},{0.801920, 1.120717, 0.012100}}],
    Polygon[{{0.778312, 1.119811, 0.023903},{0.778312, 1.124456, 0.035116},{
      0.799609, 1.127829, 0.035116},{0.801045, 1.123412, 0.023903}}],
    Polygon[{{0.778312, 1.124456, 0.035116},{0.778312, 1.130798, 0.045465},{
      0.797650, 1.133861, 0.045465},{0.799609, 1.127829, 0.035116}}],
    Polygon[{{0.778312, 1.130798, 0.045465},{0.778312, 1.138681, 0.054695},{
      0.795214, 1.141358, 0.054695},{0.797650, 1.133861, 0.045465}}],
    Polygon[{{0.778312, 1.138681, 0.054695},{0.778312, 1.147910, 0.062578},{
      0.792362, 1.150136, 0.062578},{0.795214, 1.141358, 0.054695}}],
    Polygon[{{0.778312, 1.147910, 0.062578},{0.778312, 1.158259, 0.068920},{
      0.789164, 1.159978, 0.068920},{0.792362, 1.150136, 0.062578}}],
    Polygon[{{0.778312, 1.158259, 0.068920},{0.778312, 1.169473, 0.073564},{
      0.785698, 1.170643, 0.073564},{0.789164, 1.159978, 0.068920}}],
    Polygon[{{0.778312, 1.169473, 0.073564},{0.778312, 1.181275, 0.076398},{
      0.782051, 1.181868, 0.076398},{0.785698, 1.170643, 0.073564}}],
    Polygon[{{0.782051, 1.181868, -0.076398},{0.785698, 1.170643, -0.073564},{
      0.792362, 1.174038, -0.073564},{0.785425, 1.183586, -0.076398}}],
    Polygon[{{0.785698, 1.170643, -0.073564},{0.789164, 1.159978, -0.068920},{
      0.798953, 1.164966, -0.068920},{0.792362, 1.174038, -0.073564}}],
    Polygon[{{0.789164, 1.159978, -0.068920},{0.792362, 1.150136, -0.062578},{
      0.805036, 1.156593, -0.062578},{0.798953, 1.164966, -0.068920}}],
    Polygon[{{0.792362, 1.150136, -0.062578},{0.795214, 1.141358, -0.054695},{
      0.810461, 1.149127, -0.054695},{0.805036, 1.156593, -0.062578}}],
    Polygon[{{0.795214, 1.141358, -0.054695},{0.797650, 1.133861, -0.045465},{
      0.815094, 1.142749, -0.045465},{0.810461, 1.149127, -0.054695}}],
    Polygon[{{0.797650, 1.133861, -0.045465},{0.799609, 1.127829, -0.035116},{
      0.818822, 1.137619, -0.035116},{0.815094, 1.142749, -0.045465}}],
    Polygon[{{0.799609, 1.127829, -0.035116},{0.801045, 1.123412, -0.023903},{
      0.821552, 1.133861, -0.023903},{0.818822, 1.137619, -0.035116}}],
    Polygon[{{0.801045, 1.123412, -0.023903},{0.801920, 1.120717, -0.012100},{
      0.823218, 1.131568, -0.012100},{0.821552, 1.133861, -0.023903}}],
    Polygon[{{0.801920, 1.120717, -0.012100},{0.802215, 1.119811, 0.000000},{
      0.823777, 1.130798, 0.000000},{0.823218, 1.131568, -0.012100}}],
    Polygon[{{0.802215, 1.119811, 0.000000},{0.801920, 1.120717, 0.012100},{
      0.823218, 1.131568, 0.012100},{0.823777, 1.130798, 0.000000}}],
    Polygon[{{0.801920, 1.120717, 0.012100},{0.801045, 1.123412, 0.023903},{
      0.821552, 1.133861, 0.023903},{0.823218, 1.131568, 0.012100}}],
    Polygon[{{0.801045, 1.123412, 0.023903},{0.799609, 1.127829, 0.035116},{
      0.818822, 1.137619, 0.035116},{0.821552, 1.133861, 0.023903}}],
    Polygon[{{0.799609, 1.127829, 0.035116},{0.797650, 1.133861, 0.045465},{
      0.815094, 1.142749, 0.045465},{0.818822, 1.137619, 0.035116}}],
    Polygon[{{0.797650, 1.133861, 0.045465},{0.795214, 1.141358, 0.054695},{
      0.810461, 1.149127, 0.054695},{0.815094, 1.142749, 0.045465}}],
    Polygon[{{0.795214, 1.141358, 0.054695},{0.792362, 1.150136, 0.062578},{
      0.805036, 1.156593, 0.062578},{0.810461, 1.149127, 0.054695}}],
    Polygon[{{0.792362, 1.150136, 0.062578},{0.789164, 1.159978, 0.068920},{
      0.798953, 1.164966, 0.068920},{0.805036, 1.156593, 0.062578}}],
    Polygon[{{0.789164, 1.159978, 0.068920},{0.785698, 1.170643, 0.073564},{
      0.792362, 1.174038, 0.073564},{0.798953, 1.164966, 0.068920}}],
    Polygon[{{0.785698, 1.170643, 0.073564},{0.782051, 1.181868, 0.076398},{
      0.785425, 1.183586, 0.076398},{0.792362, 1.174038, 0.073564}}],
    Polygon[{{0.785425, 1.183586, -0.076398},{0.792362, 1.174038, -0.073564},{
      0.797650, 1.179326, -0.073564},{0.788101, 1.186263, -0.076398}}],
    Polygon[{{0.792362, 1.174038, -0.073564},{0.798953, 1.164966, -0.068920},{
      0.806722, 1.172735, -0.068920},{0.797650, 1.179326, -0.073564}}],
    Polygon[{{0.798953, 1.164966, -0.068920},{0.805036, 1.156593, -0.062578},{
      0.815094, 1.166652, -0.062578},{0.806722, 1.172735, -0.068920}}],
    Polygon[{{0.805036, 1.156593, -0.062578},{0.810461, 1.149127, -0.054695},{
      0.822561, 1.161227, -0.054695},{0.815094, 1.166652, -0.062578}}],
    Polygon[{{0.810461, 1.149127, -0.054695},{0.815094, 1.142749, -0.045465},{
      0.828939, 1.156593, -0.045465},{0.822561, 1.161227, -0.054695}}],
    Polygon[{{0.815094, 1.142749, -0.045465},{0.818822, 1.137619, -0.035116},{
      0.834069, 1.152866, -0.035116},{0.828939, 1.156593, -0.045465}}],
    Polygon[{{0.818822, 1.137619, -0.035116},{0.821552, 1.133861, -0.023903},{
      0.837827, 1.150136, -0.023903},{0.834069, 1.152866, -0.035116}}],
    Polygon[{{0.821552, 1.133861, -0.023903},{0.823218, 1.131568, -0.012100},{
      0.840119, 1.148470, -0.012100},{0.837827, 1.150136, -0.023903}}],
    Polygon[{{0.823218, 1.131568, -0.012100},{0.823777, 1.130798, 0.000000},{
      0.840890, 1.147910, 0.000000},{0.840119, 1.148470, -0.012100}}],
    Polygon[{{0.823777, 1.130798, 0.000000},{0.823218, 1.131568, 0.012100},{
      0.840119, 1.148470, 0.012100},{0.840890, 1.147910, 0.000000}}],
    Polygon[{{0.823218, 1.131568, 0.012100},{0.821552, 1.133861, 0.023903},{
      0.837827, 1.150136, 0.023903},{0.840119, 1.148470, 0.012100}}],
    Polygon[{{0.821552, 1.133861, 0.023903},{0.818822, 1.137619, 0.035116},{
      0.834069, 1.152866, 0.035116},{0.837827, 1.150136, 0.023903}}],
    Polygon[{{0.818822, 1.137619, 0.035116},{0.815094, 1.142749, 0.045465},{
      0.828939, 1.156593, 0.045465},{0.834069, 1.152866, 0.035116}}],
    Polygon[{{0.815094, 1.142749, 0.045465},{0.810461, 1.149127, 0.054695},{
      0.822561, 1.161227, 0.054695},{0.828939, 1.156593, 0.045465}}],
    Polygon[{{0.810461, 1.149127, 0.054695},{0.805036, 1.156593, 0.062578},{
      0.815094, 1.166652, 0.062578},{0.822561, 1.161227, 0.054695}}],
    Polygon[{{0.805036, 1.156593, 0.062578},{0.798953, 1.164966, 0.068920},{
      0.806722, 1.172735, 0.068920},{0.815094, 1.166652, 0.062578}}],
    Polygon[{{0.798953, 1.164966, 0.068920},{0.792362, 1.174038, 0.073564},{
      0.797650, 1.179326, 0.073564},{0.806722, 1.172735, 0.068920}}],
    Polygon[{{0.792362, 1.174038, 0.073564},{0.785425, 1.183586, 0.076398},{
      0.788101, 1.186263, 0.076398},{0.797650, 1.179326, 0.073564}}],
    Polygon[{{0.788101, 1.186263, -0.076398},{0.797650, 1.179326, -0.073564},{
      0.801045, 1.185989, -0.073564},{0.789820, 1.189636, -0.076398}}],
    Polygon[{{0.797650, 1.179326, -0.073564},{0.806722, 1.172735, -0.068920},{
      0.811710, 1.182524, -0.068920},{0.801045, 1.185989, -0.073564}}],
    Polygon[{{0.806722, 1.172735, -0.068920},{0.815094, 1.166652, -0.062578},{
      0.821552, 1.179326, -0.062578},{0.811710, 1.182524, -0.068920}}],
    Polygon[{{0.815094, 1.166652, -0.062578},{0.822561, 1.161227, -0.054695},{
      0.830330, 1.176474, -0.054695},{0.821552, 1.179326, -0.062578}}],
    Polygon[{{0.822561, 1.161227, -0.054695},{0.828939, 1.156593, -0.045465},{
      0.837827, 1.174038, -0.045465},{0.830330, 1.176474, -0.054695}}],
    Polygon[{{0.828939, 1.156593, -0.045465},{0.834069, 1.152866, -0.035116},{
      0.843859, 1.172078, -0.035116},{0.837827, 1.174038, -0.045465}}],
    Polygon[{{0.834069, 1.152866, -0.035116},{0.837827, 1.150136, -0.023903},{
      0.848276, 1.170643, -0.023903},{0.843859, 1.172078, -0.035116}}],
    Polygon[{{0.837827, 1.150136, -0.023903},{0.840119, 1.148470, -0.012100},{
      0.850971, 1.169767, -0.012100},{0.848276, 1.170643, -0.023903}}],
    Polygon[{{0.840119, 1.148470, -0.012100},{0.840890, 1.147910, 0.000000},{
      0.851877, 1.169473, 0.000000},{0.850971, 1.169767, -0.012100}}],
    Polygon[{{0.840890, 1.147910, 0.000000},{0.840119, 1.148470, 0.012100},{
      0.850971, 1.169767, 0.012100},{0.851877, 1.169473, 0.000000}}],
    Polygon[{{0.840119, 1.148470, 0.012100},{0.837827, 1.150136, 0.023903},{
      0.848276, 1.170643, 0.023903},{0.850971, 1.169767, 0.012100}}],
    Polygon[{{0.837827, 1.150136, 0.023903},{0.834069, 1.152866, 0.035116},{
      0.843859, 1.172078, 0.035116},{0.848276, 1.170643, 0.023903}}],
    Polygon[{{0.834069, 1.152866, 0.035116},{0.828939, 1.156593, 0.045465},{
      0.837827, 1.174038, 0.045465},{0.843859, 1.172078, 0.035116}}],
    Polygon[{{0.828939, 1.156593, 0.045465},{0.822561, 1.161227, 0.054695},{
      0.830330, 1.176474, 0.054695},{0.837827, 1.174038, 0.045465}}],
    Polygon[{{0.822561, 1.161227, 0.054695},{0.815094, 1.166652, 0.062578},{
      0.821552, 1.179326, 0.062578},{0.830330, 1.176474, 0.054695}}],
    Polygon[{{0.815094, 1.166652, 0.062578},{0.806722, 1.172735, 0.068920},{
      0.811710, 1.182524, 0.068920},{0.821552, 1.179326, 0.062578}}],
    Polygon[{{0.806722, 1.172735, 0.068920},{0.797650, 1.179326, 0.073564},{
      0.801045, 1.185989, 0.073564},{0.811710, 1.182524, 0.068920}}],
    Polygon[{{0.797650, 1.179326, 0.073564},{0.788101, 1.186263, 0.076398},{
      0.789820, 1.189636, 0.076398},{0.801045, 1.185989, 0.073564}}],
    Polygon[{{0.789820, 1.189636, -0.076398},{0.801045, 1.185989, -0.073564},{
      0.802215, 1.193376, -0.073564},{0.790412, 1.193376, -0.076398}}],
    Polygon[{{0.801045, 1.185989, -0.073564},{0.811710, 1.182524, -0.068920},{
      0.813428, 1.193376, -0.068920},{0.802215, 1.193376, -0.073564}}],
    Polygon[{{0.811710, 1.182524, -0.068920},{0.821552, 1.179326, -0.062578},{
      0.823777, 1.193376, -0.062578},{0.813428, 1.193376, -0.068920}}],
    Polygon[{{0.821552, 1.179326, -0.062578},{0.830330, 1.176474, -0.054695},{
      0.833007, 1.193376, -0.054695},{0.823777, 1.193376, -0.062578}}],
    Polygon[{{0.830330, 1.176474, -0.054695},{0.837827, 1.174038, -0.045465},{
      0.840890, 1.193376, -0.045465},{0.833007, 1.193376, -0.054695}}],
    Polygon[{{0.837827, 1.174038, -0.045465},{0.843859, 1.172078, -0.035116},{
      0.847232, 1.193376, -0.035116},{0.840890, 1.193376, -0.045465}}],
    Polygon[{{0.843859, 1.172078, -0.035116},{0.848276, 1.170643, -0.023903},{
      0.851877, 1.193376, -0.023903},{0.847232, 1.193376, -0.035116}}],
    Polygon[{{0.848276, 1.170643, -0.023903},{0.850971, 1.169767, -0.012100},{
      0.854710, 1.193376, -0.012100},{0.851877, 1.193376, -0.023903}}],
    Polygon[{{0.850971, 1.169767, -0.012100},{0.851877, 1.169473, 0.000000},{
      0.855662, 1.193376, 0.000000},{0.854710, 1.193376, -0.012100}}],
    Polygon[{{0.851877, 1.169473, 0.000000},{0.850971, 1.169767, 0.012100},{
      0.854710, 1.193376, 0.012100},{0.855662, 1.193376, 0.000000}}],
    Polygon[{{0.850971, 1.169767, 0.012100},{0.848276, 1.170643, 0.023903},{
      0.851877, 1.193376, 0.023903},{0.854710, 1.193376, 0.012100}}],
    Polygon[{{0.848276, 1.170643, 0.023903},{0.843859, 1.172078, 0.035116},{
      0.847232, 1.193376, 0.035116},{0.851877, 1.193376, 0.023903}}],
    Polygon[{{0.843859, 1.172078, 0.035116},{0.837827, 1.174038, 0.045465},{
      0.840890, 1.193376, 0.045465},{0.847232, 1.193376, 0.035116}}],
    Polygon[{{0.837827, 1.174038, 0.045465},{0.830330, 1.176474, 0.054695},{
      0.833007, 1.193376, 0.054695},{0.840890, 1.193376, 0.045465}}],
    Polygon[{{0.830330, 1.176474, 0.054695},{0.821552, 1.179326, 0.062578},{
      0.823777, 1.193376, 0.062578},{0.833007, 1.193376, 0.054695}}],
    Polygon[{{0.821552, 1.179326, 0.062578},{0.811710, 1.182524, 0.068920},{
      0.813428, 1.193376, 0.068920},{0.823777, 1.193376, 0.062578}}],
    Polygon[{{0.811710, 1.182524, 0.068920},{0.801045, 1.185989, 0.073564},{
      0.802215, 1.193376, 0.073564},{0.813428, 1.193376, 0.068920}}],
    Polygon[{{0.801045, 1.185989, 0.073564},{0.789820, 1.189636, 0.076398},{
      0.790412, 1.193376, 0.076398},{0.802215, 1.193376, 0.073564}}],
    Polygon[{{0.697083, 1.113249, -0.040942},{0.703408, 1.113249, -0.039423},{
      0.702781, 1.117207, -0.039423},{0.696766, 1.115252, -0.040942}}],
    Polygon[{{0.703408, 1.113249, -0.039423},{0.709418, 1.113249, -0.036934},{
      0.708497, 1.119064, -0.036934},{0.702781, 1.117207, -0.039423}}],
    Polygon[{{0.709418, 1.113249, -0.036934},{0.714964, 1.113249, -0.033535},{
      0.713771, 1.120778, -0.033535},{0.708497, 1.119064, -0.036934}}],
    Polygon[{{0.714964, 1.113249, -0.033535},{0.719910, 1.113249, -0.029311},{
      0.718475, 1.122306, -0.029311},{0.713771, 1.120778, -0.033535}}],
    Polygon[{{0.719910, 1.113249, -0.029311},{0.724134, 1.113249, -0.024365},{
      0.722493, 1.123612, -0.024365},{0.718475, 1.122306, -0.029311}}],
    Polygon[{{0.724134, 1.113249, -0.024365},{0.727533, 1.113249, -0.018819},{
      0.725725, 1.124662, -0.018819},{0.722493, 1.123612, -0.024365}}],
    Polygon[{{0.727533, 1.113249, -0.018819},{0.730022, 1.113249, -0.012809},{
      0.728092, 1.125431, -0.012809},{0.725725, 1.124662, -0.018819}}],
    Polygon[{{0.730022, 1.113249, -0.012809},{0.731540, 1.113249, -0.006485},{
      0.729537, 1.125900, -0.006485},{0.728092, 1.125431, -0.012809}}],
    Polygon[{{0.731540, 1.113249, -0.006485},{0.732051, 1.113249, 0.000000},{
      0.730022, 1.126058, 0.000000},{0.729537, 1.125900, -0.006485}}],
    Polygon[{{0.732051, 1.113249, 0.000000},{0.731540, 1.113249, 0.006485},{
      0.729537, 1.125900, 0.006485},{0.730022, 1.126058, 0.000000}}],
    Polygon[{{0.731540, 1.113249, 0.006485},{0.730022, 1.113249, 0.012809},{
      0.728092, 1.125431, 0.012809},{0.729537, 1.125900, 0.006485}}],
    Polygon[{{0.730022, 1.113249, 0.012809},{0.727533, 1.113249, 0.018819},{
      0.725725, 1.124662, 0.018819},{0.728092, 1.125431, 0.012809}}],
    Polygon[{{0.727533, 1.113249, 0.018819},{0.724134, 1.113249, 0.024365},{
      0.722493, 1.123612, 0.024365},{0.725725, 1.124662, 0.018819}}],
    Polygon[{{0.724134, 1.113249, 0.024365},{0.719910, 1.113249, 0.029311},{
      0.718475, 1.122306, 0.029311},{0.722493, 1.123612, 0.024365}}],
    Polygon[{{0.719910, 1.113249, 0.029311},{0.714964, 1.113249, 0.033535},{
      0.713771, 1.120778, 0.033535},{0.718475, 1.122306, 0.029311}}],
    Polygon[{{0.714964, 1.113249, 0.033535},{0.709418, 1.113249, 0.036934},{
      0.708497, 1.119064, 0.036934},{0.713771, 1.120778, 0.033535}}],
    Polygon[{{0.709418, 1.113249, 0.036934},{0.703408, 1.113249, 0.039423},{
      0.702781, 1.117207, 0.039423},{0.708497, 1.119064, 0.036934}}],
    Polygon[{{0.703408, 1.113249, 0.039423},{0.697083, 1.113249, 0.040942},{
      0.696766, 1.115252, 0.040942},{0.702781, 1.117207, 0.039423}}],
    Polygon[{{0.696766, 1.115252, -0.040942},{0.702781, 1.117207, -0.039423},{
      0.700962, 1.120778, -0.039423},{0.695845, 1.117060, -0.040942}}],
    Polygon[{{0.702781, 1.117207, -0.039423},{0.708497, 1.119064, -0.036934},{
      0.705824, 1.124310, -0.036934},{0.700962, 1.120778, -0.039423}}],
    Polygon[{{0.708497, 1.119064, -0.036934},{0.713771, 1.120778, -0.033535},{
      0.710310, 1.127570, -0.033535},{0.705824, 1.124310, -0.036934}}],
    Polygon[{{0.713771, 1.120778, -0.033535},{0.718475, 1.122306, -0.029311},{
      0.714312, 1.130477, -0.029311},{0.710310, 1.127570, -0.033535}}],
    Polygon[{{0.718475, 1.122306, -0.029311},{0.722493, 1.123612, -0.024365},{
      0.717730, 1.132960, -0.024365},{0.714312, 1.130477, -0.029311}}],
    Polygon[{{0.722493, 1.123612, -0.024365},{0.725725, 1.124662, -0.018819},{
      0.720479, 1.134958, -0.018819},{0.717730, 1.132960, -0.024365}}],
    Polygon[{{0.725725, 1.124662, -0.018819},{0.728092, 1.125431, -0.012809},{
      0.722493, 1.136421, -0.012809},{0.720479, 1.134958, -0.018819}}],
    Polygon[{{0.728092, 1.125431, -0.012809},{0.729537, 1.125900, -0.006485},{
      0.723721, 1.137313, -0.006485},{0.722493, 1.136421, -0.012809}}],
    Polygon[{{0.729537, 1.125900, -0.006485},{0.730022, 1.126058, 0.000000},{
      0.724134, 1.137613, 0.000000},{0.723721, 1.137313, -0.006485}}],
    Polygon[{{0.730022, 1.126058, 0.000000},{0.729537, 1.125900, 0.006485},{
      0.723721, 1.137313, 0.006485},{0.724134, 1.137613, 0.000000}}],
    Polygon[{{0.729537, 1.125900, 0.006485},{0.728092, 1.125431, 0.012809},{
      0.722493, 1.136421, 0.012809},{0.723721, 1.137313, 0.006485}}],
    Polygon[{{0.728092, 1.125431, 0.012809},{0.725725, 1.124662, 0.018819},{
      0.720479, 1.134958, 0.018819},{0.722493, 1.136421, 0.012809}}],
    Polygon[{{0.725725, 1.124662, 0.018819},{0.722493, 1.123612, 0.024365},{
      0.717730, 1.132960, 0.024365},{0.720479, 1.134958, 0.018819}}],
    Polygon[{{0.722493, 1.123612, 0.024365},{0.718475, 1.122306, 0.029311},{
      0.714312, 1.130477, 0.029311},{0.717730, 1.132960, 0.024365}}],
    Polygon[{{0.718475, 1.122306, 0.029311},{0.713771, 1.120778, 0.033535},{
      0.710310, 1.127570, 0.033535},{0.714312, 1.130477, 0.029311}}],
    Polygon[{{0.713771, 1.120778, 0.033535},{0.708497, 1.119064, 0.036934},{
      0.705824, 1.124310, 0.036934},{0.710310, 1.127570, 0.033535}}],
    Polygon[{{0.708497, 1.119064, 0.036934},{0.702781, 1.117207, 0.039423},{
      0.700962, 1.120778, 0.039423},{0.705824, 1.124310, 0.036934}}],
    Polygon[{{0.702781, 1.117207, 0.039423},{0.696766, 1.115252, 0.040942},{
      0.695845, 1.117060, 0.040942},{0.700962, 1.120778, 0.039423}}],
    Polygon[{{0.695845, 1.117060, -0.040942},{0.700962, 1.120778, -0.039423},{
      0.698128, 1.123612, -0.039423},{0.694410, 1.118495, -0.040942}}],
    Polygon[{{0.700962, 1.120778, -0.039423},{0.705824, 1.124310, -0.036934},{
      0.701660, 1.128473, -0.036934},{0.698128, 1.123612, -0.039423}}],
    Polygon[{{0.705824, 1.124310, -0.036934},{0.710310, 1.127570, -0.033535},{
      0.704920, 1.132960, -0.033535},{0.701660, 1.128473, -0.036934}}],
    Polygon[{{0.710310, 1.127570, -0.033535},{0.714312, 1.130477, -0.029311},{
      0.707827, 1.136962, -0.029311},{0.704920, 1.132960, -0.033535}}],
    Polygon[{{0.714312, 1.130477, -0.029311},{0.717730, 1.132960, -0.024365},{
      0.710310, 1.140379, -0.024365},{0.707827, 1.136962, -0.029311}}],
    Polygon[{{0.717730, 1.132960, -0.024365},{0.720479, 1.134958, -0.018819},{
      0.712308, 1.143129, -0.018819},{0.710310, 1.140379, -0.024365}}],
    Polygon[{{0.720479, 1.134958, -0.018819},{0.722493, 1.136421, -0.012809},{
      0.713771, 1.145143, -0.012809},{0.712308, 1.143129, -0.018819}}],
    Polygon[{{0.722493, 1.136421, -0.012809},{0.723721, 1.137313, -0.006485},{
      0.714664, 1.146371, -0.006485},{0.713771, 1.145143, -0.012809}}],
    Polygon[{{0.723721, 1.137313, -0.006485},{0.724134, 1.137613, 0.000000},{
      0.714964, 1.146784, 0.000000},{0.714664, 1.146371, -0.006485}}],
    Polygon[{{0.724134, 1.137613, 0.000000},{0.723721, 1.137313, 0.006485},{
      0.714664, 1.146371, 0.006485},{0.714964, 1.146784, 0.000000}}],
    Polygon[{{0.723721, 1.137313, 0.006485},{0.722493, 1.136421, 0.012809},{
      0.713771, 1.145143, 0.012809},{0.714664, 1.146371, 0.006485}}],
    Polygon[{{0.722493, 1.136421, 0.012809},{0.720479, 1.134958, 0.018819},{
      0.712308, 1.143129, 0.018819},{0.713771, 1.145143, 0.012809}}],
    Polygon[{{0.720479, 1.134958, 0.018819},{0.717730, 1.132960, 0.024365},{
      0.710310, 1.140379, 0.024365},{0.712308, 1.143129, 0.018819}}],
    Polygon[{{0.717730, 1.132960, 0.024365},{0.714312, 1.130477, 0.029311},{
      0.707827, 1.136962, 0.029311},{0.710310, 1.140379, 0.024365}}],
    Polygon[{{0.714312, 1.130477, 0.029311},{0.710310, 1.127570, 0.033535},{
      0.704920, 1.132960, 0.033535},{0.707827, 1.136962, 0.029311}}],
    Polygon[{{0.710310, 1.127570, 0.033535},{0.705824, 1.124310, 0.036934},{
      0.701660, 1.128473, 0.036934},{0.704920, 1.132960, 0.033535}}],
    Polygon[{{0.705824, 1.124310, 0.036934},{0.700962, 1.120778, 0.039423},{
      0.698128, 1.123612, 0.039423},{0.701660, 1.128473, 0.036934}}],
    Polygon[{{0.700962, 1.120778, 0.039423},{0.695845, 1.117060, 0.040942},{
      0.694410, 1.118495, 0.040942},{0.698128, 1.123612, 0.039423}}],
    Polygon[{{0.694410, 1.118495, -0.040942},{0.698128, 1.123612, -0.039423},{
      0.694557, 1.125431, -0.039423},{0.692603, 1.119416, -0.040942}}],
    Polygon[{{0.698128, 1.123612, -0.039423},{0.701660, 1.128473, -0.036934},{
      0.696414, 1.131146, -0.036934},{0.694557, 1.125431, -0.039423}}],
    Polygon[{{0.701660, 1.128473, -0.036934},{0.704920, 1.132960, -0.033535},{
      0.698128, 1.136421, -0.033535},{0.696414, 1.131146, -0.036934}}],
    Polygon[{{0.704920, 1.132960, -0.033535},{0.707827, 1.136962, -0.029311},{
      0.699656, 1.141125, -0.029311},{0.698128, 1.136421, -0.033535}}],
    Polygon[{{0.707827, 1.136962, -0.029311},{0.710310, 1.140379, -0.024365},{
      0.700962, 1.145143, -0.024365},{0.699656, 1.141125, -0.029311}}],
    Polygon[{{0.710310, 1.140379, -0.024365},{0.712308, 1.143129, -0.018819},{
      0.702012, 1.148375, -0.018819},{0.700962, 1.145143, -0.024365}}],
    Polygon[{{0.712308, 1.143129, -0.018819},{0.713771, 1.145143, -0.012809},{
      0.702781, 1.150742, -0.012809},{0.702012, 1.148375, -0.018819}}],
    Polygon[{{0.713771, 1.145143, -0.012809},{0.714664, 1.146371, -0.006485},{
      0.703251, 1.152186, -0.006485},{0.702781, 1.150742, -0.012809}}],
    Polygon[{{0.714664, 1.146371, -0.006485},{0.714964, 1.146784, 0.000000},{
      0.703408, 1.152672, 0.000000},{0.703251, 1.152186, -0.006485}}],
    Polygon[{{0.714964, 1.146784, 0.000000},{0.714664, 1.146371, 0.006485},{
      0.703251, 1.152186, 0.006485},{0.703408, 1.152672, 0.000000}}],
    Polygon[{{0.714664, 1.146371, 0.006485},{0.713771, 1.145143, 0.012809},{
      0.702781, 1.150742, 0.012809},{0.703251, 1.152186, 0.006485}}],
    Polygon[{{0.713771, 1.145143, 0.012809},{0.712308, 1.143129, 0.018819},{
      0.702012, 1.148375, 0.018819},{0.702781, 1.150742, 0.012809}}],
    Polygon[{{0.712308, 1.143129, 0.018819},{0.710310, 1.140379, 0.024365},{
      0.700962, 1.145143, 0.024365},{0.702012, 1.148375, 0.018819}}],
    Polygon[{{0.710310, 1.140379, 0.024365},{0.707827, 1.136962, 0.029311},{
      0.699656, 1.141125, 0.029311},{0.700962, 1.145143, 0.024365}}],
    Polygon[{{0.707827, 1.136962, 0.029311},{0.704920, 1.132960, 0.033535},{
      0.698128, 1.136421, 0.033535},{0.699656, 1.141125, 0.029311}}],
    Polygon[{{0.704920, 1.132960, 0.033535},{0.701660, 1.128473, 0.036934},{
      0.696414, 1.131146, 0.036934},{0.698128, 1.136421, 0.033535}}],
    Polygon[{{0.701660, 1.128473, 0.036934},{0.698128, 1.123612, 0.039423},{
      0.694557, 1.125431, 0.039423},{0.696414, 1.131146, 0.036934}}],
    Polygon[{{0.698128, 1.123612, 0.039423},{0.694410, 1.118495, 0.040942},{
      0.692603, 1.119416, 0.040942},{0.694557, 1.125431, 0.039423}}],
    Polygon[{{0.692603, 1.119416, -0.040942},{0.694557, 1.125431, -0.039423},{
      0.690599, 1.126058, -0.039423},{0.690599, 1.119733, -0.040942}}],
    Polygon[{{0.694557, 1.125431, -0.039423},{0.696414, 1.131146, -0.036934},{
      0.690599, 1.132067, -0.036934},{0.690599, 1.126058, -0.039423}}],
    Polygon[{{0.696414, 1.131146, -0.036934},{0.698128, 1.136421, -0.033535},{
      0.690599, 1.137613, -0.033535},{0.690599, 1.132067, -0.036934}}],
    Polygon[{{0.698128, 1.136421, -0.033535},{0.699656, 1.141125, -0.029311},{
      0.690599, 1.142560, -0.029311},{0.690599, 1.137613, -0.033535}}],
    Polygon[{{0.699656, 1.141125, -0.029311},{0.700962, 1.145143, -0.024365},{
      0.690599, 1.146784, -0.024365},{0.690599, 1.142560, -0.029311}}],
    Polygon[{{0.700962, 1.145143, -0.024365},{0.702012, 1.148375, -0.018819},{
      0.690599, 1.150183, -0.018819},{0.690599, 1.146784, -0.024365}}],
    Polygon[{{0.702012, 1.148375, -0.018819},{0.702781, 1.150742, -0.012809},{
      0.690599, 1.152672, -0.012809},{0.690599, 1.150183, -0.018819}}],
    Polygon[{{0.702781, 1.150742, -0.012809},{0.703251, 1.152186, -0.006485},{
      0.690599, 1.154190, -0.006485},{0.690599, 1.152672, -0.012809}}],
    Polygon[{{0.703251, 1.152186, -0.006485},{0.703408, 1.152672, 0.000000},{
      0.690599, 1.154701, 0.000000},{0.690599, 1.154190, -0.006485}}],
    Polygon[{{0.703408, 1.152672, 0.000000},{0.703251, 1.152186, 0.006485},{
      0.690599, 1.154190, 0.006485},{0.690599, 1.154701, 0.000000}}],
    Polygon[{{0.703251, 1.152186, 0.006485},{0.702781, 1.150742, 0.012809},{
      0.690599, 1.152672, 0.012809},{0.690599, 1.154190, 0.006485}}],
    Polygon[{{0.702781, 1.150742, 0.012809},{0.702012, 1.148375, 0.018819},{
      0.690599, 1.150183, 0.018819},{0.690599, 1.152672, 0.012809}}],
    Polygon[{{0.702012, 1.148375, 0.018819},{0.700962, 1.145143, 0.024365},{
      0.690599, 1.146784, 0.024365},{0.690599, 1.150183, 0.018819}}],
    Polygon[{{0.700962, 1.145143, 0.024365},{0.699656, 1.141125, 0.029311},{
      0.690599, 1.142560, 0.029311},{0.690599, 1.146784, 0.024365}}],
    Polygon[{{0.699656, 1.141125, 0.029311},{0.698128, 1.136421, 0.033535},{
      0.690599, 1.137613, 0.033535},{0.690599, 1.142560, 0.029311}}],
    Polygon[{{0.698128, 1.136421, 0.033535},{0.696414, 1.131146, 0.036934},{
      0.690599, 1.132067, 0.036934},{0.690599, 1.137613, 0.033535}}],
    Polygon[{{0.696414, 1.131146, 0.036934},{0.694557, 1.125431, 0.039423},{
      0.690599, 1.126058, 0.039423},{0.690599, 1.132067, 0.036934}}],
    Polygon[{{0.694557, 1.125431, 0.039423},{0.692603, 1.119416, 0.040942},{
      0.690599, 1.119733, 0.040942},{0.690599, 1.126058, 0.039423}}],
    Polygon[{{0.690599, 1.119733, -0.040942},{0.690599, 1.126058, -0.039423},{
      0.686641, 1.125431, -0.039423},{0.688595, 1.119416, -0.040942}}],
    Polygon[{{0.690599, 1.126058, -0.039423},{0.690599, 1.132067, -0.036934},{
      0.684784, 1.131146, -0.036934},{0.686641, 1.125431, -0.039423}}],
    Polygon[{{0.690599, 1.132067, -0.036934},{0.690599, 1.137613, -0.033535},{
      0.683070, 1.136421, -0.033535},{0.684784, 1.131146, -0.036934}}],
    Polygon[{{0.690599, 1.137613, -0.033535},{0.690599, 1.142560, -0.029311},{
      0.681541, 1.141125, -0.029311},{0.683070, 1.136421, -0.033535}}],
    Polygon[{{0.690599, 1.142560, -0.029311},{0.690599, 1.146784, -0.024365},{
      0.680236, 1.145143, -0.024365},{0.681541, 1.141125, -0.029311}}],
    Polygon[{{0.690599, 1.146784, -0.024365},{0.690599, 1.150183, -0.018819},{
      0.679186, 1.148375, -0.018819},{0.680236, 1.145143, -0.024365}}],
    Polygon[{{0.690599, 1.150183, -0.018819},{0.690599, 1.152672, -0.012809},{
      0.678416, 1.150742, -0.012809},{0.679186, 1.148375, -0.018819}}],
    Polygon[{{0.690599, 1.152672, -0.012809},{0.690599, 1.154190, -0.006485},{
      0.677947, 1.152186, -0.006485},{0.678416, 1.150742, -0.012809}}],
    Polygon[{{0.690599, 1.154190, -0.006485},{0.690599, 1.154701, 0.000000},{
      0.677790, 1.152672, 0.000000},{0.677947, 1.152186, -0.006485}}],
    Polygon[{{0.690599, 1.154701, 0.000000},{0.690599, 1.154190, 0.006485},{
      0.677947, 1.152186, 0.006485},{0.677790, 1.152672, 0.000000}}],
    Polygon[{{0.690599, 1.154190, 0.006485},{0.690599, 1.152672, 0.012809},{
      0.678416, 1.150742, 0.012809},{0.677947, 1.152186, 0.006485}}],
    Polygon[{{0.690599, 1.152672, 0.012809},{0.690599, 1.150183, 0.018819},{
      0.679186, 1.148375, 0.018819},{0.678416, 1.150742, 0.012809}}],
    Polygon[{{0.690599, 1.150183, 0.018819},{0.690599, 1.146784, 0.024365},{
      0.680236, 1.145143, 0.024365},{0.679186, 1.148375, 0.018819}}],
    Polygon[{{0.690599, 1.146784, 0.024365},{0.690599, 1.142560, 0.029311},{
      0.681541, 1.141125, 0.029311},{0.680236, 1.145143, 0.024365}}],
    Polygon[{{0.690599, 1.142560, 0.029311},{0.690599, 1.137613, 0.033535},{
      0.683070, 1.136421, 0.033535},{0.681541, 1.141125, 0.029311}}],
    Polygon[{{0.690599, 1.137613, 0.033535},{0.690599, 1.132067, 0.036934},{
      0.684784, 1.131146, 0.036934},{0.683070, 1.136421, 0.033535}}],
    Polygon[{{0.690599, 1.132067, 0.036934},{0.690599, 1.126058, 0.039423},{
      0.686641, 1.125431, 0.039423},{0.684784, 1.131146, 0.036934}}],
    Polygon[{{0.690599, 1.126058, 0.039423},{0.690599, 1.119733, 0.040942},{
      0.688595, 1.119416, 0.040942},{0.686641, 1.125431, 0.039423}}],
    Polygon[{{0.688595, 1.119416, -0.040942},{0.686641, 1.125431, -0.039423},{
      0.683070, 1.123612, -0.039423},{0.686787, 1.118495, -0.040942}}],
    Polygon[{{0.686641, 1.125431, -0.039423},{0.684784, 1.131146, -0.036934},{
      0.679538, 1.128473, -0.036934},{0.683070, 1.123612, -0.039423}}],
    Polygon[{{0.684784, 1.131146, -0.036934},{0.683070, 1.136421, -0.033535},{
      0.676278, 1.132960, -0.033535},{0.679538, 1.128473, -0.036934}}],
    Polygon[{{0.683070, 1.136421, -0.033535},{0.681541, 1.141125, -0.029311},{
      0.673370, 1.136962, -0.029311},{0.676278, 1.132960, -0.033535}}],
    Polygon[{{0.681541, 1.141125, -0.029311},{0.680236, 1.145143, -0.024365},{
      0.670887, 1.140379, -0.024365},{0.673370, 1.136962, -0.029311}}],
    Polygon[{{0.680236, 1.145143, -0.024365},{0.679186, 1.148375, -0.018819},{
      0.668890, 1.143129, -0.018819},{0.670887, 1.140379, -0.024365}}],
    Polygon[{{0.679186, 1.148375, -0.018819},{0.678416, 1.150742, -0.012809},{
      0.667427, 1.145143, -0.012809},{0.668890, 1.143129, -0.018819}}],
    Polygon[{{0.678416, 1.150742, -0.012809},{0.677947, 1.152186, -0.006485},{
      0.666534, 1.146371, -0.006485},{0.667427, 1.145143, -0.012809}}],
    Polygon[{{0.677947, 1.152186, -0.006485},{0.677790, 1.152672, 0.000000},{
      0.666234, 1.146784, 0.000000},{0.666534, 1.146371, -0.006485}}],
    Polygon[{{0.677790, 1.152672, 0.000000},{0.677947, 1.152186, 0.006485},{
      0.666534, 1.146371, 0.006485},{0.666234, 1.146784, 0.000000}}],
    Polygon[{{0.677947, 1.152186, 0.006485},{0.678416, 1.150742, 0.012809},{
      0.667427, 1.145143, 0.012809},{0.666534, 1.146371, 0.006485}}],
    Polygon[{{0.678416, 1.150742, 0.012809},{0.679186, 1.148375, 0.018819},{
      0.668890, 1.143129, 0.018819},{0.667427, 1.145143, 0.012809}}],
    Polygon[{{0.679186, 1.148375, 0.018819},{0.680236, 1.145143, 0.024365},{
      0.670887, 1.140379, 0.024365},{0.668890, 1.143129, 0.018819}}],
    Polygon[{{0.680236, 1.145143, 0.024365},{0.681541, 1.141125, 0.029311},{
      0.673370, 1.136962, 0.029311},{0.670887, 1.140379, 0.024365}}],
    Polygon[{{0.681541, 1.141125, 0.029311},{0.683070, 1.136421, 0.033535},{
      0.676278, 1.132960, 0.033535},{0.673370, 1.136962, 0.029311}}],
    Polygon[{{0.683070, 1.136421, 0.033535},{0.684784, 1.131146, 0.036934},{
      0.679538, 1.128473, 0.036934},{0.676278, 1.132960, 0.033535}}],
    Polygon[{{0.684784, 1.131146, 0.036934},{0.686641, 1.125431, 0.039423},{
      0.683070, 1.123612, 0.039423},{0.679538, 1.128473, 0.036934}}],
    Polygon[{{0.686641, 1.125431, 0.039423},{0.688595, 1.119416, 0.040942},{
      0.686787, 1.118495, 0.040942},{0.683070, 1.123612, 0.039423}}],
    Polygon[{{0.686787, 1.118495, -0.040942},{0.683070, 1.123612, -0.039423},{
      0.680236, 1.120778, -0.039423},{0.685353, 1.117060, -0.040942}}],
    Polygon[{{0.683070, 1.123612, -0.039423},{0.679538, 1.128473, -0.036934},{
      0.675374, 1.124310, -0.036934},{0.680236, 1.120778, -0.039423}}],
    Polygon[{{0.679538, 1.128473, -0.036934},{0.676278, 1.132960, -0.033535},{
      0.670887, 1.127570, -0.033535},{0.675374, 1.124310, -0.036934}}],
    Polygon[{{0.676278, 1.132960, -0.033535},{0.673370, 1.136962, -0.029311},{
      0.666886, 1.130477, -0.029311},{0.670887, 1.127570, -0.033535}}],
    Polygon[{{0.673370, 1.136962, -0.029311},{0.670887, 1.140379, -0.024365},{
      0.663468, 1.132960, -0.024365},{0.666886, 1.130477, -0.029311}}],
    Polygon[{{0.670887, 1.140379, -0.024365},{0.668890, 1.143129, -0.018819},{
      0.660719, 1.134958, -0.018819},{0.663468, 1.132960, -0.024365}}],
    Polygon[{{0.668890, 1.143129, -0.018819},{0.667427, 1.145143, -0.012809},{
      0.658705, 1.136421, -0.012809},{0.660719, 1.134958, -0.018819}}],
    Polygon[{{0.667427, 1.145143, -0.012809},{0.666534, 1.146371, -0.006485},{
      0.657477, 1.137313, -0.006485},{0.658705, 1.136421, -0.012809}}],
    Polygon[{{0.666534, 1.146371, -0.006485},{0.666234, 1.146784, 0.000000},{
      0.657064, 1.137613, 0.000000},{0.657477, 1.137313, -0.006485}}],
    Polygon[{{0.666234, 1.146784, 0.000000},{0.666534, 1.146371, 0.006485},{
      0.657477, 1.137313, 0.006485},{0.657064, 1.137613, 0.000000}}],
    Polygon[{{0.666534, 1.146371, 0.006485},{0.667427, 1.145143, 0.012809},{
      0.658705, 1.136421, 0.012809},{0.657477, 1.137313, 0.006485}}],
    Polygon[{{0.667427, 1.145143, 0.012809},{0.668890, 1.143129, 0.018819},{
      0.660719, 1.134958, 0.018819},{0.658705, 1.136421, 0.012809}}],
    Polygon[{{0.668890, 1.143129, 0.018819},{0.670887, 1.140379, 0.024365},{
      0.663468, 1.132960, 0.024365},{0.660719, 1.134958, 0.018819}}],
    Polygon[{{0.670887, 1.140379, 0.024365},{0.673370, 1.136962, 0.029311},{
      0.666886, 1.130477, 0.029311},{0.663468, 1.132960, 0.024365}}],
    Polygon[{{0.673370, 1.136962, 0.029311},{0.676278, 1.132960, 0.033535},{
      0.670887, 1.127570, 0.033535},{0.666886, 1.130477, 0.029311}}],
    Polygon[{{0.676278, 1.132960, 0.033535},{0.679538, 1.128473, 0.036934},{
      0.675374, 1.124310, 0.036934},{0.670887, 1.127570, 0.033535}}],
    Polygon[{{0.679538, 1.128473, 0.036934},{0.683070, 1.123612, 0.039423},{
      0.680236, 1.120778, 0.039423},{0.675374, 1.124310, 0.036934}}],
    Polygon[{{0.683070, 1.123612, 0.039423},{0.686787, 1.118495, 0.040942},{
      0.685353, 1.117060, 0.040942},{0.680236, 1.120778, 0.039423}}],
    Polygon[{{0.685353, 1.117060, -0.040942},{0.680236, 1.120778, -0.039423},{
      0.678416, 1.117207, -0.039423},{0.684432, 1.115252, -0.040942}}],
    Polygon[{{0.680236, 1.120778, -0.039423},{0.675374, 1.124310, -0.036934},{
      0.672701, 1.119064, -0.036934},{0.678416, 1.117207, -0.039423}}],
    Polygon[{{0.675374, 1.124310, -0.036934},{0.670887, 1.127570, -0.033535},{
      0.667427, 1.120778, -0.033535},{0.672701, 1.119064, -0.036934}}],
    Polygon[{{0.670887, 1.127570, -0.033535},{0.666886, 1.130477, -0.029311},{
      0.662723, 1.122306, -0.029311},{0.667427, 1.120778, -0.033535}}],
    Polygon[{{0.666886, 1.130477, -0.029311},{0.663468, 1.132960, -0.024365},{
      0.658705, 1.123612, -0.024365},{0.662723, 1.122306, -0.029311}}],
    Polygon[{{0.663468, 1.132960, -0.024365},{0.660719, 1.134958, -0.018819},{
      0.655473, 1.124662, -0.018819},{0.658705, 1.123612, -0.024365}}],
    Polygon[{{0.660719, 1.134958, -0.018819},{0.658705, 1.136421, -0.012809},{
      0.653105, 1.125431, -0.012809},{0.655473, 1.124662, -0.018819}}],
    Polygon[{{0.658705, 1.136421, -0.012809},{0.657477, 1.137313, -0.006485},{
      0.651661, 1.125900, -0.006485},{0.653105, 1.125431, -0.012809}}],
    Polygon[{{0.657477, 1.137313, -0.006485},{0.657064, 1.137613, 0.000000},{
      0.651176, 1.126058, 0.000000},{0.651661, 1.125900, -0.006485}}],
    Polygon[{{0.657064, 1.137613, 0.000000},{0.657477, 1.137313, 0.006485},{
      0.651661, 1.125900, 0.006485},{0.651176, 1.126058, 0.000000}}],
    Polygon[{{0.657477, 1.137313, 0.006485},{0.658705, 1.136421, 0.012809},{
      0.653105, 1.125431, 0.012809},{0.651661, 1.125900, 0.006485}}],
    Polygon[{{0.658705, 1.136421, 0.012809},{0.660719, 1.134958, 0.018819},{
      0.655473, 1.124662, 0.018819},{0.653105, 1.125431, 0.012809}}],
    Polygon[{{0.660719, 1.134958, 0.018819},{0.663468, 1.132960, 0.024365},{
      0.658705, 1.123612, 0.024365},{0.655473, 1.124662, 0.018819}}],
    Polygon[{{0.663468, 1.132960, 0.024365},{0.666886, 1.130477, 0.029311},{
      0.662723, 1.122306, 0.029311},{0.658705, 1.123612, 0.024365}}],
    Polygon[{{0.666886, 1.130477, 0.029311},{0.670887, 1.127570, 0.033535},{
      0.667427, 1.120778, 0.033535},{0.662723, 1.122306, 0.029311}}],
    Polygon[{{0.670887, 1.127570, 0.033535},{0.675374, 1.124310, 0.036934},{
      0.672701, 1.119064, 0.036934},{0.667427, 1.120778, 0.033535}}],
    Polygon[{{0.675374, 1.124310, 0.036934},{0.680236, 1.120778, 0.039423},{
      0.678416, 1.117207, 0.039423},{0.672701, 1.119064, 0.036934}}],
    Polygon[{{0.680236, 1.120778, 0.039423},{0.685353, 1.117060, 0.040942},{
      0.684432, 1.115252, 0.040942},{0.678416, 1.117207, 0.039423}}],
    Polygon[{{0.684432, 1.115252, -0.040942},{0.678416, 1.117207, -0.039423},{
      0.677790, 1.113249, -0.039423},{0.684114, 1.113249, -0.040942}}],
    Polygon[{{0.678416, 1.117207, -0.039423},{0.672701, 1.119064, -0.036934},{
      0.671780, 1.113249, -0.036934},{0.677790, 1.113249, -0.039423}}],
    Polygon[{{0.672701, 1.119064, -0.036934},{0.667427, 1.120778, -0.033535},{
      0.666234, 1.113249, -0.033535},{0.671780, 1.113249, -0.036934}}],
    Polygon[{{0.667427, 1.120778, -0.033535},{0.662723, 1.122306, -0.029311},{
      0.661288, 1.113249, -0.029311},{0.666234, 1.113249, -0.033535}}],
    Polygon[{{0.662723, 1.122306, -0.029311},{0.658705, 1.123612, -0.024365},{
      0.657064, 1.113249, -0.024365},{0.661288, 1.113249, -0.029311}}],
    Polygon[{{0.658705, 1.123612, -0.024365},{0.655473, 1.124662, -0.018819},{
      0.653665, 1.113249, -0.018819},{0.657064, 1.113249, -0.024365}}],
    Polygon[{{0.655473, 1.124662, -0.018819},{0.653105, 1.125431, -0.012809},{
      0.651176, 1.113249, -0.012809},{0.653665, 1.113249, -0.018819}}],
    Polygon[{{0.653105, 1.125431, -0.012809},{0.651661, 1.125900, -0.006485},{
      0.649657, 1.113249, -0.006485},{0.651176, 1.113249, -0.012809}}],
    Polygon[{{0.651661, 1.125900, -0.006485},{0.651176, 1.126058, 0.000000},{
      0.649147, 1.113249, 0.000000},{0.649657, 1.113249, -0.006485}}],
    Polygon[{{0.651176, 1.126058, 0.000000},{0.651661, 1.125900, 0.006485},{
      0.649657, 1.113249, 0.006485},{0.649147, 1.113249, 0.000000}}],
    Polygon[{{0.651661, 1.125900, 0.006485},{0.653105, 1.125431, 0.012809},{
      0.651176, 1.113249, 0.012809},{0.649657, 1.113249, 0.006485}}],
    Polygon[{{0.653105, 1.125431, 0.012809},{0.655473, 1.124662, 0.018819},{
      0.653665, 1.113249, 0.018819},{0.651176, 1.113249, 0.012809}}],
    Polygon[{{0.655473, 1.124662, 0.018819},{0.658705, 1.123612, 0.024365},{
      0.657064, 1.113249, 0.024365},{0.653665, 1.113249, 0.018819}}],
    Polygon[{{0.658705, 1.123612, 0.024365},{0.662723, 1.122306, 0.029311},{
      0.661288, 1.113249, 0.029311},{0.657064, 1.113249, 0.024365}}],
    Polygon[{{0.662723, 1.122306, 0.029311},{0.667427, 1.120778, 0.033535},{
      0.666234, 1.113249, 0.033535},{0.661288, 1.113249, 0.029311}}],
    Polygon[{{0.667427, 1.120778, 0.033535},{0.672701, 1.119064, 0.036934},{
      0.671780, 1.113249, 0.036934},{0.666234, 1.113249, 0.033535}}],
    Polygon[{{0.672701, 1.119064, 0.036934},{0.678416, 1.117207, 0.039423},{
      0.677790, 1.113249, 0.039423},{0.671780, 1.113249, 0.036934}}],
    Polygon[{{0.678416, 1.117207, 0.039423},{0.684432, 1.115252, 0.040942},{
      0.684114, 1.113249, 0.040942},{0.677790, 1.113249, 0.039423}}],
    Polygon[{{0.684114, 1.113249, -0.040942},{0.677790, 1.113249, -0.039423},{
      0.678416, 1.109290, -0.039423},{0.684432, 1.111245, -0.040942}}],
    Polygon[{{0.677790, 1.113249, -0.039423},{0.671780, 1.113249, -0.036934},{
      0.672701, 1.107433, -0.036934},{0.678416, 1.109290, -0.039423}}],
    Polygon[{{0.671780, 1.113249, -0.036934},{0.666234, 1.113249, -0.033535},{
      0.667427, 1.105720, -0.033535},{0.672701, 1.107433, -0.036934}}],
    Polygon[{{0.666234, 1.113249, -0.033535},{0.661288, 1.113249, -0.029311},{
      0.662723, 1.104191, -0.029311},{0.667427, 1.105720, -0.033535}}],
    Polygon[{{0.661288, 1.113249, -0.029311},{0.657064, 1.113249, -0.024365},{
      0.658705, 1.102886, -0.024365},{0.662723, 1.104191, -0.029311}}],
    Polygon[{{0.657064, 1.113249, -0.024365},{0.653665, 1.113249, -0.018819},{
      0.655473, 1.101835, -0.018819},{0.658705, 1.102886, -0.024365}}],
    Polygon[{{0.653665, 1.113249, -0.018819},{0.651176, 1.113249, -0.012809},{
      0.653105, 1.101066, -0.012809},{0.655473, 1.101835, -0.018819}}],
    Polygon[{{0.651176, 1.113249, -0.012809},{0.649657, 1.113249, -0.006485},{
      0.651661, 1.100597, -0.006485},{0.653105, 1.101066, -0.012809}}],
    Polygon[{{0.649657, 1.113249, -0.006485},{0.649147, 1.113249, 0.000000},{
      0.651176, 1.100439, 0.000000},{0.651661, 1.100597, -0.006485}}],
    Polygon[{{0.649147, 1.113249, 0.000000},{0.649657, 1.113249, 0.006485},{
      0.651661, 1.100597, 0.006485},{0.651176, 1.100439, 0.000000}}],
    Polygon[{{0.649657, 1.113249, 0.006485},{0.651176, 1.113249, 0.012809},{
      0.653105, 1.101066, 0.012809},{0.651661, 1.100597, 0.006485}}],
    Polygon[{{0.651176, 1.113249, 0.012809},{0.653665, 1.113249, 0.018819},{
      0.655473, 1.101835, 0.018819},{0.653105, 1.101066, 0.012809}}],
    Polygon[{{0.653665, 1.113249, 0.018819},{0.657064, 1.113249, 0.024365},{
      0.658705, 1.102886, 0.024365},{0.655473, 1.101835, 0.018819}}],
    Polygon[{{0.657064, 1.113249, 0.024365},{0.661288, 1.113249, 0.029311},{
      0.662723, 1.104191, 0.029311},{0.658705, 1.102886, 0.024365}}],
    Polygon[{{0.661288, 1.113249, 0.029311},{0.666234, 1.113249, 0.033535},{
      0.667427, 1.105720, 0.033535},{0.662723, 1.104191, 0.029311}}],
    Polygon[{{0.666234, 1.113249, 0.033535},{0.671780, 1.113249, 0.036934},{
      0.672701, 1.107433, 0.036934},{0.667427, 1.105720, 0.033535}}],
    Polygon[{{0.671780, 1.113249, 0.036934},{0.677790, 1.113249, 0.039423},{
      0.678416, 1.109290, 0.039423},{0.672701, 1.107433, 0.036934}}],
    Polygon[{{0.677790, 1.113249, 0.039423},{0.684114, 1.113249, 0.040942},{
      0.684432, 1.111245, 0.040942},{0.678416, 1.109290, 0.039423}}],
    Polygon[{{0.684432, 1.111245, -0.040942},{0.678416, 1.109290, -0.039423},{
      0.680236, 1.105720, -0.039423},{0.685353, 1.109437, -0.040942}}],
    Polygon[{{0.678416, 1.109290, -0.039423},{0.672701, 1.107433, -0.036934},{
      0.675374, 1.102187, -0.036934},{0.680236, 1.105720, -0.039423}}],
    Polygon[{{0.672701, 1.107433, -0.036934},{0.667427, 1.105720, -0.033535},{
      0.670887, 1.098927, -0.033535},{0.675374, 1.102187, -0.036934}}],
    Polygon[{{0.667427, 1.105720, -0.033535},{0.662723, 1.104191, -0.029311},{
      0.666886, 1.096020, -0.029311},{0.670887, 1.098927, -0.033535}}],
    Polygon[{{0.662723, 1.104191, -0.029311},{0.658705, 1.102886, -0.024365},{
      0.663468, 1.093537, -0.024365},{0.666886, 1.096020, -0.029311}}],
    Polygon[{{0.658705, 1.102886, -0.024365},{0.655473, 1.101835, -0.018819},{
      0.660719, 1.091540, -0.018819},{0.663468, 1.093537, -0.024365}}],
    Polygon[{{0.655473, 1.101835, -0.018819},{0.653105, 1.101066, -0.012809},{
      0.658705, 1.090076, -0.012809},{0.660719, 1.091540, -0.018819}}],
    Polygon[{{0.653105, 1.101066, -0.012809},{0.651661, 1.100597, -0.006485},{
      0.657477, 1.089184, -0.006485},{0.658705, 1.090076, -0.012809}}],
    Polygon[{{0.651661, 1.100597, -0.006485},{0.651176, 1.100439, 0.000000},{
      0.657064, 1.088884, 0.000000},{0.657477, 1.089184, -0.006485}}],
    Polygon[{{0.651176, 1.100439, 0.000000},{0.651661, 1.100597, 0.006485},{
      0.657477, 1.089184, 0.006485},{0.657064, 1.088884, 0.000000}}],
    Polygon[{{0.651661, 1.100597, 0.006485},{0.653105, 1.101066, 0.012809},{
      0.658705, 1.090076, 0.012809},{0.657477, 1.089184, 0.006485}}],
    Polygon[{{0.653105, 1.101066, 0.012809},{0.655473, 1.101835, 0.018819},{
      0.660719, 1.091540, 0.018819},{0.658705, 1.090076, 0.012809}}],
    Polygon[{{0.655473, 1.101835, 0.018819},{0.658705, 1.102886, 0.024365},{
      0.663468, 1.093537, 0.024365},{0.660719, 1.091540, 0.018819}}],
    Polygon[{{0.658705, 1.102886, 0.024365},{0.662723, 1.104191, 0.029311},{
      0.666886, 1.096020, 0.029311},{0.663468, 1.093537, 0.024365}}],
    Polygon[{{0.662723, 1.104191, 0.029311},{0.667427, 1.105720, 0.033535},{
      0.670887, 1.098927, 0.033535},{0.666886, 1.096020, 0.029311}}],
    Polygon[{{0.667427, 1.105720, 0.033535},{0.672701, 1.107433, 0.036934},{
      0.675374, 1.102187, 0.036934},{0.670887, 1.098927, 0.033535}}],
    Polygon[{{0.672701, 1.107433, 0.036934},{0.678416, 1.109290, 0.039423},{
      0.680236, 1.105720, 0.039423},{0.675374, 1.102187, 0.036934}}],
    Polygon[{{0.678416, 1.109290, 0.039423},{0.684432, 1.111245, 0.040942},{
      0.685353, 1.109437, 0.040942},{0.680236, 1.105720, 0.039423}}],
    Polygon[{{0.685353, 1.109437, -0.040942},{0.680236, 1.105720, -0.039423},{
      0.683070, 1.102886, -0.039423},{0.686787, 1.108003, -0.040942}}],
    Polygon[{{0.680236, 1.105720, -0.039423},{0.675374, 1.102187, -0.036934},{
      0.679538, 1.098024, -0.036934},{0.683070, 1.102886, -0.039423}}],
    Polygon[{{0.675374, 1.102187, -0.036934},{0.670887, 1.098927, -0.033535},{
      0.676278, 1.093537, -0.033535},{0.679538, 1.098024, -0.036934}}],
    Polygon[{{0.670887, 1.098927, -0.033535},{0.666886, 1.096020, -0.029311},{
      0.673370, 1.089536, -0.029311},{0.676278, 1.093537, -0.033535}}],
    Polygon[{{0.666886, 1.096020, -0.029311},{0.663468, 1.093537, -0.024365},{
      0.670887, 1.086118, -0.024365},{0.673370, 1.089536, -0.029311}}],
    Polygon[{{0.663468, 1.093537, -0.024365},{0.660719, 1.091540, -0.018819},{
      0.668890, 1.083369, -0.018819},{0.670887, 1.086118, -0.024365}}],
    Polygon[{{0.660719, 1.091540, -0.018819},{0.658705, 1.090076, -0.012809},{
      0.667427, 1.081355, -0.012809},{0.668890, 1.083369, -0.018819}}],
    Polygon[{{0.658705, 1.090076, -0.012809},{0.657477, 1.089184, -0.006485},{
      0.666534, 1.080126, -0.006485},{0.667427, 1.081355, -0.012809}}],
    Polygon[{{0.657477, 1.089184, -0.006485},{0.657064, 1.088884, 0.000000},{
      0.666234, 1.079713, 0.000000},{0.666534, 1.080126, -0.006485}}],
    Polygon[{{0.657064, 1.088884, 0.000000},{0.657477, 1.089184, 0.006485},{
      0.666534, 1.080126, 0.006485},{0.666234, 1.079713, 0.000000}}],
    Polygon[{{0.657477, 1.089184, 0.006485},{0.658705, 1.090076, 0.012809},{
      0.667427, 1.081355, 0.012809},{0.666534, 1.080126, 0.006485}}],
    Polygon[{{0.658705, 1.090076, 0.012809},{0.660719, 1.091540, 0.018819},{
      0.668890, 1.083369, 0.018819},{0.667427, 1.081355, 0.012809}}],
    Polygon[{{0.660719, 1.091540, 0.018819},{0.663468, 1.093537, 0.024365},{
      0.670887, 1.086118, 0.024365},{0.668890, 1.083369, 0.018819}}],
    Polygon[{{0.663468, 1.093537, 0.024365},{0.666886, 1.096020, 0.029311},{
      0.673370, 1.089536, 0.029311},{0.670887, 1.086118, 0.024365}}],
    Polygon[{{0.666886, 1.096020, 0.029311},{0.670887, 1.098927, 0.033535},{
      0.676278, 1.093537, 0.033535},{0.673370, 1.089536, 0.029311}}],
    Polygon[{{0.670887, 1.098927, 0.033535},{0.675374, 1.102187, 0.036934},{
      0.679538, 1.098024, 0.036934},{0.676278, 1.093537, 0.033535}}],
    Polygon[{{0.675374, 1.102187, 0.036934},{0.680236, 1.105720, 0.039423},{
      0.683070, 1.102886, 0.039423},{0.679538, 1.098024, 0.036934}}],
    Polygon[{{0.680236, 1.105720, 0.039423},{0.685353, 1.109437, 0.040942},{
      0.686787, 1.108003, 0.040942},{0.683070, 1.102886, 0.039423}}],
    Polygon[{{0.686787, 1.108003, -0.040942},{0.683070, 1.102886, -0.039423},{
      0.686641, 1.101066, -0.039423},{0.688595, 1.107082, -0.040942}}],
    Polygon[{{0.683070, 1.102886, -0.039423},{0.679538, 1.098024, -0.036934},{
      0.684784, 1.095351, -0.036934},{0.686641, 1.101066, -0.039423}}],
    Polygon[{{0.679538, 1.098024, -0.036934},{0.676278, 1.093537, -0.033535},{
      0.683070, 1.090076, -0.033535},{0.684784, 1.095351, -0.036934}}],
    Polygon[{{0.676278, 1.093537, -0.033535},{0.673370, 1.089536, -0.029311},{
      0.681541, 1.085372, -0.029311},{0.683070, 1.090076, -0.033535}}],
    Polygon[{{0.673370, 1.089536, -0.029311},{0.670887, 1.086118, -0.024365},{
      0.680236, 1.081355, -0.024365},{0.681541, 1.085372, -0.029311}}],
    Polygon[{{0.670887, 1.086118, -0.024365},{0.668890, 1.083369, -0.018819},{
      0.679186, 1.078122, -0.018819},{0.680236, 1.081355, -0.024365}}],
    Polygon[{{0.668890, 1.083369, -0.018819},{0.667427, 1.081355, -0.012809},{
      0.678416, 1.075755, -0.012809},{0.679186, 1.078122, -0.018819}}],
    Polygon[{{0.667427, 1.081355, -0.012809},{0.666534, 1.080126, -0.006485},{
      0.677947, 1.074311, -0.006485},{0.678416, 1.075755, -0.012809}}],
    Polygon[{{0.666534, 1.080126, -0.006485},{0.666234, 1.079713, 0.000000},{
      0.677790, 1.073826, 0.000000},{0.677947, 1.074311, -0.006485}}],
    Polygon[{{0.666234, 1.079713, 0.000000},{0.666534, 1.080126, 0.006485},{
      0.677947, 1.074311, 0.006485},{0.677790, 1.073826, 0.000000}}],
    Polygon[{{0.666534, 1.080126, 0.006485},{0.667427, 1.081355, 0.012809},{
      0.678416, 1.075755, 0.012809},{0.677947, 1.074311, 0.006485}}],
    Polygon[{{0.667427, 1.081355, 0.012809},{0.668890, 1.083369, 0.018819},{
      0.679186, 1.078122, 0.018819},{0.678416, 1.075755, 0.012809}}],
    Polygon[{{0.668890, 1.083369, 0.018819},{0.670887, 1.086118, 0.024365},{
      0.680236, 1.081355, 0.024365},{0.679186, 1.078122, 0.018819}}],
    Polygon[{{0.670887, 1.086118, 0.024365},{0.673370, 1.089536, 0.029311},{
      0.681541, 1.085372, 0.029311},{0.680236, 1.081355, 0.024365}}],
    Polygon[{{0.673370, 1.089536, 0.029311},{0.676278, 1.093537, 0.033535},{
      0.683070, 1.090076, 0.033535},{0.681541, 1.085372, 0.029311}}],
    Polygon[{{0.676278, 1.093537, 0.033535},{0.679538, 1.098024, 0.036934},{
      0.684784, 1.095351, 0.036934},{0.683070, 1.090076, 0.033535}}],
    Polygon[{{0.679538, 1.098024, 0.036934},{0.683070, 1.102886, 0.039423},{
      0.686641, 1.101066, 0.039423},{0.684784, 1.095351, 0.036934}}],
    Polygon[{{0.683070, 1.102886, 0.039423},{0.686787, 1.108003, 0.040942},{
      0.688595, 1.107082, 0.040942},{0.686641, 1.101066, 0.039423}}],
    Polygon[{{0.688595, 1.107082, -0.040942},{0.686641, 1.101066, -0.039423},{
      0.690599, 1.100439, -0.039423},{0.690599, 1.106764, -0.040942}}],
    Polygon[{{0.686641, 1.101066, -0.039423},{0.684784, 1.095351, -0.036934},{
      0.690599, 1.094430, -0.036934},{0.690599, 1.100439, -0.039423}}],
    Polygon[{{0.684784, 1.095351, -0.036934},{0.683070, 1.090076, -0.033535},{
      0.690599, 1.088884, -0.033535},{0.690599, 1.094430, -0.036934}}],
    Polygon[{{0.683070, 1.090076, -0.033535},{0.681541, 1.085372, -0.029311},{
      0.690599, 1.083938, -0.029311},{0.690599, 1.088884, -0.033535}}],
    Polygon[{{0.681541, 1.085372, -0.029311},{0.680236, 1.081355, -0.024365},{
      0.690599, 1.079713, -0.024365},{0.690599, 1.083938, -0.029311}}],
    Polygon[{{0.680236, 1.081355, -0.024365},{0.679186, 1.078122, -0.018819},{
      0.690599, 1.076315, -0.018819},{0.690599, 1.079713, -0.024365}}],
    Polygon[{{0.679186, 1.078122, -0.018819},{0.678416, 1.075755, -0.012809},{
      0.690599, 1.073826, -0.012809},{0.690599, 1.076315, -0.018819}}],
    Polygon[{{0.678416, 1.075755, -0.012809},{0.677947, 1.074311, -0.006485},{
      0.690599, 1.072307, -0.006485},{0.690599, 1.073826, -0.012809}}],
    Polygon[{{0.677947, 1.074311, -0.006485},{0.677790, 1.073826, 0.000000},{
      0.690599, 1.071797, 0.000000},{0.690599, 1.072307, -0.006485}}],
    Polygon[{{0.677790, 1.073826, 0.000000},{0.677947, 1.074311, 0.006485},{
      0.690599, 1.072307, 0.006485},{0.690599, 1.071797, 0.000000}}],
    Polygon[{{0.677947, 1.074311, 0.006485},{0.678416, 1.075755, 0.012809},{
      0.690599, 1.073826, 0.012809},{0.690599, 1.072307, 0.006485}}],
    Polygon[{{0.678416, 1.075755, 0.012809},{0.679186, 1.078122, 0.018819},{
      0.690599, 1.076315, 0.018819},{0.690599, 1.073826, 0.012809}}],
    Polygon[{{0.679186, 1.078122, 0.018819},{0.680236, 1.081355, 0.024365},{
      0.690599, 1.079713, 0.024365},{0.690599, 1.076315, 0.018819}}],
    Polygon[{{0.680236, 1.081355, 0.024365},{0.681541, 1.085372, 0.029311},{
      0.690599, 1.083938, 0.029311},{0.690599, 1.079713, 0.024365}}],
    Polygon[{{0.681541, 1.085372, 0.029311},{0.683070, 1.090076, 0.033535},{
      0.690599, 1.088884, 0.033535},{0.690599, 1.083938, 0.029311}}],
    Polygon[{{0.683070, 1.090076, 0.033535},{0.684784, 1.095351, 0.036934},{
      0.690599, 1.094430, 0.036934},{0.690599, 1.088884, 0.033535}}],
    Polygon[{{0.684784, 1.095351, 0.036934},{0.686641, 1.101066, 0.039423},{
      0.690599, 1.100439, 0.039423},{0.690599, 1.094430, 0.036934}}],
    Polygon[{{0.686641, 1.101066, 0.039423},{0.688595, 1.107082, 0.040942},{
      0.690599, 1.106764, 0.040942},{0.690599, 1.100439, 0.039423}}],
    Polygon[{{0.690599, 1.106764, -0.040942},{0.690599, 1.100439, -0.039423},{
      0.694557, 1.101066, -0.039423},{0.692603, 1.107082, -0.040942}}],
    Polygon[{{0.690599, 1.100439, -0.039423},{0.690599, 1.094430, -0.036934},{
      0.696414, 1.095351, -0.036934},{0.694557, 1.101066, -0.039423}}],
    Polygon[{{0.690599, 1.094430, -0.036934},{0.690599, 1.088884, -0.033535},{
      0.698128, 1.090076, -0.033535},{0.696414, 1.095351, -0.036934}}],
    Polygon[{{0.690599, 1.088884, -0.033535},{0.690599, 1.083938, -0.029311},{
      0.699656, 1.085372, -0.029311},{0.698128, 1.090076, -0.033535}}],
    Polygon[{{0.690599, 1.083938, -0.029311},{0.690599, 1.079713, -0.024365},{
      0.700962, 1.081355, -0.024365},{0.699656, 1.085372, -0.029311}}],
    Polygon[{{0.690599, 1.079713, -0.024365},{0.690599, 1.076315, -0.018819},{
      0.702012, 1.078122, -0.018819},{0.700962, 1.081355, -0.024365}}],
    Polygon[{{0.690599, 1.076315, -0.018819},{0.690599, 1.073826, -0.012809},{
      0.702781, 1.075755, -0.012809},{0.702012, 1.078122, -0.018819}}],
    Polygon[{{0.690599, 1.073826, -0.012809},{0.690599, 1.072307, -0.006485},{
      0.703251, 1.074311, -0.006485},{0.702781, 1.075755, -0.012809}}],
    Polygon[{{0.690599, 1.072307, -0.006485},{0.690599, 1.071797, 0.000000},{
      0.703408, 1.073826, 0.000000},{0.703251, 1.074311, -0.006485}}],
    Polygon[{{0.690599, 1.071797, 0.000000},{0.690599, 1.072307, 0.006485},{
      0.703251, 1.074311, 0.006485},{0.703408, 1.073826, 0.000000}}],
    Polygon[{{0.690599, 1.072307, 0.006485},{0.690599, 1.073826, 0.012809},{
      0.702781, 1.075755, 0.012809},{0.703251, 1.074311, 0.006485}}],
    Polygon[{{0.690599, 1.073826, 0.012809},{0.690599, 1.076315, 0.018819},{
      0.702012, 1.078122, 0.018819},{0.702781, 1.075755, 0.012809}}],
    Polygon[{{0.690599, 1.076315, 0.018819},{0.690599, 1.079713, 0.024365},{
      0.700962, 1.081355, 0.024365},{0.702012, 1.078122, 0.018819}}],
    Polygon[{{0.690599, 1.079713, 0.024365},{0.690599, 1.083938, 0.029311},{
      0.699656, 1.085372, 0.029311},{0.700962, 1.081355, 0.024365}}],
    Polygon[{{0.690599, 1.083938, 0.029311},{0.690599, 1.088884, 0.033535},{
      0.698128, 1.090076, 0.033535},{0.699656, 1.085372, 0.029311}}],
    Polygon[{{0.690599, 1.088884, 0.033535},{0.690599, 1.094430, 0.036934},{
      0.696414, 1.095351, 0.036934},{0.698128, 1.090076, 0.033535}}],
    Polygon[{{0.690599, 1.094430, 0.036934},{0.690599, 1.100439, 0.039423},{
      0.694557, 1.101066, 0.039423},{0.696414, 1.095351, 0.036934}}],
    Polygon[{{0.690599, 1.100439, 0.039423},{0.690599, 1.106764, 0.040942},{
      0.692603, 1.107082, 0.040942},{0.694557, 1.101066, 0.039423}}],
    Polygon[{{0.692603, 1.107082, -0.040942},{0.694557, 1.101066, -0.039423},{
      0.698128, 1.102886, -0.039423},{0.694410, 1.108003, -0.040942}}],
    Polygon[{{0.694557, 1.101066, -0.039423},{0.696414, 1.095351, -0.036934},{
      0.701660, 1.098024, -0.036934},{0.698128, 1.102886, -0.039423}}],
    Polygon[{{0.696414, 1.095351, -0.036934},{0.698128, 1.090076, -0.033535},{
      0.704920, 1.093537, -0.033535},{0.701660, 1.098024, -0.036934}}],
    Polygon[{{0.698128, 1.090076, -0.033535},{0.699656, 1.085372, -0.029311},{
      0.707827, 1.089536, -0.029311},{0.704920, 1.093537, -0.033535}}],
    Polygon[{{0.699656, 1.085372, -0.029311},{0.700962, 1.081355, -0.024365},{
      0.710310, 1.086118, -0.024365},{0.707827, 1.089536, -0.029311}}],
    Polygon[{{0.700962, 1.081355, -0.024365},{0.702012, 1.078122, -0.018819},{
      0.712308, 1.083369, -0.018819},{0.710310, 1.086118, -0.024365}}],
    Polygon[{{0.702012, 1.078122, -0.018819},{0.702781, 1.075755, -0.012809},{
      0.713771, 1.081355, -0.012809},{0.712308, 1.083369, -0.018819}}],
    Polygon[{{0.702781, 1.075755, -0.012809},{0.703251, 1.074311, -0.006485},{
      0.714664, 1.080126, -0.006485},{0.713771, 1.081355, -0.012809}}],
    Polygon[{{0.703251, 1.074311, -0.006485},{0.703408, 1.073826, 0.000000},{
      0.714964, 1.079713, 0.000000},{0.714664, 1.080126, -0.006485}}],
    Polygon[{{0.703408, 1.073826, 0.000000},{0.703251, 1.074311, 0.006485},{
      0.714664, 1.080126, 0.006485},{0.714964, 1.079713, 0.000000}}],
    Polygon[{{0.703251, 1.074311, 0.006485},{0.702781, 1.075755, 0.012809},{
      0.713771, 1.081355, 0.012809},{0.714664, 1.080126, 0.006485}}],
    Polygon[{{0.702781, 1.075755, 0.012809},{0.702012, 1.078122, 0.018819},{
      0.712308, 1.083369, 0.018819},{0.713771, 1.081355, 0.012809}}],
    Polygon[{{0.702012, 1.078122, 0.018819},{0.700962, 1.081355, 0.024365},{
      0.710310, 1.086118, 0.024365},{0.712308, 1.083369, 0.018819}}],
    Polygon[{{0.700962, 1.081355, 0.024365},{0.699656, 1.085372, 0.029311},{
      0.707827, 1.089536, 0.029311},{0.710310, 1.086118, 0.024365}}],
    Polygon[{{0.699656, 1.085372, 0.029311},{0.698128, 1.090076, 0.033535},{
      0.704920, 1.093537, 0.033535},{0.707827, 1.089536, 0.029311}}],
    Polygon[{{0.698128, 1.090076, 0.033535},{0.696414, 1.095351, 0.036934},{
      0.701660, 1.098024, 0.036934},{0.704920, 1.093537, 0.033535}}],
    Polygon[{{0.696414, 1.095351, 0.036934},{0.694557, 1.101066, 0.039423},{
      0.698128, 1.102886, 0.039423},{0.701660, 1.098024, 0.036934}}],
    Polygon[{{0.694557, 1.101066, 0.039423},{0.692603, 1.107082, 0.040942},{
      0.694410, 1.108003, 0.040942},{0.698128, 1.102886, 0.039423}}],
    Polygon[{{0.694410, 1.108003, -0.040942},{0.698128, 1.102886, -0.039423},{
      0.700962, 1.105720, -0.039423},{0.695845, 1.109437, -0.040942}}],
    Polygon[{{0.698128, 1.102886, -0.039423},{0.701660, 1.098024, -0.036934},{
      0.705824, 1.102187, -0.036934},{0.700962, 1.105720, -0.039423}}],
    Polygon[{{0.701660, 1.098024, -0.036934},{0.704920, 1.093537, -0.033535},{
      0.710310, 1.098927, -0.033535},{0.705824, 1.102187, -0.036934}}],
    Polygon[{{0.704920, 1.093537, -0.033535},{0.707827, 1.089536, -0.029311},{
      0.714312, 1.096020, -0.029311},{0.710310, 1.098927, -0.033535}}],
    Polygon[{{0.707827, 1.089536, -0.029311},{0.710310, 1.086118, -0.024365},{
      0.717730, 1.093537, -0.024365},{0.714312, 1.096020, -0.029311}}],
    Polygon[{{0.710310, 1.086118, -0.024365},{0.712308, 1.083369, -0.018819},{
      0.720479, 1.091540, -0.018819},{0.717730, 1.093537, -0.024365}}],
    Polygon[{{0.712308, 1.083369, -0.018819},{0.713771, 1.081355, -0.012809},{
      0.722493, 1.090076, -0.012809},{0.720479, 1.091540, -0.018819}}],
    Polygon[{{0.713771, 1.081355, -0.012809},{0.714664, 1.080126, -0.006485},{
      0.723721, 1.089184, -0.006485},{0.722493, 1.090076, -0.012809}}],
    Polygon[{{0.714664, 1.080126, -0.006485},{0.714964, 1.079713, 0.000000},{
      0.724134, 1.088884, 0.000000},{0.723721, 1.089184, -0.006485}}],
    Polygon[{{0.714964, 1.079713, 0.000000},{0.714664, 1.080126, 0.006485},{
      0.723721, 1.089184, 0.006485},{0.724134, 1.088884, 0.000000}}],
    Polygon[{{0.714664, 1.080126, 0.006485},{0.713771, 1.081355, 0.012809},{
      0.722493, 1.090076, 0.012809},{0.723721, 1.089184, 0.006485}}],
    Polygon[{{0.713771, 1.081355, 0.012809},{0.712308, 1.083369, 0.018819},{
      0.720479, 1.091540, 0.018819},{0.722493, 1.090076, 0.012809}}],
    Polygon[{{0.712308, 1.083369, 0.018819},{0.710310, 1.086118, 0.024365},{
      0.717730, 1.093537, 0.024365},{0.720479, 1.091540, 0.018819}}],
    Polygon[{{0.710310, 1.086118, 0.024365},{0.707827, 1.089536, 0.029311},{
      0.714312, 1.096020, 0.029311},{0.717730, 1.093537, 0.024365}}],
    Polygon[{{0.707827, 1.089536, 0.029311},{0.704920, 1.093537, 0.033535},{
      0.710310, 1.098927, 0.033535},{0.714312, 1.096020, 0.029311}}],
    Polygon[{{0.704920, 1.093537, 0.033535},{0.701660, 1.098024, 0.036934},{
      0.705824, 1.102187, 0.036934},{0.710310, 1.098927, 0.033535}}],
    Polygon[{{0.701660, 1.098024, 0.036934},{0.698128, 1.102886, 0.039423},{
      0.700962, 1.105720, 0.039423},{0.705824, 1.102187, 0.036934}}],
    Polygon[{{0.698128, 1.102886, 0.039423},{0.694410, 1.108003, 0.040942},{
      0.695845, 1.109437, 0.040942},{0.700962, 1.105720, 0.039423}}],
    Polygon[{{0.695845, 1.109437, -0.040942},{0.700962, 1.105720, -0.039423},{
      0.702781, 1.109290, -0.039423},{0.696766, 1.111245, -0.040942}}],
    Polygon[{{0.700962, 1.105720, -0.039423},{0.705824, 1.102187, -0.036934},{
      0.708497, 1.107433, -0.036934},{0.702781, 1.109290, -0.039423}}],
    Polygon[{{0.705824, 1.102187, -0.036934},{0.710310, 1.098927, -0.033535},{
      0.713771, 1.105720, -0.033535},{0.708497, 1.107433, -0.036934}}],
    Polygon[{{0.710310, 1.098927, -0.033535},{0.714312, 1.096020, -0.029311},{
      0.718475, 1.104191, -0.029311},{0.713771, 1.105720, -0.033535}}],
    Polygon[{{0.714312, 1.096020, -0.029311},{0.717730, 1.093537, -0.024365},{
      0.722493, 1.102886, -0.024365},{0.718475, 1.104191, -0.029311}}],
    Polygon[{{0.717730, 1.093537, -0.024365},{0.720479, 1.091540, -0.018819},{
      0.725725, 1.101835, -0.018819},{0.722493, 1.102886, -0.024365}}],
    Polygon[{{0.720479, 1.091540, -0.018819},{0.722493, 1.090076, -0.012809},{
      0.728092, 1.101066, -0.012809},{0.725725, 1.101835, -0.018819}}],
    Polygon[{{0.722493, 1.090076, -0.012809},{0.723721, 1.089184, -0.006485},{
      0.729537, 1.100597, -0.006485},{0.728092, 1.101066, -0.012809}}],
    Polygon[{{0.723721, 1.089184, -0.006485},{0.724134, 1.088884, 0.000000},{
      0.730022, 1.100439, 0.000000},{0.729537, 1.100597, -0.006485}}],
    Polygon[{{0.724134, 1.088884, 0.000000},{0.723721, 1.089184, 0.006485},{
      0.729537, 1.100597, 0.006485},{0.730022, 1.100439, 0.000000}}],
    Polygon[{{0.723721, 1.089184, 0.006485},{0.722493, 1.090076, 0.012809},{
      0.728092, 1.101066, 0.012809},{0.729537, 1.100597, 0.006485}}],
    Polygon[{{0.722493, 1.090076, 0.012809},{0.720479, 1.091540, 0.018819},{
      0.725725, 1.101835, 0.018819},{0.728092, 1.101066, 0.012809}}],
    Polygon[{{0.720479, 1.091540, 0.018819},{0.717730, 1.093537, 0.024365},{
      0.722493, 1.102886, 0.024365},{0.725725, 1.101835, 0.018819}}],
    Polygon[{{0.717730, 1.093537, 0.024365},{0.714312, 1.096020, 0.029311},{
      0.718475, 1.104191, 0.029311},{0.722493, 1.102886, 0.024365}}],
    Polygon[{{0.714312, 1.096020, 0.029311},{0.710310, 1.098927, 0.033535},{
      0.713771, 1.105720, 0.033535},{0.718475, 1.104191, 0.029311}}],
    Polygon[{{0.710310, 1.098927, 0.033535},{0.705824, 1.102187, 0.036934},{
      0.708497, 1.107433, 0.036934},{0.713771, 1.105720, 0.033535}}],
    Polygon[{{0.705824, 1.102187, 0.036934},{0.700962, 1.105720, 0.039423},{
      0.702781, 1.109290, 0.039423},{0.708497, 1.107433, 0.036934}}],
    Polygon[{{0.700962, 1.105720, 0.039423},{0.695845, 1.109437, 0.040942},{
      0.696766, 1.111245, 0.040942},{0.702781, 1.109290, 0.039423}}],
    Polygon[{{0.696766, 1.111245, -0.040942},{0.702781, 1.109290, -0.039423},{
      0.703408, 1.113249, -0.039423},{0.697083, 1.113249, -0.040942}}],
    Polygon[{{0.702781, 1.109290, -0.039423},{0.708497, 1.107433, -0.036934},{
      0.709418, 1.113249, -0.036934},{0.703408, 1.113249, -0.039423}}],
    Polygon[{{0.708497, 1.107433, -0.036934},{0.713771, 1.105720, -0.033535},{
      0.714964, 1.113249, -0.033535},{0.709418, 1.113249, -0.036934}}],
    Polygon[{{0.713771, 1.105720, -0.033535},{0.718475, 1.104191, -0.029311},{
      0.719910, 1.113249, -0.029311},{0.714964, 1.113249, -0.033535}}],
    Polygon[{{0.718475, 1.104191, -0.029311},{0.722493, 1.102886, -0.024365},{
      0.724134, 1.113249, -0.024365},{0.719910, 1.113249, -0.029311}}],
    Polygon[{{0.722493, 1.102886, -0.024365},{0.725725, 1.101835, -0.018819},{
      0.727533, 1.113249, -0.018819},{0.724134, 1.113249, -0.024365}}],
    Polygon[{{0.725725, 1.101835, -0.018819},{0.728092, 1.101066, -0.012809},{
      0.730022, 1.113249, -0.012809},{0.727533, 1.113249, -0.018819}}],
    Polygon[{{0.728092, 1.101066, -0.012809},{0.729537, 1.100597, -0.006485},{
      0.731540, 1.113249, -0.006485},{0.730022, 1.113249, -0.012809}}],
    Polygon[{{0.729537, 1.100597, -0.006485},{0.730022, 1.100439, 0.000000},{
      0.732051, 1.113249, 0.000000},{0.731540, 1.113249, -0.006485}}],
    Polygon[{{0.730022, 1.100439, 0.000000},{0.729537, 1.100597, 0.006485},{
      0.731540, 1.113249, 0.006485},{0.732051, 1.113249, 0.000000}}],
    Polygon[{{0.729537, 1.100597, 0.006485},{0.728092, 1.101066, 0.012809},{
      0.730022, 1.113249, 0.012809},{0.731540, 1.113249, 0.006485}}],
    Polygon[{{0.728092, 1.101066, 0.012809},{0.725725, 1.101835, 0.018819},{
      0.727533, 1.113249, 0.018819},{0.730022, 1.113249, 0.012809}}],
    Polygon[{{0.725725, 1.101835, 0.018819},{0.722493, 1.102886, 0.024365},{
      0.724134, 1.113249, 0.024365},{0.727533, 1.113249, 0.018819}}],
    Polygon[{{0.722493, 1.102886, 0.024365},{0.718475, 1.104191, 0.029311},{
      0.719910, 1.113249, 0.029311},{0.724134, 1.113249, 0.024365}}],
    Polygon[{{0.718475, 1.104191, 0.029311},{0.713771, 1.105720, 0.033535},{
      0.714964, 1.113249, 0.033535},{0.719910, 1.113249, 0.029311}}],
    Polygon[{{0.713771, 1.105720, 0.033535},{0.708497, 1.107433, 0.036934},{
      0.709418, 1.113249, 0.036934},{0.714964, 1.113249, 0.033535}}],
    Polygon[{{0.708497, 1.107433, 0.036934},{0.702781, 1.109290, 0.039423},{
      0.703408, 1.113249, 0.039423},{0.709418, 1.113249, 0.036934}}],
    Polygon[{{0.702781, 1.109290, 0.039423},{0.696766, 1.111245, 0.040942},{
      0.697083, 1.113249, 0.040942},{0.703408, 1.113249, 0.039423}}],
    Polygon[{{0.648371, 1.064459, -0.025466},{0.652305, 1.064459, -0.024521},{
      0.651915, 1.066921, -0.024521},{0.648174, 1.065705, -0.025466}}],
    Polygon[{{0.652305, 1.064459, -0.024521},{0.656043, 1.064459, -0.022973},{
      0.655470, 1.068076, -0.022973},{0.651915, 1.066921, -0.024521}}],
    Polygon[{{0.656043, 1.064459, -0.022973},{0.659493, 1.064459, -0.020859},{
      0.658751, 1.069142, -0.020859},{0.655470, 1.068076, -0.022973}}],
    Polygon[{{0.659493, 1.064459, -0.020859},{0.662569, 1.064459, -0.018232},{
      0.661677, 1.070092, -0.018232},{0.658751, 1.069142, -0.020859}}],
    Polygon[{{0.662569, 1.064459, -0.018232},{0.665197, 1.064459, -0.015155},{
      0.664176, 1.070904, -0.015155},{0.661677, 1.070092, -0.018232}}],
    Polygon[{{0.665197, 1.064459, -0.015155},{0.667311, 1.064459, -0.011705},{
      0.666186, 1.071558, -0.011705},{0.664176, 1.070904, -0.015155}}],
    Polygon[{{0.667311, 1.064459, -0.011705},{0.668859, 1.064459, -0.007968},{
      0.667659, 1.072036, -0.007968},{0.666186, 1.071558, -0.011705}}],
    Polygon[{{0.668859, 1.064459, -0.007968},{0.669804, 1.064459, -0.004033},{
      0.668557, 1.072328, -0.004033},{0.667659, 1.072036, -0.007968}}],
    Polygon[{{0.669804, 1.064459, -0.004033},{0.670121, 1.064459, 0.000000},{
      0.668859, 1.072426, 0.000000},{0.668557, 1.072328, -0.004033}}],
    Polygon[{{0.670121, 1.064459, 0.000000},{0.669804, 1.064459, 0.004033},{
      0.668557, 1.072328, 0.004033},{0.668859, 1.072426, 0.000000}}],
    Polygon[{{0.669804, 1.064459, 0.004033},{0.668859, 1.064459, 0.007968},{
      0.667659, 1.072036, 0.007968},{0.668557, 1.072328, 0.004033}}],
    Polygon[{{0.668859, 1.064459, 0.007968},{0.667311, 1.064459, 0.011705},{
      0.666186, 1.071558, 0.011705},{0.667659, 1.072036, 0.007968}}],
    Polygon[{{0.667311, 1.064459, 0.011705},{0.665197, 1.064459, 0.015155},{
      0.664176, 1.070904, 0.015155},{0.666186, 1.071558, 0.011705}}],
    Polygon[{{0.665197, 1.064459, 0.015155},{0.662569, 1.064459, 0.018232},{
      0.661677, 1.070092, 0.018232},{0.664176, 1.070904, 0.015155}}],
    Polygon[{{0.662569, 1.064459, 0.018232},{0.659493, 1.064459, 0.020859},{
      0.658751, 1.069142, 0.020859},{0.661677, 1.070092, 0.018232}}],
    Polygon[{{0.659493, 1.064459, 0.020859},{0.656043, 1.064459, 0.022973},{
      0.655470, 1.068076, 0.022973},{0.658751, 1.069142, 0.020859}}],
    Polygon[{{0.656043, 1.064459, 0.022973},{0.652305, 1.064459, 0.024521},{
      0.651915, 1.066921, 0.024521},{0.655470, 1.068076, 0.022973}}],
    Polygon[{{0.652305, 1.064459, 0.024521},{0.648371, 1.064459, 0.025466},{
      0.648174, 1.065705, 0.025466},{0.651915, 1.066921, 0.024521}}],
    Polygon[{{0.648174, 1.065705, -0.025466},{0.651915, 1.066921, -0.024521},{
      0.650783, 1.069142, -0.024521},{0.647601, 1.066829, -0.025466}}],
    Polygon[{{0.651915, 1.066921, -0.024521},{0.655470, 1.068076, -0.022973},{
      0.653807, 1.071339, -0.022973},{0.650783, 1.069142, -0.024521}}],
    Polygon[{{0.655470, 1.068076, -0.022973},{0.658751, 1.069142, -0.020859},{
      0.656598, 1.073367, -0.020859},{0.653807, 1.071339, -0.022973}}],
    Polygon[{{0.658751, 1.069142, -0.020859},{0.661677, 1.070092, -0.018232},{
      0.659087, 1.075175, -0.018232},{0.656598, 1.073367, -0.020859}}],
    Polygon[{{0.661677, 1.070092, -0.018232},{0.664176, 1.070904, -0.015155},{
      0.661213, 1.076719, -0.015155},{0.659087, 1.075175, -0.018232}}],
    Polygon[{{0.664176, 1.070904, -0.015155},{0.666186, 1.071558, -0.011705},{
      0.662923, 1.077962, -0.011705},{0.661213, 1.076719, -0.015155}}],
    Polygon[{{0.666186, 1.071558, -0.011705},{0.667659, 1.072036, -0.007968},{
      0.664176, 1.078872, -0.007968},{0.662923, 1.077962, -0.011705}}],
    Polygon[{{0.667659, 1.072036, -0.007968},{0.668557, 1.072328, -0.004033},{
      0.664940, 1.079427, -0.004033},{0.664176, 1.078872, -0.007968}}],
    Polygon[{{0.668557, 1.072328, -0.004033},{0.668859, 1.072426, 0.000000},{
      0.665197, 1.079614, 0.000000},{0.664940, 1.079427, -0.004033}}],
    Polygon[{{0.668859, 1.072426, 0.000000},{0.668557, 1.072328, 0.004033},{
      0.664940, 1.079427, 0.004033},{0.665197, 1.079614, 0.000000}}],
    Polygon[{{0.668557, 1.072328, 0.004033},{0.667659, 1.072036, 0.007968},{
      0.664176, 1.078872, 0.007968},{0.664940, 1.079427, 0.004033}}],
    Polygon[{{0.667659, 1.072036, 0.007968},{0.666186, 1.071558, 0.011705},{
      0.662923, 1.077962, 0.011705},{0.664176, 1.078872, 0.007968}}],
    Polygon[{{0.666186, 1.071558, 0.011705},{0.664176, 1.070904, 0.015155},{
      0.661213, 1.076719, 0.015155},{0.662923, 1.077962, 0.011705}}],
    Polygon[{{0.664176, 1.070904, 0.015155},{0.661677, 1.070092, 0.018232},{
      0.659087, 1.075175, 0.018232},{0.661213, 1.076719, 0.015155}}],
    Polygon[{{0.661677, 1.070092, 0.018232},{0.658751, 1.069142, 0.020859},{
      0.656598, 1.073367, 0.020859},{0.659087, 1.075175, 0.018232}}],
    Polygon[{{0.658751, 1.069142, 0.020859},{0.655470, 1.068076, 0.022973},{
      0.653807, 1.071339, 0.022973},{0.656598, 1.073367, 0.020859}}],
    Polygon[{{0.655470, 1.068076, 0.022973},{0.651915, 1.066921, 0.024521},{
      0.650783, 1.069142, 0.024521},{0.653807, 1.071339, 0.022973}}],
    Polygon[{{0.651915, 1.066921, 0.024521},{0.648174, 1.065705, 0.025466},{
      0.647601, 1.066829, 0.025466},{0.650783, 1.069142, 0.024521}}],
    Polygon[{{0.647601, 1.066829, -0.025466},{0.650783, 1.069142, -0.024521},{
      0.649021, 1.070904, -0.024521},{0.646708, 1.067722, -0.025466}}],
    Polygon[{{0.650783, 1.069142, -0.024521},{0.653807, 1.071339, -0.022973},{
      0.651218, 1.073928, -0.022973},{0.649021, 1.070904, -0.024521}}],
    Polygon[{{0.653807, 1.071339, -0.022973},{0.656598, 1.073367, -0.020859},{
      0.653246, 1.076719, -0.020859},{0.651218, 1.073928, -0.022973}}],
    Polygon[{{0.656598, 1.073367, -0.020859},{0.659087, 1.075175, -0.018232},{
      0.655054, 1.079208, -0.018232},{0.653246, 1.076719, -0.020859}}],
    Polygon[{{0.659087, 1.075175, -0.018232},{0.661213, 1.076719, -0.015155},{
      0.656598, 1.081334, -0.015155},{0.655054, 1.079208, -0.018232}}],
    Polygon[{{0.661213, 1.076719, -0.015155},{0.662923, 1.077962, -0.011705},{
      0.657841, 1.083044, -0.011705},{0.656598, 1.081334, -0.015155}}],
    Polygon[{{0.662923, 1.077962, -0.011705},{0.664176, 1.078872, -0.007968},{
      0.658751, 1.084297, -0.007968},{0.657841, 1.083044, -0.011705}}],
    Polygon[{{0.664176, 1.078872, -0.007968},{0.664940, 1.079427, -0.004033},{
      0.659306, 1.085061, -0.004033},{0.658751, 1.084297, -0.007968}}],
    Polygon[{{0.664940, 1.079427, -0.004033},{0.665197, 1.079614, 0.000000},{
      0.659493, 1.085318, 0.000000},{0.659306, 1.085061, -0.004033}}],
    Polygon[{{0.665197, 1.079614, 0.000000},{0.664940, 1.079427, 0.004033},{
      0.659306, 1.085061, 0.004033},{0.659493, 1.085318, 0.000000}}],
    Polygon[{{0.664940, 1.079427, 0.004033},{0.664176, 1.078872, 0.007968},{
      0.658751, 1.084297, 0.007968},{0.659306, 1.085061, 0.004033}}],
    Polygon[{{0.664176, 1.078872, 0.007968},{0.662923, 1.077962, 0.011705},{
      0.657841, 1.083044, 0.011705},{0.658751, 1.084297, 0.007968}}],
    Polygon[{{0.662923, 1.077962, 0.011705},{0.661213, 1.076719, 0.015155},{
      0.656598, 1.081334, 0.015155},{0.657841, 1.083044, 0.011705}}],
    Polygon[{{0.661213, 1.076719, 0.015155},{0.659087, 1.075175, 0.018232},{
      0.655054, 1.079208, 0.018232},{0.656598, 1.081334, 0.015155}}],
    Polygon[{{0.659087, 1.075175, 0.018232},{0.656598, 1.073367, 0.020859},{
      0.653246, 1.076719, 0.020859},{0.655054, 1.079208, 0.018232}}],
    Polygon[{{0.656598, 1.073367, 0.020859},{0.653807, 1.071339, 0.022973},{
      0.651218, 1.073928, 0.022973},{0.653246, 1.076719, 0.020859}}],
    Polygon[{{0.653807, 1.071339, 0.022973},{0.650783, 1.069142, 0.024521},{
      0.649021, 1.070904, 0.024521},{0.651218, 1.073928, 0.022973}}],
    Polygon[{{0.650783, 1.069142, 0.024521},{0.647601, 1.066829, 0.025466},{
      0.646708, 1.067722, 0.025466},{0.649021, 1.070904, 0.024521}}],
    Polygon[{{0.646708, 1.067722, -0.025466},{0.649021, 1.070904, -0.024521},{
      0.646800, 1.072036, -0.024521},{0.645584, 1.068295, -0.025466}}],
    Polygon[{{0.649021, 1.070904, -0.024521},{0.651218, 1.073928, -0.022973},{
      0.647955, 1.075591, -0.022973},{0.646800, 1.072036, -0.024521}}],
    Polygon[{{0.651218, 1.073928, -0.022973},{0.653246, 1.076719, -0.020859},{
      0.649021, 1.078872, -0.020859},{0.647955, 1.075591, -0.022973}}],
    Polygon[{{0.653246, 1.076719, -0.020859},{0.655054, 1.079208, -0.018232},{
      0.649971, 1.081798, -0.018232},{0.649021, 1.078872, -0.020859}}],
    Polygon[{{0.655054, 1.079208, -0.018232},{0.656598, 1.081334, -0.015155},{
      0.650783, 1.084297, -0.015155},{0.649971, 1.081798, -0.018232}}],
    Polygon[{{0.656598, 1.081334, -0.015155},{0.657841, 1.083044, -0.011705},{
      0.651437, 1.086307, -0.011705},{0.650783, 1.084297, -0.015155}}],
    Polygon[{{0.657841, 1.083044, -0.011705},{0.658751, 1.084297, -0.007968},{
      0.651915, 1.087780, -0.007968},{0.651437, 1.086307, -0.011705}}],
    Polygon[{{0.658751, 1.084297, -0.007968},{0.659306, 1.085061, -0.004033},{
      0.652207, 1.088678, -0.004033},{0.651915, 1.087780, -0.007968}}],
    Polygon[{{0.659306, 1.085061, -0.004033},{0.659493, 1.085318, 0.000000},{
      0.652305, 1.088980, 0.000000},{0.652207, 1.088678, -0.004033}}],
    Polygon[{{0.659493, 1.085318, 0.000000},{0.659306, 1.085061, 0.004033},{
      0.652207, 1.088678, 0.004033},{0.652305, 1.088980, 0.000000}}],
    Polygon[{{0.659306, 1.085061, 0.004033},{0.658751, 1.084297, 0.007968},{
      0.651915, 1.087780, 0.007968},{0.652207, 1.088678, 0.004033}}],
    Polygon[{{0.658751, 1.084297, 0.007968},{0.657841, 1.083044, 0.011705},{
      0.651437, 1.086307, 0.011705},{0.651915, 1.087780, 0.007968}}],
    Polygon[{{0.657841, 1.083044, 0.011705},{0.656598, 1.081334, 0.015155},{
      0.650783, 1.084297, 0.015155},{0.651437, 1.086307, 0.011705}}],
    Polygon[{{0.656598, 1.081334, 0.015155},{0.655054, 1.079208, 0.018232},{
      0.649971, 1.081798, 0.018232},{0.650783, 1.084297, 0.015155}}],
    Polygon[{{0.655054, 1.079208, 0.018232},{0.653246, 1.076719, 0.020859},{
      0.649021, 1.078872, 0.020859},{0.649971, 1.081798, 0.018232}}],
    Polygon[{{0.653246, 1.076719, 0.020859},{0.651218, 1.073928, 0.022973},{
      0.647955, 1.075591, 0.022973},{0.649021, 1.078872, 0.020859}}],
    Polygon[{{0.651218, 1.073928, 0.022973},{0.649021, 1.070904, 0.024521},{
      0.646800, 1.072036, 0.024521},{0.647955, 1.075591, 0.022973}}],
    Polygon[{{0.649021, 1.070904, 0.024521},{0.646708, 1.067722, 0.025466},{
      0.645584, 1.068295, 0.025466},{0.646800, 1.072036, 0.024521}}],
    Polygon[{{0.645584, 1.068295, -0.025466},{0.646800, 1.072036, -0.024521},{
      0.644338, 1.072426, -0.024521},{0.644338, 1.068492, -0.025466}}],
    Polygon[{{0.646800, 1.072036, -0.024521},{0.647955, 1.075591, -0.022973},{
      0.644338, 1.076164, -0.022973},{0.644338, 1.072426, -0.024521}}],
    Polygon[{{0.647955, 1.075591, -0.022973},{0.649021, 1.078872, -0.020859},{
      0.644338, 1.079614, -0.020859},{0.644338, 1.076164, -0.022973}}],
    Polygon[{{0.649021, 1.078872, -0.020859},{0.649971, 1.081798, -0.018232},{
      0.644338, 1.082690, -0.018232},{0.644338, 1.079614, -0.020859}}],
    Polygon[{{0.649971, 1.081798, -0.018232},{0.650783, 1.084297, -0.015155},{
      0.644338, 1.085318, -0.015155},{0.644338, 1.082690, -0.018232}}],
    Polygon[{{0.650783, 1.084297, -0.015155},{0.651437, 1.086307, -0.011705},{
      0.644338, 1.087432, -0.011705},{0.644338, 1.085318, -0.015155}}],
    Polygon[{{0.651437, 1.086307, -0.011705},{0.651915, 1.087780, -0.007968},{
      0.644338, 1.088980, -0.007968},{0.644338, 1.087432, -0.011705}}],
    Polygon[{{0.651915, 1.087780, -0.007968},{0.652207, 1.088678, -0.004033},{
      0.644338, 1.089925, -0.004033},{0.644338, 1.088980, -0.007968}}],
    Polygon[{{0.652207, 1.088678, -0.004033},{0.652305, 1.088980, 0.000000},{
      0.644338, 1.090242, 0.000000},{0.644338, 1.089925, -0.004033}}],
    Polygon[{{0.652305, 1.088980, 0.000000},{0.652207, 1.088678, 0.004033},{
      0.644338, 1.089925, 0.004033},{0.644338, 1.090242, 0.000000}}],
    Polygon[{{0.652207, 1.088678, 0.004033},{0.651915, 1.087780, 0.007968},{
      0.644338, 1.088980, 0.007968},{0.644338, 1.089925, 0.004033}}],
    Polygon[{{0.651915, 1.087780, 0.007968},{0.651437, 1.086307, 0.011705},{
      0.644338, 1.087432, 0.011705},{0.644338, 1.088980, 0.007968}}],
    Polygon[{{0.651437, 1.086307, 0.011705},{0.650783, 1.084297, 0.015155},{
      0.644338, 1.085318, 0.015155},{0.644338, 1.087432, 0.011705}}],
    Polygon[{{0.650783, 1.084297, 0.015155},{0.649971, 1.081798, 0.018232},{
      0.644338, 1.082690, 0.018232},{0.644338, 1.085318, 0.015155}}],
    Polygon[{{0.649971, 1.081798, 0.018232},{0.649021, 1.078872, 0.020859},{
      0.644338, 1.079614, 0.020859},{0.644338, 1.082690, 0.018232}}],
    Polygon[{{0.649021, 1.078872, 0.020859},{0.647955, 1.075591, 0.022973},{
      0.644338, 1.076164, 0.022973},{0.644338, 1.079614, 0.020859}}],
    Polygon[{{0.647955, 1.075591, 0.022973},{0.646800, 1.072036, 0.024521},{
      0.644338, 1.072426, 0.024521},{0.644338, 1.076164, 0.022973}}],
    Polygon[{{0.646800, 1.072036, 0.024521},{0.645584, 1.068295, 0.025466},{
      0.644338, 1.068492, 0.025466},{0.644338, 1.072426, 0.024521}}],
    Polygon[{{0.644338, 1.068492, -0.025466},{0.644338, 1.072426, -0.024521},{
      0.641875, 1.072036, -0.024521},{0.643091, 1.068295, -0.025466}}],
    Polygon[{{0.644338, 1.072426, -0.024521},{0.644338, 1.076164, -0.022973},{
      0.640720, 1.075591, -0.022973},{0.641875, 1.072036, -0.024521}}],
    Polygon[{{0.644338, 1.076164, -0.022973},{0.644338, 1.079614, -0.020859},{
      0.639654, 1.078872, -0.020859},{0.640720, 1.075591, -0.022973}}],
    Polygon[{{0.644338, 1.079614, -0.020859},{0.644338, 1.082690, -0.018232},{
      0.638704, 1.081798, -0.018232},{0.639654, 1.078872, -0.020859}}],
    Polygon[{{0.644338, 1.082690, -0.018232},{0.644338, 1.085318, -0.015155},{
      0.637892, 1.084297, -0.015155},{0.638704, 1.081798, -0.018232}}],
    Polygon[{{0.644338, 1.085318, -0.015155},{0.644338, 1.087432, -0.011705},{
      0.637238, 1.086307, -0.011705},{0.637892, 1.084297, -0.015155}}],
    Polygon[{{0.644338, 1.087432, -0.011705},{0.644338, 1.088980, -0.007968},{
      0.636760, 1.087780, -0.007968},{0.637238, 1.086307, -0.011705}}],
    Polygon[{{0.644338, 1.088980, -0.007968},{0.644338, 1.089925, -0.004033},{
      0.636468, 1.088678, -0.004033},{0.636760, 1.087780, -0.007968}}],
    Polygon[{{0.644338, 1.089925, -0.004033},{0.644338, 1.090242, 0.000000},{
      0.636370, 1.088980, 0.000000},{0.636468, 1.088678, -0.004033}}],
    Polygon[{{0.644338, 1.090242, 0.000000},{0.644338, 1.089925, 0.004033},{
      0.636468, 1.088678, 0.004033},{0.636370, 1.088980, 0.000000}}],
    Polygon[{{0.644338, 1.089925, 0.004033},{0.644338, 1.088980, 0.007968},{
      0.636760, 1.087780, 0.007968},{0.636468, 1.088678, 0.004033}}],
    Polygon[{{0.644338, 1.088980, 0.007968},{0.644338, 1.087432, 0.011705},{
      0.637238, 1.086307, 0.011705},{0.636760, 1.087780, 0.007968}}],
    Polygon[{{0.644338, 1.087432, 0.011705},{0.644338, 1.085318, 0.015155},{
      0.637892, 1.084297, 0.015155},{0.637238, 1.086307, 0.011705}}],
    Polygon[{{0.644338, 1.085318, 0.015155},{0.644338, 1.082690, 0.018232},{
      0.638704, 1.081798, 0.018232},{0.637892, 1.084297, 0.015155}}],
    Polygon[{{0.644338, 1.082690, 0.018232},{0.644338, 1.079614, 0.020859},{
      0.639654, 1.078872, 0.020859},{0.638704, 1.081798, 0.018232}}],
    Polygon[{{0.644338, 1.079614, 0.020859},{0.644338, 1.076164, 0.022973},{
      0.640720, 1.075591, 0.022973},{0.639654, 1.078872, 0.020859}}],
    Polygon[{{0.644338, 1.076164, 0.022973},{0.644338, 1.072426, 0.024521},{
      0.641875, 1.072036, 0.024521},{0.640720, 1.075591, 0.022973}}],
    Polygon[{{0.644338, 1.072426, 0.024521},{0.644338, 1.068492, 0.025466},{
      0.643091, 1.068295, 0.025466},{0.641875, 1.072036, 0.024521}}],
    Polygon[{{0.643091, 1.068295, -0.025466},{0.641875, 1.072036, -0.024521},{
      0.639654, 1.070904, -0.024521},{0.641967, 1.067722, -0.025466}}],
    Polygon[{{0.641875, 1.072036, -0.024521},{0.640720, 1.075591, -0.022973},{
      0.637457, 1.073928, -0.022973},{0.639654, 1.070904, -0.024521}}],
    Polygon[{{0.640720, 1.075591, -0.022973},{0.639654, 1.078872, -0.020859},{
      0.635430, 1.076719, -0.020859},{0.637457, 1.073928, -0.022973}}],
    Polygon[{{0.639654, 1.078872, -0.020859},{0.638704, 1.081798, -0.018232},{
      0.633621, 1.079208, -0.018232},{0.635430, 1.076719, -0.020859}}],
    Polygon[{{0.638704, 1.081798, -0.018232},{0.637892, 1.084297, -0.015155},{
      0.632077, 1.081334, -0.015155},{0.633621, 1.079208, -0.018232}}],
    Polygon[{{0.637892, 1.084297, -0.015155},{0.637238, 1.086307, -0.011705},{
      0.630834, 1.083044, -0.011705},{0.632077, 1.081334, -0.015155}}],
    Polygon[{{0.637238, 1.086307, -0.011705},{0.636760, 1.087780, -0.007968},{
      0.629924, 1.084297, -0.007968},{0.630834, 1.083044, -0.011705}}],
    Polygon[{{0.636760, 1.087780, -0.007968},{0.636468, 1.088678, -0.004033},{
      0.629369, 1.085061, -0.004033},{0.629924, 1.084297, -0.007968}}],
    Polygon[{{0.636468, 1.088678, -0.004033},{0.636370, 1.088980, 0.000000},{
      0.629182, 1.085318, 0.000000},{0.629369, 1.085061, -0.004033}}],
    Polygon[{{0.636370, 1.088980, 0.000000},{0.636468, 1.088678, 0.004033},{
      0.629369, 1.085061, 0.004033},{0.629182, 1.085318, 0.000000}}],
    Polygon[{{0.636468, 1.088678, 0.004033},{0.636760, 1.087780, 0.007968},{
      0.629924, 1.084297, 0.007968},{0.629369, 1.085061, 0.004033}}],
    Polygon[{{0.636760, 1.087780, 0.007968},{0.637238, 1.086307, 0.011705},{
      0.630834, 1.083044, 0.011705},{0.629924, 1.084297, 0.007968}}],
    Polygon[{{0.637238, 1.086307, 0.011705},{0.637892, 1.084297, 0.015155},{
      0.632077, 1.081334, 0.015155},{0.630834, 1.083044, 0.011705}}],
    Polygon[{{0.637892, 1.084297, 0.015155},{0.638704, 1.081798, 0.018232},{
      0.633621, 1.079208, 0.018232},{0.632077, 1.081334, 0.015155}}],
    Polygon[{{0.638704, 1.081798, 0.018232},{0.639654, 1.078872, 0.020859},{
      0.635430, 1.076719, 0.020859},{0.633621, 1.079208, 0.018232}}],
    Polygon[{{0.639654, 1.078872, 0.020859},{0.640720, 1.075591, 0.022973},{
      0.637457, 1.073928, 0.022973},{0.635430, 1.076719, 0.020859}}],
    Polygon[{{0.640720, 1.075591, 0.022973},{0.641875, 1.072036, 0.024521},{
      0.639654, 1.070904, 0.024521},{0.637457, 1.073928, 0.022973}}],
    Polygon[{{0.641875, 1.072036, 0.024521},{0.643091, 1.068295, 0.025466},{
      0.641967, 1.067722, 0.025466},{0.639654, 1.070904, 0.024521}}],
    Polygon[{{0.641967, 1.067722, -0.025466},{0.639654, 1.070904, -0.024521},{
      0.637892, 1.069142, -0.024521},{0.641074, 1.066829, -0.025466}}],
    Polygon[{{0.639654, 1.070904, -0.024521},{0.637457, 1.073928, -0.022973},{
      0.634868, 1.071339, -0.022973},{0.637892, 1.069142, -0.024521}}],
    Polygon[{{0.637457, 1.073928, -0.022973},{0.635430, 1.076719, -0.020859},{
      0.632077, 1.073367, -0.020859},{0.634868, 1.071339, -0.022973}}],
    Polygon[{{0.635430, 1.076719, -0.020859},{0.633621, 1.079208, -0.018232},{
      0.629588, 1.075175, -0.018232},{0.632077, 1.073367, -0.020859}}],
    Polygon[{{0.633621, 1.079208, -0.018232},{0.632077, 1.081334, -0.015155},{
      0.627462, 1.076719, -0.015155},{0.629588, 1.075175, -0.018232}}],
    Polygon[{{0.632077, 1.081334, -0.015155},{0.630834, 1.083044, -0.011705},{
      0.625752, 1.077962, -0.011705},{0.627462, 1.076719, -0.015155}}],
    Polygon[{{0.630834, 1.083044, -0.011705},{0.629924, 1.084297, -0.007968},{
      0.624499, 1.078872, -0.007968},{0.625752, 1.077962, -0.011705}}],
    Polygon[{{0.629924, 1.084297, -0.007968},{0.629369, 1.085061, -0.004033},{
      0.623735, 1.079427, -0.004033},{0.624499, 1.078872, -0.007968}}],
    Polygon[{{0.629369, 1.085061, -0.004033},{0.629182, 1.085318, 0.000000},{
      0.623478, 1.079614, 0.000000},{0.623735, 1.079427, -0.004033}}],
    Polygon[{{0.629182, 1.085318, 0.000000},{0.629369, 1.085061, 0.004033},{
      0.623735, 1.079427, 0.004033},{0.623478, 1.079614, 0.000000}}],
    Polygon[{{0.629369, 1.085061, 0.004033},{0.629924, 1.084297, 0.007968},{
      0.624499, 1.078872, 0.007968},{0.623735, 1.079427, 0.004033}}],
    Polygon[{{0.629924, 1.084297, 0.007968},{0.630834, 1.083044, 0.011705},{
      0.625752, 1.077962, 0.011705},{0.624499, 1.078872, 0.007968}}],
    Polygon[{{0.630834, 1.083044, 0.011705},{0.632077, 1.081334, 0.015155},{
      0.627462, 1.076719, 0.015155},{0.625752, 1.077962, 0.011705}}],
    Polygon[{{0.632077, 1.081334, 0.015155},{0.633621, 1.079208, 0.018232},{
      0.629588, 1.075175, 0.018232},{0.627462, 1.076719, 0.015155}}],
    Polygon[{{0.633621, 1.079208, 0.018232},{0.635430, 1.076719, 0.020859},{
      0.632077, 1.073367, 0.020859},{0.629588, 1.075175, 0.018232}}],
    Polygon[{{0.635430, 1.076719, 0.020859},{0.637457, 1.073928, 0.022973},{
      0.634868, 1.071339, 0.022973},{0.632077, 1.073367, 0.020859}}],
    Polygon[{{0.637457, 1.073928, 0.022973},{0.639654, 1.070904, 0.024521},{
      0.637892, 1.069142, 0.024521},{0.634868, 1.071339, 0.022973}}],
    Polygon[{{0.639654, 1.070904, 0.024521},{0.641967, 1.067722, 0.025466},{
      0.641074, 1.066829, 0.025466},{0.637892, 1.069142, 0.024521}}],
    Polygon[{{0.641074, 1.066829, -0.025466},{0.637892, 1.069142, -0.024521},{
      0.636760, 1.066921, -0.024521},{0.640502, 1.065705, -0.025466}}],
    Polygon[{{0.637892, 1.069142, -0.024521},{0.634868, 1.071339, -0.022973},{
      0.633205, 1.068076, -0.022973},{0.636760, 1.066921, -0.024521}}],
    Polygon[{{0.634868, 1.071339, -0.022973},{0.632077, 1.073367, -0.020859},{
      0.629924, 1.069142, -0.020859},{0.633205, 1.068076, -0.022973}}],
    Polygon[{{0.632077, 1.073367, -0.020859},{0.629588, 1.075175, -0.018232},{
      0.626998, 1.070092, -0.018232},{0.629924, 1.069142, -0.020859}}],
    Polygon[{{0.629588, 1.075175, -0.018232},{0.627462, 1.076719, -0.015155},{
      0.624499, 1.070904, -0.015155},{0.626998, 1.070092, -0.018232}}],
    Polygon[{{0.627462, 1.076719, -0.015155},{0.625752, 1.077962, -0.011705},{
      0.622489, 1.071558, -0.011705},{0.624499, 1.070904, -0.015155}}],
    Polygon[{{0.625752, 1.077962, -0.011705},{0.624499, 1.078872, -0.007968},{
      0.621016, 1.072036, -0.007968},{0.622489, 1.071558, -0.011705}}],
    Polygon[{{0.624499, 1.078872, -0.007968},{0.623735, 1.079427, -0.004033},{
      0.620118, 1.072328, -0.004033},{0.621016, 1.072036, -0.007968}}],
    Polygon[{{0.623735, 1.079427, -0.004033},{0.623478, 1.079614, 0.000000},{
      0.619816, 1.072426, 0.000000},{0.620118, 1.072328, -0.004033}}],
    Polygon[{{0.623478, 1.079614, 0.000000},{0.623735, 1.079427, 0.004033},{
      0.620118, 1.072328, 0.004033},{0.619816, 1.072426, 0.000000}}],
    Polygon[{{0.623735, 1.079427, 0.004033},{0.624499, 1.078872, 0.007968},{
      0.621016, 1.072036, 0.007968},{0.620118, 1.072328, 0.004033}}],
    Polygon[{{0.624499, 1.078872, 0.007968},{0.625752, 1.077962, 0.011705},{
      0.622489, 1.071558, 0.011705},{0.621016, 1.072036, 0.007968}}],
    Polygon[{{0.625752, 1.077962, 0.011705},{0.627462, 1.076719, 0.015155},{
      0.624499, 1.070904, 0.015155},{0.622489, 1.071558, 0.011705}}],
    Polygon[{{0.627462, 1.076719, 0.015155},{0.629588, 1.075175, 0.018232},{
      0.626998, 1.070092, 0.018232},{0.624499, 1.070904, 0.015155}}],
    Polygon[{{0.629588, 1.075175, 0.018232},{0.632077, 1.073367, 0.020859},{
      0.629924, 1.069142, 0.020859},{0.626998, 1.070092, 0.018232}}],
    Polygon[{{0.632077, 1.073367, 0.020859},{0.634868, 1.071339, 0.022973},{
      0.633205, 1.068076, 0.022973},{0.629924, 1.069142, 0.020859}}],
    Polygon[{{0.634868, 1.071339, 0.022973},{0.637892, 1.069142, 0.024521},{
      0.636760, 1.066921, 0.024521},{0.633205, 1.068076, 0.022973}}],
    Polygon[{{0.637892, 1.069142, 0.024521},{0.641074, 1.066829, 0.025466},{
      0.640502, 1.065705, 0.025466},{0.636760, 1.066921, 0.024521}}],
    Polygon[{{0.640502, 1.065705, -0.025466},{0.636760, 1.066921, -0.024521},{
      0.636370, 1.064459, -0.024521},{0.640304, 1.064459, -0.025466}}],
    Polygon[{{0.636760, 1.066921, -0.024521},{0.633205, 1.068076, -0.022973},{
      0.632632, 1.064459, -0.022973},{0.636370, 1.064459, -0.024521}}],
    Polygon[{{0.633205, 1.068076, -0.022973},{0.629924, 1.069142, -0.020859},{
      0.629182, 1.064459, -0.020859},{0.632632, 1.064459, -0.022973}}],
    Polygon[{{0.629924, 1.069142, -0.020859},{0.626998, 1.070092, -0.018232},{
      0.626106, 1.064459, -0.018232},{0.629182, 1.064459, -0.020859}}],
    Polygon[{{0.626998, 1.070092, -0.018232},{0.624499, 1.070904, -0.015155},{
      0.623478, 1.064459, -0.015155},{0.626106, 1.064459, -0.018232}}],
    Polygon[{{0.624499, 1.070904, -0.015155},{0.622489, 1.071558, -0.011705},{
      0.621364, 1.064459, -0.011705},{0.623478, 1.064459, -0.015155}}],
    Polygon[{{0.622489, 1.071558, -0.011705},{0.621016, 1.072036, -0.007968},{
      0.619816, 1.064459, -0.007968},{0.621364, 1.064459, -0.011705}}],
    Polygon[{{0.621016, 1.072036, -0.007968},{0.620118, 1.072328, -0.004033},{
      0.618872, 1.064459, -0.004033},{0.619816, 1.064459, -0.007968}}],
    Polygon[{{0.620118, 1.072328, -0.004033},{0.619816, 1.072426, 0.000000},{
      0.618554, 1.064459, 0.000000},{0.618872, 1.064459, -0.004033}}],
    Polygon[{{0.619816, 1.072426, 0.000000},{0.620118, 1.072328, 0.004033},{
      0.618872, 1.064459, 0.004033},{0.618554, 1.064459, 0.000000}}],
    Polygon[{{0.620118, 1.072328, 0.004033},{0.621016, 1.072036, 0.007968},{
      0.619816, 1.064459, 0.007968},{0.618872, 1.064459, 0.004033}}],
    Polygon[{{0.621016, 1.072036, 0.007968},{0.622489, 1.071558, 0.011705},{
      0.621364, 1.064459, 0.011705},{0.619816, 1.064459, 0.007968}}],
    Polygon[{{0.622489, 1.071558, 0.011705},{0.624499, 1.070904, 0.015155},{
      0.623478, 1.064459, 0.015155},{0.621364, 1.064459, 0.011705}}],
    Polygon[{{0.624499, 1.070904, 0.015155},{0.626998, 1.070092, 0.018232},{
      0.626106, 1.064459, 0.018232},{0.623478, 1.064459, 0.015155}}],
    Polygon[{{0.626998, 1.070092, 0.018232},{0.629924, 1.069142, 0.020859},{
      0.629182, 1.064459, 0.020859},{0.626106, 1.064459, 0.018232}}],
    Polygon[{{0.629924, 1.069142, 0.020859},{0.633205, 1.068076, 0.022973},{
      0.632632, 1.064459, 0.022973},{0.629182, 1.064459, 0.020859}}],
    Polygon[{{0.633205, 1.068076, 0.022973},{0.636760, 1.066921, 0.024521},{
      0.636370, 1.064459, 0.024521},{0.632632, 1.064459, 0.022973}}],
    Polygon[{{0.636760, 1.066921, 0.024521},{0.640502, 1.065705, 0.025466},{
      0.640304, 1.064459, 0.025466},{0.636370, 1.064459, 0.024521}}],
    Polygon[{{0.640304, 1.064459, -0.025466},{0.636370, 1.064459, -0.024521},{
      0.636760, 1.061996, -0.024521},{0.640502, 1.063212, -0.025466}}],
    Polygon[{{0.636370, 1.064459, -0.024521},{0.632632, 1.064459, -0.022973},{
      0.633205, 1.060841, -0.022973},{0.636760, 1.061996, -0.024521}}],
    Polygon[{{0.632632, 1.064459, -0.022973},{0.629182, 1.064459, -0.020859},{
      0.629924, 1.059775, -0.020859},{0.633205, 1.060841, -0.022973}}],
    Polygon[{{0.629182, 1.064459, -0.020859},{0.626106, 1.064459, -0.018232},{
      0.626998, 1.058825, -0.018232},{0.629924, 1.059775, -0.020859}}],
    Polygon[{{0.626106, 1.064459, -0.018232},{0.623478, 1.064459, -0.015155},{
      0.624499, 1.058013, -0.015155},{0.626998, 1.058825, -0.018232}}],
    Polygon[{{0.623478, 1.064459, -0.015155},{0.621364, 1.064459, -0.011705},{
      0.622489, 1.057359, -0.011705},{0.624499, 1.058013, -0.015155}}],
    Polygon[{{0.621364, 1.064459, -0.011705},{0.619816, 1.064459, -0.007968},{
      0.621016, 1.056881, -0.007968},{0.622489, 1.057359, -0.011705}}],
    Polygon[{{0.619816, 1.064459, -0.007968},{0.618872, 1.064459, -0.004033},{
      0.620118, 1.056589, -0.004033},{0.621016, 1.056881, -0.007968}}],
    Polygon[{{0.618872, 1.064459, -0.004033},{0.618554, 1.064459, 0.000000},{
      0.619816, 1.056491, 0.000000},{0.620118, 1.056589, -0.004033}}],
    Polygon[{{0.618554, 1.064459, 0.000000},{0.618872, 1.064459, 0.004033},{
      0.620118, 1.056589, 0.004033},{0.619816, 1.056491, 0.000000}}],
    Polygon[{{0.618872, 1.064459, 0.004033},{0.619816, 1.064459, 0.007968},{
      0.621016, 1.056881, 0.007968},{0.620118, 1.056589, 0.004033}}],
    Polygon[{{0.619816, 1.064459, 0.007968},{0.621364, 1.064459, 0.011705},{
      0.622489, 1.057359, 0.011705},{0.621016, 1.056881, 0.007968}}],
    Polygon[{{0.621364, 1.064459, 0.011705},{0.623478, 1.064459, 0.015155},{
      0.624499, 1.058013, 0.015155},{0.622489, 1.057359, 0.011705}}],
    Polygon[{{0.623478, 1.064459, 0.015155},{0.626106, 1.064459, 0.018232},{
      0.626998, 1.058825, 0.018232},{0.624499, 1.058013, 0.015155}}],
    Polygon[{{0.626106, 1.064459, 0.018232},{0.629182, 1.064459, 0.020859},{
      0.629924, 1.059775, 0.020859},{0.626998, 1.058825, 0.018232}}],
    Polygon[{{0.629182, 1.064459, 0.020859},{0.632632, 1.064459, 0.022973},{
      0.633205, 1.060841, 0.022973},{0.629924, 1.059775, 0.020859}}],
    Polygon[{{0.632632, 1.064459, 0.022973},{0.636370, 1.064459, 0.024521},{
      0.636760, 1.061996, 0.024521},{0.633205, 1.060841, 0.022973}}],
    Polygon[{{0.636370, 1.064459, 0.024521},{0.640304, 1.064459, 0.025466},{
      0.640502, 1.063212, 0.025466},{0.636760, 1.061996, 0.024521}}],
    Polygon[{{0.640502, 1.063212, -0.025466},{0.636760, 1.061996, -0.024521},{
      0.637892, 1.059775, -0.024521},{0.641074, 1.062088, -0.025466}}],
    Polygon[{{0.636760, 1.061996, -0.024521},{0.633205, 1.060841, -0.022973},{
      0.634868, 1.057578, -0.022973},{0.637892, 1.059775, -0.024521}}],
    Polygon[{{0.633205, 1.060841, -0.022973},{0.629924, 1.059775, -0.020859},{
      0.632077, 1.055551, -0.020859},{0.634868, 1.057578, -0.022973}}],
    Polygon[{{0.629924, 1.059775, -0.020859},{0.626998, 1.058825, -0.018232},{
      0.629588, 1.053742, -0.018232},{0.632077, 1.055551, -0.020859}}],
    Polygon[{{0.626998, 1.058825, -0.018232},{0.624499, 1.058013, -0.015155},{
      0.627462, 1.052198, -0.015155},{0.629588, 1.053742, -0.018232}}],
    Polygon[{{0.624499, 1.058013, -0.015155},{0.622489, 1.057359, -0.011705},{
      0.625752, 1.050955, -0.011705},{0.627462, 1.052198, -0.015155}}],
    Polygon[{{0.622489, 1.057359, -0.011705},{0.621016, 1.056881, -0.007968},{
      0.624499, 1.050045, -0.007968},{0.625752, 1.050955, -0.011705}}],
    Polygon[{{0.621016, 1.056881, -0.007968},{0.620118, 1.056589, -0.004033},{
      0.623735, 1.049490, -0.004033},{0.624499, 1.050045, -0.007968}}],
    Polygon[{{0.620118, 1.056589, -0.004033},{0.619816, 1.056491, 0.000000},{
      0.623478, 1.049303, 0.000000},{0.623735, 1.049490, -0.004033}}],
    Polygon[{{0.619816, 1.056491, 0.000000},{0.620118, 1.056589, 0.004033},{
      0.623735, 1.049490, 0.004033},{0.623478, 1.049303, 0.000000}}],
    Polygon[{{0.620118, 1.056589, 0.004033},{0.621016, 1.056881, 0.007968},{
      0.624499, 1.050045, 0.007968},{0.623735, 1.049490, 0.004033}}],
    Polygon[{{0.621016, 1.056881, 0.007968},{0.622489, 1.057359, 0.011705},{
      0.625752, 1.050955, 0.011705},{0.624499, 1.050045, 0.007968}}],
    Polygon[{{0.622489, 1.057359, 0.011705},{0.624499, 1.058013, 0.015155},{
      0.627462, 1.052198, 0.015155},{0.625752, 1.050955, 0.011705}}],
    Polygon[{{0.624499, 1.058013, 0.015155},{0.626998, 1.058825, 0.018232},{
      0.629588, 1.053742, 0.018232},{0.627462, 1.052198, 0.015155}}],
    Polygon[{{0.626998, 1.058825, 0.018232},{0.629924, 1.059775, 0.020859},{
      0.632077, 1.055551, 0.020859},{0.629588, 1.053742, 0.018232}}],
    Polygon[{{0.629924, 1.059775, 0.020859},{0.633205, 1.060841, 0.022973},{
      0.634868, 1.057578, 0.022973},{0.632077, 1.055551, 0.020859}}],
    Polygon[{{0.633205, 1.060841, 0.022973},{0.636760, 1.061996, 0.024521},{
      0.637892, 1.059775, 0.024521},{0.634868, 1.057578, 0.022973}}],
    Polygon[{{0.636760, 1.061996, 0.024521},{0.640502, 1.063212, 0.025466},{
      0.641074, 1.062088, 0.025466},{0.637892, 1.059775, 0.024521}}],
    Polygon[{{0.641074, 1.062088, -0.025466},{0.637892, 1.059775, -0.024521},{
      0.639654, 1.058013, -0.024521},{0.641967, 1.061195, -0.025466}}],
    Polygon[{{0.637892, 1.059775, -0.024521},{0.634868, 1.057578, -0.022973},{
      0.637457, 1.054989, -0.022973},{0.639654, 1.058013, -0.024521}}],
    Polygon[{{0.634868, 1.057578, -0.022973},{0.632077, 1.055551, -0.020859},{
      0.635430, 1.052198, -0.020859},{0.637457, 1.054989, -0.022973}}],
    Polygon[{{0.632077, 1.055551, -0.020859},{0.629588, 1.053742, -0.018232},{
      0.633621, 1.049709, -0.018232},{0.635430, 1.052198, -0.020859}}],
    Polygon[{{0.629588, 1.053742, -0.018232},{0.627462, 1.052198, -0.015155},{
      0.632077, 1.047583, -0.015155},{0.633621, 1.049709, -0.018232}}],
    Polygon[{{0.627462, 1.052198, -0.015155},{0.625752, 1.050955, -0.011705},{
      0.630834, 1.045873, -0.011705},{0.632077, 1.047583, -0.015155}}],
    Polygon[{{0.625752, 1.050955, -0.011705},{0.624499, 1.050045, -0.007968},{
      0.629924, 1.044620, -0.007968},{0.630834, 1.045873, -0.011705}}],
    Polygon[{{0.624499, 1.050045, -0.007968},{0.623735, 1.049490, -0.004033},{
      0.629369, 1.043856, -0.004033},{0.629924, 1.044620, -0.007968}}],
    Polygon[{{0.623735, 1.049490, -0.004033},{0.623478, 1.049303, 0.000000},{
      0.629182, 1.043599, 0.000000},{0.629369, 1.043856, -0.004033}}],
    Polygon[{{0.623478, 1.049303, 0.000000},{0.623735, 1.049490, 0.004033},{
      0.629369, 1.043856, 0.004033},{0.629182, 1.043599, 0.000000}}],
    Polygon[{{0.623735, 1.049490, 0.004033},{0.624499, 1.050045, 0.007968},{
      0.629924, 1.044620, 0.007968},{0.629369, 1.043856, 0.004033}}],
    Polygon[{{0.624499, 1.050045, 0.007968},{0.625752, 1.050955, 0.011705},{
      0.630834, 1.045873, 0.011705},{0.629924, 1.044620, 0.007968}}],
    Polygon[{{0.625752, 1.050955, 0.011705},{0.627462, 1.052198, 0.015155},{
      0.632077, 1.047583, 0.015155},{0.630834, 1.045873, 0.011705}}],
    Polygon[{{0.627462, 1.052198, 0.015155},{0.629588, 1.053742, 0.018232},{
      0.633621, 1.049709, 0.018232},{0.632077, 1.047583, 0.015155}}],
    Polygon[{{0.629588, 1.053742, 0.018232},{0.632077, 1.055551, 0.020859},{
      0.635430, 1.052198, 0.020859},{0.633621, 1.049709, 0.018232}}],
    Polygon[{{0.632077, 1.055551, 0.020859},{0.634868, 1.057578, 0.022973},{
      0.637457, 1.054989, 0.022973},{0.635430, 1.052198, 0.020859}}],
    Polygon[{{0.634868, 1.057578, 0.022973},{0.637892, 1.059775, 0.024521},{
      0.639654, 1.058013, 0.024521},{0.637457, 1.054989, 0.022973}}],
    Polygon[{{0.637892, 1.059775, 0.024521},{0.641074, 1.062088, 0.025466},{
      0.641967, 1.061195, 0.025466},{0.639654, 1.058013, 0.024521}}],
    Polygon[{{0.641967, 1.061195, -0.025466},{0.639654, 1.058013, -0.024521},{
      0.641875, 1.056881, -0.024521},{0.643091, 1.060623, -0.025466}}],
    Polygon[{{0.639654, 1.058013, -0.024521},{0.637457, 1.054989, -0.022973},{
      0.640720, 1.053326, -0.022973},{0.641875, 1.056881, -0.024521}}],
    Polygon[{{0.637457, 1.054989, -0.022973},{0.635430, 1.052198, -0.020859},{
      0.639654, 1.050045, -0.020859},{0.640720, 1.053326, -0.022973}}],
    Polygon[{{0.635430, 1.052198, -0.020859},{0.633621, 1.049709, -0.018232},{
      0.638704, 1.047119, -0.018232},{0.639654, 1.050045, -0.020859}}],
    Polygon[{{0.633621, 1.049709, -0.018232},{0.632077, 1.047583, -0.015155},{
      0.637892, 1.044620, -0.015155},{0.638704, 1.047119, -0.018232}}],
    Polygon[{{0.632077, 1.047583, -0.015155},{0.630834, 1.045873, -0.011705},{
      0.637238, 1.042610, -0.011705},{0.637892, 1.044620, -0.015155}}],
    Polygon[{{0.630834, 1.045873, -0.011705},{0.629924, 1.044620, -0.007968},{
      0.636760, 1.041137, -0.007968},{0.637238, 1.042610, -0.011705}}],
    Polygon[{{0.629924, 1.044620, -0.007968},{0.629369, 1.043856, -0.004033},{
      0.636468, 1.040239, -0.004033},{0.636760, 1.041137, -0.007968}}],
    Polygon[{{0.629369, 1.043856, -0.004033},{0.629182, 1.043599, 0.000000},{
      0.636370, 1.039937, 0.000000},{0.636468, 1.040239, -0.004033}}],
    Polygon[{{0.629182, 1.043599, 0.000000},{0.629369, 1.043856, 0.004033},{
      0.636468, 1.040239, 0.004033},{0.636370, 1.039937, 0.000000}}],
    Polygon[{{0.629369, 1.043856, 0.004033},{0.629924, 1.044620, 0.007968},{
      0.636760, 1.041137, 0.007968},{0.636468, 1.040239, 0.004033}}],
    Polygon[{{0.629924, 1.044620, 0.007968},{0.630834, 1.045873, 0.011705},{
      0.637238, 1.042610, 0.011705},{0.636760, 1.041137, 0.007968}}],
    Polygon[{{0.630834, 1.045873, 0.011705},{0.632077, 1.047583, 0.015155},{
      0.637892, 1.044620, 0.015155},{0.637238, 1.042610, 0.011705}}],
    Polygon[{{0.632077, 1.047583, 0.015155},{0.633621, 1.049709, 0.018232},{
      0.638704, 1.047119, 0.018232},{0.637892, 1.044620, 0.015155}}],
    Polygon[{{0.633621, 1.049709, 0.018232},{0.635430, 1.052198, 0.020859},{
      0.639654, 1.050045, 0.020859},{0.638704, 1.047119, 0.018232}}],
    Polygon[{{0.635430, 1.052198, 0.020859},{0.637457, 1.054989, 0.022973},{
      0.640720, 1.053326, 0.022973},{0.639654, 1.050045, 0.020859}}],
    Polygon[{{0.637457, 1.054989, 0.022973},{0.639654, 1.058013, 0.024521},{
      0.641875, 1.056881, 0.024521},{0.640720, 1.053326, 0.022973}}],
    Polygon[{{0.639654, 1.058013, 0.024521},{0.641967, 1.061195, 0.025466},{
      0.643091, 1.060623, 0.025466},{0.641875, 1.056881, 0.024521}}],
    Polygon[{{0.643091, 1.060623, -0.025466},{0.641875, 1.056881, -0.024521},{
      0.644338, 1.056491, -0.024521},{0.644338, 1.060425, -0.025466}}],
    Polygon[{{0.641875, 1.056881, -0.024521},{0.640720, 1.053326, -0.022973},{
      0.644338, 1.052753, -0.022973},{0.644338, 1.056491, -0.024521}}],
    Polygon[{{0.640720, 1.053326, -0.022973},{0.639654, 1.050045, -0.020859},{
      0.644338, 1.049303, -0.020859},{0.644338, 1.052753, -0.022973}}],
    Polygon[{{0.639654, 1.050045, -0.020859},{0.638704, 1.047119, -0.018232},{
      0.644338, 1.046227, -0.018232},{0.644338, 1.049303, -0.020859}}],
    Polygon[{{0.638704, 1.047119, -0.018232},{0.637892, 1.044620, -0.015155},{
      0.644338, 1.043599, -0.015155},{0.644338, 1.046227, -0.018232}}],
    Polygon[{{0.637892, 1.044620, -0.015155},{0.637238, 1.042610, -0.011705},{
      0.644338, 1.041485, -0.011705},{0.644338, 1.043599, -0.015155}}],
    Polygon[{{0.637238, 1.042610, -0.011705},{0.636760, 1.041137, -0.007968},{
      0.644338, 1.039937, -0.007968},{0.644338, 1.041485, -0.011705}}],
    Polygon[{{0.636760, 1.041137, -0.007968},{0.636468, 1.040239, -0.004033},{
      0.644338, 1.038993, -0.004033},{0.644338, 1.039937, -0.007968}}],
    Polygon[{{0.636468, 1.040239, -0.004033},{0.636370, 1.039937, 0.000000},{
      0.644338, 1.038675, 0.000000},{0.644338, 1.038993, -0.004033}}],
    Polygon[{{0.636370, 1.039937, 0.000000},{0.636468, 1.040239, 0.004033},{
      0.644338, 1.038993, 0.004033},{0.644338, 1.038675, 0.000000}}],
    Polygon[{{0.636468, 1.040239, 0.004033},{0.636760, 1.041137, 0.007968},{
      0.644338, 1.039937, 0.007968},{0.644338, 1.038993, 0.004033}}],
    Polygon[{{0.636760, 1.041137, 0.007968},{0.637238, 1.042610, 0.011705},{
      0.644338, 1.041485, 0.011705},{0.644338, 1.039937, 0.007968}}],
    Polygon[{{0.637238, 1.042610, 0.011705},{0.637892, 1.044620, 0.015155},{
      0.644338, 1.043599, 0.015155},{0.644338, 1.041485, 0.011705}}],
    Polygon[{{0.637892, 1.044620, 0.015155},{0.638704, 1.047119, 0.018232},{
      0.644338, 1.046227, 0.018232},{0.644338, 1.043599, 0.015155}}],
    Polygon[{{0.638704, 1.047119, 0.018232},{0.639654, 1.050045, 0.020859},{
      0.644338, 1.049303, 0.020859},{0.644338, 1.046227, 0.018232}}],
    Polygon[{{0.639654, 1.050045, 0.020859},{0.640720, 1.053326, 0.022973},{
      0.644338, 1.052753, 0.022973},{0.644338, 1.049303, 0.020859}}],
    Polygon[{{0.640720, 1.053326, 0.022973},{0.641875, 1.056881, 0.024521},{
      0.644338, 1.056491, 0.024521},{0.644338, 1.052753, 0.022973}}],
    Polygon[{{0.641875, 1.056881, 0.024521},{0.643091, 1.060623, 0.025466},{
      0.644338, 1.060425, 0.025466},{0.644338, 1.056491, 0.024521}}],
    Polygon[{{0.644338, 1.060425, -0.025466},{0.644338, 1.056491, -0.024521},{
      0.646800, 1.056881, -0.024521},{0.645584, 1.060623, -0.025466}}],
    Polygon[{{0.644338, 1.056491, -0.024521},{0.644338, 1.052753, -0.022973},{
      0.647955, 1.053326, -0.022973},{0.646800, 1.056881, -0.024521}}],
    Polygon[{{0.644338, 1.052753, -0.022973},{0.644338, 1.049303, -0.020859},{
      0.649021, 1.050045, -0.020859},{0.647955, 1.053326, -0.022973}}],
    Polygon[{{0.644338, 1.049303, -0.020859},{0.644338, 1.046227, -0.018232},{
      0.649971, 1.047119, -0.018232},{0.649021, 1.050045, -0.020859}}],
    Polygon[{{0.644338, 1.046227, -0.018232},{0.644338, 1.043599, -0.015155},{
      0.650783, 1.044620, -0.015155},{0.649971, 1.047119, -0.018232}}],
    Polygon[{{0.644338, 1.043599, -0.015155},{0.644338, 1.041485, -0.011705},{
      0.651437, 1.042610, -0.011705},{0.650783, 1.044620, -0.015155}}],
    Polygon[{{0.644338, 1.041485, -0.011705},{0.644338, 1.039937, -0.007968},{
      0.651915, 1.041137, -0.007968},{0.651437, 1.042610, -0.011705}}],
    Polygon[{{0.644338, 1.039937, -0.007968},{0.644338, 1.038993, -0.004033},{
      0.652207, 1.040239, -0.004033},{0.651915, 1.041137, -0.007968}}],
    Polygon[{{0.644338, 1.038993, -0.004033},{0.644338, 1.038675, 0.000000},{
      0.652305, 1.039937, 0.000000},{0.652207, 1.040239, -0.004033}}],
    Polygon[{{0.644338, 1.038675, 0.000000},{0.644338, 1.038993, 0.004033},{
      0.652207, 1.040239, 0.004033},{0.652305, 1.039937, 0.000000}}],
    Polygon[{{0.644338, 1.038993, 0.004033},{0.644338, 1.039937, 0.007968},{
      0.651915, 1.041137, 0.007968},{0.652207, 1.040239, 0.004033}}],
    Polygon[{{0.644338, 1.039937, 0.007968},{0.644338, 1.041485, 0.011705},{
      0.651437, 1.042610, 0.011705},{0.651915, 1.041137, 0.007968}}],
    Polygon[{{0.644338, 1.041485, 0.011705},{0.644338, 1.043599, 0.015155},{
      0.650783, 1.044620, 0.015155},{0.651437, 1.042610, 0.011705}}],
    Polygon[{{0.644338, 1.043599, 0.015155},{0.644338, 1.046227, 0.018232},{
      0.649971, 1.047119, 0.018232},{0.650783, 1.044620, 0.015155}}],
    Polygon[{{0.644338, 1.046227, 0.018232},{0.644338, 1.049303, 0.020859},{
      0.649021, 1.050045, 0.020859},{0.649971, 1.047119, 0.018232}}],
    Polygon[{{0.644338, 1.049303, 0.020859},{0.644338, 1.052753, 0.022973},{
      0.647955, 1.053326, 0.022973},{0.649021, 1.050045, 0.020859}}],
    Polygon[{{0.644338, 1.052753, 0.022973},{0.644338, 1.056491, 0.024521},{
      0.646800, 1.056881, 0.024521},{0.647955, 1.053326, 0.022973}}],
    Polygon[{{0.644338, 1.056491, 0.024521},{0.644338, 1.060425, 0.025466},{
      0.645584, 1.060623, 0.025466},{0.646800, 1.056881, 0.024521}}],
    Polygon[{{0.645584, 1.060623, -0.025466},{0.646800, 1.056881, -0.024521},{
      0.649021, 1.058013, -0.024521},{0.646708, 1.061195, -0.025466}}],
    Polygon[{{0.646800, 1.056881, -0.024521},{0.647955, 1.053326, -0.022973},{
      0.651218, 1.054989, -0.022973},{0.649021, 1.058013, -0.024521}}],
    Polygon[{{0.647955, 1.053326, -0.022973},{0.649021, 1.050045, -0.020859},{
      0.653246, 1.052198, -0.020859},{0.651218, 1.054989, -0.022973}}],
    Polygon[{{0.649021, 1.050045, -0.020859},{0.649971, 1.047119, -0.018232},{
      0.655054, 1.049709, -0.018232},{0.653246, 1.052198, -0.020859}}],
    Polygon[{{0.649971, 1.047119, -0.018232},{0.650783, 1.044620, -0.015155},{
      0.656598, 1.047583, -0.015155},{0.655054, 1.049709, -0.018232}}],
    Polygon[{{0.650783, 1.044620, -0.015155},{0.651437, 1.042610, -0.011705},{
      0.657841, 1.045873, -0.011705},{0.656598, 1.047583, -0.015155}}],
    Polygon[{{0.651437, 1.042610, -0.011705},{0.651915, 1.041137, -0.007968},{
      0.658751, 1.044620, -0.007968},{0.657841, 1.045873, -0.011705}}],
    Polygon[{{0.651915, 1.041137, -0.007968},{0.652207, 1.040239, -0.004033},{
      0.659306, 1.043856, -0.004033},{0.658751, 1.044620, -0.007968}}],
    Polygon[{{0.652207, 1.040239, -0.004033},{0.652305, 1.039937, 0.000000},{
      0.659493, 1.043599, 0.000000},{0.659306, 1.043856, -0.004033}}],
    Polygon[{{0.652305, 1.039937, 0.000000},{0.652207, 1.040239, 0.004033},{
      0.659306, 1.043856, 0.004033},{0.659493, 1.043599, 0.000000}}],
    Polygon[{{0.652207, 1.040239, 0.004033},{0.651915, 1.041137, 0.007968},{
      0.658751, 1.044620, 0.007968},{0.659306, 1.043856, 0.004033}}],
    Polygon[{{0.651915, 1.041137, 0.007968},{0.651437, 1.042610, 0.011705},{
      0.657841, 1.045873, 0.011705},{0.658751, 1.044620, 0.007968}}],
    Polygon[{{0.651437, 1.042610, 0.011705},{0.650783, 1.044620, 0.015155},{
      0.656598, 1.047583, 0.015155},{0.657841, 1.045873, 0.011705}}],
    Polygon[{{0.650783, 1.044620, 0.015155},{0.649971, 1.047119, 0.018232},{
      0.655054, 1.049709, 0.018232},{0.656598, 1.047583, 0.015155}}],
    Polygon[{{0.649971, 1.047119, 0.018232},{0.649021, 1.050045, 0.020859},{
      0.653246, 1.052198, 0.020859},{0.655054, 1.049709, 0.018232}}],
    Polygon[{{0.649021, 1.050045, 0.020859},{0.647955, 1.053326, 0.022973},{
      0.651218, 1.054989, 0.022973},{0.653246, 1.052198, 0.020859}}],
    Polygon[{{0.647955, 1.053326, 0.022973},{0.646800, 1.056881, 0.024521},{
      0.649021, 1.058013, 0.024521},{0.651218, 1.054989, 0.022973}}],
    Polygon[{{0.646800, 1.056881, 0.024521},{0.645584, 1.060623, 0.025466},{
      0.646708, 1.061195, 0.025466},{0.649021, 1.058013, 0.024521}}],
    Polygon[{{0.646708, 1.061195, -0.025466},{0.649021, 1.058013, -0.024521},{
      0.650783, 1.059775, -0.024521},{0.647601, 1.062088, -0.025466}}],
    Polygon[{{0.649021, 1.058013, -0.024521},{0.651218, 1.054989, -0.022973},{
      0.653807, 1.057578, -0.022973},{0.650783, 1.059775, -0.024521}}],
    Polygon[{{0.651218, 1.054989, -0.022973},{0.653246, 1.052198, -0.020859},{
      0.656598, 1.055551, -0.020859},{0.653807, 1.057578, -0.022973}}],
    Polygon[{{0.653246, 1.052198, -0.020859},{0.655054, 1.049709, -0.018232},{
      0.659087, 1.053742, -0.018232},{0.656598, 1.055551, -0.020859}}],
    Polygon[{{0.655054, 1.049709, -0.018232},{0.656598, 1.047583, -0.015155},{
      0.661213, 1.052198, -0.015155},{0.659087, 1.053742, -0.018232}}],
    Polygon[{{0.656598, 1.047583, -0.015155},{0.657841, 1.045873, -0.011705},{
      0.662923, 1.050955, -0.011705},{0.661213, 1.052198, -0.015155}}],
    Polygon[{{0.657841, 1.045873, -0.011705},{0.658751, 1.044620, -0.007968},{
      0.664176, 1.050045, -0.007968},{0.662923, 1.050955, -0.011705}}],
    Polygon[{{0.658751, 1.044620, -0.007968},{0.659306, 1.043856, -0.004033},{
      0.664940, 1.049490, -0.004033},{0.664176, 1.050045, -0.007968}}],
    Polygon[{{0.659306, 1.043856, -0.004033},{0.659493, 1.043599, 0.000000},{
      0.665197, 1.049303, 0.000000},{0.664940, 1.049490, -0.004033}}],
    Polygon[{{0.659493, 1.043599, 0.000000},{0.659306, 1.043856, 0.004033},{
      0.664940, 1.049490, 0.004033},{0.665197, 1.049303, 0.000000}}],
    Polygon[{{0.659306, 1.043856, 0.004033},{0.658751, 1.044620, 0.007968},{
      0.664176, 1.050045, 0.007968},{0.664940, 1.049490, 0.004033}}],
    Polygon[{{0.658751, 1.044620, 0.007968},{0.657841, 1.045873, 0.011705},{
      0.662923, 1.050955, 0.011705},{0.664176, 1.050045, 0.007968}}],
    Polygon[{{0.657841, 1.045873, 0.011705},{0.656598, 1.047583, 0.015155},{
      0.661213, 1.052198, 0.015155},{0.662923, 1.050955, 0.011705}}],
    Polygon[{{0.656598, 1.047583, 0.015155},{0.655054, 1.049709, 0.018232},{
      0.659087, 1.053742, 0.018232},{0.661213, 1.052198, 0.015155}}],
    Polygon[{{0.655054, 1.049709, 0.018232},{0.653246, 1.052198, 0.020859},{
      0.656598, 1.055551, 0.020859},{0.659087, 1.053742, 0.018232}}],
    Polygon[{{0.653246, 1.052198, 0.020859},{0.651218, 1.054989, 0.022973},{
      0.653807, 1.057578, 0.022973},{0.656598, 1.055551, 0.020859}}],
    Polygon[{{0.651218, 1.054989, 0.022973},{0.649021, 1.058013, 0.024521},{
      0.650783, 1.059775, 0.024521},{0.653807, 1.057578, 0.022973}}],
    Polygon[{{0.649021, 1.058013, 0.024521},{0.646708, 1.061195, 0.025466},{
      0.647601, 1.062088, 0.025466},{0.650783, 1.059775, 0.024521}}],
    Polygon[{{0.647601, 1.062088, -0.025466},{0.650783, 1.059775, -0.024521},{
      0.651915, 1.061996, -0.024521},{0.648174, 1.063212, -0.025466}}],
    Polygon[{{0.650783, 1.059775, -0.024521},{0.653807, 1.057578, -0.022973},{
      0.655470, 1.060841, -0.022973},{0.651915, 1.061996, -0.024521}}],
    Polygon[{{0.653807, 1.057578, -0.022973},{0.656598, 1.055551, -0.020859},{
      0.658751, 1.059775, -0.020859},{0.655470, 1.060841, -0.022973}}],
    Polygon[{{0.656598, 1.055551, -0.020859},{0.659087, 1.053742, -0.018232},{
      0.661677, 1.058825, -0.018232},{0.658751, 1.059775, -0.020859}}],
    Polygon[{{0.659087, 1.053742, -0.018232},{0.661213, 1.052198, -0.015155},{
      0.664176, 1.058013, -0.015155},{0.661677, 1.058825, -0.018232}}],
    Polygon[{{0.661213, 1.052198, -0.015155},{0.662923, 1.050955, -0.011705},{
      0.666186, 1.057359, -0.011705},{0.664176, 1.058013, -0.015155}}],
    Polygon[{{0.662923, 1.050955, -0.011705},{0.664176, 1.050045, -0.007968},{
      0.667659, 1.056881, -0.007968},{0.666186, 1.057359, -0.011705}}],
    Polygon[{{0.664176, 1.050045, -0.007968},{0.664940, 1.049490, -0.004033},{
      0.668557, 1.056589, -0.004033},{0.667659, 1.056881, -0.007968}}],
    Polygon[{{0.664940, 1.049490, -0.004033},{0.665197, 1.049303, 0.000000},{
      0.668859, 1.056491, 0.000000},{0.668557, 1.056589, -0.004033}}],
    Polygon[{{0.665197, 1.049303, 0.000000},{0.664940, 1.049490, 0.004033},{
      0.668557, 1.056589, 0.004033},{0.668859, 1.056491, 0.000000}}],
    Polygon[{{0.664940, 1.049490, 0.004033},{0.664176, 1.050045, 0.007968},{
      0.667659, 1.056881, 0.007968},{0.668557, 1.056589, 0.004033}}],
    Polygon[{{0.664176, 1.050045, 0.007968},{0.662923, 1.050955, 0.011705},{
      0.666186, 1.057359, 0.011705},{0.667659, 1.056881, 0.007968}}],
    Polygon[{{0.662923, 1.050955, 0.011705},{0.661213, 1.052198, 0.015155},{
      0.664176, 1.058013, 0.015155},{0.666186, 1.057359, 0.011705}}],
    Polygon[{{0.661213, 1.052198, 0.015155},{0.659087, 1.053742, 0.018232},{
      0.661677, 1.058825, 0.018232},{0.664176, 1.058013, 0.015155}}],
    Polygon[{{0.659087, 1.053742, 0.018232},{0.656598, 1.055551, 0.020859},{
      0.658751, 1.059775, 0.020859},{0.661677, 1.058825, 0.018232}}],
    Polygon[{{0.656598, 1.055551, 0.020859},{0.653807, 1.057578, 0.022973},{
      0.655470, 1.060841, 0.022973},{0.658751, 1.059775, 0.020859}}],
    Polygon[{{0.653807, 1.057578, 0.022973},{0.650783, 1.059775, 0.024521},{
      0.651915, 1.061996, 0.024521},{0.655470, 1.060841, 0.022973}}],
    Polygon[{{0.650783, 1.059775, 0.024521},{0.647601, 1.062088, 0.025466},{
      0.648174, 1.063212, 0.025466},{0.651915, 1.061996, 0.024521}}],
    Polygon[{{0.648174, 1.063212, -0.025466},{0.651915, 1.061996, -0.024521},{
      0.652305, 1.064459, -0.024521},{0.648371, 1.064459, -0.025466}}],
    Polygon[{{0.651915, 1.061996, -0.024521},{0.655470, 1.060841, -0.022973},{
      0.656043, 1.064459, -0.022973},{0.652305, 1.064459, -0.024521}}],
    Polygon[{{0.655470, 1.060841, -0.022973},{0.658751, 1.059775, -0.020859},{
      0.659493, 1.064459, -0.020859},{0.656043, 1.064459, -0.022973}}],
    Polygon[{{0.658751, 1.059775, -0.020859},{0.661677, 1.058825, -0.018232},{
      0.662569, 1.064459, -0.018232},{0.659493, 1.064459, -0.020859}}],
    Polygon[{{0.661677, 1.058825, -0.018232},{0.664176, 1.058013, -0.015155},{
      0.665197, 1.064459, -0.015155},{0.662569, 1.064459, -0.018232}}],
    Polygon[{{0.664176, 1.058013, -0.015155},{0.666186, 1.057359, -0.011705},{
      0.667311, 1.064459, -0.011705},{0.665197, 1.064459, -0.015155}}],
    Polygon[{{0.666186, 1.057359, -0.011705},{0.667659, 1.056881, -0.007968},{
      0.668859, 1.064459, -0.007968},{0.667311, 1.064459, -0.011705}}],
    Polygon[{{0.667659, 1.056881, -0.007968},{0.668557, 1.056589, -0.004033},{
      0.669804, 1.064459, -0.004033},{0.668859, 1.064459, -0.007968}}],
    Polygon[{{0.668557, 1.056589, -0.004033},{0.668859, 1.056491, 0.000000},{
      0.670121, 1.064459, 0.000000},{0.669804, 1.064459, -0.004033}}],
    Polygon[{{0.668859, 1.056491, 0.000000},{0.668557, 1.056589, 0.004033},{
      0.669804, 1.064459, 0.004033},{0.670121, 1.064459, 0.000000}}],
    Polygon[{{0.668557, 1.056589, 0.004033},{0.667659, 1.056881, 0.007968},{
      0.668859, 1.064459, 0.007968},{0.669804, 1.064459, 0.004033}}],
    Polygon[{{0.667659, 1.056881, 0.007968},{0.666186, 1.057359, 0.011705},{
      0.667311, 1.064459, 0.011705},{0.668859, 1.064459, 0.007968}}],
    Polygon[{{0.666186, 1.057359, 0.011705},{0.664176, 1.058013, 0.015155},{
      0.665197, 1.064459, 0.015155},{0.667311, 1.064459, 0.011705}}],
    Polygon[{{0.664176, 1.058013, 0.015155},{0.661677, 1.058825, 0.018232},{
      0.662569, 1.064459, 0.018232},{0.665197, 1.064459, 0.015155}}],
    Polygon[{{0.661677, 1.058825, 0.018232},{0.658751, 1.059775, 0.020859},{
      0.659493, 1.064459, 0.020859},{0.662569, 1.064459, 0.018232}}],
    Polygon[{{0.658751, 1.059775, 0.020859},{0.655470, 1.060841, 0.022973},{
      0.656043, 1.064459, 0.022973},{0.659493, 1.064459, 0.020859}}],
    Polygon[{{0.655470, 1.060841, 0.022973},{0.651915, 1.061996, 0.024521},{
      0.652305, 1.064459, 0.024521},{0.656043, 1.064459, 0.022973}}],
    Polygon[{{0.651915, 1.061996, 0.024521},{0.648174, 1.063212, 0.025466},{
      0.648371, 1.064459, 0.025466},{0.652305, 1.064459, 0.024521}}],
    Polygon[{{0.692760, 1.168518, -0.013647},{0.694869, 1.168518, -0.013141},{
      0.694660, 1.169837, -0.013141},{0.692655, 1.169186, -0.013647}}],
    Polygon[{{0.694869, 1.168518, -0.013141},{0.696872, 1.168518, -0.012311},{
      0.696565, 1.170456, -0.012311},{0.694660, 1.169837, -0.013141}}],
    Polygon[{{0.696872, 1.168518, -0.012311},{0.698721, 1.168518, -0.011178},{
      0.698323, 1.171028, -0.011178},{0.696565, 1.170456, -0.012311}}],
    Polygon[{{0.698721, 1.168518, -0.011178},{0.700369, 1.168518, -0.009770},{
      0.699891, 1.171537, -0.009770},{0.698323, 1.171028, -0.011178}}],
    Polygon[{{0.700369, 1.168518, -0.009770},{0.701777, 1.168518, -0.008122},{
      0.701230, 1.171972, -0.008122},{0.699891, 1.171537, -0.009770}}],
    Polygon[{{0.701777, 1.168518, -0.008122},{0.702910, 1.168518, -0.006273},{
      0.702308, 1.172322, -0.006273},{0.701230, 1.171972, -0.008122}}],
    Polygon[{{0.702910, 1.168518, -0.006273},{0.703740, 1.168518, -0.004270},{
      0.703097, 1.172579, -0.004270},{0.702308, 1.172322, -0.006273}}],
    Polygon[{{0.703740, 1.168518, -0.004270},{0.704246, 1.168518, -0.002162},{
      0.703578, 1.172735, -0.002162},{0.703097, 1.172579, -0.004270}}],
    Polygon[{{0.704246, 1.168518, -0.002162},{0.704416, 1.168518, 0.000000},{
      0.703740, 1.172788, 0.000000},{0.703578, 1.172735, -0.002162}}],
    Polygon[{{0.704416, 1.168518, 0.000000},{0.704246, 1.168518, 0.002162},{
      0.703578, 1.172735, 0.002162},{0.703740, 1.172788, 0.000000}}],
    Polygon[{{0.704246, 1.168518, 0.002162},{0.703740, 1.168518, 0.004270},{
      0.703097, 1.172579, 0.004270},{0.703578, 1.172735, 0.002162}}],
    Polygon[{{0.703740, 1.168518, 0.004270},{0.702910, 1.168518, 0.006273},{
      0.702308, 1.172322, 0.006273},{0.703097, 1.172579, 0.004270}}],
    Polygon[{{0.702910, 1.168518, 0.006273},{0.701777, 1.168518, 0.008122},{
      0.701230, 1.171972, 0.008122},{0.702308, 1.172322, 0.006273}}],
    Polygon[{{0.701777, 1.168518, 0.008122},{0.700369, 1.168518, 0.009770},{
      0.699891, 1.171537, 0.009770},{0.701230, 1.171972, 0.008122}}],
    Polygon[{{0.700369, 1.168518, 0.009770},{0.698721, 1.168518, 0.011178},{
      0.698323, 1.171028, 0.011178},{0.699891, 1.171537, 0.009770}}],
    Polygon[{{0.698721, 1.168518, 0.011178},{0.696872, 1.168518, 0.012311},{
      0.696565, 1.170456, 0.012311},{0.698323, 1.171028, 0.011178}}],
    Polygon[{{0.696872, 1.168518, 0.012311},{0.694869, 1.168518, 0.013141},{
      0.694660, 1.169837, 0.013141},{0.696565, 1.170456, 0.012311}}],
    Polygon[{{0.694869, 1.168518, 0.013141},{0.692760, 1.168518, 0.013647},{
      0.692655, 1.169186, 0.013647},{0.694660, 1.169837, 0.013141}}],
    Polygon[{{0.692655, 1.169186, -0.013647},{0.694660, 1.169837, -0.013141},{
      0.694053, 1.171028, -0.013141},{0.692348, 1.169788, -0.013647}}],
    Polygon[{{0.694660, 1.169837, -0.013141},{0.696565, 1.170456, -0.012311},{
      0.695674, 1.172205, -0.012311},{0.694053, 1.171028, -0.013141}}],
    Polygon[{{0.696565, 1.170456, -0.012311},{0.698323, 1.171028, -0.011178},{
      0.697169, 1.173292, -0.011178},{0.695674, 1.172205, -0.012311}}],
    Polygon[{{0.698323, 1.171028, -0.011178},{0.699891, 1.171537, -0.009770},{
      0.698503, 1.174261, -0.009770},{0.697169, 1.173292, -0.011178}}],
    Polygon[{{0.699891, 1.171537, -0.009770},{0.701230, 1.171972, -0.008122},{
      0.699642, 1.175088, -0.008122},{0.698503, 1.174261, -0.009770}}],
    Polygon[{{0.701230, 1.171972, -0.008122},{0.702308, 1.172322, -0.006273},{
      0.700559, 1.175754, -0.006273},{0.699642, 1.175088, -0.008122}}],
    Polygon[{{0.702308, 1.172322, -0.006273},{0.703097, 1.172579, -0.004270},{
      0.701230, 1.176242, -0.004270},{0.700559, 1.175754, -0.006273}}],
    Polygon[{{0.703097, 1.172579, -0.004270},{0.703578, 1.172735, -0.002162},{
      0.701640, 1.176539, -0.002162},{0.701230, 1.176242, -0.004270}}],
    Polygon[{{0.703578, 1.172735, -0.002162},{0.703740, 1.172788, 0.000000},{
      0.701777, 1.176639, 0.000000},{0.701640, 1.176539, -0.002162}}],
    Polygon[{{0.703740, 1.172788, 0.000000},{0.703578, 1.172735, 0.002162},{
      0.701640, 1.176539, 0.002162},{0.701777, 1.176639, 0.000000}}],
    Polygon[{{0.703578, 1.172735, 0.002162},{0.703097, 1.172579, 0.004270},{
      0.701230, 1.176242, 0.004270},{0.701640, 1.176539, 0.002162}}],
    Polygon[{{0.703097, 1.172579, 0.004270},{0.702308, 1.172322, 0.006273},{
      0.700559, 1.175754, 0.006273},{0.701230, 1.176242, 0.004270}}],
    Polygon[{{0.702308, 1.172322, 0.006273},{0.701230, 1.171972, 0.008122},{
      0.699642, 1.175088, 0.008122},{0.700559, 1.175754, 0.006273}}],
    Polygon[{{0.701230, 1.171972, 0.008122},{0.699891, 1.171537, 0.009770},{
      0.698503, 1.174261, 0.009770},{0.699642, 1.175088, 0.008122}}],
    Polygon[{{0.699891, 1.171537, 0.009770},{0.698323, 1.171028, 0.011178},{
      0.697169, 1.173292, 0.011178},{0.698503, 1.174261, 0.009770}}],
    Polygon[{{0.698323, 1.171028, 0.011178},{0.696565, 1.170456, 0.012311},{
      0.695674, 1.172205, 0.012311},{0.697169, 1.173292, 0.011178}}],
    Polygon[{{0.696565, 1.170456, 0.012311},{0.694660, 1.169837, 0.013141},{
      0.694053, 1.171028, 0.013141},{0.695674, 1.172205, 0.012311}}],
    Polygon[{{0.694660, 1.169837, 0.013141},{0.692655, 1.169186, 0.013647},{
      0.692348, 1.169788, 0.013647},{0.694053, 1.171028, 0.013141}}],
    Polygon[{{0.692348, 1.169788, -0.013647},{0.694053, 1.171028, -0.013141},{
      0.693109, 1.171972, -0.013141},{0.691869, 1.170267, -0.013647}}],
    Polygon[{{0.694053, 1.171028, -0.013141},{0.695674, 1.172205, -0.012311},{
      0.694286, 1.173593, -0.012311},{0.693109, 1.171972, -0.013141}}],
    Polygon[{{0.695674, 1.172205, -0.012311},{0.697169, 1.173292, -0.011178},{
      0.695373, 1.175088, -0.011178},{0.694286, 1.173593, -0.012311}}],
    Polygon[{{0.697169, 1.173292, -0.011178},{0.698503, 1.174261, -0.009770},{
      0.696342, 1.176422, -0.009770},{0.695373, 1.175088, -0.011178}}],
    Polygon[{{0.698503, 1.174261, -0.009770},{0.699642, 1.175088, -0.008122},{
      0.697169, 1.177561, -0.008122},{0.696342, 1.176422, -0.009770}}],
    Polygon[{{0.699642, 1.175088, -0.008122},{0.700559, 1.175754, -0.006273},{
      0.697835, 1.178478, -0.006273},{0.697169, 1.177561, -0.008122}}],
    Polygon[{{0.700559, 1.175754, -0.006273},{0.701230, 1.176242, -0.004270},{
      0.698323, 1.179149, -0.004270},{0.697835, 1.178478, -0.006273}}],
    Polygon[{{0.701230, 1.176242, -0.004270},{0.701640, 1.176539, -0.002162},{
      0.698621, 1.179559, -0.002162},{0.698323, 1.179149, -0.004270}}],
    Polygon[{{0.701640, 1.176539, -0.002162},{0.701777, 1.176639, 0.000000},{
      0.698721, 1.179696, 0.000000},{0.698621, 1.179559, -0.002162}}],
    Polygon[{{0.701777, 1.176639, 0.000000},{0.701640, 1.176539, 0.002162},{
      0.698621, 1.179559, 0.002162},{0.698721, 1.179696, 0.000000}}],
    Polygon[{{0.701640, 1.176539, 0.002162},{0.701230, 1.176242, 0.004270},{
      0.698323, 1.179149, 0.004270},{0.698621, 1.179559, 0.002162}}],
    Polygon[{{0.701230, 1.176242, 0.004270},{0.700559, 1.175754, 0.006273},{
      0.697835, 1.178478, 0.006273},{0.698323, 1.179149, 0.004270}}],
    Polygon[{{0.700559, 1.175754, 0.006273},{0.699642, 1.175088, 0.008122},{
      0.697169, 1.177561, 0.008122},{0.697835, 1.178478, 0.006273}}],
    Polygon[{{0.699642, 1.175088, 0.008122},{0.698503, 1.174261, 0.009770},{
      0.696342, 1.176422, 0.009770},{0.697169, 1.177561, 0.008122}}],
    Polygon[{{0.698503, 1.174261, 0.009770},{0.697169, 1.173292, 0.011178},{
      0.695373, 1.175088, 0.011178},{0.696342, 1.176422, 0.009770}}],
    Polygon[{{0.697169, 1.173292, 0.011178},{0.695674, 1.172205, 0.012311},{
      0.694286, 1.173593, 0.012311},{0.695373, 1.175088, 0.011178}}],
    Polygon[{{0.695674, 1.172205, 0.012311},{0.694053, 1.171028, 0.013141},{
      0.693109, 1.171972, 0.013141},{0.694286, 1.173593, 0.012311}}],
    Polygon[{{0.694053, 1.171028, 0.013141},{0.692348, 1.169788, 0.013647},{
      0.691869, 1.170267, 0.013647},{0.693109, 1.171972, 0.013141}}],
    Polygon[{{0.691869, 1.170267, -0.013647},{0.693109, 1.171972, -0.013141},{
      0.691918, 1.172579, -0.013141},{0.691267, 1.170574, -0.013647}}],
    Polygon[{{0.693109, 1.171972, -0.013141},{0.694286, 1.173593, -0.012311},{
      0.692537, 1.174484, -0.012311},{0.691918, 1.172579, -0.013141}}],
    Polygon[{{0.694286, 1.173593, -0.012311},{0.695373, 1.175088, -0.011178},{
      0.693109, 1.176242, -0.011178},{0.692537, 1.174484, -0.012311}}],
    Polygon[{{0.695373, 1.175088, -0.011178},{0.696342, 1.176422, -0.009770},{
      0.693618, 1.177810, -0.009770},{0.693109, 1.176242, -0.011178}}],
    Polygon[{{0.696342, 1.176422, -0.009770},{0.697169, 1.177561, -0.008122},{
      0.694053, 1.179149, -0.008122},{0.693618, 1.177810, -0.009770}}],
    Polygon[{{0.697169, 1.177561, -0.008122},{0.697835, 1.178478, -0.006273},{
      0.694403, 1.180227, -0.006273},{0.694053, 1.179149, -0.008122}}],
    Polygon[{{0.697835, 1.178478, -0.006273},{0.698323, 1.179149, -0.004270},{
      0.694660, 1.181016, -0.004270},{0.694403, 1.180227, -0.006273}}],
    Polygon[{{0.698323, 1.179149, -0.004270},{0.698621, 1.179559, -0.002162},{
      0.694816, 1.181497, -0.002162},{0.694660, 1.181016, -0.004270}}],
    Polygon[{{0.698621, 1.179559, -0.002162},{0.698721, 1.179696, 0.000000},{
      0.694869, 1.181659, 0.000000},{0.694816, 1.181497, -0.002162}}],
    Polygon[{{0.698721, 1.179696, 0.000000},{0.698621, 1.179559, 0.002162},{
      0.694816, 1.181497, 0.002162},{0.694869, 1.181659, 0.000000}}],
    Polygon[{{0.698621, 1.179559, 0.002162},{0.698323, 1.179149, 0.004270},{
      0.694660, 1.181016, 0.004270},{0.694816, 1.181497, 0.002162}}],
    Polygon[{{0.698323, 1.179149, 0.004270},{0.697835, 1.178478, 0.006273},{
      0.694403, 1.180227, 0.006273},{0.694660, 1.181016, 0.004270}}],
    Polygon[{{0.697835, 1.178478, 0.006273},{0.697169, 1.177561, 0.008122},{
      0.694053, 1.179149, 0.008122},{0.694403, 1.180227, 0.006273}}],
    Polygon[{{0.697169, 1.177561, 0.008122},{0.696342, 1.176422, 0.009770},{
      0.693618, 1.177810, 0.009770},{0.694053, 1.179149, 0.008122}}],
    Polygon[{{0.696342, 1.176422, 0.009770},{0.695373, 1.175088, 0.011178},{
      0.693109, 1.176242, 0.011178},{0.693618, 1.177810, 0.009770}}],
    Polygon[{{0.695373, 1.175088, 0.011178},{0.694286, 1.173593, 0.012311},{
      0.692537, 1.174484, 0.012311},{0.693109, 1.176242, 0.011178}}],
    Polygon[{{0.694286, 1.173593, 0.012311},{0.693109, 1.171972, 0.013141},{
      0.691918, 1.172579, 0.013141},{0.692537, 1.174484, 0.012311}}],
    Polygon[{{0.693109, 1.171972, 0.013141},{0.691869, 1.170267, 0.013647},{
      0.691267, 1.170574, 0.013647},{0.691918, 1.172579, 0.013141}}],
    Polygon[{{0.691267, 1.170574, -0.013647},{0.691918, 1.172579, -0.013141},{
      0.690599, 1.172788, -0.013141},{0.690599, 1.170679, -0.013647}}],
    Polygon[{{0.691918, 1.172579, -0.013141},{0.692537, 1.174484, -0.012311},{
      0.690599, 1.174791, -0.012311},{0.690599, 1.172788, -0.013141}}],
    Polygon[{{0.692537, 1.174484, -0.012311},{0.693109, 1.176242, -0.011178},{
      0.690599, 1.176639, -0.011178},{0.690599, 1.174791, -0.012311}}],
    Polygon[{{0.693109, 1.176242, -0.011178},{0.693618, 1.177810, -0.009770},{
      0.690599, 1.178288, -0.009770},{0.690599, 1.176639, -0.011178}}],
    Polygon[{{0.693618, 1.177810, -0.009770},{0.694053, 1.179149, -0.008122},{
      0.690599, 1.179696, -0.008122},{0.690599, 1.178288, -0.009770}}],
    Polygon[{{0.694053, 1.179149, -0.008122},{0.694403, 1.180227, -0.006273},{
      0.690599, 1.180829, -0.006273},{0.690599, 1.179696, -0.008122}}],
    Polygon[{{0.694403, 1.180227, -0.006273},{0.694660, 1.181016, -0.004270},{
      0.690599, 1.181659, -0.004270},{0.690599, 1.180829, -0.006273}}],
    Polygon[{{0.694660, 1.181016, -0.004270},{0.694816, 1.181497, -0.002162},{
      0.690599, 1.182165, -0.002162},{0.690599, 1.181659, -0.004270}}],
    Polygon[{{0.694816, 1.181497, -0.002162},{0.694869, 1.181659, 0.000000},{
      0.690599, 1.182335, 0.000000},{0.690599, 1.182165, -0.002162}}],
    Polygon[{{0.694869, 1.181659, 0.000000},{0.694816, 1.181497, 0.002162},{
      0.690599, 1.182165, 0.002162},{0.690599, 1.182335, 0.000000}}],
    Polygon[{{0.694816, 1.181497, 0.002162},{0.694660, 1.181016, 0.004270},{
      0.690599, 1.181659, 0.004270},{0.690599, 1.182165, 0.002162}}],
    Polygon[{{0.694660, 1.181016, 0.004270},{0.694403, 1.180227, 0.006273},{
      0.690599, 1.180829, 0.006273},{0.690599, 1.181659, 0.004270}}],
    Polygon[{{0.694403, 1.180227, 0.006273},{0.694053, 1.179149, 0.008122},{
      0.690599, 1.179696, 0.008122},{0.690599, 1.180829, 0.006273}}],
    Polygon[{{0.694053, 1.179149, 0.008122},{0.693618, 1.177810, 0.009770},{
      0.690599, 1.178288, 0.009770},{0.690599, 1.179696, 0.008122}}],
    Polygon[{{0.693618, 1.177810, 0.009770},{0.693109, 1.176242, 0.011178},{
      0.690599, 1.176639, 0.011178},{0.690599, 1.178288, 0.009770}}],
    Polygon[{{0.693109, 1.176242, 0.011178},{0.692537, 1.174484, 0.012311},{
      0.690599, 1.174791, 0.012311},{0.690599, 1.176639, 0.011178}}],
    Polygon[{{0.692537, 1.174484, 0.012311},{0.691918, 1.172579, 0.013141},{
      0.690599, 1.172788, 0.013141},{0.690599, 1.174791, 0.012311}}],
    Polygon[{{0.691918, 1.172579, 0.013141},{0.691267, 1.170574, 0.013647},{
      0.690599, 1.170679, 0.013647},{0.690599, 1.172788, 0.013141}}],
    Polygon[{{0.690599, 1.170679, -0.013647},{0.690599, 1.172788, -0.013141},{
      0.689279, 1.172579, -0.013141},{0.689931, 1.170574, -0.013647}}],
    Polygon[{{0.690599, 1.172788, -0.013141},{0.690599, 1.174791, -0.012311},{
      0.688661, 1.174484, -0.012311},{0.689279, 1.172579, -0.013141}}],
    Polygon[{{0.690599, 1.174791, -0.012311},{0.690599, 1.176639, -0.011178},{
      0.688089, 1.176242, -0.011178},{0.688661, 1.174484, -0.012311}}],
    Polygon[{{0.690599, 1.176639, -0.011178},{0.690599, 1.178288, -0.009770},{
      0.687580, 1.177810, -0.009770},{0.688089, 1.176242, -0.011178}}],
    Polygon[{{0.690599, 1.178288, -0.009770},{0.690599, 1.179696, -0.008122},{
      0.687145, 1.179149, -0.008122},{0.687580, 1.177810, -0.009770}}],
    Polygon[{{0.690599, 1.179696, -0.008122},{0.690599, 1.180829, -0.006273},{
      0.686795, 1.180227, -0.006273},{0.687145, 1.179149, -0.008122}}],
    Polygon[{{0.690599, 1.180829, -0.006273},{0.690599, 1.181659, -0.004270},{
      0.686538, 1.181016, -0.004270},{0.686795, 1.180227, -0.006273}}],
    Polygon[{{0.690599, 1.181659, -0.004270},{0.690599, 1.182165, -0.002162},{
      0.686382, 1.181497, -0.002162},{0.686538, 1.181016, -0.004270}}],
    Polygon[{{0.690599, 1.182165, -0.002162},{0.690599, 1.182335, 0.000000},{
      0.686329, 1.181659, 0.000000},{0.686382, 1.181497, -0.002162}}],
    Polygon[{{0.690599, 1.182335, 0.000000},{0.690599, 1.182165, 0.002162},{
      0.686382, 1.181497, 0.002162},{0.686329, 1.181659, 0.000000}}],
    Polygon[{{0.690599, 1.182165, 0.002162},{0.690599, 1.181659, 0.004270},{
      0.686538, 1.181016, 0.004270},{0.686382, 1.181497, 0.002162}}],
    Polygon[{{0.690599, 1.181659, 0.004270},{0.690599, 1.180829, 0.006273},{
      0.686795, 1.180227, 0.006273},{0.686538, 1.181016, 0.004270}}],
    Polygon[{{0.690599, 1.180829, 0.006273},{0.690599, 1.179696, 0.008122},{
      0.687145, 1.179149, 0.008122},{0.686795, 1.180227, 0.006273}}],
    Polygon[{{0.690599, 1.179696, 0.008122},{0.690599, 1.178288, 0.009770},{
      0.687580, 1.177810, 0.009770},{0.687145, 1.179149, 0.008122}}],
    Polygon[{{0.690599, 1.178288, 0.009770},{0.690599, 1.176639, 0.011178},{
      0.688089, 1.176242, 0.011178},{0.687580, 1.177810, 0.009770}}],
    Polygon[{{0.690599, 1.176639, 0.011178},{0.690599, 1.174791, 0.012311},{
      0.688661, 1.174484, 0.012311},{0.688089, 1.176242, 0.011178}}],
    Polygon[{{0.690599, 1.174791, 0.012311},{0.690599, 1.172788, 0.013141},{
      0.689279, 1.172579, 0.013141},{0.688661, 1.174484, 0.012311}}],
    Polygon[{{0.690599, 1.172788, 0.013141},{0.690599, 1.170679, 0.013647},{
      0.689931, 1.170574, 0.013647},{0.689279, 1.172579, 0.013141}}],
    Polygon[{{0.689931, 1.170574, -0.013647},{0.689279, 1.172579, -0.013141},{
      0.688089, 1.171972, -0.013141},{0.689328, 1.170267, -0.013647}}],
    Polygon[{{0.689279, 1.172579, -0.013141},{0.688661, 1.174484, -0.012311},{
      0.686912, 1.173593, -0.012311},{0.688089, 1.171972, -0.013141}}],
    Polygon[{{0.688661, 1.174484, -0.012311},{0.688089, 1.176242, -0.011178},{
      0.685825, 1.175088, -0.011178},{0.686912, 1.173593, -0.012311}}],
    Polygon[{{0.688089, 1.176242, -0.011178},{0.687580, 1.177810, -0.009770},{
      0.684856, 1.176422, -0.009770},{0.685825, 1.175088, -0.011178}}],
    Polygon[{{0.687580, 1.177810, -0.009770},{0.687145, 1.179149, -0.008122},{
      0.684028, 1.177561, -0.008122},{0.684856, 1.176422, -0.009770}}],
    Polygon[{{0.687145, 1.179149, -0.008122},{0.686795, 1.180227, -0.006273},{
      0.683363, 1.178478, -0.006273},{0.684028, 1.177561, -0.008122}}],
    Polygon[{{0.686795, 1.180227, -0.006273},{0.686538, 1.181016, -0.004270},{
      0.682875, 1.179149, -0.004270},{0.683363, 1.178478, -0.006273}}],
    Polygon[{{0.686538, 1.181016, -0.004270},{0.686382, 1.181497, -0.002162},{
      0.682577, 1.179559, -0.002162},{0.682875, 1.179149, -0.004270}}],
    Polygon[{{0.686382, 1.181497, -0.002162},{0.686329, 1.181659, 0.000000},{
      0.682477, 1.179696, 0.000000},{0.682577, 1.179559, -0.002162}}],
    Polygon[{{0.686329, 1.181659, 0.000000},{0.686382, 1.181497, 0.002162},{
      0.682577, 1.179559, 0.002162},{0.682477, 1.179696, 0.000000}}],
    Polygon[{{0.686382, 1.181497, 0.002162},{0.686538, 1.181016, 0.004270},{
      0.682875, 1.179149, 0.004270},{0.682577, 1.179559, 0.002162}}],
    Polygon[{{0.686538, 1.181016, 0.004270},{0.686795, 1.180227, 0.006273},{
      0.683363, 1.178478, 0.006273},{0.682875, 1.179149, 0.004270}}],
    Polygon[{{0.686795, 1.180227, 0.006273},{0.687145, 1.179149, 0.008122},{
      0.684028, 1.177561, 0.008122},{0.683363, 1.178478, 0.006273}}],
    Polygon[{{0.687145, 1.179149, 0.008122},{0.687580, 1.177810, 0.009770},{
      0.684856, 1.176422, 0.009770},{0.684028, 1.177561, 0.008122}}],
    Polygon[{{0.687580, 1.177810, 0.009770},{0.688089, 1.176242, 0.011178},{
      0.685825, 1.175088, 0.011178},{0.684856, 1.176422, 0.009770}}],
    Polygon[{{0.688089, 1.176242, 0.011178},{0.688661, 1.174484, 0.012311},{
      0.686912, 1.173593, 0.012311},{0.685825, 1.175088, 0.011178}}],
    Polygon[{{0.688661, 1.174484, 0.012311},{0.689279, 1.172579, 0.013141},{
      0.688089, 1.171972, 0.013141},{0.686912, 1.173593, 0.012311}}],
    Polygon[{{0.689279, 1.172579, 0.013141},{0.689931, 1.170574, 0.013647},{
      0.689328, 1.170267, 0.013647},{0.688089, 1.171972, 0.013141}}],
    Polygon[{{0.689328, 1.170267, -0.013647},{0.688089, 1.171972, -0.013141},{
      0.687145, 1.171028, -0.013141},{0.688850, 1.169788, -0.013647}}],
    Polygon[{{0.688089, 1.171972, -0.013141},{0.686912, 1.173593, -0.012311},{
      0.685524, 1.172205, -0.012311},{0.687145, 1.171028, -0.013141}}],
    Polygon[{{0.686912, 1.173593, -0.012311},{0.685825, 1.175088, -0.011178},{
      0.684028, 1.173292, -0.011178},{0.685524, 1.172205, -0.012311}}],
    Polygon[{{0.685825, 1.175088, -0.011178},{0.684856, 1.176422, -0.009770},{
      0.682695, 1.174261, -0.009770},{0.684028, 1.173292, -0.011178}}],
    Polygon[{{0.684856, 1.176422, -0.009770},{0.684028, 1.177561, -0.008122},{
      0.681555, 1.175088, -0.008122},{0.682695, 1.174261, -0.009770}}],
    Polygon[{{0.684028, 1.177561, -0.008122},{0.683363, 1.178478, -0.006273},{
      0.680639, 1.175754, -0.006273},{0.681555, 1.175088, -0.008122}}],
    Polygon[{{0.683363, 1.178478, -0.006273},{0.682875, 1.179149, -0.004270},{
      0.679968, 1.176242, -0.004270},{0.680639, 1.175754, -0.006273}}],
    Polygon[{{0.682875, 1.179149, -0.004270},{0.682577, 1.179559, -0.002162},{
      0.679558, 1.176539, -0.002162},{0.679968, 1.176242, -0.004270}}],
    Polygon[{{0.682577, 1.179559, -0.002162},{0.682477, 1.179696, 0.000000},{
      0.679420, 1.176639, 0.000000},{0.679558, 1.176539, -0.002162}}],
    Polygon[{{0.682477, 1.179696, 0.000000},{0.682577, 1.179559, 0.002162},{
      0.679558, 1.176539, 0.002162},{0.679420, 1.176639, 0.000000}}],
    Polygon[{{0.682577, 1.179559, 0.002162},{0.682875, 1.179149, 0.004270},{
      0.679968, 1.176242, 0.004270},{0.679558, 1.176539, 0.002162}}],
    Polygon[{{0.682875, 1.179149, 0.004270},{0.683363, 1.178478, 0.006273},{
      0.680639, 1.175754, 0.006273},{0.679968, 1.176242, 0.004270}}],
    Polygon[{{0.683363, 1.178478, 0.006273},{0.684028, 1.177561, 0.008122},{
      0.681555, 1.175088, 0.008122},{0.680639, 1.175754, 0.006273}}],
    Polygon[{{0.684028, 1.177561, 0.008122},{0.684856, 1.176422, 0.009770},{
      0.682695, 1.174261, 0.009770},{0.681555, 1.175088, 0.008122}}],
    Polygon[{{0.684856, 1.176422, 0.009770},{0.685825, 1.175088, 0.011178},{
      0.684028, 1.173292, 0.011178},{0.682695, 1.174261, 0.009770}}],
    Polygon[{{0.685825, 1.175088, 0.011178},{0.686912, 1.173593, 0.012311},{
      0.685524, 1.172205, 0.012311},{0.684028, 1.173292, 0.011178}}],
    Polygon[{{0.686912, 1.173593, 0.012311},{0.688089, 1.171972, 0.013141},{
      0.687145, 1.171028, 0.013141},{0.685524, 1.172205, 0.012311}}],
    Polygon[{{0.688089, 1.171972, 0.013141},{0.689328, 1.170267, 0.013647},{
      0.688850, 1.169788, 0.013647},{0.687145, 1.171028, 0.013141}}],
    Polygon[{{0.688850, 1.169788, -0.013647},{0.687145, 1.171028, -0.013141},{
      0.686538, 1.169837, -0.013141},{0.688543, 1.169186, -0.013647}}],
    Polygon[{{0.687145, 1.171028, -0.013141},{0.685524, 1.172205, -0.012311},{
      0.684633, 1.170456, -0.012311},{0.686538, 1.169837, -0.013141}}],
    Polygon[{{0.685524, 1.172205, -0.012311},{0.684028, 1.173292, -0.011178},{
      0.682875, 1.171028, -0.011178},{0.684633, 1.170456, -0.012311}}],
    Polygon[{{0.684028, 1.173292, -0.011178},{0.682695, 1.174261, -0.009770},{
      0.681307, 1.171537, -0.009770},{0.682875, 1.171028, -0.011178}}],
    Polygon[{{0.682695, 1.174261, -0.009770},{0.681555, 1.175088, -0.008122},{
      0.679968, 1.171972, -0.008122},{0.681307, 1.171537, -0.009770}}],
    Polygon[{{0.681555, 1.175088, -0.008122},{0.680639, 1.175754, -0.006273},{
      0.678890, 1.172322, -0.006273},{0.679968, 1.171972, -0.008122}}],
    Polygon[{{0.680639, 1.175754, -0.006273},{0.679968, 1.176242, -0.004270},{
      0.678101, 1.172579, -0.004270},{0.678890, 1.172322, -0.006273}}],
    Polygon[{{0.679968, 1.176242, -0.004270},{0.679558, 1.176539, -0.002162},{
      0.677620, 1.172735, -0.002162},{0.678101, 1.172579, -0.004270}}],
    Polygon[{{0.679558, 1.176539, -0.002162},{0.679420, 1.176639, 0.000000},{
      0.677458, 1.172788, 0.000000},{0.677620, 1.172735, -0.002162}}],
    Polygon[{{0.679420, 1.176639, 0.000000},{0.679558, 1.176539, 0.002162},{
      0.677620, 1.172735, 0.002162},{0.677458, 1.172788, 0.000000}}],
    Polygon[{{0.679558, 1.176539, 0.002162},{0.679968, 1.176242, 0.004270},{
      0.678101, 1.172579, 0.004270},{0.677620, 1.172735, 0.002162}}],
    Polygon[{{0.679968, 1.176242, 0.004270},{0.680639, 1.175754, 0.006273},{
      0.678890, 1.172322, 0.006273},{0.678101, 1.172579, 0.004270}}],
    Polygon[{{0.680639, 1.175754, 0.006273},{0.681555, 1.175088, 0.008122},{
      0.679968, 1.171972, 0.008122},{0.678890, 1.172322, 0.006273}}],
    Polygon[{{0.681555, 1.175088, 0.008122},{0.682695, 1.174261, 0.009770},{
      0.681307, 1.171537, 0.009770},{0.679968, 1.171972, 0.008122}}],
    Polygon[{{0.682695, 1.174261, 0.009770},{0.684028, 1.173292, 0.011178},{
      0.682875, 1.171028, 0.011178},{0.681307, 1.171537, 0.009770}}],
    Polygon[{{0.684028, 1.173292, 0.011178},{0.685524, 1.172205, 0.012311},{
      0.684633, 1.170456, 0.012311},{0.682875, 1.171028, 0.011178}}],
    Polygon[{{0.685524, 1.172205, 0.012311},{0.687145, 1.171028, 0.013141},{
      0.686538, 1.169837, 0.013141},{0.684633, 1.170456, 0.012311}}],
    Polygon[{{0.687145, 1.171028, 0.013141},{0.688850, 1.169788, 0.013647},{
      0.688543, 1.169186, 0.013647},{0.686538, 1.169837, 0.013141}}],
    Polygon[{{0.688543, 1.169186, -0.013647},{0.686538, 1.169837, -0.013141},{
      0.686329, 1.168518, -0.013141},{0.688437, 1.168518, -0.013647}}],
    Polygon[{{0.686538, 1.169837, -0.013141},{0.684633, 1.170456, -0.012311},{
      0.684326, 1.168518, -0.012311},{0.686329, 1.168518, -0.013141}}],
    Polygon[{{0.684633, 1.170456, -0.012311},{0.682875, 1.171028, -0.011178},{
      0.682477, 1.168518, -0.011178},{0.684326, 1.168518, -0.012311}}],
    Polygon[{{0.682875, 1.171028, -0.011178},{0.681307, 1.171537, -0.009770},{
      0.680829, 1.168518, -0.009770},{0.682477, 1.168518, -0.011178}}],
    Polygon[{{0.681307, 1.171537, -0.009770},{0.679968, 1.171972, -0.008122},{
      0.679420, 1.168518, -0.008122},{0.680829, 1.168518, -0.009770}}],
    Polygon[{{0.679968, 1.171972, -0.008122},{0.678890, 1.172322, -0.006273},{
      0.678288, 1.168518, -0.006273},{0.679420, 1.168518, -0.008122}}],
    Polygon[{{0.678890, 1.172322, -0.006273},{0.678101, 1.172579, -0.004270},{
      0.677458, 1.168518, -0.004270},{0.678288, 1.168518, -0.006273}}],
    Polygon[{{0.678101, 1.172579, -0.004270},{0.677620, 1.172735, -0.002162},{
      0.676952, 1.168518, -0.002162},{0.677458, 1.168518, -0.004270}}],
    Polygon[{{0.677620, 1.172735, -0.002162},{0.677458, 1.172788, 0.000000},{
      0.676782, 1.168518, 0.000000},{0.676952, 1.168518, -0.002162}}],
    Polygon[{{0.677458, 1.172788, 0.000000},{0.677620, 1.172735, 0.002162},{
      0.676952, 1.168518, 0.002162},{0.676782, 1.168518, 0.000000}}],
    Polygon[{{0.677620, 1.172735, 0.002162},{0.678101, 1.172579, 0.004270},{
      0.677458, 1.168518, 0.004270},{0.676952, 1.168518, 0.002162}}],
    Polygon[{{0.678101, 1.172579, 0.004270},{0.678890, 1.172322, 0.006273},{
      0.678288, 1.168518, 0.006273},{0.677458, 1.168518, 0.004270}}],
    Polygon[{{0.678890, 1.172322, 0.006273},{0.679968, 1.171972, 0.008122},{
      0.679420, 1.168518, 0.008122},{0.678288, 1.168518, 0.006273}}],
    Polygon[{{0.679968, 1.171972, 0.008122},{0.681307, 1.171537, 0.009770},{
      0.680829, 1.168518, 0.009770},{0.679420, 1.168518, 0.008122}}],
    Polygon[{{0.681307, 1.171537, 0.009770},{0.682875, 1.171028, 0.011178},{
      0.682477, 1.168518, 0.011178},{0.680829, 1.168518, 0.009770}}],
    Polygon[{{0.682875, 1.171028, 0.011178},{0.684633, 1.170456, 0.012311},{
      0.684326, 1.168518, 0.012311},{0.682477, 1.168518, 0.011178}}],
    Polygon[{{0.684633, 1.170456, 0.012311},{0.686538, 1.169837, 0.013141},{
      0.686329, 1.168518, 0.013141},{0.684326, 1.168518, 0.012311}}],
    Polygon[{{0.686538, 1.169837, 0.013141},{0.688543, 1.169186, 0.013647},{
      0.688437, 1.168518, 0.013647},{0.686329, 1.168518, 0.013141}}],
    Polygon[{{0.688437, 1.168518, -0.013647},{0.686329, 1.168518, -0.013141},{
      0.686538, 1.167198, -0.013141},{0.688543, 1.167850, -0.013647}}],
    Polygon[{{0.686329, 1.168518, -0.013141},{0.684326, 1.168518, -0.012311},{
      0.684633, 1.166579, -0.012311},{0.686538, 1.167198, -0.013141}}],
    Polygon[{{0.684326, 1.168518, -0.012311},{0.682477, 1.168518, -0.011178},{
      0.682875, 1.166008, -0.011178},{0.684633, 1.166579, -0.012311}}],
    Polygon[{{0.682477, 1.168518, -0.011178},{0.680829, 1.168518, -0.009770},{
      0.681307, 1.165499, -0.009770},{0.682875, 1.166008, -0.011178}}],
    Polygon[{{0.680829, 1.168518, -0.009770},{0.679420, 1.168518, -0.008122},{
      0.679968, 1.165064, -0.008122},{0.681307, 1.165499, -0.009770}}],
    Polygon[{{0.679420, 1.168518, -0.008122},{0.678288, 1.168518, -0.006273},{
      0.678890, 1.164713, -0.006273},{0.679968, 1.165064, -0.008122}}],
    Polygon[{{0.678288, 1.168518, -0.006273},{0.677458, 1.168518, -0.004270},{
      0.678101, 1.164457, -0.004270},{0.678890, 1.164713, -0.006273}}],
    Polygon[{{0.677458, 1.168518, -0.004270},{0.676952, 1.168518, -0.002162},{
      0.677620, 1.164301, -0.002162},{0.678101, 1.164457, -0.004270}}],
    Polygon[{{0.676952, 1.168518, -0.002162},{0.676782, 1.168518, 0.000000},{
      0.677458, 1.164248, 0.000000},{0.677620, 1.164301, -0.002162}}],
    Polygon[{{0.676782, 1.168518, 0.000000},{0.676952, 1.168518, 0.002162},{
      0.677620, 1.164301, 0.002162},{0.677458, 1.164248, 0.000000}}],
    Polygon[{{0.676952, 1.168518, 0.002162},{0.677458, 1.168518, 0.004270},{
      0.678101, 1.164457, 0.004270},{0.677620, 1.164301, 0.002162}}],
    Polygon[{{0.677458, 1.168518, 0.004270},{0.678288, 1.168518, 0.006273},{
      0.678890, 1.164713, 0.006273},{0.678101, 1.164457, 0.004270}}],
    Polygon[{{0.678288, 1.168518, 0.006273},{0.679420, 1.168518, 0.008122},{
      0.679968, 1.165064, 0.008122},{0.678890, 1.164713, 0.006273}}],
    Polygon[{{0.679420, 1.168518, 0.008122},{0.680829, 1.168518, 0.009770},{
      0.681307, 1.165499, 0.009770},{0.679968, 1.165064, 0.008122}}],
    Polygon[{{0.680829, 1.168518, 0.009770},{0.682477, 1.168518, 0.011178},{
      0.682875, 1.166008, 0.011178},{0.681307, 1.165499, 0.009770}}],
    Polygon[{{0.682477, 1.168518, 0.011178},{0.684326, 1.168518, 0.012311},{
      0.684633, 1.166579, 0.012311},{0.682875, 1.166008, 0.011178}}],
    Polygon[{{0.684326, 1.168518, 0.012311},{0.686329, 1.168518, 0.013141},{
      0.686538, 1.167198, 0.013141},{0.684633, 1.166579, 0.012311}}],
    Polygon[{{0.686329, 1.168518, 0.013141},{0.688437, 1.168518, 0.013647},{
      0.688543, 1.167850, 0.013647},{0.686538, 1.167198, 0.013141}}],
    Polygon[{{0.688543, 1.167850, -0.013647},{0.686538, 1.167198, -0.013141},{
      0.687145, 1.166008, -0.013141},{0.688850, 1.167247, -0.013647}}],
    Polygon[{{0.686538, 1.167198, -0.013141},{0.684633, 1.166579, -0.012311},{
      0.685524, 1.164831, -0.012311},{0.687145, 1.166008, -0.013141}}],
    Polygon[{{0.684633, 1.166579, -0.012311},{0.682875, 1.166008, -0.011178},{
      0.684028, 1.163744, -0.011178},{0.685524, 1.164831, -0.012311}}],
    Polygon[{{0.682875, 1.166008, -0.011178},{0.681307, 1.165499, -0.009770},{
      0.682695, 1.162775, -0.009770},{0.684028, 1.163744, -0.011178}}],
    Polygon[{{0.681307, 1.165499, -0.009770},{0.679968, 1.165064, -0.008122},{
      0.681555, 1.161947, -0.008122},{0.682695, 1.162775, -0.009770}}],
    Polygon[{{0.679968, 1.165064, -0.008122},{0.678890, 1.164713, -0.006273},{
      0.680639, 1.161281, -0.006273},{0.681555, 1.161947, -0.008122}}],
    Polygon[{{0.678890, 1.164713, -0.006273},{0.678101, 1.164457, -0.004270},{
      0.679968, 1.160794, -0.004270},{0.680639, 1.161281, -0.006273}}],
    Polygon[{{0.678101, 1.164457, -0.004270},{0.677620, 1.164301, -0.002162},{
      0.679558, 1.160496, -0.002162},{0.679968, 1.160794, -0.004270}}],
    Polygon[{{0.677620, 1.164301, -0.002162},{0.677458, 1.164248, 0.000000},{
      0.679420, 1.160396, 0.000000},{0.679558, 1.160496, -0.002162}}],
    Polygon[{{0.677458, 1.164248, 0.000000},{0.677620, 1.164301, 0.002162},{
      0.679558, 1.160496, 0.002162},{0.679420, 1.160396, 0.000000}}],
    Polygon[{{0.677620, 1.164301, 0.002162},{0.678101, 1.164457, 0.004270},{
      0.679968, 1.160794, 0.004270},{0.679558, 1.160496, 0.002162}}],
    Polygon[{{0.678101, 1.164457, 0.004270},{0.678890, 1.164713, 0.006273},{
      0.680639, 1.161281, 0.006273},{0.679968, 1.160794, 0.004270}}],
    Polygon[{{0.678890, 1.164713, 0.006273},{0.679968, 1.165064, 0.008122},{
      0.681555, 1.161947, 0.008122},{0.680639, 1.161281, 0.006273}}],
    Polygon[{{0.679968, 1.165064, 0.008122},{0.681307, 1.165499, 0.009770},{
      0.682695, 1.162775, 0.009770},{0.681555, 1.161947, 0.008122}}],
    Polygon[{{0.681307, 1.165499, 0.009770},{0.682875, 1.166008, 0.011178},{
      0.684028, 1.163744, 0.011178},{0.682695, 1.162775, 0.009770}}],
    Polygon[{{0.682875, 1.166008, 0.011178},{0.684633, 1.166579, 0.012311},{
      0.685524, 1.164831, 0.012311},{0.684028, 1.163744, 0.011178}}],
    Polygon[{{0.684633, 1.166579, 0.012311},{0.686538, 1.167198, 0.013141},{
      0.687145, 1.166008, 0.013141},{0.685524, 1.164831, 0.012311}}],
    Polygon[{{0.686538, 1.167198, 0.013141},{0.688543, 1.167850, 0.013647},{
      0.688850, 1.167247, 0.013647},{0.687145, 1.166008, 0.013141}}],
    Polygon[{{0.688850, 1.167247, -0.013647},{0.687145, 1.166008, -0.013141},{
      0.688089, 1.165064, -0.013141},{0.689328, 1.166769, -0.013647}}],
    Polygon[{{0.687145, 1.166008, -0.013141},{0.685524, 1.164831, -0.012311},{
      0.686912, 1.163443, -0.012311},{0.688089, 1.165064, -0.013141}}],
    Polygon[{{0.685524, 1.164831, -0.012311},{0.684028, 1.163744, -0.011178},{
      0.685825, 1.161947, -0.011178},{0.686912, 1.163443, -0.012311}}],
    Polygon[{{0.684028, 1.163744, -0.011178},{0.682695, 1.162775, -0.009770},{
      0.684856, 1.160614, -0.009770},{0.685825, 1.161947, -0.011178}}],
    Polygon[{{0.682695, 1.162775, -0.009770},{0.681555, 1.161947, -0.008122},{
      0.684028, 1.159474, -0.008122},{0.684856, 1.160614, -0.009770}}],
    Polygon[{{0.681555, 1.161947, -0.008122},{0.680639, 1.161281, -0.006273},{
      0.683363, 1.158558, -0.006273},{0.684028, 1.159474, -0.008122}}],
    Polygon[{{0.680639, 1.161281, -0.006273},{0.679968, 1.160794, -0.004270},{
      0.682875, 1.157887, -0.004270},{0.683363, 1.158558, -0.006273}}],
    Polygon[{{0.679968, 1.160794, -0.004270},{0.679558, 1.160496, -0.002162},{
      0.682577, 1.157477, -0.002162},{0.682875, 1.157887, -0.004270}}],
    Polygon[{{0.679558, 1.160496, -0.002162},{0.679420, 1.160396, 0.000000},{
      0.682477, 1.157339, 0.000000},{0.682577, 1.157477, -0.002162}}],
    Polygon[{{0.679420, 1.160396, 0.000000},{0.679558, 1.160496, 0.002162},{
      0.682577, 1.157477, 0.002162},{0.682477, 1.157339, 0.000000}}],
    Polygon[{{0.679558, 1.160496, 0.002162},{0.679968, 1.160794, 0.004270},{
      0.682875, 1.157887, 0.004270},{0.682577, 1.157477, 0.002162}}],
    Polygon[{{0.679968, 1.160794, 0.004270},{0.680639, 1.161281, 0.006273},{
      0.683363, 1.158558, 0.006273},{0.682875, 1.157887, 0.004270}}],
    Polygon[{{0.680639, 1.161281, 0.006273},{0.681555, 1.161947, 0.008122},{
      0.684028, 1.159474, 0.008122},{0.683363, 1.158558, 0.006273}}],
    Polygon[{{0.681555, 1.161947, 0.008122},{0.682695, 1.162775, 0.009770},{
      0.684856, 1.160614, 0.009770},{0.684028, 1.159474, 0.008122}}],
    Polygon[{{0.682695, 1.162775, 0.009770},{0.684028, 1.163744, 0.011178},{
      0.685825, 1.161947, 0.011178},{0.684856, 1.160614, 0.009770}}],
    Polygon[{{0.684028, 1.163744, 0.011178},{0.685524, 1.164831, 0.012311},{
      0.686912, 1.163443, 0.012311},{0.685825, 1.161947, 0.011178}}],
    Polygon[{{0.685524, 1.164831, 0.012311},{0.687145, 1.166008, 0.013141},{
      0.688089, 1.165064, 0.013141},{0.686912, 1.163443, 0.012311}}],
    Polygon[{{0.687145, 1.166008, 0.013141},{0.688850, 1.167247, 0.013647},{
      0.689328, 1.166769, 0.013647},{0.688089, 1.165064, 0.013141}}],
    Polygon[{{0.689328, 1.166769, -0.013647},{0.688089, 1.165064, -0.013141},{
      0.689279, 1.164457, -0.013141},{0.689931, 1.166462, -0.013647}}],
    Polygon[{{0.688089, 1.165064, -0.013141},{0.686912, 1.163443, -0.012311},{
      0.688661, 1.162552, -0.012311},{0.689279, 1.164457, -0.013141}}],
    Polygon[{{0.686912, 1.163443, -0.012311},{0.685825, 1.161947, -0.011178},{
      0.688089, 1.160794, -0.011178},{0.688661, 1.162552, -0.012311}}],
    Polygon[{{0.685825, 1.161947, -0.011178},{0.684856, 1.160614, -0.009770},{
      0.687580, 1.159226, -0.009770},{0.688089, 1.160794, -0.011178}}],
    Polygon[{{0.684856, 1.160614, -0.009770},{0.684028, 1.159474, -0.008122},{
      0.687145, 1.157887, -0.008122},{0.687580, 1.159226, -0.009770}}],
    Polygon[{{0.684028, 1.159474, -0.008122},{0.683363, 1.158558, -0.006273},{
      0.686795, 1.156809, -0.006273},{0.687145, 1.157887, -0.008122}}],
    Polygon[{{0.683363, 1.158558, -0.006273},{0.682875, 1.157887, -0.004270},{
      0.686538, 1.156020, -0.004270},{0.686795, 1.156809, -0.006273}}],
    Polygon[{{0.682875, 1.157887, -0.004270},{0.682577, 1.157477, -0.002162},{
      0.686382, 1.155539, -0.002162},{0.686538, 1.156020, -0.004270}}],
    Polygon[{{0.682577, 1.157477, -0.002162},{0.682477, 1.157339, 0.000000},{
      0.686329, 1.155377, 0.000000},{0.686382, 1.155539, -0.002162}}],
    Polygon[{{0.682477, 1.157339, 0.000000},{0.682577, 1.157477, 0.002162},{
      0.686382, 1.155539, 0.002162},{0.686329, 1.155377, 0.000000}}],
    Polygon[{{0.682577, 1.157477, 0.002162},{0.682875, 1.157887, 0.004270},{
      0.686538, 1.156020, 0.004270},{0.686382, 1.155539, 0.002162}}],
    Polygon[{{0.682875, 1.157887, 0.004270},{0.683363, 1.158558, 0.006273},{
      0.686795, 1.156809, 0.006273},{0.686538, 1.156020, 0.004270}}],
    Polygon[{{0.683363, 1.158558, 0.006273},{0.684028, 1.159474, 0.008122},{
      0.687145, 1.157887, 0.008122},{0.686795, 1.156809, 0.006273}}],
    Polygon[{{0.684028, 1.159474, 0.008122},{0.684856, 1.160614, 0.009770},{
      0.687580, 1.159226, 0.009770},{0.687145, 1.157887, 0.008122}}],
    Polygon[{{0.684856, 1.160614, 0.009770},{0.685825, 1.161947, 0.011178},{
      0.688089, 1.160794, 0.011178},{0.687580, 1.159226, 0.009770}}],
    Polygon[{{0.685825, 1.161947, 0.011178},{0.686912, 1.163443, 0.012311},{
      0.688661, 1.162552, 0.012311},{0.688089, 1.160794, 0.011178}}],
    Polygon[{{0.686912, 1.163443, 0.012311},{0.688089, 1.165064, 0.013141},{
      0.689279, 1.164457, 0.013141},{0.688661, 1.162552, 0.012311}}],
    Polygon[{{0.688089, 1.165064, 0.013141},{0.689328, 1.166769, 0.013647},{
      0.689931, 1.166462, 0.013647},{0.689279, 1.164457, 0.013141}}],
    Polygon[{{0.689931, 1.166462, -0.013647},{0.689279, 1.164457, -0.013141},{
      0.690599, 1.164248, -0.013141},{0.690599, 1.166356, -0.013647}}],
    Polygon[{{0.689279, 1.164457, -0.013141},{0.688661, 1.162552, -0.012311},{
      0.690599, 1.162245, -0.012311},{0.690599, 1.164248, -0.013141}}],
    Polygon[{{0.688661, 1.162552, -0.012311},{0.688089, 1.160794, -0.011178},{
      0.690599, 1.160396, -0.011178},{0.690599, 1.162245, -0.012311}}],
    Polygon[{{0.688089, 1.160794, -0.011178},{0.687580, 1.159226, -0.009770},{
      0.690599, 1.158748, -0.009770},{0.690599, 1.160396, -0.011178}}],
    Polygon[{{0.687580, 1.159226, -0.009770},{0.687145, 1.157887, -0.008122},{
      0.690599, 1.157339, -0.008122},{0.690599, 1.158748, -0.009770}}],
    Polygon[{{0.687145, 1.157887, -0.008122},{0.686795, 1.156809, -0.006273},{
      0.690599, 1.156206, -0.006273},{0.690599, 1.157339, -0.008122}}],
    Polygon[{{0.686795, 1.156809, -0.006273},{0.686538, 1.156020, -0.004270},{
      0.690599, 1.155377, -0.004270},{0.690599, 1.156206, -0.006273}}],
    Polygon[{{0.686538, 1.156020, -0.004270},{0.686382, 1.155539, -0.002162},{
      0.690599, 1.154871, -0.002162},{0.690599, 1.155377, -0.004270}}],
    Polygon[{{0.686382, 1.155539, -0.002162},{0.686329, 1.155377, 0.000000},{
      0.690599, 1.154701, 0.000000},{0.690599, 1.154871, -0.002162}}],
    Polygon[{{0.686329, 1.155377, 0.000000},{0.686382, 1.155539, 0.002162},{
      0.690599, 1.154871, 0.002162},{0.690599, 1.154701, 0.000000}}],
    Polygon[{{0.686382, 1.155539, 0.002162},{0.686538, 1.156020, 0.004270},{
      0.690599, 1.155377, 0.004270},{0.690599, 1.154871, 0.002162}}],
    Polygon[{{0.686538, 1.156020, 0.004270},{0.686795, 1.156809, 0.006273},{
      0.690599, 1.156206, 0.006273},{0.690599, 1.155377, 0.004270}}],
    Polygon[{{0.686795, 1.156809, 0.006273},{0.687145, 1.157887, 0.008122},{
      0.690599, 1.157339, 0.008122},{0.690599, 1.156206, 0.006273}}],
    Polygon[{{0.687145, 1.157887, 0.008122},{0.687580, 1.159226, 0.009770},{
      0.690599, 1.158748, 0.009770},{0.690599, 1.157339, 0.008122}}],
    Polygon[{{0.687580, 1.159226, 0.009770},{0.688089, 1.160794, 0.011178},{
      0.690599, 1.160396, 0.011178},{0.690599, 1.158748, 0.009770}}],
    Polygon[{{0.688089, 1.160794, 0.011178},{0.688661, 1.162552, 0.012311},{
      0.690599, 1.162245, 0.012311},{0.690599, 1.160396, 0.011178}}],
    Polygon[{{0.688661, 1.162552, 0.012311},{0.689279, 1.164457, 0.013141},{
      0.690599, 1.164248, 0.013141},{0.690599, 1.162245, 0.012311}}],
    Polygon[{{0.689279, 1.164457, 0.013141},{0.689931, 1.166462, 0.013647},{
      0.690599, 1.166356, 0.013647},{0.690599, 1.164248, 0.013141}}],
    Polygon[{{0.690599, 1.166356, -0.013647},{0.690599, 1.164248, -0.013141},{
      0.691918, 1.164457, -0.013141},{0.691267, 1.166462, -0.013647}}],
    Polygon[{{0.690599, 1.164248, -0.013141},{0.690599, 1.162245, -0.012311},{
      0.692537, 1.162552, -0.012311},{0.691918, 1.164457, -0.013141}}],
    Polygon[{{0.690599, 1.162245, -0.012311},{0.690599, 1.160396, -0.011178},{
      0.693109, 1.160794, -0.011178},{0.692537, 1.162552, -0.012311}}],
    Polygon[{{0.690599, 1.160396, -0.011178},{0.690599, 1.158748, -0.009770},{
      0.693618, 1.159226, -0.009770},{0.693109, 1.160794, -0.011178}}],
    Polygon[{{0.690599, 1.158748, -0.009770},{0.690599, 1.157339, -0.008122},{
      0.694053, 1.157887, -0.008122},{0.693618, 1.159226, -0.009770}}],
    Polygon[{{0.690599, 1.157339, -0.008122},{0.690599, 1.156206, -0.006273},{
      0.694403, 1.156809, -0.006273},{0.694053, 1.157887, -0.008122}}],
    Polygon[{{0.690599, 1.156206, -0.006273},{0.690599, 1.155377, -0.004270},{
      0.694660, 1.156020, -0.004270},{0.694403, 1.156809, -0.006273}}],
    Polygon[{{0.690599, 1.155377, -0.004270},{0.690599, 1.154871, -0.002162},{
      0.694816, 1.155539, -0.002162},{0.694660, 1.156020, -0.004270}}],
    Polygon[{{0.690599, 1.154871, -0.002162},{0.690599, 1.154701, 0.000000},{
      0.694869, 1.155377, 0.000000},{0.694816, 1.155539, -0.002162}}],
    Polygon[{{0.690599, 1.154701, 0.000000},{0.690599, 1.154871, 0.002162},{
      0.694816, 1.155539, 0.002162},{0.694869, 1.155377, 0.000000}}],
    Polygon[{{0.690599, 1.154871, 0.002162},{0.690599, 1.155377, 0.004270},{
      0.694660, 1.156020, 0.004270},{0.694816, 1.155539, 0.002162}}],
    Polygon[{{0.690599, 1.155377, 0.004270},{0.690599, 1.156206, 0.006273},{
      0.694403, 1.156809, 0.006273},{0.694660, 1.156020, 0.004270}}],
    Polygon[{{0.690599, 1.156206, 0.006273},{0.690599, 1.157339, 0.008122},{
      0.694053, 1.157887, 0.008122},{0.694403, 1.156809, 0.006273}}],
    Polygon[{{0.690599, 1.157339, 0.008122},{0.690599, 1.158748, 0.009770},{
      0.693618, 1.159226, 0.009770},{0.694053, 1.157887, 0.008122}}],
    Polygon[{{0.690599, 1.158748, 0.009770},{0.690599, 1.160396, 0.011178},{
      0.693109, 1.160794, 0.011178},{0.693618, 1.159226, 0.009770}}],
    Polygon[{{0.690599, 1.160396, 0.011178},{0.690599, 1.162245, 0.012311},{
      0.692537, 1.162552, 0.012311},{0.693109, 1.160794, 0.011178}}],
    Polygon[{{0.690599, 1.162245, 0.012311},{0.690599, 1.164248, 0.013141},{
      0.691918, 1.164457, 0.013141},{0.692537, 1.162552, 0.012311}}],
    Polygon[{{0.690599, 1.164248, 0.013141},{0.690599, 1.166356, 0.013647},{
      0.691267, 1.166462, 0.013647},{0.691918, 1.164457, 0.013141}}],
    Polygon[{{0.691267, 1.166462, -0.013647},{0.691918, 1.164457, -0.013141},{
      0.693109, 1.165064, -0.013141},{0.691869, 1.166769, -0.013647}}],
    Polygon[{{0.691918, 1.164457, -0.013141},{0.692537, 1.162552, -0.012311},{
      0.694286, 1.163443, -0.012311},{0.693109, 1.165064, -0.013141}}],
    Polygon[{{0.692537, 1.162552, -0.012311},{0.693109, 1.160794, -0.011178},{
      0.695373, 1.161947, -0.011178},{0.694286, 1.163443, -0.012311}}],
    Polygon[{{0.693109, 1.160794, -0.011178},{0.693618, 1.159226, -0.009770},{
      0.696342, 1.160614, -0.009770},{0.695373, 1.161947, -0.011178}}],
    Polygon[{{0.693618, 1.159226, -0.009770},{0.694053, 1.157887, -0.008122},{
      0.697169, 1.159474, -0.008122},{0.696342, 1.160614, -0.009770}}],
    Polygon[{{0.694053, 1.157887, -0.008122},{0.694403, 1.156809, -0.006273},{
      0.697835, 1.158558, -0.006273},{0.697169, 1.159474, -0.008122}}],
    Polygon[{{0.694403, 1.156809, -0.006273},{0.694660, 1.156020, -0.004270},{
      0.698323, 1.157887, -0.004270},{0.697835, 1.158558, -0.006273}}],
    Polygon[{{0.694660, 1.156020, -0.004270},{0.694816, 1.155539, -0.002162},{
      0.698621, 1.157477, -0.002162},{0.698323, 1.157887, -0.004270}}],
    Polygon[{{0.694816, 1.155539, -0.002162},{0.694869, 1.155377, 0.000000},{
      0.698721, 1.157339, 0.000000},{0.698621, 1.157477, -0.002162}}],
    Polygon[{{0.694869, 1.155377, 0.000000},{0.694816, 1.155539, 0.002162},{
      0.698621, 1.157477, 0.002162},{0.698721, 1.157339, 0.000000}}],
    Polygon[{{0.694816, 1.155539, 0.002162},{0.694660, 1.156020, 0.004270},{
      0.698323, 1.157887, 0.004270},{0.698621, 1.157477, 0.002162}}],
    Polygon[{{0.694660, 1.156020, 0.004270},{0.694403, 1.156809, 0.006273},{
      0.697835, 1.158558, 0.006273},{0.698323, 1.157887, 0.004270}}],
    Polygon[{{0.694403, 1.156809, 0.006273},{0.694053, 1.157887, 0.008122},{
      0.697169, 1.159474, 0.008122},{0.697835, 1.158558, 0.006273}}],
    Polygon[{{0.694053, 1.157887, 0.008122},{0.693618, 1.159226, 0.009770},{
      0.696342, 1.160614, 0.009770},{0.697169, 1.159474, 0.008122}}],
    Polygon[{{0.693618, 1.159226, 0.009770},{0.693109, 1.160794, 0.011178},{
      0.695373, 1.161947, 0.011178},{0.696342, 1.160614, 0.009770}}],
    Polygon[{{0.693109, 1.160794, 0.011178},{0.692537, 1.162552, 0.012311},{
      0.694286, 1.163443, 0.012311},{0.695373, 1.161947, 0.011178}}],
    Polygon[{{0.692537, 1.162552, 0.012311},{0.691918, 1.164457, 0.013141},{
      0.693109, 1.165064, 0.013141},{0.694286, 1.163443, 0.012311}}],
    Polygon[{{0.691918, 1.164457, 0.013141},{0.691267, 1.166462, 0.013647},{
      0.691869, 1.166769, 0.013647},{0.693109, 1.165064, 0.013141}}],
    Polygon[{{0.691869, 1.166769, -0.013647},{0.693109, 1.165064, -0.013141},{
      0.694053, 1.166008, -0.013141},{0.692348, 1.167247, -0.013647}}],
    Polygon[{{0.693109, 1.165064, -0.013141},{0.694286, 1.163443, -0.012311},{
      0.695674, 1.164831, -0.012311},{0.694053, 1.166008, -0.013141}}],
    Polygon[{{0.694286, 1.163443, -0.012311},{0.695373, 1.161947, -0.011178},{
      0.697169, 1.163744, -0.011178},{0.695674, 1.164831, -0.012311}}],
    Polygon[{{0.695373, 1.161947, -0.011178},{0.696342, 1.160614, -0.009770},{
      0.698503, 1.162775, -0.009770},{0.697169, 1.163744, -0.011178}}],
    Polygon[{{0.696342, 1.160614, -0.009770},{0.697169, 1.159474, -0.008122},{
      0.699642, 1.161947, -0.008122},{0.698503, 1.162775, -0.009770}}],
    Polygon[{{0.697169, 1.159474, -0.008122},{0.697835, 1.158558, -0.006273},{
      0.700559, 1.161281, -0.006273},{0.699642, 1.161947, -0.008122}}],
    Polygon[{{0.697835, 1.158558, -0.006273},{0.698323, 1.157887, -0.004270},{
      0.701230, 1.160794, -0.004270},{0.700559, 1.161281, -0.006273}}],
    Polygon[{{0.698323, 1.157887, -0.004270},{0.698621, 1.157477, -0.002162},{
      0.701640, 1.160496, -0.002162},{0.701230, 1.160794, -0.004270}}],
    Polygon[{{0.698621, 1.157477, -0.002162},{0.698721, 1.157339, 0.000000},{
      0.701777, 1.160396, 0.000000},{0.701640, 1.160496, -0.002162}}],
    Polygon[{{0.698721, 1.157339, 0.000000},{0.698621, 1.157477, 0.002162},{
      0.701640, 1.160496, 0.002162},{0.701777, 1.160396, 0.000000}}],
    Polygon[{{0.698621, 1.157477, 0.002162},{0.698323, 1.157887, 0.004270},{
      0.701230, 1.160794, 0.004270},{0.701640, 1.160496, 0.002162}}],
    Polygon[{{0.698323, 1.157887, 0.004270},{0.697835, 1.158558, 0.006273},{
      0.700559, 1.161281, 0.006273},{0.701230, 1.160794, 0.004270}}],
    Polygon[{{0.697835, 1.158558, 0.006273},{0.697169, 1.159474, 0.008122},{
      0.699642, 1.161947, 0.008122},{0.700559, 1.161281, 0.006273}}],
    Polygon[{{0.697169, 1.159474, 0.008122},{0.696342, 1.160614, 0.009770},{
      0.698503, 1.162775, 0.009770},{0.699642, 1.161947, 0.008122}}],
    Polygon[{{0.696342, 1.160614, 0.009770},{0.695373, 1.161947, 0.011178},{
      0.697169, 1.163744, 0.011178},{0.698503, 1.162775, 0.009770}}],
    Polygon[{{0.695373, 1.161947, 0.011178},{0.694286, 1.163443, 0.012311},{
      0.695674, 1.164831, 0.012311},{0.697169, 1.163744, 0.011178}}],
    Polygon[{{0.694286, 1.163443, 0.012311},{0.693109, 1.165064, 0.013141},{
      0.694053, 1.166008, 0.013141},{0.695674, 1.164831, 0.012311}}],
    Polygon[{{0.693109, 1.165064, 0.013141},{0.691869, 1.166769, 0.013647},{
      0.692348, 1.167247, 0.013647},{0.694053, 1.166008, 0.013141}}],
    Polygon[{{0.692348, 1.167247, -0.013647},{0.694053, 1.166008, -0.013141},{
      0.694660, 1.167198, -0.013141},{0.692655, 1.167850, -0.013647}}],
    Polygon[{{0.694053, 1.166008, -0.013141},{0.695674, 1.164831, -0.012311},{
      0.696565, 1.166579, -0.012311},{0.694660, 1.167198, -0.013141}}],
    Polygon[{{0.695674, 1.164831, -0.012311},{0.697169, 1.163744, -0.011178},{
      0.698323, 1.166008, -0.011178},{0.696565, 1.166579, -0.012311}}],
    Polygon[{{0.697169, 1.163744, -0.011178},{0.698503, 1.162775, -0.009770},{
      0.699891, 1.165499, -0.009770},{0.698323, 1.166008, -0.011178}}],
    Polygon[{{0.698503, 1.162775, -0.009770},{0.699642, 1.161947, -0.008122},{
      0.701230, 1.165064, -0.008122},{0.699891, 1.165499, -0.009770}}],
    Polygon[{{0.699642, 1.161947, -0.008122},{0.700559, 1.161281, -0.006273},{
      0.702308, 1.164713, -0.006273},{0.701230, 1.165064, -0.008122}}],
    Polygon[{{0.700559, 1.161281, -0.006273},{0.701230, 1.160794, -0.004270},{
      0.703097, 1.164457, -0.004270},{0.702308, 1.164713, -0.006273}}],
    Polygon[{{0.701230, 1.160794, -0.004270},{0.701640, 1.160496, -0.002162},{
      0.703578, 1.164301, -0.002162},{0.703097, 1.164457, -0.004270}}],
    Polygon[{{0.701640, 1.160496, -0.002162},{0.701777, 1.160396, 0.000000},{
      0.703740, 1.164248, 0.000000},{0.703578, 1.164301, -0.002162}}],
    Polygon[{{0.701777, 1.160396, 0.000000},{0.701640, 1.160496, 0.002162},{
      0.703578, 1.164301, 0.002162},{0.703740, 1.164248, 0.000000}}],
    Polygon[{{0.701640, 1.160496, 0.002162},{0.701230, 1.160794, 0.004270},{
      0.703097, 1.164457, 0.004270},{0.703578, 1.164301, 0.002162}}],
    Polygon[{{0.701230, 1.160794, 0.004270},{0.700559, 1.161281, 0.006273},{
      0.702308, 1.164713, 0.006273},{0.703097, 1.164457, 0.004270}}],
    Polygon[{{0.700559, 1.161281, 0.006273},{0.699642, 1.161947, 0.008122},{
      0.701230, 1.165064, 0.008122},{0.702308, 1.164713, 0.006273}}],
    Polygon[{{0.699642, 1.161947, 0.008122},{0.698503, 1.162775, 0.009770},{
      0.699891, 1.165499, 0.009770},{0.701230, 1.165064, 0.008122}}],
    Polygon[{{0.698503, 1.162775, 0.009770},{0.697169, 1.163744, 0.011178},{
      0.698323, 1.166008, 0.011178},{0.699891, 1.165499, 0.009770}}],
    Polygon[{{0.697169, 1.163744, 0.011178},{0.695674, 1.164831, 0.012311},{
      0.696565, 1.166579, 0.012311},{0.698323, 1.166008, 0.011178}}],
    Polygon[{{0.695674, 1.164831, 0.012311},{0.694053, 1.166008, 0.013141},{
      0.694660, 1.167198, 0.013141},{0.696565, 1.166579, 0.012311}}],
    Polygon[{{0.694053, 1.166008, 0.013141},{0.692348, 1.167247, 0.013647},{
      0.692655, 1.167850, 0.013647},{0.694660, 1.167198, 0.013141}}],
    Polygon[{{0.692655, 1.167850, -0.013647},{0.694660, 1.167198, -0.013141},{
      0.694869, 1.168518, -0.013141},{0.692760, 1.168518, -0.013647}}],
    Polygon[{{0.694660, 1.167198, -0.013141},{0.696565, 1.166579, -0.012311},{
      0.696872, 1.168518, -0.012311},{0.694869, 1.168518, -0.013141}}],
    Polygon[{{0.696565, 1.166579, -0.012311},{0.698323, 1.166008, -0.011178},{
      0.698721, 1.168518, -0.011178},{0.696872, 1.168518, -0.012311}}],
    Polygon[{{0.698323, 1.166008, -0.011178},{0.699891, 1.165499, -0.009770},{
      0.700369, 1.168518, -0.009770},{0.698721, 1.168518, -0.011178}}],
    Polygon[{{0.699891, 1.165499, -0.009770},{0.701230, 1.165064, -0.008122},{
      0.701777, 1.168518, -0.008122},{0.700369, 1.168518, -0.009770}}],
    Polygon[{{0.701230, 1.165064, -0.008122},{0.702308, 1.164713, -0.006273},{
      0.702910, 1.168518, -0.006273},{0.701777, 1.168518, -0.008122}}],
    Polygon[{{0.702308, 1.164713, -0.006273},{0.703097, 1.164457, -0.004270},{
      0.703740, 1.168518, -0.004270},{0.702910, 1.168518, -0.006273}}],
    Polygon[{{0.703097, 1.164457, -0.004270},{0.703578, 1.164301, -0.002162},{
      0.704246, 1.168518, -0.002162},{0.703740, 1.168518, -0.004270}}],
    Polygon[{{0.703578, 1.164301, -0.002162},{0.703740, 1.164248, 0.000000},{
      0.704416, 1.168518, 0.000000},{0.704246, 1.168518, -0.002162}}],
    Polygon[{{0.703740, 1.164248, 0.000000},{0.703578, 1.164301, 0.002162},{
      0.704246, 1.168518, 0.002162},{0.704416, 1.168518, 0.000000}}],
    Polygon[{{0.703578, 1.164301, 0.002162},{0.703097, 1.164457, 0.004270},{
      0.703740, 1.168518, 0.004270},{0.704246, 1.168518, 0.002162}}],
    Polygon[{{0.703097, 1.164457, 0.004270},{0.702308, 1.164713, 0.006273},{
      0.702910, 1.168518, 0.006273},{0.703740, 1.168518, 0.004270}}],
    Polygon[{{0.702308, 1.164713, 0.006273},{0.701230, 1.165064, 0.008122},{
      0.701777, 1.168518, 0.008122},{0.702910, 1.168518, 0.006273}}],
    Polygon[{{0.701230, 1.165064, 0.008122},{0.699891, 1.165499, 0.009770},{
      0.700369, 1.168518, 0.009770},{0.701777, 1.168518, 0.008122}}],
    Polygon[{{0.699891, 1.165499, 0.009770},{0.698323, 1.166008, 0.011178},{
      0.698721, 1.168518, 0.011178},{0.700369, 1.168518, 0.009770}}],
    Polygon[{{0.698323, 1.166008, 0.011178},{0.696565, 1.166579, 0.012311},{
      0.696872, 1.168518, 0.012311},{0.698721, 1.168518, 0.011178}}],
    Polygon[{{0.696565, 1.166579, 0.012311},{0.694660, 1.167198, 0.013141},{
      0.694869, 1.168518, 0.013141},{0.696872, 1.168518, 0.012311}}],
    Polygon[{{0.694660, 1.167198, 0.013141},{0.692655, 1.167850, 0.013647},{
      0.692760, 1.168518, 0.013647},{0.694869, 1.168518, 0.013141}}],
    Polygon[{{0.746835, 1.109580, -0.012733},{0.748802, 1.109580, -0.012261},{
      0.748607, 1.110811, -0.012261},{0.746737, 1.110203, -0.012733}}],
    Polygon[{{0.748802, 1.109580, -0.012261},{0.750671, 1.109580, -0.011487},{
      0.750385, 1.111388, -0.011487},{0.748607, 1.110811, -0.012261}}],
    Polygon[{{0.750671, 1.109580, -0.011487},{0.752396, 1.109580, -0.010430},{
      0.752025, 1.111921, -0.010430},{0.750385, 1.111388, -0.011487}}],
    Polygon[{{0.752396, 1.109580, -0.010430},{0.753934, 1.109580, -0.009116},{
      0.753488, 1.112396, -0.009116},{0.752025, 1.111921, -0.010430}}],
    Polygon[{{0.753934, 1.109580, -0.009116},{0.755248, 1.109580, -0.007578},{
      0.754738, 1.112803, -0.007578},{0.753488, 1.112396, -0.009116}}],
    Polygon[{{0.755248, 1.109580, -0.007578},{0.756305, 1.109580, -0.005853},{
      0.755743, 1.113129, -0.005853},{0.754738, 1.112803, -0.007578}}],
    Polygon[{{0.756305, 1.109580, -0.005853},{0.757079, 1.109580, -0.003984},{
      0.756479, 1.113368, -0.003984},{0.755743, 1.113129, -0.005853}}],
    Polygon[{{0.757079, 1.109580, -0.003984},{0.757551, 1.109580, -0.002017},{
      0.756928, 1.113514, -0.002017},{0.756479, 1.113368, -0.003984}}],
    Polygon[{{0.757551, 1.109580, -0.002017},{0.757710, 1.109580, 0.000000},{
      0.757079, 1.113563, 0.000000},{0.756928, 1.113514, -0.002017}}],
    Polygon[{{0.757710, 1.109580, 0.000000},{0.757551, 1.109580, 0.002017},{
      0.756928, 1.113514, 0.002017},{0.757079, 1.113563, 0.000000}}],
    Polygon[{{0.757551, 1.109580, 0.002017},{0.757079, 1.109580, 0.003984},{
      0.756479, 1.113368, 0.003984},{0.756928, 1.113514, 0.002017}}],
    Polygon[{{0.757079, 1.109580, 0.003984},{0.756305, 1.109580, 0.005853},{
      0.755743, 1.113129, 0.005853},{0.756479, 1.113368, 0.003984}}],
    Polygon[{{0.756305, 1.109580, 0.005853},{0.755248, 1.109580, 0.007578},{
      0.754738, 1.112803, 0.007578},{0.755743, 1.113129, 0.005853}}],
    Polygon[{{0.755248, 1.109580, 0.007578},{0.753934, 1.109580, 0.009116},{
      0.753488, 1.112396, 0.009116},{0.754738, 1.112803, 0.007578}}],
    Polygon[{{0.753934, 1.109580, 0.009116},{0.752396, 1.109580, 0.010430},{
      0.752025, 1.111921, 0.010430},{0.753488, 1.112396, 0.009116}}],
    Polygon[{{0.752396, 1.109580, 0.010430},{0.750671, 1.109580, 0.011487},{
      0.750385, 1.111388, 0.011487},{0.752025, 1.111921, 0.010430}}],
    Polygon[{{0.750671, 1.109580, 0.011487},{0.748802, 1.109580, 0.012261},{
      0.748607, 1.110811, 0.012261},{0.750385, 1.111388, 0.011487}}],
    Polygon[{{0.748802, 1.109580, 0.012261},{0.746835, 1.109580, 0.012733},{
      0.746737, 1.110203, 0.012733},{0.748607, 1.110811, 0.012261}}],
    Polygon[{{0.746737, 1.110203, -0.012733},{0.748607, 1.110811, -0.012261},{
      0.748041, 1.111921, -0.012261},{0.746450, 1.110765, -0.012733}}],
    Polygon[{{0.748607, 1.110811, -0.012261},{0.750385, 1.111388, -0.011487},{
      0.749553, 1.113020, -0.011487},{0.748041, 1.111921, -0.012261}}],
    Polygon[{{0.750385, 1.111388, -0.011487},{0.752025, 1.111921, -0.010430},{
      0.750949, 1.114034, -0.010430},{0.749553, 1.113020, -0.011487}}],
    Polygon[{{0.752025, 1.111921, -0.010430},{0.753488, 1.112396, -0.009116},{
      0.752193, 1.114938, -0.009116},{0.750949, 1.114034, -0.010430}}],
    Polygon[{{0.753488, 1.112396, -0.009116},{0.754738, 1.112803, -0.007578},{
      0.753256, 1.115710, -0.007578},{0.752193, 1.114938, -0.009116}}],
    Polygon[{{0.754738, 1.112803, -0.007578},{0.755743, 1.113129, -0.005853},{
      0.754111, 1.116331, -0.005853},{0.753256, 1.115710, -0.007578}}],
    Polygon[{{0.755743, 1.113129, -0.005853},{0.756479, 1.113368, -0.003984},{
      0.754738, 1.116786, -0.003984},{0.754111, 1.116331, -0.005853}}],
    Polygon[{{0.756479, 1.113368, -0.003984},{0.756928, 1.113514, -0.002017},{
      0.755120, 1.117064, -0.002017},{0.754738, 1.116786, -0.003984}}],
    Polygon[{{0.756928, 1.113514, -0.002017},{0.757079, 1.113563, 0.000000},{
      0.755248, 1.117157, 0.000000},{0.755120, 1.117064, -0.002017}}],
    Polygon[{{0.757079, 1.113563, 0.000000},{0.756928, 1.113514, 0.002017},{
      0.755120, 1.117064, 0.002017},{0.755248, 1.117157, 0.000000}}],
    Polygon[{{0.756928, 1.113514, 0.002017},{0.756479, 1.113368, 0.003984},{
      0.754738, 1.116786, 0.003984},{0.755120, 1.117064, 0.002017}}],
    Polygon[{{0.756479, 1.113368, 0.003984},{0.755743, 1.113129, 0.005853},{
      0.754111, 1.116331, 0.005853},{0.754738, 1.116786, 0.003984}}],
    Polygon[{{0.755743, 1.113129, 0.005853},{0.754738, 1.112803, 0.007578},{
      0.753256, 1.115710, 0.007578},{0.754111, 1.116331, 0.005853}}],
    Polygon[{{0.754738, 1.112803, 0.007578},{0.753488, 1.112396, 0.009116},{
      0.752193, 1.114938, 0.009116},{0.753256, 1.115710, 0.007578}}],
    Polygon[{{0.753488, 1.112396, 0.009116},{0.752025, 1.111921, 0.010430},{
      0.750949, 1.114034, 0.010430},{0.752193, 1.114938, 0.009116}}],
    Polygon[{{0.752025, 1.111921, 0.010430},{0.750385, 1.111388, 0.011487},{
      0.749553, 1.113020, 0.011487},{0.750949, 1.114034, 0.010430}}],
    Polygon[{{0.750385, 1.111388, 0.011487},{0.748607, 1.110811, 0.012261},{
      0.748041, 1.111921, 0.012261},{0.749553, 1.113020, 0.011487}}],
    Polygon[{{0.748607, 1.110811, 0.012261},{0.746737, 1.110203, 0.012733},{
      0.746450, 1.110765, 0.012733},{0.748041, 1.111921, 0.012261}}],
    Polygon[{{0.746450, 1.110765, -0.012733},{0.748041, 1.111921, -0.012261},{
      0.747160, 1.112803, -0.012261},{0.746004, 1.111211, -0.012733}}],
    Polygon[{{0.748041, 1.111921, -0.012261},{0.749553, 1.113020, -0.011487},{
      0.748259, 1.114314, -0.011487},{0.747160, 1.112803, -0.012261}}],
    Polygon[{{0.749553, 1.113020, -0.011487},{0.750949, 1.114034, -0.010430},{
      0.749272, 1.115710, -0.010430},{0.748259, 1.114314, -0.011487}}],
    Polygon[{{0.750949, 1.114034, -0.010430},{0.752193, 1.114938, -0.009116},{
      0.750177, 1.116954, -0.009116},{0.749272, 1.115710, -0.010430}}],
    Polygon[{{0.752193, 1.114938, -0.009116},{0.753256, 1.115710, -0.007578},{
      0.750949, 1.118017, -0.007578},{0.750177, 1.116954, -0.009116}}],
    Polygon[{{0.753256, 1.115710, -0.007578},{0.754111, 1.116331, -0.005853},{
      0.751570, 1.118872, -0.005853},{0.750949, 1.118017, -0.007578}}],
    Polygon[{{0.754111, 1.116331, -0.005853},{0.754738, 1.116786, -0.003984},{
      0.752025, 1.119499, -0.003984},{0.751570, 1.118872, -0.005853}}],
    Polygon[{{0.754738, 1.116786, -0.003984},{0.755120, 1.117064, -0.002017},{
      0.752303, 1.119881, -0.002017},{0.752025, 1.119499, -0.003984}}],
    Polygon[{{0.755120, 1.117064, -0.002017},{0.755248, 1.117157, 0.000000},{
      0.752396, 1.120009, 0.000000},{0.752303, 1.119881, -0.002017}}],
    Polygon[{{0.755248, 1.117157, 0.000000},{0.755120, 1.117064, 0.002017},{
      0.752303, 1.119881, 0.002017},{0.752396, 1.120009, 0.000000}}],
    Polygon[{{0.755120, 1.117064, 0.002017},{0.754738, 1.116786, 0.003984},{
      0.752025, 1.119499, 0.003984},{0.752303, 1.119881, 0.002017}}],
    Polygon[{{0.754738, 1.116786, 0.003984},{0.754111, 1.116331, 0.005853},{
      0.751570, 1.118872, 0.005853},{0.752025, 1.119499, 0.003984}}],
    Polygon[{{0.754111, 1.116331, 0.005853},{0.753256, 1.115710, 0.007578},{
      0.750949, 1.118017, 0.007578},{0.751570, 1.118872, 0.005853}}],
    Polygon[{{0.753256, 1.115710, 0.007578},{0.752193, 1.114938, 0.009116},{
      0.750177, 1.116954, 0.009116},{0.750949, 1.118017, 0.007578}}],
    Polygon[{{0.752193, 1.114938, 0.009116},{0.750949, 1.114034, 0.010430},{
      0.749272, 1.115710, 0.010430},{0.750177, 1.116954, 0.009116}}],
    Polygon[{{0.750949, 1.114034, 0.010430},{0.749553, 1.113020, 0.011487},{
      0.748259, 1.114314, 0.011487},{0.749272, 1.115710, 0.010430}}],
    Polygon[{{0.749553, 1.113020, 0.011487},{0.748041, 1.111921, 0.012261},{
      0.747160, 1.112803, 0.012261},{0.748259, 1.114314, 0.011487}}],
    Polygon[{{0.748041, 1.111921, 0.012261},{0.746450, 1.110765, 0.012733},{
      0.746004, 1.111211, 0.012733},{0.747160, 1.112803, 0.012261}}],
    Polygon[{{0.746004, 1.111211, -0.012733},{0.747160, 1.112803, -0.012261},{
      0.746050, 1.113368, -0.012261},{0.745442, 1.111498, -0.012733}}],
    Polygon[{{0.747160, 1.112803, -0.012261},{0.748259, 1.114314, -0.011487},{
      0.746627, 1.115146, -0.011487},{0.746050, 1.113368, -0.012261}}],
    Polygon[{{0.748259, 1.114314, -0.011487},{0.749272, 1.115710, -0.010430},{
      0.747160, 1.116786, -0.010430},{0.746627, 1.115146, -0.011487}}],
    Polygon[{{0.749272, 1.115710, -0.010430},{0.750177, 1.116954, -0.009116},{
      0.747635, 1.118249, -0.009116},{0.747160, 1.116786, -0.010430}}],
    Polygon[{{0.750177, 1.116954, -0.009116},{0.750949, 1.118017, -0.007578},{
      0.748041, 1.119499, -0.007578},{0.747635, 1.118249, -0.009116}}],
    Polygon[{{0.750949, 1.118017, -0.007578},{0.751570, 1.118872, -0.005853},{
      0.748368, 1.120504, -0.005853},{0.748041, 1.119499, -0.007578}}],
    Polygon[{{0.751570, 1.118872, -0.005853},{0.752025, 1.119499, -0.003984},{
      0.748607, 1.121240, -0.003984},{0.748368, 1.120504, -0.005853}}],
    Polygon[{{0.752025, 1.119499, -0.003984},{0.752303, 1.119881, -0.002017},{
      0.748753, 1.121689, -0.002017},{0.748607, 1.121240, -0.003984}}],
    Polygon[{{0.752303, 1.119881, -0.002017},{0.752396, 1.120009, 0.000000},{
      0.748802, 1.121840, 0.000000},{0.748753, 1.121689, -0.002017}}],
    Polygon[{{0.752396, 1.120009, 0.000000},{0.752303, 1.119881, 0.002017},{
      0.748753, 1.121689, 0.002017},{0.748802, 1.121840, 0.000000}}],
    Polygon[{{0.752303, 1.119881, 0.002017},{0.752025, 1.119499, 0.003984},{
      0.748607, 1.121240, 0.003984},{0.748753, 1.121689, 0.002017}}],
    Polygon[{{0.752025, 1.119499, 0.003984},{0.751570, 1.118872, 0.005853},{
      0.748368, 1.120504, 0.005853},{0.748607, 1.121240, 0.003984}}],
    Polygon[{{0.751570, 1.118872, 0.005853},{0.750949, 1.118017, 0.007578},{
      0.748041, 1.119499, 0.007578},{0.748368, 1.120504, 0.005853}}],
    Polygon[{{0.750949, 1.118017, 0.007578},{0.750177, 1.116954, 0.009116},{
      0.747635, 1.118249, 0.009116},{0.748041, 1.119499, 0.007578}}],
    Polygon[{{0.750177, 1.116954, 0.009116},{0.749272, 1.115710, 0.010430},{
      0.747160, 1.116786, 0.010430},{0.747635, 1.118249, 0.009116}}],
    Polygon[{{0.749272, 1.115710, 0.010430},{0.748259, 1.114314, 0.011487},{
      0.746627, 1.115146, 0.011487},{0.747160, 1.116786, 0.010430}}],
    Polygon[{{0.748259, 1.114314, 0.011487},{0.747160, 1.112803, 0.012261},{
      0.746050, 1.113368, 0.012261},{0.746627, 1.115146, 0.011487}}],
    Polygon[{{0.747160, 1.112803, 0.012261},{0.746004, 1.111211, 0.012733},{
      0.745442, 1.111498, 0.012733},{0.746050, 1.113368, 0.012261}}],
    Polygon[{{0.745442, 1.111498, -0.012733},{0.746050, 1.113368, -0.012261},{
      0.744819, 1.113563, -0.012261},{0.744819, 1.111596, -0.012733}}],
    Polygon[{{0.746050, 1.113368, -0.012261},{0.746627, 1.115146, -0.011487},{
      0.744819, 1.115432, -0.011487},{0.744819, 1.113563, -0.012261}}],
    Polygon[{{0.746627, 1.115146, -0.011487},{0.747160, 1.116786, -0.010430},{
      0.744819, 1.117157, -0.010430},{0.744819, 1.115432, -0.011487}}],
    Polygon[{{0.747160, 1.116786, -0.010430},{0.747635, 1.118249, -0.009116},{
      0.744819, 1.118695, -0.009116},{0.744819, 1.117157, -0.010430}}],
    Polygon[{{0.747635, 1.118249, -0.009116},{0.748041, 1.119499, -0.007578},{
      0.744819, 1.120009, -0.007578},{0.744819, 1.118695, -0.009116}}],
    Polygon[{{0.748041, 1.119499, -0.007578},{0.748368, 1.120504, -0.005853},{
      0.744819, 1.121066, -0.005853},{0.744819, 1.120009, -0.007578}}],
    Polygon[{{0.748368, 1.120504, -0.005853},{0.748607, 1.121240, -0.003984},{
      0.744819, 1.121840, -0.003984},{0.744819, 1.121066, -0.005853}}],
    Polygon[{{0.748607, 1.121240, -0.003984},{0.748753, 1.121689, -0.002017},{
      0.744819, 1.122313, -0.002017},{0.744819, 1.121840, -0.003984}}],
    Polygon[{{0.748753, 1.121689, -0.002017},{0.748802, 1.121840, 0.000000},{
      0.744819, 1.122471, 0.000000},{0.744819, 1.122313, -0.002017}}],
    Polygon[{{0.748802, 1.121840, 0.000000},{0.748753, 1.121689, 0.002017},{
      0.744819, 1.122313, 0.002017},{0.744819, 1.122471, 0.000000}}],
    Polygon[{{0.748753, 1.121689, 0.002017},{0.748607, 1.121240, 0.003984},{
      0.744819, 1.121840, 0.003984},{0.744819, 1.122313, 0.002017}}],
    Polygon[{{0.748607, 1.121240, 0.003984},{0.748368, 1.120504, 0.005853},{
      0.744819, 1.121066, 0.005853},{0.744819, 1.121840, 0.003984}}],
    Polygon[{{0.748368, 1.120504, 0.005853},{0.748041, 1.119499, 0.007578},{
      0.744819, 1.120009, 0.007578},{0.744819, 1.121066, 0.005853}}],
    Polygon[{{0.748041, 1.119499, 0.007578},{0.747635, 1.118249, 0.009116},{
      0.744819, 1.118695, 0.009116},{0.744819, 1.120009, 0.007578}}],
    Polygon[{{0.747635, 1.118249, 0.009116},{0.747160, 1.116786, 0.010430},{
      0.744819, 1.117157, 0.010430},{0.744819, 1.118695, 0.009116}}],
    Polygon[{{0.747160, 1.116786, 0.010430},{0.746627, 1.115146, 0.011487},{
      0.744819, 1.115432, 0.011487},{0.744819, 1.117157, 0.010430}}],
    Polygon[{{0.746627, 1.115146, 0.011487},{0.746050, 1.113368, 0.012261},{
      0.744819, 1.113563, 0.012261},{0.744819, 1.115432, 0.011487}}],
    Polygon[{{0.746050, 1.113368, 0.012261},{0.745442, 1.111498, 0.012733},{
      0.744819, 1.111596, 0.012733},{0.744819, 1.113563, 0.012261}}],
    Polygon[{{0.744819, 1.111596, -0.012733},{0.744819, 1.113563, -0.012261},{
      0.743587, 1.113368, -0.012261},{0.744195, 1.111498, -0.012733}}],
    Polygon[{{0.744819, 1.113563, -0.012261},{0.744819, 1.115432, -0.011487},{
      0.743010, 1.115146, -0.011487},{0.743587, 1.113368, -0.012261}}],
    Polygon[{{0.744819, 1.115432, -0.011487},{0.744819, 1.117157, -0.010430},{
      0.742477, 1.116786, -0.010430},{0.743010, 1.115146, -0.011487}}],
    Polygon[{{0.744819, 1.117157, -0.010430},{0.744819, 1.118695, -0.009116},{
      0.742002, 1.118249, -0.009116},{0.742477, 1.116786, -0.010430}}],
    Polygon[{{0.744819, 1.118695, -0.009116},{0.744819, 1.120009, -0.007578},{
      0.741596, 1.119499, -0.007578},{0.742002, 1.118249, -0.009116}}],
    Polygon[{{0.744819, 1.120009, -0.007578},{0.744819, 1.121066, -0.005853},{
      0.741269, 1.120504, -0.005853},{0.741596, 1.119499, -0.007578}}],
    Polygon[{{0.744819, 1.121066, -0.005853},{0.744819, 1.121840, -0.003984},{
      0.741030, 1.121240, -0.003984},{0.741269, 1.120504, -0.005853}}],
    Polygon[{{0.744819, 1.121840, -0.003984},{0.744819, 1.122313, -0.002017},{
      0.740884, 1.121689, -0.002017},{0.741030, 1.121240, -0.003984}}],
    Polygon[{{0.744819, 1.122313, -0.002017},{0.744819, 1.122471, 0.000000},{
      0.740835, 1.121840, 0.000000},{0.740884, 1.121689, -0.002017}}],
    Polygon[{{0.744819, 1.122471, 0.000000},{0.744819, 1.122313, 0.002017},{
      0.740884, 1.121689, 0.002017},{0.740835, 1.121840, 0.000000}}],
    Polygon[{{0.744819, 1.122313, 0.002017},{0.744819, 1.121840, 0.003984},{
      0.741030, 1.121240, 0.003984},{0.740884, 1.121689, 0.002017}}],
    Polygon[{{0.744819, 1.121840, 0.003984},{0.744819, 1.121066, 0.005853},{
      0.741269, 1.120504, 0.005853},{0.741030, 1.121240, 0.003984}}],
    Polygon[{{0.744819, 1.121066, 0.005853},{0.744819, 1.120009, 0.007578},{
      0.741596, 1.119499, 0.007578},{0.741269, 1.120504, 0.005853}}],
    Polygon[{{0.744819, 1.120009, 0.007578},{0.744819, 1.118695, 0.009116},{
      0.742002, 1.118249, 0.009116},{0.741596, 1.119499, 0.007578}}],
    Polygon[{{0.744819, 1.118695, 0.009116},{0.744819, 1.117157, 0.010430},{
      0.742477, 1.116786, 0.010430},{0.742002, 1.118249, 0.009116}}],
    Polygon[{{0.744819, 1.117157, 0.010430},{0.744819, 1.115432, 0.011487},{
      0.743010, 1.115146, 0.011487},{0.742477, 1.116786, 0.010430}}],
    Polygon[{{0.744819, 1.115432, 0.011487},{0.744819, 1.113563, 0.012261},{
      0.743587, 1.113368, 0.012261},{0.743010, 1.115146, 0.011487}}],
    Polygon[{{0.744819, 1.113563, 0.012261},{0.744819, 1.111596, 0.012733},{
      0.744195, 1.111498, 0.012733},{0.743587, 1.113368, 0.012261}}],
    Polygon[{{0.744195, 1.111498, -0.012733},{0.743587, 1.113368, -0.012261},{
      0.742477, 1.112803, -0.012261},{0.743633, 1.111211, -0.012733}}],
    Polygon[{{0.743587, 1.113368, -0.012261},{0.743010, 1.115146, -0.011487},{
      0.741378, 1.114314, -0.011487},{0.742477, 1.112803, -0.012261}}],
    Polygon[{{0.743010, 1.115146, -0.011487},{0.742477, 1.116786, -0.010430},{
      0.740365, 1.115710, -0.010430},{0.741378, 1.114314, -0.011487}}],
    Polygon[{{0.742477, 1.116786, -0.010430},{0.742002, 1.118249, -0.009116},{
      0.739460, 1.116954, -0.009116},{0.740365, 1.115710, -0.010430}}],
    Polygon[{{0.742002, 1.118249, -0.009116},{0.741596, 1.119499, -0.007578},{
      0.738688, 1.118017, -0.007578},{0.739460, 1.116954, -0.009116}}],
    Polygon[{{0.741596, 1.119499, -0.007578},{0.741269, 1.120504, -0.005853},{
      0.738067, 1.118872, -0.005853},{0.738688, 1.118017, -0.007578}}],
    Polygon[{{0.741269, 1.120504, -0.005853},{0.741030, 1.121240, -0.003984},{
      0.737612, 1.119499, -0.003984},{0.738067, 1.118872, -0.005853}}],
    Polygon[{{0.741030, 1.121240, -0.003984},{0.740884, 1.121689, -0.002017},{
      0.737334, 1.119881, -0.002017},{0.737612, 1.119499, -0.003984}}],
    Polygon[{{0.740884, 1.121689, -0.002017},{0.740835, 1.121840, 0.000000},{
      0.737241, 1.120009, 0.000000},{0.737334, 1.119881, -0.002017}}],
    Polygon[{{0.740835, 1.121840, 0.000000},{0.740884, 1.121689, 0.002017},{
      0.737334, 1.119881, 0.002017},{0.737241, 1.120009, 0.000000}}],
    Polygon[{{0.740884, 1.121689, 0.002017},{0.741030, 1.121240, 0.003984},{
      0.737612, 1.119499, 0.003984},{0.737334, 1.119881, 0.002017}}],
    Polygon[{{0.741030, 1.121240, 0.003984},{0.741269, 1.120504, 0.005853},{
      0.738067, 1.118872, 0.005853},{0.737612, 1.119499, 0.003984}}],
    Polygon[{{0.741269, 1.120504, 0.005853},{0.741596, 1.119499, 0.007578},{
      0.738688, 1.118017, 0.007578},{0.738067, 1.118872, 0.005853}}],
    Polygon[{{0.741596, 1.119499, 0.007578},{0.742002, 1.118249, 0.009116},{
      0.739460, 1.116954, 0.009116},{0.738688, 1.118017, 0.007578}}],
    Polygon[{{0.742002, 1.118249, 0.009116},{0.742477, 1.116786, 0.010430},{
      0.740365, 1.115710, 0.010430},{0.739460, 1.116954, 0.009116}}],
    Polygon[{{0.742477, 1.116786, 0.010430},{0.743010, 1.115146, 0.011487},{
      0.741378, 1.114314, 0.011487},{0.740365, 1.115710, 0.010430}}],
    Polygon[{{0.743010, 1.115146, 0.011487},{0.743587, 1.113368, 0.012261},{
      0.742477, 1.112803, 0.012261},{0.741378, 1.114314, 0.011487}}],
    Polygon[{{0.743587, 1.113368, 0.012261},{0.744195, 1.111498, 0.012733},{
      0.743633, 1.111211, 0.012733},{0.742477, 1.112803, 0.012261}}],
    Polygon[{{0.743633, 1.111211, -0.012733},{0.742477, 1.112803, -0.012261},{
      0.741596, 1.111921, -0.012261},{0.743187, 1.110765, -0.012733}}],
    Polygon[{{0.742477, 1.112803, -0.012261},{0.741378, 1.114314, -0.011487},{
      0.740084, 1.113020, -0.011487},{0.741596, 1.111921, -0.012261}}],
    Polygon[{{0.741378, 1.114314, -0.011487},{0.740365, 1.115710, -0.010430},{
      0.738688, 1.114034, -0.010430},{0.740084, 1.113020, -0.011487}}],
    Polygon[{{0.740365, 1.115710, -0.010430},{0.739460, 1.116954, -0.009116},{
      0.737444, 1.114938, -0.009116},{0.738688, 1.114034, -0.010430}}],
    Polygon[{{0.739460, 1.116954, -0.009116},{0.738688, 1.118017, -0.007578},{
      0.736381, 1.115710, -0.007578},{0.737444, 1.114938, -0.009116}}],
    Polygon[{{0.738688, 1.118017, -0.007578},{0.738067, 1.118872, -0.005853},{
      0.735526, 1.116331, -0.005853},{0.736381, 1.115710, -0.007578}}],
    Polygon[{{0.738067, 1.118872, -0.005853},{0.737612, 1.119499, -0.003984},{
      0.734899, 1.116786, -0.003984},{0.735526, 1.116331, -0.005853}}],
    Polygon[{{0.737612, 1.119499, -0.003984},{0.737334, 1.119881, -0.002017},{
      0.734517, 1.117064, -0.002017},{0.734899, 1.116786, -0.003984}}],
    Polygon[{{0.737334, 1.119881, -0.002017},{0.737241, 1.120009, 0.000000},{
      0.734389, 1.117157, 0.000000},{0.734517, 1.117064, -0.002017}}],
    Polygon[{{0.737241, 1.120009, 0.000000},{0.737334, 1.119881, 0.002017},{
      0.734517, 1.117064, 0.002017},{0.734389, 1.117157, 0.000000}}],
    Polygon[{{0.737334, 1.119881, 0.002017},{0.737612, 1.119499, 0.003984},{
      0.734899, 1.116786, 0.003984},{0.734517, 1.117064, 0.002017}}],
    Polygon[{{0.737612, 1.119499, 0.003984},{0.738067, 1.118872, 0.005853},{
      0.735526, 1.116331, 0.005853},{0.734899, 1.116786, 0.003984}}],
    Polygon[{{0.738067, 1.118872, 0.005853},{0.738688, 1.118017, 0.007578},{
      0.736381, 1.115710, 0.007578},{0.735526, 1.116331, 0.005853}}],
    Polygon[{{0.738688, 1.118017, 0.007578},{0.739460, 1.116954, 0.009116},{
      0.737444, 1.114938, 0.009116},{0.736381, 1.115710, 0.007578}}],
    Polygon[{{0.739460, 1.116954, 0.009116},{0.740365, 1.115710, 0.010430},{
      0.738688, 1.114034, 0.010430},{0.737444, 1.114938, 0.009116}}],
    Polygon[{{0.740365, 1.115710, 0.010430},{0.741378, 1.114314, 0.011487},{
      0.740084, 1.113020, 0.011487},{0.738688, 1.114034, 0.010430}}],
    Polygon[{{0.741378, 1.114314, 0.011487},{0.742477, 1.112803, 0.012261},{
      0.741596, 1.111921, 0.012261},{0.740084, 1.113020, 0.011487}}],
    Polygon[{{0.742477, 1.112803, 0.012261},{0.743633, 1.111211, 0.012733},{
      0.743187, 1.110765, 0.012733},{0.741596, 1.111921, 0.012261}}],
    Polygon[{{0.743187, 1.110765, -0.012733},{0.741596, 1.111921, -0.012261},{
      0.741030, 1.110811, -0.012261},{0.742900, 1.110203, -0.012733}}],
    Polygon[{{0.741596, 1.111921, -0.012261},{0.740084, 1.113020, -0.011487},{
      0.739252, 1.111388, -0.011487},{0.741030, 1.110811, -0.012261}}],
    Polygon[{{0.740084, 1.113020, -0.011487},{0.738688, 1.114034, -0.010430},{
      0.737612, 1.111921, -0.010430},{0.739252, 1.111388, -0.011487}}],
    Polygon[{{0.738688, 1.114034, -0.010430},{0.737444, 1.114938, -0.009116},{
      0.736149, 1.112396, -0.009116},{0.737612, 1.111921, -0.010430}}],
    Polygon[{{0.737444, 1.114938, -0.009116},{0.736381, 1.115710, -0.007578},{
      0.734899, 1.112803, -0.007578},{0.736149, 1.112396, -0.009116}}],
    Polygon[{{0.736381, 1.115710, -0.007578},{0.735526, 1.116331, -0.005853},{
      0.733894, 1.113129, -0.005853},{0.734899, 1.112803, -0.007578}}],
    Polygon[{{0.735526, 1.116331, -0.005853},{0.734899, 1.116786, -0.003984},{
      0.733158, 1.113368, -0.003984},{0.733894, 1.113129, -0.005853}}],
    Polygon[{{0.734899, 1.116786, -0.003984},{0.734517, 1.117064, -0.002017},{
      0.732709, 1.113514, -0.002017},{0.733158, 1.113368, -0.003984}}],
    Polygon[{{0.734517, 1.117064, -0.002017},{0.734389, 1.117157, 0.000000},{
      0.732558, 1.113563, 0.000000},{0.732709, 1.113514, -0.002017}}],
    Polygon[{{0.734389, 1.117157, 0.000000},{0.734517, 1.117064, 0.002017},{
      0.732709, 1.113514, 0.002017},{0.732558, 1.113563, 0.000000}}],
    Polygon[{{0.734517, 1.117064, 0.002017},{0.734899, 1.116786, 0.003984},{
      0.733158, 1.113368, 0.003984},{0.732709, 1.113514, 0.002017}}],
    Polygon[{{0.734899, 1.116786, 0.003984},{0.735526, 1.116331, 0.005853},{
      0.733894, 1.113129, 0.005853},{0.733158, 1.113368, 0.003984}}],
    Polygon[{{0.735526, 1.116331, 0.005853},{0.736381, 1.115710, 0.007578},{
      0.734899, 1.112803, 0.007578},{0.733894, 1.113129, 0.005853}}],
    Polygon[{{0.736381, 1.115710, 0.007578},{0.737444, 1.114938, 0.009116},{
      0.736149, 1.112396, 0.009116},{0.734899, 1.112803, 0.007578}}],
    Polygon[{{0.737444, 1.114938, 0.009116},{0.738688, 1.114034, 0.010430},{
      0.737612, 1.111921, 0.010430},{0.736149, 1.112396, 0.009116}}],
    Polygon[{{0.738688, 1.114034, 0.010430},{0.740084, 1.113020, 0.011487},{
      0.739252, 1.111388, 0.011487},{0.737612, 1.111921, 0.010430}}],
    Polygon[{{0.740084, 1.113020, 0.011487},{0.741596, 1.111921, 0.012261},{
      0.741030, 1.110811, 0.012261},{0.739252, 1.111388, 0.011487}}],
    Polygon[{{0.741596, 1.111921, 0.012261},{0.743187, 1.110765, 0.012733},{
      0.742900, 1.110203, 0.012733},{0.741030, 1.110811, 0.012261}}],
    Polygon[{{0.742900, 1.110203, -0.012733},{0.741030, 1.110811, -0.012261},{
      0.740835, 1.109580, -0.012261},{0.742802, 1.109580, -0.012733}}],
    Polygon[{{0.741030, 1.110811, -0.012261},{0.739252, 1.111388, -0.011487},{
      0.738966, 1.109580, -0.011487},{0.740835, 1.109580, -0.012261}}],
    Polygon[{{0.739252, 1.111388, -0.011487},{0.737612, 1.111921, -0.010430},{
      0.737241, 1.109580, -0.010430},{0.738966, 1.109580, -0.011487}}],
    Polygon[{{0.737612, 1.111921, -0.010430},{0.736149, 1.112396, -0.009116},{
      0.735703, 1.109580, -0.009116},{0.737241, 1.109580, -0.010430}}],
    Polygon[{{0.736149, 1.112396, -0.009116},{0.734899, 1.112803, -0.007578},{
      0.734389, 1.109580, -0.007578},{0.735703, 1.109580, -0.009116}}],
    Polygon[{{0.734899, 1.112803, -0.007578},{0.733894, 1.113129, -0.005853},{
      0.733332, 1.109580, -0.005853},{0.734389, 1.109580, -0.007578}}],
    Polygon[{{0.733894, 1.113129, -0.005853},{0.733158, 1.113368, -0.003984},{
      0.732558, 1.109580, -0.003984},{0.733332, 1.109580, -0.005853}}],
    Polygon[{{0.733158, 1.113368, -0.003984},{0.732709, 1.113514, -0.002017},{
      0.732086, 1.109580, -0.002017},{0.732558, 1.109580, -0.003984}}],
    Polygon[{{0.732709, 1.113514, -0.002017},{0.732558, 1.113563, 0.000000},{
      0.731927, 1.109580, 0.000000},{0.732086, 1.109580, -0.002017}}],
    Polygon[{{0.732558, 1.113563, 0.000000},{0.732709, 1.113514, 0.002017},{
      0.732086, 1.109580, 0.002017},{0.731927, 1.109580, 0.000000}}],
    Polygon[{{0.732709, 1.113514, 0.002017},{0.733158, 1.113368, 0.003984},{
      0.732558, 1.109580, 0.003984},{0.732086, 1.109580, 0.002017}}],
    Polygon[{{0.733158, 1.113368, 0.003984},{0.733894, 1.113129, 0.005853},{
      0.733332, 1.109580, 0.005853},{0.732558, 1.109580, 0.003984}}],
    Polygon[{{0.733894, 1.113129, 0.005853},{0.734899, 1.112803, 0.007578},{
      0.734389, 1.109580, 0.007578},{0.733332, 1.109580, 0.005853}}],
    Polygon[{{0.734899, 1.112803, 0.007578},{0.736149, 1.112396, 0.009116},{
      0.735703, 1.109580, 0.009116},{0.734389, 1.109580, 0.007578}}],
    Polygon[{{0.736149, 1.112396, 0.009116},{0.737612, 1.111921, 0.010430},{
      0.737241, 1.109580, 0.010430},{0.735703, 1.109580, 0.009116}}],
    Polygon[{{0.737612, 1.111921, 0.010430},{0.739252, 1.111388, 0.011487},{
      0.738966, 1.109580, 0.011487},{0.737241, 1.109580, 0.010430}}],
    Polygon[{{0.739252, 1.111388, 0.011487},{0.741030, 1.110811, 0.012261},{
      0.740835, 1.109580, 0.012261},{0.738966, 1.109580, 0.011487}}],
    Polygon[{{0.741030, 1.110811, 0.012261},{0.742900, 1.110203, 0.012733},{
      0.742802, 1.109580, 0.012733},{0.740835, 1.109580, 0.012261}}],
    Polygon[{{0.742802, 1.109580, -0.012733},{0.740835, 1.109580, -0.012261},{
      0.741030, 1.108348, -0.012261},{0.742900, 1.108956, -0.012733}}],
    Polygon[{{0.740835, 1.109580, -0.012261},{0.738966, 1.109580, -0.011487},{
      0.739252, 1.107771, -0.011487},{0.741030, 1.108348, -0.012261}}],
    Polygon[{{0.738966, 1.109580, -0.011487},{0.737241, 1.109580, -0.010430},{
      0.737612, 1.107238, -0.010430},{0.739252, 1.107771, -0.011487}}],
    Polygon[{{0.737241, 1.109580, -0.010430},{0.735703, 1.109580, -0.009116},{
      0.736149, 1.106763, -0.009116},{0.737612, 1.107238, -0.010430}}],
    Polygon[{{0.735703, 1.109580, -0.009116},{0.734389, 1.109580, -0.007578},{
      0.734899, 1.106357, -0.007578},{0.736149, 1.106763, -0.009116}}],
    Polygon[{{0.734389, 1.109580, -0.007578},{0.733332, 1.109580, -0.005853},{
      0.733894, 1.106030, -0.005853},{0.734899, 1.106357, -0.007578}}],
    Polygon[{{0.733332, 1.109580, -0.005853},{0.732558, 1.109580, -0.003984},{
      0.733158, 1.105791, -0.003984},{0.733894, 1.106030, -0.005853}}],
    Polygon[{{0.732558, 1.109580, -0.003984},{0.732086, 1.109580, -0.002017},{
      0.732709, 1.105645, -0.002017},{0.733158, 1.105791, -0.003984}}],
    Polygon[{{0.732086, 1.109580, -0.002017},{0.731927, 1.109580, 0.000000},{
      0.732558, 1.105596, 0.000000},{0.732709, 1.105645, -0.002017}}],
    Polygon[{{0.731927, 1.109580, 0.000000},{0.732086, 1.109580, 0.002017},{
      0.732709, 1.105645, 0.002017},{0.732558, 1.105596, 0.000000}}],
    Polygon[{{0.732086, 1.109580, 0.002017},{0.732558, 1.109580, 0.003984},{
      0.733158, 1.105791, 0.003984},{0.732709, 1.105645, 0.002017}}],
    Polygon[{{0.732558, 1.109580, 0.003984},{0.733332, 1.109580, 0.005853},{
      0.733894, 1.106030, 0.005853},{0.733158, 1.105791, 0.003984}}],
    Polygon[{{0.733332, 1.109580, 0.005853},{0.734389, 1.109580, 0.007578},{
      0.734899, 1.106357, 0.007578},{0.733894, 1.106030, 0.005853}}],
    Polygon[{{0.734389, 1.109580, 0.007578},{0.735703, 1.109580, 0.009116},{
      0.736149, 1.106763, 0.009116},{0.734899, 1.106357, 0.007578}}],
    Polygon[{{0.735703, 1.109580, 0.009116},{0.737241, 1.109580, 0.010430},{
      0.737612, 1.107238, 0.010430},{0.736149, 1.106763, 0.009116}}],
    Polygon[{{0.737241, 1.109580, 0.010430},{0.738966, 1.109580, 0.011487},{
      0.739252, 1.107771, 0.011487},{0.737612, 1.107238, 0.010430}}],
    Polygon[{{0.738966, 1.109580, 0.011487},{0.740835, 1.109580, 0.012261},{
      0.741030, 1.108348, 0.012261},{0.739252, 1.107771, 0.011487}}],
    Polygon[{{0.740835, 1.109580, 0.012261},{0.742802, 1.109580, 0.012733},{
      0.742900, 1.108956, 0.012733},{0.741030, 1.108348, 0.012261}}],
    Polygon[{{0.742900, 1.108956, -0.012733},{0.741030, 1.108348, -0.012261},{
      0.741596, 1.107238, -0.012261},{0.743187, 1.108394, -0.012733}}],
    Polygon[{{0.741030, 1.108348, -0.012261},{0.739252, 1.107771, -0.011487},{
      0.740084, 1.106139, -0.011487},{0.741596, 1.107238, -0.012261}}],
    Polygon[{{0.739252, 1.107771, -0.011487},{0.737612, 1.107238, -0.010430},{
      0.738688, 1.105126, -0.010430},{0.740084, 1.106139, -0.011487}}],
    Polygon[{{0.737612, 1.107238, -0.010430},{0.736149, 1.106763, -0.009116},{
      0.737444, 1.104221, -0.009116},{0.738688, 1.105126, -0.010430}}],
    Polygon[{{0.736149, 1.106763, -0.009116},{0.734899, 1.106357, -0.007578},{
      0.736381, 1.103449, -0.007578},{0.737444, 1.104221, -0.009116}}],
    Polygon[{{0.734899, 1.106357, -0.007578},{0.733894, 1.106030, -0.005853},{
      0.735526, 1.102828, -0.005853},{0.736381, 1.103449, -0.007578}}],
    Polygon[{{0.733894, 1.106030, -0.005853},{0.733158, 1.105791, -0.003984},{
      0.734899, 1.102373, -0.003984},{0.735526, 1.102828, -0.005853}}],
    Polygon[{{0.733158, 1.105791, -0.003984},{0.732709, 1.105645, -0.002017},{
      0.734517, 1.102095, -0.002017},{0.734899, 1.102373, -0.003984}}],
    Polygon[{{0.732709, 1.105645, -0.002017},{0.732558, 1.105596, 0.000000},{
      0.734389, 1.102002, 0.000000},{0.734517, 1.102095, -0.002017}}],
    Polygon[{{0.732558, 1.105596, 0.000000},{0.732709, 1.105645, 0.002017},{
      0.734517, 1.102095, 0.002017},{0.734389, 1.102002, 0.000000}}],
    Polygon[{{0.732709, 1.105645, 0.002017},{0.733158, 1.105791, 0.003984},{
      0.734899, 1.102373, 0.003984},{0.734517, 1.102095, 0.002017}}],
    Polygon[{{0.733158, 1.105791, 0.003984},{0.733894, 1.106030, 0.005853},{
      0.735526, 1.102828, 0.005853},{0.734899, 1.102373, 0.003984}}],
    Polygon[{{0.733894, 1.106030, 0.005853},{0.734899, 1.106357, 0.007578},{
      0.736381, 1.103449, 0.007578},{0.735526, 1.102828, 0.005853}}],
    Polygon[{{0.734899, 1.106357, 0.007578},{0.736149, 1.106763, 0.009116},{
      0.737444, 1.104221, 0.009116},{0.736381, 1.103449, 0.007578}}],
    Polygon[{{0.736149, 1.106763, 0.009116},{0.737612, 1.107238, 0.010430},{
      0.738688, 1.105126, 0.010430},{0.737444, 1.104221, 0.009116}}],
    Polygon[{{0.737612, 1.107238, 0.010430},{0.739252, 1.107771, 0.011487},{
      0.740084, 1.106139, 0.011487},{0.738688, 1.105126, 0.010430}}],
    Polygon[{{0.739252, 1.107771, 0.011487},{0.741030, 1.108348, 0.012261},{
      0.741596, 1.107238, 0.012261},{0.740084, 1.106139, 0.011487}}],
    Polygon[{{0.741030, 1.108348, 0.012261},{0.742900, 1.108956, 0.012733},{
      0.743187, 1.108394, 0.012733},{0.741596, 1.107238, 0.012261}}],
    Polygon[{{0.743187, 1.108394, -0.012733},{0.741596, 1.107238, -0.012261},{
      0.742477, 1.106357, -0.012261},{0.743633, 1.107948, -0.012733}}],
    Polygon[{{0.741596, 1.107238, -0.012261},{0.740084, 1.106139, -0.011487},{
      0.741378, 1.104845, -0.011487},{0.742477, 1.106357, -0.012261}}],
    Polygon[{{0.740084, 1.106139, -0.011487},{0.738688, 1.105126, -0.010430},{
      0.740365, 1.103449, -0.010430},{0.741378, 1.104845, -0.011487}}],
    Polygon[{{0.738688, 1.105126, -0.010430},{0.737444, 1.104221, -0.009116},{
      0.739460, 1.102205, -0.009116},{0.740365, 1.103449, -0.010430}}],
    Polygon[{{0.737444, 1.104221, -0.009116},{0.736381, 1.103449, -0.007578},{
      0.738688, 1.101142, -0.007578},{0.739460, 1.102205, -0.009116}}],
    Polygon[{{0.736381, 1.103449, -0.007578},{0.735526, 1.102828, -0.005853},{
      0.738067, 1.100287, -0.005853},{0.738688, 1.101142, -0.007578}}],
    Polygon[{{0.735526, 1.102828, -0.005853},{0.734899, 1.102373, -0.003984},{
      0.737612, 1.099660, -0.003984},{0.738067, 1.100287, -0.005853}}],
    Polygon[{{0.734899, 1.102373, -0.003984},{0.734517, 1.102095, -0.002017},{
      0.737334, 1.099278, -0.002017},{0.737612, 1.099660, -0.003984}}],
    Polygon[{{0.734517, 1.102095, -0.002017},{0.734389, 1.102002, 0.000000},{
      0.737241, 1.099150, 0.000000},{0.737334, 1.099278, -0.002017}}],
    Polygon[{{0.734389, 1.102002, 0.000000},{0.734517, 1.102095, 0.002017},{
      0.737334, 1.099278, 0.002017},{0.737241, 1.099150, 0.000000}}],
    Polygon[{{0.734517, 1.102095, 0.002017},{0.734899, 1.102373, 0.003984},{
      0.737612, 1.099660, 0.003984},{0.737334, 1.099278, 0.002017}}],
    Polygon[{{0.734899, 1.102373, 0.003984},{0.735526, 1.102828, 0.005853},{
      0.738067, 1.100287, 0.005853},{0.737612, 1.099660, 0.003984}}],
    Polygon[{{0.735526, 1.102828, 0.005853},{0.736381, 1.103449, 0.007578},{
      0.738688, 1.101142, 0.007578},{0.738067, 1.100287, 0.005853}}],
    Polygon[{{0.736381, 1.103449, 0.007578},{0.737444, 1.104221, 0.009116},{
      0.739460, 1.102205, 0.009116},{0.738688, 1.101142, 0.007578}}],
    Polygon[{{0.737444, 1.104221, 0.009116},{0.738688, 1.105126, 0.010430},{
      0.740365, 1.103449, 0.010430},{0.739460, 1.102205, 0.009116}}],
    Polygon[{{0.738688, 1.105126, 0.010430},{0.740084, 1.106139, 0.011487},{
      0.741378, 1.104845, 0.011487},{0.740365, 1.103449, 0.010430}}],
    Polygon[{{0.740084, 1.106139, 0.011487},{0.741596, 1.107238, 0.012261},{
      0.742477, 1.106357, 0.012261},{0.741378, 1.104845, 0.011487}}],
    Polygon[{{0.741596, 1.107238, 0.012261},{0.743187, 1.108394, 0.012733},{
      0.743633, 1.107948, 0.012733},{0.742477, 1.106357, 0.012261}}],
    Polygon[{{0.743633, 1.107948, -0.012733},{0.742477, 1.106357, -0.012261},{
      0.743587, 1.105791, -0.012261},{0.744195, 1.107661, -0.012733}}],
    Polygon[{{0.742477, 1.106357, -0.012261},{0.741378, 1.104845, -0.011487},{
      0.743010, 1.104013, -0.011487},{0.743587, 1.105791, -0.012261}}],
    Polygon[{{0.741378, 1.104845, -0.011487},{0.740365, 1.103449, -0.010430},{
      0.742477, 1.102373, -0.010430},{0.743010, 1.104013, -0.011487}}],
    Polygon[{{0.740365, 1.103449, -0.010430},{0.739460, 1.102205, -0.009116},{
      0.742002, 1.100910, -0.009116},{0.742477, 1.102373, -0.010430}}],
    Polygon[{{0.739460, 1.102205, -0.009116},{0.738688, 1.101142, -0.007578},{
      0.741596, 1.099660, -0.007578},{0.742002, 1.100910, -0.009116}}],
    Polygon[{{0.738688, 1.101142, -0.007578},{0.738067, 1.100287, -0.005853},{
      0.741269, 1.098655, -0.005853},{0.741596, 1.099660, -0.007578}}],
    Polygon[{{0.738067, 1.100287, -0.005853},{0.737612, 1.099660, -0.003984},{
      0.741030, 1.097919, -0.003984},{0.741269, 1.098655, -0.005853}}],
    Polygon[{{0.737612, 1.099660, -0.003984},{0.737334, 1.099278, -0.002017},{
      0.740884, 1.097470, -0.002017},{0.741030, 1.097919, -0.003984}}],
    Polygon[{{0.737334, 1.099278, -0.002017},{0.737241, 1.099150, 0.000000},{
      0.740835, 1.097319, 0.000000},{0.740884, 1.097470, -0.002017}}],
    Polygon[{{0.737241, 1.099150, 0.000000},{0.737334, 1.099278, 0.002017},{
      0.740884, 1.097470, 0.002017},{0.740835, 1.097319, 0.000000}}],
    Polygon[{{0.737334, 1.099278, 0.002017},{0.737612, 1.099660, 0.003984},{
      0.741030, 1.097919, 0.003984},{0.740884, 1.097470, 0.002017}}],
    Polygon[{{0.737612, 1.099660, 0.003984},{0.738067, 1.100287, 0.005853},{
      0.741269, 1.098655, 0.005853},{0.741030, 1.097919, 0.003984}}],
    Polygon[{{0.738067, 1.100287, 0.005853},{0.738688, 1.101142, 0.007578},{
      0.741596, 1.099660, 0.007578},{0.741269, 1.098655, 0.005853}}],
    Polygon[{{0.738688, 1.101142, 0.007578},{0.739460, 1.102205, 0.009116},{
      0.742002, 1.100910, 0.009116},{0.741596, 1.099660, 0.007578}}],
    Polygon[{{0.739460, 1.102205, 0.009116},{0.740365, 1.103449, 0.010430},{
      0.742477, 1.102373, 0.010430},{0.742002, 1.100910, 0.009116}}],
    Polygon[{{0.740365, 1.103449, 0.010430},{0.741378, 1.104845, 0.011487},{
      0.743010, 1.104013, 0.011487},{0.742477, 1.102373, 0.010430}}],
    Polygon[{{0.741378, 1.104845, 0.011487},{0.742477, 1.106357, 0.012261},{
      0.743587, 1.105791, 0.012261},{0.743010, 1.104013, 0.011487}}],
    Polygon[{{0.742477, 1.106357, 0.012261},{0.743633, 1.107948, 0.012733},{
      0.744195, 1.107661, 0.012733},{0.743587, 1.105791, 0.012261}}],
    Polygon[{{0.744195, 1.107661, -0.012733},{0.743587, 1.105791, -0.012261},{
      0.744819, 1.105596, -0.012261},{0.744819, 1.107563, -0.012733}}],
    Polygon[{{0.743587, 1.105791, -0.012261},{0.743010, 1.104013, -0.011487},{
      0.744819, 1.103727, -0.011487},{0.744819, 1.105596, -0.012261}}],
    Polygon[{{0.743010, 1.104013, -0.011487},{0.742477, 1.102373, -0.010430},{
      0.744819, 1.102002, -0.010430},{0.744819, 1.103727, -0.011487}}],
    Polygon[{{0.742477, 1.102373, -0.010430},{0.742002, 1.100910, -0.009116},{
      0.744819, 1.100464, -0.009116},{0.744819, 1.102002, -0.010430}}],
    Polygon[{{0.742002, 1.100910, -0.009116},{0.741596, 1.099660, -0.007578},{
      0.744819, 1.099150, -0.007578},{0.744819, 1.100464, -0.009116}}],
    Polygon[{{0.741596, 1.099660, -0.007578},{0.741269, 1.098655, -0.005853},{
      0.744819, 1.098093, -0.005853},{0.744819, 1.099150, -0.007578}}],
    Polygon[{{0.741269, 1.098655, -0.005853},{0.741030, 1.097919, -0.003984},{
      0.744819, 1.097319, -0.003984},{0.744819, 1.098093, -0.005853}}],
    Polygon[{{0.741030, 1.097919, -0.003984},{0.740884, 1.097470, -0.002017},{
      0.744819, 1.096847, -0.002017},{0.744819, 1.097319, -0.003984}}],
    Polygon[{{0.740884, 1.097470, -0.002017},{0.740835, 1.097319, 0.000000},{
      0.744819, 1.096688, 0.000000},{0.744819, 1.096847, -0.002017}}],
    Polygon[{{0.740835, 1.097319, 0.000000},{0.740884, 1.097470, 0.002017},{
      0.744819, 1.096847, 0.002017},{0.744819, 1.096688, 0.000000}}],
    Polygon[{{0.740884, 1.097470, 0.002017},{0.741030, 1.097919, 0.003984},{
      0.744819, 1.097319, 0.003984},{0.744819, 1.096847, 0.002017}}],
    Polygon[{{0.741030, 1.097919, 0.003984},{0.741269, 1.098655, 0.005853},{
      0.744819, 1.098093, 0.005853},{0.744819, 1.097319, 0.003984}}],
    Polygon[{{0.741269, 1.098655, 0.005853},{0.741596, 1.099660, 0.007578},{
      0.744819, 1.099150, 0.007578},{0.744819, 1.098093, 0.005853}}],
    Polygon[{{0.741596, 1.099660, 0.007578},{0.742002, 1.100910, 0.009116},{
      0.744819, 1.100464, 0.009116},{0.744819, 1.099150, 0.007578}}],
    Polygon[{{0.742002, 1.100910, 0.009116},{0.742477, 1.102373, 0.010430},{
      0.744819, 1.102002, 0.010430},{0.744819, 1.100464, 0.009116}}],
    Polygon[{{0.742477, 1.102373, 0.010430},{0.743010, 1.104013, 0.011487},{
      0.744819, 1.103727, 0.011487},{0.744819, 1.102002, 0.010430}}],
    Polygon[{{0.743010, 1.104013, 0.011487},{0.743587, 1.105791, 0.012261},{
      0.744819, 1.105596, 0.012261},{0.744819, 1.103727, 0.011487}}],
    Polygon[{{0.743587, 1.105791, 0.012261},{0.744195, 1.107661, 0.012733},{
      0.744819, 1.107563, 0.012733},{0.744819, 1.105596, 0.012261}}],
    Polygon[{{0.744819, 1.107563, -0.012733},{0.744819, 1.105596, -0.012261},{
      0.746050, 1.105791, -0.012261},{0.745442, 1.107661, -0.012733}}],
    Polygon[{{0.744819, 1.105596, -0.012261},{0.744819, 1.103727, -0.011487},{
      0.746627, 1.104013, -0.011487},{0.746050, 1.105791, -0.012261}}],
    Polygon[{{0.744819, 1.103727, -0.011487},{0.744819, 1.102002, -0.010430},{
      0.747160, 1.102373, -0.010430},{0.746627, 1.104013, -0.011487}}],
    Polygon[{{0.744819, 1.102002, -0.010430},{0.744819, 1.100464, -0.009116},{
      0.747635, 1.100910, -0.009116},{0.747160, 1.102373, -0.010430}}],
    Polygon[{{0.744819, 1.100464, -0.009116},{0.744819, 1.099150, -0.007578},{
      0.748041, 1.099660, -0.007578},{0.747635, 1.100910, -0.009116}}],
    Polygon[{{0.744819, 1.099150, -0.007578},{0.744819, 1.098093, -0.005853},{
      0.748368, 1.098655, -0.005853},{0.748041, 1.099660, -0.007578}}],
    Polygon[{{0.744819, 1.098093, -0.005853},{0.744819, 1.097319, -0.003984},{
      0.748607, 1.097919, -0.003984},{0.748368, 1.098655, -0.005853}}],
    Polygon[{{0.744819, 1.097319, -0.003984},{0.744819, 1.096847, -0.002017},{
      0.748753, 1.097470, -0.002017},{0.748607, 1.097919, -0.003984}}],
    Polygon[{{0.744819, 1.096847, -0.002017},{0.744819, 1.096688, 0.000000},{
      0.748802, 1.097319, 0.000000},{0.748753, 1.097470, -0.002017}}],
    Polygon[{{0.744819, 1.096688, 0.000000},{0.744819, 1.096847, 0.002017},{
      0.748753, 1.097470, 0.002017},{0.748802, 1.097319, 0.000000}}],
    Polygon[{{0.744819, 1.096847, 0.002017},{0.744819, 1.097319, 0.003984},{
      0.748607, 1.097919, 0.003984},{0.748753, 1.097470, 0.002017}}],
    Polygon[{{0.744819, 1.097319, 0.003984},{0.744819, 1.098093, 0.005853},{
      0.748368, 1.098655, 0.005853},{0.748607, 1.097919, 0.003984}}],
    Polygon[{{0.744819, 1.098093, 0.005853},{0.744819, 1.099150, 0.007578},{
      0.748041, 1.099660, 0.007578},{0.748368, 1.098655, 0.005853}}],
    Polygon[{{0.744819, 1.099150, 0.007578},{0.744819, 1.100464, 0.009116},{
      0.747635, 1.100910, 0.009116},{0.748041, 1.099660, 0.007578}}],
    Polygon[{{0.744819, 1.100464, 0.009116},{0.744819, 1.102002, 0.010430},{
      0.747160, 1.102373, 0.010430},{0.747635, 1.100910, 0.009116}}],
    Polygon[{{0.744819, 1.102002, 0.010430},{0.744819, 1.103727, 0.011487},{
      0.746627, 1.104013, 0.011487},{0.747160, 1.102373, 0.010430}}],
    Polygon[{{0.744819, 1.103727, 0.011487},{0.744819, 1.105596, 0.012261},{
      0.746050, 1.105791, 0.012261},{0.746627, 1.104013, 0.011487}}],
    Polygon[{{0.744819, 1.105596, 0.012261},{0.744819, 1.107563, 0.012733},{
      0.745442, 1.107661, 0.012733},{0.746050, 1.105791, 0.012261}}],
    Polygon[{{0.745442, 1.107661, -0.012733},{0.746050, 1.105791, -0.012261},{
      0.747160, 1.106357, -0.012261},{0.746004, 1.107948, -0.012733}}],
    Polygon[{{0.746050, 1.105791, -0.012261},{0.746627, 1.104013, -0.011487},{
      0.748259, 1.104845, -0.011487},{0.747160, 1.106357, -0.012261}}],
    Polygon[{{0.746627, 1.104013, -0.011487},{0.747160, 1.102373, -0.010430},{
      0.749272, 1.103449, -0.010430},{0.748259, 1.104845, -0.011487}}],
    Polygon[{{0.747160, 1.102373, -0.010430},{0.747635, 1.100910, -0.009116},{
      0.750177, 1.102205, -0.009116},{0.749272, 1.103449, -0.010430}}],
    Polygon[{{0.747635, 1.100910, -0.009116},{0.748041, 1.099660, -0.007578},{
      0.750949, 1.101142, -0.007578},{0.750177, 1.102205, -0.009116}}],
    Polygon[{{0.748041, 1.099660, -0.007578},{0.748368, 1.098655, -0.005853},{
      0.751570, 1.100287, -0.005853},{0.750949, 1.101142, -0.007578}}],
    Polygon[{{0.748368, 1.098655, -0.005853},{0.748607, 1.097919, -0.003984},{
      0.752025, 1.099660, -0.003984},{0.751570, 1.100287, -0.005853}}],
    Polygon[{{0.748607, 1.097919, -0.003984},{0.748753, 1.097470, -0.002017},{
      0.752303, 1.099278, -0.002017},{0.752025, 1.099660, -0.003984}}],
    Polygon[{{0.748753, 1.097470, -0.002017},{0.748802, 1.097319, 0.000000},{
      0.752396, 1.099150, 0.000000},{0.752303, 1.099278, -0.002017}}],
    Polygon[{{0.748802, 1.097319, 0.000000},{0.748753, 1.097470, 0.002017},{
      0.752303, 1.099278, 0.002017},{0.752396, 1.099150, 0.000000}}],
    Polygon[{{0.748753, 1.097470, 0.002017},{0.748607, 1.097919, 0.003984},{
      0.752025, 1.099660, 0.003984},{0.752303, 1.099278, 0.002017}}],
    Polygon[{{0.748607, 1.097919, 0.003984},{0.748368, 1.098655, 0.005853},{
      0.751570, 1.100287, 0.005853},{0.752025, 1.099660, 0.003984}}],
    Polygon[{{0.748368, 1.098655, 0.005853},{0.748041, 1.099660, 0.007578},{
      0.750949, 1.101142, 0.007578},{0.751570, 1.100287, 0.005853}}],
    Polygon[{{0.748041, 1.099660, 0.007578},{0.747635, 1.100910, 0.009116},{
      0.750177, 1.102205, 0.009116},{0.750949, 1.101142, 0.007578}}],
    Polygon[{{0.747635, 1.100910, 0.009116},{0.747160, 1.102373, 0.010430},{
      0.749272, 1.103449, 0.010430},{0.750177, 1.102205, 0.009116}}],
    Polygon[{{0.747160, 1.102373, 0.010430},{0.746627, 1.104013, 0.011487},{
      0.748259, 1.104845, 0.011487},{0.749272, 1.103449, 0.010430}}],
    Polygon[{{0.746627, 1.104013, 0.011487},{0.746050, 1.105791, 0.012261},{
      0.747160, 1.106357, 0.012261},{0.748259, 1.104845, 0.011487}}],
    Polygon[{{0.746050, 1.105791, 0.012261},{0.745442, 1.107661, 0.012733},{
      0.746004, 1.107948, 0.012733},{0.747160, 1.106357, 0.012261}}],
    Polygon[{{0.746004, 1.107948, -0.012733},{0.747160, 1.106357, -0.012261},{
      0.748041, 1.107238, -0.012261},{0.746450, 1.108394, -0.012733}}],
    Polygon[{{0.747160, 1.106357, -0.012261},{0.748259, 1.104845, -0.011487},{
      0.749553, 1.106139, -0.011487},{0.748041, 1.107238, -0.012261}}],
    Polygon[{{0.748259, 1.104845, -0.011487},{0.749272, 1.103449, -0.010430},{
      0.750949, 1.105126, -0.010430},{0.749553, 1.106139, -0.011487}}],
    Polygon[{{0.749272, 1.103449, -0.010430},{0.750177, 1.102205, -0.009116},{
      0.752193, 1.104221, -0.009116},{0.750949, 1.105126, -0.010430}}],
    Polygon[{{0.750177, 1.102205, -0.009116},{0.750949, 1.101142, -0.007578},{
      0.753256, 1.103449, -0.007578},{0.752193, 1.104221, -0.009116}}],
    Polygon[{{0.750949, 1.101142, -0.007578},{0.751570, 1.100287, -0.005853},{
      0.754111, 1.102828, -0.005853},{0.753256, 1.103449, -0.007578}}],
    Polygon[{{0.751570, 1.100287, -0.005853},{0.752025, 1.099660, -0.003984},{
      0.754738, 1.102373, -0.003984},{0.754111, 1.102828, -0.005853}}],
    Polygon[{{0.752025, 1.099660, -0.003984},{0.752303, 1.099278, -0.002017},{
      0.755120, 1.102095, -0.002017},{0.754738, 1.102373, -0.003984}}],
    Polygon[{{0.752303, 1.099278, -0.002017},{0.752396, 1.099150, 0.000000},{
      0.755248, 1.102002, 0.000000},{0.755120, 1.102095, -0.002017}}],
    Polygon[{{0.752396, 1.099150, 0.000000},{0.752303, 1.099278, 0.002017},{
      0.755120, 1.102095, 0.002017},{0.755248, 1.102002, 0.000000}}],
    Polygon[{{0.752303, 1.099278, 0.002017},{0.752025, 1.099660, 0.003984},{
      0.754738, 1.102373, 0.003984},{0.755120, 1.102095, 0.002017}}],
    Polygon[{{0.752025, 1.099660, 0.003984},{0.751570, 1.100287, 0.005853},{
      0.754111, 1.102828, 0.005853},{0.754738, 1.102373, 0.003984}}],
    Polygon[{{0.751570, 1.100287, 0.005853},{0.750949, 1.101142, 0.007578},{
      0.753256, 1.103449, 0.007578},{0.754111, 1.102828, 0.005853}}],
    Polygon[{{0.750949, 1.101142, 0.007578},{0.750177, 1.102205, 0.009116},{
      0.752193, 1.104221, 0.009116},{0.753256, 1.103449, 0.007578}}],
    Polygon[{{0.750177, 1.102205, 0.009116},{0.749272, 1.103449, 0.010430},{
      0.750949, 1.105126, 0.010430},{0.752193, 1.104221, 0.009116}}],
    Polygon[{{0.749272, 1.103449, 0.010430},{0.748259, 1.104845, 0.011487},{
      0.749553, 1.106139, 0.011487},{0.750949, 1.105126, 0.010430}}],
    Polygon[{{0.748259, 1.104845, 0.011487},{0.747160, 1.106357, 0.012261},{
      0.748041, 1.107238, 0.012261},{0.749553, 1.106139, 0.011487}}],
    Polygon[{{0.747160, 1.106357, 0.012261},{0.746004, 1.107948, 0.012733},{
      0.746450, 1.108394, 0.012733},{0.748041, 1.107238, 0.012261}}],
    Polygon[{{0.746450, 1.108394, -0.012733},{0.748041, 1.107238, -0.012261},{
      0.748607, 1.108348, -0.012261},{0.746737, 1.108956, -0.012733}}],
    Polygon[{{0.748041, 1.107238, -0.012261},{0.749553, 1.106139, -0.011487},{
      0.750385, 1.107771, -0.011487},{0.748607, 1.108348, -0.012261}}],
    Polygon[{{0.749553, 1.106139, -0.011487},{0.750949, 1.105126, -0.010430},{
      0.752025, 1.107238, -0.010430},{0.750385, 1.107771, -0.011487}}],
    Polygon[{{0.750949, 1.105126, -0.010430},{0.752193, 1.104221, -0.009116},{
      0.753488, 1.106763, -0.009116},{0.752025, 1.107238, -0.010430}}],
    Polygon[{{0.752193, 1.104221, -0.009116},{0.753256, 1.103449, -0.007578},{
      0.754738, 1.106357, -0.007578},{0.753488, 1.106763, -0.009116}}],
    Polygon[{{0.753256, 1.103449, -0.007578},{0.754111, 1.102828, -0.005853},{
      0.755743, 1.106030, -0.005853},{0.754738, 1.106357, -0.007578}}],
    Polygon[{{0.754111, 1.102828, -0.005853},{0.754738, 1.102373, -0.003984},{
      0.756479, 1.105791, -0.003984},{0.755743, 1.106030, -0.005853}}],
    Polygon[{{0.754738, 1.102373, -0.003984},{0.755120, 1.102095, -0.002017},{
      0.756928, 1.105645, -0.002017},{0.756479, 1.105791, -0.003984}}],
    Polygon[{{0.755120, 1.102095, -0.002017},{0.755248, 1.102002, 0.000000},{
      0.757079, 1.105596, 0.000000},{0.756928, 1.105645, -0.002017}}],
    Polygon[{{0.755248, 1.102002, 0.000000},{0.755120, 1.102095, 0.002017},{
      0.756928, 1.105645, 0.002017},{0.757079, 1.105596, 0.000000}}],
    Polygon[{{0.755120, 1.102095, 0.002017},{0.754738, 1.102373, 0.003984},{
      0.756479, 1.105791, 0.003984},{0.756928, 1.105645, 0.002017}}],
    Polygon[{{0.754738, 1.102373, 0.003984},{0.754111, 1.102828, 0.005853},{
      0.755743, 1.106030, 0.005853},{0.756479, 1.105791, 0.003984}}],
    Polygon[{{0.754111, 1.102828, 0.005853},{0.753256, 1.103449, 0.007578},{
      0.754738, 1.106357, 0.007578},{0.755743, 1.106030, 0.005853}}],
    Polygon[{{0.753256, 1.103449, 0.007578},{0.752193, 1.104221, 0.009116},{
      0.753488, 1.106763, 0.009116},{0.754738, 1.106357, 0.007578}}],
    Polygon[{{0.752193, 1.104221, 0.009116},{0.750949, 1.105126, 0.010430},{
      0.752025, 1.107238, 0.010430},{0.753488, 1.106763, 0.009116}}],
    Polygon[{{0.750949, 1.105126, 0.010430},{0.749553, 1.106139, 0.011487},{
      0.750385, 1.107771, 0.011487},{0.752025, 1.107238, 0.010430}}],
    Polygon[{{0.749553, 1.106139, 0.011487},{0.748041, 1.107238, 0.012261},{
      0.748607, 1.108348, 0.012261},{0.750385, 1.107771, 0.011487}}],
    Polygon[{{0.748041, 1.107238, 0.012261},{0.746450, 1.108394, 0.012733},{
      0.746737, 1.108956, 0.012733},{0.748607, 1.108348, 0.012261}}],
    Polygon[{{0.746737, 1.108956, -0.012733},{0.748607, 1.108348, -0.012261},{
      0.748802, 1.109580, -0.012261},{0.746835, 1.109580, -0.012733}}],
    Polygon[{{0.748607, 1.108348, -0.012261},{0.750385, 1.107771, -0.011487},{
      0.750671, 1.109580, -0.011487},{0.748802, 1.109580, -0.012261}}],
    Polygon[{{0.750385, 1.107771, -0.011487},{0.752025, 1.107238, -0.010430},{
      0.752396, 1.109580, -0.010430},{0.750671, 1.109580, -0.011487}}],
    Polygon[{{0.752025, 1.107238, -0.010430},{0.753488, 1.106763, -0.009116},{
      0.753934, 1.109580, -0.009116},{0.752396, 1.109580, -0.010430}}],
    Polygon[{{0.753488, 1.106763, -0.009116},{0.754738, 1.106357, -0.007578},{
      0.755248, 1.109580, -0.007578},{0.753934, 1.109580, -0.009116}}],
    Polygon[{{0.754738, 1.106357, -0.007578},{0.755743, 1.106030, -0.005853},{
      0.756305, 1.109580, -0.005853},{0.755248, 1.109580, -0.007578}}],
    Polygon[{{0.755743, 1.106030, -0.005853},{0.756479, 1.105791, -0.003984},{
      0.757079, 1.109580, -0.003984},{0.756305, 1.109580, -0.005853}}],
    Polygon[{{0.756479, 1.105791, -0.003984},{0.756928, 1.105645, -0.002017},{
      0.757551, 1.109580, -0.002017},{0.757079, 1.109580, -0.003984}}],
    Polygon[{{0.756928, 1.105645, -0.002017},{0.757079, 1.105596, 0.000000},{
      0.757710, 1.109580, 0.000000},{0.757551, 1.109580, -0.002017}}],
    Polygon[{{0.757079, 1.105596, 0.000000},{0.756928, 1.105645, 0.002017},{
      0.757551, 1.109580, 0.002017},{0.757710, 1.109580, 0.000000}}],
    Polygon[{{0.756928, 1.105645, 0.002017},{0.756479, 1.105791, 0.003984},{
      0.757079, 1.109580, 0.003984},{0.757551, 1.109580, 0.002017}}],
    Polygon[{{0.756479, 1.105791, 0.003984},{0.755743, 1.106030, 0.005853},{
      0.756305, 1.109580, 0.005853},{0.757079, 1.109580, 0.003984}}],
    Polygon[{{0.755743, 1.106030, 0.005853},{0.754738, 1.106357, 0.007578},{
      0.755248, 1.109580, 0.007578},{0.756305, 1.109580, 0.005853}}],
    Polygon[{{0.754738, 1.106357, 0.007578},{0.753488, 1.106763, 0.009116},{
      0.753934, 1.109580, 0.009116},{0.755248, 1.109580, 0.007578}}],
    Polygon[{{0.753488, 1.106763, 0.009116},{0.752025, 1.107238, 0.010430},{
      0.752396, 1.109580, 0.010430},{0.753934, 1.109580, 0.009116}}],
    Polygon[{{0.752025, 1.107238, 0.010430},{0.750385, 1.107771, 0.011487},{
      0.750671, 1.109580, 0.011487},{0.752396, 1.109580, 0.010430}}],
    Polygon[{{0.750385, 1.107771, 0.011487},{0.748607, 1.108348, 0.012261},{
      0.748802, 1.109580, 0.012261},{0.750671, 1.109580, 0.011487}}],
    Polygon[{{0.748607, 1.108348, 0.012261},{0.746737, 1.108956, 0.012733},{
      0.746835, 1.109580, 0.012733},{0.748802, 1.109580, 0.012261}}],
    Polygon[{{0.788286, 1.299558, -0.028615},{0.792706, 1.299558, -0.027554},{
      0.792268, 1.302325, -0.027554},{0.788064, 1.300959, -0.028615}}],
    Polygon[{{0.792706, 1.299558, -0.027554},{0.796906, 1.299558, -0.025814},{
      0.796263, 1.303623, -0.025814},{0.792268, 1.302325, -0.027554}}],
    Polygon[{{0.796906, 1.299558, -0.025814},{0.800783, 1.299558, -0.023438},{
      0.799949, 1.304820, -0.023438},{0.796263, 1.303623, -0.025814}}],
    Polygon[{{0.800783, 1.299558, -0.023438},{0.804240, 1.299558, -0.020486},{
      0.803237, 1.305889, -0.020486},{0.799949, 1.304820, -0.023438}}],
    Polygon[{{0.804240, 1.299558, -0.020486},{0.807192, 1.299558, -0.017029},{
      0.806045, 1.306801, -0.017029},{0.803237, 1.305889, -0.020486}}],
    Polygon[{{0.807192, 1.299558, -0.017029},{0.809567, 1.299558, -0.013153},{
      0.808304, 1.307535, -0.013153},{0.806045, 1.306801, -0.017029}}],
    Polygon[{{0.809567, 1.299558, -0.013153},{0.811307, 1.299558, -0.008953},{
      0.809959, 1.308073, -0.008953},{0.808304, 1.307535, -0.013153}}],
    Polygon[{{0.811307, 1.299558, -0.008953},{0.812369, 1.299558, -0.004532},{
      0.810968, 1.308401, -0.004532},{0.809959, 1.308073, -0.008953}}],
    Polygon[{{0.812369, 1.299558, -0.004532},{0.812725, 1.299558, 0.000000},{
      0.811307, 1.308511, 0.000000},{0.810968, 1.308401, -0.004532}}],
    Polygon[{{0.812725, 1.299558, 0.000000},{0.812369, 1.299558, 0.004532},{
      0.810968, 1.308401, 0.004532},{0.811307, 1.308511, 0.000000}}],
    Polygon[{{0.812369, 1.299558, 0.004532},{0.811307, 1.299558, 0.008953},{
      0.809959, 1.308073, 0.008953},{0.810968, 1.308401, 0.004532}}],
    Polygon[{{0.811307, 1.299558, 0.008953},{0.809567, 1.299558, 0.013153},{
      0.808304, 1.307535, 0.013153},{0.809959, 1.308073, 0.008953}}],
    Polygon[{{0.809567, 1.299558, 0.013153},{0.807192, 1.299558, 0.017029},{
      0.806045, 1.306801, 0.017029},{0.808304, 1.307535, 0.013153}}],
    Polygon[{{0.807192, 1.299558, 0.017029},{0.804240, 1.299558, 0.020486},{
      0.803237, 1.305889, 0.020486},{0.806045, 1.306801, 0.017029}}],
    Polygon[{{0.804240, 1.299558, 0.020486},{0.800783, 1.299558, 0.023438},{
      0.799949, 1.304820, 0.023438},{0.803237, 1.305889, 0.020486}}],
    Polygon[{{0.800783, 1.299558, 0.023438},{0.796906, 1.299558, 0.025814},{
      0.796263, 1.303623, 0.025814},{0.799949, 1.304820, 0.023438}}],
    Polygon[{{0.796906, 1.299558, 0.025814},{0.792706, 1.299558, 0.027554},{
      0.792268, 1.302325, 0.027554},{0.796263, 1.303623, 0.025814}}],
    Polygon[{{0.792706, 1.299558, 0.027554},{0.788286, 1.299558, 0.028615},{
      0.788064, 1.300959, 0.028615},{0.792268, 1.302325, 0.027554}}],
    Polygon[{{0.788064, 1.300959, -0.028615},{0.792268, 1.302325, -0.027554},{
      0.790997, 1.304820, -0.027554},{0.787420, 1.302222, -0.028615}}],
    Polygon[{{0.792268, 1.302325, -0.027554},{0.796263, 1.303623, -0.025814},{
      0.794394, 1.307289, -0.025814},{0.790997, 1.304820, -0.027554}}],
    Polygon[{{0.796263, 1.303623, -0.025814},{0.799949, 1.304820, -0.023438},{
      0.797530, 1.309568, -0.023438},{0.794394, 1.307289, -0.025814}}],
    Polygon[{{0.799949, 1.304820, -0.023438},{0.803237, 1.305889, -0.020486},{
      0.800327, 1.311599, -0.020486},{0.797530, 1.309568, -0.023438}}],
    Polygon[{{0.803237, 1.305889, -0.020486},{0.806045, 1.306801, -0.017029},{
      0.802716, 1.313335, -0.017029},{0.800327, 1.311599, -0.020486}}],
    Polygon[{{0.806045, 1.306801, -0.017029},{0.808304, 1.307535, -0.013153},{
      0.804637, 1.314731, -0.013153},{0.802716, 1.313335, -0.017029}}],
    Polygon[{{0.808304, 1.307535, -0.013153},{0.809959, 1.308073, -0.008953},{
      0.806045, 1.315754, -0.008953},{0.804637, 1.314731, -0.013153}}],
    Polygon[{{0.809959, 1.308073, -0.008953},{0.810968, 1.308401, -0.004532},{
      0.806904, 1.316378, -0.004532},{0.806045, 1.315754, -0.008953}}],
    Polygon[{{0.810968, 1.308401, -0.004532},{0.811307, 1.308511, 0.000000},{
      0.807192, 1.316587, 0.000000},{0.806904, 1.316378, -0.004532}}],
    Polygon[{{0.811307, 1.308511, 0.000000},{0.810968, 1.308401, 0.004532},{
      0.806904, 1.316378, 0.004532},{0.807192, 1.316587, 0.000000}}],
    Polygon[{{0.810968, 1.308401, 0.004532},{0.809959, 1.308073, 0.008953},{
      0.806045, 1.315754, 0.008953},{0.806904, 1.316378, 0.004532}}],
    Polygon[{{0.809959, 1.308073, 0.008953},{0.808304, 1.307535, 0.013153},{
      0.804637, 1.314731, 0.013153},{0.806045, 1.315754, 0.008953}}],
    Polygon[{{0.808304, 1.307535, 0.013153},{0.806045, 1.306801, 0.017029},{
      0.802716, 1.313335, 0.017029},{0.804637, 1.314731, 0.013153}}],
    Polygon[{{0.806045, 1.306801, 0.017029},{0.803237, 1.305889, 0.020486},{
      0.800327, 1.311599, 0.020486},{0.802716, 1.313335, 0.017029}}],
    Polygon[{{0.803237, 1.305889, 0.020486},{0.799949, 1.304820, 0.023438},{
      0.797530, 1.309568, 0.023438},{0.800327, 1.311599, 0.020486}}],
    Polygon[{{0.799949, 1.304820, 0.023438},{0.796263, 1.303623, 0.025814},{
      0.794394, 1.307289, 0.025814},{0.797530, 1.309568, 0.023438}}],
    Polygon[{{0.796263, 1.303623, 0.025814},{0.792268, 1.302325, 0.027554},{
      0.790997, 1.304820, 0.027554},{0.794394, 1.307289, 0.025814}}],
    Polygon[{{0.792268, 1.302325, 0.027554},{0.788064, 1.300959, 0.028615},{
      0.787420, 1.302222, 0.028615},{0.790997, 1.304820, 0.027554}}],
    Polygon[{{0.787420, 1.302222, -0.028615},{0.790997, 1.304820, -0.027554},{
      0.789016, 1.306801, -0.027554},{0.786418, 1.303225, -0.028615}}],
    Polygon[{{0.790997, 1.304820, -0.027554},{0.794394, 1.307289, -0.025814},{
      0.791485, 1.310199, -0.025814},{0.789016, 1.306801, -0.027554}}],
    Polygon[{{0.794394, 1.307289, -0.025814},{0.797530, 1.309568, -0.023438},{
      0.793763, 1.313335, -0.023438},{0.791485, 1.310199, -0.025814}}],
    Polygon[{{0.797530, 1.309568, -0.023438},{0.800327, 1.311599, -0.020486},{
      0.795795, 1.316132, -0.020486},{0.793763, 1.313335, -0.023438}}],
    Polygon[{{0.800327, 1.311599, -0.020486},{0.802716, 1.313335, -0.017029},{
      0.797530, 1.318520, -0.017029},{0.795795, 1.316132, -0.020486}}],
    Polygon[{{0.802716, 1.313335, -0.017029},{0.804637, 1.314731, -0.013153},{
      0.798927, 1.320442, -0.013153},{0.797530, 1.318520, -0.017029}}],
    Polygon[{{0.804637, 1.314731, -0.013153},{0.806045, 1.315754, -0.008953},{
      0.799949, 1.321849, -0.008953},{0.798927, 1.320442, -0.013153}}],
    Polygon[{{0.806045, 1.315754, -0.008953},{0.806904, 1.316378, -0.004532},{
      0.800573, 1.322708, -0.004532},{0.799949, 1.321849, -0.008953}}],
    Polygon[{{0.806904, 1.316378, -0.004532},{0.807192, 1.316587, 0.000000},{
      0.800783, 1.322997, 0.000000},{0.800573, 1.322708, -0.004532}}],
    Polygon[{{0.807192, 1.316587, 0.000000},{0.806904, 1.316378, 0.004532},{
      0.800573, 1.322708, 0.004532},{0.800783, 1.322997, 0.000000}}],
    Polygon[{{0.806904, 1.316378, 0.004532},{0.806045, 1.315754, 0.008953},{
      0.799949, 1.321849, 0.008953},{0.800573, 1.322708, 0.004532}}],
    Polygon[{{0.806045, 1.315754, 0.008953},{0.804637, 1.314731, 0.013153},{
      0.798927, 1.320442, 0.013153},{0.799949, 1.321849, 0.008953}}],
    Polygon[{{0.804637, 1.314731, 0.013153},{0.802716, 1.313335, 0.017029},{
      0.797530, 1.318520, 0.017029},{0.798927, 1.320442, 0.013153}}],
    Polygon[{{0.802716, 1.313335, 0.017029},{0.800327, 1.311599, 0.020486},{
      0.795795, 1.316132, 0.020486},{0.797530, 1.318520, 0.017029}}],
    Polygon[{{0.800327, 1.311599, 0.020486},{0.797530, 1.309568, 0.023438},{
      0.793763, 1.313335, 0.023438},{0.795795, 1.316132, 0.020486}}],
    Polygon[{{0.797530, 1.309568, 0.023438},{0.794394, 1.307289, 0.025814},{
      0.791485, 1.310199, 0.025814},{0.793763, 1.313335, 0.023438}}],
    Polygon[{{0.794394, 1.307289, 0.025814},{0.790997, 1.304820, 0.027554},{
      0.789016, 1.306801, 0.027554},{0.791485, 1.310199, 0.025814}}],
    Polygon[{{0.790997, 1.304820, 0.027554},{0.787420, 1.302222, 0.028615},{
      0.786418, 1.303225, 0.028615},{0.789016, 1.306801, 0.027554}}],
    Polygon[{{0.786418, 1.303225, -0.028615},{0.789016, 1.306801, -0.027554},{
      0.786520, 1.308073, -0.027554},{0.785154, 1.303868, -0.028615}}],
    Polygon[{{0.789016, 1.306801, -0.027554},{0.791485, 1.310199, -0.025814},{
      0.787818, 1.312067, -0.025814},{0.786520, 1.308073, -0.027554}}],
    Polygon[{{0.791485, 1.310199, -0.025814},{0.793763, 1.313335, -0.023438},{
      0.789016, 1.315754, -0.023438},{0.787818, 1.312067, -0.025814}}],
    Polygon[{{0.793763, 1.313335, -0.023438},{0.795795, 1.316132, -0.020486},{
      0.790084, 1.319041, -0.020486},{0.789016, 1.315754, -0.023438}}],
    Polygon[{{0.795795, 1.316132, -0.020486},{0.797530, 1.318520, -0.017029},{
      0.790997, 1.321849, -0.017029},{0.790084, 1.319041, -0.020486}}],
    Polygon[{{0.797530, 1.318520, -0.017029},{0.798927, 1.320442, -0.013153},{
      0.791731, 1.324108, -0.013153},{0.790997, 1.321849, -0.017029}}],
    Polygon[{{0.798927, 1.320442, -0.013153},{0.799949, 1.321849, -0.008953},{
      0.792268, 1.325763, -0.008953},{0.791731, 1.324108, -0.013153}}],
    Polygon[{{0.799949, 1.321849, -0.008953},{0.800573, 1.322708, -0.004532},{
      0.792596, 1.326772, -0.004532},{0.792268, 1.325763, -0.008953}}],
    Polygon[{{0.800573, 1.322708, -0.004532},{0.800783, 1.322997, 0.000000},{
      0.792706, 1.327112, 0.000000},{0.792596, 1.326772, -0.004532}}],
    Polygon[{{0.800783, 1.322997, 0.000000},{0.800573, 1.322708, 0.004532},{
      0.792596, 1.326772, 0.004532},{0.792706, 1.327112, 0.000000}}],
    Polygon[{{0.800573, 1.322708, 0.004532},{0.799949, 1.321849, 0.008953},{
      0.792268, 1.325763, 0.008953},{0.792596, 1.326772, 0.004532}}],
    Polygon[{{0.799949, 1.321849, 0.008953},{0.798927, 1.320442, 0.013153},{
      0.791731, 1.324108, 0.013153},{0.792268, 1.325763, 0.008953}}],
    Polygon[{{0.798927, 1.320442, 0.013153},{0.797530, 1.318520, 0.017029},{
      0.790997, 1.321849, 0.017029},{0.791731, 1.324108, 0.013153}}],
    Polygon[{{0.797530, 1.318520, 0.017029},{0.795795, 1.316132, 0.020486},{
      0.790084, 1.319041, 0.020486},{0.790997, 1.321849, 0.017029}}],
    Polygon[{{0.795795, 1.316132, 0.020486},{0.793763, 1.313335, 0.023438},{
      0.789016, 1.315754, 0.023438},{0.790084, 1.319041, 0.020486}}],
    Polygon[{{0.793763, 1.313335, 0.023438},{0.791485, 1.310199, 0.025814},{
      0.787818, 1.312067, 0.025814},{0.789016, 1.315754, 0.023438}}],
    Polygon[{{0.791485, 1.310199, 0.025814},{0.789016, 1.306801, 0.027554},{
      0.786520, 1.308073, 0.027554},{0.787818, 1.312067, 0.025814}}],
    Polygon[{{0.789016, 1.306801, 0.027554},{0.786418, 1.303225, 0.028615},{
      0.785154, 1.303868, 0.028615},{0.786520, 1.308073, 0.027554}}],
    Polygon[{{0.785154, 1.303868, -0.028615},{0.786520, 1.308073, -0.027554},{
      0.783754, 1.308511, -0.027554},{0.783754, 1.304090, -0.028615}}],
    Polygon[{{0.786520, 1.308073, -0.027554},{0.787818, 1.312067, -0.025814},{
      0.783754, 1.312711, -0.025814},{0.783754, 1.308511, -0.027554}}],
    Polygon[{{0.787818, 1.312067, -0.025814},{0.789016, 1.315754, -0.023438},{
      0.783754, 1.316587, -0.023438},{0.783754, 1.312711, -0.025814}}],
    Polygon[{{0.789016, 1.315754, -0.023438},{0.790084, 1.319041, -0.020486},{
      0.783754, 1.320044, -0.020486},{0.783754, 1.316587, -0.023438}}],
    Polygon[{{0.790084, 1.319041, -0.020486},{0.790997, 1.321849, -0.017029},{
      0.783754, 1.322997, -0.017029},{0.783754, 1.320044, -0.020486}}],
    Polygon[{{0.790997, 1.321849, -0.017029},{0.791731, 1.324108, -0.013153},{
      0.783754, 1.325372, -0.013153},{0.783754, 1.322997, -0.017029}}],
    Polygon[{{0.791731, 1.324108, -0.013153},{0.792268, 1.325763, -0.008953},{
      0.783754, 1.327112, -0.008953},{0.783754, 1.325372, -0.013153}}],
    Polygon[{{0.792268, 1.325763, -0.008953},{0.792596, 1.326772, -0.004532},{
      0.783754, 1.328173, -0.004532},{0.783754, 1.327112, -0.008953}}],
    Polygon[{{0.792596, 1.326772, -0.004532},{0.792706, 1.327112, 0.000000},{
      0.783754, 1.328530, 0.000000},{0.783754, 1.328173, -0.004532}}],
    Polygon[{{0.792706, 1.327112, 0.000000},{0.792596, 1.326772, 0.004532},{
      0.783754, 1.328173, 0.004532},{0.783754, 1.328530, 0.000000}}],
    Polygon[{{0.792596, 1.326772, 0.004532},{0.792268, 1.325763, 0.008953},{
      0.783754, 1.327112, 0.008953},{0.783754, 1.328173, 0.004532}}],
    Polygon[{{0.792268, 1.325763, 0.008953},{0.791731, 1.324108, 0.013153},{
      0.783754, 1.325372, 0.013153},{0.783754, 1.327112, 0.008953}}],
    Polygon[{{0.791731, 1.324108, 0.013153},{0.790997, 1.321849, 0.017029},{
      0.783754, 1.322997, 0.017029},{0.783754, 1.325372, 0.013153}}],
    Polygon[{{0.790997, 1.321849, 0.017029},{0.790084, 1.319041, 0.020486},{
      0.783754, 1.320044, 0.020486},{0.783754, 1.322997, 0.017029}}],
    Polygon[{{0.790084, 1.319041, 0.020486},{0.789016, 1.315754, 0.023438},{
      0.783754, 1.316587, 0.023438},{0.783754, 1.320044, 0.020486}}],
    Polygon[{{0.789016, 1.315754, 0.023438},{0.787818, 1.312067, 0.025814},{
      0.783754, 1.312711, 0.025814},{0.783754, 1.316587, 0.023438}}],
    Polygon[{{0.787818, 1.312067, 0.025814},{0.786520, 1.308073, 0.027554},{
      0.783754, 1.308511, 0.027554},{0.783754, 1.312711, 0.025814}}],
    Polygon[{{0.786520, 1.308073, 0.027554},{0.785154, 1.303868, 0.028615},{
      0.783754, 1.304090, 0.028615},{0.783754, 1.308511, 0.027554}}],
    Polygon[{{0.783754, 1.304090, -0.028615},{0.783754, 1.308511, -0.027554},{
      0.780987, 1.308073, -0.027554},{0.782353, 1.303868, -0.028615}}],
    Polygon[{{0.783754, 1.308511, -0.027554},{0.783754, 1.312711, -0.025814},{
      0.779689, 1.312067, -0.025814},{0.780987, 1.308073, -0.027554}}],
    Polygon[{{0.783754, 1.312711, -0.025814},{0.783754, 1.316587, -0.023438},{
      0.778491, 1.315754, -0.023438},{0.779689, 1.312067, -0.025814}}],
    Polygon[{{0.783754, 1.316587, -0.023438},{0.783754, 1.320044, -0.020486},{
      0.777423, 1.319041, -0.020486},{0.778491, 1.315754, -0.023438}}],
    Polygon[{{0.783754, 1.320044, -0.020486},{0.783754, 1.322997, -0.017029},{
      0.776511, 1.321849, -0.017029},{0.777423, 1.319041, -0.020486}}],
    Polygon[{{0.783754, 1.322997, -0.017029},{0.783754, 1.325372, -0.013153},{
      0.775777, 1.324108, -0.013153},{0.776511, 1.321849, -0.017029}}],
    Polygon[{{0.783754, 1.325372, -0.013153},{0.783754, 1.327112, -0.008953},{
      0.775239, 1.325763, -0.008953},{0.775777, 1.324108, -0.013153}}],
    Polygon[{{0.783754, 1.327112, -0.008953},{0.783754, 1.328173, -0.004532},{
      0.774911, 1.326772, -0.004532},{0.775239, 1.325763, -0.008953}}],
    Polygon[{{0.783754, 1.328173, -0.004532},{0.783754, 1.328530, 0.000000},{
      0.774801, 1.327112, 0.000000},{0.774911, 1.326772, -0.004532}}],
    Polygon[{{0.783754, 1.328530, 0.000000},{0.783754, 1.328173, 0.004532},{
      0.774911, 1.326772, 0.004532},{0.774801, 1.327112, 0.000000}}],
    Polygon[{{0.783754, 1.328173, 0.004532},{0.783754, 1.327112, 0.008953},{
      0.775239, 1.325763, 0.008953},{0.774911, 1.326772, 0.004532}}],
    Polygon[{{0.783754, 1.327112, 0.008953},{0.783754, 1.325372, 0.013153},{
      0.775777, 1.324108, 0.013153},{0.775239, 1.325763, 0.008953}}],
    Polygon[{{0.783754, 1.325372, 0.013153},{0.783754, 1.322997, 0.017029},{
      0.776511, 1.321849, 0.017029},{0.775777, 1.324108, 0.013153}}],
    Polygon[{{0.783754, 1.322997, 0.017029},{0.783754, 1.320044, 0.020486},{
      0.777423, 1.319041, 0.020486},{0.776511, 1.321849, 0.017029}}],
    Polygon[{{0.783754, 1.320044, 0.020486},{0.783754, 1.316587, 0.023438},{
      0.778491, 1.315754, 0.023438},{0.777423, 1.319041, 0.020486}}],
    Polygon[{{0.783754, 1.316587, 0.023438},{0.783754, 1.312711, 0.025814},{
      0.779689, 1.312067, 0.025814},{0.778491, 1.315754, 0.023438}}],
    Polygon[{{0.783754, 1.312711, 0.025814},{0.783754, 1.308511, 0.027554},{
      0.780987, 1.308073, 0.027554},{0.779689, 1.312067, 0.025814}}],
    Polygon[{{0.783754, 1.308511, 0.027554},{0.783754, 1.304090, 0.028615},{
      0.782353, 1.303868, 0.028615},{0.780987, 1.308073, 0.027554}}],
    Polygon[{{0.782353, 1.303868, -0.028615},{0.780987, 1.308073, -0.027554},{
      0.778491, 1.306801, -0.027554},{0.781090, 1.303225, -0.028615}}],
    Polygon[{{0.780987, 1.308073, -0.027554},{0.779689, 1.312067, -0.025814},{
      0.776023, 1.310199, -0.025814},{0.778491, 1.306801, -0.027554}}],
    Polygon[{{0.779689, 1.312067, -0.025814},{0.778491, 1.315754, -0.023438},{
      0.773744, 1.313335, -0.023438},{0.776023, 1.310199, -0.025814}}],
    Polygon[{{0.778491, 1.315754, -0.023438},{0.777423, 1.319041, -0.020486},{
      0.771712, 1.316132, -0.020486},{0.773744, 1.313335, -0.023438}}],
    Polygon[{{0.777423, 1.319041, -0.020486},{0.776511, 1.321849, -0.017029},{
      0.769977, 1.318520, -0.017029},{0.771712, 1.316132, -0.020486}}],
    Polygon[{{0.776511, 1.321849, -0.017029},{0.775777, 1.324108, -0.013153},{
      0.768581, 1.320442, -0.013153},{0.769977, 1.318520, -0.017029}}],
    Polygon[{{0.775777, 1.324108, -0.013153},{0.775239, 1.325763, -0.008953},{
      0.767558, 1.321849, -0.008953},{0.768581, 1.320442, -0.013153}}],
    Polygon[{{0.775239, 1.325763, -0.008953},{0.774911, 1.326772, -0.004532},{
      0.766934, 1.322708, -0.004532},{0.767558, 1.321849, -0.008953}}],
    Polygon[{{0.774911, 1.326772, -0.004532},{0.774801, 1.327112, 0.000000},{
      0.766725, 1.322997, 0.000000},{0.766934, 1.322708, -0.004532}}],
    Polygon[{{0.774801, 1.327112, 0.000000},{0.774911, 1.326772, 0.004532},{
      0.766934, 1.322708, 0.004532},{0.766725, 1.322997, 0.000000}}],
    Polygon[{{0.774911, 1.326772, 0.004532},{0.775239, 1.325763, 0.008953},{
      0.767558, 1.321849, 0.008953},{0.766934, 1.322708, 0.004532}}],
    Polygon[{{0.775239, 1.325763, 0.008953},{0.775777, 1.324108, 0.013153},{
      0.768581, 1.320442, 0.013153},{0.767558, 1.321849, 0.008953}}],
    Polygon[{{0.775777, 1.324108, 0.013153},{0.776511, 1.321849, 0.017029},{
      0.769977, 1.318520, 0.017029},{0.768581, 1.320442, 0.013153}}],
    Polygon[{{0.776511, 1.321849, 0.017029},{0.777423, 1.319041, 0.020486},{
      0.771712, 1.316132, 0.020486},{0.769977, 1.318520, 0.017029}}],
    Polygon[{{0.777423, 1.319041, 0.020486},{0.778491, 1.315754, 0.023438},{
      0.773744, 1.313335, 0.023438},{0.771712, 1.316132, 0.020486}}],
    Polygon[{{0.778491, 1.315754, 0.023438},{0.779689, 1.312067, 0.025814},{
      0.776023, 1.310199, 0.025814},{0.773744, 1.313335, 0.023438}}],
    Polygon[{{0.779689, 1.312067, 0.025814},{0.780987, 1.308073, 0.027554},{
      0.778491, 1.306801, 0.027554},{0.776023, 1.310199, 0.025814}}],
    Polygon[{{0.780987, 1.308073, 0.027554},{0.782353, 1.303868, 0.028615},{
      0.781090, 1.303225, 0.028615},{0.778491, 1.306801, 0.027554}}],
    Polygon[{{0.781090, 1.303225, -0.028615},{0.778491, 1.306801, -0.027554},{
      0.776511, 1.304820, -0.027554},{0.780087, 1.302222, -0.028615}}],
    Polygon[{{0.778491, 1.306801, -0.027554},{0.776023, 1.310199, -0.025814},{
      0.773113, 1.307289, -0.025814},{0.776511, 1.304820, -0.027554}}],
    Polygon[{{0.776023, 1.310199, -0.025814},{0.773744, 1.313335, -0.023438},{
      0.769977, 1.309568, -0.023438},{0.773113, 1.307289, -0.025814}}],
    Polygon[{{0.773744, 1.313335, -0.023438},{0.771712, 1.316132, -0.020486},{
      0.767180, 1.311599, -0.020486},{0.769977, 1.309568, -0.023438}}],
    Polygon[{{0.771712, 1.316132, -0.020486},{0.769977, 1.318520, -0.017029},{
      0.764792, 1.313335, -0.017029},{0.767180, 1.311599, -0.020486}}],
    Polygon[{{0.769977, 1.318520, -0.017029},{0.768581, 1.320442, -0.013153},{
      0.762870, 1.314731, -0.013153},{0.764792, 1.313335, -0.017029}}],
    Polygon[{{0.768581, 1.320442, -0.013153},{0.767558, 1.321849, -0.008953},{
      0.761462, 1.315754, -0.008953},{0.762870, 1.314731, -0.013153}}],
    Polygon[{{0.767558, 1.321849, -0.008953},{0.766934, 1.322708, -0.004532},{
      0.760604, 1.316378, -0.004532},{0.761462, 1.315754, -0.008953}}],
    Polygon[{{0.766934, 1.322708, -0.004532},{0.766725, 1.322997, 0.000000},{
      0.760315, 1.316587, 0.000000},{0.760604, 1.316378, -0.004532}}],
    Polygon[{{0.766725, 1.322997, 0.000000},{0.766934, 1.322708, 0.004532},{
      0.760604, 1.316378, 0.004532},{0.760315, 1.316587, 0.000000}}],
    Polygon[{{0.766934, 1.322708, 0.004532},{0.767558, 1.321849, 0.008953},{
      0.761462, 1.315754, 0.008953},{0.760604, 1.316378, 0.004532}}],
    Polygon[{{0.767558, 1.321849, 0.008953},{0.768581, 1.320442, 0.013153},{
      0.762870, 1.314731, 0.013153},{0.761462, 1.315754, 0.008953}}],
    Polygon[{{0.768581, 1.320442, 0.013153},{0.769977, 1.318520, 0.017029},{
      0.764792, 1.313335, 0.017029},{0.762870, 1.314731, 0.013153}}],
    Polygon[{{0.769977, 1.318520, 0.017029},{0.771712, 1.316132, 0.020486},{
      0.767180, 1.311599, 0.020486},{0.764792, 1.313335, 0.017029}}],
    Polygon[{{0.771712, 1.316132, 0.020486},{0.773744, 1.313335, 0.023438},{
      0.769977, 1.309568, 0.023438},{0.767180, 1.311599, 0.020486}}],
    Polygon[{{0.773744, 1.313335, 0.023438},{0.776023, 1.310199, 0.025814},{
      0.773113, 1.307289, 0.025814},{0.769977, 1.309568, 0.023438}}],
    Polygon[{{0.776023, 1.310199, 0.025814},{0.778491, 1.306801, 0.027554},{
      0.776511, 1.304820, 0.027554},{0.773113, 1.307289, 0.025814}}],
    Polygon[{{0.778491, 1.306801, 0.027554},{0.781090, 1.303225, 0.028615},{
      0.780087, 1.302222, 0.028615},{0.776511, 1.304820, 0.027554}}],
    Polygon[{{0.780087, 1.302222, -0.028615},{0.776511, 1.304820, -0.027554},{
      0.775239, 1.302325, -0.027554},{0.779443, 1.300959, -0.028615}}],
    Polygon[{{0.776511, 1.304820, -0.027554},{0.773113, 1.307289, -0.025814},{
      0.771245, 1.303623, -0.025814},{0.775239, 1.302325, -0.027554}}],
    Polygon[{{0.773113, 1.307289, -0.025814},{0.769977, 1.309568, -0.023438},{
      0.767558, 1.304820, -0.023438},{0.771245, 1.303623, -0.025814}}],
    Polygon[{{0.769977, 1.309568, -0.023438},{0.767180, 1.311599, -0.020486},{
      0.764270, 1.305889, -0.020486},{0.767558, 1.304820, -0.023438}}],
    Polygon[{{0.767180, 1.311599, -0.020486},{0.764792, 1.313335, -0.017029},{
      0.761462, 1.306801, -0.017029},{0.764270, 1.305889, -0.020486}}],
    Polygon[{{0.764792, 1.313335, -0.017029},{0.762870, 1.314731, -0.013153},{
      0.759203, 1.307535, -0.013153},{0.761462, 1.306801, -0.017029}}],
    Polygon[{{0.762870, 1.314731, -0.013153},{0.761462, 1.315754, -0.008953},{
      0.757549, 1.308073, -0.008953},{0.759203, 1.307535, -0.013153}}],
    Polygon[{{0.761462, 1.315754, -0.008953},{0.760604, 1.316378, -0.004532},{
      0.756539, 1.308401, -0.004532},{0.757549, 1.308073, -0.008953}}],
    Polygon[{{0.760604, 1.316378, -0.004532},{0.760315, 1.316587, 0.000000},{
      0.756200, 1.308511, 0.000000},{0.756539, 1.308401, -0.004532}}],
    Polygon[{{0.760315, 1.316587, 0.000000},{0.760604, 1.316378, 0.004532},{
      0.756539, 1.308401, 0.004532},{0.756200, 1.308511, 0.000000}}],
    Polygon[{{0.760604, 1.316378, 0.004532},{0.761462, 1.315754, 0.008953},{
      0.757549, 1.308073, 0.008953},{0.756539, 1.308401, 0.004532}}],
    Polygon[{{0.761462, 1.315754, 0.008953},{0.762870, 1.314731, 0.013153},{
      0.759203, 1.307535, 0.013153},{0.757549, 1.308073, 0.008953}}],
    Polygon[{{0.762870, 1.314731, 0.013153},{0.764792, 1.313335, 0.017029},{
      0.761462, 1.306801, 0.017029},{0.759203, 1.307535, 0.013153}}],
    Polygon[{{0.764792, 1.313335, 0.017029},{0.767180, 1.311599, 0.020486},{
      0.764270, 1.305889, 0.020486},{0.761462, 1.306801, 0.017029}}],
    Polygon[{{0.767180, 1.311599, 0.020486},{0.769977, 1.309568, 0.023438},{
      0.767558, 1.304820, 0.023438},{0.764270, 1.305889, 0.020486}}],
    Polygon[{{0.769977, 1.309568, 0.023438},{0.773113, 1.307289, 0.025814},{
      0.771245, 1.303623, 0.025814},{0.767558, 1.304820, 0.023438}}],
    Polygon[{{0.773113, 1.307289, 0.025814},{0.776511, 1.304820, 0.027554},{
      0.775239, 1.302325, 0.027554},{0.771245, 1.303623, 0.025814}}],
    Polygon[{{0.776511, 1.304820, 0.027554},{0.780087, 1.302222, 0.028615},{
      0.779443, 1.300959, 0.028615},{0.775239, 1.302325, 0.027554}}],
    Polygon[{{0.779443, 1.300959, -0.028615},{0.775239, 1.302325, -0.027554},{
      0.774801, 1.299558, -0.027554},{0.779222, 1.299558, -0.028615}}],
    Polygon[{{0.775239, 1.302325, -0.027554},{0.771245, 1.303623, -0.025814},{
      0.770601, 1.299558, -0.025814},{0.774801, 1.299558, -0.027554}}],
    Polygon[{{0.771245, 1.303623, -0.025814},{0.767558, 1.304820, -0.023438},{
      0.766725, 1.299558, -0.023438},{0.770601, 1.299558, -0.025814}}],
    Polygon[{{0.767558, 1.304820, -0.023438},{0.764270, 1.305889, -0.020486},{
      0.763268, 1.299558, -0.020486},{0.766725, 1.299558, -0.023438}}],
    Polygon[{{0.764270, 1.305889, -0.020486},{0.761462, 1.306801, -0.017029},{
      0.760315, 1.299558, -0.017029},{0.763268, 1.299558, -0.020486}}],
    Polygon[{{0.761462, 1.306801, -0.017029},{0.759203, 1.307535, -0.013153},{
      0.757940, 1.299558, -0.013153},{0.760315, 1.299558, -0.017029}}],
    Polygon[{{0.759203, 1.307535, -0.013153},{0.757549, 1.308073, -0.008953},{
      0.756200, 1.299558, -0.008953},{0.757940, 1.299558, -0.013153}}],
    Polygon[{{0.757549, 1.308073, -0.008953},{0.756539, 1.308401, -0.004532},{
      0.755139, 1.299558, -0.004532},{0.756200, 1.299558, -0.008953}}],
    Polygon[{{0.756539, 1.308401, -0.004532},{0.756200, 1.308511, 0.000000},{
      0.754782, 1.299558, 0.000000},{0.755139, 1.299558, -0.004532}}],
    Polygon[{{0.756200, 1.308511, 0.000000},{0.756539, 1.308401, 0.004532},{
      0.755139, 1.299558, 0.004532},{0.754782, 1.299558, 0.000000}}],
    Polygon[{{0.756539, 1.308401, 0.004532},{0.757549, 1.308073, 0.008953},{
      0.756200, 1.299558, 0.008953},{0.755139, 1.299558, 0.004532}}],
    Polygon[{{0.757549, 1.308073, 0.008953},{0.759203, 1.307535, 0.013153},{
      0.757940, 1.299558, 0.013153},{0.756200, 1.299558, 0.008953}}],
    Polygon[{{0.759203, 1.307535, 0.013153},{0.761462, 1.306801, 0.017029},{
      0.760315, 1.299558, 0.017029},{0.757940, 1.299558, 0.013153}}],
    Polygon[{{0.761462, 1.306801, 0.017029},{0.764270, 1.305889, 0.020486},{
      0.763268, 1.299558, 0.020486},{0.760315, 1.299558, 0.017029}}],
    Polygon[{{0.764270, 1.305889, 0.020486},{0.767558, 1.304820, 0.023438},{
      0.766725, 1.299558, 0.023438},{0.763268, 1.299558, 0.020486}}],
    Polygon[{{0.767558, 1.304820, 0.023438},{0.771245, 1.303623, 0.025814},{
      0.770601, 1.299558, 0.025814},{0.766725, 1.299558, 0.023438}}],
    Polygon[{{0.771245, 1.303623, 0.025814},{0.775239, 1.302325, 0.027554},{
      0.774801, 1.299558, 0.027554},{0.770601, 1.299558, 0.025814}}],
    Polygon[{{0.775239, 1.302325, 0.027554},{0.779443, 1.300959, 0.028615},{
      0.779222, 1.299558, 0.028615},{0.774801, 1.299558, 0.027554}}],
    Polygon[{{0.779222, 1.299558, -0.028615},{0.774801, 1.299558, -0.027554},{
      0.775239, 1.296792, -0.027554},{0.779443, 1.298158, -0.028615}}],
    Polygon[{{0.774801, 1.299558, -0.027554},{0.770601, 1.299558, -0.025814},{
      0.771245, 1.295494, -0.025814},{0.775239, 1.296792, -0.027554}}],
    Polygon[{{0.770601, 1.299558, -0.025814},{0.766725, 1.299558, -0.023438},{
      0.767558, 1.294296, -0.023438},{0.771245, 1.295494, -0.025814}}],
    Polygon[{{0.766725, 1.299558, -0.023438},{0.763268, 1.299558, -0.020486},{
      0.764270, 1.293228, -0.020486},{0.767558, 1.294296, -0.023438}}],
    Polygon[{{0.763268, 1.299558, -0.020486},{0.760315, 1.299558, -0.017029},{
      0.761462, 1.292315, -0.017029},{0.764270, 1.293228, -0.020486}}],
    Polygon[{{0.760315, 1.299558, -0.017029},{0.757940, 1.299558, -0.013153},{
      0.759203, 1.291581, -0.013153},{0.761462, 1.292315, -0.017029}}],
    Polygon[{{0.757940, 1.299558, -0.013153},{0.756200, 1.299558, -0.008953},{
      0.757549, 1.291044, -0.008953},{0.759203, 1.291581, -0.013153}}],
    Polygon[{{0.756200, 1.299558, -0.008953},{0.755139, 1.299558, -0.004532},{
      0.756539, 1.290716, -0.004532},{0.757549, 1.291044, -0.008953}}],
    Polygon[{{0.755139, 1.299558, -0.004532},{0.754782, 1.299558, 0.000000},{
      0.756200, 1.290605, 0.000000},{0.756539, 1.290716, -0.004532}}],
    Polygon[{{0.754782, 1.299558, 0.000000},{0.755139, 1.299558, 0.004532},{
      0.756539, 1.290716, 0.004532},{0.756200, 1.290605, 0.000000}}],
    Polygon[{{0.755139, 1.299558, 0.004532},{0.756200, 1.299558, 0.008953},{
      0.757549, 1.291044, 0.008953},{0.756539, 1.290716, 0.004532}}],
    Polygon[{{0.756200, 1.299558, 0.008953},{0.757940, 1.299558, 0.013153},{
      0.759203, 1.291581, 0.013153},{0.757549, 1.291044, 0.008953}}],
    Polygon[{{0.757940, 1.299558, 0.013153},{0.760315, 1.299558, 0.017029},{
      0.761462, 1.292315, 0.017029},{0.759203, 1.291581, 0.013153}}],
    Polygon[{{0.760315, 1.299558, 0.017029},{0.763268, 1.299558, 0.020486},{
      0.764270, 1.293228, 0.020486},{0.761462, 1.292315, 0.017029}}],
    Polygon[{{0.763268, 1.299558, 0.020486},{0.766725, 1.299558, 0.023438},{
      0.767558, 1.294296, 0.023438},{0.764270, 1.293228, 0.020486}}],
    Polygon[{{0.766725, 1.299558, 0.023438},{0.770601, 1.299558, 0.025814},{
      0.771245, 1.295494, 0.025814},{0.767558, 1.294296, 0.023438}}],
    Polygon[{{0.770601, 1.299558, 0.025814},{0.774801, 1.299558, 0.027554},{
      0.775239, 1.296792, 0.027554},{0.771245, 1.295494, 0.025814}}],
    Polygon[{{0.774801, 1.299558, 0.027554},{0.779222, 1.299558, 0.028615},{
      0.779443, 1.298158, 0.028615},{0.775239, 1.296792, 0.027554}}],
    Polygon[{{0.779443, 1.298158, -0.028615},{0.775239, 1.296792, -0.027554},{
      0.776511, 1.294296, -0.027554},{0.780087, 1.296894, -0.028615}}],
    Polygon[{{0.775239, 1.296792, -0.027554},{0.771245, 1.295494, -0.025814},{
      0.773113, 1.291827, -0.025814},{0.776511, 1.294296, -0.027554}}],
    Polygon[{{0.771245, 1.295494, -0.025814},{0.767558, 1.294296, -0.023438},{
      0.769977, 1.289549, -0.023438},{0.773113, 1.291827, -0.025814}}],
    Polygon[{{0.767558, 1.294296, -0.023438},{0.764270, 1.293228, -0.020486},{
      0.767180, 1.287517, -0.020486},{0.769977, 1.289549, -0.023438}}],
    Polygon[{{0.764270, 1.293228, -0.020486},{0.761462, 1.292315, -0.017029},{
      0.764792, 1.285781, -0.017029},{0.767180, 1.287517, -0.020486}}],
    Polygon[{{0.761462, 1.292315, -0.017029},{0.759203, 1.291581, -0.013153},{
      0.762870, 1.284385, -0.013153},{0.764792, 1.285781, -0.017029}}],
    Polygon[{{0.759203, 1.291581, -0.013153},{0.757549, 1.291044, -0.008953},{
      0.761462, 1.283363, -0.008953},{0.762870, 1.284385, -0.013153}}],
    Polygon[{{0.757549, 1.291044, -0.008953},{0.756539, 1.290716, -0.004532},{
      0.760604, 1.282739, -0.004532},{0.761462, 1.283363, -0.008953}}],
    Polygon[{{0.756539, 1.290716, -0.004532},{0.756200, 1.290605, 0.000000},{
      0.760315, 1.282529, 0.000000},{0.760604, 1.282739, -0.004532}}],
    Polygon[{{0.756200, 1.290605, 0.000000},{0.756539, 1.290716, 0.004532},{
      0.760604, 1.282739, 0.004532},{0.760315, 1.282529, 0.000000}}],
    Polygon[{{0.756539, 1.290716, 0.004532},{0.757549, 1.291044, 0.008953},{
      0.761462, 1.283363, 0.008953},{0.760604, 1.282739, 0.004532}}],
    Polygon[{{0.757549, 1.291044, 0.008953},{0.759203, 1.291581, 0.013153},{
      0.762870, 1.284385, 0.013153},{0.761462, 1.283363, 0.008953}}],
    Polygon[{{0.759203, 1.291581, 0.013153},{0.761462, 1.292315, 0.017029},{
      0.764792, 1.285781, 0.017029},{0.762870, 1.284385, 0.013153}}],
    Polygon[{{0.761462, 1.292315, 0.017029},{0.764270, 1.293228, 0.020486},{
      0.767180, 1.287517, 0.020486},{0.764792, 1.285781, 0.017029}}],
    Polygon[{{0.764270, 1.293228, 0.020486},{0.767558, 1.294296, 0.023438},{
      0.769977, 1.289549, 0.023438},{0.767180, 1.287517, 0.020486}}],
    Polygon[{{0.767558, 1.294296, 0.023438},{0.771245, 1.295494, 0.025814},{
      0.773113, 1.291827, 0.025814},{0.769977, 1.289549, 0.023438}}],
    Polygon[{{0.771245, 1.295494, 0.025814},{0.775239, 1.296792, 0.027554},{
      0.776511, 1.294296, 0.027554},{0.773113, 1.291827, 0.025814}}],
    Polygon[{{0.775239, 1.296792, 0.027554},{0.779443, 1.298158, 0.028615},{
      0.780087, 1.296894, 0.028615},{0.776511, 1.294296, 0.027554}}],
    Polygon[{{0.780087, 1.296894, -0.028615},{0.776511, 1.294296, -0.027554},{
      0.778491, 1.292315, -0.027554},{0.781090, 1.295892, -0.028615}}],
    Polygon[{{0.776511, 1.294296, -0.027554},{0.773113, 1.291827, -0.025814},{
      0.776023, 1.288917, -0.025814},{0.778491, 1.292315, -0.027554}}],
    Polygon[{{0.773113, 1.291827, -0.025814},{0.769977, 1.289549, -0.023438},{
      0.773744, 1.285781, -0.023438},{0.776023, 1.288917, -0.025814}}],
    Polygon[{{0.769977, 1.289549, -0.023438},{0.767180, 1.287517, -0.020486},{
      0.771712, 1.282985, -0.020486},{0.773744, 1.285781, -0.023438}}],
    Polygon[{{0.767180, 1.287517, -0.020486},{0.764792, 1.285781, -0.017029},{
      0.769977, 1.280596, -0.017029},{0.771712, 1.282985, -0.020486}}],
    Polygon[{{0.764792, 1.285781, -0.017029},{0.762870, 1.284385, -0.013153},{
      0.768581, 1.278674, -0.013153},{0.769977, 1.280596, -0.017029}}],
    Polygon[{{0.762870, 1.284385, -0.013153},{0.761462, 1.283363, -0.008953},{
      0.767558, 1.277267, -0.008953},{0.768581, 1.278674, -0.013153}}],
    Polygon[{{0.761462, 1.283363, -0.008953},{0.760604, 1.282739, -0.004532},{
      0.766934, 1.276408, -0.004532},{0.767558, 1.277267, -0.008953}}],
    Polygon[{{0.760604, 1.282739, -0.004532},{0.760315, 1.282529, 0.000000},{
      0.766725, 1.276120, 0.000000},{0.766934, 1.276408, -0.004532}}],
    Polygon[{{0.760315, 1.282529, 0.000000},{0.760604, 1.282739, 0.004532},{
      0.766934, 1.276408, 0.004532},{0.766725, 1.276120, 0.000000}}],
    Polygon[{{0.760604, 1.282739, 0.004532},{0.761462, 1.283363, 0.008953},{
      0.767558, 1.277267, 0.008953},{0.766934, 1.276408, 0.004532}}],
    Polygon[{{0.761462, 1.283363, 0.008953},{0.762870, 1.284385, 0.013153},{
      0.768581, 1.278674, 0.013153},{0.767558, 1.277267, 0.008953}}],
    Polygon[{{0.762870, 1.284385, 0.013153},{0.764792, 1.285781, 0.017029},{
      0.769977, 1.280596, 0.017029},{0.768581, 1.278674, 0.013153}}],
    Polygon[{{0.764792, 1.285781, 0.017029},{0.767180, 1.287517, 0.020486},{
      0.771712, 1.282985, 0.020486},{0.769977, 1.280596, 0.017029}}],
    Polygon[{{0.767180, 1.287517, 0.020486},{0.769977, 1.289549, 0.023438},{
      0.773744, 1.285781, 0.023438},{0.771712, 1.282985, 0.020486}}],
    Polygon[{{0.769977, 1.289549, 0.023438},{0.773113, 1.291827, 0.025814},{
      0.776023, 1.288917, 0.025814},{0.773744, 1.285781, 0.023438}}],
    Polygon[{{0.773113, 1.291827, 0.025814},{0.776511, 1.294296, 0.027554},{
      0.778491, 1.292315, 0.027554},{0.776023, 1.288917, 0.025814}}],
    Polygon[{{0.776511, 1.294296, 0.027554},{0.780087, 1.296894, 0.028615},{
      0.781090, 1.295892, 0.028615},{0.778491, 1.292315, 0.027554}}],
    Polygon[{{0.781090, 1.295892, -0.028615},{0.778491, 1.292315, -0.027554},{
      0.780987, 1.291044, -0.027554},{0.782353, 1.295248, -0.028615}}],
    Polygon[{{0.778491, 1.292315, -0.027554},{0.776023, 1.288917, -0.025814},{
      0.779689, 1.287049, -0.025814},{0.780987, 1.291044, -0.027554}}],
    Polygon[{{0.776023, 1.288917, -0.025814},{0.773744, 1.285781, -0.023438},{
      0.778491, 1.283363, -0.023438},{0.779689, 1.287049, -0.025814}}],
    Polygon[{{0.773744, 1.285781, -0.023438},{0.771712, 1.282985, -0.020486},{
      0.777423, 1.280075, -0.020486},{0.778491, 1.283363, -0.023438}}],
    Polygon[{{0.771712, 1.282985, -0.020486},{0.769977, 1.280596, -0.017029},{
      0.776511, 1.277267, -0.017029},{0.777423, 1.280075, -0.020486}}],
    Polygon[{{0.769977, 1.280596, -0.017029},{0.768581, 1.278674, -0.013153},{
      0.775777, 1.275008, -0.013153},{0.776511, 1.277267, -0.017029}}],
    Polygon[{{0.768581, 1.278674, -0.013153},{0.767558, 1.277267, -0.008953},{
      0.775239, 1.273353, -0.008953},{0.775777, 1.275008, -0.013153}}],
    Polygon[{{0.767558, 1.277267, -0.008953},{0.766934, 1.276408, -0.004532},{
      0.774911, 1.272344, -0.004532},{0.775239, 1.273353, -0.008953}}],
    Polygon[{{0.766934, 1.276408, -0.004532},{0.766725, 1.276120, 0.000000},{
      0.774801, 1.272005, 0.000000},{0.774911, 1.272344, -0.004532}}],
    Polygon[{{0.766725, 1.276120, 0.000000},{0.766934, 1.276408, 0.004532},{
      0.774911, 1.272344, 0.004532},{0.774801, 1.272005, 0.000000}}],
    Polygon[{{0.766934, 1.276408, 0.004532},{0.767558, 1.277267, 0.008953},{
      0.775239, 1.273353, 0.008953},{0.774911, 1.272344, 0.004532}}],
    Polygon[{{0.767558, 1.277267, 0.008953},{0.768581, 1.278674, 0.013153},{
      0.775777, 1.275008, 0.013153},{0.775239, 1.273353, 0.008953}}],
    Polygon[{{0.768581, 1.278674, 0.013153},{0.769977, 1.280596, 0.017029},{
      0.776511, 1.277267, 0.017029},{0.775777, 1.275008, 0.013153}}],
    Polygon[{{0.769977, 1.280596, 0.017029},{0.771712, 1.282985, 0.020486},{
      0.777423, 1.280075, 0.020486},{0.776511, 1.277267, 0.017029}}],
    Polygon[{{0.771712, 1.282985, 0.020486},{0.773744, 1.285781, 0.023438},{
      0.778491, 1.283363, 0.023438},{0.777423, 1.280075, 0.020486}}],
    Polygon[{{0.773744, 1.285781, 0.023438},{0.776023, 1.288917, 0.025814},{
      0.779689, 1.287049, 0.025814},{0.778491, 1.283363, 0.023438}}],
    Polygon[{{0.776023, 1.288917, 0.025814},{0.778491, 1.292315, 0.027554},{
      0.780987, 1.291044, 0.027554},{0.779689, 1.287049, 0.025814}}],
    Polygon[{{0.778491, 1.292315, 0.027554},{0.781090, 1.295892, 0.028615},{
      0.782353, 1.295248, 0.028615},{0.780987, 1.291044, 0.027554}}],
    Polygon[{{0.782353, 1.295248, -0.028615},{0.780987, 1.291044, -0.027554},{
      0.783754, 1.290605, -0.027554},{0.783754, 1.295026, -0.028615}}],
    Polygon[{{0.780987, 1.291044, -0.027554},{0.779689, 1.287049, -0.025814},{
      0.783754, 1.286405, -0.025814},{0.783754, 1.290605, -0.027554}}],
    Polygon[{{0.779689, 1.287049, -0.025814},{0.778491, 1.283363, -0.023438},{
      0.783754, 1.282529, -0.023438},{0.783754, 1.286405, -0.025814}}],
    Polygon[{{0.778491, 1.283363, -0.023438},{0.777423, 1.280075, -0.020486},{
      0.783754, 1.279072, -0.020486},{0.783754, 1.282529, -0.023438}}],
    Polygon[{{0.777423, 1.280075, -0.020486},{0.776511, 1.277267, -0.017029},{
      0.783754, 1.276120, -0.017029},{0.783754, 1.279072, -0.020486}}],
    Polygon[{{0.776511, 1.277267, -0.017029},{0.775777, 1.275008, -0.013153},{
      0.783754, 1.273744, -0.013153},{0.783754, 1.276120, -0.017029}}],
    Polygon[{{0.775777, 1.275008, -0.013153},{0.775239, 1.273353, -0.008953},{
      0.783754, 1.272005, -0.008953},{0.783754, 1.273744, -0.013153}}],
    Polygon[{{0.775239, 1.273353, -0.008953},{0.774911, 1.272344, -0.004532},{
      0.783754, 1.270943, -0.004532},{0.783754, 1.272005, -0.008953}}],
    Polygon[{{0.774911, 1.272344, -0.004532},{0.774801, 1.272005, 0.000000},{
      0.783754, 1.270587, 0.000000},{0.783754, 1.270943, -0.004532}}],
    Polygon[{{0.774801, 1.272005, 0.000000},{0.774911, 1.272344, 0.004532},{
      0.783754, 1.270943, 0.004532},{0.783754, 1.270587, 0.000000}}],
    Polygon[{{0.774911, 1.272344, 0.004532},{0.775239, 1.273353, 0.008953},{
      0.783754, 1.272005, 0.008953},{0.783754, 1.270943, 0.004532}}],
    Polygon[{{0.775239, 1.273353, 0.008953},{0.775777, 1.275008, 0.013153},{
      0.783754, 1.273744, 0.013153},{0.783754, 1.272005, 0.008953}}],
    Polygon[{{0.775777, 1.275008, 0.013153},{0.776511, 1.277267, 0.017029},{
      0.783754, 1.276120, 0.017029},{0.783754, 1.273744, 0.013153}}],
    Polygon[{{0.776511, 1.277267, 0.017029},{0.777423, 1.280075, 0.020486},{
      0.783754, 1.279072, 0.020486},{0.783754, 1.276120, 0.017029}}],
    Polygon[{{0.777423, 1.280075, 0.020486},{0.778491, 1.283363, 0.023438},{
      0.783754, 1.282529, 0.023438},{0.783754, 1.279072, 0.020486}}],
    Polygon[{{0.778491, 1.283363, 0.023438},{0.779689, 1.287049, 0.025814},{
      0.783754, 1.286405, 0.025814},{0.783754, 1.282529, 0.023438}}],
    Polygon[{{0.779689, 1.287049, 0.025814},{0.780987, 1.291044, 0.027554},{
      0.783754, 1.290605, 0.027554},{0.783754, 1.286405, 0.025814}}],
    Polygon[{{0.780987, 1.291044, 0.027554},{0.782353, 1.295248, 0.028615},{
      0.783754, 1.295026, 0.028615},{0.783754, 1.290605, 0.027554}}],
    Polygon[{{0.783754, 1.295026, -0.028615},{0.783754, 1.290605, -0.027554},{
      0.786520, 1.291044, -0.027554},{0.785154, 1.295248, -0.028615}}],
    Polygon[{{0.783754, 1.290605, -0.027554},{0.783754, 1.286405, -0.025814},{
      0.787818, 1.287049, -0.025814},{0.786520, 1.291044, -0.027554}}],
    Polygon[{{0.783754, 1.286405, -0.025814},{0.783754, 1.282529, -0.023438},{
      0.789016, 1.283363, -0.023438},{0.787818, 1.287049, -0.025814}}],
    Polygon[{{0.783754, 1.282529, -0.023438},{0.783754, 1.279072, -0.020486},{
      0.790084, 1.280075, -0.020486},{0.789016, 1.283363, -0.023438}}],
    Polygon[{{0.783754, 1.279072, -0.020486},{0.783754, 1.276120, -0.017029},{
      0.790997, 1.277267, -0.017029},{0.790084, 1.280075, -0.020486}}],
    Polygon[{{0.783754, 1.276120, -0.017029},{0.783754, 1.273744, -0.013153},{
      0.791731, 1.275008, -0.013153},{0.790997, 1.277267, -0.017029}}],
    Polygon[{{0.783754, 1.273744, -0.013153},{0.783754, 1.272005, -0.008953},{
      0.792268, 1.273353, -0.008953},{0.791731, 1.275008, -0.013153}}],
    Polygon[{{0.783754, 1.272005, -0.008953},{0.783754, 1.270943, -0.004532},{
      0.792596, 1.272344, -0.004532},{0.792268, 1.273353, -0.008953}}],
    Polygon[{{0.783754, 1.270943, -0.004532},{0.783754, 1.270587, 0.000000},{
      0.792706, 1.272005, 0.000000},{0.792596, 1.272344, -0.004532}}],
    Polygon[{{0.783754, 1.270587, 0.000000},{0.783754, 1.270943, 0.004532},{
      0.792596, 1.272344, 0.004532},{0.792706, 1.272005, 0.000000}}],
    Polygon[{{0.783754, 1.270943, 0.004532},{0.783754, 1.272005, 0.008953},{
      0.792268, 1.273353, 0.008953},{0.792596, 1.272344, 0.004532}}],
    Polygon[{{0.783754, 1.272005, 0.008953},{0.783754, 1.273744, 0.013153},{
      0.791731, 1.275008, 0.013153},{0.792268, 1.273353, 0.008953}}],
    Polygon[{{0.783754, 1.273744, 0.013153},{0.783754, 1.276120, 0.017029},{
      0.790997, 1.277267, 0.017029},{0.791731, 1.275008, 0.013153}}],
    Polygon[{{0.783754, 1.276120, 0.017029},{0.783754, 1.279072, 0.020486},{
      0.790084, 1.280075, 0.020486},{0.790997, 1.277267, 0.017029}}],
    Polygon[{{0.783754, 1.279072, 0.020486},{0.783754, 1.282529, 0.023438},{
      0.789016, 1.283363, 0.023438},{0.790084, 1.280075, 0.020486}}],
    Polygon[{{0.783754, 1.282529, 0.023438},{0.783754, 1.286405, 0.025814},{
      0.787818, 1.287049, 0.025814},{0.789016, 1.283363, 0.023438}}],
    Polygon[{{0.783754, 1.286405, 0.025814},{0.783754, 1.290605, 0.027554},{
      0.786520, 1.291044, 0.027554},{0.787818, 1.287049, 0.025814}}],
    Polygon[{{0.783754, 1.290605, 0.027554},{0.783754, 1.295026, 0.028615},{
      0.785154, 1.295248, 0.028615},{0.786520, 1.291044, 0.027554}}],
    Polygon[{{0.785154, 1.295248, -0.028615},{0.786520, 1.291044, -0.027554},{
      0.789016, 1.292315, -0.027554},{0.786418, 1.295892, -0.028615}}],
    Polygon[{{0.786520, 1.291044, -0.027554},{0.787818, 1.287049, -0.025814},{
      0.791485, 1.288917, -0.025814},{0.789016, 1.292315, -0.027554}}],
    Polygon[{{0.787818, 1.287049, -0.025814},{0.789016, 1.283363, -0.023438},{
      0.793763, 1.285781, -0.023438},{0.791485, 1.288917, -0.025814}}],
    Polygon[{{0.789016, 1.283363, -0.023438},{0.790084, 1.280075, -0.020486},{
      0.795795, 1.282985, -0.020486},{0.793763, 1.285781, -0.023438}}],
    Polygon[{{0.790084, 1.280075, -0.020486},{0.790997, 1.277267, -0.017029},{
      0.797530, 1.280596, -0.017029},{0.795795, 1.282985, -0.020486}}],
    Polygon[{{0.790997, 1.277267, -0.017029},{0.791731, 1.275008, -0.013153},{
      0.798927, 1.278674, -0.013153},{0.797530, 1.280596, -0.017029}}],
    Polygon[{{0.791731, 1.275008, -0.013153},{0.792268, 1.273353, -0.008953},{
      0.799949, 1.277267, -0.008953},{0.798927, 1.278674, -0.013153}}],
    Polygon[{{0.792268, 1.273353, -0.008953},{0.792596, 1.272344, -0.004532},{
      0.800573, 1.276408, -0.004532},{0.799949, 1.277267, -0.008953}}],
    Polygon[{{0.792596, 1.272344, -0.004532},{0.792706, 1.272005, 0.000000},{
      0.800783, 1.276120, 0.000000},{0.800573, 1.276408, -0.004532}}],
    Polygon[{{0.792706, 1.272005, 0.000000},{0.792596, 1.272344, 0.004532},{
      0.800573, 1.276408, 0.004532},{0.800783, 1.276120, 0.000000}}],
    Polygon[{{0.792596, 1.272344, 0.004532},{0.792268, 1.273353, 0.008953},{
      0.799949, 1.277267, 0.008953},{0.800573, 1.276408, 0.004532}}],
    Polygon[{{0.792268, 1.273353, 0.008953},{0.791731, 1.275008, 0.013153},{
      0.798927, 1.278674, 0.013153},{0.799949, 1.277267, 0.008953}}],
    Polygon[{{0.791731, 1.275008, 0.013153},{0.790997, 1.277267, 0.017029},{
      0.797530, 1.280596, 0.017029},{0.798927, 1.278674, 0.013153}}],
    Polygon[{{0.790997, 1.277267, 0.017029},{0.790084, 1.280075, 0.020486},{
      0.795795, 1.282985, 0.020486},{0.797530, 1.280596, 0.017029}}],
    Polygon[{{0.790084, 1.280075, 0.020486},{0.789016, 1.283363, 0.023438},{
      0.793763, 1.285781, 0.023438},{0.795795, 1.282985, 0.020486}}],
    Polygon[{{0.789016, 1.283363, 0.023438},{0.787818, 1.287049, 0.025814},{
      0.791485, 1.288917, 0.025814},{0.793763, 1.285781, 0.023438}}],
    Polygon[{{0.787818, 1.287049, 0.025814},{0.786520, 1.291044, 0.027554},{
      0.789016, 1.292315, 0.027554},{0.791485, 1.288917, 0.025814}}],
    Polygon[{{0.786520, 1.291044, 0.027554},{0.785154, 1.295248, 0.028615},{
      0.786418, 1.295892, 0.028615},{0.789016, 1.292315, 0.027554}}],
    Polygon[{{0.786418, 1.295892, -0.028615},{0.789016, 1.292315, -0.027554},{
      0.790997, 1.294296, -0.027554},{0.787420, 1.296894, -0.028615}}],
    Polygon[{{0.789016, 1.292315, -0.027554},{0.791485, 1.288917, -0.025814},{
      0.794394, 1.291827, -0.025814},{0.790997, 1.294296, -0.027554}}],
    Polygon[{{0.791485, 1.288917, -0.025814},{0.793763, 1.285781, -0.023438},{
      0.797530, 1.289549, -0.023438},{0.794394, 1.291827, -0.025814}}],
    Polygon[{{0.793763, 1.285781, -0.023438},{0.795795, 1.282985, -0.020486},{
      0.800327, 1.287517, -0.020486},{0.797530, 1.289549, -0.023438}}],
    Polygon[{{0.795795, 1.282985, -0.020486},{0.797530, 1.280596, -0.017029},{
      0.802716, 1.285781, -0.017029},{0.800327, 1.287517, -0.020486}}],
    Polygon[{{0.797530, 1.280596, -0.017029},{0.798927, 1.278674, -0.013153},{
      0.804637, 1.284385, -0.013153},{0.802716, 1.285781, -0.017029}}],
    Polygon[{{0.798927, 1.278674, -0.013153},{0.799949, 1.277267, -0.008953},{
      0.806045, 1.283363, -0.008953},{0.804637, 1.284385, -0.013153}}],
    Polygon[{{0.799949, 1.277267, -0.008953},{0.800573, 1.276408, -0.004532},{
      0.806904, 1.282739, -0.004532},{0.806045, 1.283363, -0.008953}}],
    Polygon[{{0.800573, 1.276408, -0.004532},{0.800783, 1.276120, 0.000000},{
      0.807192, 1.282529, 0.000000},{0.806904, 1.282739, -0.004532}}],
    Polygon[{{0.800783, 1.276120, 0.000000},{0.800573, 1.276408, 0.004532},{
      0.806904, 1.282739, 0.004532},{0.807192, 1.282529, 0.000000}}],
    Polygon[{{0.800573, 1.276408, 0.004532},{0.799949, 1.277267, 0.008953},{
      0.806045, 1.283363, 0.008953},{0.806904, 1.282739, 0.004532}}],
    Polygon[{{0.799949, 1.277267, 0.008953},{0.798927, 1.278674, 0.013153},{
      0.804637, 1.284385, 0.013153},{0.806045, 1.283363, 0.008953}}],
    Polygon[{{0.798927, 1.278674, 0.013153},{0.797530, 1.280596, 0.017029},{
      0.802716, 1.285781, 0.017029},{0.804637, 1.284385, 0.013153}}],
    Polygon[{{0.797530, 1.280596, 0.017029},{0.795795, 1.282985, 0.020486},{
      0.800327, 1.287517, 0.020486},{0.802716, 1.285781, 0.017029}}],
    Polygon[{{0.795795, 1.282985, 0.020486},{0.793763, 1.285781, 0.023438},{
      0.797530, 1.289549, 0.023438},{0.800327, 1.287517, 0.020486}}],
    Polygon[{{0.793763, 1.285781, 0.023438},{0.791485, 1.288917, 0.025814},{
      0.794394, 1.291827, 0.025814},{0.797530, 1.289549, 0.023438}}],
    Polygon[{{0.791485, 1.288917, 0.025814},{0.789016, 1.292315, 0.027554},{
      0.790997, 1.294296, 0.027554},{0.794394, 1.291827, 0.025814}}],
    Polygon[{{0.789016, 1.292315, 0.027554},{0.786418, 1.295892, 0.028615},{
      0.787420, 1.296894, 0.028615},{0.790997, 1.294296, 0.027554}}],
    Polygon[{{0.787420, 1.296894, -0.028615},{0.790997, 1.294296, -0.027554},{
      0.792268, 1.296792, -0.027554},{0.788064, 1.298158, -0.028615}}],
    Polygon[{{0.790997, 1.294296, -0.027554},{0.794394, 1.291827, -0.025814},{
      0.796263, 1.295494, -0.025814},{0.792268, 1.296792, -0.027554}}],
    Polygon[{{0.794394, 1.291827, -0.025814},{0.797530, 1.289549, -0.023438},{
      0.799949, 1.294296, -0.023438},{0.796263, 1.295494, -0.025814}}],
    Polygon[{{0.797530, 1.289549, -0.023438},{0.800327, 1.287517, -0.020486},{
      0.803237, 1.293228, -0.020486},{0.799949, 1.294296, -0.023438}}],
    Polygon[{{0.800327, 1.287517, -0.020486},{0.802716, 1.285781, -0.017029},{
      0.806045, 1.292315, -0.017029},{0.803237, 1.293228, -0.020486}}],
    Polygon[{{0.802716, 1.285781, -0.017029},{0.804637, 1.284385, -0.013153},{
      0.808304, 1.291581, -0.013153},{0.806045, 1.292315, -0.017029}}],
    Polygon[{{0.804637, 1.284385, -0.013153},{0.806045, 1.283363, -0.008953},{
      0.809959, 1.291044, -0.008953},{0.808304, 1.291581, -0.013153}}],
    Polygon[{{0.806045, 1.283363, -0.008953},{0.806904, 1.282739, -0.004532},{
      0.810968, 1.290716, -0.004532},{0.809959, 1.291044, -0.008953}}],
    Polygon[{{0.806904, 1.282739, -0.004532},{0.807192, 1.282529, 0.000000},{
      0.811307, 1.290605, 0.000000},{0.810968, 1.290716, -0.004532}}],
    Polygon[{{0.807192, 1.282529, 0.000000},{0.806904, 1.282739, 0.004532},{
      0.810968, 1.290716, 0.004532},{0.811307, 1.290605, 0.000000}}],
    Polygon[{{0.806904, 1.282739, 0.004532},{0.806045, 1.283363, 0.008953},{
      0.809959, 1.291044, 0.008953},{0.810968, 1.290716, 0.004532}}],
    Polygon[{{0.806045, 1.283363, 0.008953},{0.804637, 1.284385, 0.013153},{
      0.808304, 1.291581, 0.013153},{0.809959, 1.291044, 0.008953}}],
    Polygon[{{0.804637, 1.284385, 0.013153},{0.802716, 1.285781, 0.017029},{
      0.806045, 1.292315, 0.017029},{0.808304, 1.291581, 0.013153}}],
    Polygon[{{0.802716, 1.285781, 0.017029},{0.800327, 1.287517, 0.020486},{
      0.803237, 1.293228, 0.020486},{0.806045, 1.292315, 0.017029}}],
    Polygon[{{0.800327, 1.287517, 0.020486},{0.797530, 1.289549, 0.023438},{
      0.799949, 1.294296, 0.023438},{0.803237, 1.293228, 0.020486}}],
    Polygon[{{0.797530, 1.289549, 0.023438},{0.794394, 1.291827, 0.025814},{
      0.796263, 1.295494, 0.025814},{0.799949, 1.294296, 0.023438}}],
    Polygon[{{0.794394, 1.291827, 0.025814},{0.790997, 1.294296, 0.027554},{
      0.792268, 1.296792, 0.027554},{0.796263, 1.295494, 0.025814}}],
    Polygon[{{0.790997, 1.294296, 0.027554},{0.787420, 1.296894, 0.028615},{
      0.788064, 1.298158, 0.028615},{0.792268, 1.296792, 0.027554}}],
    Polygon[{{0.788064, 1.298158, -0.028615},{0.792268, 1.296792, -0.027554},{
      0.792706, 1.299558, -0.027554},{0.788286, 1.299558, -0.028615}}],
    Polygon[{{0.792268, 1.296792, -0.027554},{0.796263, 1.295494, -0.025814},{
      0.796906, 1.299558, -0.025814},{0.792706, 1.299558, -0.027554}}],
    Polygon[{{0.796263, 1.295494, -0.025814},{0.799949, 1.294296, -0.023438},{
      0.800783, 1.299558, -0.023438},{0.796906, 1.299558, -0.025814}}],
    Polygon[{{0.799949, 1.294296, -0.023438},{0.803237, 1.293228, -0.020486},{
      0.804240, 1.299558, -0.020486},{0.800783, 1.299558, -0.023438}}],
    Polygon[{{0.803237, 1.293228, -0.020486},{0.806045, 1.292315, -0.017029},{
      0.807192, 1.299558, -0.017029},{0.804240, 1.299558, -0.020486}}],
    Polygon[{{0.806045, 1.292315, -0.017029},{0.808304, 1.291581, -0.013153},{
      0.809567, 1.299558, -0.013153},{0.807192, 1.299558, -0.017029}}],
    Polygon[{{0.808304, 1.291581, -0.013153},{0.809959, 1.291044, -0.008953},{
      0.811307, 1.299558, -0.008953},{0.809567, 1.299558, -0.013153}}],
    Polygon[{{0.809959, 1.291044, -0.008953},{0.810968, 1.290716, -0.004532},{
      0.812369, 1.299558, -0.004532},{0.811307, 1.299558, -0.008953}}],
    Polygon[{{0.810968, 1.290716, -0.004532},{0.811307, 1.290605, 0.000000},{
      0.812725, 1.299558, 0.000000},{0.812369, 1.299558, -0.004532}}],
    Polygon[{{0.811307, 1.290605, 0.000000},{0.810968, 1.290716, 0.004532},{
      0.812369, 1.299558, 0.004532},{0.812725, 1.299558, 0.000000}}],
    Polygon[{{0.810968, 1.290716, 0.004532},{0.809959, 1.291044, 0.008953},{
      0.811307, 1.299558, 0.008953},{0.812369, 1.299558, 0.004532}}],
    Polygon[{{0.809959, 1.291044, 0.008953},{0.808304, 1.291581, 0.013153},{
      0.809567, 1.299558, 0.013153},{0.811307, 1.299558, 0.008953}}],
    Polygon[{{0.808304, 1.291581, 0.013153},{0.806045, 1.292315, 0.017029},{
      0.807192, 1.299558, 0.017029},{0.809567, 1.299558, 0.013153}}],
    Polygon[{{0.806045, 1.292315, 0.017029},{0.803237, 1.293228, 0.020486},{
      0.804240, 1.299558, 0.020486},{0.807192, 1.299558, 0.017029}}],
    Polygon[{{0.803237, 1.293228, 0.020486},{0.799949, 1.294296, 0.023438},{
      0.800783, 1.299558, 0.023438},{0.804240, 1.299558, 0.020486}}],
    Polygon[{{0.799949, 1.294296, 0.023438},{0.796263, 1.295494, 0.025814},{
      0.796906, 1.299558, 0.025814},{0.800783, 1.299558, 0.023438}}],
    Polygon[{{0.796263, 1.295494, 0.025814},{0.792268, 1.296792, 0.027554},{
      0.792706, 1.299558, 0.027554},{0.796906, 1.299558, 0.025814}}],
    Polygon[{{0.792268, 1.296792, 0.027554},{0.788064, 1.298158, 0.028615},{
      0.788286, 1.299558, 0.028615},{0.792706, 1.299558, 0.027554}}],
    Polygon[{{0.794912, 1.342678, -0.014853},{0.797207, 1.342678, -0.014302},{
      0.796980, 1.344114, -0.014302},{0.794797, 1.343405, -0.014853}}],
    Polygon[{{0.797207, 1.342678, -0.014302},{0.799387, 1.342678, -0.013399},{
      0.799053, 1.344787, -0.013399},{0.796980, 1.344114, -0.014302}}],
    Polygon[{{0.799387, 1.342678, -0.013399},{0.801399, 1.342678, -0.012166},{
      0.800967, 1.345409, -0.012166},{0.799053, 1.344787, -0.013399}}],
    Polygon[{{0.801399, 1.342678, -0.012166},{0.803194, 1.342678, -0.010634},{
      0.802673, 1.345964, -0.010634},{0.800967, 1.345409, -0.012166}}],
    Polygon[{{0.803194, 1.342678, -0.010634},{0.804726, 1.342678, -0.008839},{
      0.804131, 1.346437, -0.008839},{0.802673, 1.345964, -0.010634}}],
    Polygon[{{0.804726, 1.342678, -0.008839},{0.805959, 1.342678, -0.006827},{
      0.805303, 1.346818, -0.006827},{0.804131, 1.346437, -0.008839}}],
    Polygon[{{0.805959, 1.342678, -0.006827},{0.806862, 1.342678, -0.004647},{
      0.806162, 1.347097, -0.004647},{0.805303, 1.346818, -0.006827}}],
    Polygon[{{0.806862, 1.342678, -0.004647},{0.807413, 1.342678, -0.002352},{
      0.806686, 1.347268, -0.002352},{0.806162, 1.347097, -0.004647}}],
    Polygon[{{0.807413, 1.342678, -0.002352},{0.807598, 1.342678, 0.000000},{
      0.806862, 1.347325, 0.000000},{0.806686, 1.347268, -0.002352}}],
    Polygon[{{0.807598, 1.342678, 0.000000},{0.807413, 1.342678, 0.002352},{
      0.806686, 1.347268, 0.002352},{0.806862, 1.347325, 0.000000}}],
    Polygon[{{0.807413, 1.342678, 0.002352},{0.806862, 1.342678, 0.004647},{
      0.806162, 1.347097, 0.004647},{0.806686, 1.347268, 0.002352}}],
    Polygon[{{0.806862, 1.342678, 0.004647},{0.805959, 1.342678, 0.006827},{
      0.805303, 1.346818, 0.006827},{0.806162, 1.347097, 0.004647}}],
    Polygon[{{0.805959, 1.342678, 0.006827},{0.804726, 1.342678, 0.008839},{
      0.804131, 1.346437, 0.008839},{0.805303, 1.346818, 0.006827}}],
    Polygon[{{0.804726, 1.342678, 0.008839},{0.803194, 1.342678, 0.010634},{
      0.802673, 1.345964, 0.010634},{0.804131, 1.346437, 0.008839}}],
    Polygon[{{0.803194, 1.342678, 0.010634},{0.801399, 1.342678, 0.012166},{
      0.800967, 1.345409, 0.012166},{0.802673, 1.345964, 0.010634}}],
    Polygon[{{0.801399, 1.342678, 0.012166},{0.799387, 1.342678, 0.013399},{
      0.799053, 1.344787, 0.013399},{0.800967, 1.345409, 0.012166}}],
    Polygon[{{0.799387, 1.342678, 0.013399},{0.797207, 1.342678, 0.014302},{
      0.796980, 1.344114, 0.014302},{0.799053, 1.344787, 0.013399}}],
    Polygon[{{0.797207, 1.342678, 0.014302},{0.794912, 1.342678, 0.014853},{
      0.794797, 1.343405, 0.014853},{0.796980, 1.344114, 0.014302}}],
    Polygon[{{0.794797, 1.343405, -0.014853},{0.796980, 1.344114, -0.014302},{
      0.796319, 1.345409, -0.014302},{0.794463, 1.344061, -0.014853}}],
    Polygon[{{0.796980, 1.344114, -0.014302},{0.799053, 1.344787, -0.013399},{
      0.798083, 1.346691, -0.013399},{0.796319, 1.345409, -0.014302}}],
    Polygon[{{0.799053, 1.344787, -0.013399},{0.800967, 1.345409, -0.012166},{
      0.799711, 1.347873, -0.012166},{0.798083, 1.346691, -0.013399}}],
    Polygon[{{0.800967, 1.345409, -0.012166},{0.802673, 1.345964, -0.010634},{
      0.801163, 1.348928, -0.010634},{0.799711, 1.347873, -0.012166}}],
    Polygon[{{0.802673, 1.345964, -0.010634},{0.804131, 1.346437, -0.008839},{
      0.802403, 1.349829, -0.008839},{0.801163, 1.348928, -0.010634}}],
    Polygon[{{0.804131, 1.346437, -0.008839},{0.805303, 1.346818, -0.006827},{
      0.803400, 1.350554, -0.006827},{0.802403, 1.349829, -0.008839}}],
    Polygon[{{0.805303, 1.346818, -0.006827},{0.806162, 1.347097, -0.004647},{
      0.804131, 1.351084, -0.004647},{0.803400, 1.350554, -0.006827}}],
    Polygon[{{0.806162, 1.347097, -0.004647},{0.806686, 1.347268, -0.002352},{
      0.804576, 1.351408, -0.002352},{0.804131, 1.351084, -0.004647}}],
    Polygon[{{0.806686, 1.347268, -0.002352},{0.806862, 1.347325, 0.000000},{
      0.804726, 1.351517, 0.000000},{0.804576, 1.351408, -0.002352}}],
    Polygon[{{0.806862, 1.347325, 0.000000},{0.806686, 1.347268, 0.002352},{
      0.804576, 1.351408, 0.002352},{0.804726, 1.351517, 0.000000}}],
    Polygon[{{0.806686, 1.347268, 0.002352},{0.806162, 1.347097, 0.004647},{
      0.804131, 1.351084, 0.004647},{0.804576, 1.351408, 0.002352}}],
    Polygon[{{0.806162, 1.347097, 0.004647},{0.805303, 1.346818, 0.006827},{
      0.803400, 1.350554, 0.006827},{0.804131, 1.351084, 0.004647}}],
    Polygon[{{0.805303, 1.346818, 0.006827},{0.804131, 1.346437, 0.008839},{
      0.802403, 1.349829, 0.008839},{0.803400, 1.350554, 0.006827}}],
    Polygon[{{0.804131, 1.346437, 0.008839},{0.802673, 1.345964, 0.010634},{
      0.801163, 1.348928, 0.010634},{0.802403, 1.349829, 0.008839}}],
    Polygon[{{0.802673, 1.345964, 0.010634},{0.800967, 1.345409, 0.012166},{
      0.799711, 1.347873, 0.012166},{0.801163, 1.348928, 0.010634}}],
    Polygon[{{0.800967, 1.345409, 0.012166},{0.799053, 1.344787, 0.013399},{
      0.798083, 1.346691, 0.013399},{0.799711, 1.347873, 0.012166}}],
    Polygon[{{0.799053, 1.344787, 0.013399},{0.796980, 1.344114, 0.014302},{
      0.796319, 1.345409, 0.014302},{0.798083, 1.346691, 0.013399}}],
    Polygon[{{0.796980, 1.344114, 0.014302},{0.794797, 1.343405, 0.014853},{
      0.794463, 1.344061, 0.014853},{0.796319, 1.345409, 0.014302}}],
    Polygon[{{0.794463, 1.344061, -0.014853},{0.796319, 1.345409, -0.014302},{
      0.795291, 1.346437, -0.014302},{0.793943, 1.344581, -0.014853}}],
    Polygon[{{0.796319, 1.345409, -0.014302},{0.798083, 1.346691, -0.013399},{
      0.796573, 1.348201, -0.013399},{0.795291, 1.346437, -0.014302}}],
    Polygon[{{0.798083, 1.346691, -0.013399},{0.799711, 1.347873, -0.012166},{
      0.797756, 1.349829, -0.012166},{0.796573, 1.348201, -0.013399}}],
    Polygon[{{0.799711, 1.347873, -0.012166},{0.801163, 1.348928, -0.010634},{
      0.798810, 1.351280, -0.010634},{0.797756, 1.349829, -0.012166}}],
    Polygon[{{0.801163, 1.348928, -0.010634},{0.802403, 1.349829, -0.008839},{
      0.799711, 1.352520, -0.008839},{0.798810, 1.351280, -0.010634}}],
    Polygon[{{0.802403, 1.349829, -0.008839},{0.803400, 1.350554, -0.006827},{
      0.800436, 1.353518, -0.006827},{0.799711, 1.352520, -0.008839}}],
    Polygon[{{0.803400, 1.350554, -0.006827},{0.804131, 1.351084, -0.004647},{
      0.800967, 1.354248, -0.004647},{0.800436, 1.353518, -0.006827}}],
    Polygon[{{0.804131, 1.351084, -0.004647},{0.804576, 1.351408, -0.002352},{
      0.801290, 1.354694, -0.002352},{0.800967, 1.354248, -0.004647}}],
    Polygon[{{0.804576, 1.351408, -0.002352},{0.804726, 1.351517, 0.000000},{
      0.801399, 1.354844, 0.000000},{0.801290, 1.354694, -0.002352}}],
    Polygon[{{0.804726, 1.351517, 0.000000},{0.804576, 1.351408, 0.002352},{
      0.801290, 1.354694, 0.002352},{0.801399, 1.354844, 0.000000}}],
    Polygon[{{0.804576, 1.351408, 0.002352},{0.804131, 1.351084, 0.004647},{
      0.800967, 1.354248, 0.004647},{0.801290, 1.354694, 0.002352}}],
    Polygon[{{0.804131, 1.351084, 0.004647},{0.803400, 1.350554, 0.006827},{
      0.800436, 1.353518, 0.006827},{0.800967, 1.354248, 0.004647}}],
    Polygon[{{0.803400, 1.350554, 0.006827},{0.802403, 1.349829, 0.008839},{
      0.799711, 1.352520, 0.008839},{0.800436, 1.353518, 0.006827}}],
    Polygon[{{0.802403, 1.349829, 0.008839},{0.801163, 1.348928, 0.010634},{
      0.798810, 1.351280, 0.010634},{0.799711, 1.352520, 0.008839}}],
    Polygon[{{0.801163, 1.348928, 0.010634},{0.799711, 1.347873, 0.012166},{
      0.797756, 1.349829, 0.012166},{0.798810, 1.351280, 0.010634}}],
    Polygon[{{0.799711, 1.347873, 0.012166},{0.798083, 1.346691, 0.013399},{
      0.796573, 1.348201, 0.013399},{0.797756, 1.349829, 0.012166}}],
    Polygon[{{0.798083, 1.346691, 0.013399},{0.796319, 1.345409, 0.014302},{
      0.795291, 1.346437, 0.014302},{0.796573, 1.348201, 0.013399}}],
    Polygon[{{0.796319, 1.345409, 0.014302},{0.794463, 1.344061, 0.014853},{
      0.793943, 1.344581, 0.014853},{0.795291, 1.346437, 0.014302}}],
    Polygon[{{0.793943, 1.344581, -0.014853},{0.795291, 1.346437, -0.014302},{
      0.793996, 1.347097, -0.014302},{0.793287, 1.344915, -0.014853}}],
    Polygon[{{0.795291, 1.346437, -0.014302},{0.796573, 1.348201, -0.013399},{
      0.794670, 1.349171, -0.013399},{0.793996, 1.347097, -0.014302}}],
    Polygon[{{0.796573, 1.348201, -0.013399},{0.797756, 1.349829, -0.012166},{
      0.795291, 1.351084, -0.012166},{0.794670, 1.349171, -0.013399}}],
    Polygon[{{0.797756, 1.349829, -0.012166},{0.798810, 1.351280, -0.010634},{
      0.795846, 1.352791, -0.010634},{0.795291, 1.351084, -0.012166}}],
    Polygon[{{0.798810, 1.351280, -0.010634},{0.799711, 1.352520, -0.008839},{
      0.796319, 1.354248, -0.008839},{0.795846, 1.352791, -0.010634}}],
    Polygon[{{0.799711, 1.352520, -0.008839},{0.800436, 1.353518, -0.006827},{
      0.796700, 1.355421, -0.006827},{0.796319, 1.354248, -0.008839}}],
    Polygon[{{0.800436, 1.353518, -0.006827},{0.800967, 1.354248, -0.004647},{
      0.796980, 1.356280, -0.004647},{0.796700, 1.355421, -0.006827}}],
    Polygon[{{0.800967, 1.354248, -0.004647},{0.801290, 1.354694, -0.002352},{
      0.797150, 1.356804, -0.002352},{0.796980, 1.356280, -0.004647}}],
    Polygon[{{0.801290, 1.354694, -0.002352},{0.801399, 1.354844, 0.000000},{
      0.797207, 1.356980, 0.000000},{0.797150, 1.356804, -0.002352}}],
    Polygon[{{0.801399, 1.354844, 0.000000},{0.801290, 1.354694, 0.002352},{
      0.797150, 1.356804, 0.002352},{0.797207, 1.356980, 0.000000}}],
    Polygon[{{0.801290, 1.354694, 0.002352},{0.800967, 1.354248, 0.004647},{
      0.796980, 1.356280, 0.004647},{0.797150, 1.356804, 0.002352}}],
    Polygon[{{0.800967, 1.354248, 0.004647},{0.800436, 1.353518, 0.006827},{
      0.796700, 1.355421, 0.006827},{0.796980, 1.356280, 0.004647}}],
    Polygon[{{0.800436, 1.353518, 0.006827},{0.799711, 1.352520, 0.008839},{
      0.796319, 1.354248, 0.008839},{0.796700, 1.355421, 0.006827}}],
    Polygon[{{0.799711, 1.352520, 0.008839},{0.798810, 1.351280, 0.010634},{
      0.795846, 1.352791, 0.010634},{0.796319, 1.354248, 0.008839}}],
    Polygon[{{0.798810, 1.351280, 0.010634},{0.797756, 1.349829, 0.012166},{
      0.795291, 1.351084, 0.012166},{0.795846, 1.352791, 0.010634}}],
    Polygon[{{0.797756, 1.349829, 0.012166},{0.796573, 1.348201, 0.013399},{
      0.794670, 1.349171, 0.013399},{0.795291, 1.351084, 0.012166}}],
    Polygon[{{0.796573, 1.348201, 0.013399},{0.795291, 1.346437, 0.014302},{
      0.793996, 1.347097, 0.014302},{0.794670, 1.349171, 0.013399}}],
    Polygon[{{0.795291, 1.346437, 0.014302},{0.793943, 1.344581, 0.014853},{
      0.793287, 1.344915, 0.014853},{0.793996, 1.347097, 0.014302}}],
    Polygon[{{0.793287, 1.344915, -0.014853},{0.793996, 1.347097, -0.014302},{
      0.792560, 1.347325, -0.014302},{0.792560, 1.345030, -0.014853}}],
    Polygon[{{0.793996, 1.347097, -0.014302},{0.794670, 1.349171, -0.013399},{
      0.792560, 1.349505, -0.013399},{0.792560, 1.347325, -0.014302}}],
    Polygon[{{0.794670, 1.349171, -0.013399},{0.795291, 1.351084, -0.012166},{
      0.792560, 1.351517, -0.012166},{0.792560, 1.349505, -0.013399}}],
    Polygon[{{0.795291, 1.351084, -0.012166},{0.795846, 1.352791, -0.010634},{
      0.792560, 1.353311, -0.010634},{0.792560, 1.351517, -0.012166}}],
    Polygon[{{0.795846, 1.352791, -0.010634},{0.796319, 1.354248, -0.008839},{
      0.792560, 1.354844, -0.008839},{0.792560, 1.353311, -0.010634}}],
    Polygon[{{0.796319, 1.354248, -0.008839},{0.796700, 1.355421, -0.006827},{
      0.792560, 1.356077, -0.006827},{0.792560, 1.354844, -0.008839}}],
    Polygon[{{0.796700, 1.355421, -0.006827},{0.796980, 1.356280, -0.004647},{
      0.792560, 1.356980, -0.004647},{0.792560, 1.356077, -0.006827}}],
    Polygon[{{0.796980, 1.356280, -0.004647},{0.797150, 1.356804, -0.002352},{
      0.792560, 1.357531, -0.002352},{0.792560, 1.356980, -0.004647}}],
    Polygon[{{0.797150, 1.356804, -0.002352},{0.797207, 1.356980, 0.000000},{
      0.792560, 1.357716, 0.000000},{0.792560, 1.357531, -0.002352}}],
    Polygon[{{0.797207, 1.356980, 0.000000},{0.797150, 1.356804, 0.002352},{
      0.792560, 1.357531, 0.002352},{0.792560, 1.357716, 0.000000}}],
    Polygon[{{0.797150, 1.356804, 0.002352},{0.796980, 1.356280, 0.004647},{
      0.792560, 1.356980, 0.004647},{0.792560, 1.357531, 0.002352}}],
    Polygon[{{0.796980, 1.356280, 0.004647},{0.796700, 1.355421, 0.006827},{
      0.792560, 1.356077, 0.006827},{0.792560, 1.356980, 0.004647}}],
    Polygon[{{0.796700, 1.355421, 0.006827},{0.796319, 1.354248, 0.008839},{
      0.792560, 1.354844, 0.008839},{0.792560, 1.356077, 0.006827}}],
    Polygon[{{0.796319, 1.354248, 0.008839},{0.795846, 1.352791, 0.010634},{
      0.792560, 1.353311, 0.010634},{0.792560, 1.354844, 0.008839}}],
    Polygon[{{0.795846, 1.352791, 0.010634},{0.795291, 1.351084, 0.012166},{
      0.792560, 1.351517, 0.012166},{0.792560, 1.353311, 0.010634}}],
    Polygon[{{0.795291, 1.351084, 0.012166},{0.794670, 1.349171, 0.013399},{
      0.792560, 1.349505, 0.013399},{0.792560, 1.351517, 0.012166}}],
    Polygon[{{0.794670, 1.349171, 0.013399},{0.793996, 1.347097, 0.014302},{
      0.792560, 1.347325, 0.014302},{0.792560, 1.349505, 0.013399}}],
    Polygon[{{0.793996, 1.347097, 0.014302},{0.793287, 1.344915, 0.014853},{
      0.792560, 1.345030, 0.014853},{0.792560, 1.347325, 0.014302}}],
    Polygon[{{0.792560, 1.345030, -0.014853},{0.792560, 1.347325, -0.014302},{
      0.791124, 1.347097, -0.014302},{0.791833, 1.344915, -0.014853}}],
    Polygon[{{0.792560, 1.347325, -0.014302},{0.792560, 1.349505, -0.013399},{
      0.790450, 1.349171, -0.013399},{0.791124, 1.347097, -0.014302}}],
    Polygon[{{0.792560, 1.349505, -0.013399},{0.792560, 1.351517, -0.012166},{
      0.789828, 1.351084, -0.012166},{0.790450, 1.349171, -0.013399}}],
    Polygon[{{0.792560, 1.351517, -0.012166},{0.792560, 1.353311, -0.010634},{
      0.789274, 1.352791, -0.010634},{0.789828, 1.351084, -0.012166}}],
    Polygon[{{0.792560, 1.353311, -0.010634},{0.792560, 1.354844, -0.008839},{
      0.788800, 1.354248, -0.008839},{0.789274, 1.352791, -0.010634}}],
    Polygon[{{0.792560, 1.354844, -0.008839},{0.792560, 1.356077, -0.006827},{
      0.788419, 1.355421, -0.006827},{0.788800, 1.354248, -0.008839}}],
    Polygon[{{0.792560, 1.356077, -0.006827},{0.792560, 1.356980, -0.004647},{
      0.788140, 1.356280, -0.004647},{0.788419, 1.355421, -0.006827}}],
    Polygon[{{0.792560, 1.356980, -0.004647},{0.792560, 1.357531, -0.002352},{
      0.787970, 1.356804, -0.002352},{0.788140, 1.356280, -0.004647}}],
    Polygon[{{0.792560, 1.357531, -0.002352},{0.792560, 1.357716, 0.000000},{
      0.787913, 1.356980, 0.000000},{0.787970, 1.356804, -0.002352}}],
    Polygon[{{0.792560, 1.357716, 0.000000},{0.792560, 1.357531, 0.002352},{
      0.787970, 1.356804, 0.002352},{0.787913, 1.356980, 0.000000}}],
    Polygon[{{0.792560, 1.357531, 0.002352},{0.792560, 1.356980, 0.004647},{
      0.788140, 1.356280, 0.004647},{0.787970, 1.356804, 0.002352}}],
    Polygon[{{0.792560, 1.356980, 0.004647},{0.792560, 1.356077, 0.006827},{
      0.788419, 1.355421, 0.006827},{0.788140, 1.356280, 0.004647}}],
    Polygon[{{0.792560, 1.356077, 0.006827},{0.792560, 1.354844, 0.008839},{
      0.788800, 1.354248, 0.008839},{0.788419, 1.355421, 0.006827}}],
    Polygon[{{0.792560, 1.354844, 0.008839},{0.792560, 1.353311, 0.010634},{
      0.789274, 1.352791, 0.010634},{0.788800, 1.354248, 0.008839}}],
    Polygon[{{0.792560, 1.353311, 0.010634},{0.792560, 1.351517, 0.012166},{
      0.789828, 1.351084, 0.012166},{0.789274, 1.352791, 0.010634}}],
    Polygon[{{0.792560, 1.351517, 0.012166},{0.792560, 1.349505, 0.013399},{
      0.790450, 1.349171, 0.013399},{0.789828, 1.351084, 0.012166}}],
    Polygon[{{0.792560, 1.349505, 0.013399},{0.792560, 1.347325, 0.014302},{
      0.791124, 1.347097, 0.014302},{0.790450, 1.349171, 0.013399}}],
    Polygon[{{0.792560, 1.347325, 0.014302},{0.792560, 1.345030, 0.014853},{
      0.791833, 1.344915, 0.014853},{0.791124, 1.347097, 0.014302}}],
    Polygon[{{0.791833, 1.344915, -0.014853},{0.791124, 1.347097, -0.014302},{
      0.789828, 1.346437, -0.014302},{0.791177, 1.344581, -0.014853}}],
    Polygon[{{0.791124, 1.347097, -0.014302},{0.790450, 1.349171, -0.013399},{
      0.788547, 1.348201, -0.013399},{0.789828, 1.346437, -0.014302}}],
    Polygon[{{0.790450, 1.349171, -0.013399},{0.789828, 1.351084, -0.012166},{
      0.787364, 1.349829, -0.012166},{0.788547, 1.348201, -0.013399}}],
    Polygon[{{0.789828, 1.351084, -0.012166},{0.789274, 1.352791, -0.010634},{
      0.786310, 1.351280, -0.010634},{0.787364, 1.349829, -0.012166}}],
    Polygon[{{0.789274, 1.352791, -0.010634},{0.788800, 1.354248, -0.008839},{
      0.785409, 1.352520, -0.008839},{0.786310, 1.351280, -0.010634}}],
    Polygon[{{0.788800, 1.354248, -0.008839},{0.788419, 1.355421, -0.006827},{
      0.784684, 1.353518, -0.006827},{0.785409, 1.352520, -0.008839}}],
    Polygon[{{0.788419, 1.355421, -0.006827},{0.788140, 1.356280, -0.004647},{
      0.784153, 1.354248, -0.004647},{0.784684, 1.353518, -0.006827}}],
    Polygon[{{0.788140, 1.356280, -0.004647},{0.787970, 1.356804, -0.002352},{
      0.783830, 1.354694, -0.002352},{0.784153, 1.354248, -0.004647}}],
    Polygon[{{0.787970, 1.356804, -0.002352},{0.787913, 1.356980, 0.000000},{
      0.783721, 1.354844, 0.000000},{0.783830, 1.354694, -0.002352}}],
    Polygon[{{0.787913, 1.356980, 0.000000},{0.787970, 1.356804, 0.002352},{
      0.783830, 1.354694, 0.002352},{0.783721, 1.354844, 0.000000}}],
    Polygon[{{0.787970, 1.356804, 0.002352},{0.788140, 1.356280, 0.004647},{
      0.784153, 1.354248, 0.004647},{0.783830, 1.354694, 0.002352}}],
    Polygon[{{0.788140, 1.356280, 0.004647},{0.788419, 1.355421, 0.006827},{
      0.784684, 1.353518, 0.006827},{0.784153, 1.354248, 0.004647}}],
    Polygon[{{0.788419, 1.355421, 0.006827},{0.788800, 1.354248, 0.008839},{
      0.785409, 1.352520, 0.008839},{0.784684, 1.353518, 0.006827}}],
    Polygon[{{0.788800, 1.354248, 0.008839},{0.789274, 1.352791, 0.010634},{
      0.786310, 1.351280, 0.010634},{0.785409, 1.352520, 0.008839}}],
    Polygon[{{0.789274, 1.352791, 0.010634},{0.789828, 1.351084, 0.012166},{
      0.787364, 1.349829, 0.012166},{0.786310, 1.351280, 0.010634}}],
    Polygon[{{0.789828, 1.351084, 0.012166},{0.790450, 1.349171, 0.013399},{
      0.788547, 1.348201, 0.013399},{0.787364, 1.349829, 0.012166}}],
    Polygon[{{0.790450, 1.349171, 0.013399},{0.791124, 1.347097, 0.014302},{
      0.789828, 1.346437, 0.014302},{0.788547, 1.348201, 0.013399}}],
    Polygon[{{0.791124, 1.347097, 0.014302},{0.791833, 1.344915, 0.014853},{
      0.791177, 1.344581, 0.014853},{0.789828, 1.346437, 0.014302}}],
    Polygon[{{0.791177, 1.344581, -0.014853},{0.789828, 1.346437, -0.014302},{
      0.788800, 1.345409, -0.014302},{0.790657, 1.344061, -0.014853}}],
    Polygon[{{0.789828, 1.346437, -0.014302},{0.788547, 1.348201, -0.013399},{
      0.787037, 1.346691, -0.013399},{0.788800, 1.345409, -0.014302}}],
    Polygon[{{0.788547, 1.348201, -0.013399},{0.787364, 1.349829, -0.012166},{
      0.785409, 1.347873, -0.012166},{0.787037, 1.346691, -0.013399}}],
    Polygon[{{0.787364, 1.349829, -0.012166},{0.786310, 1.351280, -0.010634},{
      0.783957, 1.348928, -0.010634},{0.785409, 1.347873, -0.012166}}],
    Polygon[{{0.786310, 1.351280, -0.010634},{0.785409, 1.352520, -0.008839},{
      0.782717, 1.349829, -0.008839},{0.783957, 1.348928, -0.010634}}],
    Polygon[{{0.785409, 1.352520, -0.008839},{0.784684, 1.353518, -0.006827},{
      0.781720, 1.350554, -0.006827},{0.782717, 1.349829, -0.008839}}],
    Polygon[{{0.784684, 1.353518, -0.006827},{0.784153, 1.354248, -0.004647},{
      0.780989, 1.351084, -0.004647},{0.781720, 1.350554, -0.006827}}],
    Polygon[{{0.784153, 1.354248, -0.004647},{0.783830, 1.354694, -0.002352},{
      0.780544, 1.351408, -0.002352},{0.780989, 1.351084, -0.004647}}],
    Polygon[{{0.783830, 1.354694, -0.002352},{0.783721, 1.354844, 0.000000},{
      0.780394, 1.351517, 0.000000},{0.780544, 1.351408, -0.002352}}],
    Polygon[{{0.783721, 1.354844, 0.000000},{0.783830, 1.354694, 0.002352},{
      0.780544, 1.351408, 0.002352},{0.780394, 1.351517, 0.000000}}],
    Polygon[{{0.783830, 1.354694, 0.002352},{0.784153, 1.354248, 0.004647},{
      0.780989, 1.351084, 0.004647},{0.780544, 1.351408, 0.002352}}],
    Polygon[{{0.784153, 1.354248, 0.004647},{0.784684, 1.353518, 0.006827},{
      0.781720, 1.350554, 0.006827},{0.780989, 1.351084, 0.004647}}],
    Polygon[{{0.784684, 1.353518, 0.006827},{0.785409, 1.352520, 0.008839},{
      0.782717, 1.349829, 0.008839},{0.781720, 1.350554, 0.006827}}],
    Polygon[{{0.785409, 1.352520, 0.008839},{0.786310, 1.351280, 0.010634},{
      0.783957, 1.348928, 0.010634},{0.782717, 1.349829, 0.008839}}],
    Polygon[{{0.786310, 1.351280, 0.010634},{0.787364, 1.349829, 0.012166},{
      0.785409, 1.347873, 0.012166},{0.783957, 1.348928, 0.010634}}],
    Polygon[{{0.787364, 1.349829, 0.012166},{0.788547, 1.348201, 0.013399},{
      0.787037, 1.346691, 0.013399},{0.785409, 1.347873, 0.012166}}],
    Polygon[{{0.788547, 1.348201, 0.013399},{0.789828, 1.346437, 0.014302},{
      0.788800, 1.345409, 0.014302},{0.787037, 1.346691, 0.013399}}],
    Polygon[{{0.789828, 1.346437, 0.014302},{0.791177, 1.344581, 0.014853},{
      0.790657, 1.344061, 0.014853},{0.788800, 1.345409, 0.014302}}],
    Polygon[{{0.790657, 1.344061, -0.014853},{0.788800, 1.345409, -0.014302},{
      0.788140, 1.344114, -0.014302},{0.790323, 1.343405, -0.014853}}],
    Polygon[{{0.788800, 1.345409, -0.014302},{0.787037, 1.346691, -0.013399},{
      0.786067, 1.344787, -0.013399},{0.788140, 1.344114, -0.014302}}],
    Polygon[{{0.787037, 1.346691, -0.013399},{0.785409, 1.347873, -0.012166},{
      0.784153, 1.345409, -0.012166},{0.786067, 1.344787, -0.013399}}],
    Polygon[{{0.785409, 1.347873, -0.012166},{0.783957, 1.348928, -0.010634},{
      0.782447, 1.345964, -0.010634},{0.784153, 1.345409, -0.012166}}],
    Polygon[{{0.783957, 1.348928, -0.010634},{0.782717, 1.349829, -0.008839},{
      0.780989, 1.346437, -0.008839},{0.782447, 1.345964, -0.010634}}],
    Polygon[{{0.782717, 1.349829, -0.008839},{0.781720, 1.350554, -0.006827},{
      0.779817, 1.346818, -0.006827},{0.780989, 1.346437, -0.008839}}],
    Polygon[{{0.781720, 1.350554, -0.006827},{0.780989, 1.351084, -0.004647},{
      0.778958, 1.347097, -0.004647},{0.779817, 1.346818, -0.006827}}],
    Polygon[{{0.780989, 1.351084, -0.004647},{0.780544, 1.351408, -0.002352},{
      0.778434, 1.347268, -0.002352},{0.778958, 1.347097, -0.004647}}],
    Polygon[{{0.780544, 1.351408, -0.002352},{0.780394, 1.351517, 0.000000},{
      0.778258, 1.347325, 0.000000},{0.778434, 1.347268, -0.002352}}],
    Polygon[{{0.780394, 1.351517, 0.000000},{0.780544, 1.351408, 0.002352},{
      0.778434, 1.347268, 0.002352},{0.778258, 1.347325, 0.000000}}],
    Polygon[{{0.780544, 1.351408, 0.002352},{0.780989, 1.351084, 0.004647},{
      0.778958, 1.347097, 0.004647},{0.778434, 1.347268, 0.002352}}],
    Polygon[{{0.780989, 1.351084, 0.004647},{0.781720, 1.350554, 0.006827},{
      0.779817, 1.346818, 0.006827},{0.778958, 1.347097, 0.004647}}],
    Polygon[{{0.781720, 1.350554, 0.006827},{0.782717, 1.349829, 0.008839},{
      0.780989, 1.346437, 0.008839},{0.779817, 1.346818, 0.006827}}],
    Polygon[{{0.782717, 1.349829, 0.008839},{0.783957, 1.348928, 0.010634},{
      0.782447, 1.345964, 0.010634},{0.780989, 1.346437, 0.008839}}],
    Polygon[{{0.783957, 1.348928, 0.010634},{0.785409, 1.347873, 0.012166},{
      0.784153, 1.345409, 0.012166},{0.782447, 1.345964, 0.010634}}],
    Polygon[{{0.785409, 1.347873, 0.012166},{0.787037, 1.346691, 0.013399},{
      0.786067, 1.344787, 0.013399},{0.784153, 1.345409, 0.012166}}],
    Polygon[{{0.787037, 1.346691, 0.013399},{0.788800, 1.345409, 0.014302},{
      0.788140, 1.344114, 0.014302},{0.786067, 1.344787, 0.013399}}],
    Polygon[{{0.788800, 1.345409, 0.014302},{0.790657, 1.344061, 0.014853},{
      0.790323, 1.343405, 0.014853},{0.788140, 1.344114, 0.014302}}],
    Polygon[{{0.790323, 1.343405, -0.014853},{0.788140, 1.344114, -0.014302},{
      0.787913, 1.342678, -0.014302},{0.790207, 1.342678, -0.014853}}],
    Polygon[{{0.788140, 1.344114, -0.014302},{0.786067, 1.344787, -0.013399},{
      0.785733, 1.342678, -0.013399},{0.787913, 1.342678, -0.014302}}],
    Polygon[{{0.786067, 1.344787, -0.013399},{0.784153, 1.345409, -0.012166},{
      0.783721, 1.342678, -0.012166},{0.785733, 1.342678, -0.013399}}],
    Polygon[{{0.784153, 1.345409, -0.012166},{0.782447, 1.345964, -0.010634},{
      0.781926, 1.342678, -0.010634},{0.783721, 1.342678, -0.012166}}],
    Polygon[{{0.782447, 1.345964, -0.010634},{0.780989, 1.346437, -0.008839},{
      0.780394, 1.342678, -0.008839},{0.781926, 1.342678, -0.010634}}],
    Polygon[{{0.780989, 1.346437, -0.008839},{0.779817, 1.346818, -0.006827},{
      0.779161, 1.342678, -0.006827},{0.780394, 1.342678, -0.008839}}],
    Polygon[{{0.779817, 1.346818, -0.006827},{0.778958, 1.347097, -0.004647},{
      0.778258, 1.342678, -0.004647},{0.779161, 1.342678, -0.006827}}],
    Polygon[{{0.778958, 1.347097, -0.004647},{0.778434, 1.347268, -0.002352},{
      0.777707, 1.342678, -0.002352},{0.778258, 1.342678, -0.004647}}],
    Polygon[{{0.778434, 1.347268, -0.002352},{0.778258, 1.347325, 0.000000},{
      0.777522, 1.342678, 0.000000},{0.777707, 1.342678, -0.002352}}],
    Polygon[{{0.778258, 1.347325, 0.000000},{0.778434, 1.347268, 0.002352},{
      0.777707, 1.342678, 0.002352},{0.777522, 1.342678, 0.000000}}],
    Polygon[{{0.778434, 1.347268, 0.002352},{0.778958, 1.347097, 0.004647},{
      0.778258, 1.342678, 0.004647},{0.777707, 1.342678, 0.002352}}],
    Polygon[{{0.778958, 1.347097, 0.004647},{0.779817, 1.346818, 0.006827},{
      0.779161, 1.342678, 0.006827},{0.778258, 1.342678, 0.004647}}],
    Polygon[{{0.779817, 1.346818, 0.006827},{0.780989, 1.346437, 0.008839},{
      0.780394, 1.342678, 0.008839},{0.779161, 1.342678, 0.006827}}],
    Polygon[{{0.780989, 1.346437, 0.008839},{0.782447, 1.345964, 0.010634},{
      0.781926, 1.342678, 0.010634},{0.780394, 1.342678, 0.008839}}],
    Polygon[{{0.782447, 1.345964, 0.010634},{0.784153, 1.345409, 0.012166},{
      0.783721, 1.342678, 0.012166},{0.781926, 1.342678, 0.010634}}],
    Polygon[{{0.784153, 1.345409, 0.012166},{0.786067, 1.344787, 0.013399},{
      0.785733, 1.342678, 0.013399},{0.783721, 1.342678, 0.012166}}],
    Polygon[{{0.786067, 1.344787, 0.013399},{0.788140, 1.344114, 0.014302},{
      0.787913, 1.342678, 0.014302},{0.785733, 1.342678, 0.013399}}],
    Polygon[{{0.788140, 1.344114, 0.014302},{0.790323, 1.343405, 0.014853},{
      0.790207, 1.342678, 0.014853},{0.787913, 1.342678, 0.014302}}],
    Polygon[{{0.790207, 1.342678, -0.014853},{0.787913, 1.342678, -0.014302},{
      0.788140, 1.341242, -0.014302},{0.790323, 1.341951, -0.014853}}],
    Polygon[{{0.787913, 1.342678, -0.014302},{0.785733, 1.342678, -0.013399},{
      0.786067, 1.340568, -0.013399},{0.788140, 1.341242, -0.014302}}],
    Polygon[{{0.785733, 1.342678, -0.013399},{0.783721, 1.342678, -0.012166},{
      0.784153, 1.339946, -0.012166},{0.786067, 1.340568, -0.013399}}],
    Polygon[{{0.783721, 1.342678, -0.012166},{0.781926, 1.342678, -0.010634},{
      0.782447, 1.339392, -0.010634},{0.784153, 1.339946, -0.012166}}],
    Polygon[{{0.781926, 1.342678, -0.010634},{0.780394, 1.342678, -0.008839},{
      0.780989, 1.338918, -0.008839},{0.782447, 1.339392, -0.010634}}],
    Polygon[{{0.780394, 1.342678, -0.008839},{0.779161, 1.342678, -0.006827},{
      0.779817, 1.338537, -0.006827},{0.780989, 1.338918, -0.008839}}],
    Polygon[{{0.779161, 1.342678, -0.006827},{0.778258, 1.342678, -0.004647},{
      0.778958, 1.338258, -0.004647},{0.779817, 1.338537, -0.006827}}],
    Polygon[{{0.778258, 1.342678, -0.004647},{0.777707, 1.342678, -0.002352},{
      0.778434, 1.338088, -0.002352},{0.778958, 1.338258, -0.004647}}],
    Polygon[{{0.777707, 1.342678, -0.002352},{0.777522, 1.342678, 0.000000},{
      0.778258, 1.338031, 0.000000},{0.778434, 1.338088, -0.002352}}],
    Polygon[{{0.777522, 1.342678, 0.000000},{0.777707, 1.342678, 0.002352},{
      0.778434, 1.338088, 0.002352},{0.778258, 1.338031, 0.000000}}],
    Polygon[{{0.777707, 1.342678, 0.002352},{0.778258, 1.342678, 0.004647},{
      0.778958, 1.338258, 0.004647},{0.778434, 1.338088, 0.002352}}],
    Polygon[{{0.778258, 1.342678, 0.004647},{0.779161, 1.342678, 0.006827},{
      0.779817, 1.338537, 0.006827},{0.778958, 1.338258, 0.004647}}],
    Polygon[{{0.779161, 1.342678, 0.006827},{0.780394, 1.342678, 0.008839},{
      0.780989, 1.338918, 0.008839},{0.779817, 1.338537, 0.006827}}],
    Polygon[{{0.780394, 1.342678, 0.008839},{0.781926, 1.342678, 0.010634},{
      0.782447, 1.339392, 0.010634},{0.780989, 1.338918, 0.008839}}],
    Polygon[{{0.781926, 1.342678, 0.010634},{0.783721, 1.342678, 0.012166},{
      0.784153, 1.339946, 0.012166},{0.782447, 1.339392, 0.010634}}],
    Polygon[{{0.783721, 1.342678, 0.012166},{0.785733, 1.342678, 0.013399},{
      0.786067, 1.340568, 0.013399},{0.784153, 1.339946, 0.012166}}],
    Polygon[{{0.785733, 1.342678, 0.013399},{0.787913, 1.342678, 0.014302},{
      0.788140, 1.341242, 0.014302},{0.786067, 1.340568, 0.013399}}],
    Polygon[{{0.787913, 1.342678, 0.014302},{0.790207, 1.342678, 0.014853},{
      0.790323, 1.341951, 0.014853},{0.788140, 1.341242, 0.014302}}],
    Polygon[{{0.790323, 1.341951, -0.014853},{0.788140, 1.341242, -0.014302},{
      0.788800, 1.339946, -0.014302},{0.790657, 1.341295, -0.014853}}],
    Polygon[{{0.788140, 1.341242, -0.014302},{0.786067, 1.340568, -0.013399},{
      0.787037, 1.338665, -0.013399},{0.788800, 1.339946, -0.014302}}],
    Polygon[{{0.786067, 1.340568, -0.013399},{0.784153, 1.339946, -0.012166},{
      0.785409, 1.337482, -0.012166},{0.787037, 1.338665, -0.013399}}],
    Polygon[{{0.784153, 1.339946, -0.012166},{0.782447, 1.339392, -0.010634},{
      0.783957, 1.336427, -0.010634},{0.785409, 1.337482, -0.012166}}],
    Polygon[{{0.782447, 1.339392, -0.010634},{0.780989, 1.338918, -0.008839},{
      0.782717, 1.335527, -0.008839},{0.783957, 1.336427, -0.010634}}],
    Polygon[{{0.780989, 1.338918, -0.008839},{0.779817, 1.338537, -0.006827},{
      0.781720, 1.334802, -0.006827},{0.782717, 1.335527, -0.008839}}],
    Polygon[{{0.779817, 1.338537, -0.006827},{0.778958, 1.338258, -0.004647},{
      0.780989, 1.334271, -0.004647},{0.781720, 1.334802, -0.006827}}],
    Polygon[{{0.778958, 1.338258, -0.004647},{0.778434, 1.338088, -0.002352},{
      0.780544, 1.333947, -0.002352},{0.780989, 1.334271, -0.004647}}],
    Polygon[{{0.778434, 1.338088, -0.002352},{0.778258, 1.338031, 0.000000},{
      0.780394, 1.333839, 0.000000},{0.780544, 1.333947, -0.002352}}],
    Polygon[{{0.778258, 1.338031, 0.000000},{0.778434, 1.338088, 0.002352},{
      0.780544, 1.333947, 0.002352},{0.780394, 1.333839, 0.000000}}],
    Polygon[{{0.778434, 1.338088, 0.002352},{0.778958, 1.338258, 0.004647},{
      0.780989, 1.334271, 0.004647},{0.780544, 1.333947, 0.002352}}],
    Polygon[{{0.778958, 1.338258, 0.004647},{0.779817, 1.338537, 0.006827},{
      0.781720, 1.334802, 0.006827},{0.780989, 1.334271, 0.004647}}],
    Polygon[{{0.779817, 1.338537, 0.006827},{0.780989, 1.338918, 0.008839},{
      0.782717, 1.335527, 0.008839},{0.781720, 1.334802, 0.006827}}],
    Polygon[{{0.780989, 1.338918, 0.008839},{0.782447, 1.339392, 0.010634},{
      0.783957, 1.336427, 0.010634},{0.782717, 1.335527, 0.008839}}],
    Polygon[{{0.782447, 1.339392, 0.010634},{0.784153, 1.339946, 0.012166},{
      0.785409, 1.337482, 0.012166},{0.783957, 1.336427, 0.010634}}],
    Polygon[{{0.784153, 1.339946, 0.012166},{0.786067, 1.340568, 0.013399},{
      0.787037, 1.338665, 0.013399},{0.785409, 1.337482, 0.012166}}],
    Polygon[{{0.786067, 1.340568, 0.013399},{0.788140, 1.341242, 0.014302},{
      0.788800, 1.339946, 0.014302},{0.787037, 1.338665, 0.013399}}],
    Polygon[{{0.788140, 1.341242, 0.014302},{0.790323, 1.341951, 0.014853},{
      0.790657, 1.341295, 0.014853},{0.788800, 1.339946, 0.014302}}],
    Polygon[{{0.790657, 1.341295, -0.014853},{0.788800, 1.339946, -0.014302},{
      0.789828, 1.338918, -0.014302},{0.791177, 1.340775, -0.014853}}],
    Polygon[{{0.788800, 1.339946, -0.014302},{0.787037, 1.338665, -0.013399},{
      0.788547, 1.337154, -0.013399},{0.789828, 1.338918, -0.014302}}],
    Polygon[{{0.787037, 1.338665, -0.013399},{0.785409, 1.337482, -0.012166},{
      0.787364, 1.335527, -0.012166},{0.788547, 1.337154, -0.013399}}],
    Polygon[{{0.785409, 1.337482, -0.012166},{0.783957, 1.336427, -0.010634},{
      0.786310, 1.334075, -0.010634},{0.787364, 1.335527, -0.012166}}],
    Polygon[{{0.783957, 1.336427, -0.010634},{0.782717, 1.335527, -0.008839},{
      0.785409, 1.332835, -0.008839},{0.786310, 1.334075, -0.010634}}],
    Polygon[{{0.782717, 1.335527, -0.008839},{0.781720, 1.334802, -0.006827},{
      0.784684, 1.331838, -0.006827},{0.785409, 1.332835, -0.008839}}],
    Polygon[{{0.781720, 1.334802, -0.006827},{0.780989, 1.334271, -0.004647},{
      0.784153, 1.331107, -0.004647},{0.784684, 1.331838, -0.006827}}],
    Polygon[{{0.780989, 1.334271, -0.004647},{0.780544, 1.333947, -0.002352},{
      0.783830, 1.330661, -0.002352},{0.784153, 1.331107, -0.004647}}],
    Polygon[{{0.780544, 1.333947, -0.002352},{0.780394, 1.333839, 0.000000},{
      0.783721, 1.330512, 0.000000},{0.783830, 1.330661, -0.002352}}],
    Polygon[{{0.780394, 1.333839, 0.000000},{0.780544, 1.333947, 0.002352},{
      0.783830, 1.330661, 0.002352},{0.783721, 1.330512, 0.000000}}],
    Polygon[{{0.780544, 1.333947, 0.002352},{0.780989, 1.334271, 0.004647},{
      0.784153, 1.331107, 0.004647},{0.783830, 1.330661, 0.002352}}],
    Polygon[{{0.780989, 1.334271, 0.004647},{0.781720, 1.334802, 0.006827},{
      0.784684, 1.331838, 0.006827},{0.784153, 1.331107, 0.004647}}],
    Polygon[{{0.781720, 1.334802, 0.006827},{0.782717, 1.335527, 0.008839},{
      0.785409, 1.332835, 0.008839},{0.784684, 1.331838, 0.006827}}],
    Polygon[{{0.782717, 1.335527, 0.008839},{0.783957, 1.336427, 0.010634},{
      0.786310, 1.334075, 0.010634},{0.785409, 1.332835, 0.008839}}],
    Polygon[{{0.783957, 1.336427, 0.010634},{0.785409, 1.337482, 0.012166},{
      0.787364, 1.335527, 0.012166},{0.786310, 1.334075, 0.010634}}],
    Polygon[{{0.785409, 1.337482, 0.012166},{0.787037, 1.338665, 0.013399},{
      0.788547, 1.337154, 0.013399},{0.787364, 1.335527, 0.012166}}],
    Polygon[{{0.787037, 1.338665, 0.013399},{0.788800, 1.339946, 0.014302},{
      0.789828, 1.338918, 0.014302},{0.788547, 1.337154, 0.013399}}],
    Polygon[{{0.788800, 1.339946, 0.014302},{0.790657, 1.341295, 0.014853},{
      0.791177, 1.340775, 0.014853},{0.789828, 1.338918, 0.014302}}],
    Polygon[{{0.791177, 1.340775, -0.014853},{0.789828, 1.338918, -0.014302},{
      0.791124, 1.338258, -0.014302},{0.791833, 1.340440, -0.014853}}],
    Polygon[{{0.789828, 1.338918, -0.014302},{0.788547, 1.337154, -0.013399},{
      0.790450, 1.336185, -0.013399},{0.791124, 1.338258, -0.014302}}],
    Polygon[{{0.788547, 1.337154, -0.013399},{0.787364, 1.335527, -0.012166},{
      0.789828, 1.334271, -0.012166},{0.790450, 1.336185, -0.013399}}],
    Polygon[{{0.787364, 1.335527, -0.012166},{0.786310, 1.334075, -0.010634},{
      0.789274, 1.332565, -0.010634},{0.789828, 1.334271, -0.012166}}],
    Polygon[{{0.786310, 1.334075, -0.010634},{0.785409, 1.332835, -0.008839},{
      0.788800, 1.331107, -0.008839},{0.789274, 1.332565, -0.010634}}],
    Polygon[{{0.785409, 1.332835, -0.008839},{0.784684, 1.331838, -0.006827},{
      0.788419, 1.329934, -0.006827},{0.788800, 1.331107, -0.008839}}],
    Polygon[{{0.784684, 1.331838, -0.006827},{0.784153, 1.331107, -0.004647},{
      0.788140, 1.329076, -0.004647},{0.788419, 1.329934, -0.006827}}],
    Polygon[{{0.784153, 1.331107, -0.004647},{0.783830, 1.330661, -0.002352},{
      0.787970, 1.328552, -0.002352},{0.788140, 1.329076, -0.004647}}],
    Polygon[{{0.783830, 1.330661, -0.002352},{0.783721, 1.330512, 0.000000},{
      0.787913, 1.328376, 0.000000},{0.787970, 1.328552, -0.002352}}],
    Polygon[{{0.783721, 1.330512, 0.000000},{0.783830, 1.330661, 0.002352},{
      0.787970, 1.328552, 0.002352},{0.787913, 1.328376, 0.000000}}],
    Polygon[{{0.783830, 1.330661, 0.002352},{0.784153, 1.331107, 0.004647},{
      0.788140, 1.329076, 0.004647},{0.787970, 1.328552, 0.002352}}],
    Polygon[{{0.784153, 1.331107, 0.004647},{0.784684, 1.331838, 0.006827},{
      0.788419, 1.329934, 0.006827},{0.788140, 1.329076, 0.004647}}],
    Polygon[{{0.784684, 1.331838, 0.006827},{0.785409, 1.332835, 0.008839},{
      0.788800, 1.331107, 0.008839},{0.788419, 1.329934, 0.006827}}],
    Polygon[{{0.785409, 1.332835, 0.008839},{0.786310, 1.334075, 0.010634},{
      0.789274, 1.332565, 0.010634},{0.788800, 1.331107, 0.008839}}],
    Polygon[{{0.786310, 1.334075, 0.010634},{0.787364, 1.335527, 0.012166},{
      0.789828, 1.334271, 0.012166},{0.789274, 1.332565, 0.010634}}],
    Polygon[{{0.787364, 1.335527, 0.012166},{0.788547, 1.337154, 0.013399},{
      0.790450, 1.336185, 0.013399},{0.789828, 1.334271, 0.012166}}],
    Polygon[{{0.788547, 1.337154, 0.013399},{0.789828, 1.338918, 0.014302},{
      0.791124, 1.338258, 0.014302},{0.790450, 1.336185, 0.013399}}],
    Polygon[{{0.789828, 1.338918, 0.014302},{0.791177, 1.340775, 0.014853},{
      0.791833, 1.340440, 0.014853},{0.791124, 1.338258, 0.014302}}],
    Polygon[{{0.791833, 1.340440, -0.014853},{0.791124, 1.338258, -0.014302},{
      0.792560, 1.338031, -0.014302},{0.792560, 1.340325, -0.014853}}],
    Polygon[{{0.791124, 1.338258, -0.014302},{0.790450, 1.336185, -0.013399},{
      0.792560, 1.335851, -0.013399},{0.792560, 1.338031, -0.014302}}],
    Polygon[{{0.790450, 1.336185, -0.013399},{0.789828, 1.334271, -0.012166},{
      0.792560, 1.333839, -0.012166},{0.792560, 1.335851, -0.013399}}],
    Polygon[{{0.789828, 1.334271, -0.012166},{0.789274, 1.332565, -0.010634},{
      0.792560, 1.332044, -0.010634},{0.792560, 1.333839, -0.012166}}],
    Polygon[{{0.789274, 1.332565, -0.010634},{0.788800, 1.331107, -0.008839},{
      0.792560, 1.330512, -0.008839},{0.792560, 1.332044, -0.010634}}],
    Polygon[{{0.788800, 1.331107, -0.008839},{0.788419, 1.329934, -0.006827},{
      0.792560, 1.329279, -0.006827},{0.792560, 1.330512, -0.008839}}],
    Polygon[{{0.788419, 1.329934, -0.006827},{0.788140, 1.329076, -0.004647},{
      0.792560, 1.328376, -0.004647},{0.792560, 1.329279, -0.006827}}],
    Polygon[{{0.788140, 1.329076, -0.004647},{0.787970, 1.328552, -0.002352},{
      0.792560, 1.327825, -0.002352},{0.792560, 1.328376, -0.004647}}],
    Polygon[{{0.787970, 1.328552, -0.002352},{0.787913, 1.328376, 0.000000},{
      0.792560, 1.327640, 0.000000},{0.792560, 1.327825, -0.002352}}],
    Polygon[{{0.787913, 1.328376, 0.000000},{0.787970, 1.328552, 0.002352},{
      0.792560, 1.327825, 0.002352},{0.792560, 1.327640, 0.000000}}],
    Polygon[{{0.787970, 1.328552, 0.002352},{0.788140, 1.329076, 0.004647},{
      0.792560, 1.328376, 0.004647},{0.792560, 1.327825, 0.002352}}],
    Polygon[{{0.788140, 1.329076, 0.004647},{0.788419, 1.329934, 0.006827},{
      0.792560, 1.329279, 0.006827},{0.792560, 1.328376, 0.004647}}],
    Polygon[{{0.788419, 1.329934, 0.006827},{0.788800, 1.331107, 0.008839},{
      0.792560, 1.330512, 0.008839},{0.792560, 1.329279, 0.006827}}],
    Polygon[{{0.788800, 1.331107, 0.008839},{0.789274, 1.332565, 0.010634},{
      0.792560, 1.332044, 0.010634},{0.792560, 1.330512, 0.008839}}],
    Polygon[{{0.789274, 1.332565, 0.010634},{0.789828, 1.334271, 0.012166},{
      0.792560, 1.333839, 0.012166},{0.792560, 1.332044, 0.010634}}],
    Polygon[{{0.789828, 1.334271, 0.012166},{0.790450, 1.336185, 0.013399},{
      0.792560, 1.335851, 0.013399},{0.792560, 1.333839, 0.012166}}],
    Polygon[{{0.790450, 1.336185, 0.013399},{0.791124, 1.338258, 0.014302},{
      0.792560, 1.338031, 0.014302},{0.792560, 1.335851, 0.013399}}],
    Polygon[{{0.791124, 1.338258, 0.014302},{0.791833, 1.340440, 0.014853},{
      0.792560, 1.340325, 0.014853},{0.792560, 1.338031, 0.014302}}],
    Polygon[{{0.792560, 1.340325, -0.014853},{0.792560, 1.338031, -0.014302},{
      0.793996, 1.338258, -0.014302},{0.793287, 1.340440, -0.014853}}],
    Polygon[{{0.792560, 1.338031, -0.014302},{0.792560, 1.335851, -0.013399},{
      0.794670, 1.336185, -0.013399},{0.793996, 1.338258, -0.014302}}],
    Polygon[{{0.792560, 1.335851, -0.013399},{0.792560, 1.333839, -0.012166},{
      0.795291, 1.334271, -0.012166},{0.794670, 1.336185, -0.013399}}],
    Polygon[{{0.792560, 1.333839, -0.012166},{0.792560, 1.332044, -0.010634},{
      0.795846, 1.332565, -0.010634},{0.795291, 1.334271, -0.012166}}],
    Polygon[{{0.792560, 1.332044, -0.010634},{0.792560, 1.330512, -0.008839},{
      0.796319, 1.331107, -0.008839},{0.795846, 1.332565, -0.010634}}],
    Polygon[{{0.792560, 1.330512, -0.008839},{0.792560, 1.329279, -0.006827},{
      0.796700, 1.329934, -0.006827},{0.796319, 1.331107, -0.008839}}],
    Polygon[{{0.792560, 1.329279, -0.006827},{0.792560, 1.328376, -0.004647},{
      0.796980, 1.329076, -0.004647},{0.796700, 1.329934, -0.006827}}],
    Polygon[{{0.792560, 1.328376, -0.004647},{0.792560, 1.327825, -0.002352},{
      0.797150, 1.328552, -0.002352},{0.796980, 1.329076, -0.004647}}],
    Polygon[{{0.792560, 1.327825, -0.002352},{0.792560, 1.327640, 0.000000},{
      0.797207, 1.328376, 0.000000},{0.797150, 1.328552, -0.002352}}],
    Polygon[{{0.792560, 1.327640, 0.000000},{0.792560, 1.327825, 0.002352},{
      0.797150, 1.328552, 0.002352},{0.797207, 1.328376, 0.000000}}],
    Polygon[{{0.792560, 1.327825, 0.002352},{0.792560, 1.328376, 0.004647},{
      0.796980, 1.329076, 0.004647},{0.797150, 1.328552, 0.002352}}],
    Polygon[{{0.792560, 1.328376, 0.004647},{0.792560, 1.329279, 0.006827},{
      0.796700, 1.329934, 0.006827},{0.796980, 1.329076, 0.004647}}],
    Polygon[{{0.792560, 1.329279, 0.006827},{0.792560, 1.330512, 0.008839},{
      0.796319, 1.331107, 0.008839},{0.796700, 1.329934, 0.006827}}],
    Polygon[{{0.792560, 1.330512, 0.008839},{0.792560, 1.332044, 0.010634},{
      0.795846, 1.332565, 0.010634},{0.796319, 1.331107, 0.008839}}],
    Polygon[{{0.792560, 1.332044, 0.010634},{0.792560, 1.333839, 0.012166},{
      0.795291, 1.334271, 0.012166},{0.795846, 1.332565, 0.010634}}],
    Polygon[{{0.792560, 1.333839, 0.012166},{0.792560, 1.335851, 0.013399},{
      0.794670, 1.336185, 0.013399},{0.795291, 1.334271, 0.012166}}],
    Polygon[{{0.792560, 1.335851, 0.013399},{0.792560, 1.338031, 0.014302},{
      0.793996, 1.338258, 0.014302},{0.794670, 1.336185, 0.013399}}],
    Polygon[{{0.792560, 1.338031, 0.014302},{0.792560, 1.340325, 0.014853},{
      0.793287, 1.340440, 0.014853},{0.793996, 1.338258, 0.014302}}],
    Polygon[{{0.793287, 1.340440, -0.014853},{0.793996, 1.338258, -0.014302},{
      0.795291, 1.338918, -0.014302},{0.793943, 1.340775, -0.014853}}],
    Polygon[{{0.793996, 1.338258, -0.014302},{0.794670, 1.336185, -0.013399},{
      0.796573, 1.337154, -0.013399},{0.795291, 1.338918, -0.014302}}],
    Polygon[{{0.794670, 1.336185, -0.013399},{0.795291, 1.334271, -0.012166},{
      0.797756, 1.335527, -0.012166},{0.796573, 1.337154, -0.013399}}],
    Polygon[{{0.795291, 1.334271, -0.012166},{0.795846, 1.332565, -0.010634},{
      0.798810, 1.334075, -0.010634},{0.797756, 1.335527, -0.012166}}],
    Polygon[{{0.795846, 1.332565, -0.010634},{0.796319, 1.331107, -0.008839},{
      0.799711, 1.332835, -0.008839},{0.798810, 1.334075, -0.010634}}],
    Polygon[{{0.796319, 1.331107, -0.008839},{0.796700, 1.329934, -0.006827},{
      0.800436, 1.331838, -0.006827},{0.799711, 1.332835, -0.008839}}],
    Polygon[{{0.796700, 1.329934, -0.006827},{0.796980, 1.329076, -0.004647},{
      0.800967, 1.331107, -0.004647},{0.800436, 1.331838, -0.006827}}],
    Polygon[{{0.796980, 1.329076, -0.004647},{0.797150, 1.328552, -0.002352},{
      0.801290, 1.330661, -0.002352},{0.800967, 1.331107, -0.004647}}],
    Polygon[{{0.797150, 1.328552, -0.002352},{0.797207, 1.328376, 0.000000},{
      0.801399, 1.330512, 0.000000},{0.801290, 1.330661, -0.002352}}],
    Polygon[{{0.797207, 1.328376, 0.000000},{0.797150, 1.328552, 0.002352},{
      0.801290, 1.330661, 0.002352},{0.801399, 1.330512, 0.000000}}],
    Polygon[{{0.797150, 1.328552, 0.002352},{0.796980, 1.329076, 0.004647},{
      0.800967, 1.331107, 0.004647},{0.801290, 1.330661, 0.002352}}],
    Polygon[{{0.796980, 1.329076, 0.004647},{0.796700, 1.329934, 0.006827},{
      0.800436, 1.331838, 0.006827},{0.800967, 1.331107, 0.004647}}],
    Polygon[{{0.796700, 1.329934, 0.006827},{0.796319, 1.331107, 0.008839},{
      0.799711, 1.332835, 0.008839},{0.800436, 1.331838, 0.006827}}],
    Polygon[{{0.796319, 1.331107, 0.008839},{0.795846, 1.332565, 0.010634},{
      0.798810, 1.334075, 0.010634},{0.799711, 1.332835, 0.008839}}],
    Polygon[{{0.795846, 1.332565, 0.010634},{0.795291, 1.334271, 0.012166},{
      0.797756, 1.335527, 0.012166},{0.798810, 1.334075, 0.010634}}],
    Polygon[{{0.795291, 1.334271, 0.012166},{0.794670, 1.336185, 0.013399},{
      0.796573, 1.337154, 0.013399},{0.797756, 1.335527, 0.012166}}],
    Polygon[{{0.794670, 1.336185, 0.013399},{0.793996, 1.338258, 0.014302},{
      0.795291, 1.338918, 0.014302},{0.796573, 1.337154, 0.013399}}],
    Polygon[{{0.793996, 1.338258, 0.014302},{0.793287, 1.340440, 0.014853},{
      0.793943, 1.340775, 0.014853},{0.795291, 1.338918, 0.014302}}],
    Polygon[{{0.793943, 1.340775, -0.014853},{0.795291, 1.338918, -0.014302},{
      0.796319, 1.339946, -0.014302},{0.794463, 1.341295, -0.014853}}],
    Polygon[{{0.795291, 1.338918, -0.014302},{0.796573, 1.337154, -0.013399},{
      0.798083, 1.338665, -0.013399},{0.796319, 1.339946, -0.014302}}],
    Polygon[{{0.796573, 1.337154, -0.013399},{0.797756, 1.335527, -0.012166},{
      0.799711, 1.337482, -0.012166},{0.798083, 1.338665, -0.013399}}],
    Polygon[{{0.797756, 1.335527, -0.012166},{0.798810, 1.334075, -0.010634},{
      0.801163, 1.336427, -0.010634},{0.799711, 1.337482, -0.012166}}],
    Polygon[{{0.798810, 1.334075, -0.010634},{0.799711, 1.332835, -0.008839},{
      0.802403, 1.335527, -0.008839},{0.801163, 1.336427, -0.010634}}],
    Polygon[{{0.799711, 1.332835, -0.008839},{0.800436, 1.331838, -0.006827},{
      0.803400, 1.334802, -0.006827},{0.802403, 1.335527, -0.008839}}],
    Polygon[{{0.800436, 1.331838, -0.006827},{0.800967, 1.331107, -0.004647},{
      0.804131, 1.334271, -0.004647},{0.803400, 1.334802, -0.006827}}],
    Polygon[{{0.800967, 1.331107, -0.004647},{0.801290, 1.330661, -0.002352},{
      0.804576, 1.333947, -0.002352},{0.804131, 1.334271, -0.004647}}],
    Polygon[{{0.801290, 1.330661, -0.002352},{0.801399, 1.330512, 0.000000},{
      0.804726, 1.333839, 0.000000},{0.804576, 1.333947, -0.002352}}],
    Polygon[{{0.801399, 1.330512, 0.000000},{0.801290, 1.330661, 0.002352},{
      0.804576, 1.333947, 0.002352},{0.804726, 1.333839, 0.000000}}],
    Polygon[{{0.801290, 1.330661, 0.002352},{0.800967, 1.331107, 0.004647},{
      0.804131, 1.334271, 0.004647},{0.804576, 1.333947, 0.002352}}],
    Polygon[{{0.800967, 1.331107, 0.004647},{0.800436, 1.331838, 0.006827},{
      0.803400, 1.334802, 0.006827},{0.804131, 1.334271, 0.004647}}],
    Polygon[{{0.800436, 1.331838, 0.006827},{0.799711, 1.332835, 0.008839},{
      0.802403, 1.335527, 0.008839},{0.803400, 1.334802, 0.006827}}],
    Polygon[{{0.799711, 1.332835, 0.008839},{0.798810, 1.334075, 0.010634},{
      0.801163, 1.336427, 0.010634},{0.802403, 1.335527, 0.008839}}],
    Polygon[{{0.798810, 1.334075, 0.010634},{0.797756, 1.335527, 0.012166},{
      0.799711, 1.337482, 0.012166},{0.801163, 1.336427, 0.010634}}],
    Polygon[{{0.797756, 1.335527, 0.012166},{0.796573, 1.337154, 0.013399},{
      0.798083, 1.338665, 0.013399},{0.799711, 1.337482, 0.012166}}],
    Polygon[{{0.796573, 1.337154, 0.013399},{0.795291, 1.338918, 0.014302},{
      0.796319, 1.339946, 0.014302},{0.798083, 1.338665, 0.013399}}],
    Polygon[{{0.795291, 1.338918, 0.014302},{0.793943, 1.340775, 0.014853},{
      0.794463, 1.341295, 0.014853},{0.796319, 1.339946, 0.014302}}],
    Polygon[{{0.794463, 1.341295, -0.014853},{0.796319, 1.339946, -0.014302},{
      0.796980, 1.341242, -0.014302},{0.794797, 1.341951, -0.014853}}],
    Polygon[{{0.796319, 1.339946, -0.014302},{0.798083, 1.338665, -0.013399},{
      0.799053, 1.340568, -0.013399},{0.796980, 1.341242, -0.014302}}],
    Polygon[{{0.798083, 1.338665, -0.013399},{0.799711, 1.337482, -0.012166},{
      0.800967, 1.339946, -0.012166},{0.799053, 1.340568, -0.013399}}],
    Polygon[{{0.799711, 1.337482, -0.012166},{0.801163, 1.336427, -0.010634},{
      0.802673, 1.339392, -0.010634},{0.800967, 1.339946, -0.012166}}],
    Polygon[{{0.801163, 1.336427, -0.010634},{0.802403, 1.335527, -0.008839},{
      0.804131, 1.338918, -0.008839},{0.802673, 1.339392, -0.010634}}],
    Polygon[{{0.802403, 1.335527, -0.008839},{0.803400, 1.334802, -0.006827},{
      0.805303, 1.338537, -0.006827},{0.804131, 1.338918, -0.008839}}],
    Polygon[{{0.803400, 1.334802, -0.006827},{0.804131, 1.334271, -0.004647},{
      0.806162, 1.338258, -0.004647},{0.805303, 1.338537, -0.006827}}],
    Polygon[{{0.804131, 1.334271, -0.004647},{0.804576, 1.333947, -0.002352},{
      0.806686, 1.338088, -0.002352},{0.806162, 1.338258, -0.004647}}],
    Polygon[{{0.804576, 1.333947, -0.002352},{0.804726, 1.333839, 0.000000},{
      0.806862, 1.338031, 0.000000},{0.806686, 1.338088, -0.002352}}],
    Polygon[{{0.804726, 1.333839, 0.000000},{0.804576, 1.333947, 0.002352},{
      0.806686, 1.338088, 0.002352},{0.806862, 1.338031, 0.000000}}],
    Polygon[{{0.804576, 1.333947, 0.002352},{0.804131, 1.334271, 0.004647},{
      0.806162, 1.338258, 0.004647},{0.806686, 1.338088, 0.002352}}],
    Polygon[{{0.804131, 1.334271, 0.004647},{0.803400, 1.334802, 0.006827},{
      0.805303, 1.338537, 0.006827},{0.806162, 1.338258, 0.004647}}],
    Polygon[{{0.803400, 1.334802, 0.006827},{0.802403, 1.335527, 0.008839},{
      0.804131, 1.338918, 0.008839},{0.805303, 1.338537, 0.006827}}],
    Polygon[{{0.802403, 1.335527, 0.008839},{0.801163, 1.336427, 0.010634},{
      0.802673, 1.339392, 0.010634},{0.804131, 1.338918, 0.008839}}],
    Polygon[{{0.801163, 1.336427, 0.010634},{0.799711, 1.337482, 0.012166},{
      0.800967, 1.339946, 0.012166},{0.802673, 1.339392, 0.010634}}],
    Polygon[{{0.799711, 1.337482, 0.012166},{0.798083, 1.338665, 0.013399},{
      0.799053, 1.340568, 0.013399},{0.800967, 1.339946, 0.012166}}],
    Polygon[{{0.798083, 1.338665, 0.013399},{0.796319, 1.339946, 0.014302},{
      0.796980, 1.341242, 0.014302},{0.799053, 1.340568, 0.013399}}],
    Polygon[{{0.796319, 1.339946, 0.014302},{0.794463, 1.341295, 0.014853},{
      0.794797, 1.341951, 0.014853},{0.796980, 1.341242, 0.014302}}],
    Polygon[{{0.794797, 1.341951, -0.014853},{0.796980, 1.341242, -0.014302},{
      0.797207, 1.342678, -0.014302},{0.794912, 1.342678, -0.014853}}],
    Polygon[{{0.796980, 1.341242, -0.014302},{0.799053, 1.340568, -0.013399},{
      0.799387, 1.342678, -0.013399},{0.797207, 1.342678, -0.014302}}],
    Polygon[{{0.799053, 1.340568, -0.013399},{0.800967, 1.339946, -0.012166},{
      0.801399, 1.342678, -0.012166},{0.799387, 1.342678, -0.013399}}],
    Polygon[{{0.800967, 1.339946, -0.012166},{0.802673, 1.339392, -0.010634},{
      0.803194, 1.342678, -0.010634},{0.801399, 1.342678, -0.012166}}],
    Polygon[{{0.802673, 1.339392, -0.010634},{0.804131, 1.338918, -0.008839},{
      0.804726, 1.342678, -0.008839},{0.803194, 1.342678, -0.010634}}],
    Polygon[{{0.804131, 1.338918, -0.008839},{0.805303, 1.338537, -0.006827},{
      0.805959, 1.342678, -0.006827},{0.804726, 1.342678, -0.008839}}],
    Polygon[{{0.805303, 1.338537, -0.006827},{0.806162, 1.338258, -0.004647},{
      0.806862, 1.342678, -0.004647},{0.805959, 1.342678, -0.006827}}],
    Polygon[{{0.806162, 1.338258, -0.004647},{0.806686, 1.338088, -0.002352},{
      0.807413, 1.342678, -0.002352},{0.806862, 1.342678, -0.004647}}],
    Polygon[{{0.806686, 1.338088, -0.002352},{0.806862, 1.338031, 0.000000},{
      0.807598, 1.342678, 0.000000},{0.807413, 1.342678, -0.002352}}],
    Polygon[{{0.806862, 1.338031, 0.000000},{0.806686, 1.338088, 0.002352},{
      0.807413, 1.342678, 0.002352},{0.807598, 1.342678, 0.000000}}],
    Polygon[{{0.806686, 1.338088, 0.002352},{0.806162, 1.338258, 0.004647},{
      0.806862, 1.342678, 0.004647},{0.807413, 1.342678, 0.002352}}],
    Polygon[{{0.806162, 1.338258, 0.004647},{0.805303, 1.338537, 0.006827},{
      0.805959, 1.342678, 0.006827},{0.806862, 1.342678, 0.004647}}],
    Polygon[{{0.805303, 1.338537, 0.006827},{0.804131, 1.338918, 0.008839},{
      0.804726, 1.342678, 0.008839},{0.805959, 1.342678, 0.006827}}],
    Polygon[{{0.804131, 1.338918, 0.008839},{0.802673, 1.339392, 0.010634},{
      0.803194, 1.342678, 0.010634},{0.804726, 1.342678, 0.008839}}],
    Polygon[{{0.802673, 1.339392, 0.010634},{0.800967, 1.339946, 0.012166},{
      0.801399, 1.342678, 0.012166},{0.803194, 1.342678, 0.010634}}],
    Polygon[{{0.800967, 1.339946, 0.012166},{0.799053, 1.340568, 0.013399},{
      0.799387, 1.342678, 0.013399},{0.801399, 1.342678, 0.012166}}],
    Polygon[{{0.799053, 1.340568, 0.013399},{0.796980, 1.341242, 0.014302},{
      0.797207, 1.342678, 0.014302},{0.799387, 1.342678, 0.013399}}],
    Polygon[{{0.796980, 1.341242, 0.014302},{0.794797, 1.341951, 0.014853},{
      0.794912, 1.342678, 0.014853},{0.797207, 1.342678, 0.014302}}],
    Polygon[{{0.752091, 1.277340, -0.011012},{0.753792, 1.277340, -0.010603},{
      0.753623, 1.278405, -0.010603},{0.752005, 1.277879, -0.011012}}],
    Polygon[{{0.753792, 1.277340, -0.010603},{0.755408, 1.277340, -0.009934},{
      0.755160, 1.278904, -0.009934},{0.753623, 1.278405, -0.010603}}],
    Polygon[{{0.755408, 1.277340, -0.009934},{0.756900, 1.277340, -0.009020},{
      0.756579, 1.279365, -0.009020},{0.755160, 1.278904, -0.009934}}],
    Polygon[{{0.756900, 1.277340, -0.009020},{0.758230, 1.277340, -0.007884},{
      0.757844, 1.279776, -0.007884},{0.756579, 1.279365, -0.009020}}],
    Polygon[{{0.758230, 1.277340, -0.007884},{0.759366, 1.277340, -0.006553},{
      0.758925, 1.280128, -0.006553},{0.757844, 1.279776, -0.007884}}],
    Polygon[{{0.759366, 1.277340, -0.006553},{0.760280, 1.277340, -0.005062},{
      0.759794, 1.280410, -0.005062},{0.758925, 1.280128, -0.006553}}],
    Polygon[{{0.760280, 1.277340, -0.005062},{0.760950, 1.277340, -0.003445},{
      0.760431, 1.280617, -0.003445},{0.759794, 1.280410, -0.005062}}],
    Polygon[{{0.760950, 1.277340, -0.003445},{0.761358, 1.277340, -0.001744},{
      0.760819, 1.280743, -0.001744},{0.760431, 1.280617, -0.003445}}],
    Polygon[{{0.761358, 1.277340, -0.001744},{0.761496, 1.277340, 0.000000},{
      0.760950, 1.280786, 0.000000},{0.760819, 1.280743, -0.001744}}],
    Polygon[{{0.761496, 1.277340, 0.000000},{0.761358, 1.277340, 0.001744},{
      0.760819, 1.280743, 0.001744},{0.760950, 1.280786, 0.000000}}],
    Polygon[{{0.761358, 1.277340, 0.001744},{0.760950, 1.277340, 0.003445},{
      0.760431, 1.280617, 0.003445},{0.760819, 1.280743, 0.001744}}],
    Polygon[{{0.760950, 1.277340, 0.003445},{0.760280, 1.277340, 0.005062},{
      0.759794, 1.280410, 0.005062},{0.760431, 1.280617, 0.003445}}],
    Polygon[{{0.760280, 1.277340, 0.005062},{0.759366, 1.277340, 0.006553},{
      0.758925, 1.280128, 0.006553},{0.759794, 1.280410, 0.005062}}],
    Polygon[{{0.759366, 1.277340, 0.006553},{0.758230, 1.277340, 0.007884},{
      0.757844, 1.279776, 0.007884},{0.758925, 1.280128, 0.006553}}],
    Polygon[{{0.758230, 1.277340, 0.007884},{0.756900, 1.277340, 0.009020},{
      0.756579, 1.279365, 0.009020},{0.757844, 1.279776, 0.007884}}],
    Polygon[{{0.756900, 1.277340, 0.009020},{0.755408, 1.277340, 0.009934},{
      0.755160, 1.278904, 0.009934},{0.756579, 1.279365, 0.009020}}],
    Polygon[{{0.755408, 1.277340, 0.009934},{0.753792, 1.277340, 0.010603},{
      0.753623, 1.278405, 0.010603},{0.755160, 1.278904, 0.009934}}],
    Polygon[{{0.753792, 1.277340, 0.010603},{0.752091, 1.277340, 0.011012},{
      0.752005, 1.277879, 0.011012},{0.753623, 1.278405, 0.010603}}],
    Polygon[{{0.752005, 1.277879, -0.011012},{0.753623, 1.278405, -0.010603},{
      0.753134, 1.279365, -0.010603},{0.751758, 1.278365, -0.011012}}],
    Polygon[{{0.753623, 1.278405, -0.010603},{0.755160, 1.278904, -0.009934},{
      0.754441, 1.280315, -0.009934},{0.753134, 1.279365, -0.010603}}],
    Polygon[{{0.755160, 1.278904, -0.009934},{0.756579, 1.279365, -0.009020},{
      0.755648, 1.281192, -0.009020},{0.754441, 1.280315, -0.009934}}],
    Polygon[{{0.756579, 1.279365, -0.009020},{0.757844, 1.279776, -0.007884},{
      0.756725, 1.281974, -0.007884},{0.755648, 1.281192, -0.009020}}],
    Polygon[{{0.757844, 1.279776, -0.007884},{0.758925, 1.280128, -0.006553},{
      0.757644, 1.282642, -0.006553},{0.756725, 1.281974, -0.007884}}],
    Polygon[{{0.758925, 1.280128, -0.006553},{0.759794, 1.280410, -0.005062},{
      0.758383, 1.283179, -0.005062},{0.757644, 1.282642, -0.006553}}],
    Polygon[{{0.759794, 1.280410, -0.005062},{0.760431, 1.280617, -0.003445},{
      0.758925, 1.283573, -0.003445},{0.758383, 1.283179, -0.005062}}],
    Polygon[{{0.760431, 1.280617, -0.003445},{0.760819, 1.280743, -0.001744},{
      0.759255, 1.283813, -0.001744},{0.758925, 1.283573, -0.003445}}],
    Polygon[{{0.760819, 1.280743, -0.001744},{0.760950, 1.280786, 0.000000},{
      0.759366, 1.283894, 0.000000},{0.759255, 1.283813, -0.001744}}],
    Polygon[{{0.760950, 1.280786, 0.000000},{0.760819, 1.280743, 0.001744},{
      0.759255, 1.283813, 0.001744},{0.759366, 1.283894, 0.000000}}],
    Polygon[{{0.760819, 1.280743, 0.001744},{0.760431, 1.280617, 0.003445},{
      0.758925, 1.283573, 0.003445},{0.759255, 1.283813, 0.001744}}],
    Polygon[{{0.760431, 1.280617, 0.003445},{0.759794, 1.280410, 0.005062},{
      0.758383, 1.283179, 0.005062},{0.758925, 1.283573, 0.003445}}],
    Polygon[{{0.759794, 1.280410, 0.005062},{0.758925, 1.280128, 0.006553},{
      0.757644, 1.282642, 0.006553},{0.758383, 1.283179, 0.005062}}],
    Polygon[{{0.758925, 1.280128, 0.006553},{0.757844, 1.279776, 0.007884},{
      0.756725, 1.281974, 0.007884},{0.757644, 1.282642, 0.006553}}],
    Polygon[{{0.757844, 1.279776, 0.007884},{0.756579, 1.279365, 0.009020},{
      0.755648, 1.281192, 0.009020},{0.756725, 1.281974, 0.007884}}],
    Polygon[{{0.756579, 1.279365, 0.009020},{0.755160, 1.278904, 0.009934},{
      0.754441, 1.280315, 0.009934},{0.755648, 1.281192, 0.009020}}],
    Polygon[{{0.755160, 1.278904, 0.009934},{0.753623, 1.278405, 0.010603},{
      0.753134, 1.279365, 0.010603},{0.754441, 1.280315, 0.009934}}],
    Polygon[{{0.753623, 1.278405, 0.010603},{0.752005, 1.277879, 0.011012},{
      0.751758, 1.278365, 0.011012},{0.753134, 1.279365, 0.010603}}],
    Polygon[{{0.751758, 1.278365, -0.011012},{0.753134, 1.279365, -0.010603},{
      0.752372, 1.280128, -0.010603},{0.751372, 1.278751, -0.011012}}],
    Polygon[{{0.753134, 1.279365, -0.010603},{0.754441, 1.280315, -0.009934},{
      0.753322, 1.281435, -0.009934},{0.752372, 1.280128, -0.010603}}],
    Polygon[{{0.754441, 1.280315, -0.009934},{0.755648, 1.281192, -0.009020},{
      0.754199, 1.282642, -0.009020},{0.753322, 1.281435, -0.009934}}],
    Polygon[{{0.755648, 1.281192, -0.009020},{0.756725, 1.281974, -0.007884},{
      0.754980, 1.283718, -0.007884},{0.754199, 1.282642, -0.009020}}],
    Polygon[{{0.756725, 1.281974, -0.007884},{0.757644, 1.282642, -0.006553},{
      0.755648, 1.284637, -0.006553},{0.754980, 1.283718, -0.007884}}],
    Polygon[{{0.757644, 1.282642, -0.006553},{0.758383, 1.283179, -0.005062},{
      0.756186, 1.285377, -0.005062},{0.755648, 1.284637, -0.006553}}],
    Polygon[{{0.758383, 1.283179, -0.005062},{0.758925, 1.283573, -0.003445},{
      0.756579, 1.285919, -0.003445},{0.756186, 1.285377, -0.005062}}],
    Polygon[{{0.758925, 1.283573, -0.003445},{0.759255, 1.283813, -0.001744},{
      0.756819, 1.286249, -0.001744},{0.756579, 1.285919, -0.003445}}],
    Polygon[{{0.759255, 1.283813, -0.001744},{0.759366, 1.283894, 0.000000},{
      0.756900, 1.286360, 0.000000},{0.756819, 1.286249, -0.001744}}],
    Polygon[{{0.759366, 1.283894, 0.000000},{0.759255, 1.283813, 0.001744},{
      0.756819, 1.286249, 0.001744},{0.756900, 1.286360, 0.000000}}],
    Polygon[{{0.759255, 1.283813, 0.001744},{0.758925, 1.283573, 0.003445},{
      0.756579, 1.285919, 0.003445},{0.756819, 1.286249, 0.001744}}],
    Polygon[{{0.758925, 1.283573, 0.003445},{0.758383, 1.283179, 0.005062},{
      0.756186, 1.285377, 0.005062},{0.756579, 1.285919, 0.003445}}],
    Polygon[{{0.758383, 1.283179, 0.005062},{0.757644, 1.282642, 0.006553},{
      0.755648, 1.284637, 0.006553},{0.756186, 1.285377, 0.005062}}],
    Polygon[{{0.757644, 1.282642, 0.006553},{0.756725, 1.281974, 0.007884},{
      0.754980, 1.283718, 0.007884},{0.755648, 1.284637, 0.006553}}],
    Polygon[{{0.756725, 1.281974, 0.007884},{0.755648, 1.281192, 0.009020},{
      0.754199, 1.282642, 0.009020},{0.754980, 1.283718, 0.007884}}],
    Polygon[{{0.755648, 1.281192, 0.009020},{0.754441, 1.280315, 0.009934},{
      0.753322, 1.281435, 0.009934},{0.754199, 1.282642, 0.009020}}],
    Polygon[{{0.754441, 1.280315, 0.009934},{0.753134, 1.279365, 0.010603},{
      0.752372, 1.280128, 0.010603},{0.753322, 1.281435, 0.009934}}],
    Polygon[{{0.753134, 1.279365, 0.010603},{0.751758, 1.278365, 0.011012},{
      0.751372, 1.278751, 0.011012},{0.752372, 1.280128, 0.010603}}],
    Polygon[{{0.751372, 1.278751, -0.011012},{0.752372, 1.280128, -0.010603},{
      0.751411, 1.280617, -0.010603},{0.750886, 1.278999, -0.011012}}],
    Polygon[{{0.752372, 1.280128, -0.010603},{0.753322, 1.281435, -0.009934},{
      0.751911, 1.282154, -0.009934},{0.751411, 1.280617, -0.010603}}],
    Polygon[{{0.753322, 1.281435, -0.009934},{0.754199, 1.282642, -0.009020},{
      0.752372, 1.283573, -0.009020},{0.751911, 1.282154, -0.009934}}],
    Polygon[{{0.754199, 1.282642, -0.009020},{0.754980, 1.283718, -0.007884},{
      0.752783, 1.284838, -0.007884},{0.752372, 1.283573, -0.009020}}],
    Polygon[{{0.754980, 1.283718, -0.007884},{0.755648, 1.284637, -0.006553},{
      0.753134, 1.285919, -0.006553},{0.752783, 1.284838, -0.007884}}],
    Polygon[{{0.755648, 1.284637, -0.006553},{0.756186, 1.285377, -0.005062},{
      0.753416, 1.286788, -0.005062},{0.753134, 1.285919, -0.006553}}],
    Polygon[{{0.756186, 1.285377, -0.005062},{0.756579, 1.285919, -0.003445},{
      0.753623, 1.287425, -0.003445},{0.753416, 1.286788, -0.005062}}],
    Polygon[{{0.756579, 1.285919, -0.003445},{0.756819, 1.286249, -0.001744},{
      0.753749, 1.287813, -0.001744},{0.753623, 1.287425, -0.003445}}],
    Polygon[{{0.756819, 1.286249, -0.001744},{0.756900, 1.286360, 0.000000},{
      0.753792, 1.287944, 0.000000},{0.753749, 1.287813, -0.001744}}],
    Polygon[{{0.756900, 1.286360, 0.000000},{0.756819, 1.286249, 0.001744},{
      0.753749, 1.287813, 0.001744},{0.753792, 1.287944, 0.000000}}],
    Polygon[{{0.756819, 1.286249, 0.001744},{0.756579, 1.285919, 0.003445},{
      0.753623, 1.287425, 0.003445},{0.753749, 1.287813, 0.001744}}],
    Polygon[{{0.756579, 1.285919, 0.003445},{0.756186, 1.285377, 0.005062},{
      0.753416, 1.286788, 0.005062},{0.753623, 1.287425, 0.003445}}],
    Polygon[{{0.756186, 1.285377, 0.005062},{0.755648, 1.284637, 0.006553},{
      0.753134, 1.285919, 0.006553},{0.753416, 1.286788, 0.005062}}],
    Polygon[{{0.755648, 1.284637, 0.006553},{0.754980, 1.283718, 0.007884},{
      0.752783, 1.284838, 0.007884},{0.753134, 1.285919, 0.006553}}],
    Polygon[{{0.754980, 1.283718, 0.007884},{0.754199, 1.282642, 0.009020},{
      0.752372, 1.283573, 0.009020},{0.752783, 1.284838, 0.007884}}],
    Polygon[{{0.754199, 1.282642, 0.009020},{0.753322, 1.281435, 0.009934},{
      0.751911, 1.282154, 0.009934},{0.752372, 1.283573, 0.009020}}],
    Polygon[{{0.753322, 1.281435, 0.009934},{0.752372, 1.280128, 0.010603},{
      0.751411, 1.280617, 0.010603},{0.751911, 1.282154, 0.009934}}],
    Polygon[{{0.752372, 1.280128, 0.010603},{0.751372, 1.278751, 0.011012},{
      0.750886, 1.278999, 0.011012},{0.751411, 1.280617, 0.010603}}],
    Polygon[{{0.750886, 1.278999, -0.011012},{0.751411, 1.280617, -0.010603},{
      0.750347, 1.280786, -0.010603},{0.750347, 1.279084, -0.011012}}],
    Polygon[{{0.751411, 1.280617, -0.010603},{0.751911, 1.282154, -0.009934},{
      0.750347, 1.282402, -0.009934},{0.750347, 1.280786, -0.010603}}],
    Polygon[{{0.751911, 1.282154, -0.009934},{0.752372, 1.283573, -0.009020},{
      0.750347, 1.283894, -0.009020},{0.750347, 1.282402, -0.009934}}],
    Polygon[{{0.752372, 1.283573, -0.009020},{0.752783, 1.284838, -0.007884},{
      0.750347, 1.285224, -0.007884},{0.750347, 1.283894, -0.009020}}],
    Polygon[{{0.752783, 1.284838, -0.007884},{0.753134, 1.285919, -0.006553},{
      0.750347, 1.286360, -0.006553},{0.750347, 1.285224, -0.007884}}],
    Polygon[{{0.753134, 1.285919, -0.006553},{0.753416, 1.286788, -0.005062},{
      0.750347, 1.287274, -0.005062},{0.750347, 1.286360, -0.006553}}],
    Polygon[{{0.753416, 1.286788, -0.005062},{0.753623, 1.287425, -0.003445},{
      0.750347, 1.287944, -0.003445},{0.750347, 1.287274, -0.005062}}],
    Polygon[{{0.753623, 1.287425, -0.003445},{0.753749, 1.287813, -0.001744},{
      0.750347, 1.288352, -0.001744},{0.750347, 1.287944, -0.003445}}],
    Polygon[{{0.753749, 1.287813, -0.001744},{0.753792, 1.287944, 0.000000},{
      0.750347, 1.288489, 0.000000},{0.750347, 1.288352, -0.001744}}],
    Polygon[{{0.753792, 1.287944, 0.000000},{0.753749, 1.287813, 0.001744},{
      0.750347, 1.288352, 0.001744},{0.750347, 1.288489, 0.000000}}],
    Polygon[{{0.753749, 1.287813, 0.001744},{0.753623, 1.287425, 0.003445},{
      0.750347, 1.287944, 0.003445},{0.750347, 1.288352, 0.001744}}],
    Polygon[{{0.753623, 1.287425, 0.003445},{0.753416, 1.286788, 0.005062},{
      0.750347, 1.287274, 0.005062},{0.750347, 1.287944, 0.003445}}],
    Polygon[{{0.753416, 1.286788, 0.005062},{0.753134, 1.285919, 0.006553},{
      0.750347, 1.286360, 0.006553},{0.750347, 1.287274, 0.005062}}],
    Polygon[{{0.753134, 1.285919, 0.006553},{0.752783, 1.284838, 0.007884},{
      0.750347, 1.285224, 0.007884},{0.750347, 1.286360, 0.006553}}],
    Polygon[{{0.752783, 1.284838, 0.007884},{0.752372, 1.283573, 0.009020},{
      0.750347, 1.283894, 0.009020},{0.750347, 1.285224, 0.007884}}],
    Polygon[{{0.752372, 1.283573, 0.009020},{0.751911, 1.282154, 0.009934},{
      0.750347, 1.282402, 0.009934},{0.750347, 1.283894, 0.009020}}],
    Polygon[{{0.751911, 1.282154, 0.009934},{0.751411, 1.280617, 0.010603},{
      0.750347, 1.280786, 0.010603},{0.750347, 1.282402, 0.009934}}],
    Polygon[{{0.751411, 1.280617, 0.010603},{0.750886, 1.278999, 0.011012},{
      0.750347, 1.279084, 0.011012},{0.750347, 1.280786, 0.010603}}],
    Polygon[{{0.750347, 1.279084, -0.011012},{0.750347, 1.280786, -0.010603},{
      0.749282, 1.280617, -0.010603},{0.749808, 1.278999, -0.011012}}],
    Polygon[{{0.750347, 1.280786, -0.010603},{0.750347, 1.282402, -0.009934},{
      0.748783, 1.282154, -0.009934},{0.749282, 1.280617, -0.010603}}],
    Polygon[{{0.750347, 1.282402, -0.009934},{0.750347, 1.283894, -0.009020},{
      0.748322, 1.283573, -0.009020},{0.748783, 1.282154, -0.009934}}],
    Polygon[{{0.750347, 1.283894, -0.009020},{0.750347, 1.285224, -0.007884},{
      0.747910, 1.284838, -0.007884},{0.748322, 1.283573, -0.009020}}],
    Polygon[{{0.750347, 1.285224, -0.007884},{0.750347, 1.286360, -0.006553},{
      0.747559, 1.285919, -0.006553},{0.747910, 1.284838, -0.007884}}],
    Polygon[{{0.750347, 1.286360, -0.006553},{0.750347, 1.287274, -0.005062},{
      0.747277, 1.286788, -0.005062},{0.747559, 1.285919, -0.006553}}],
    Polygon[{{0.750347, 1.287274, -0.005062},{0.750347, 1.287944, -0.003445},{
      0.747070, 1.287425, -0.003445},{0.747277, 1.286788, -0.005062}}],
    Polygon[{{0.750347, 1.287944, -0.003445},{0.750347, 1.288352, -0.001744},{
      0.746944, 1.287813, -0.001744},{0.747070, 1.287425, -0.003445}}],
    Polygon[{{0.750347, 1.288352, -0.001744},{0.750347, 1.288489, 0.000000},{
      0.746901, 1.287944, 0.000000},{0.746944, 1.287813, -0.001744}}],
    Polygon[{{0.750347, 1.288489, 0.000000},{0.750347, 1.288352, 0.001744},{
      0.746944, 1.287813, 0.001744},{0.746901, 1.287944, 0.000000}}],
    Polygon[{{0.750347, 1.288352, 0.001744},{0.750347, 1.287944, 0.003445},{
      0.747070, 1.287425, 0.003445},{0.746944, 1.287813, 0.001744}}],
    Polygon[{{0.750347, 1.287944, 0.003445},{0.750347, 1.287274, 0.005062},{
      0.747277, 1.286788, 0.005062},{0.747070, 1.287425, 0.003445}}],
    Polygon[{{0.750347, 1.287274, 0.005062},{0.750347, 1.286360, 0.006553},{
      0.747559, 1.285919, 0.006553},{0.747277, 1.286788, 0.005062}}],
    Polygon[{{0.750347, 1.286360, 0.006553},{0.750347, 1.285224, 0.007884},{
      0.747910, 1.284838, 0.007884},{0.747559, 1.285919, 0.006553}}],
    Polygon[{{0.750347, 1.285224, 0.007884},{0.750347, 1.283894, 0.009020},{
      0.748322, 1.283573, 0.009020},{0.747910, 1.284838, 0.007884}}],
    Polygon[{{0.750347, 1.283894, 0.009020},{0.750347, 1.282402, 0.009934},{
      0.748783, 1.282154, 0.009934},{0.748322, 1.283573, 0.009020}}],
    Polygon[{{0.750347, 1.282402, 0.009934},{0.750347, 1.280786, 0.010603},{
      0.749282, 1.280617, 0.010603},{0.748783, 1.282154, 0.009934}}],
    Polygon[{{0.750347, 1.280786, 0.010603},{0.750347, 1.279084, 0.011012},{
      0.749808, 1.278999, 0.011012},{0.749282, 1.280617, 0.010603}}],
    Polygon[{{0.749808, 1.278999, -0.011012},{0.749282, 1.280617, -0.010603},{
      0.748322, 1.280128, -0.010603},{0.749321, 1.278751, -0.011012}}],
    Polygon[{{0.749282, 1.280617, -0.010603},{0.748783, 1.282154, -0.009934},{
      0.747371, 1.281435, -0.009934},{0.748322, 1.280128, -0.010603}}],
    Polygon[{{0.748783, 1.282154, -0.009934},{0.748322, 1.283573, -0.009020},{
      0.746495, 1.282642, -0.009020},{0.747371, 1.281435, -0.009934}}],
    Polygon[{{0.748322, 1.283573, -0.009020},{0.747910, 1.284838, -0.007884},{
      0.745713, 1.283718, -0.007884},{0.746495, 1.282642, -0.009020}}],
    Polygon[{{0.747910, 1.284838, -0.007884},{0.747559, 1.285919, -0.006553},{
      0.745045, 1.284637, -0.006553},{0.745713, 1.283718, -0.007884}}],
    Polygon[{{0.747559, 1.285919, -0.006553},{0.747277, 1.286788, -0.005062},{
      0.744508, 1.285377, -0.005062},{0.745045, 1.284637, -0.006553}}],
    Polygon[{{0.747277, 1.286788, -0.005062},{0.747070, 1.287425, -0.003445},{
      0.744114, 1.285919, -0.003445},{0.744508, 1.285377, -0.005062}}],
    Polygon[{{0.747070, 1.287425, -0.003445},{0.746944, 1.287813, -0.001744},{
      0.743874, 1.286249, -0.001744},{0.744114, 1.285919, -0.003445}}],
    Polygon[{{0.746944, 1.287813, -0.001744},{0.746901, 1.287944, 0.000000},{
      0.743793, 1.286360, 0.000000},{0.743874, 1.286249, -0.001744}}],
    Polygon[{{0.746901, 1.287944, 0.000000},{0.746944, 1.287813, 0.001744},{
      0.743874, 1.286249, 0.001744},{0.743793, 1.286360, 0.000000}}],
    Polygon[{{0.746944, 1.287813, 0.001744},{0.747070, 1.287425, 0.003445},{
      0.744114, 1.285919, 0.003445},{0.743874, 1.286249, 0.001744}}],
    Polygon[{{0.747070, 1.287425, 0.003445},{0.747277, 1.286788, 0.005062},{
      0.744508, 1.285377, 0.005062},{0.744114, 1.285919, 0.003445}}],
    Polygon[{{0.747277, 1.286788, 0.005062},{0.747559, 1.285919, 0.006553},{
      0.745045, 1.284637, 0.006553},{0.744508, 1.285377, 0.005062}}],
    Polygon[{{0.747559, 1.285919, 0.006553},{0.747910, 1.284838, 0.007884},{
      0.745713, 1.283718, 0.007884},{0.745045, 1.284637, 0.006553}}],
    Polygon[{{0.747910, 1.284838, 0.007884},{0.748322, 1.283573, 0.009020},{
      0.746495, 1.282642, 0.009020},{0.745713, 1.283718, 0.007884}}],
    Polygon[{{0.748322, 1.283573, 0.009020},{0.748783, 1.282154, 0.009934},{
      0.747371, 1.281435, 0.009934},{0.746495, 1.282642, 0.009020}}],
    Polygon[{{0.748783, 1.282154, 0.009934},{0.749282, 1.280617, 0.010603},{
      0.748322, 1.280128, 0.010603},{0.747371, 1.281435, 0.009934}}],
    Polygon[{{0.749282, 1.280617, 0.010603},{0.749808, 1.278999, 0.011012},{
      0.749321, 1.278751, 0.011012},{0.748322, 1.280128, 0.010603}}],
    Polygon[{{0.749321, 1.278751, -0.011012},{0.748322, 1.280128, -0.010603},{
      0.747559, 1.279365, -0.010603},{0.748936, 1.278365, -0.011012}}],
    Polygon[{{0.748322, 1.280128, -0.010603},{0.747371, 1.281435, -0.009934},{
      0.746252, 1.280315, -0.009934},{0.747559, 1.279365, -0.010603}}],
    Polygon[{{0.747371, 1.281435, -0.009934},{0.746495, 1.282642, -0.009020},{
      0.745045, 1.281192, -0.009020},{0.746252, 1.280315, -0.009934}}],
    Polygon[{{0.746495, 1.282642, -0.009020},{0.745713, 1.283718, -0.007884},{
      0.743969, 1.281974, -0.007884},{0.745045, 1.281192, -0.009020}}],
    Polygon[{{0.745713, 1.283718, -0.007884},{0.745045, 1.284637, -0.006553},{
      0.743049, 1.282642, -0.006553},{0.743969, 1.281974, -0.007884}}],
    Polygon[{{0.745045, 1.284637, -0.006553},{0.744508, 1.285377, -0.005062},{
      0.742310, 1.283179, -0.005062},{0.743049, 1.282642, -0.006553}}],
    Polygon[{{0.744508, 1.285377, -0.005062},{0.744114, 1.285919, -0.003445},{
      0.741768, 1.283573, -0.003445},{0.742310, 1.283179, -0.005062}}],
    Polygon[{{0.744114, 1.285919, -0.003445},{0.743874, 1.286249, -0.001744},{
      0.741438, 1.283813, -0.001744},{0.741768, 1.283573, -0.003445}}],
    Polygon[{{0.743874, 1.286249, -0.001744},{0.743793, 1.286360, 0.000000},{
      0.741327, 1.283894, 0.000000},{0.741438, 1.283813, -0.001744}}],
    Polygon[{{0.743793, 1.286360, 0.000000},{0.743874, 1.286249, 0.001744},{
      0.741438, 1.283813, 0.001744},{0.741327, 1.283894, 0.000000}}],
    Polygon[{{0.743874, 1.286249, 0.001744},{0.744114, 1.285919, 0.003445},{
      0.741768, 1.283573, 0.003445},{0.741438, 1.283813, 0.001744}}],
    Polygon[{{0.744114, 1.285919, 0.003445},{0.744508, 1.285377, 0.005062},{
      0.742310, 1.283179, 0.005062},{0.741768, 1.283573, 0.003445}}],
    Polygon[{{0.744508, 1.285377, 0.005062},{0.745045, 1.284637, 0.006553},{
      0.743049, 1.282642, 0.006553},{0.742310, 1.283179, 0.005062}}],
    Polygon[{{0.745045, 1.284637, 0.006553},{0.745713, 1.283718, 0.007884},{
      0.743969, 1.281974, 0.007884},{0.743049, 1.282642, 0.006553}}],
    Polygon[{{0.745713, 1.283718, 0.007884},{0.746495, 1.282642, 0.009020},{
      0.745045, 1.281192, 0.009020},{0.743969, 1.281974, 0.007884}}],
    Polygon[{{0.746495, 1.282642, 0.009020},{0.747371, 1.281435, 0.009934},{
      0.746252, 1.280315, 0.009934},{0.745045, 1.281192, 0.009020}}],
    Polygon[{{0.747371, 1.281435, 0.009934},{0.748322, 1.280128, 0.010603},{
      0.747559, 1.279365, 0.010603},{0.746252, 1.280315, 0.009934}}],
    Polygon[{{0.748322, 1.280128, 0.010603},{0.749321, 1.278751, 0.011012},{
      0.748936, 1.278365, 0.011012},{0.747559, 1.279365, 0.010603}}],
    Polygon[{{0.748936, 1.278365, -0.011012},{0.747559, 1.279365, -0.010603},{
      0.747070, 1.278405, -0.010603},{0.748688, 1.277879, -0.011012}}],
    Polygon[{{0.747559, 1.279365, -0.010603},{0.746252, 1.280315, -0.009934},{
      0.745533, 1.278904, -0.009934},{0.747070, 1.278405, -0.010603}}],
    Polygon[{{0.746252, 1.280315, -0.009934},{0.745045, 1.281192, -0.009020},{
      0.744114, 1.279365, -0.009020},{0.745533, 1.278904, -0.009934}}],
    Polygon[{{0.745045, 1.281192, -0.009020},{0.743969, 1.281974, -0.007884},{
      0.742849, 1.279776, -0.007884},{0.744114, 1.279365, -0.009020}}],
    Polygon[{{0.743969, 1.281974, -0.007884},{0.743049, 1.282642, -0.006553},{
      0.741768, 1.280128, -0.006553},{0.742849, 1.279776, -0.007884}}],
    Polygon[{{0.743049, 1.282642, -0.006553},{0.742310, 1.283179, -0.005062},{
      0.740899, 1.280410, -0.005062},{0.741768, 1.280128, -0.006553}}],
    Polygon[{{0.742310, 1.283179, -0.005062},{0.741768, 1.283573, -0.003445},{
      0.740262, 1.280617, -0.003445},{0.740899, 1.280410, -0.005062}}],
    Polygon[{{0.741768, 1.283573, -0.003445},{0.741438, 1.283813, -0.001744},{
      0.739874, 1.280743, -0.001744},{0.740262, 1.280617, -0.003445}}],
    Polygon[{{0.741438, 1.283813, -0.001744},{0.741327, 1.283894, 0.000000},{
      0.739743, 1.280786, 0.000000},{0.739874, 1.280743, -0.001744}}],
    Polygon[{{0.741327, 1.283894, 0.000000},{0.741438, 1.283813, 0.001744},{
      0.739874, 1.280743, 0.001744},{0.739743, 1.280786, 0.000000}}],
    Polygon[{{0.741438, 1.283813, 0.001744},{0.741768, 1.283573, 0.003445},{
      0.740262, 1.280617, 0.003445},{0.739874, 1.280743, 0.001744}}],
    Polygon[{{0.741768, 1.283573, 0.003445},{0.742310, 1.283179, 0.005062},{
      0.740899, 1.280410, 0.005062},{0.740262, 1.280617, 0.003445}}],
    Polygon[{{0.742310, 1.283179, 0.005062},{0.743049, 1.282642, 0.006553},{
      0.741768, 1.280128, 0.006553},{0.740899, 1.280410, 0.005062}}],
    Polygon[{{0.743049, 1.282642, 0.006553},{0.743969, 1.281974, 0.007884},{
      0.742849, 1.279776, 0.007884},{0.741768, 1.280128, 0.006553}}],
    Polygon[{{0.743969, 1.281974, 0.007884},{0.745045, 1.281192, 0.009020},{
      0.744114, 1.279365, 0.009020},{0.742849, 1.279776, 0.007884}}],
    Polygon[{{0.745045, 1.281192, 0.009020},{0.746252, 1.280315, 0.009934},{
      0.745533, 1.278904, 0.009934},{0.744114, 1.279365, 0.009020}}],
    Polygon[{{0.746252, 1.280315, 0.009934},{0.747559, 1.279365, 0.010603},{
      0.747070, 1.278405, 0.010603},{0.745533, 1.278904, 0.009934}}],
    Polygon[{{0.747559, 1.279365, 0.010603},{0.748936, 1.278365, 0.011012},{
      0.748688, 1.277879, 0.011012},{0.747070, 1.278405, 0.010603}}],
    Polygon[{{0.748688, 1.277879, -0.011012},{0.747070, 1.278405, -0.010603},{
      0.746901, 1.277340, -0.010603},{0.748603, 1.277340, -0.011012}}],
    Polygon[{{0.747070, 1.278405, -0.010603},{0.745533, 1.278904, -0.009934},{
      0.745285, 1.277340, -0.009934},{0.746901, 1.277340, -0.010603}}],
    Polygon[{{0.745533, 1.278904, -0.009934},{0.744114, 1.279365, -0.009020},{
      0.743793, 1.277340, -0.009020},{0.745285, 1.277340, -0.009934}}],
    Polygon[{{0.744114, 1.279365, -0.009020},{0.742849, 1.279776, -0.007884},{
      0.742463, 1.277340, -0.007884},{0.743793, 1.277340, -0.009020}}],
    Polygon[{{0.742849, 1.279776, -0.007884},{0.741768, 1.280128, -0.006553},{
      0.741327, 1.277340, -0.006553},{0.742463, 1.277340, -0.007884}}],
    Polygon[{{0.741768, 1.280128, -0.006553},{0.740899, 1.280410, -0.005062},{
      0.740413, 1.277340, -0.005062},{0.741327, 1.277340, -0.006553}}],
    Polygon[{{0.740899, 1.280410, -0.005062},{0.740262, 1.280617, -0.003445},{
      0.739743, 1.277340, -0.003445},{0.740413, 1.277340, -0.005062}}],
    Polygon[{{0.740262, 1.280617, -0.003445},{0.739874, 1.280743, -0.001744},{
      0.739335, 1.277340, -0.001744},{0.739743, 1.277340, -0.003445}}],
    Polygon[{{0.739874, 1.280743, -0.001744},{0.739743, 1.280786, 0.000000},{
      0.739198, 1.277340, 0.000000},{0.739335, 1.277340, -0.001744}}],
    Polygon[{{0.739743, 1.280786, 0.000000},{0.739874, 1.280743, 0.001744},{
      0.739335, 1.277340, 0.001744},{0.739198, 1.277340, 0.000000}}],
    Polygon[{{0.739874, 1.280743, 0.001744},{0.740262, 1.280617, 0.003445},{
      0.739743, 1.277340, 0.003445},{0.739335, 1.277340, 0.001744}}],
    Polygon[{{0.740262, 1.280617, 0.003445},{0.740899, 1.280410, 0.005062},{
      0.740413, 1.277340, 0.005062},{0.739743, 1.277340, 0.003445}}],
    Polygon[{{0.740899, 1.280410, 0.005062},{0.741768, 1.280128, 0.006553},{
      0.741327, 1.277340, 0.006553},{0.740413, 1.277340, 0.005062}}],
    Polygon[{{0.741768, 1.280128, 0.006553},{0.742849, 1.279776, 0.007884},{
      0.742463, 1.277340, 0.007884},{0.741327, 1.277340, 0.006553}}],
    Polygon[{{0.742849, 1.279776, 0.007884},{0.744114, 1.279365, 0.009020},{
      0.743793, 1.277340, 0.009020},{0.742463, 1.277340, 0.007884}}],
    Polygon[{{0.744114, 1.279365, 0.009020},{0.745533, 1.278904, 0.009934},{
      0.745285, 1.277340, 0.009934},{0.743793, 1.277340, 0.009020}}],
    Polygon[{{0.745533, 1.278904, 0.009934},{0.747070, 1.278405, 0.010603},{
      0.746901, 1.277340, 0.010603},{0.745285, 1.277340, 0.009934}}],
    Polygon[{{0.747070, 1.278405, 0.010603},{0.748688, 1.277879, 0.011012},{
      0.748603, 1.277340, 0.011012},{0.746901, 1.277340, 0.010603}}],
    Polygon[{{0.748603, 1.277340, -0.011012},{0.746901, 1.277340, -0.010603},{
      0.747070, 1.276276, -0.010603},{0.748688, 1.276801, -0.011012}}],
    Polygon[{{0.746901, 1.277340, -0.010603},{0.745285, 1.277340, -0.009934},{
      0.745533, 1.275776, -0.009934},{0.747070, 1.276276, -0.010603}}],
    Polygon[{{0.745285, 1.277340, -0.009934},{0.743793, 1.277340, -0.009020},{
      0.744114, 1.275315, -0.009020},{0.745533, 1.275776, -0.009934}}],
    Polygon[{{0.743793, 1.277340, -0.009020},{0.742463, 1.277340, -0.007884},{
      0.742849, 1.274904, -0.007884},{0.744114, 1.275315, -0.009020}}],
    Polygon[{{0.742463, 1.277340, -0.007884},{0.741327, 1.277340, -0.006553},{
      0.741768, 1.274553, -0.006553},{0.742849, 1.274904, -0.007884}}],
    Polygon[{{0.741327, 1.277340, -0.006553},{0.740413, 1.277340, -0.005062},{
      0.740899, 1.274271, -0.005062},{0.741768, 1.274553, -0.006553}}],
    Polygon[{{0.740413, 1.277340, -0.005062},{0.739743, 1.277340, -0.003445},{
      0.740262, 1.274064, -0.003445},{0.740899, 1.274271, -0.005062}}],
    Polygon[{{0.739743, 1.277340, -0.003445},{0.739335, 1.277340, -0.001744},{
      0.739874, 1.273937, -0.001744},{0.740262, 1.274064, -0.003445}}],
    Polygon[{{0.739335, 1.277340, -0.001744},{0.739198, 1.277340, 0.000000},{
      0.739743, 1.273895, 0.000000},{0.739874, 1.273937, -0.001744}}],
    Polygon[{{0.739198, 1.277340, 0.000000},{0.739335, 1.277340, 0.001744},{
      0.739874, 1.273937, 0.001744},{0.739743, 1.273895, 0.000000}}],
    Polygon[{{0.739335, 1.277340, 0.001744},{0.739743, 1.277340, 0.003445},{
      0.740262, 1.274064, 0.003445},{0.739874, 1.273937, 0.001744}}],
    Polygon[{{0.739743, 1.277340, 0.003445},{0.740413, 1.277340, 0.005062},{
      0.740899, 1.274271, 0.005062},{0.740262, 1.274064, 0.003445}}],
    Polygon[{{0.740413, 1.277340, 0.005062},{0.741327, 1.277340, 0.006553},{
      0.741768, 1.274553, 0.006553},{0.740899, 1.274271, 0.005062}}],
    Polygon[{{0.741327, 1.277340, 0.006553},{0.742463, 1.277340, 0.007884},{
      0.742849, 1.274904, 0.007884},{0.741768, 1.274553, 0.006553}}],
    Polygon[{{0.742463, 1.277340, 0.007884},{0.743793, 1.277340, 0.009020},{
      0.744114, 1.275315, 0.009020},{0.742849, 1.274904, 0.007884}}],
    Polygon[{{0.743793, 1.277340, 0.009020},{0.745285, 1.277340, 0.009934},{
      0.745533, 1.275776, 0.009934},{0.744114, 1.275315, 0.009020}}],
    Polygon[{{0.745285, 1.277340, 0.009934},{0.746901, 1.277340, 0.010603},{
      0.747070, 1.276276, 0.010603},{0.745533, 1.275776, 0.009934}}],
    Polygon[{{0.746901, 1.277340, 0.010603},{0.748603, 1.277340, 0.011012},{
      0.748688, 1.276801, 0.011012},{0.747070, 1.276276, 0.010603}}],
    Polygon[{{0.748688, 1.276801, -0.011012},{0.747070, 1.276276, -0.010603},{
      0.747559, 1.275315, -0.010603},{0.748936, 1.276315, -0.011012}}],
    Polygon[{{0.747070, 1.276276, -0.010603},{0.745533, 1.275776, -0.009934},{
      0.746252, 1.274365, -0.009934},{0.747559, 1.275315, -0.010603}}],
    Polygon[{{0.745533, 1.275776, -0.009934},{0.744114, 1.275315, -0.009020},{
      0.745045, 1.273488, -0.009020},{0.746252, 1.274365, -0.009934}}],
    Polygon[{{0.744114, 1.275315, -0.009020},{0.742849, 1.274904, -0.007884},{
      0.743969, 1.272707, -0.007884},{0.745045, 1.273488, -0.009020}}],
    Polygon[{{0.742849, 1.274904, -0.007884},{0.741768, 1.274553, -0.006553},{
      0.743049, 1.272039, -0.006553},{0.743969, 1.272707, -0.007884}}],
    Polygon[{{0.741768, 1.274553, -0.006553},{0.740899, 1.274271, -0.005062},{
      0.742310, 1.271501, -0.005062},{0.743049, 1.272039, -0.006553}}],
    Polygon[{{0.740899, 1.274271, -0.005062},{0.740262, 1.274064, -0.003445},{
      0.741768, 1.271108, -0.003445},{0.742310, 1.271501, -0.005062}}],
    Polygon[{{0.740262, 1.274064, -0.003445},{0.739874, 1.273937, -0.001744},{
      0.741438, 1.270868, -0.001744},{0.741768, 1.271108, -0.003445}}],
    Polygon[{{0.739874, 1.273937, -0.001744},{0.739743, 1.273895, 0.000000},{
      0.741327, 1.270787, 0.000000},{0.741438, 1.270868, -0.001744}}],
    Polygon[{{0.739743, 1.273895, 0.000000},{0.739874, 1.273937, 0.001744},{
      0.741438, 1.270868, 0.001744},{0.741327, 1.270787, 0.000000}}],
    Polygon[{{0.739874, 1.273937, 0.001744},{0.740262, 1.274064, 0.003445},{
      0.741768, 1.271108, 0.003445},{0.741438, 1.270868, 0.001744}}],
    Polygon[{{0.740262, 1.274064, 0.003445},{0.740899, 1.274271, 0.005062},{
      0.742310, 1.271501, 0.005062},{0.741768, 1.271108, 0.003445}}],
    Polygon[{{0.740899, 1.274271, 0.005062},{0.741768, 1.274553, 0.006553},{
      0.743049, 1.272039, 0.006553},{0.742310, 1.271501, 0.005062}}],
    Polygon[{{0.741768, 1.274553, 0.006553},{0.742849, 1.274904, 0.007884},{
      0.743969, 1.272707, 0.007884},{0.743049, 1.272039, 0.006553}}],
    Polygon[{{0.742849, 1.274904, 0.007884},{0.744114, 1.275315, 0.009020},{
      0.745045, 1.273488, 0.009020},{0.743969, 1.272707, 0.007884}}],
    Polygon[{{0.744114, 1.275315, 0.009020},{0.745533, 1.275776, 0.009934},{
      0.746252, 1.274365, 0.009934},{0.745045, 1.273488, 0.009020}}],
    Polygon[{{0.745533, 1.275776, 0.009934},{0.747070, 1.276276, 0.010603},{
      0.747559, 1.275315, 0.010603},{0.746252, 1.274365, 0.009934}}],
    Polygon[{{0.747070, 1.276276, 0.010603},{0.748688, 1.276801, 0.011012},{
      0.748936, 1.276315, 0.011012},{0.747559, 1.275315, 0.010603}}],
    Polygon[{{0.748936, 1.276315, -0.011012},{0.747559, 1.275315, -0.010603},{
      0.748322, 1.274553, -0.010603},{0.749321, 1.275929, -0.011012}}],
    Polygon[{{0.747559, 1.275315, -0.010603},{0.746252, 1.274365, -0.009934},{
      0.747371, 1.273245, -0.009934},{0.748322, 1.274553, -0.010603}}],
    Polygon[{{0.746252, 1.274365, -0.009934},{0.745045, 1.273488, -0.009020},{
      0.746495, 1.272039, -0.009020},{0.747371, 1.273245, -0.009934}}],
    Polygon[{{0.745045, 1.273488, -0.009020},{0.743969, 1.272707, -0.007884},{
      0.745713, 1.270962, -0.007884},{0.746495, 1.272039, -0.009020}}],
    Polygon[{{0.743969, 1.272707, -0.007884},{0.743049, 1.272039, -0.006553},{
      0.745045, 1.270043, -0.006553},{0.745713, 1.270962, -0.007884}}],
    Polygon[{{0.743049, 1.272039, -0.006553},{0.742310, 1.271501, -0.005062},{
      0.744508, 1.269304, -0.005062},{0.745045, 1.270043, -0.006553}}],
    Polygon[{{0.742310, 1.271501, -0.005062},{0.741768, 1.271108, -0.003445},{
      0.744114, 1.268762, -0.003445},{0.744508, 1.269304, -0.005062}}],
    Polygon[{{0.741768, 1.271108, -0.003445},{0.741438, 1.270868, -0.001744},{
      0.743874, 1.268432, -0.001744},{0.744114, 1.268762, -0.003445}}],
    Polygon[{{0.741438, 1.270868, -0.001744},{0.741327, 1.270787, 0.000000},{
      0.743793, 1.268321, 0.000000},{0.743874, 1.268432, -0.001744}}],
    Polygon[{{0.741327, 1.270787, 0.000000},{0.741438, 1.270868, 0.001744},{
      0.743874, 1.268432, 0.001744},{0.743793, 1.268321, 0.000000}}],
    Polygon[{{0.741438, 1.270868, 0.001744},{0.741768, 1.271108, 0.003445},{
      0.744114, 1.268762, 0.003445},{0.743874, 1.268432, 0.001744}}],
    Polygon[{{0.741768, 1.271108, 0.003445},{0.742310, 1.271501, 0.005062},{
      0.744508, 1.269304, 0.005062},{0.744114, 1.268762, 0.003445}}],
    Polygon[{{0.742310, 1.271501, 0.005062},{0.743049, 1.272039, 0.006553},{
      0.745045, 1.270043, 0.006553},{0.744508, 1.269304, 0.005062}}],
    Polygon[{{0.743049, 1.272039, 0.006553},{0.743969, 1.272707, 0.007884},{
      0.745713, 1.270962, 0.007884},{0.745045, 1.270043, 0.006553}}],
    Polygon[{{0.743969, 1.272707, 0.007884},{0.745045, 1.273488, 0.009020},{
      0.746495, 1.272039, 0.009020},{0.745713, 1.270962, 0.007884}}],
    Polygon[{{0.745045, 1.273488, 0.009020},{0.746252, 1.274365, 0.009934},{
      0.747371, 1.273245, 0.009934},{0.746495, 1.272039, 0.009020}}],
    Polygon[{{0.746252, 1.274365, 0.009934},{0.747559, 1.275315, 0.010603},{
      0.748322, 1.274553, 0.010603},{0.747371, 1.273245, 0.009934}}],
    Polygon[{{0.747559, 1.275315, 0.010603},{0.748936, 1.276315, 0.011012},{
      0.749321, 1.275929, 0.011012},{0.748322, 1.274553, 0.010603}}],
    Polygon[{{0.749321, 1.275929, -0.011012},{0.748322, 1.274553, -0.010603},{
      0.749282, 1.274064, -0.010603},{0.749808, 1.275682, -0.011012}}],
    Polygon[{{0.748322, 1.274553, -0.010603},{0.747371, 1.273245, -0.009934},{
      0.748783, 1.272527, -0.009934},{0.749282, 1.274064, -0.010603}}],
    Polygon[{{0.747371, 1.273245, -0.009934},{0.746495, 1.272039, -0.009020},{
      0.748322, 1.271108, -0.009020},{0.748783, 1.272527, -0.009934}}],
    Polygon[{{0.746495, 1.272039, -0.009020},{0.745713, 1.270962, -0.007884},{
      0.747910, 1.269843, -0.007884},{0.748322, 1.271108, -0.009020}}],
    Polygon[{{0.745713, 1.270962, -0.007884},{0.745045, 1.270043, -0.006553},{
      0.747559, 1.268762, -0.006553},{0.747910, 1.269843, -0.007884}}],
    Polygon[{{0.745045, 1.270043, -0.006553},{0.744508, 1.269304, -0.005062},{
      0.747277, 1.267893, -0.005062},{0.747559, 1.268762, -0.006553}}],
    Polygon[{{0.744508, 1.269304, -0.005062},{0.744114, 1.268762, -0.003445},{
      0.747070, 1.267256, -0.003445},{0.747277, 1.267893, -0.005062}}],
    Polygon[{{0.744114, 1.268762, -0.003445},{0.743874, 1.268432, -0.001744},{
      0.746944, 1.266868, -0.001744},{0.747070, 1.267256, -0.003445}}],
    Polygon[{{0.743874, 1.268432, -0.001744},{0.743793, 1.268321, 0.000000},{
      0.746901, 1.266737, 0.000000},{0.746944, 1.266868, -0.001744}}],
    Polygon[{{0.743793, 1.268321, 0.000000},{0.743874, 1.268432, 0.001744},{
      0.746944, 1.266868, 0.001744},{0.746901, 1.266737, 0.000000}}],
    Polygon[{{0.743874, 1.268432, 0.001744},{0.744114, 1.268762, 0.003445},{
      0.747070, 1.267256, 0.003445},{0.746944, 1.266868, 0.001744}}],
    Polygon[{{0.744114, 1.268762, 0.003445},{0.744508, 1.269304, 0.005062},{
      0.747277, 1.267893, 0.005062},{0.747070, 1.267256, 0.003445}}],
    Polygon[{{0.744508, 1.269304, 0.005062},{0.745045, 1.270043, 0.006553},{
      0.747559, 1.268762, 0.006553},{0.747277, 1.267893, 0.005062}}],
    Polygon[{{0.745045, 1.270043, 0.006553},{0.745713, 1.270962, 0.007884},{
      0.747910, 1.269843, 0.007884},{0.747559, 1.268762, 0.006553}}],
    Polygon[{{0.745713, 1.270962, 0.007884},{0.746495, 1.272039, 0.009020},{
      0.748322, 1.271108, 0.009020},{0.747910, 1.269843, 0.007884}}],
    Polygon[{{0.746495, 1.272039, 0.009020},{0.747371, 1.273245, 0.009934},{
      0.748783, 1.272527, 0.009934},{0.748322, 1.271108, 0.009020}}],
    Polygon[{{0.747371, 1.273245, 0.009934},{0.748322, 1.274553, 0.010603},{
      0.749282, 1.274064, 0.010603},{0.748783, 1.272527, 0.009934}}],
    Polygon[{{0.748322, 1.274553, 0.010603},{0.749321, 1.275929, 0.011012},{
      0.749808, 1.275682, 0.011012},{0.749282, 1.274064, 0.010603}}],
    Polygon[{{0.749808, 1.275682, -0.011012},{0.749282, 1.274064, -0.010603},{
      0.750347, 1.273895, -0.010603},{0.750347, 1.275596, -0.011012}}],
    Polygon[{{0.749282, 1.274064, -0.010603},{0.748783, 1.272527, -0.009934},{
      0.750347, 1.272279, -0.009934},{0.750347, 1.273895, -0.010603}}],
    Polygon[{{0.748783, 1.272527, -0.009934},{0.748322, 1.271108, -0.009020},{
      0.750347, 1.270787, -0.009020},{0.750347, 1.272279, -0.009934}}],
    Polygon[{{0.748322, 1.271108, -0.009020},{0.747910, 1.269843, -0.007884},{
      0.750347, 1.269457, -0.007884},{0.750347, 1.270787, -0.009020}}],
    Polygon[{{0.747910, 1.269843, -0.007884},{0.747559, 1.268762, -0.006553},{
      0.750347, 1.268321, -0.006553},{0.750347, 1.269457, -0.007884}}],
    Polygon[{{0.747559, 1.268762, -0.006553},{0.747277, 1.267893, -0.005062},{
      0.750347, 1.267406, -0.005062},{0.750347, 1.268321, -0.006553}}],
    Polygon[{{0.747277, 1.267893, -0.005062},{0.747070, 1.267256, -0.003445},{
      0.750347, 1.266737, -0.003445},{0.750347, 1.267406, -0.005062}}],
    Polygon[{{0.747070, 1.267256, -0.003445},{0.746944, 1.266868, -0.001744},{
      0.750347, 1.266328, -0.001744},{0.750347, 1.266737, -0.003445}}],
    Polygon[{{0.746944, 1.266868, -0.001744},{0.746901, 1.266737, 0.000000},{
      0.750347, 1.266191, 0.000000},{0.750347, 1.266328, -0.001744}}],
    Polygon[{{0.746901, 1.266737, 0.000000},{0.746944, 1.266868, 0.001744},{
      0.750347, 1.266328, 0.001744},{0.750347, 1.266191, 0.000000}}],
    Polygon[{{0.746944, 1.266868, 0.001744},{0.747070, 1.267256, 0.003445},{
      0.750347, 1.266737, 0.003445},{0.750347, 1.266328, 0.001744}}],
    Polygon[{{0.747070, 1.267256, 0.003445},{0.747277, 1.267893, 0.005062},{
      0.750347, 1.267406, 0.005062},{0.750347, 1.266737, 0.003445}}],
    Polygon[{{0.747277, 1.267893, 0.005062},{0.747559, 1.268762, 0.006553},{
      0.750347, 1.268321, 0.006553},{0.750347, 1.267406, 0.005062}}],
    Polygon[{{0.747559, 1.268762, 0.006553},{0.747910, 1.269843, 0.007884},{
      0.750347, 1.269457, 0.007884},{0.750347, 1.268321, 0.006553}}],
    Polygon[{{0.747910, 1.269843, 0.007884},{0.748322, 1.271108, 0.009020},{
      0.750347, 1.270787, 0.009020},{0.750347, 1.269457, 0.007884}}],
    Polygon[{{0.748322, 1.271108, 0.009020},{0.748783, 1.272527, 0.009934},{
      0.750347, 1.272279, 0.009934},{0.750347, 1.270787, 0.009020}}],
    Polygon[{{0.748783, 1.272527, 0.009934},{0.749282, 1.274064, 0.010603},{
      0.750347, 1.273895, 0.010603},{0.750347, 1.272279, 0.009934}}],
    Polygon[{{0.749282, 1.274064, 0.010603},{0.749808, 1.275682, 0.011012},{
      0.750347, 1.275596, 0.011012},{0.750347, 1.273895, 0.010603}}],
    Polygon[{{0.750347, 1.275596, -0.011012},{0.750347, 1.273895, -0.010603},{
      0.751411, 1.274064, -0.010603},{0.750886, 1.275682, -0.011012}}],
    Polygon[{{0.750347, 1.273895, -0.010603},{0.750347, 1.272279, -0.009934},{
      0.751911, 1.272527, -0.009934},{0.751411, 1.274064, -0.010603}}],
    Polygon[{{0.750347, 1.272279, -0.009934},{0.750347, 1.270787, -0.009020},{
      0.752372, 1.271108, -0.009020},{0.751911, 1.272527, -0.009934}}],
    Polygon[{{0.750347, 1.270787, -0.009020},{0.750347, 1.269457, -0.007884},{
      0.752783, 1.269843, -0.007884},{0.752372, 1.271108, -0.009020}}],
    Polygon[{{0.750347, 1.269457, -0.007884},{0.750347, 1.268321, -0.006553},{
      0.753134, 1.268762, -0.006553},{0.752783, 1.269843, -0.007884}}],
    Polygon[{{0.750347, 1.268321, -0.006553},{0.750347, 1.267406, -0.005062},{
      0.753416, 1.267893, -0.005062},{0.753134, 1.268762, -0.006553}}],
    Polygon[{{0.750347, 1.267406, -0.005062},{0.750347, 1.266737, -0.003445},{
      0.753623, 1.267256, -0.003445},{0.753416, 1.267893, -0.005062}}],
    Polygon[{{0.750347, 1.266737, -0.003445},{0.750347, 1.266328, -0.001744},{
      0.753749, 1.266868, -0.001744},{0.753623, 1.267256, -0.003445}}],
    Polygon[{{0.750347, 1.266328, -0.001744},{0.750347, 1.266191, 0.000000},{
      0.753792, 1.266737, 0.000000},{0.753749, 1.266868, -0.001744}}],
    Polygon[{{0.750347, 1.266191, 0.000000},{0.750347, 1.266328, 0.001744},{
      0.753749, 1.266868, 0.001744},{0.753792, 1.266737, 0.000000}}],
    Polygon[{{0.750347, 1.266328, 0.001744},{0.750347, 1.266737, 0.003445},{
      0.753623, 1.267256, 0.003445},{0.753749, 1.266868, 0.001744}}],
    Polygon[{{0.750347, 1.266737, 0.003445},{0.750347, 1.267406, 0.005062},{
      0.753416, 1.267893, 0.005062},{0.753623, 1.267256, 0.003445}}],
    Polygon[{{0.750347, 1.267406, 0.005062},{0.750347, 1.268321, 0.006553},{
      0.753134, 1.268762, 0.006553},{0.753416, 1.267893, 0.005062}}],
    Polygon[{{0.750347, 1.268321, 0.006553},{0.750347, 1.269457, 0.007884},{
      0.752783, 1.269843, 0.007884},{0.753134, 1.268762, 0.006553}}],
    Polygon[{{0.750347, 1.269457, 0.007884},{0.750347, 1.270787, 0.009020},{
      0.752372, 1.271108, 0.009020},{0.752783, 1.269843, 0.007884}}],
    Polygon[{{0.750347, 1.270787, 0.009020},{0.750347, 1.272279, 0.009934},{
      0.751911, 1.272527, 0.009934},{0.752372, 1.271108, 0.009020}}],
    Polygon[{{0.750347, 1.272279, 0.009934},{0.750347, 1.273895, 0.010603},{
      0.751411, 1.274064, 0.010603},{0.751911, 1.272527, 0.009934}}],
    Polygon[{{0.750347, 1.273895, 0.010603},{0.750347, 1.275596, 0.011012},{
      0.750886, 1.275682, 0.011012},{0.751411, 1.274064, 0.010603}}],
    Polygon[{{0.750886, 1.275682, -0.011012},{0.751411, 1.274064, -0.010603},{
      0.752372, 1.274553, -0.010603},{0.751372, 1.275929, -0.011012}}],
    Polygon[{{0.751411, 1.274064, -0.010603},{0.751911, 1.272527, -0.009934},{
      0.753322, 1.273245, -0.009934},{0.752372, 1.274553, -0.010603}}],
    Polygon[{{0.751911, 1.272527, -0.009934},{0.752372, 1.271108, -0.009020},{
      0.754199, 1.272039, -0.009020},{0.753322, 1.273245, -0.009934}}],
    Polygon[{{0.752372, 1.271108, -0.009020},{0.752783, 1.269843, -0.007884},{
      0.754980, 1.270962, -0.007884},{0.754199, 1.272039, -0.009020}}],
    Polygon[{{0.752783, 1.269843, -0.007884},{0.753134, 1.268762, -0.006553},{
      0.755648, 1.270043, -0.006553},{0.754980, 1.270962, -0.007884}}],
    Polygon[{{0.753134, 1.268762, -0.006553},{0.753416, 1.267893, -0.005062},{
      0.756186, 1.269304, -0.005062},{0.755648, 1.270043, -0.006553}}],
    Polygon[{{0.753416, 1.267893, -0.005062},{0.753623, 1.267256, -0.003445},{
      0.756579, 1.268762, -0.003445},{0.756186, 1.269304, -0.005062}}],
    Polygon[{{0.753623, 1.267256, -0.003445},{0.753749, 1.266868, -0.001744},{
      0.756819, 1.268432, -0.001744},{0.756579, 1.268762, -0.003445}}],
    Polygon[{{0.753749, 1.266868, -0.001744},{0.753792, 1.266737, 0.000000},{
      0.756900, 1.268321, 0.000000},{0.756819, 1.268432, -0.001744}}],
    Polygon[{{0.753792, 1.266737, 0.000000},{0.753749, 1.266868, 0.001744},{
      0.756819, 1.268432, 0.001744},{0.756900, 1.268321, 0.000000}}],
    Polygon[{{0.753749, 1.266868, 0.001744},{0.753623, 1.267256, 0.003445},{
      0.756579, 1.268762, 0.003445},{0.756819, 1.268432, 0.001744}}],
    Polygon[{{0.753623, 1.267256, 0.003445},{0.753416, 1.267893, 0.005062},{
      0.756186, 1.269304, 0.005062},{0.756579, 1.268762, 0.003445}}],
    Polygon[{{0.753416, 1.267893, 0.005062},{0.753134, 1.268762, 0.006553},{
      0.755648, 1.270043, 0.006553},{0.756186, 1.269304, 0.005062}}],
    Polygon[{{0.753134, 1.268762, 0.006553},{0.752783, 1.269843, 0.007884},{
      0.754980, 1.270962, 0.007884},{0.755648, 1.270043, 0.006553}}],
    Polygon[{{0.752783, 1.269843, 0.007884},{0.752372, 1.271108, 0.009020},{
      0.754199, 1.272039, 0.009020},{0.754980, 1.270962, 0.007884}}],
    Polygon[{{0.752372, 1.271108, 0.009020},{0.751911, 1.272527, 0.009934},{
      0.753322, 1.273245, 0.009934},{0.754199, 1.272039, 0.009020}}],
    Polygon[{{0.751911, 1.272527, 0.009934},{0.751411, 1.274064, 0.010603},{
      0.752372, 1.274553, 0.010603},{0.753322, 1.273245, 0.009934}}],
    Polygon[{{0.751411, 1.274064, 0.010603},{0.750886, 1.275682, 0.011012},{
      0.751372, 1.275929, 0.011012},{0.752372, 1.274553, 0.010603}}],
    Polygon[{{0.751372, 1.275929, -0.011012},{0.752372, 1.274553, -0.010603},{
      0.753134, 1.275315, -0.010603},{0.751758, 1.276315, -0.011012}}],
    Polygon[{{0.752372, 1.274553, -0.010603},{0.753322, 1.273245, -0.009934},{
      0.754441, 1.274365, -0.009934},{0.753134, 1.275315, -0.010603}}],
    Polygon[{{0.753322, 1.273245, -0.009934},{0.754199, 1.272039, -0.009020},{
      0.755648, 1.273488, -0.009020},{0.754441, 1.274365, -0.009934}}],
    Polygon[{{0.754199, 1.272039, -0.009020},{0.754980, 1.270962, -0.007884},{
      0.756725, 1.272707, -0.007884},{0.755648, 1.273488, -0.009020}}],
    Polygon[{{0.754980, 1.270962, -0.007884},{0.755648, 1.270043, -0.006553},{
      0.757644, 1.272039, -0.006553},{0.756725, 1.272707, -0.007884}}],
    Polygon[{{0.755648, 1.270043, -0.006553},{0.756186, 1.269304, -0.005062},{
      0.758383, 1.271501, -0.005062},{0.757644, 1.272039, -0.006553}}],
    Polygon[{{0.756186, 1.269304, -0.005062},{0.756579, 1.268762, -0.003445},{
      0.758925, 1.271108, -0.003445},{0.758383, 1.271501, -0.005062}}],
    Polygon[{{0.756579, 1.268762, -0.003445},{0.756819, 1.268432, -0.001744},{
      0.759255, 1.270868, -0.001744},{0.758925, 1.271108, -0.003445}}],
    Polygon[{{0.756819, 1.268432, -0.001744},{0.756900, 1.268321, 0.000000},{
      0.759366, 1.270787, 0.000000},{0.759255, 1.270868, -0.001744}}],
    Polygon[{{0.756900, 1.268321, 0.000000},{0.756819, 1.268432, 0.001744},{
      0.759255, 1.270868, 0.001744},{0.759366, 1.270787, 0.000000}}],
    Polygon[{{0.756819, 1.268432, 0.001744},{0.756579, 1.268762, 0.003445},{
      0.758925, 1.271108, 0.003445},{0.759255, 1.270868, 0.001744}}],
    Polygon[{{0.756579, 1.268762, 0.003445},{0.756186, 1.269304, 0.005062},{
      0.758383, 1.271501, 0.005062},{0.758925, 1.271108, 0.003445}}],
    Polygon[{{0.756186, 1.269304, 0.005062},{0.755648, 1.270043, 0.006553},{
      0.757644, 1.272039, 0.006553},{0.758383, 1.271501, 0.005062}}],
    Polygon[{{0.755648, 1.270043, 0.006553},{0.754980, 1.270962, 0.007884},{
      0.756725, 1.272707, 0.007884},{0.757644, 1.272039, 0.006553}}],
    Polygon[{{0.754980, 1.270962, 0.007884},{0.754199, 1.272039, 0.009020},{
      0.755648, 1.273488, 0.009020},{0.756725, 1.272707, 0.007884}}],
    Polygon[{{0.754199, 1.272039, 0.009020},{0.753322, 1.273245, 0.009934},{
      0.754441, 1.274365, 0.009934},{0.755648, 1.273488, 0.009020}}],
    Polygon[{{0.753322, 1.273245, 0.009934},{0.752372, 1.274553, 0.010603},{
      0.753134, 1.275315, 0.010603},{0.754441, 1.274365, 0.009934}}],
    Polygon[{{0.752372, 1.274553, 0.010603},{0.751372, 1.275929, 0.011012},{
      0.751758, 1.276315, 0.011012},{0.753134, 1.275315, 0.010603}}],
    Polygon[{{0.751758, 1.276315, -0.011012},{0.753134, 1.275315, -0.010603},{
      0.753623, 1.276276, -0.010603},{0.752005, 1.276801, -0.011012}}],
    Polygon[{{0.753134, 1.275315, -0.010603},{0.754441, 1.274365, -0.009934},{
      0.755160, 1.275776, -0.009934},{0.753623, 1.276276, -0.010603}}],
    Polygon[{{0.754441, 1.274365, -0.009934},{0.755648, 1.273488, -0.009020},{
      0.756579, 1.275315, -0.009020},{0.755160, 1.275776, -0.009934}}],
    Polygon[{{0.755648, 1.273488, -0.009020},{0.756725, 1.272707, -0.007884},{
      0.757844, 1.274904, -0.007884},{0.756579, 1.275315, -0.009020}}],
    Polygon[{{0.756725, 1.272707, -0.007884},{0.757644, 1.272039, -0.006553},{
      0.758925, 1.274553, -0.006553},{0.757844, 1.274904, -0.007884}}],
    Polygon[{{0.757644, 1.272039, -0.006553},{0.758383, 1.271501, -0.005062},{
      0.759794, 1.274271, -0.005062},{0.758925, 1.274553, -0.006553}}],
    Polygon[{{0.758383, 1.271501, -0.005062},{0.758925, 1.271108, -0.003445},{
      0.760431, 1.274064, -0.003445},{0.759794, 1.274271, -0.005062}}],
    Polygon[{{0.758925, 1.271108, -0.003445},{0.759255, 1.270868, -0.001744},{
      0.760819, 1.273937, -0.001744},{0.760431, 1.274064, -0.003445}}],
    Polygon[{{0.759255, 1.270868, -0.001744},{0.759366, 1.270787, 0.000000},{
      0.760950, 1.273895, 0.000000},{0.760819, 1.273937, -0.001744}}],
    Polygon[{{0.759366, 1.270787, 0.000000},{0.759255, 1.270868, 0.001744},{
      0.760819, 1.273937, 0.001744},{0.760950, 1.273895, 0.000000}}],
    Polygon[{{0.759255, 1.270868, 0.001744},{0.758925, 1.271108, 0.003445},{
      0.760431, 1.274064, 0.003445},{0.760819, 1.273937, 0.001744}}],
    Polygon[{{0.758925, 1.271108, 0.003445},{0.758383, 1.271501, 0.005062},{
      0.759794, 1.274271, 0.005062},{0.760431, 1.274064, 0.003445}}],
    Polygon[{{0.758383, 1.271501, 0.005062},{0.757644, 1.272039, 0.006553},{
      0.758925, 1.274553, 0.006553},{0.759794, 1.274271, 0.005062}}],
    Polygon[{{0.757644, 1.272039, 0.006553},{0.756725, 1.272707, 0.007884},{
      0.757844, 1.274904, 0.007884},{0.758925, 1.274553, 0.006553}}],
    Polygon[{{0.756725, 1.272707, 0.007884},{0.755648, 1.273488, 0.009020},{
      0.756579, 1.275315, 0.009020},{0.757844, 1.274904, 0.007884}}],
    Polygon[{{0.755648, 1.273488, 0.009020},{0.754441, 1.274365, 0.009934},{
      0.755160, 1.275776, 0.009934},{0.756579, 1.275315, 0.009020}}],
    Polygon[{{0.754441, 1.274365, 0.009934},{0.753134, 1.275315, 0.010603},{
      0.753623, 1.276276, 0.010603},{0.755160, 1.275776, 0.009934}}],
    Polygon[{{0.753134, 1.275315, 0.010603},{0.751758, 1.276315, 0.011012},{
      0.752005, 1.276801, 0.011012},{0.753623, 1.276276, 0.010603}}],
    Polygon[{{0.752005, 1.276801, -0.011012},{0.753623, 1.276276, -0.010603},{
      0.753792, 1.277340, -0.010603},{0.752091, 1.277340, -0.011012}}],
    Polygon[{{0.753623, 1.276276, -0.010603},{0.755160, 1.275776, -0.009934},{
      0.755408, 1.277340, -0.009934},{0.753792, 1.277340, -0.010603}}],
    Polygon[{{0.755160, 1.275776, -0.009934},{0.756579, 1.275315, -0.009020},{
      0.756900, 1.277340, -0.009020},{0.755408, 1.277340, -0.009934}}],
    Polygon[{{0.756579, 1.275315, -0.009020},{0.757844, 1.274904, -0.007884},{
      0.758230, 1.277340, -0.007884},{0.756900, 1.277340, -0.009020}}],
    Polygon[{{0.757844, 1.274904, -0.007884},{0.758925, 1.274553, -0.006553},{
      0.759366, 1.277340, -0.006553},{0.758230, 1.277340, -0.007884}}],
    Polygon[{{0.758925, 1.274553, -0.006553},{0.759794, 1.274271, -0.005062},{
      0.760280, 1.277340, -0.005062},{0.759366, 1.277340, -0.006553}}],
    Polygon[{{0.759794, 1.274271, -0.005062},{0.760431, 1.274064, -0.003445},{
      0.760950, 1.277340, -0.003445},{0.760280, 1.277340, -0.005062}}],
    Polygon[{{0.760431, 1.274064, -0.003445},{0.760819, 1.273937, -0.001744},{
      0.761358, 1.277340, -0.001744},{0.760950, 1.277340, -0.003445}}],
    Polygon[{{0.760819, 1.273937, -0.001744},{0.760950, 1.273895, 0.000000},{
      0.761496, 1.277340, 0.000000},{0.761358, 1.277340, -0.001744}}],
    Polygon[{{0.760950, 1.273895, 0.000000},{0.760819, 1.273937, 0.001744},{
      0.761358, 1.277340, 0.001744},{0.761496, 1.277340, 0.000000}}],
    Polygon[{{0.760819, 1.273937, 0.001744},{0.760431, 1.274064, 0.003445},{
      0.760950, 1.277340, 0.003445},{0.761358, 1.277340, 0.001744}}],
    Polygon[{{0.760431, 1.274064, 0.003445},{0.759794, 1.274271, 0.005062},{
      0.760280, 1.277340, 0.005062},{0.760950, 1.277340, 0.003445}}],
    Polygon[{{0.759794, 1.274271, 0.005062},{0.758925, 1.274553, 0.006553},{
      0.759366, 1.277340, 0.006553},{0.760280, 1.277340, 0.005062}}],
    Polygon[{{0.758925, 1.274553, 0.006553},{0.757844, 1.274904, 0.007884},{
      0.758230, 1.277340, 0.007884},{0.759366, 1.277340, 0.006553}}],
    Polygon[{{0.757844, 1.274904, 0.007884},{0.756579, 1.275315, 0.009020},{
      0.756900, 1.277340, 0.009020},{0.758230, 1.277340, 0.007884}}],
    Polygon[{{0.756579, 1.275315, 0.009020},{0.755160, 1.275776, 0.009934},{
      0.755408, 1.277340, 0.009934},{0.756900, 1.277340, 0.009020}}],
    Polygon[{{0.755160, 1.275776, 0.009934},{0.753623, 1.276276, 0.010603},{
      0.753792, 1.277340, 0.010603},{0.755408, 1.277340, 0.009934}}],
    Polygon[{{0.753623, 1.276276, 0.010603},{0.752005, 1.276801, 0.011012},{
      0.752091, 1.277340, 0.011012},{0.753792, 1.277340, 0.010603}}],
    Polygon[{{0.813474, 1.273429, -0.009381},{0.814924, 1.273429, -0.009033},{
      0.814780, 1.274336, -0.009033},{0.813402, 1.273888, -0.009381}}],
    Polygon[{{0.814924, 1.273429, -0.009033},{0.816301, 1.273429, -0.008463},{
      0.816090, 1.274762, -0.008463},{0.814780, 1.274336, -0.009033}}],
    Polygon[{{0.816301, 1.273429, -0.008463},{0.817572, 1.273429, -0.007684},{
      0.817298, 1.275154, -0.007684},{0.816090, 1.274762, -0.008463}}],
    Polygon[{{0.817572, 1.273429, -0.007684},{0.818705, 1.273429, -0.006716},{
      0.818376, 1.275505, -0.006716},{0.817298, 1.275154, -0.007684}}],
    Polygon[{{0.818705, 1.273429, -0.006716},{0.819673, 1.273429, -0.005583},{
      0.819297, 1.275804, -0.005583},{0.818376, 1.275505, -0.006716}}],
    Polygon[{{0.819673, 1.273429, -0.005583},{0.820452, 1.273429, -0.004312},{
      0.820037, 1.276044, -0.004312},{0.819297, 1.275804, -0.005583}}],
    Polygon[{{0.820452, 1.273429, -0.004312},{0.821022, 1.273429, -0.002935},{
      0.820580, 1.276221, -0.002935},{0.820037, 1.276044, -0.004312}}],
    Polygon[{{0.821022, 1.273429, -0.002935},{0.821370, 1.273429, -0.001486},{
      0.820911, 1.276328, -0.001486},{0.820580, 1.276221, -0.002935}}],
    Polygon[{{0.821370, 1.273429, -0.001486},{0.821487, 1.273429, 0.000000},{
      0.821022, 1.276364, 0.000000},{0.820911, 1.276328, -0.001486}}],
    Polygon[{{0.821487, 1.273429, 0.000000},{0.821370, 1.273429, 0.001486},{
      0.820911, 1.276328, 0.001486},{0.821022, 1.276364, 0.000000}}],
    Polygon[{{0.821370, 1.273429, 0.001486},{0.821022, 1.273429, 0.002935},{
      0.820580, 1.276221, 0.002935},{0.820911, 1.276328, 0.001486}}],
    Polygon[{{0.821022, 1.273429, 0.002935},{0.820452, 1.273429, 0.004312},{
      0.820037, 1.276044, 0.004312},{0.820580, 1.276221, 0.002935}}],
    Polygon[{{0.820452, 1.273429, 0.004312},{0.819673, 1.273429, 0.005583},{
      0.819297, 1.275804, 0.005583},{0.820037, 1.276044, 0.004312}}],
    Polygon[{{0.819673, 1.273429, 0.005583},{0.818705, 1.273429, 0.006716},{
      0.818376, 1.275505, 0.006716},{0.819297, 1.275804, 0.005583}}],
    Polygon[{{0.818705, 1.273429, 0.006716},{0.817572, 1.273429, 0.007684},{
      0.817298, 1.275154, 0.007684},{0.818376, 1.275505, 0.006716}}],
    Polygon[{{0.817572, 1.273429, 0.007684},{0.816301, 1.273429, 0.008463},{
      0.816090, 1.274762, 0.008463},{0.817298, 1.275154, 0.007684}}],
    Polygon[{{0.816301, 1.273429, 0.008463},{0.814924, 1.273429, 0.009033},{
      0.814780, 1.274336, 0.009033},{0.816090, 1.274762, 0.008463}}],
    Polygon[{{0.814924, 1.273429, 0.009033},{0.813474, 1.273429, 0.009381},{
      0.813402, 1.273888, 0.009381},{0.814780, 1.274336, 0.009033}}],
    Polygon[{{0.813402, 1.273888, -0.009381},{0.814780, 1.274336, -0.009033},{
      0.814363, 1.275154, -0.009033},{0.813191, 1.274303, -0.009381}}],
    Polygon[{{0.814780, 1.274336, -0.009033},{0.816090, 1.274762, -0.008463},{
      0.815477, 1.275964, -0.008463},{0.814363, 1.275154, -0.009033}}],
    Polygon[{{0.816090, 1.274762, -0.008463},{0.817298, 1.275154, -0.007684},{
      0.816505, 1.276711, -0.007684},{0.815477, 1.275964, -0.008463}}],
    Polygon[{{0.817298, 1.275154, -0.007684},{0.818376, 1.275505, -0.006716},{
      0.817422, 1.277377, -0.006716},{0.816505, 1.276711, -0.007684}}],
    Polygon[{{0.818376, 1.275505, -0.006716},{0.819297, 1.275804, -0.005583},{
      0.818205, 1.277946, -0.005583},{0.817422, 1.277377, -0.006716}}],
    Polygon[{{0.819297, 1.275804, -0.005583},{0.820037, 1.276044, -0.004312},{
      0.818835, 1.278404, -0.004312},{0.818205, 1.277946, -0.005583}}],
    Polygon[{{0.820037, 1.276044, -0.004312},{0.820580, 1.276221, -0.002935},{
      0.819297, 1.278739, -0.002935},{0.818835, 1.278404, -0.004312}}],
    Polygon[{{0.820580, 1.276221, -0.002935},{0.820911, 1.276328, -0.001486},{
      0.819578, 1.278943, -0.001486},{0.819297, 1.278739, -0.002935}}],
    Polygon[{{0.820911, 1.276328, -0.001486},{0.821022, 1.276364, 0.000000},{
      0.819673, 1.279012, 0.000000},{0.819578, 1.278943, -0.001486}}],
    Polygon[{{0.821022, 1.276364, 0.000000},{0.820911, 1.276328, 0.001486},{
      0.819578, 1.278943, 0.001486},{0.819673, 1.279012, 0.000000}}],
    Polygon[{{0.820911, 1.276328, 0.001486},{0.820580, 1.276221, 0.002935},{
      0.819297, 1.278739, 0.002935},{0.819578, 1.278943, 0.001486}}],
    Polygon[{{0.820580, 1.276221, 0.002935},{0.820037, 1.276044, 0.004312},{
      0.818835, 1.278404, 0.004312},{0.819297, 1.278739, 0.002935}}],
    Polygon[{{0.820037, 1.276044, 0.004312},{0.819297, 1.275804, 0.005583},{
      0.818205, 1.277946, 0.005583},{0.818835, 1.278404, 0.004312}}],
    Polygon[{{0.819297, 1.275804, 0.005583},{0.818376, 1.275505, 0.006716},{
      0.817422, 1.277377, 0.006716},{0.818205, 1.277946, 0.005583}}],
    Polygon[{{0.818376, 1.275505, 0.006716},{0.817298, 1.275154, 0.007684},{
      0.816505, 1.276711, 0.007684},{0.817422, 1.277377, 0.006716}}],
    Polygon[{{0.817298, 1.275154, 0.007684},{0.816090, 1.274762, 0.008463},{
      0.815477, 1.275964, 0.008463},{0.816505, 1.276711, 0.007684}}],
    Polygon[{{0.816090, 1.274762, 0.008463},{0.814780, 1.274336, 0.009033},{
      0.814363, 1.275154, 0.009033},{0.815477, 1.275964, 0.008463}}],
    Polygon[{{0.814780, 1.274336, 0.009033},{0.813402, 1.273888, 0.009381},{
      0.813191, 1.274303, 0.009381},{0.814363, 1.275154, 0.009033}}],
    Polygon[{{0.813191, 1.274303, -0.009381},{0.814363, 1.275154, -0.009033},{
      0.813714, 1.275804, -0.009033},{0.812862, 1.274631, -0.009381}}],
    Polygon[{{0.814363, 1.275154, -0.009033},{0.815477, 1.275964, -0.008463},{
      0.814523, 1.276918, -0.008463},{0.813714, 1.275804, -0.009033}}],
    Polygon[{{0.815477, 1.275964, -0.008463},{0.816505, 1.276711, -0.007684},{
      0.815270, 1.277946, -0.007684},{0.814523, 1.276918, -0.008463}}],
    Polygon[{{0.816505, 1.276711, -0.007684},{0.817422, 1.277377, -0.006716},{
      0.815936, 1.278863, -0.006716},{0.815270, 1.277946, -0.007684}}],
    Polygon[{{0.817422, 1.277377, -0.006716},{0.818205, 1.277946, -0.005583},{
      0.816505, 1.279646, -0.005583},{0.815936, 1.278863, -0.006716}}],
    Polygon[{{0.818205, 1.277946, -0.005583},{0.818835, 1.278404, -0.004312},{
      0.816963, 1.280276, -0.004312},{0.816505, 1.279646, -0.005583}}],
    Polygon[{{0.818835, 1.278404, -0.004312},{0.819297, 1.278739, -0.002935},{
      0.817298, 1.280737, -0.002935},{0.816963, 1.280276, -0.004312}}],
    Polygon[{{0.819297, 1.278739, -0.002935},{0.819578, 1.278943, -0.001486},{
      0.817503, 1.281019, -0.001486},{0.817298, 1.280737, -0.002935}}],
    Polygon[{{0.819578, 1.278943, -0.001486},{0.819673, 1.279012, 0.000000},{
      0.817572, 1.281114, 0.000000},{0.817503, 1.281019, -0.001486}}],
    Polygon[{{0.819673, 1.279012, 0.000000},{0.819578, 1.278943, 0.001486},{
      0.817503, 1.281019, 0.001486},{0.817572, 1.281114, 0.000000}}],
    Polygon[{{0.819578, 1.278943, 0.001486},{0.819297, 1.278739, 0.002935},{
      0.817298, 1.280737, 0.002935},{0.817503, 1.281019, 0.001486}}],
    Polygon[{{0.819297, 1.278739, 0.002935},{0.818835, 1.278404, 0.004312},{
      0.816963, 1.280276, 0.004312},{0.817298, 1.280737, 0.002935}}],
    Polygon[{{0.818835, 1.278404, 0.004312},{0.818205, 1.277946, 0.005583},{
      0.816505, 1.279646, 0.005583},{0.816963, 1.280276, 0.004312}}],
    Polygon[{{0.818205, 1.277946, 0.005583},{0.817422, 1.277377, 0.006716},{
      0.815936, 1.278863, 0.006716},{0.816505, 1.279646, 0.005583}}],
    Polygon[{{0.817422, 1.277377, 0.006716},{0.816505, 1.276711, 0.007684},{
      0.815270, 1.277946, 0.007684},{0.815936, 1.278863, 0.006716}}],
    Polygon[{{0.816505, 1.276711, 0.007684},{0.815477, 1.275964, 0.008463},{
      0.814523, 1.276918, 0.008463},{0.815270, 1.277946, 0.007684}}],
    Polygon[{{0.815477, 1.275964, 0.008463},{0.814363, 1.275154, 0.009033},{
      0.813714, 1.275804, 0.009033},{0.814523, 1.276918, 0.008463}}],
    Polygon[{{0.814363, 1.275154, 0.009033},{0.813191, 1.274303, 0.009381},{
      0.812862, 1.274631, 0.009381},{0.813714, 1.275804, 0.009033}}],
    Polygon[{{0.812862, 1.274631, -0.009381},{0.813714, 1.275804, -0.009033},{
      0.812896, 1.276221, -0.009033},{0.812448, 1.274842, -0.009381}}],
    Polygon[{{0.813714, 1.275804, -0.009033},{0.814523, 1.276918, -0.008463},{
      0.813321, 1.277530, -0.008463},{0.812896, 1.276221, -0.009033}}],
    Polygon[{{0.814523, 1.276918, -0.008463},{0.815270, 1.277946, -0.007684},{
      0.813714, 1.278739, -0.007684},{0.813321, 1.277530, -0.008463}}],
    Polygon[{{0.815270, 1.277946, -0.007684},{0.815936, 1.278863, -0.006716},{
      0.814064, 1.279817, -0.006716},{0.813714, 1.278739, -0.007684}}],
    Polygon[{{0.815936, 1.278863, -0.006716},{0.816505, 1.279646, -0.005583},{
      0.814363, 1.280737, -0.005583},{0.814064, 1.279817, -0.006716}}],
    Polygon[{{0.816505, 1.279646, -0.005583},{0.816963, 1.280276, -0.004312},{
      0.814604, 1.281478, -0.004312},{0.814363, 1.280737, -0.005583}}],
    Polygon[{{0.816963, 1.280276, -0.004312},{0.817298, 1.280737, -0.002935},{
      0.814780, 1.282021, -0.002935},{0.814604, 1.281478, -0.004312}}],
    Polygon[{{0.817298, 1.280737, -0.002935},{0.817503, 1.281019, -0.001486},{
      0.814888, 1.282351, -0.001486},{0.814780, 1.282021, -0.002935}}],
    Polygon[{{0.817503, 1.281019, -0.001486},{0.817572, 1.281114, 0.000000},{
      0.814924, 1.282463, 0.000000},{0.814888, 1.282351, -0.001486}}],
    Polygon[{{0.817572, 1.281114, 0.000000},{0.817503, 1.281019, 0.001486},{
      0.814888, 1.282351, 0.001486},{0.814924, 1.282463, 0.000000}}],
    Polygon[{{0.817503, 1.281019, 0.001486},{0.817298, 1.280737, 0.002935},{
      0.814780, 1.282021, 0.002935},{0.814888, 1.282351, 0.001486}}],
    Polygon[{{0.817298, 1.280737, 0.002935},{0.816963, 1.280276, 0.004312},{
      0.814604, 1.281478, 0.004312},{0.814780, 1.282021, 0.002935}}],
    Polygon[{{0.816963, 1.280276, 0.004312},{0.816505, 1.279646, 0.005583},{
      0.814363, 1.280737, 0.005583},{0.814604, 1.281478, 0.004312}}],
    Polygon[{{0.816505, 1.279646, 0.005583},{0.815936, 1.278863, 0.006716},{
      0.814064, 1.279817, 0.006716},{0.814363, 1.280737, 0.005583}}],
    Polygon[{{0.815936, 1.278863, 0.006716},{0.815270, 1.277946, 0.007684},{
      0.813714, 1.278739, 0.007684},{0.814064, 1.279817, 0.006716}}],
    Polygon[{{0.815270, 1.277946, 0.007684},{0.814523, 1.276918, 0.008463},{
      0.813321, 1.277530, 0.008463},{0.813714, 1.278739, 0.007684}}],
    Polygon[{{0.814523, 1.276918, 0.008463},{0.813714, 1.275804, 0.009033},{
      0.812896, 1.276221, 0.009033},{0.813321, 1.277530, 0.008463}}],
    Polygon[{{0.813714, 1.275804, 0.009033},{0.812862, 1.274631, 0.009381},{
      0.812448, 1.274842, 0.009381},{0.812896, 1.276221, 0.009033}}],
    Polygon[{{0.812448, 1.274842, -0.009381},{0.812896, 1.276221, -0.009033},{
      0.811989, 1.276364, -0.009033},{0.811989, 1.274915, -0.009381}}],
    Polygon[{{0.812896, 1.276221, -0.009033},{0.813321, 1.277530, -0.008463},{
      0.811989, 1.277741, -0.008463},{0.811989, 1.276364, -0.009033}}],
    Polygon[{{0.813321, 1.277530, -0.008463},{0.813714, 1.278739, -0.007684},{
      0.811989, 1.279012, -0.007684},{0.811989, 1.277741, -0.008463}}],
    Polygon[{{0.813714, 1.278739, -0.007684},{0.814064, 1.279817, -0.006716},{
      0.811989, 1.280146, -0.006716},{0.811989, 1.279012, -0.007684}}],
    Polygon[{{0.814064, 1.279817, -0.006716},{0.814363, 1.280737, -0.005583},{
      0.811989, 1.281114, -0.005583},{0.811989, 1.280146, -0.006716}}],
    Polygon[{{0.814363, 1.280737, -0.005583},{0.814604, 1.281478, -0.004312},{
      0.811989, 1.281892, -0.004312},{0.811989, 1.281114, -0.005583}}],
    Polygon[{{0.814604, 1.281478, -0.004312},{0.814780, 1.282021, -0.002935},{
      0.811989, 1.282463, -0.002935},{0.811989, 1.281892, -0.004312}}],
    Polygon[{{0.814780, 1.282021, -0.002935},{0.814888, 1.282351, -0.001486},{
      0.811989, 1.282811, -0.001486},{0.811989, 1.282463, -0.002935}}],
    Polygon[{{0.814888, 1.282351, -0.001486},{0.814924, 1.282463, 0.000000},{
      0.811989, 1.282928, 0.000000},{0.811989, 1.282811, -0.001486}}],
    Polygon[{{0.814924, 1.282463, 0.000000},{0.814888, 1.282351, 0.001486},{
      0.811989, 1.282811, 0.001486},{0.811989, 1.282928, 0.000000}}],
    Polygon[{{0.814888, 1.282351, 0.001486},{0.814780, 1.282021, 0.002935},{
      0.811989, 1.282463, 0.002935},{0.811989, 1.282811, 0.001486}}],
    Polygon[{{0.814780, 1.282021, 0.002935},{0.814604, 1.281478, 0.004312},{
      0.811989, 1.281892, 0.004312},{0.811989, 1.282463, 0.002935}}],
    Polygon[{{0.814604, 1.281478, 0.004312},{0.814363, 1.280737, 0.005583},{
      0.811989, 1.281114, 0.005583},{0.811989, 1.281892, 0.004312}}],
    Polygon[{{0.814363, 1.280737, 0.005583},{0.814064, 1.279817, 0.006716},{
      0.811989, 1.280146, 0.006716},{0.811989, 1.281114, 0.005583}}],
    Polygon[{{0.814064, 1.279817, 0.006716},{0.813714, 1.278739, 0.007684},{
      0.811989, 1.279012, 0.007684},{0.811989, 1.280146, 0.006716}}],
    Polygon[{{0.813714, 1.278739, 0.007684},{0.813321, 1.277530, 0.008463},{
      0.811989, 1.277741, 0.008463},{0.811989, 1.279012, 0.007684}}],
    Polygon[{{0.813321, 1.277530, 0.008463},{0.812896, 1.276221, 0.009033},{
      0.811989, 1.276364, 0.009033},{0.811989, 1.277741, 0.008463}}],
    Polygon[{{0.812896, 1.276221, 0.009033},{0.812448, 1.274842, 0.009381},{
      0.811989, 1.274915, 0.009381},{0.811989, 1.276364, 0.009033}}],
    Polygon[{{0.811989, 1.274915, -0.009381},{0.811989, 1.276364, -0.009033},{
      0.811082, 1.276221, -0.009033},{0.811529, 1.274842, -0.009381}}],
    Polygon[{{0.811989, 1.276364, -0.009033},{0.811989, 1.277741, -0.008463},{
      0.810656, 1.277530, -0.008463},{0.811082, 1.276221, -0.009033}}],
    Polygon[{{0.811989, 1.277741, -0.008463},{0.811989, 1.279012, -0.007684},{
      0.810263, 1.278739, -0.007684},{0.810656, 1.277530, -0.008463}}],
    Polygon[{{0.811989, 1.279012, -0.007684},{0.811989, 1.280146, -0.006716},{
      0.809913, 1.279817, -0.006716},{0.810263, 1.278739, -0.007684}}],
    Polygon[{{0.811989, 1.280146, -0.006716},{0.811989, 1.281114, -0.005583},{
      0.809614, 1.280737, -0.005583},{0.809913, 1.279817, -0.006716}}],
    Polygon[{{0.811989, 1.281114, -0.005583},{0.811989, 1.281892, -0.004312},{
      0.809373, 1.281478, -0.004312},{0.809614, 1.280737, -0.005583}}],
    Polygon[{{0.811989, 1.281892, -0.004312},{0.811989, 1.282463, -0.002935},{
      0.809197, 1.282021, -0.002935},{0.809373, 1.281478, -0.004312}}],
    Polygon[{{0.811989, 1.282463, -0.002935},{0.811989, 1.282811, -0.001486},{
      0.809090, 1.282351, -0.001486},{0.809197, 1.282021, -0.002935}}],
    Polygon[{{0.811989, 1.282811, -0.001486},{0.811989, 1.282928, 0.000000},{
      0.809053, 1.282463, 0.000000},{0.809090, 1.282351, -0.001486}}],
    Polygon[{{0.811989, 1.282928, 0.000000},{0.811989, 1.282811, 0.001486},{
      0.809090, 1.282351, 0.001486},{0.809053, 1.282463, 0.000000}}],
    Polygon[{{0.811989, 1.282811, 0.001486},{0.811989, 1.282463, 0.002935},{
      0.809197, 1.282021, 0.002935},{0.809090, 1.282351, 0.001486}}],
    Polygon[{{0.811989, 1.282463, 0.002935},{0.811989, 1.281892, 0.004312},{
      0.809373, 1.281478, 0.004312},{0.809197, 1.282021, 0.002935}}],
    Polygon[{{0.811989, 1.281892, 0.004312},{0.811989, 1.281114, 0.005583},{
      0.809614, 1.280737, 0.005583},{0.809373, 1.281478, 0.004312}}],
    Polygon[{{0.811989, 1.281114, 0.005583},{0.811989, 1.280146, 0.006716},{
      0.809913, 1.279817, 0.006716},{0.809614, 1.280737, 0.005583}}],
    Polygon[{{0.811989, 1.280146, 0.006716},{0.811989, 1.279012, 0.007684},{
      0.810263, 1.278739, 0.007684},{0.809913, 1.279817, 0.006716}}],
    Polygon[{{0.811989, 1.279012, 0.007684},{0.811989, 1.277741, 0.008463},{
      0.810656, 1.277530, 0.008463},{0.810263, 1.278739, 0.007684}}],
    Polygon[{{0.811989, 1.277741, 0.008463},{0.811989, 1.276364, 0.009033},{
      0.811082, 1.276221, 0.009033},{0.810656, 1.277530, 0.008463}}],
    Polygon[{{0.811989, 1.276364, 0.009033},{0.811989, 1.274915, 0.009381},{
      0.811529, 1.274842, 0.009381},{0.811082, 1.276221, 0.009033}}],
    Polygon[{{0.811529, 1.274842, -0.009381},{0.811082, 1.276221, -0.009033},{
      0.810263, 1.275804, -0.009033},{0.811115, 1.274631, -0.009381}}],
    Polygon[{{0.811082, 1.276221, -0.009033},{0.810656, 1.277530, -0.008463},{
      0.809454, 1.276918, -0.008463},{0.810263, 1.275804, -0.009033}}],
    Polygon[{{0.810656, 1.277530, -0.008463},{0.810263, 1.278739, -0.007684},{
      0.808707, 1.277946, -0.007684},{0.809454, 1.276918, -0.008463}}],
    Polygon[{{0.810263, 1.278739, -0.007684},{0.809913, 1.279817, -0.006716},{
      0.808041, 1.278863, -0.006716},{0.808707, 1.277946, -0.007684}}],
    Polygon[{{0.809913, 1.279817, -0.006716},{0.809614, 1.280737, -0.005583},{
      0.807472, 1.279646, -0.005583},{0.808041, 1.278863, -0.006716}}],
    Polygon[{{0.809614, 1.280737, -0.005583},{0.809373, 1.281478, -0.004312},{
      0.807014, 1.280276, -0.004312},{0.807472, 1.279646, -0.005583}}],
    Polygon[{{0.809373, 1.281478, -0.004312},{0.809197, 1.282021, -0.002935},{
      0.806679, 1.280737, -0.002935},{0.807014, 1.280276, -0.004312}}],
    Polygon[{{0.809197, 1.282021, -0.002935},{0.809090, 1.282351, -0.001486},{
      0.806474, 1.281019, -0.001486},{0.806679, 1.280737, -0.002935}}],
    Polygon[{{0.809090, 1.282351, -0.001486},{0.809053, 1.282463, 0.000000},{
      0.806406, 1.281114, 0.000000},{0.806474, 1.281019, -0.001486}}],
    Polygon[{{0.809053, 1.282463, 0.000000},{0.809090, 1.282351, 0.001486},{
      0.806474, 1.281019, 0.001486},{0.806406, 1.281114, 0.000000}}],
    Polygon[{{0.809090, 1.282351, 0.001486},{0.809197, 1.282021, 0.002935},{
      0.806679, 1.280737, 0.002935},{0.806474, 1.281019, 0.001486}}],
    Polygon[{{0.809197, 1.282021, 0.002935},{0.809373, 1.281478, 0.004312},{
      0.807014, 1.280276, 0.004312},{0.806679, 1.280737, 0.002935}}],
    Polygon[{{0.809373, 1.281478, 0.004312},{0.809614, 1.280737, 0.005583},{
      0.807472, 1.279646, 0.005583},{0.807014, 1.280276, 0.004312}}],
    Polygon[{{0.809614, 1.280737, 0.005583},{0.809913, 1.279817, 0.006716},{
      0.808041, 1.278863, 0.006716},{0.807472, 1.279646, 0.005583}}],
    Polygon[{{0.809913, 1.279817, 0.006716},{0.810263, 1.278739, 0.007684},{
      0.808707, 1.277946, 0.007684},{0.808041, 1.278863, 0.006716}}],
    Polygon[{{0.810263, 1.278739, 0.007684},{0.810656, 1.277530, 0.008463},{
      0.809454, 1.276918, 0.008463},{0.808707, 1.277946, 0.007684}}],
    Polygon[{{0.810656, 1.277530, 0.008463},{0.811082, 1.276221, 0.009033},{
      0.810263, 1.275804, 0.009033},{0.809454, 1.276918, 0.008463}}],
    Polygon[{{0.811082, 1.276221, 0.009033},{0.811529, 1.274842, 0.009381},{
      0.811115, 1.274631, 0.009381},{0.810263, 1.275804, 0.009033}}],
    Polygon[{{0.811115, 1.274631, -0.009381},{0.810263, 1.275804, -0.009033},{
      0.809614, 1.275154, -0.009033},{0.810786, 1.274303, -0.009381}}],
    Polygon[{{0.810263, 1.275804, -0.009033},{0.809454, 1.276918, -0.008463},{
      0.808500, 1.275964, -0.008463},{0.809614, 1.275154, -0.009033}}],
    Polygon[{{0.809454, 1.276918, -0.008463},{0.808707, 1.277946, -0.007684},{
      0.807472, 1.276711, -0.007684},{0.808500, 1.275964, -0.008463}}],
    Polygon[{{0.808707, 1.277946, -0.007684},{0.808041, 1.278863, -0.006716},{
      0.806555, 1.277377, -0.006716},{0.807472, 1.276711, -0.007684}}],
    Polygon[{{0.808041, 1.278863, -0.006716},{0.807472, 1.279646, -0.005583},{
      0.805772, 1.277946, -0.005583},{0.806555, 1.277377, -0.006716}}],
    Polygon[{{0.807472, 1.279646, -0.005583},{0.807014, 1.280276, -0.004312},{
      0.805142, 1.278404, -0.004312},{0.805772, 1.277946, -0.005583}}],
    Polygon[{{0.807014, 1.280276, -0.004312},{0.806679, 1.280737, -0.002935},{
      0.804680, 1.278739, -0.002935},{0.805142, 1.278404, -0.004312}}],
    Polygon[{{0.806679, 1.280737, -0.002935},{0.806474, 1.281019, -0.001486},{
      0.804399, 1.278943, -0.001486},{0.804680, 1.278739, -0.002935}}],
    Polygon[{{0.806474, 1.281019, -0.001486},{0.806406, 1.281114, 0.000000},{
      0.804304, 1.279012, 0.000000},{0.804399, 1.278943, -0.001486}}],
    Polygon[{{0.806406, 1.281114, 0.000000},{0.806474, 1.281019, 0.001486},{
      0.804399, 1.278943, 0.001486},{0.804304, 1.279012, 0.000000}}],
    Polygon[{{0.806474, 1.281019, 0.001486},{0.806679, 1.280737, 0.002935},{
      0.804680, 1.278739, 0.002935},{0.804399, 1.278943, 0.001486}}],
    Polygon[{{0.806679, 1.280737, 0.002935},{0.807014, 1.280276, 0.004312},{
      0.805142, 1.278404, 0.004312},{0.804680, 1.278739, 0.002935}}],
    Polygon[{{0.807014, 1.280276, 0.004312},{0.807472, 1.279646, 0.005583},{
      0.805772, 1.277946, 0.005583},{0.805142, 1.278404, 0.004312}}],
    Polygon[{{0.807472, 1.279646, 0.005583},{0.808041, 1.278863, 0.006716},{
      0.806555, 1.277377, 0.006716},{0.805772, 1.277946, 0.005583}}],
    Polygon[{{0.808041, 1.278863, 0.006716},{0.808707, 1.277946, 0.007684},{
      0.807472, 1.276711, 0.007684},{0.806555, 1.277377, 0.006716}}],
    Polygon[{{0.808707, 1.277946, 0.007684},{0.809454, 1.276918, 0.008463},{
      0.808500, 1.275964, 0.008463},{0.807472, 1.276711, 0.007684}}],
    Polygon[{{0.809454, 1.276918, 0.008463},{0.810263, 1.275804, 0.009033},{
      0.809614, 1.275154, 0.009033},{0.808500, 1.275964, 0.008463}}],
    Polygon[{{0.810263, 1.275804, 0.009033},{0.811115, 1.274631, 0.009381},{
      0.810786, 1.274303, 0.009381},{0.809614, 1.275154, 0.009033}}],
    Polygon[{{0.810786, 1.274303, -0.009381},{0.809614, 1.275154, -0.009033},{
      0.809197, 1.274336, -0.009033},{0.810575, 1.273888, -0.009381}}],
    Polygon[{{0.809614, 1.275154, -0.009033},{0.808500, 1.275964, -0.008463},{
      0.807887, 1.274762, -0.008463},{0.809197, 1.274336, -0.009033}}],
    Polygon[{{0.808500, 1.275964, -0.008463},{0.807472, 1.276711, -0.007684},{
      0.806679, 1.275154, -0.007684},{0.807887, 1.274762, -0.008463}}],
    Polygon[{{0.807472, 1.276711, -0.007684},{0.806555, 1.277377, -0.006716},{
      0.805601, 1.275505, -0.006716},{0.806679, 1.275154, -0.007684}}],
    Polygon[{{0.806555, 1.277377, -0.006716},{0.805772, 1.277946, -0.005583},{
      0.804680, 1.275804, -0.005583},{0.805601, 1.275505, -0.006716}}],
    Polygon[{{0.805772, 1.277946, -0.005583},{0.805142, 1.278404, -0.004312},{
      0.803940, 1.276044, -0.004312},{0.804680, 1.275804, -0.005583}}],
    Polygon[{{0.805142, 1.278404, -0.004312},{0.804680, 1.278739, -0.002935},{
      0.803397, 1.276221, -0.002935},{0.803940, 1.276044, -0.004312}}],
    Polygon[{{0.804680, 1.278739, -0.002935},{0.804399, 1.278943, -0.001486},{
      0.803066, 1.276328, -0.001486},{0.803397, 1.276221, -0.002935}}],
    Polygon[{{0.804399, 1.278943, -0.001486},{0.804304, 1.279012, 0.000000},{
      0.802955, 1.276364, 0.000000},{0.803066, 1.276328, -0.001486}}],
    Polygon[{{0.804304, 1.279012, 0.000000},{0.804399, 1.278943, 0.001486},{
      0.803066, 1.276328, 0.001486},{0.802955, 1.276364, 0.000000}}],
    Polygon[{{0.804399, 1.278943, 0.001486},{0.804680, 1.278739, 0.002935},{
      0.803397, 1.276221, 0.002935},{0.803066, 1.276328, 0.001486}}],
    Polygon[{{0.804680, 1.278739, 0.002935},{0.805142, 1.278404, 0.004312},{
      0.803940, 1.276044, 0.004312},{0.803397, 1.276221, 0.002935}}],
    Polygon[{{0.805142, 1.278404, 0.004312},{0.805772, 1.277946, 0.005583},{
      0.804680, 1.275804, 0.005583},{0.803940, 1.276044, 0.004312}}],
    Polygon[{{0.805772, 1.277946, 0.005583},{0.806555, 1.277377, 0.006716},{
      0.805601, 1.275505, 0.006716},{0.804680, 1.275804, 0.005583}}],
    Polygon[{{0.806555, 1.277377, 0.006716},{0.807472, 1.276711, 0.007684},{
      0.806679, 1.275154, 0.007684},{0.805601, 1.275505, 0.006716}}],
    Polygon[{{0.807472, 1.276711, 0.007684},{0.808500, 1.275964, 0.008463},{
      0.807887, 1.274762, 0.008463},{0.806679, 1.275154, 0.007684}}],
    Polygon[{{0.808500, 1.275964, 0.008463},{0.809614, 1.275154, 0.009033},{
      0.809197, 1.274336, 0.009033},{0.807887, 1.274762, 0.008463}}],
    Polygon[{{0.809614, 1.275154, 0.009033},{0.810786, 1.274303, 0.009381},{
      0.810575, 1.273888, 0.009381},{0.809197, 1.274336, 0.009033}}],
    Polygon[{{0.810575, 1.273888, -0.009381},{0.809197, 1.274336, -0.009033},{
      0.809053, 1.273429, -0.009033},{0.810503, 1.273429, -0.009381}}],
    Polygon[{{0.809197, 1.274336, -0.009033},{0.807887, 1.274762, -0.008463},{
      0.807676, 1.273429, -0.008463},{0.809053, 1.273429, -0.009033}}],
    Polygon[{{0.807887, 1.274762, -0.008463},{0.806679, 1.275154, -0.007684},{
      0.806406, 1.273429, -0.007684},{0.807676, 1.273429, -0.008463}}],
    Polygon[{{0.806679, 1.275154, -0.007684},{0.805601, 1.275505, -0.006716},{
      0.805272, 1.273429, -0.006716},{0.806406, 1.273429, -0.007684}}],
    Polygon[{{0.805601, 1.275505, -0.006716},{0.804680, 1.275804, -0.005583},{
      0.804304, 1.273429, -0.005583},{0.805272, 1.273429, -0.006716}}],
    Polygon[{{0.804680, 1.275804, -0.005583},{0.803940, 1.276044, -0.004312},{
      0.803526, 1.273429, -0.004312},{0.804304, 1.273429, -0.005583}}],
    Polygon[{{0.803940, 1.276044, -0.004312},{0.803397, 1.276221, -0.002935},{
      0.802955, 1.273429, -0.002935},{0.803526, 1.273429, -0.004312}}],
    Polygon[{{0.803397, 1.276221, -0.002935},{0.803066, 1.276328, -0.001486},{
      0.802607, 1.273429, -0.001486},{0.802955, 1.273429, -0.002935}}],
    Polygon[{{0.803066, 1.276328, -0.001486},{0.802955, 1.276364, 0.000000},{
      0.802490, 1.273429, 0.000000},{0.802607, 1.273429, -0.001486}}],
    Polygon[{{0.802955, 1.276364, 0.000000},{0.803066, 1.276328, 0.001486},{
      0.802607, 1.273429, 0.001486},{0.802490, 1.273429, 0.000000}}],
    Polygon[{{0.803066, 1.276328, 0.001486},{0.803397, 1.276221, 0.002935},{
      0.802955, 1.273429, 0.002935},{0.802607, 1.273429, 0.001486}}],
    Polygon[{{0.803397, 1.276221, 0.002935},{0.803940, 1.276044, 0.004312},{
      0.803526, 1.273429, 0.004312},{0.802955, 1.273429, 0.002935}}],
    Polygon[{{0.803940, 1.276044, 0.004312},{0.804680, 1.275804, 0.005583},{
      0.804304, 1.273429, 0.005583},{0.803526, 1.273429, 0.004312}}],
    Polygon[{{0.804680, 1.275804, 0.005583},{0.805601, 1.275505, 0.006716},{
      0.805272, 1.273429, 0.006716},{0.804304, 1.273429, 0.005583}}],
    Polygon[{{0.805601, 1.275505, 0.006716},{0.806679, 1.275154, 0.007684},{
      0.806406, 1.273429, 0.007684},{0.805272, 1.273429, 0.006716}}],
    Polygon[{{0.806679, 1.275154, 0.007684},{0.807887, 1.274762, 0.008463},{
      0.807676, 1.273429, 0.008463},{0.806406, 1.273429, 0.007684}}],
    Polygon[{{0.807887, 1.274762, 0.008463},{0.809197, 1.274336, 0.009033},{
      0.809053, 1.273429, 0.009033},{0.807676, 1.273429, 0.008463}}],
    Polygon[{{0.809197, 1.274336, 0.009033},{0.810575, 1.273888, 0.009381},{
      0.810503, 1.273429, 0.009381},{0.809053, 1.273429, 0.009033}}],
    Polygon[{{0.810503, 1.273429, -0.009381},{0.809053, 1.273429, -0.009033},{
      0.809197, 1.272522, -0.009033},{0.810575, 1.272970, -0.009381}}],
    Polygon[{{0.809053, 1.273429, -0.009033},{0.807676, 1.273429, -0.008463},{
      0.807887, 1.272097, -0.008463},{0.809197, 1.272522, -0.009033}}],
    Polygon[{{0.807676, 1.273429, -0.008463},{0.806406, 1.273429, -0.007684},{
      0.806679, 1.271704, -0.007684},{0.807887, 1.272097, -0.008463}}],
    Polygon[{{0.806406, 1.273429, -0.007684},{0.805272, 1.273429, -0.006716},{
      0.805601, 1.271354, -0.006716},{0.806679, 1.271704, -0.007684}}],
    Polygon[{{0.805272, 1.273429, -0.006716},{0.804304, 1.273429, -0.005583},{
      0.804680, 1.271055, -0.005583},{0.805601, 1.271354, -0.006716}}],
    Polygon[{{0.804304, 1.273429, -0.005583},{0.803526, 1.273429, -0.004312},{
      0.803940, 1.270814, -0.004312},{0.804680, 1.271055, -0.005583}}],
    Polygon[{{0.803526, 1.273429, -0.004312},{0.802955, 1.273429, -0.002935},{
      0.803397, 1.270638, -0.002935},{0.803940, 1.270814, -0.004312}}],
    Polygon[{{0.802955, 1.273429, -0.002935},{0.802607, 1.273429, -0.001486},{
      0.803066, 1.270530, -0.001486},{0.803397, 1.270638, -0.002935}}],
    Polygon[{{0.802607, 1.273429, -0.001486},{0.802490, 1.273429, 0.000000},{
      0.802955, 1.270494, 0.000000},{0.803066, 1.270530, -0.001486}}],
    Polygon[{{0.802490, 1.273429, 0.000000},{0.802607, 1.273429, 0.001486},{
      0.803066, 1.270530, 0.001486},{0.802955, 1.270494, 0.000000}}],
    Polygon[{{0.802607, 1.273429, 0.001486},{0.802955, 1.273429, 0.002935},{
      0.803397, 1.270638, 0.002935},{0.803066, 1.270530, 0.001486}}],
    Polygon[{{0.802955, 1.273429, 0.002935},{0.803526, 1.273429, 0.004312},{
      0.803940, 1.270814, 0.004312},{0.803397, 1.270638, 0.002935}}],
    Polygon[{{0.803526, 1.273429, 0.004312},{0.804304, 1.273429, 0.005583},{
      0.804680, 1.271055, 0.005583},{0.803940, 1.270814, 0.004312}}],
    Polygon[{{0.804304, 1.273429, 0.005583},{0.805272, 1.273429, 0.006716},{
      0.805601, 1.271354, 0.006716},{0.804680, 1.271055, 0.005583}}],
    Polygon[{{0.805272, 1.273429, 0.006716},{0.806406, 1.273429, 0.007684},{
      0.806679, 1.271704, 0.007684},{0.805601, 1.271354, 0.006716}}],
    Polygon[{{0.806406, 1.273429, 0.007684},{0.807676, 1.273429, 0.008463},{
      0.807887, 1.272097, 0.008463},{0.806679, 1.271704, 0.007684}}],
    Polygon[{{0.807676, 1.273429, 0.008463},{0.809053, 1.273429, 0.009033},{
      0.809197, 1.272522, 0.009033},{0.807887, 1.272097, 0.008463}}],
    Polygon[{{0.809053, 1.273429, 0.009033},{0.810503, 1.273429, 0.009381},{
      0.810575, 1.272970, 0.009381},{0.809197, 1.272522, 0.009033}}],
    Polygon[{{0.810575, 1.272970, -0.009381},{0.809197, 1.272522, -0.009033},{
      0.809614, 1.271704, -0.009033},{0.810786, 1.272556, -0.009381}}],
    Polygon[{{0.809197, 1.272522, -0.009033},{0.807887, 1.272097, -0.008463},{
      0.808500, 1.270895, -0.008463},{0.809614, 1.271704, -0.009033}}],
    Polygon[{{0.807887, 1.272097, -0.008463},{0.806679, 1.271704, -0.007684},{
      0.807472, 1.270148, -0.007684},{0.808500, 1.270895, -0.008463}}],
    Polygon[{{0.806679, 1.271704, -0.007684},{0.805601, 1.271354, -0.006716},{
      0.806555, 1.269482, -0.006716},{0.807472, 1.270148, -0.007684}}],
    Polygon[{{0.805601, 1.271354, -0.006716},{0.804680, 1.271055, -0.005583},{
      0.805772, 1.268913, -0.005583},{0.806555, 1.269482, -0.006716}}],
    Polygon[{{0.804680, 1.271055, -0.005583},{0.803940, 1.270814, -0.004312},{
      0.805142, 1.268455, -0.004312},{0.805772, 1.268913, -0.005583}}],
    Polygon[{{0.803940, 1.270814, -0.004312},{0.803397, 1.270638, -0.002935},{
      0.804680, 1.268120, -0.002935},{0.805142, 1.268455, -0.004312}}],
    Polygon[{{0.803397, 1.270638, -0.002935},{0.803066, 1.270530, -0.001486},{
      0.804399, 1.267915, -0.001486},{0.804680, 1.268120, -0.002935}}],
    Polygon[{{0.803066, 1.270530, -0.001486},{0.802955, 1.270494, 0.000000},{
      0.804304, 1.267846, 0.000000},{0.804399, 1.267915, -0.001486}}],
    Polygon[{{0.802955, 1.270494, 0.000000},{0.803066, 1.270530, 0.001486},{
      0.804399, 1.267915, 0.001486},{0.804304, 1.267846, 0.000000}}],
    Polygon[{{0.803066, 1.270530, 0.001486},{0.803397, 1.270638, 0.002935},{
      0.804680, 1.268120, 0.002935},{0.804399, 1.267915, 0.001486}}],
    Polygon[{{0.803397, 1.270638, 0.002935},{0.803940, 1.270814, 0.004312},{
      0.805142, 1.268455, 0.004312},{0.804680, 1.268120, 0.002935}}],
    Polygon[{{0.803940, 1.270814, 0.004312},{0.804680, 1.271055, 0.005583},{
      0.805772, 1.268913, 0.005583},{0.805142, 1.268455, 0.004312}}],
    Polygon[{{0.804680, 1.271055, 0.005583},{0.805601, 1.271354, 0.006716},{
      0.806555, 1.269482, 0.006716},{0.805772, 1.268913, 0.005583}}],
    Polygon[{{0.805601, 1.271354, 0.006716},{0.806679, 1.271704, 0.007684},{
      0.807472, 1.270148, 0.007684},{0.806555, 1.269482, 0.006716}}],
    Polygon[{{0.806679, 1.271704, 0.007684},{0.807887, 1.272097, 0.008463},{
      0.808500, 1.270895, 0.008463},{0.807472, 1.270148, 0.007684}}],
    Polygon[{{0.807887, 1.272097, 0.008463},{0.809197, 1.272522, 0.009033},{
      0.809614, 1.271704, 0.009033},{0.808500, 1.270895, 0.008463}}],
    Polygon[{{0.809197, 1.272522, 0.009033},{0.810575, 1.272970, 0.009381},{
      0.810786, 1.272556, 0.009381},{0.809614, 1.271704, 0.009033}}],
    Polygon[{{0.810786, 1.272556, -0.009381},{0.809614, 1.271704, -0.009033},{
      0.810263, 1.271055, -0.009033},{0.811115, 1.272227, -0.009381}}],
    Polygon[{{0.809614, 1.271704, -0.009033},{0.808500, 1.270895, -0.008463},{
      0.809454, 1.269941, -0.008463},{0.810263, 1.271055, -0.009033}}],
    Polygon[{{0.808500, 1.270895, -0.008463},{0.807472, 1.270148, -0.007684},{
      0.808707, 1.268913, -0.007684},{0.809454, 1.269941, -0.008463}}],
    Polygon[{{0.807472, 1.270148, -0.007684},{0.806555, 1.269482, -0.006716},{
      0.808041, 1.267996, -0.006716},{0.808707, 1.268913, -0.007684}}],
    Polygon[{{0.806555, 1.269482, -0.006716},{0.805772, 1.268913, -0.005583},{
      0.807472, 1.267213, -0.005583},{0.808041, 1.267996, -0.006716}}],
    Polygon[{{0.805772, 1.268913, -0.005583},{0.805142, 1.268455, -0.004312},{
      0.807014, 1.266582, -0.004312},{0.807472, 1.267213, -0.005583}}],
    Polygon[{{0.805142, 1.268455, -0.004312},{0.804680, 1.268120, -0.002935},{
      0.806679, 1.266121, -0.002935},{0.807014, 1.266582, -0.004312}}],
    Polygon[{{0.804680, 1.268120, -0.002935},{0.804399, 1.267915, -0.001486},{
      0.806474, 1.265840, -0.001486},{0.806679, 1.266121, -0.002935}}],
    Polygon[{{0.804399, 1.267915, -0.001486},{0.804304, 1.267846, 0.000000},{
      0.806406, 1.265745, 0.000000},{0.806474, 1.265840, -0.001486}}],
    Polygon[{{0.804304, 1.267846, 0.000000},{0.804399, 1.267915, 0.001486},{
      0.806474, 1.265840, 0.001486},{0.806406, 1.265745, 0.000000}}],
    Polygon[{{0.804399, 1.267915, 0.001486},{0.804680, 1.268120, 0.002935},{
      0.806679, 1.266121, 0.002935},{0.806474, 1.265840, 0.001486}}],
    Polygon[{{0.804680, 1.268120, 0.002935},{0.805142, 1.268455, 0.004312},{
      0.807014, 1.266582, 0.004312},{0.806679, 1.266121, 0.002935}}],
    Polygon[{{0.805142, 1.268455, 0.004312},{0.805772, 1.268913, 0.005583},{
      0.807472, 1.267213, 0.005583},{0.807014, 1.266582, 0.004312}}],
    Polygon[{{0.805772, 1.268913, 0.005583},{0.806555, 1.269482, 0.006716},{
      0.808041, 1.267996, 0.006716},{0.807472, 1.267213, 0.005583}}],
    Polygon[{{0.806555, 1.269482, 0.006716},{0.807472, 1.270148, 0.007684},{
      0.808707, 1.268913, 0.007684},{0.808041, 1.267996, 0.006716}}],
    Polygon[{{0.807472, 1.270148, 0.007684},{0.808500, 1.270895, 0.008463},{
      0.809454, 1.269941, 0.008463},{0.808707, 1.268913, 0.007684}}],
    Polygon[{{0.808500, 1.270895, 0.008463},{0.809614, 1.271704, 0.009033},{
      0.810263, 1.271055, 0.009033},{0.809454, 1.269941, 0.008463}}],
    Polygon[{{0.809614, 1.271704, 0.009033},{0.810786, 1.272556, 0.009381},{
      0.811115, 1.272227, 0.009381},{0.810263, 1.271055, 0.009033}}],
    Polygon[{{0.811115, 1.272227, -0.009381},{0.810263, 1.271055, -0.009033},{
      0.811082, 1.270638, -0.009033},{0.811529, 1.272016, -0.009381}}],
    Polygon[{{0.810263, 1.271055, -0.009033},{0.809454, 1.269941, -0.008463},{
      0.810656, 1.269328, -0.008463},{0.811082, 1.270638, -0.009033}}],
    Polygon[{{0.809454, 1.269941, -0.008463},{0.808707, 1.268913, -0.007684},{
      0.810263, 1.268120, -0.007684},{0.810656, 1.269328, -0.008463}}],
    Polygon[{{0.808707, 1.268913, -0.007684},{0.808041, 1.267996, -0.006716},{
      0.809913, 1.267042, -0.006716},{0.810263, 1.268120, -0.007684}}],
    Polygon[{{0.808041, 1.267996, -0.006716},{0.807472, 1.267213, -0.005583},{
      0.809614, 1.266121, -0.005583},{0.809913, 1.267042, -0.006716}}],
    Polygon[{{0.807472, 1.267213, -0.005583},{0.807014, 1.266582, -0.004312},{
      0.809373, 1.265380, -0.004312},{0.809614, 1.266121, -0.005583}}],
    Polygon[{{0.807014, 1.266582, -0.004312},{0.806679, 1.266121, -0.002935},{
      0.809197, 1.264838, -0.002935},{0.809373, 1.265380, -0.004312}}],
    Polygon[{{0.806679, 1.266121, -0.002935},{0.806474, 1.265840, -0.001486},{
      0.809090, 1.264507, -0.001486},{0.809197, 1.264838, -0.002935}}],
    Polygon[{{0.806474, 1.265840, -0.001486},{0.806406, 1.265745, 0.000000},{
      0.809053, 1.264396, 0.000000},{0.809090, 1.264507, -0.001486}}],
    Polygon[{{0.806406, 1.265745, 0.000000},{0.806474, 1.265840, 0.001486},{
      0.809090, 1.264507, 0.001486},{0.809053, 1.264396, 0.000000}}],
    Polygon[{{0.806474, 1.265840, 0.001486},{0.806679, 1.266121, 0.002935},{
      0.809197, 1.264838, 0.002935},{0.809090, 1.264507, 0.001486}}],
    Polygon[{{0.806679, 1.266121, 0.002935},{0.807014, 1.266582, 0.004312},{
      0.809373, 1.265380, 0.004312},{0.809197, 1.264838, 0.002935}}],
    Polygon[{{0.807014, 1.266582, 0.004312},{0.807472, 1.267213, 0.005583},{
      0.809614, 1.266121, 0.005583},{0.809373, 1.265380, 0.004312}}],
    Polygon[{{0.807472, 1.267213, 0.005583},{0.808041, 1.267996, 0.006716},{
      0.809913, 1.267042, 0.006716},{0.809614, 1.266121, 0.005583}}],
    Polygon[{{0.808041, 1.267996, 0.006716},{0.808707, 1.268913, 0.007684},{
      0.810263, 1.268120, 0.007684},{0.809913, 1.267042, 0.006716}}],
    Polygon[{{0.808707, 1.268913, 0.007684},{0.809454, 1.269941, 0.008463},{
      0.810656, 1.269328, 0.008463},{0.810263, 1.268120, 0.007684}}],
    Polygon[{{0.809454, 1.269941, 0.008463},{0.810263, 1.271055, 0.009033},{
      0.811082, 1.270638, 0.009033},{0.810656, 1.269328, 0.008463}}],
    Polygon[{{0.810263, 1.271055, 0.009033},{0.811115, 1.272227, 0.009381},{
      0.811529, 1.272016, 0.009381},{0.811082, 1.270638, 0.009033}}],
    Polygon[{{0.811529, 1.272016, -0.009381},{0.811082, 1.270638, -0.009033},{
      0.811989, 1.270494, -0.009033},{0.811989, 1.271943, -0.009381}}],
    Polygon[{{0.811082, 1.270638, -0.009033},{0.810656, 1.269328, -0.008463},{
      0.811989, 1.269117, -0.008463},{0.811989, 1.270494, -0.009033}}],
    Polygon[{{0.810656, 1.269328, -0.008463},{0.810263, 1.268120, -0.007684},{
      0.811989, 1.267846, -0.007684},{0.811989, 1.269117, -0.008463}}],
    Polygon[{{0.810263, 1.268120, -0.007684},{0.809913, 1.267042, -0.006716},{
      0.811989, 1.266713, -0.006716},{0.811989, 1.267846, -0.007684}}],
    Polygon[{{0.809913, 1.267042, -0.006716},{0.809614, 1.266121, -0.005583},{
      0.811989, 1.265745, -0.005583},{0.811989, 1.266713, -0.006716}}],
    Polygon[{{0.809614, 1.266121, -0.005583},{0.809373, 1.265380, -0.004312},{
      0.811989, 1.264966, -0.004312},{0.811989, 1.265745, -0.005583}}],
    Polygon[{{0.809373, 1.265380, -0.004312},{0.809197, 1.264838, -0.002935},{
      0.811989, 1.264396, -0.002935},{0.811989, 1.264966, -0.004312}}],
    Polygon[{{0.809197, 1.264838, -0.002935},{0.809090, 1.264507, -0.001486},{
      0.811989, 1.264048, -0.001486},{0.811989, 1.264396, -0.002935}}],
    Polygon[{{0.809090, 1.264507, -0.001486},{0.809053, 1.264396, 0.000000},{
      0.811989, 1.263931, 0.000000},{0.811989, 1.264048, -0.001486}}],
    Polygon[{{0.809053, 1.264396, 0.000000},{0.809090, 1.264507, 0.001486},{
      0.811989, 1.264048, 0.001486},{0.811989, 1.263931, 0.000000}}],
    Polygon[{{0.809090, 1.264507, 0.001486},{0.809197, 1.264838, 0.002935},{
      0.811989, 1.264396, 0.002935},{0.811989, 1.264048, 0.001486}}],
    Polygon[{{0.809197, 1.264838, 0.002935},{0.809373, 1.265380, 0.004312},{
      0.811989, 1.264966, 0.004312},{0.811989, 1.264396, 0.002935}}],
    Polygon[{{0.809373, 1.265380, 0.004312},{0.809614, 1.266121, 0.005583},{
      0.811989, 1.265745, 0.005583},{0.811989, 1.264966, 0.004312}}],
    Polygon[{{0.809614, 1.266121, 0.005583},{0.809913, 1.267042, 0.006716},{
      0.811989, 1.266713, 0.006716},{0.811989, 1.265745, 0.005583}}],
    Polygon[{{0.809913, 1.267042, 0.006716},{0.810263, 1.268120, 0.007684},{
      0.811989, 1.267846, 0.007684},{0.811989, 1.266713, 0.006716}}],
    Polygon[{{0.810263, 1.268120, 0.007684},{0.810656, 1.269328, 0.008463},{
      0.811989, 1.269117, 0.008463},{0.811989, 1.267846, 0.007684}}],
    Polygon[{{0.810656, 1.269328, 0.008463},{0.811082, 1.270638, 0.009033},{
      0.811989, 1.270494, 0.009033},{0.811989, 1.269117, 0.008463}}],
    Polygon[{{0.811082, 1.270638, 0.009033},{0.811529, 1.272016, 0.009381},{
      0.811989, 1.271943, 0.009381},{0.811989, 1.270494, 0.009033}}],
    Polygon[{{0.811989, 1.271943, -0.009381},{0.811989, 1.270494, -0.009033},{
      0.812896, 1.270638, -0.009033},{0.812448, 1.272016, -0.009381}}],
    Polygon[{{0.811989, 1.270494, -0.009033},{0.811989, 1.269117, -0.008463},{
      0.813321, 1.269328, -0.008463},{0.812896, 1.270638, -0.009033}}],
    Polygon[{{0.811989, 1.269117, -0.008463},{0.811989, 1.267846, -0.007684},{
      0.813714, 1.268120, -0.007684},{0.813321, 1.269328, -0.008463}}],
    Polygon[{{0.811989, 1.267846, -0.007684},{0.811989, 1.266713, -0.006716},{
      0.814064, 1.267042, -0.006716},{0.813714, 1.268120, -0.007684}}],
    Polygon[{{0.811989, 1.266713, -0.006716},{0.811989, 1.265745, -0.005583},{
      0.814363, 1.266121, -0.005583},{0.814064, 1.267042, -0.006716}}],
    Polygon[{{0.811989, 1.265745, -0.005583},{0.811989, 1.264966, -0.004312},{
      0.814604, 1.265380, -0.004312},{0.814363, 1.266121, -0.005583}}],
    Polygon[{{0.811989, 1.264966, -0.004312},{0.811989, 1.264396, -0.002935},{
      0.814780, 1.264838, -0.002935},{0.814604, 1.265380, -0.004312}}],
    Polygon[{{0.811989, 1.264396, -0.002935},{0.811989, 1.264048, -0.001486},{
      0.814888, 1.264507, -0.001486},{0.814780, 1.264838, -0.002935}}],
    Polygon[{{0.811989, 1.264048, -0.001486},{0.811989, 1.263931, 0.000000},{
      0.814924, 1.264396, 0.000000},{0.814888, 1.264507, -0.001486}}],
    Polygon[{{0.811989, 1.263931, 0.000000},{0.811989, 1.264048, 0.001486},{
      0.814888, 1.264507, 0.001486},{0.814924, 1.264396, 0.000000}}],
    Polygon[{{0.811989, 1.264048, 0.001486},{0.811989, 1.264396, 0.002935},{
      0.814780, 1.264838, 0.002935},{0.814888, 1.264507, 0.001486}}],
    Polygon[{{0.811989, 1.264396, 0.002935},{0.811989, 1.264966, 0.004312},{
      0.814604, 1.265380, 0.004312},{0.814780, 1.264838, 0.002935}}],
    Polygon[{{0.811989, 1.264966, 0.004312},{0.811989, 1.265745, 0.005583},{
      0.814363, 1.266121, 0.005583},{0.814604, 1.265380, 0.004312}}],
    Polygon[{{0.811989, 1.265745, 0.005583},{0.811989, 1.266713, 0.006716},{
      0.814064, 1.267042, 0.006716},{0.814363, 1.266121, 0.005583}}],
    Polygon[{{0.811989, 1.266713, 0.006716},{0.811989, 1.267846, 0.007684},{
      0.813714, 1.268120, 0.007684},{0.814064, 1.267042, 0.006716}}],
    Polygon[{{0.811989, 1.267846, 0.007684},{0.811989, 1.269117, 0.008463},{
      0.813321, 1.269328, 0.008463},{0.813714, 1.268120, 0.007684}}],
    Polygon[{{0.811989, 1.269117, 0.008463},{0.811989, 1.270494, 0.009033},{
      0.812896, 1.270638, 0.009033},{0.813321, 1.269328, 0.008463}}],
    Polygon[{{0.811989, 1.270494, 0.009033},{0.811989, 1.271943, 0.009381},{
      0.812448, 1.272016, 0.009381},{0.812896, 1.270638, 0.009033}}],
    Polygon[{{0.812448, 1.272016, -0.009381},{0.812896, 1.270638, -0.009033},{
      0.813714, 1.271055, -0.009033},{0.812862, 1.272227, -0.009381}}],
    Polygon[{{0.812896, 1.270638, -0.009033},{0.813321, 1.269328, -0.008463},{
      0.814523, 1.269941, -0.008463},{0.813714, 1.271055, -0.009033}}],
    Polygon[{{0.813321, 1.269328, -0.008463},{0.813714, 1.268120, -0.007684},{
      0.815270, 1.268913, -0.007684},{0.814523, 1.269941, -0.008463}}],
    Polygon[{{0.813714, 1.268120, -0.007684},{0.814064, 1.267042, -0.006716},{
      0.815936, 1.267996, -0.006716},{0.815270, 1.268913, -0.007684}}],
    Polygon[{{0.814064, 1.267042, -0.006716},{0.814363, 1.266121, -0.005583},{
      0.816505, 1.267213, -0.005583},{0.815936, 1.267996, -0.006716}}],
    Polygon[{{0.814363, 1.266121, -0.005583},{0.814604, 1.265380, -0.004312},{
      0.816963, 1.266582, -0.004312},{0.816505, 1.267213, -0.005583}}],
    Polygon[{{0.814604, 1.265380, -0.004312},{0.814780, 1.264838, -0.002935},{
      0.817298, 1.266121, -0.002935},{0.816963, 1.266582, -0.004312}}],
    Polygon[{{0.814780, 1.264838, -0.002935},{0.814888, 1.264507, -0.001486},{
      0.817503, 1.265840, -0.001486},{0.817298, 1.266121, -0.002935}}],
    Polygon[{{0.814888, 1.264507, -0.001486},{0.814924, 1.264396, 0.000000},{
      0.817572, 1.265745, 0.000000},{0.817503, 1.265840, -0.001486}}],
    Polygon[{{0.814924, 1.264396, 0.000000},{0.814888, 1.264507, 0.001486},{
      0.817503, 1.265840, 0.001486},{0.817572, 1.265745, 0.000000}}],
    Polygon[{{0.814888, 1.264507, 0.001486},{0.814780, 1.264838, 0.002935},{
      0.817298, 1.266121, 0.002935},{0.817503, 1.265840, 0.001486}}],
    Polygon[{{0.814780, 1.264838, 0.002935},{0.814604, 1.265380, 0.004312},{
      0.816963, 1.266582, 0.004312},{0.817298, 1.266121, 0.002935}}],
    Polygon[{{0.814604, 1.265380, 0.004312},{0.814363, 1.266121, 0.005583},{
      0.816505, 1.267213, 0.005583},{0.816963, 1.266582, 0.004312}}],
    Polygon[{{0.814363, 1.266121, 0.005583},{0.814064, 1.267042, 0.006716},{
      0.815936, 1.267996, 0.006716},{0.816505, 1.267213, 0.005583}}],
    Polygon[{{0.814064, 1.267042, 0.006716},{0.813714, 1.268120, 0.007684},{
      0.815270, 1.268913, 0.007684},{0.815936, 1.267996, 0.006716}}],
    Polygon[{{0.813714, 1.268120, 0.007684},{0.813321, 1.269328, 0.008463},{
      0.814523, 1.269941, 0.008463},{0.815270, 1.268913, 0.007684}}],
    Polygon[{{0.813321, 1.269328, 0.008463},{0.812896, 1.270638, 0.009033},{
      0.813714, 1.271055, 0.009033},{0.814523, 1.269941, 0.008463}}],
    Polygon[{{0.812896, 1.270638, 0.009033},{0.812448, 1.272016, 0.009381},{
      0.812862, 1.272227, 0.009381},{0.813714, 1.271055, 0.009033}}],
    Polygon[{{0.812862, 1.272227, -0.009381},{0.813714, 1.271055, -0.009033},{
      0.814363, 1.271704, -0.009033},{0.813191, 1.272556, -0.009381}}],
    Polygon[{{0.813714, 1.271055, -0.009033},{0.814523, 1.269941, -0.008463},{
      0.815477, 1.270895, -0.008463},{0.814363, 1.271704, -0.009033}}],
    Polygon[{{0.814523, 1.269941, -0.008463},{0.815270, 1.268913, -0.007684},{
      0.816505, 1.270148, -0.007684},{0.815477, 1.270895, -0.008463}}],
    Polygon[{{0.815270, 1.268913, -0.007684},{0.815936, 1.267996, -0.006716},{
      0.817422, 1.269482, -0.006716},{0.816505, 1.270148, -0.007684}}],
    Polygon[{{0.815936, 1.267996, -0.006716},{0.816505, 1.267213, -0.005583},{
      0.818205, 1.268913, -0.005583},{0.817422, 1.269482, -0.006716}}],
    Polygon[{{0.816505, 1.267213, -0.005583},{0.816963, 1.266582, -0.004312},{
      0.818835, 1.268455, -0.004312},{0.818205, 1.268913, -0.005583}}],
    Polygon[{{0.816963, 1.266582, -0.004312},{0.817298, 1.266121, -0.002935},{
      0.819297, 1.268120, -0.002935},{0.818835, 1.268455, -0.004312}}],
    Polygon[{{0.817298, 1.266121, -0.002935},{0.817503, 1.265840, -0.001486},{
      0.819578, 1.267915, -0.001486},{0.819297, 1.268120, -0.002935}}],
    Polygon[{{0.817503, 1.265840, -0.001486},{0.817572, 1.265745, 0.000000},{
      0.819673, 1.267846, 0.000000},{0.819578, 1.267915, -0.001486}}],
    Polygon[{{0.817572, 1.265745, 0.000000},{0.817503, 1.265840, 0.001486},{
      0.819578, 1.267915, 0.001486},{0.819673, 1.267846, 0.000000}}],
    Polygon[{{0.817503, 1.265840, 0.001486},{0.817298, 1.266121, 0.002935},{
      0.819297, 1.268120, 0.002935},{0.819578, 1.267915, 0.001486}}],
    Polygon[{{0.817298, 1.266121, 0.002935},{0.816963, 1.266582, 0.004312},{
      0.818835, 1.268455, 0.004312},{0.819297, 1.268120, 0.002935}}],
    Polygon[{{0.816963, 1.266582, 0.004312},{0.816505, 1.267213, 0.005583},{
      0.818205, 1.268913, 0.005583},{0.818835, 1.268455, 0.004312}}],
    Polygon[{{0.816505, 1.267213, 0.005583},{0.815936, 1.267996, 0.006716},{
      0.817422, 1.269482, 0.006716},{0.818205, 1.268913, 0.005583}}],
    Polygon[{{0.815936, 1.267996, 0.006716},{0.815270, 1.268913, 0.007684},{
      0.816505, 1.270148, 0.007684},{0.817422, 1.269482, 0.006716}}],
    Polygon[{{0.815270, 1.268913, 0.007684},{0.814523, 1.269941, 0.008463},{
      0.815477, 1.270895, 0.008463},{0.816505, 1.270148, 0.007684}}],
    Polygon[{{0.814523, 1.269941, 0.008463},{0.813714, 1.271055, 0.009033},{
      0.814363, 1.271704, 0.009033},{0.815477, 1.270895, 0.008463}}],
    Polygon[{{0.813714, 1.271055, 0.009033},{0.812862, 1.272227, 0.009381},{
      0.813191, 1.272556, 0.009381},{0.814363, 1.271704, 0.009033}}],
    Polygon[{{0.813191, 1.272556, -0.009381},{0.814363, 1.271704, -0.009033},{
      0.814780, 1.272522, -0.009033},{0.813402, 1.272970, -0.009381}}],
    Polygon[{{0.814363, 1.271704, -0.009033},{0.815477, 1.270895, -0.008463},{
      0.816090, 1.272097, -0.008463},{0.814780, 1.272522, -0.009033}}],
    Polygon[{{0.815477, 1.270895, -0.008463},{0.816505, 1.270148, -0.007684},{
      0.817298, 1.271704, -0.007684},{0.816090, 1.272097, -0.008463}}],
    Polygon[{{0.816505, 1.270148, -0.007684},{0.817422, 1.269482, -0.006716},{
      0.818376, 1.271354, -0.006716},{0.817298, 1.271704, -0.007684}}],
    Polygon[{{0.817422, 1.269482, -0.006716},{0.818205, 1.268913, -0.005583},{
      0.819297, 1.271055, -0.005583},{0.818376, 1.271354, -0.006716}}],
    Polygon[{{0.818205, 1.268913, -0.005583},{0.818835, 1.268455, -0.004312},{
      0.820037, 1.270814, -0.004312},{0.819297, 1.271055, -0.005583}}],
    Polygon[{{0.818835, 1.268455, -0.004312},{0.819297, 1.268120, -0.002935},{
      0.820580, 1.270638, -0.002935},{0.820037, 1.270814, -0.004312}}],
    Polygon[{{0.819297, 1.268120, -0.002935},{0.819578, 1.267915, -0.001486},{
      0.820911, 1.270530, -0.001486},{0.820580, 1.270638, -0.002935}}],
    Polygon[{{0.819578, 1.267915, -0.001486},{0.819673, 1.267846, 0.000000},{
      0.821022, 1.270494, 0.000000},{0.820911, 1.270530, -0.001486}}],
    Polygon[{{0.819673, 1.267846, 0.000000},{0.819578, 1.267915, 0.001486},{
      0.820911, 1.270530, 0.001486},{0.821022, 1.270494, 0.000000}}],
    Polygon[{{0.819578, 1.267915, 0.001486},{0.819297, 1.268120, 0.002935},{
      0.820580, 1.270638, 0.002935},{0.820911, 1.270530, 0.001486}}],
    Polygon[{{0.819297, 1.268120, 0.002935},{0.818835, 1.268455, 0.004312},{
      0.820037, 1.270814, 0.004312},{0.820580, 1.270638, 0.002935}}],
    Polygon[{{0.818835, 1.268455, 0.004312},{0.818205, 1.268913, 0.005583},{
      0.819297, 1.271055, 0.005583},{0.820037, 1.270814, 0.004312}}],
    Polygon[{{0.818205, 1.268913, 0.005583},{0.817422, 1.269482, 0.006716},{
      0.818376, 1.271354, 0.006716},{0.819297, 1.271055, 0.005583}}],
    Polygon[{{0.817422, 1.269482, 0.006716},{0.816505, 1.270148, 0.007684},{
      0.817298, 1.271704, 0.007684},{0.818376, 1.271354, 0.006716}}],
    Polygon[{{0.816505, 1.270148, 0.007684},{0.815477, 1.270895, 0.008463},{
      0.816090, 1.272097, 0.008463},{0.817298, 1.271704, 0.007684}}],
    Polygon[{{0.815477, 1.270895, 0.008463},{0.814363, 1.271704, 0.009033},{
      0.814780, 1.272522, 0.009033},{0.816090, 1.272097, 0.008463}}],
    Polygon[{{0.814363, 1.271704, 0.009033},{0.813191, 1.272556, 0.009381},{
      0.813402, 1.272970, 0.009381},{0.814780, 1.272522, 0.009033}}],
    Polygon[{{0.813402, 1.272970, -0.009381},{0.814780, 1.272522, -0.009033},{
      0.814924, 1.273429, -0.009033},{0.813474, 1.273429, -0.009381}}],
    Polygon[{{0.814780, 1.272522, -0.009033},{0.816090, 1.272097, -0.008463},{
      0.816301, 1.273429, -0.008463},{0.814924, 1.273429, -0.009033}}],
    Polygon[{{0.816090, 1.272097, -0.008463},{0.817298, 1.271704, -0.007684},{
      0.817572, 1.273429, -0.007684},{0.816301, 1.273429, -0.008463}}],
    Polygon[{{0.817298, 1.271704, -0.007684},{0.818376, 1.271354, -0.006716},{
      0.818705, 1.273429, -0.006716},{0.817572, 1.273429, -0.007684}}],
    Polygon[{{0.818376, 1.271354, -0.006716},{0.819297, 1.271055, -0.005583},{
      0.819673, 1.273429, -0.005583},{0.818705, 1.273429, -0.006716}}],
    Polygon[{{0.819297, 1.271055, -0.005583},{0.820037, 1.270814, -0.004312},{
      0.820452, 1.273429, -0.004312},{0.819673, 1.273429, -0.005583}}],
    Polygon[{{0.820037, 1.270814, -0.004312},{0.820580, 1.270638, -0.002935},{
      0.821022, 1.273429, -0.002935},{0.820452, 1.273429, -0.004312}}],
    Polygon[{{0.820580, 1.270638, -0.002935},{0.820911, 1.270530, -0.001486},{
      0.821370, 1.273429, -0.001486},{0.821022, 1.273429, -0.002935}}],
    Polygon[{{0.820911, 1.270530, -0.001486},{0.821022, 1.270494, 0.000000},{
      0.821487, 1.273429, 0.000000},{0.821370, 1.273429, -0.001486}}],
    Polygon[{{0.821022, 1.270494, 0.000000},{0.820911, 1.270530, 0.001486},{
      0.821370, 1.273429, 0.001486},{0.821487, 1.273429, 0.000000}}],
    Polygon[{{0.820911, 1.270530, 0.001486},{0.820580, 1.270638, 0.002935},{
      0.821022, 1.273429, 0.002935},{0.821370, 1.273429, 0.001486}}],
    Polygon[{{0.820580, 1.270638, 0.002935},{0.820037, 1.270814, 0.004312},{
      0.820452, 1.273429, 0.004312},{0.821022, 1.273429, 0.002935}}],
    Polygon[{{0.820037, 1.270814, 0.004312},{0.819297, 1.271055, 0.005583},{
      0.819673, 1.273429, 0.005583},{0.820452, 1.273429, 0.004312}}],
    Polygon[{{0.819297, 1.271055, 0.005583},{0.818376, 1.271354, 0.006716},{
      0.818705, 1.273429, 0.006716},{0.819673, 1.273429, 0.005583}}],
    Polygon[{{0.818376, 1.271354, 0.006716},{0.817298, 1.271704, 0.007684},{
      0.817572, 1.273429, 0.007684},{0.818705, 1.273429, 0.006716}}],
    Polygon[{{0.817298, 1.271704, 0.007684},{0.816090, 1.272097, 0.008463},{
      0.816301, 1.273429, 0.008463},{0.817572, 1.273429, 0.007684}}],
    Polygon[{{0.816090, 1.272097, 0.008463},{0.814780, 1.272522, 0.009033},{
      0.814924, 1.273429, 0.009033},{0.816301, 1.273429, 0.008463}}],
    Polygon[{{0.814780, 1.272522, 0.009033},{0.813402, 1.272970, 0.009381},{
      0.813474, 1.273429, 0.009381},{0.814924, 1.273429, 0.009033}}],
    Polygon[{{0.881409, 1.167291, -0.024871},{0.885251, 1.167291, -0.023948},{
      0.884870, 1.169695, -0.023948},{0.881216, 1.168508, -0.024871}}],
    Polygon[{{0.885251, 1.167291, -0.023948},{0.888901, 1.167291, -0.022436},{
      0.888342, 1.170824, -0.022436},{0.884870, 1.169695, -0.023948}}],
    Polygon[{{0.888901, 1.167291, -0.022436},{0.892271, 1.167291, -0.020372},{
      0.891546, 1.171865, -0.020372},{0.888342, 1.170824, -0.022436}}],
    Polygon[{{0.892271, 1.167291, -0.020372},{0.895275, 1.167291, -0.017806},{
      0.894404, 1.172793, -0.017806},{0.891546, 1.171865, -0.020372}}],
    Polygon[{{0.895275, 1.167291, -0.017806},{0.897841, 1.167291, -0.014801},{
      0.896844, 1.173586, -0.014801},{0.894404, 1.172793, -0.017806}}],
    Polygon[{{0.897841, 1.167291, -0.014801},{0.899906, 1.167291, -0.011432},{
      0.898808, 1.174224, -0.011432},{0.896844, 1.173586, -0.014801}}],
    Polygon[{{0.899906, 1.167291, -0.011432},{0.901418, 1.167291, -0.007781},{
      0.900246, 1.174691, -0.007781},{0.898808, 1.174224, -0.011432}}],
    Polygon[{{0.901418, 1.167291, -0.007781},{0.902340, 1.167291, -0.003939},{
      0.901123, 1.174976, -0.003939},{0.900246, 1.174691, -0.007781}}],
    Polygon[{{0.902340, 1.167291, -0.003939},{0.902650, 1.167291, 0.000000},{
      0.901418, 1.175072, 0.000000},{0.901123, 1.174976, -0.003939}}],
    Polygon[{{0.902650, 1.167291, 0.000000},{0.902340, 1.167291, 0.003939},{
      0.901123, 1.174976, 0.003939},{0.901418, 1.175072, 0.000000}}],
    Polygon[{{0.902340, 1.167291, 0.003939},{0.901418, 1.167291, 0.007781},{
      0.900246, 1.174691, 0.007781},{0.901123, 1.174976, 0.003939}}],
    Polygon[{{0.901418, 1.167291, 0.007781},{0.899906, 1.167291, 0.011432},{
      0.898808, 1.174224, 0.011432},{0.900246, 1.174691, 0.007781}}],
    Polygon[{{0.899906, 1.167291, 0.011432},{0.897841, 1.167291, 0.014801},{
      0.896844, 1.173586, 0.014801},{0.898808, 1.174224, 0.011432}}],
    Polygon[{{0.897841, 1.167291, 0.014801},{0.895275, 1.167291, 0.017806},{
      0.894404, 1.172793, 0.017806},{0.896844, 1.173586, 0.014801}}],
    Polygon[{{0.895275, 1.167291, 0.017806},{0.892271, 1.167291, 0.020372},{
      0.891546, 1.171865, 0.020372},{0.894404, 1.172793, 0.017806}}],
    Polygon[{{0.892271, 1.167291, 0.020372},{0.888901, 1.167291, 0.022436},{
      0.888342, 1.170824, 0.022436},{0.891546, 1.171865, 0.020372}}],
    Polygon[{{0.888901, 1.167291, 0.022436},{0.885251, 1.167291, 0.023948},{
      0.884870, 1.169695, 0.023948},{0.888342, 1.170824, 0.022436}}],
    Polygon[{{0.885251, 1.167291, 0.023948},{0.881409, 1.167291, 0.024871},{
      0.881216, 1.168508, 0.024871},{0.884870, 1.169695, 0.023948}}],
    Polygon[{{0.881216, 1.168508, -0.024871},{0.884870, 1.169695, -0.023948},{
      0.883765, 1.171865, -0.023948},{0.880656, 1.169606, -0.024871}}],
    Polygon[{{0.884870, 1.169695, -0.023948},{0.888342, 1.170824, -0.022436},{
      0.886718, 1.174010, -0.022436},{0.883765, 1.171865, -0.023948}}],
    Polygon[{{0.888342, 1.170824, -0.022436},{0.891546, 1.171865, -0.020372},{
      0.889444, 1.175991, -0.020372},{0.886718, 1.174010, -0.022436}}],
    Polygon[{{0.891546, 1.171865, -0.020372},{0.894404, 1.172793, -0.017806},{
      0.891875, 1.177757, -0.017806},{0.889444, 1.175991, -0.020372}}],
    Polygon[{{0.894404, 1.172793, -0.017806},{0.896844, 1.173586, -0.014801},{
      0.893951, 1.179265, -0.014801},{0.891875, 1.177757, -0.017806}}],
    Polygon[{{0.896844, 1.173586, -0.014801},{0.898808, 1.174224, -0.011432},{
      0.895621, 1.180479, -0.011432},{0.893951, 1.179265, -0.014801}}],
    Polygon[{{0.898808, 1.174224, -0.011432},{0.900246, 1.174691, -0.007781},{
      0.896844, 1.181367, -0.007781},{0.895621, 1.180479, -0.011432}}],
    Polygon[{{0.900246, 1.174691, -0.007781},{0.901123, 1.174976, -0.003939},{
      0.897591, 1.181910, -0.003939},{0.896844, 1.181367, -0.007781}}],
    Polygon[{{0.901123, 1.174976, -0.003939},{0.901418, 1.175072, 0.000000},{
      0.897841, 1.182092, 0.000000},{0.897591, 1.181910, -0.003939}}],
    Polygon[{{0.901418, 1.175072, 0.000000},{0.901123, 1.174976, 0.003939},{
      0.897591, 1.181910, 0.003939},{0.897841, 1.182092, 0.000000}}],
    Polygon[{{0.901123, 1.174976, 0.003939},{0.900246, 1.174691, 0.007781},{
      0.896844, 1.181367, 0.007781},{0.897591, 1.181910, 0.003939}}],
    Polygon[{{0.900246, 1.174691, 0.007781},{0.898808, 1.174224, 0.011432},{
      0.895621, 1.180479, 0.011432},{0.896844, 1.181367, 0.007781}}],
    Polygon[{{0.898808, 1.174224, 0.011432},{0.896844, 1.173586, 0.014801},{
      0.893951, 1.179265, 0.014801},{0.895621, 1.180479, 0.011432}}],
    Polygon[{{0.896844, 1.173586, 0.014801},{0.894404, 1.172793, 0.017806},{
      0.891875, 1.177757, 0.017806},{0.893951, 1.179265, 0.014801}}],
    Polygon[{{0.894404, 1.172793, 0.017806},{0.891546, 1.171865, 0.020372},{
      0.889444, 1.175991, 0.020372},{0.891875, 1.177757, 0.017806}}],
    Polygon[{{0.891546, 1.171865, 0.020372},{0.888342, 1.170824, 0.022436},{
      0.886718, 1.174010, 0.022436},{0.889444, 1.175991, 0.020372}}],
    Polygon[{{0.888342, 1.170824, 0.022436},{0.884870, 1.169695, 0.023948},{
      0.883765, 1.171865, 0.023948},{0.886718, 1.174010, 0.022436}}],
    Polygon[{{0.884870, 1.169695, 0.023948},{0.881216, 1.168508, 0.024871},{
      0.880656, 1.169606, 0.024871},{0.883765, 1.171865, 0.023948}}],
    Polygon[{{0.880656, 1.169606, -0.024871},{0.883765, 1.171865, -0.023948},{
      0.882043, 1.173586, -0.023948},{0.879785, 1.170478, -0.024871}}],
    Polygon[{{0.883765, 1.171865, -0.023948},{0.886718, 1.174010, -0.022436},{
      0.884189, 1.176540, -0.022436},{0.882043, 1.173586, -0.023948}}],
    Polygon[{{0.886718, 1.174010, -0.022436},{0.889444, 1.175991, -0.020372},{
      0.886169, 1.179265, -0.020372},{0.884189, 1.176540, -0.022436}}],
    Polygon[{{0.889444, 1.175991, -0.020372},{0.891875, 1.177757, -0.017806},{
      0.887935, 1.181696, -0.017806},{0.886169, 1.179265, -0.020372}}],
    Polygon[{{0.891875, 1.177757, -0.017806},{0.893951, 1.179265, -0.014801},{
      0.889444, 1.183772, -0.014801},{0.887935, 1.181696, -0.017806}}],
    Polygon[{{0.893951, 1.179265, -0.014801},{0.895621, 1.180479, -0.011432},{
      0.890657, 1.185442, -0.011432},{0.889444, 1.183772, -0.014801}}],
    Polygon[{{0.895621, 1.180479, -0.011432},{0.896844, 1.181367, -0.007781},{
      0.891546, 1.186666, -0.007781},{0.890657, 1.185442, -0.011432}}],
    Polygon[{{0.896844, 1.181367, -0.007781},{0.897591, 1.181910, -0.003939},{
      0.892088, 1.187412, -0.003939},{0.891546, 1.186666, -0.007781}}],
    Polygon[{{0.897591, 1.181910, -0.003939},{0.897841, 1.182092, 0.000000},{
      0.892271, 1.187663, 0.000000},{0.892088, 1.187412, -0.003939}}],
    Polygon[{{0.897841, 1.182092, 0.000000},{0.897591, 1.181910, 0.003939},{
      0.892088, 1.187412, 0.003939},{0.892271, 1.187663, 0.000000}}],
    Polygon[{{0.897591, 1.181910, 0.003939},{0.896844, 1.181367, 0.007781},{
      0.891546, 1.186666, 0.007781},{0.892088, 1.187412, 0.003939}}],
    Polygon[{{0.896844, 1.181367, 0.007781},{0.895621, 1.180479, 0.011432},{
      0.890657, 1.185442, 0.011432},{0.891546, 1.186666, 0.007781}}],
    Polygon[{{0.895621, 1.180479, 0.011432},{0.893951, 1.179265, 0.014801},{
      0.889444, 1.183772, 0.014801},{0.890657, 1.185442, 0.011432}}],
    Polygon[{{0.893951, 1.179265, 0.014801},{0.891875, 1.177757, 0.017806},{
      0.887935, 1.181696, 0.017806},{0.889444, 1.183772, 0.014801}}],
    Polygon[{{0.891875, 1.177757, 0.017806},{0.889444, 1.175991, 0.020372},{
      0.886169, 1.179265, 0.020372},{0.887935, 1.181696, 0.017806}}],
    Polygon[{{0.889444, 1.175991, 0.020372},{0.886718, 1.174010, 0.022436},{
      0.884189, 1.176540, 0.022436},{0.886169, 1.179265, 0.020372}}],
    Polygon[{{0.886718, 1.174010, 0.022436},{0.883765, 1.171865, 0.023948},{
      0.882043, 1.173586, 0.023948},{0.884189, 1.176540, 0.022436}}],
    Polygon[{{0.883765, 1.171865, 0.023948},{0.880656, 1.169606, 0.024871},{
      0.879785, 1.170478, 0.024871},{0.882043, 1.173586, 0.023948}}],
    Polygon[{{0.879785, 1.170478, -0.024871},{0.882043, 1.173586, -0.023948},{
      0.879874, 1.174691, -0.023948},{0.878687, 1.171037, -0.024871}}],
    Polygon[{{0.882043, 1.173586, -0.023948},{0.884189, 1.176540, -0.022436},{
      0.881002, 1.178163, -0.022436},{0.879874, 1.174691, -0.023948}}],
    Polygon[{{0.884189, 1.176540, -0.022436},{0.886169, 1.179265, -0.020372},{
      0.882043, 1.181367, -0.020372},{0.881002, 1.178163, -0.022436}}],
    Polygon[{{0.886169, 1.179265, -0.020372},{0.887935, 1.181696, -0.017806},{
      0.882972, 1.184225, -0.017806},{0.882043, 1.181367, -0.020372}}],
    Polygon[{{0.887935, 1.181696, -0.017806},{0.889444, 1.183772, -0.014801},{
      0.883765, 1.186666, -0.014801},{0.882972, 1.184225, -0.017806}}],
    Polygon[{{0.889444, 1.183772, -0.014801},{0.890657, 1.185442, -0.011432},{
      0.884403, 1.188629, -0.011432},{0.883765, 1.186666, -0.014801}}],
    Polygon[{{0.890657, 1.185442, -0.011432},{0.891546, 1.186666, -0.007781},{
      0.884870, 1.190067, -0.007781},{0.884403, 1.188629, -0.011432}}],
    Polygon[{{0.891546, 1.186666, -0.007781},{0.892088, 1.187412, -0.003939},{
      0.885155, 1.190944, -0.003939},{0.884870, 1.190067, -0.007781}}],
    Polygon[{{0.892088, 1.187412, -0.003939},{0.892271, 1.187663, 0.000000},{
      0.885251, 1.191239, 0.000000},{0.885155, 1.190944, -0.003939}}],
    Polygon[{{0.892271, 1.187663, 0.000000},{0.892088, 1.187412, 0.003939},{
      0.885155, 1.190944, 0.003939},{0.885251, 1.191239, 0.000000}}],
    Polygon[{{0.892088, 1.187412, 0.003939},{0.891546, 1.186666, 0.007781},{
      0.884870, 1.190067, 0.007781},{0.885155, 1.190944, 0.003939}}],
    Polygon[{{0.891546, 1.186666, 0.007781},{0.890657, 1.185442, 0.011432},{
      0.884403, 1.188629, 0.011432},{0.884870, 1.190067, 0.007781}}],
    Polygon[{{0.890657, 1.185442, 0.011432},{0.889444, 1.183772, 0.014801},{
      0.883765, 1.186666, 0.014801},{0.884403, 1.188629, 0.011432}}],
    Polygon[{{0.889444, 1.183772, 0.014801},{0.887935, 1.181696, 0.017806},{
      0.882972, 1.184225, 0.017806},{0.883765, 1.186666, 0.014801}}],
    Polygon[{{0.887935, 1.181696, 0.017806},{0.886169, 1.179265, 0.020372},{
      0.882043, 1.181367, 0.020372},{0.882972, 1.184225, 0.017806}}],
    Polygon[{{0.886169, 1.179265, 0.020372},{0.884189, 1.176540, 0.022436},{
      0.881002, 1.178163, 0.022436},{0.882043, 1.181367, 0.020372}}],
    Polygon[{{0.884189, 1.176540, 0.022436},{0.882043, 1.173586, 0.023948},{
      0.879874, 1.174691, 0.023948},{0.881002, 1.178163, 0.022436}}],
    Polygon[{{0.882043, 1.173586, 0.023948},{0.879785, 1.170478, 0.024871},{
      0.878687, 1.171037, 0.024871},{0.879874, 1.174691, 0.023948}}],
    Polygon[{{0.878687, 1.171037, -0.024871},{0.879874, 1.174691, -0.023948},{
      0.877470, 1.175072, -0.023948},{0.877470, 1.171230, -0.024871}}],
    Polygon[{{0.879874, 1.174691, -0.023948},{0.881002, 1.178163, -0.022436},{
      0.877470, 1.178723, -0.022436},{0.877470, 1.175072, -0.023948}}],
    Polygon[{{0.881002, 1.178163, -0.022436},{0.882043, 1.181367, -0.020372},{
      0.877470, 1.182092, -0.020372},{0.877470, 1.178723, -0.022436}}],
    Polygon[{{0.882043, 1.181367, -0.020372},{0.882972, 1.184225, -0.017806},{
      0.877470, 1.185096, -0.017806},{0.877470, 1.182092, -0.020372}}],
    Polygon[{{0.882972, 1.184225, -0.017806},{0.883765, 1.186666, -0.014801},{
      0.877470, 1.187663, -0.014801},{0.877470, 1.185096, -0.017806}}],
    Polygon[{{0.883765, 1.186666, -0.014801},{0.884403, 1.188629, -0.011432},{
      0.877470, 1.189727, -0.011432},{0.877470, 1.187663, -0.014801}}],
    Polygon[{{0.884403, 1.188629, -0.011432},{0.884870, 1.190067, -0.007781},{
      0.877470, 1.191239, -0.007781},{0.877470, 1.189727, -0.011432}}],
    Polygon[{{0.884870, 1.190067, -0.007781},{0.885155, 1.190944, -0.003939},{
      0.877470, 1.192162, -0.003939},{0.877470, 1.191239, -0.007781}}],
    Polygon[{{0.885155, 1.190944, -0.003939},{0.885251, 1.191239, 0.000000},{
      0.877470, 1.192472, 0.000000},{0.877470, 1.192162, -0.003939}}],
    Polygon[{{0.885251, 1.191239, 0.000000},{0.885155, 1.190944, 0.003939},{
      0.877470, 1.192162, 0.003939},{0.877470, 1.192472, 0.000000}}],
    Polygon[{{0.885155, 1.190944, 0.003939},{0.884870, 1.190067, 0.007781},{
      0.877470, 1.191239, 0.007781},{0.877470, 1.192162, 0.003939}}],
    Polygon[{{0.884870, 1.190067, 0.007781},{0.884403, 1.188629, 0.011432},{
      0.877470, 1.189727, 0.011432},{0.877470, 1.191239, 0.007781}}],
    Polygon[{{0.884403, 1.188629, 0.011432},{0.883765, 1.186666, 0.014801},{
      0.877470, 1.187663, 0.014801},{0.877470, 1.189727, 0.011432}}],
    Polygon[{{0.883765, 1.186666, 0.014801},{0.882972, 1.184225, 0.017806},{
      0.877470, 1.185096, 0.017806},{0.877470, 1.187663, 0.014801}}],
    Polygon[{{0.882972, 1.184225, 0.017806},{0.882043, 1.181367, 0.020372},{
      0.877470, 1.182092, 0.020372},{0.877470, 1.185096, 0.017806}}],
    Polygon[{{0.882043, 1.181367, 0.020372},{0.881002, 1.178163, 0.022436},{
      0.877470, 1.178723, 0.022436},{0.877470, 1.182092, 0.020372}}],
    Polygon[{{0.881002, 1.178163, 0.022436},{0.879874, 1.174691, 0.023948},{
      0.877470, 1.175072, 0.023948},{0.877470, 1.178723, 0.022436}}],
    Polygon[{{0.879874, 1.174691, 0.023948},{0.878687, 1.171037, 0.024871},{
      0.877470, 1.171230, 0.024871},{0.877470, 1.175072, 0.023948}}],
    Polygon[{{0.877470, 1.171230, -0.024871},{0.877470, 1.175072, -0.023948},{
      0.875065, 1.174691, -0.023948},{0.876252, 1.171037, -0.024871}}],
    Polygon[{{0.877470, 1.175072, -0.023948},{0.877470, 1.178723, -0.022436},{
      0.873937, 1.178163, -0.022436},{0.875065, 1.174691, -0.023948}}],
    Polygon[{{0.877470, 1.178723, -0.022436},{0.877470, 1.182092, -0.020372},{
      0.872896, 1.181367, -0.020372},{0.873937, 1.178163, -0.022436}}],
    Polygon[{{0.877470, 1.182092, -0.020372},{0.877470, 1.185096, -0.017806},{
      0.871967, 1.184225, -0.017806},{0.872896, 1.181367, -0.020372}}],
    Polygon[{{0.877470, 1.185096, -0.017806},{0.877470, 1.187663, -0.014801},{
      0.871174, 1.186666, -0.014801},{0.871967, 1.184225, -0.017806}}],
    Polygon[{{0.877470, 1.187663, -0.014801},{0.877470, 1.189727, -0.011432},{
      0.870536, 1.188629, -0.011432},{0.871174, 1.186666, -0.014801}}],
    Polygon[{{0.877470, 1.189727, -0.011432},{0.877470, 1.191239, -0.007781},{
      0.870069, 1.190067, -0.007781},{0.870536, 1.188629, -0.011432}}],
    Polygon[{{0.877470, 1.191239, -0.007781},{0.877470, 1.192162, -0.003939},{
      0.869784, 1.190944, -0.003939},{0.870069, 1.190067, -0.007781}}],
    Polygon[{{0.877470, 1.192162, -0.003939},{0.877470, 1.192472, 0.000000},{
      0.869688, 1.191239, 0.000000},{0.869784, 1.190944, -0.003939}}],
    Polygon[{{0.877470, 1.192472, 0.000000},{0.877470, 1.192162, 0.003939},{
      0.869784, 1.190944, 0.003939},{0.869688, 1.191239, 0.000000}}],
    Polygon[{{0.877470, 1.192162, 0.003939},{0.877470, 1.191239, 0.007781},{
      0.870069, 1.190067, 0.007781},{0.869784, 1.190944, 0.003939}}],
    Polygon[{{0.877470, 1.191239, 0.007781},{0.877470, 1.189727, 0.011432},{
      0.870536, 1.188629, 0.011432},{0.870069, 1.190067, 0.007781}}],
    Polygon[{{0.877470, 1.189727, 0.011432},{0.877470, 1.187663, 0.014801},{
      0.871174, 1.186666, 0.014801},{0.870536, 1.188629, 0.011432}}],
    Polygon[{{0.877470, 1.187663, 0.014801},{0.877470, 1.185096, 0.017806},{
      0.871967, 1.184225, 0.017806},{0.871174, 1.186666, 0.014801}}],
    Polygon[{{0.877470, 1.185096, 0.017806},{0.877470, 1.182092, 0.020372},{
      0.872896, 1.181367, 0.020372},{0.871967, 1.184225, 0.017806}}],
    Polygon[{{0.877470, 1.182092, 0.020372},{0.877470, 1.178723, 0.022436},{
      0.873937, 1.178163, 0.022436},{0.872896, 1.181367, 0.020372}}],
    Polygon[{{0.877470, 1.178723, 0.022436},{0.877470, 1.175072, 0.023948},{
      0.875065, 1.174691, 0.023948},{0.873937, 1.178163, 0.022436}}],
    Polygon[{{0.877470, 1.175072, 0.023948},{0.877470, 1.171230, 0.024871},{
      0.876252, 1.171037, 0.024871},{0.875065, 1.174691, 0.023948}}],
    Polygon[{{0.876252, 1.171037, -0.024871},{0.875065, 1.174691, -0.023948},{
      0.872896, 1.173586, -0.023948},{0.875154, 1.170478, -0.024871}}],
    Polygon[{{0.875065, 1.174691, -0.023948},{0.873937, 1.178163, -0.022436},{
      0.870750, 1.176540, -0.022436},{0.872896, 1.173586, -0.023948}}],
    Polygon[{{0.873937, 1.178163, -0.022436},{0.872896, 1.181367, -0.020372},{
      0.868770, 1.179265, -0.020372},{0.870750, 1.176540, -0.022436}}],
    Polygon[{{0.872896, 1.181367, -0.020372},{0.871967, 1.184225, -0.017806},{
      0.867004, 1.181696, -0.017806},{0.868770, 1.179265, -0.020372}}],
    Polygon[{{0.871967, 1.184225, -0.017806},{0.871174, 1.186666, -0.014801},{
      0.865495, 1.183772, -0.014801},{0.867004, 1.181696, -0.017806}}],
    Polygon[{{0.871174, 1.186666, -0.014801},{0.870536, 1.188629, -0.011432},{
      0.864282, 1.185442, -0.011432},{0.865495, 1.183772, -0.014801}}],
    Polygon[{{0.870536, 1.188629, -0.011432},{0.870069, 1.190067, -0.007781},{
      0.863393, 1.186666, -0.007781},{0.864282, 1.185442, -0.011432}}],
    Polygon[{{0.870069, 1.190067, -0.007781},{0.869784, 1.190944, -0.003939},{
      0.862851, 1.187412, -0.003939},{0.863393, 1.186666, -0.007781}}],
    Polygon[{{0.869784, 1.190944, -0.003939},{0.869688, 1.191239, 0.000000},{
      0.862669, 1.187663, 0.000000},{0.862851, 1.187412, -0.003939}}],
    Polygon[{{0.869688, 1.191239, 0.000000},{0.869784, 1.190944, 0.003939},{
      0.862851, 1.187412, 0.003939},{0.862669, 1.187663, 0.000000}}],
    Polygon[{{0.869784, 1.190944, 0.003939},{0.870069, 1.190067, 0.007781},{
      0.863393, 1.186666, 0.007781},{0.862851, 1.187412, 0.003939}}],
    Polygon[{{0.870069, 1.190067, 0.007781},{0.870536, 1.188629, 0.011432},{
      0.864282, 1.185442, 0.011432},{0.863393, 1.186666, 0.007781}}],
    Polygon[{{0.870536, 1.188629, 0.011432},{0.871174, 1.186666, 0.014801},{
      0.865495, 1.183772, 0.014801},{0.864282, 1.185442, 0.011432}}],
    Polygon[{{0.871174, 1.186666, 0.014801},{0.871967, 1.184225, 0.017806},{
      0.867004, 1.181696, 0.017806},{0.865495, 1.183772, 0.014801}}],
    Polygon[{{0.871967, 1.184225, 0.017806},{0.872896, 1.181367, 0.020372},{
      0.868770, 1.179265, 0.020372},{0.867004, 1.181696, 0.017806}}],
    Polygon[{{0.872896, 1.181367, 0.020372},{0.873937, 1.178163, 0.022436},{
      0.870750, 1.176540, 0.022436},{0.868770, 1.179265, 0.020372}}],
    Polygon[{{0.873937, 1.178163, 0.022436},{0.875065, 1.174691, 0.023948},{
      0.872896, 1.173586, 0.023948},{0.870750, 1.176540, 0.022436}}],
    Polygon[{{0.875065, 1.174691, 0.023948},{0.876252, 1.171037, 0.024871},{
      0.875154, 1.170478, 0.024871},{0.872896, 1.173586, 0.023948}}],
    Polygon[{{0.875154, 1.170478, -0.024871},{0.872896, 1.173586, -0.023948},{
      0.871174, 1.171865, -0.023948},{0.874283, 1.169606, -0.024871}}],
    Polygon[{{0.872896, 1.173586, -0.023948},{0.870750, 1.176540, -0.022436},{
      0.868221, 1.174010, -0.022436},{0.871174, 1.171865, -0.023948}}],
    Polygon[{{0.870750, 1.176540, -0.022436},{0.868770, 1.179265, -0.020372},{
      0.865495, 1.175991, -0.020372},{0.868221, 1.174010, -0.022436}}],
    Polygon[{{0.868770, 1.179265, -0.020372},{0.867004, 1.181696, -0.017806},{
      0.863065, 1.177757, -0.017806},{0.865495, 1.175991, -0.020372}}],
    Polygon[{{0.867004, 1.181696, -0.017806},{0.865495, 1.183772, -0.014801},{
      0.860989, 1.179265, -0.014801},{0.863065, 1.177757, -0.017806}}],
    Polygon[{{0.865495, 1.183772, -0.014801},{0.864282, 1.185442, -0.011432},{
      0.859318, 1.180479, -0.011432},{0.860989, 1.179265, -0.014801}}],
    Polygon[{{0.864282, 1.185442, -0.011432},{0.863393, 1.186666, -0.007781},{
      0.858095, 1.181367, -0.007781},{0.859318, 1.180479, -0.011432}}],
    Polygon[{{0.863393, 1.186666, -0.007781},{0.862851, 1.187412, -0.003939},{
      0.857349, 1.181910, -0.003939},{0.858095, 1.181367, -0.007781}}],
    Polygon[{{0.862851, 1.187412, -0.003939},{0.862669, 1.187663, 0.000000},{
      0.857098, 1.182092, 0.000000},{0.857349, 1.181910, -0.003939}}],
    Polygon[{{0.862669, 1.187663, 0.000000},{0.862851, 1.187412, 0.003939},{
      0.857349, 1.181910, 0.003939},{0.857098, 1.182092, 0.000000}}],
    Polygon[{{0.862851, 1.187412, 0.003939},{0.863393, 1.186666, 0.007781},{
      0.858095, 1.181367, 0.007781},{0.857349, 1.181910, 0.003939}}],
    Polygon[{{0.863393, 1.186666, 0.007781},{0.864282, 1.185442, 0.011432},{
      0.859318, 1.180479, 0.011432},{0.858095, 1.181367, 0.007781}}],
    Polygon[{{0.864282, 1.185442, 0.011432},{0.865495, 1.183772, 0.014801},{
      0.860989, 1.179265, 0.014801},{0.859318, 1.180479, 0.011432}}],
    Polygon[{{0.865495, 1.183772, 0.014801},{0.867004, 1.181696, 0.017806},{
      0.863065, 1.177757, 0.017806},{0.860989, 1.179265, 0.014801}}],
    Polygon[{{0.867004, 1.181696, 0.017806},{0.868770, 1.179265, 0.020372},{
      0.865495, 1.175991, 0.020372},{0.863065, 1.177757, 0.017806}}],
    Polygon[{{0.868770, 1.179265, 0.020372},{0.870750, 1.176540, 0.022436},{
      0.868221, 1.174010, 0.022436},{0.865495, 1.175991, 0.020372}}],
    Polygon[{{0.870750, 1.176540, 0.022436},{0.872896, 1.173586, 0.023948},{
      0.871174, 1.171865, 0.023948},{0.868221, 1.174010, 0.022436}}],
    Polygon[{{0.872896, 1.173586, 0.023948},{0.875154, 1.170478, 0.024871},{
      0.874283, 1.169606, 0.024871},{0.871174, 1.171865, 0.023948}}],
    Polygon[{{0.874283, 1.169606, -0.024871},{0.871174, 1.171865, -0.023948},{
      0.870069, 1.169695, -0.023948},{0.873723, 1.168508, -0.024871}}],
    Polygon[{{0.871174, 1.171865, -0.023948},{0.868221, 1.174010, -0.022436},{
      0.866597, 1.170824, -0.022436},{0.870069, 1.169695, -0.023948}}],
    Polygon[{{0.868221, 1.174010, -0.022436},{0.865495, 1.175991, -0.020372},{
      0.863393, 1.171865, -0.020372},{0.866597, 1.170824, -0.022436}}],
    Polygon[{{0.865495, 1.175991, -0.020372},{0.863065, 1.177757, -0.017806},{
      0.860536, 1.172793, -0.017806},{0.863393, 1.171865, -0.020372}}],
    Polygon[{{0.863065, 1.177757, -0.017806},{0.860989, 1.179265, -0.014801},{
      0.858095, 1.173586, -0.014801},{0.860536, 1.172793, -0.017806}}],
    Polygon[{{0.860989, 1.179265, -0.014801},{0.859318, 1.180479, -0.011432},{
      0.856131, 1.174224, -0.011432},{0.858095, 1.173586, -0.014801}}],
    Polygon[{{0.859318, 1.180479, -0.011432},{0.858095, 1.181367, -0.007781},{
      0.854693, 1.174691, -0.007781},{0.856131, 1.174224, -0.011432}}],
    Polygon[{{0.858095, 1.181367, -0.007781},{0.857349, 1.181910, -0.003939},{
      0.853816, 1.174976, -0.003939},{0.854693, 1.174691, -0.007781}}],
    Polygon[{{0.857349, 1.181910, -0.003939},{0.857098, 1.182092, 0.000000},{
      0.853521, 1.175072, 0.000000},{0.853816, 1.174976, -0.003939}}],
    Polygon[{{0.857098, 1.182092, 0.000000},{0.857349, 1.181910, 0.003939},{
      0.853816, 1.174976, 0.003939},{0.853521, 1.175072, 0.000000}}],
    Polygon[{{0.857349, 1.181910, 0.003939},{0.858095, 1.181367, 0.007781},{
      0.854693, 1.174691, 0.007781},{0.853816, 1.174976, 0.003939}}],
    Polygon[{{0.858095, 1.181367, 0.007781},{0.859318, 1.180479, 0.011432},{
      0.856131, 1.174224, 0.011432},{0.854693, 1.174691, 0.007781}}],
    Polygon[{{0.859318, 1.180479, 0.011432},{0.860989, 1.179265, 0.014801},{
      0.858095, 1.173586, 0.014801},{0.856131, 1.174224, 0.011432}}],
    Polygon[{{0.860989, 1.179265, 0.014801},{0.863065, 1.177757, 0.017806},{
      0.860536, 1.172793, 0.017806},{0.858095, 1.173586, 0.014801}}],
    Polygon[{{0.863065, 1.177757, 0.017806},{0.865495, 1.175991, 0.020372},{
      0.863393, 1.171865, 0.020372},{0.860536, 1.172793, 0.017806}}],
    Polygon[{{0.865495, 1.175991, 0.020372},{0.868221, 1.174010, 0.022436},{
      0.866597, 1.170824, 0.022436},{0.863393, 1.171865, 0.020372}}],
    Polygon[{{0.868221, 1.174010, 0.022436},{0.871174, 1.171865, 0.023948},{
      0.870069, 1.169695, 0.023948},{0.866597, 1.170824, 0.022436}}],
    Polygon[{{0.871174, 1.171865, 0.023948},{0.874283, 1.169606, 0.024871},{
      0.873723, 1.168508, 0.024871},{0.870069, 1.169695, 0.023948}}],
    Polygon[{{0.873723, 1.168508, -0.024871},{0.870069, 1.169695, -0.023948},{
      0.869688, 1.167291, -0.023948},{0.873531, 1.167291, -0.024871}}],
    Polygon[{{0.870069, 1.169695, -0.023948},{0.866597, 1.170824, -0.022436},{
      0.866038, 1.167291, -0.022436},{0.869688, 1.167291, -0.023948}}],
    Polygon[{{0.866597, 1.170824, -0.022436},{0.863393, 1.171865, -0.020372},{
      0.862669, 1.167291, -0.020372},{0.866038, 1.167291, -0.022436}}],
    Polygon[{{0.863393, 1.171865, -0.020372},{0.860536, 1.172793, -0.017806},{
      0.859664, 1.167291, -0.017806},{0.862669, 1.167291, -0.020372}}],
    Polygon[{{0.860536, 1.172793, -0.017806},{0.858095, 1.173586, -0.014801},{
      0.857098, 1.167291, -0.014801},{0.859664, 1.167291, -0.017806}}],
    Polygon[{{0.858095, 1.173586, -0.014801},{0.856131, 1.174224, -0.011432},{
      0.855033, 1.167291, -0.011432},{0.857098, 1.167291, -0.014801}}],
    Polygon[{{0.856131, 1.174224, -0.011432},{0.854693, 1.174691, -0.007781},{
      0.853521, 1.167291, -0.007781},{0.855033, 1.167291, -0.011432}}],
    Polygon[{{0.854693, 1.174691, -0.007781},{0.853816, 1.174976, -0.003939},{
      0.852599, 1.167291, -0.003939},{0.853521, 1.167291, -0.007781}}],
    Polygon[{{0.853816, 1.174976, -0.003939},{0.853521, 1.175072, 0.000000},{
      0.852289, 1.167291, 0.000000},{0.852599, 1.167291, -0.003939}}],
    Polygon[{{0.853521, 1.175072, 0.000000},{0.853816, 1.174976, 0.003939},{
      0.852599, 1.167291, 0.003939},{0.852289, 1.167291, 0.000000}}],
    Polygon[{{0.853816, 1.174976, 0.003939},{0.854693, 1.174691, 0.007781},{
      0.853521, 1.167291, 0.007781},{0.852599, 1.167291, 0.003939}}],
    Polygon[{{0.854693, 1.174691, 0.007781},{0.856131, 1.174224, 0.011432},{
      0.855033, 1.167291, 0.011432},{0.853521, 1.167291, 0.007781}}],
    Polygon[{{0.856131, 1.174224, 0.011432},{0.858095, 1.173586, 0.014801},{
      0.857098, 1.167291, 0.014801},{0.855033, 1.167291, 0.011432}}],
    Polygon[{{0.858095, 1.173586, 0.014801},{0.860536, 1.172793, 0.017806},{
      0.859664, 1.167291, 0.017806},{0.857098, 1.167291, 0.014801}}],
    Polygon[{{0.860536, 1.172793, 0.017806},{0.863393, 1.171865, 0.020372},{
      0.862669, 1.167291, 0.020372},{0.859664, 1.167291, 0.017806}}],
    Polygon[{{0.863393, 1.171865, 0.020372},{0.866597, 1.170824, 0.022436},{
      0.866038, 1.167291, 0.022436},{0.862669, 1.167291, 0.020372}}],
    Polygon[{{0.866597, 1.170824, 0.022436},{0.870069, 1.169695, 0.023948},{
      0.869688, 1.167291, 0.023948},{0.866038, 1.167291, 0.022436}}],
    Polygon[{{0.870069, 1.169695, 0.023948},{0.873723, 1.168508, 0.024871},{
      0.873531, 1.167291, 0.024871},{0.869688, 1.167291, 0.023948}}],
    Polygon[{{0.873531, 1.167291, -0.024871},{0.869688, 1.167291, -0.023948},{
      0.870069, 1.164886, -0.023948},{0.873723, 1.166074, -0.024871}}],
    Polygon[{{0.869688, 1.167291, -0.023948},{0.866038, 1.167291, -0.022436},{
      0.866597, 1.163758, -0.022436},{0.870069, 1.164886, -0.023948}}],
    Polygon[{{0.866038, 1.167291, -0.022436},{0.862669, 1.167291, -0.020372},{
      0.863393, 1.162717, -0.020372},{0.866597, 1.163758, -0.022436}}],
    Polygon[{{0.862669, 1.167291, -0.020372},{0.859664, 1.167291, -0.017806},{
      0.860536, 1.161789, -0.017806},{0.863393, 1.162717, -0.020372}}],
    Polygon[{{0.859664, 1.167291, -0.017806},{0.857098, 1.167291, -0.014801},{
      0.858095, 1.160996, -0.014801},{0.860536, 1.161789, -0.017806}}],
    Polygon[{{0.857098, 1.167291, -0.014801},{0.855033, 1.167291, -0.011432},{
      0.856131, 1.160358, -0.011432},{0.858095, 1.160996, -0.014801}}],
    Polygon[{{0.855033, 1.167291, -0.011432},{0.853521, 1.167291, -0.007781},{
      0.854693, 1.159891, -0.007781},{0.856131, 1.160358, -0.011432}}],
    Polygon[{{0.853521, 1.167291, -0.007781},{0.852599, 1.167291, -0.003939},{
      0.853816, 1.159605, -0.003939},{0.854693, 1.159891, -0.007781}}],
    Polygon[{{0.852599, 1.167291, -0.003939},{0.852289, 1.167291, 0.000000},{
      0.853521, 1.159510, 0.000000},{0.853816, 1.159605, -0.003939}}],
    Polygon[{{0.852289, 1.167291, 0.000000},{0.852599, 1.167291, 0.003939},{
      0.853816, 1.159605, 0.003939},{0.853521, 1.159510, 0.000000}}],
    Polygon[{{0.852599, 1.167291, 0.003939},{0.853521, 1.167291, 0.007781},{
      0.854693, 1.159891, 0.007781},{0.853816, 1.159605, 0.003939}}],
    Polygon[{{0.853521, 1.167291, 0.007781},{0.855033, 1.167291, 0.011432},{
      0.856131, 1.160358, 0.011432},{0.854693, 1.159891, 0.007781}}],
    Polygon[{{0.855033, 1.167291, 0.011432},{0.857098, 1.167291, 0.014801},{
      0.858095, 1.160996, 0.014801},{0.856131, 1.160358, 0.011432}}],
    Polygon[{{0.857098, 1.167291, 0.014801},{0.859664, 1.167291, 0.017806},{
      0.860536, 1.161789, 0.017806},{0.858095, 1.160996, 0.014801}}],
    Polygon[{{0.859664, 1.167291, 0.017806},{0.862669, 1.167291, 0.020372},{
      0.863393, 1.162717, 0.020372},{0.860536, 1.161789, 0.017806}}],
    Polygon[{{0.862669, 1.167291, 0.020372},{0.866038, 1.167291, 0.022436},{
      0.866597, 1.163758, 0.022436},{0.863393, 1.162717, 0.020372}}],
    Polygon[{{0.866038, 1.167291, 0.022436},{0.869688, 1.167291, 0.023948},{
      0.870069, 1.164886, 0.023948},{0.866597, 1.163758, 0.022436}}],
    Polygon[{{0.869688, 1.167291, 0.023948},{0.873531, 1.167291, 0.024871},{
      0.873723, 1.166074, 0.024871},{0.870069, 1.164886, 0.023948}}],
    Polygon[{{0.873723, 1.166074, -0.024871},{0.870069, 1.164886, -0.023948},{
      0.871174, 1.162717, -0.023948},{0.874283, 1.164976, -0.024871}}],
    Polygon[{{0.870069, 1.164886, -0.023948},{0.866597, 1.163758, -0.022436},{
      0.868221, 1.160571, -0.022436},{0.871174, 1.162717, -0.023948}}],
    Polygon[{{0.866597, 1.163758, -0.022436},{0.863393, 1.162717, -0.020372},{
      0.865495, 1.158591, -0.020372},{0.868221, 1.160571, -0.022436}}],
    Polygon[{{0.863393, 1.162717, -0.020372},{0.860536, 1.161789, -0.017806},{
      0.863065, 1.156825, -0.017806},{0.865495, 1.158591, -0.020372}}],
    Polygon[{{0.860536, 1.161789, -0.017806},{0.858095, 1.160996, -0.014801},{
      0.860989, 1.155317, -0.014801},{0.863065, 1.156825, -0.017806}}],
    Polygon[{{0.858095, 1.160996, -0.014801},{0.856131, 1.160358, -0.011432},{
      0.859318, 1.154103, -0.011432},{0.860989, 1.155317, -0.014801}}],
    Polygon[{{0.856131, 1.160358, -0.011432},{0.854693, 1.159891, -0.007781},{
      0.858095, 1.153214, -0.007781},{0.859318, 1.154103, -0.011432}}],
    Polygon[{{0.854693, 1.159891, -0.007781},{0.853816, 1.159605, -0.003939},{
      0.857349, 1.152672, -0.003939},{0.858095, 1.153214, -0.007781}}],
    Polygon[{{0.853816, 1.159605, -0.003939},{0.853521, 1.159510, 0.000000},{
      0.857098, 1.152490, 0.000000},{0.857349, 1.152672, -0.003939}}],
    Polygon[{{0.853521, 1.159510, 0.000000},{0.853816, 1.159605, 0.003939},{
      0.857349, 1.152672, 0.003939},{0.857098, 1.152490, 0.000000}}],
    Polygon[{{0.853816, 1.159605, 0.003939},{0.854693, 1.159891, 0.007781},{
      0.858095, 1.153214, 0.007781},{0.857349, 1.152672, 0.003939}}],
    Polygon[{{0.854693, 1.159891, 0.007781},{0.856131, 1.160358, 0.011432},{
      0.859318, 1.154103, 0.011432},{0.858095, 1.153214, 0.007781}}],
    Polygon[{{0.856131, 1.160358, 0.011432},{0.858095, 1.160996, 0.014801},{
      0.860989, 1.155317, 0.014801},{0.859318, 1.154103, 0.011432}}],
    Polygon[{{0.858095, 1.160996, 0.014801},{0.860536, 1.161789, 0.017806},{
      0.863065, 1.156825, 0.017806},{0.860989, 1.155317, 0.014801}}],
    Polygon[{{0.860536, 1.161789, 0.017806},{0.863393, 1.162717, 0.020372},{
      0.865495, 1.158591, 0.020372},{0.863065, 1.156825, 0.017806}}],
    Polygon[{{0.863393, 1.162717, 0.020372},{0.866597, 1.163758, 0.022436},{
      0.868221, 1.160571, 0.022436},{0.865495, 1.158591, 0.020372}}],
    Polygon[{{0.866597, 1.163758, 0.022436},{0.870069, 1.164886, 0.023948},{
      0.871174, 1.162717, 0.023948},{0.868221, 1.160571, 0.022436}}],
    Polygon[{{0.870069, 1.164886, 0.023948},{0.873723, 1.166074, 0.024871},{
      0.874283, 1.164976, 0.024871},{0.871174, 1.162717, 0.023948}}],
    Polygon[{{0.874283, 1.164976, -0.024871},{0.871174, 1.162717, -0.023948},{
      0.872896, 1.160996, -0.023948},{0.875154, 1.164104, -0.024871}}],
    Polygon[{{0.871174, 1.162717, -0.023948},{0.868221, 1.160571, -0.022436},{
      0.870750, 1.158042, -0.022436},{0.872896, 1.160996, -0.023948}}],
    Polygon[{{0.868221, 1.160571, -0.022436},{0.865495, 1.158591, -0.020372},{
      0.868770, 1.155317, -0.020372},{0.870750, 1.158042, -0.022436}}],
    Polygon[{{0.865495, 1.158591, -0.020372},{0.863065, 1.156825, -0.017806},{
      0.867004, 1.152886, -0.017806},{0.868770, 1.155317, -0.020372}}],
    Polygon[{{0.863065, 1.156825, -0.017806},{0.860989, 1.155317, -0.014801},{
      0.865495, 1.150810, -0.014801},{0.867004, 1.152886, -0.017806}}],
    Polygon[{{0.860989, 1.155317, -0.014801},{0.859318, 1.154103, -0.011432},{
      0.864282, 1.149140, -0.011432},{0.865495, 1.150810, -0.014801}}],
    Polygon[{{0.859318, 1.154103, -0.011432},{0.858095, 1.153214, -0.007781},{
      0.863393, 1.147916, -0.007781},{0.864282, 1.149140, -0.011432}}],
    Polygon[{{0.858095, 1.153214, -0.007781},{0.857349, 1.152672, -0.003939},{
      0.862851, 1.147170, -0.003939},{0.863393, 1.147916, -0.007781}}],
    Polygon[{{0.857349, 1.152672, -0.003939},{0.857098, 1.152490, 0.000000},{
      0.862669, 1.146919, 0.000000},{0.862851, 1.147170, -0.003939}}],
    Polygon[{{0.857098, 1.152490, 0.000000},{0.857349, 1.152672, 0.003939},{
      0.862851, 1.147170, 0.003939},{0.862669, 1.146919, 0.000000}}],
    Polygon[{{0.857349, 1.152672, 0.003939},{0.858095, 1.153214, 0.007781},{
      0.863393, 1.147916, 0.007781},{0.862851, 1.147170, 0.003939}}],
    Polygon[{{0.858095, 1.153214, 0.007781},{0.859318, 1.154103, 0.011432},{
      0.864282, 1.149140, 0.011432},{0.863393, 1.147916, 0.007781}}],
    Polygon[{{0.859318, 1.154103, 0.011432},{0.860989, 1.155317, 0.014801},{
      0.865495, 1.150810, 0.014801},{0.864282, 1.149140, 0.011432}}],
    Polygon[{{0.860989, 1.155317, 0.014801},{0.863065, 1.156825, 0.017806},{
      0.867004, 1.152886, 0.017806},{0.865495, 1.150810, 0.014801}}],
    Polygon[{{0.863065, 1.156825, 0.017806},{0.865495, 1.158591, 0.020372},{
      0.868770, 1.155317, 0.020372},{0.867004, 1.152886, 0.017806}}],
    Polygon[{{0.865495, 1.158591, 0.020372},{0.868221, 1.160571, 0.022436},{
      0.870750, 1.158042, 0.022436},{0.868770, 1.155317, 0.020372}}],
    Polygon[{{0.868221, 1.160571, 0.022436},{0.871174, 1.162717, 0.023948},{
      0.872896, 1.160996, 0.023948},{0.870750, 1.158042, 0.022436}}],
    Polygon[{{0.871174, 1.162717, 0.023948},{0.874283, 1.164976, 0.024871},{
      0.875154, 1.164104, 0.024871},{0.872896, 1.160996, 0.023948}}],
    Polygon[{{0.875154, 1.164104, -0.024871},{0.872896, 1.160996, -0.023948},{
      0.875065, 1.159891, -0.023948},{0.876252, 1.163545, -0.024871}}],
    Polygon[{{0.872896, 1.160996, -0.023948},{0.870750, 1.158042, -0.022436},{
      0.873937, 1.156419, -0.022436},{0.875065, 1.159891, -0.023948}}],
    Polygon[{{0.870750, 1.158042, -0.022436},{0.868770, 1.155317, -0.020372},{
      0.872896, 1.153214, -0.020372},{0.873937, 1.156419, -0.022436}}],
    Polygon[{{0.868770, 1.155317, -0.020372},{0.867004, 1.152886, -0.017806},{
      0.871967, 1.150357, -0.017806},{0.872896, 1.153214, -0.020372}}],
    Polygon[{{0.867004, 1.152886, -0.017806},{0.865495, 1.150810, -0.014801},{
      0.871174, 1.147916, -0.014801},{0.871967, 1.150357, -0.017806}}],
    Polygon[{{0.865495, 1.150810, -0.014801},{0.864282, 1.149140, -0.011432},{
      0.870536, 1.145953, -0.011432},{0.871174, 1.147916, -0.014801}}],
    Polygon[{{0.864282, 1.149140, -0.011432},{0.863393, 1.147916, -0.007781},{
      0.870069, 1.144515, -0.007781},{0.870536, 1.145953, -0.011432}}],
    Polygon[{{0.863393, 1.147916, -0.007781},{0.862851, 1.147170, -0.003939},{
      0.869784, 1.143637, -0.003939},{0.870069, 1.144515, -0.007781}}],
    Polygon[{{0.862851, 1.147170, -0.003939},{0.862669, 1.146919, 0.000000},{
      0.869688, 1.143343, 0.000000},{0.869784, 1.143637, -0.003939}}],
    Polygon[{{0.862669, 1.146919, 0.000000},{0.862851, 1.147170, 0.003939},{
      0.869784, 1.143637, 0.003939},{0.869688, 1.143343, 0.000000}}],
    Polygon[{{0.862851, 1.147170, 0.003939},{0.863393, 1.147916, 0.007781},{
      0.870069, 1.144515, 0.007781},{0.869784, 1.143637, 0.003939}}],
    Polygon[{{0.863393, 1.147916, 0.007781},{0.864282, 1.149140, 0.011432},{
      0.870536, 1.145953, 0.011432},{0.870069, 1.144515, 0.007781}}],
    Polygon[{{0.864282, 1.149140, 0.011432},{0.865495, 1.150810, 0.014801},{
      0.871174, 1.147916, 0.014801},{0.870536, 1.145953, 0.011432}}],
    Polygon[{{0.865495, 1.150810, 0.014801},{0.867004, 1.152886, 0.017806},{
      0.871967, 1.150357, 0.017806},{0.871174, 1.147916, 0.014801}}],
    Polygon[{{0.867004, 1.152886, 0.017806},{0.868770, 1.155317, 0.020372},{
      0.872896, 1.153214, 0.020372},{0.871967, 1.150357, 0.017806}}],
    Polygon[{{0.868770, 1.155317, 0.020372},{0.870750, 1.158042, 0.022436},{
      0.873937, 1.156419, 0.022436},{0.872896, 1.153214, 0.020372}}],
    Polygon[{{0.870750, 1.158042, 0.022436},{0.872896, 1.160996, 0.023948},{
      0.875065, 1.159891, 0.023948},{0.873937, 1.156419, 0.022436}}],
    Polygon[{{0.872896, 1.160996, 0.023948},{0.875154, 1.164104, 0.024871},{
      0.876252, 1.163545, 0.024871},{0.875065, 1.159891, 0.023948}}],
    Polygon[{{0.876252, 1.163545, -0.024871},{0.875065, 1.159891, -0.023948},{
      0.877470, 1.159510, -0.023948},{0.877470, 1.163352, -0.024871}}],
    Polygon[{{0.875065, 1.159891, -0.023948},{0.873937, 1.156419, -0.022436},{
      0.877470, 1.155859, -0.022436},{0.877470, 1.159510, -0.023948}}],
    Polygon[{{0.873937, 1.156419, -0.022436},{0.872896, 1.153214, -0.020372},{
      0.877470, 1.152490, -0.020372},{0.877470, 1.155859, -0.022436}}],
    Polygon[{{0.872896, 1.153214, -0.020372},{0.871967, 1.150357, -0.017806},{
      0.877470, 1.149485, -0.017806},{0.877470, 1.152490, -0.020372}}],
    Polygon[{{0.871967, 1.150357, -0.017806},{0.871174, 1.147916, -0.014801},{
      0.877470, 1.146919, -0.014801},{0.877470, 1.149485, -0.017806}}],
    Polygon[{{0.871174, 1.147916, -0.014801},{0.870536, 1.145953, -0.011432},{
      0.877470, 1.144855, -0.011432},{0.877470, 1.146919, -0.014801}}],
    Polygon[{{0.870536, 1.145953, -0.011432},{0.870069, 1.144515, -0.007781},{
      0.877470, 1.143343, -0.007781},{0.877470, 1.144855, -0.011432}}],
    Polygon[{{0.870069, 1.144515, -0.007781},{0.869784, 1.143637, -0.003939},{
      0.877470, 1.142420, -0.003939},{0.877470, 1.143343, -0.007781}}],
    Polygon[{{0.869784, 1.143637, -0.003939},{0.869688, 1.143343, 0.000000},{
      0.877470, 1.142110, 0.000000},{0.877470, 1.142420, -0.003939}}],
    Polygon[{{0.869688, 1.143343, 0.000000},{0.869784, 1.143637, 0.003939},{
      0.877470, 1.142420, 0.003939},{0.877470, 1.142110, 0.000000}}],
    Polygon[{{0.869784, 1.143637, 0.003939},{0.870069, 1.144515, 0.007781},{
      0.877470, 1.143343, 0.007781},{0.877470, 1.142420, 0.003939}}],
    Polygon[{{0.870069, 1.144515, 0.007781},{0.870536, 1.145953, 0.011432},{
      0.877470, 1.144855, 0.011432},{0.877470, 1.143343, 0.007781}}],
    Polygon[{{0.870536, 1.145953, 0.011432},{0.871174, 1.147916, 0.014801},{
      0.877470, 1.146919, 0.014801},{0.877470, 1.144855, 0.011432}}],
    Polygon[{{0.871174, 1.147916, 0.014801},{0.871967, 1.150357, 0.017806},{
      0.877470, 1.149485, 0.017806},{0.877470, 1.146919, 0.014801}}],
    Polygon[{{0.871967, 1.150357, 0.017806},{0.872896, 1.153214, 0.020372},{
      0.877470, 1.152490, 0.020372},{0.877470, 1.149485, 0.017806}}],
    Polygon[{{0.872896, 1.153214, 0.020372},{0.873937, 1.156419, 0.022436},{
      0.877470, 1.155859, 0.022436},{0.877470, 1.152490, 0.020372}}],
    Polygon[{{0.873937, 1.156419, 0.022436},{0.875065, 1.159891, 0.023948},{
      0.877470, 1.159510, 0.023948},{0.877470, 1.155859, 0.022436}}],
    Polygon[{{0.875065, 1.159891, 0.023948},{0.876252, 1.163545, 0.024871},{
      0.877470, 1.163352, 0.024871},{0.877470, 1.159510, 0.023948}}],
    Polygon[{{0.877470, 1.163352, -0.024871},{0.877470, 1.159510, -0.023948},{
      0.879874, 1.159891, -0.023948},{0.878687, 1.163545, -0.024871}}],
    Polygon[{{0.877470, 1.159510, -0.023948},{0.877470, 1.155859, -0.022436},{
      0.881002, 1.156419, -0.022436},{0.879874, 1.159891, -0.023948}}],
    Polygon[{{0.877470, 1.155859, -0.022436},{0.877470, 1.152490, -0.020372},{
      0.882043, 1.153214, -0.020372},{0.881002, 1.156419, -0.022436}}],
    Polygon[{{0.877470, 1.152490, -0.020372},{0.877470, 1.149485, -0.017806},{
      0.882972, 1.150357, -0.017806},{0.882043, 1.153214, -0.020372}}],
    Polygon[{{0.877470, 1.149485, -0.017806},{0.877470, 1.146919, -0.014801},{
      0.883765, 1.147916, -0.014801},{0.882972, 1.150357, -0.017806}}],
    Polygon[{{0.877470, 1.146919, -0.014801},{0.877470, 1.144855, -0.011432},{
      0.884403, 1.145953, -0.011432},{0.883765, 1.147916, -0.014801}}],
    Polygon[{{0.877470, 1.144855, -0.011432},{0.877470, 1.143343, -0.007781},{
      0.884870, 1.144515, -0.007781},{0.884403, 1.145953, -0.011432}}],
    Polygon[{{0.877470, 1.143343, -0.007781},{0.877470, 1.142420, -0.003939},{
      0.885155, 1.143637, -0.003939},{0.884870, 1.144515, -0.007781}}],
    Polygon[{{0.877470, 1.142420, -0.003939},{0.877470, 1.142110, 0.000000},{
      0.885251, 1.143343, 0.000000},{0.885155, 1.143637, -0.003939}}],
    Polygon[{{0.877470, 1.142110, 0.000000},{0.877470, 1.142420, 0.003939},{
      0.885155, 1.143637, 0.003939},{0.885251, 1.143343, 0.000000}}],
    Polygon[{{0.877470, 1.142420, 0.003939},{0.877470, 1.143343, 0.007781},{
      0.884870, 1.144515, 0.007781},{0.885155, 1.143637, 0.003939}}],
    Polygon[{{0.877470, 1.143343, 0.007781},{0.877470, 1.144855, 0.011432},{
      0.884403, 1.145953, 0.011432},{0.884870, 1.144515, 0.007781}}],
    Polygon[{{0.877470, 1.144855, 0.011432},{0.877470, 1.146919, 0.014801},{
      0.883765, 1.147916, 0.014801},{0.884403, 1.145953, 0.011432}}],
    Polygon[{{0.877470, 1.146919, 0.014801},{0.877470, 1.149485, 0.017806},{
      0.882972, 1.150357, 0.017806},{0.883765, 1.147916, 0.014801}}],
    Polygon[{{0.877470, 1.149485, 0.017806},{0.877470, 1.152490, 0.020372},{
      0.882043, 1.153214, 0.020372},{0.882972, 1.150357, 0.017806}}],
    Polygon[{{0.877470, 1.152490, 0.020372},{0.877470, 1.155859, 0.022436},{
      0.881002, 1.156419, 0.022436},{0.882043, 1.153214, 0.020372}}],
    Polygon[{{0.877470, 1.155859, 0.022436},{0.877470, 1.159510, 0.023948},{
      0.879874, 1.159891, 0.023948},{0.881002, 1.156419, 0.022436}}],
    Polygon[{{0.877470, 1.159510, 0.023948},{0.877470, 1.163352, 0.024871},{
      0.878687, 1.163545, 0.024871},{0.879874, 1.159891, 0.023948}}],
    Polygon[{{0.878687, 1.163545, -0.024871},{0.879874, 1.159891, -0.023948},{
      0.882043, 1.160996, -0.023948},{0.879785, 1.164104, -0.024871}}],
    Polygon[{{0.879874, 1.159891, -0.023948},{0.881002, 1.156419, -0.022436},{
      0.884189, 1.158042, -0.022436},{0.882043, 1.160996, -0.023948}}],
    Polygon[{{0.881002, 1.156419, -0.022436},{0.882043, 1.153214, -0.020372},{
      0.886169, 1.155317, -0.020372},{0.884189, 1.158042, -0.022436}}],
    Polygon[{{0.882043, 1.153214, -0.020372},{0.882972, 1.150357, -0.017806},{
      0.887935, 1.152886, -0.017806},{0.886169, 1.155317, -0.020372}}],
    Polygon[{{0.882972, 1.150357, -0.017806},{0.883765, 1.147916, -0.014801},{
      0.889444, 1.150810, -0.014801},{0.887935, 1.152886, -0.017806}}],
    Polygon[{{0.883765, 1.147916, -0.014801},{0.884403, 1.145953, -0.011432},{
      0.890657, 1.149140, -0.011432},{0.889444, 1.150810, -0.014801}}],
    Polygon[{{0.884403, 1.145953, -0.011432},{0.884870, 1.144515, -0.007781},{
      0.891546, 1.147916, -0.007781},{0.890657, 1.149140, -0.011432}}],
    Polygon[{{0.884870, 1.144515, -0.007781},{0.885155, 1.143637, -0.003939},{
      0.892088, 1.147170, -0.003939},{0.891546, 1.147916, -0.007781}}],
    Polygon[{{0.885155, 1.143637, -0.003939},{0.885251, 1.143343, 0.000000},{
      0.892271, 1.146919, 0.000000},{0.892088, 1.147170, -0.003939}}],
    Polygon[{{0.885251, 1.143343, 0.000000},{0.885155, 1.143637, 0.003939},{
      0.892088, 1.147170, 0.003939},{0.892271, 1.146919, 0.000000}}],
    Polygon[{{0.885155, 1.143637, 0.003939},{0.884870, 1.144515, 0.007781},{
      0.891546, 1.147916, 0.007781},{0.892088, 1.147170, 0.003939}}],
    Polygon[{{0.884870, 1.144515, 0.007781},{0.884403, 1.145953, 0.011432},{
      0.890657, 1.149140, 0.011432},{0.891546, 1.147916, 0.007781}}],
    Polygon[{{0.884403, 1.145953, 0.011432},{0.883765, 1.147916, 0.014801},{
      0.889444, 1.150810, 0.014801},{0.890657, 1.149140, 0.011432}}],
    Polygon[{{0.883765, 1.147916, 0.014801},{0.882972, 1.150357, 0.017806},{
      0.887935, 1.152886, 0.017806},{0.889444, 1.150810, 0.014801}}],
    Polygon[{{0.882972, 1.150357, 0.017806},{0.882043, 1.153214, 0.020372},{
      0.886169, 1.155317, 0.020372},{0.887935, 1.152886, 0.017806}}],
    Polygon[{{0.882043, 1.153214, 0.020372},{0.881002, 1.156419, 0.022436},{
      0.884189, 1.158042, 0.022436},{0.886169, 1.155317, 0.020372}}],
    Polygon[{{0.881002, 1.156419, 0.022436},{0.879874, 1.159891, 0.023948},{
      0.882043, 1.160996, 0.023948},{0.884189, 1.158042, 0.022436}}],
    Polygon[{{0.879874, 1.159891, 0.023948},{0.878687, 1.163545, 0.024871},{
      0.879785, 1.164104, 0.024871},{0.882043, 1.160996, 0.023948}}],
    Polygon[{{0.879785, 1.164104, -0.024871},{0.882043, 1.160996, -0.023948},{
      0.883765, 1.162717, -0.023948},{0.880656, 1.164976, -0.024871}}],
    Polygon[{{0.882043, 1.160996, -0.023948},{0.884189, 1.158042, -0.022436},{
      0.886718, 1.160571, -0.022436},{0.883765, 1.162717, -0.023948}}],
    Polygon[{{0.884189, 1.158042, -0.022436},{0.886169, 1.155317, -0.020372},{
      0.889444, 1.158591, -0.020372},{0.886718, 1.160571, -0.022436}}],
    Polygon[{{0.886169, 1.155317, -0.020372},{0.887935, 1.152886, -0.017806},{
      0.891875, 1.156825, -0.017806},{0.889444, 1.158591, -0.020372}}],
    Polygon[{{0.887935, 1.152886, -0.017806},{0.889444, 1.150810, -0.014801},{
      0.893951, 1.155317, -0.014801},{0.891875, 1.156825, -0.017806}}],
    Polygon[{{0.889444, 1.150810, -0.014801},{0.890657, 1.149140, -0.011432},{
      0.895621, 1.154103, -0.011432},{0.893951, 1.155317, -0.014801}}],
    Polygon[{{0.890657, 1.149140, -0.011432},{0.891546, 1.147916, -0.007781},{
      0.896844, 1.153214, -0.007781},{0.895621, 1.154103, -0.011432}}],
    Polygon[{{0.891546, 1.147916, -0.007781},{0.892088, 1.147170, -0.003939},{
      0.897591, 1.152672, -0.003939},{0.896844, 1.153214, -0.007781}}],
    Polygon[{{0.892088, 1.147170, -0.003939},{0.892271, 1.146919, 0.000000},{
      0.897841, 1.152490, 0.000000},{0.897591, 1.152672, -0.003939}}],
    Polygon[{{0.892271, 1.146919, 0.000000},{0.892088, 1.147170, 0.003939},{
      0.897591, 1.152672, 0.003939},{0.897841, 1.152490, 0.000000}}],
    Polygon[{{0.892088, 1.147170, 0.003939},{0.891546, 1.147916, 0.007781},{
      0.896844, 1.153214, 0.007781},{0.897591, 1.152672, 0.003939}}],
    Polygon[{{0.891546, 1.147916, 0.007781},{0.890657, 1.149140, 0.011432},{
      0.895621, 1.154103, 0.011432},{0.896844, 1.153214, 0.007781}}],
    Polygon[{{0.890657, 1.149140, 0.011432},{0.889444, 1.150810, 0.014801},{
      0.893951, 1.155317, 0.014801},{0.895621, 1.154103, 0.011432}}],
    Polygon[{{0.889444, 1.150810, 0.014801},{0.887935, 1.152886, 0.017806},{
      0.891875, 1.156825, 0.017806},{0.893951, 1.155317, 0.014801}}],
    Polygon[{{0.887935, 1.152886, 0.017806},{0.886169, 1.155317, 0.020372},{
      0.889444, 1.158591, 0.020372},{0.891875, 1.156825, 0.017806}}],
    Polygon[{{0.886169, 1.155317, 0.020372},{0.884189, 1.158042, 0.022436},{
      0.886718, 1.160571, 0.022436},{0.889444, 1.158591, 0.020372}}],
    Polygon[{{0.884189, 1.158042, 0.022436},{0.882043, 1.160996, 0.023948},{
      0.883765, 1.162717, 0.023948},{0.886718, 1.160571, 0.022436}}],
    Polygon[{{0.882043, 1.160996, 0.023948},{0.879785, 1.164104, 0.024871},{
      0.880656, 1.164976, 0.024871},{0.883765, 1.162717, 0.023948}}],
    Polygon[{{0.880656, 1.164976, -0.024871},{0.883765, 1.162717, -0.023948},{
      0.884870, 1.164886, -0.023948},{0.881216, 1.166074, -0.024871}}],
    Polygon[{{0.883765, 1.162717, -0.023948},{0.886718, 1.160571, -0.022436},{
      0.888342, 1.163758, -0.022436},{0.884870, 1.164886, -0.023948}}],
    Polygon[{{0.886718, 1.160571, -0.022436},{0.889444, 1.158591, -0.020372},{
      0.891546, 1.162717, -0.020372},{0.888342, 1.163758, -0.022436}}],
    Polygon[{{0.889444, 1.158591, -0.020372},{0.891875, 1.156825, -0.017806},{
      0.894404, 1.161789, -0.017806},{0.891546, 1.162717, -0.020372}}],
    Polygon[{{0.891875, 1.156825, -0.017806},{0.893951, 1.155317, -0.014801},{
      0.896844, 1.160996, -0.014801},{0.894404, 1.161789, -0.017806}}],
    Polygon[{{0.893951, 1.155317, -0.014801},{0.895621, 1.154103, -0.011432},{
      0.898808, 1.160358, -0.011432},{0.896844, 1.160996, -0.014801}}],
    Polygon[{{0.895621, 1.154103, -0.011432},{0.896844, 1.153214, -0.007781},{
      0.900246, 1.159891, -0.007781},{0.898808, 1.160358, -0.011432}}],
    Polygon[{{0.896844, 1.153214, -0.007781},{0.897591, 1.152672, -0.003939},{
      0.901123, 1.159605, -0.003939},{0.900246, 1.159891, -0.007781}}],
    Polygon[{{0.897591, 1.152672, -0.003939},{0.897841, 1.152490, 0.000000},{
      0.901418, 1.159510, 0.000000},{0.901123, 1.159605, -0.003939}}],
    Polygon[{{0.897841, 1.152490, 0.000000},{0.897591, 1.152672, 0.003939},{
      0.901123, 1.159605, 0.003939},{0.901418, 1.159510, 0.000000}}],
    Polygon[{{0.897591, 1.152672, 0.003939},{0.896844, 1.153214, 0.007781},{
      0.900246, 1.159891, 0.007781},{0.901123, 1.159605, 0.003939}}],
    Polygon[{{0.896844, 1.153214, 0.007781},{0.895621, 1.154103, 0.011432},{
      0.898808, 1.160358, 0.011432},{0.900246, 1.159891, 0.007781}}],
    Polygon[{{0.895621, 1.154103, 0.011432},{0.893951, 1.155317, 0.014801},{
      0.896844, 1.160996, 0.014801},{0.898808, 1.160358, 0.011432}}],
    Polygon[{{0.893951, 1.155317, 0.014801},{0.891875, 1.156825, 0.017806},{
      0.894404, 1.161789, 0.017806},{0.896844, 1.160996, 0.014801}}],
    Polygon[{{0.891875, 1.156825, 0.017806},{0.889444, 1.158591, 0.020372},{
      0.891546, 1.162717, 0.020372},{0.894404, 1.161789, 0.017806}}],
    Polygon[{{0.889444, 1.158591, 0.020372},{0.886718, 1.160571, 0.022436},{
      0.888342, 1.163758, 0.022436},{0.891546, 1.162717, 0.020372}}],
    Polygon[{{0.886718, 1.160571, 0.022436},{0.883765, 1.162717, 0.023948},{
      0.884870, 1.164886, 0.023948},{0.888342, 1.163758, 0.022436}}],
    Polygon[{{0.883765, 1.162717, 0.023948},{0.880656, 1.164976, 0.024871},{
      0.881216, 1.166074, 0.024871},{0.884870, 1.164886, 0.023948}}],
    Polygon[{{0.881216, 1.166074, -0.024871},{0.884870, 1.164886, -0.023948},{
      0.885251, 1.167291, -0.023948},{0.881409, 1.167291, -0.024871}}],
    Polygon[{{0.884870, 1.164886, -0.023948},{0.888342, 1.163758, -0.022436},{
      0.888901, 1.167291, -0.022436},{0.885251, 1.167291, -0.023948}}],
    Polygon[{{0.888342, 1.163758, -0.022436},{0.891546, 1.162717, -0.020372},{
      0.892271, 1.167291, -0.020372},{0.888901, 1.167291, -0.022436}}],
    Polygon[{{0.891546, 1.162717, -0.020372},{0.894404, 1.161789, -0.017806},{
      0.895275, 1.167291, -0.017806},{0.892271, 1.167291, -0.020372}}],
    Polygon[{{0.894404, 1.161789, -0.017806},{0.896844, 1.160996, -0.014801},{
      0.897841, 1.167291, -0.014801},{0.895275, 1.167291, -0.017806}}],
    Polygon[{{0.896844, 1.160996, -0.014801},{0.898808, 1.160358, -0.011432},{
      0.899906, 1.167291, -0.011432},{0.897841, 1.167291, -0.014801}}],
    Polygon[{{0.898808, 1.160358, -0.011432},{0.900246, 1.159891, -0.007781},{
      0.901418, 1.167291, -0.007781},{0.899906, 1.167291, -0.011432}}],
    Polygon[{{0.900246, 1.159891, -0.007781},{0.901123, 1.159605, -0.003939},{
      0.902340, 1.167291, -0.003939},{0.901418, 1.167291, -0.007781}}],
    Polygon[{{0.901123, 1.159605, -0.003939},{0.901418, 1.159510, 0.000000},{
      0.902650, 1.167291, 0.000000},{0.902340, 1.167291, -0.003939}}],
    Polygon[{{0.901418, 1.159510, 0.000000},{0.901123, 1.159605, 0.003939},{
      0.902340, 1.167291, 0.003939},{0.902650, 1.167291, 0.000000}}],
    Polygon[{{0.901123, 1.159605, 0.003939},{0.900246, 1.159891, 0.007781},{
      0.901418, 1.167291, 0.007781},{0.902340, 1.167291, 0.003939}}],
    Polygon[{{0.900246, 1.159891, 0.007781},{0.898808, 1.160358, 0.011432},{
      0.899906, 1.167291, 0.011432},{0.901418, 1.167291, 0.007781}}],
    Polygon[{{0.898808, 1.160358, 0.011432},{0.896844, 1.160996, 0.014801},{
      0.897841, 1.167291, 0.014801},{0.899906, 1.167291, 0.011432}}],
    Polygon[{{0.896844, 1.160996, 0.014801},{0.894404, 1.161789, 0.017806},{
      0.895275, 1.167291, 0.017806},{0.897841, 1.167291, 0.014801}}],
    Polygon[{{0.894404, 1.161789, 0.017806},{0.891546, 1.162717, 0.020372},{
      0.892271, 1.167291, 0.020372},{0.895275, 1.167291, 0.017806}}],
    Polygon[{{0.891546, 1.162717, 0.020372},{0.888342, 1.163758, 0.022436},{
      0.888901, 1.167291, 0.022436},{0.892271, 1.167291, 0.020372}}],
    Polygon[{{0.888342, 1.163758, 0.022436},{0.884870, 1.164886, 0.023948},{
      0.885251, 1.167291, 0.023948},{0.888901, 1.167291, 0.022436}}],
    Polygon[{{0.884870, 1.164886, 0.023948},{0.881216, 1.166074, 0.024871},{
      0.881409, 1.167291, 0.024871},{0.885251, 1.167291, 0.023948}}],
    Polygon[{{0.916499, 1.160923, -0.012292},{0.918398, 1.160923, -0.011836},{
      0.918210, 1.162111, -0.011836},{0.916404, 1.161525, -0.012292}}],
    Polygon[{{0.918398, 1.160923, -0.011836},{0.920202, 1.160923, -0.011089},{
      0.919926, 1.162669, -0.011089},{0.918210, 1.162111, -0.011836}}],
    Polygon[{{0.920202, 1.160923, -0.011089},{0.921868, 1.160923, -0.010068},{
      0.921510, 1.163183, -0.010068},{0.919926, 1.162669, -0.011089}}],
    Polygon[{{0.921868, 1.160923, -0.010068},{0.923353, 1.160923, -0.008800},{
      0.922922, 1.163642, -0.008800},{0.921510, 1.163183, -0.010068}}],
    Polygon[{{0.923353, 1.160923, -0.008800},{0.924621, 1.160923, -0.007315},{
      0.924128, 1.164034, -0.007315},{0.922922, 1.163642, -0.008800}}],
    Polygon[{{0.924621, 1.160923, -0.007315},{0.925641, 1.160923, -0.005650},{
      0.925098, 1.164350, -0.005650},{0.924128, 1.164034, -0.007315}}],
    Polygon[{{0.925641, 1.160923, -0.005650},{0.926388, 1.160923, -0.003846},{
      0.925809, 1.164580, -0.003846},{0.925098, 1.164350, -0.005650}}],
    Polygon[{{0.926388, 1.160923, -0.003846},{0.926844, 1.160923, -0.001947},{
      0.926243, 1.164721, -0.001947},{0.925809, 1.164580, -0.003846}}],
    Polygon[{{0.926844, 1.160923, -0.001947},{0.926998, 1.160923, 0.000000},{
      0.926388, 1.164769, 0.000000},{0.926243, 1.164721, -0.001947}}],
    Polygon[{{0.926998, 1.160923, 0.000000},{0.926844, 1.160923, 0.001947},{
      0.926243, 1.164721, 0.001947},{0.926388, 1.164769, 0.000000}}],
    Polygon[{{0.926844, 1.160923, 0.001947},{0.926388, 1.160923, 0.003846},{
      0.925809, 1.164580, 0.003846},{0.926243, 1.164721, 0.001947}}],
    Polygon[{{0.926388, 1.160923, 0.003846},{0.925641, 1.160923, 0.005650},{
      0.925098, 1.164350, 0.005650},{0.925809, 1.164580, 0.003846}}],
    Polygon[{{0.925641, 1.160923, 0.005650},{0.924621, 1.160923, 0.007315},{
      0.924128, 1.164034, 0.007315},{0.925098, 1.164350, 0.005650}}],
    Polygon[{{0.924621, 1.160923, 0.007315},{0.923353, 1.160923, 0.008800},{
      0.922922, 1.163642, 0.008800},{0.924128, 1.164034, 0.007315}}],
    Polygon[{{0.923353, 1.160923, 0.008800},{0.921868, 1.160923, 0.010068},{
      0.921510, 1.163183, 0.010068},{0.922922, 1.163642, 0.008800}}],
    Polygon[{{0.921868, 1.160923, 0.010068},{0.920202, 1.160923, 0.011089},{
      0.919926, 1.162669, 0.011089},{0.921510, 1.163183, 0.010068}}],
    Polygon[{{0.920202, 1.160923, 0.011089},{0.918398, 1.160923, 0.011836},{
      0.918210, 1.162111, 0.011836},{0.919926, 1.162669, 0.011089}}],
    Polygon[{{0.918398, 1.160923, 0.011836},{0.916499, 1.160923, 0.012292},{
      0.916404, 1.161525, 0.012292},{0.918210, 1.162111, 0.011836}}],
    Polygon[{{0.916404, 1.161525, -0.012292},{0.918210, 1.162111, -0.011836},{
      0.917664, 1.163183, -0.011836},{0.916128, 1.162067, -0.012292}}],
    Polygon[{{0.918210, 1.162111, -0.011836},{0.919926, 1.162669, -0.011089},{
      0.919123, 1.164244, -0.011089},{0.917664, 1.163183, -0.011836}}],
    Polygon[{{0.919926, 1.162669, -0.011089},{0.921510, 1.163183, -0.010068},{
      0.920471, 1.165223, -0.010068},{0.919123, 1.164244, -0.011089}}],
    Polygon[{{0.921510, 1.163183, -0.010068},{0.922922, 1.163642, -0.008800},{
      0.921672, 1.166095, -0.008800},{0.920471, 1.165223, -0.010068}}],
    Polygon[{{0.922922, 1.163642, -0.008800},{0.924128, 1.164034, -0.007315},{
      0.922698, 1.166841, -0.007315},{0.921672, 1.166095, -0.008800}}],
    Polygon[{{0.924128, 1.164034, -0.007315},{0.925098, 1.164350, -0.005650},{
      0.923523, 1.167441, -0.005650},{0.922698, 1.166841, -0.007315}}],
    Polygon[{{0.925098, 1.164350, -0.005650},{0.925809, 1.164580, -0.003846},{
      0.924128, 1.167880, -0.003846},{0.923523, 1.167441, -0.005650}}],
    Polygon[{{0.925809, 1.164580, -0.003846},{0.926243, 1.164721, -0.001947},{
      0.924497, 1.168148, -0.001947},{0.924128, 1.167880, -0.003846}}],
    Polygon[{{0.926243, 1.164721, -0.001947},{0.926388, 1.164769, 0.000000},{
      0.924621, 1.168238, 0.000000},{0.924497, 1.168148, -0.001947}}],
    Polygon[{{0.926388, 1.164769, 0.000000},{0.926243, 1.164721, 0.001947},{
      0.924497, 1.168148, 0.001947},{0.924621, 1.168238, 0.000000}}],
    Polygon[{{0.926243, 1.164721, 0.001947},{0.925809, 1.164580, 0.003846},{
      0.924128, 1.167880, 0.003846},{0.924497, 1.168148, 0.001947}}],
    Polygon[{{0.925809, 1.164580, 0.003846},{0.925098, 1.164350, 0.005650},{
      0.923523, 1.167441, 0.005650},{0.924128, 1.167880, 0.003846}}],
    Polygon[{{0.925098, 1.164350, 0.005650},{0.924128, 1.164034, 0.007315},{
      0.922698, 1.166841, 0.007315},{0.923523, 1.167441, 0.005650}}],
    Polygon[{{0.924128, 1.164034, 0.007315},{0.922922, 1.163642, 0.008800},{
      0.921672, 1.166095, 0.008800},{0.922698, 1.166841, 0.007315}}],
    Polygon[{{0.922922, 1.163642, 0.008800},{0.921510, 1.163183, 0.010068},{
      0.920471, 1.165223, 0.010068},{0.921672, 1.166095, 0.008800}}],
    Polygon[{{0.921510, 1.163183, 0.010068},{0.919926, 1.162669, 0.011089},{
      0.919123, 1.164244, 0.011089},{0.920471, 1.165223, 0.010068}}],
    Polygon[{{0.919926, 1.162669, 0.011089},{0.918210, 1.162111, 0.011836},{
      0.917664, 1.163183, 0.011836},{0.919123, 1.164244, 0.011089}}],
    Polygon[{{0.918210, 1.162111, 0.011836},{0.916404, 1.161525, 0.012292},{
      0.916128, 1.162067, 0.012292},{0.917664, 1.163183, 0.011836}}],
    Polygon[{{0.916128, 1.162067, -0.012292},{0.917664, 1.163183, -0.011836},{
      0.916813, 1.164034, -0.011836},{0.915697, 1.162498, -0.012292}}],
    Polygon[{{0.917664, 1.163183, -0.011836},{0.919123, 1.164244, -0.011089},{
      0.917874, 1.165494, -0.011089},{0.916813, 1.164034, -0.011836}}],
    Polygon[{{0.919123, 1.164244, -0.011089},{0.920471, 1.165223, -0.010068},{
      0.918852, 1.166841, -0.010068},{0.917874, 1.165494, -0.011089}}],
    Polygon[{{0.920471, 1.165223, -0.010068},{0.921672, 1.166095, -0.008800},{
      0.919725, 1.168042, -0.008800},{0.918852, 1.166841, -0.010068}}],
    Polygon[{{0.921672, 1.166095, -0.008800},{0.922698, 1.166841, -0.007315},{
      0.920471, 1.169068, -0.007315},{0.919725, 1.168042, -0.008800}}],
    Polygon[{{0.922698, 1.166841, -0.007315},{0.923523, 1.167441, -0.005650},{
      0.921070, 1.169894, -0.005650},{0.920471, 1.169068, -0.007315}}],
    Polygon[{{0.923523, 1.167441, -0.005650},{0.924128, 1.167880, -0.003846},{
      0.921510, 1.170498, -0.003846},{0.921070, 1.169894, -0.005650}}],
    Polygon[{{0.924128, 1.167880, -0.003846},{0.924497, 1.168148, -0.001947},{
      0.921777, 1.170867, -0.001947},{0.921510, 1.170498, -0.003846}}],
    Polygon[{{0.924497, 1.168148, -0.001947},{0.924621, 1.168238, 0.000000},{
      0.921868, 1.170991, 0.000000},{0.921777, 1.170867, -0.001947}}],
    Polygon[{{0.924621, 1.168238, 0.000000},{0.924497, 1.168148, 0.001947},{
      0.921777, 1.170867, 0.001947},{0.921868, 1.170991, 0.000000}}],
    Polygon[{{0.924497, 1.168148, 0.001947},{0.924128, 1.167880, 0.003846},{
      0.921510, 1.170498, 0.003846},{0.921777, 1.170867, 0.001947}}],
    Polygon[{{0.924128, 1.167880, 0.003846},{0.923523, 1.167441, 0.005650},{
      0.921070, 1.169894, 0.005650},{0.921510, 1.170498, 0.003846}}],
    Polygon[{{0.923523, 1.167441, 0.005650},{0.922698, 1.166841, 0.007315},{
      0.920471, 1.169068, 0.007315},{0.921070, 1.169894, 0.005650}}],
    Polygon[{{0.922698, 1.166841, 0.007315},{0.921672, 1.166095, 0.008800},{
      0.919725, 1.168042, 0.008800},{0.920471, 1.169068, 0.007315}}],
    Polygon[{{0.921672, 1.166095, 0.008800},{0.920471, 1.165223, 0.010068},{
      0.918852, 1.166841, 0.010068},{0.919725, 1.168042, 0.008800}}],
    Polygon[{{0.920471, 1.165223, 0.010068},{0.919123, 1.164244, 0.011089},{
      0.917874, 1.165494, 0.011089},{0.918852, 1.166841, 0.010068}}],
    Polygon[{{0.919123, 1.164244, 0.011089},{0.917664, 1.163183, 0.011836},{
      0.916813, 1.164034, 0.011836},{0.917874, 1.165494, 0.011089}}],
    Polygon[{{0.917664, 1.163183, 0.011836},{0.916128, 1.162067, 0.012292},{
      0.915697, 1.162498, 0.012292},{0.916813, 1.164034, 0.011836}}],
    Polygon[{{0.915697, 1.162498, -0.012292},{0.916813, 1.164034, -0.011836},{
      0.915741, 1.164580, -0.011836},{0.915154, 1.162775, -0.012292}}],
    Polygon[{{0.916813, 1.164034, -0.011836},{0.917874, 1.165494, -0.011089},{
      0.916299, 1.166296, -0.011089},{0.915741, 1.164580, -0.011836}}],
    Polygon[{{0.917874, 1.165494, -0.011089},{0.918852, 1.166841, -0.010068},{
      0.916813, 1.167880, -0.010068},{0.916299, 1.166296, -0.011089}}],
    Polygon[{{0.918852, 1.166841, -0.010068},{0.919725, 1.168042, -0.008800},{
      0.917272, 1.169292, -0.008800},{0.916813, 1.167880, -0.010068}}],
    Polygon[{{0.919725, 1.168042, -0.008800},{0.920471, 1.169068, -0.007315},{
      0.917664, 1.170498, -0.007315},{0.917272, 1.169292, -0.008800}}],
    Polygon[{{0.920471, 1.169068, -0.007315},{0.921070, 1.169894, -0.005650},{
      0.917979, 1.171469, -0.005650},{0.917664, 1.170498, -0.007315}}],
    Polygon[{{0.921070, 1.169894, -0.005650},{0.921510, 1.170498, -0.003846},{
      0.918210, 1.172180, -0.003846},{0.917979, 1.171469, -0.005650}}],
    Polygon[{{0.921510, 1.170498, -0.003846},{0.921777, 1.170867, -0.001947},{
      0.918351, 1.172613, -0.001947},{0.918210, 1.172180, -0.003846}}],
    Polygon[{{0.921777, 1.170867, -0.001947},{0.921868, 1.170991, 0.000000},{
      0.918398, 1.172759, 0.000000},{0.918351, 1.172613, -0.001947}}],
    Polygon[{{0.921868, 1.170991, 0.000000},{0.921777, 1.170867, 0.001947},{
      0.918351, 1.172613, 0.001947},{0.918398, 1.172759, 0.000000}}],
    Polygon[{{0.921777, 1.170867, 0.001947},{0.921510, 1.170498, 0.003846},{
      0.918210, 1.172180, 0.003846},{0.918351, 1.172613, 0.001947}}],
    Polygon[{{0.921510, 1.170498, 0.003846},{0.921070, 1.169894, 0.005650},{
      0.917979, 1.171469, 0.005650},{0.918210, 1.172180, 0.003846}}],
    Polygon[{{0.921070, 1.169894, 0.005650},{0.920471, 1.169068, 0.007315},{
      0.917664, 1.170498, 0.007315},{0.917979, 1.171469, 0.005650}}],
    Polygon[{{0.920471, 1.169068, 0.007315},{0.919725, 1.168042, 0.008800},{
      0.917272, 1.169292, 0.008800},{0.917664, 1.170498, 0.007315}}],
    Polygon[{{0.919725, 1.168042, 0.008800},{0.918852, 1.166841, 0.010068},{
      0.916813, 1.167880, 0.010068},{0.917272, 1.169292, 0.008800}}],
    Polygon[{{0.918852, 1.166841, 0.010068},{0.917874, 1.165494, 0.011089},{
      0.916299, 1.166296, 0.011089},{0.916813, 1.167880, 0.010068}}],
    Polygon[{{0.917874, 1.165494, 0.011089},{0.916813, 1.164034, 0.011836},{
      0.915741, 1.164580, 0.011836},{0.916299, 1.166296, 0.011089}}],
    Polygon[{{0.916813, 1.164034, 0.011836},{0.915697, 1.162498, 0.012292},{
      0.915154, 1.162775, 0.012292},{0.915741, 1.164580, 0.011836}}],
    Polygon[{{0.915154, 1.162775, -0.012292},{0.915741, 1.164580, -0.011836},{
      0.914553, 1.164769, -0.011836},{0.914553, 1.162870, -0.012292}}],
    Polygon[{{0.915741, 1.164580, -0.011836},{0.916299, 1.166296, -0.011089},{
      0.914553, 1.166573, -0.011089},{0.914553, 1.164769, -0.011836}}],
    Polygon[{{0.916299, 1.166296, -0.011089},{0.916813, 1.167880, -0.010068},{
      0.914553, 1.168238, -0.010068},{0.914553, 1.166573, -0.011089}}],
    Polygon[{{0.916813, 1.167880, -0.010068},{0.917272, 1.169292, -0.008800},{
      0.914553, 1.169723, -0.008800},{0.914553, 1.168238, -0.010068}}],
    Polygon[{{0.917272, 1.169292, -0.008800},{0.917664, 1.170498, -0.007315},{
      0.914553, 1.170991, -0.007315},{0.914553, 1.169723, -0.008800}}],
    Polygon[{{0.917664, 1.170498, -0.007315},{0.917979, 1.171469, -0.005650},{
      0.914553, 1.172012, -0.005650},{0.914553, 1.170991, -0.007315}}],
    Polygon[{{0.917979, 1.171469, -0.005650},{0.918210, 1.172180, -0.003846},{
      0.914553, 1.172759, -0.003846},{0.914553, 1.172012, -0.005650}}],
    Polygon[{{0.918210, 1.172180, -0.003846},{0.918351, 1.172613, -0.001947},{
      0.914553, 1.173215, -0.001947},{0.914553, 1.172759, -0.003846}}],
    Polygon[{{0.918351, 1.172613, -0.001947},{0.918398, 1.172759, 0.000000},{
      0.914553, 1.173368, 0.000000},{0.914553, 1.173215, -0.001947}}],
    Polygon[{{0.918398, 1.172759, 0.000000},{0.918351, 1.172613, 0.001947},{
      0.914553, 1.173215, 0.001947},{0.914553, 1.173368, 0.000000}}],
    Polygon[{{0.918351, 1.172613, 0.001947},{0.918210, 1.172180, 0.003846},{
      0.914553, 1.172759, 0.003846},{0.914553, 1.173215, 0.001947}}],
    Polygon[{{0.918210, 1.172180, 0.003846},{0.917979, 1.171469, 0.005650},{
      0.914553, 1.172012, 0.005650},{0.914553, 1.172759, 0.003846}}],
    Polygon[{{0.917979, 1.171469, 0.005650},{0.917664, 1.170498, 0.007315},{
      0.914553, 1.170991, 0.007315},{0.914553, 1.172012, 0.005650}}],
    Polygon[{{0.917664, 1.170498, 0.007315},{0.917272, 1.169292, 0.008800},{
      0.914553, 1.169723, 0.008800},{0.914553, 1.170991, 0.007315}}],
    Polygon[{{0.917272, 1.169292, 0.008800},{0.916813, 1.167880, 0.010068},{
      0.914553, 1.168238, 0.010068},{0.914553, 1.169723, 0.008800}}],
    Polygon[{{0.916813, 1.167880, 0.010068},{0.916299, 1.166296, 0.011089},{
      0.914553, 1.166573, 0.011089},{0.914553, 1.168238, 0.010068}}],
    Polygon[{{0.916299, 1.166296, 0.011089},{0.915741, 1.164580, 0.011836},{
      0.914553, 1.164769, 0.011836},{0.914553, 1.166573, 0.011089}}],
    Polygon[{{0.915741, 1.164580, 0.011836},{0.915154, 1.162775, 0.012292},{
      0.914553, 1.162870, 0.012292},{0.914553, 1.164769, 0.011836}}],
    Polygon[{{0.914553, 1.162870, -0.012292},{0.914553, 1.164769, -0.011836},{
      0.913364, 1.164580, -0.011836},{0.913951, 1.162775, -0.012292}}],
    Polygon[{{0.914553, 1.164769, -0.011836},{0.914553, 1.166573, -0.011089},{
      0.912807, 1.166296, -0.011089},{0.913364, 1.164580, -0.011836}}],
    Polygon[{{0.914553, 1.166573, -0.011089},{0.914553, 1.168238, -0.010068},{
      0.912292, 1.167880, -0.010068},{0.912807, 1.166296, -0.011089}}],
    Polygon[{{0.914553, 1.168238, -0.010068},{0.914553, 1.169723, -0.008800},{
      0.911833, 1.169292, -0.008800},{0.912292, 1.167880, -0.010068}}],
    Polygon[{{0.914553, 1.169723, -0.008800},{0.914553, 1.170991, -0.007315},{
      0.911441, 1.170498, -0.007315},{0.911833, 1.169292, -0.008800}}],
    Polygon[{{0.914553, 1.170991, -0.007315},{0.914553, 1.172012, -0.005650},{
      0.911126, 1.171469, -0.005650},{0.911441, 1.170498, -0.007315}}],
    Polygon[{{0.914553, 1.172012, -0.005650},{0.914553, 1.172759, -0.003846},{
      0.910895, 1.172180, -0.003846},{0.911126, 1.171469, -0.005650}}],
    Polygon[{{0.914553, 1.172759, -0.003846},{0.914553, 1.173215, -0.001947},{
      0.910754, 1.172613, -0.001947},{0.910895, 1.172180, -0.003846}}],
    Polygon[{{0.914553, 1.173215, -0.001947},{0.914553, 1.173368, 0.000000},{
      0.910707, 1.172759, 0.000000},{0.910754, 1.172613, -0.001947}}],
    Polygon[{{0.914553, 1.173368, 0.000000},{0.914553, 1.173215, 0.001947},{
      0.910754, 1.172613, 0.001947},{0.910707, 1.172759, 0.000000}}],
    Polygon[{{0.914553, 1.173215, 0.001947},{0.914553, 1.172759, 0.003846},{
      0.910895, 1.172180, 0.003846},{0.910754, 1.172613, 0.001947}}],
    Polygon[{{0.914553, 1.172759, 0.003846},{0.914553, 1.172012, 0.005650},{
      0.911126, 1.171469, 0.005650},{0.910895, 1.172180, 0.003846}}],
    Polygon[{{0.914553, 1.172012, 0.005650},{0.914553, 1.170991, 0.007315},{
      0.911441, 1.170498, 0.007315},{0.911126, 1.171469, 0.005650}}],
    Polygon[{{0.914553, 1.170991, 0.007315},{0.914553, 1.169723, 0.008800},{
      0.911833, 1.169292, 0.008800},{0.911441, 1.170498, 0.007315}}],
    Polygon[{{0.914553, 1.169723, 0.008800},{0.914553, 1.168238, 0.010068},{
      0.912292, 1.167880, 0.010068},{0.911833, 1.169292, 0.008800}}],
    Polygon[{{0.914553, 1.168238, 0.010068},{0.914553, 1.166573, 0.011089},{
      0.912807, 1.166296, 0.011089},{0.912292, 1.167880, 0.010068}}],
    Polygon[{{0.914553, 1.166573, 0.011089},{0.914553, 1.164769, 0.011836},{
      0.913364, 1.164580, 0.011836},{0.912807, 1.166296, 0.011089}}],
    Polygon[{{0.914553, 1.164769, 0.011836},{0.914553, 1.162870, 0.012292},{
      0.913951, 1.162775, 0.012292},{0.913364, 1.164580, 0.011836}}],
    Polygon[{{0.913951, 1.162775, -0.012292},{0.913364, 1.164580, -0.011836},{
      0.912292, 1.164034, -0.011836},{0.913408, 1.162498, -0.012292}}],
    Polygon[{{0.913364, 1.164580, -0.011836},{0.912807, 1.166296, -0.011089},{
      0.911232, 1.165494, -0.011089},{0.912292, 1.164034, -0.011836}}],
    Polygon[{{0.912807, 1.166296, -0.011089},{0.912292, 1.167880, -0.010068},{
      0.910253, 1.166841, -0.010068},{0.911232, 1.165494, -0.011089}}],
    Polygon[{{0.912292, 1.167880, -0.010068},{0.911833, 1.169292, -0.008800},{
      0.909380, 1.168042, -0.008800},{0.910253, 1.166841, -0.010068}}],
    Polygon[{{0.911833, 1.169292, -0.008800},{0.911441, 1.170498, -0.007315},{
      0.908635, 1.169068, -0.007315},{0.909380, 1.168042, -0.008800}}],
    Polygon[{{0.911441, 1.170498, -0.007315},{0.911126, 1.171469, -0.005650},{
      0.908035, 1.169894, -0.005650},{0.908635, 1.169068, -0.007315}}],
    Polygon[{{0.911126, 1.171469, -0.005650},{0.910895, 1.172180, -0.003846},{
      0.907596, 1.170498, -0.003846},{0.908035, 1.169894, -0.005650}}],
    Polygon[{{0.910895, 1.172180, -0.003846},{0.910754, 1.172613, -0.001947},{
      0.907328, 1.170867, -0.001947},{0.907596, 1.170498, -0.003846}}],
    Polygon[{{0.910754, 1.172613, -0.001947},{0.910707, 1.172759, 0.000000},{
      0.907238, 1.170991, 0.000000},{0.907328, 1.170867, -0.001947}}],
    Polygon[{{0.910707, 1.172759, 0.000000},{0.910754, 1.172613, 0.001947},{
      0.907328, 1.170867, 0.001947},{0.907238, 1.170991, 0.000000}}],
    Polygon[{{0.910754, 1.172613, 0.001947},{0.910895, 1.172180, 0.003846},{
      0.907596, 1.170498, 0.003846},{0.907328, 1.170867, 0.001947}}],
    Polygon[{{0.910895, 1.172180, 0.003846},{0.911126, 1.171469, 0.005650},{
      0.908035, 1.169894, 0.005650},{0.907596, 1.170498, 0.003846}}],
    Polygon[{{0.911126, 1.171469, 0.005650},{0.911441, 1.170498, 0.007315},{
      0.908635, 1.169068, 0.007315},{0.908035, 1.169894, 0.005650}}],
    Polygon[{{0.911441, 1.170498, 0.007315},{0.911833, 1.169292, 0.008800},{
      0.909380, 1.168042, 0.008800},{0.908635, 1.169068, 0.007315}}],
    Polygon[{{0.911833, 1.169292, 0.008800},{0.912292, 1.167880, 0.010068},{
      0.910253, 1.166841, 0.010068},{0.909380, 1.168042, 0.008800}}],
    Polygon[{{0.912292, 1.167880, 0.010068},{0.912807, 1.166296, 0.011089},{
      0.911232, 1.165494, 0.011089},{0.910253, 1.166841, 0.010068}}],
    Polygon[{{0.912807, 1.166296, 0.011089},{0.913364, 1.164580, 0.011836},{
      0.912292, 1.164034, 0.011836},{0.911232, 1.165494, 0.011089}}],
    Polygon[{{0.913364, 1.164580, 0.011836},{0.913951, 1.162775, 0.012292},{
      0.913408, 1.162498, 0.012292},{0.912292, 1.164034, 0.011836}}],
    Polygon[{{0.913408, 1.162498, -0.012292},{0.912292, 1.164034, -0.011836},{
      0.911441, 1.163183, -0.011836},{0.912978, 1.162067, -0.012292}}],
    Polygon[{{0.912292, 1.164034, -0.011836},{0.911232, 1.165494, -0.011089},{
      0.909982, 1.164244, -0.011089},{0.911441, 1.163183, -0.011836}}],
    Polygon[{{0.911232, 1.165494, -0.011089},{0.910253, 1.166841, -0.010068},{
      0.908635, 1.165223, -0.010068},{0.909982, 1.164244, -0.011089}}],
    Polygon[{{0.910253, 1.166841, -0.010068},{0.909380, 1.168042, -0.008800},{
      0.907433, 1.166095, -0.008800},{0.908635, 1.165223, -0.010068}}],
    Polygon[{{0.909380, 1.168042, -0.008800},{0.908635, 1.169068, -0.007315},{
      0.906407, 1.166841, -0.007315},{0.907433, 1.166095, -0.008800}}],
    Polygon[{{0.908635, 1.169068, -0.007315},{0.908035, 1.169894, -0.005650},{
      0.905582, 1.167441, -0.005650},{0.906407, 1.166841, -0.007315}}],
    Polygon[{{0.908035, 1.169894, -0.005650},{0.907596, 1.170498, -0.003846},{
      0.904977, 1.167880, -0.003846},{0.905582, 1.167441, -0.005650}}],
    Polygon[{{0.907596, 1.170498, -0.003846},{0.907328, 1.170867, -0.001947},{
      0.904608, 1.168148, -0.001947},{0.904977, 1.167880, -0.003846}}],
    Polygon[{{0.907328, 1.170867, -0.001947},{0.907238, 1.170991, 0.000000},{
      0.904484, 1.168238, 0.000000},{0.904608, 1.168148, -0.001947}}],
    Polygon[{{0.907238, 1.170991, 0.000000},{0.907328, 1.170867, 0.001947},{
      0.904608, 1.168148, 0.001947},{0.904484, 1.168238, 0.000000}}],
    Polygon[{{0.907328, 1.170867, 0.001947},{0.907596, 1.170498, 0.003846},{
      0.904977, 1.167880, 0.003846},{0.904608, 1.168148, 0.001947}}],
    Polygon[{{0.907596, 1.170498, 0.003846},{0.908035, 1.169894, 0.005650},{
      0.905582, 1.167441, 0.005650},{0.904977, 1.167880, 0.003846}}],
    Polygon[{{0.908035, 1.169894, 0.005650},{0.908635, 1.169068, 0.007315},{
      0.906407, 1.166841, 0.007315},{0.905582, 1.167441, 0.005650}}],
    Polygon[{{0.908635, 1.169068, 0.007315},{0.909380, 1.168042, 0.008800},{
      0.907433, 1.166095, 0.008800},{0.906407, 1.166841, 0.007315}}],
    Polygon[{{0.909380, 1.168042, 0.008800},{0.910253, 1.166841, 0.010068},{
      0.908635, 1.165223, 0.010068},{0.907433, 1.166095, 0.008800}}],
    Polygon[{{0.910253, 1.166841, 0.010068},{0.911232, 1.165494, 0.011089},{
      0.909982, 1.164244, 0.011089},{0.908635, 1.165223, 0.010068}}],
    Polygon[{{0.911232, 1.165494, 0.011089},{0.912292, 1.164034, 0.011836},{
      0.911441, 1.163183, 0.011836},{0.909982, 1.164244, 0.011089}}],
    Polygon[{{0.912292, 1.164034, 0.011836},{0.913408, 1.162498, 0.012292},{
      0.912978, 1.162067, 0.012292},{0.911441, 1.163183, 0.011836}}],
    Polygon[{{0.912978, 1.162067, -0.012292},{0.911441, 1.163183, -0.011836},{
      0.910895, 1.162111, -0.011836},{0.912701, 1.161525, -0.012292}}],
    Polygon[{{0.911441, 1.163183, -0.011836},{0.909982, 1.164244, -0.011089},{
      0.909179, 1.162669, -0.011089},{0.910895, 1.162111, -0.011836}}],
    Polygon[{{0.909982, 1.164244, -0.011089},{0.908635, 1.165223, -0.010068},{
      0.907596, 1.163183, -0.010068},{0.909179, 1.162669, -0.011089}}],
    Polygon[{{0.908635, 1.165223, -0.010068},{0.907433, 1.166095, -0.008800},{
      0.906183, 1.163642, -0.008800},{0.907596, 1.163183, -0.010068}}],
    Polygon[{{0.907433, 1.166095, -0.008800},{0.906407, 1.166841, -0.007315},{
      0.904977, 1.164034, -0.007315},{0.906183, 1.163642, -0.008800}}],
    Polygon[{{0.906407, 1.166841, -0.007315},{0.905582, 1.167441, -0.005650},{
      0.904007, 1.164350, -0.005650},{0.904977, 1.164034, -0.007315}}],
    Polygon[{{0.905582, 1.167441, -0.005650},{0.904977, 1.167880, -0.003846},{
      0.903296, 1.164580, -0.003846},{0.904007, 1.164350, -0.005650}}],
    Polygon[{{0.904977, 1.167880, -0.003846},{0.904608, 1.168148, -0.001947},{
      0.902862, 1.164721, -0.001947},{0.903296, 1.164580, -0.003846}}],
    Polygon[{{0.904608, 1.168148, -0.001947},{0.904484, 1.168238, 0.000000},{
      0.902717, 1.164769, 0.000000},{0.902862, 1.164721, -0.001947}}],
    Polygon[{{0.904484, 1.168238, 0.000000},{0.904608, 1.168148, 0.001947},{
      0.902862, 1.164721, 0.001947},{0.902717, 1.164769, 0.000000}}],
    Polygon[{{0.904608, 1.168148, 0.001947},{0.904977, 1.167880, 0.003846},{
      0.903296, 1.164580, 0.003846},{0.902862, 1.164721, 0.001947}}],
    Polygon[{{0.904977, 1.167880, 0.003846},{0.905582, 1.167441, 0.005650},{
      0.904007, 1.164350, 0.005650},{0.903296, 1.164580, 0.003846}}],
    Polygon[{{0.905582, 1.167441, 0.005650},{0.906407, 1.166841, 0.007315},{
      0.904977, 1.164034, 0.007315},{0.904007, 1.164350, 0.005650}}],
    Polygon[{{0.906407, 1.166841, 0.007315},{0.907433, 1.166095, 0.008800},{
      0.906183, 1.163642, 0.008800},{0.904977, 1.164034, 0.007315}}],
    Polygon[{{0.907433, 1.166095, 0.008800},{0.908635, 1.165223, 0.010068},{
      0.907596, 1.163183, 0.010068},{0.906183, 1.163642, 0.008800}}],
    Polygon[{{0.908635, 1.165223, 0.010068},{0.909982, 1.164244, 0.011089},{
      0.909179, 1.162669, 0.011089},{0.907596, 1.163183, 0.010068}}],
    Polygon[{{0.909982, 1.164244, 0.011089},{0.911441, 1.163183, 0.011836},{
      0.910895, 1.162111, 0.011836},{0.909179, 1.162669, 0.011089}}],
    Polygon[{{0.911441, 1.163183, 0.011836},{0.912978, 1.162067, 0.012292},{
      0.912701, 1.161525, 0.012292},{0.910895, 1.162111, 0.011836}}],
    Polygon[{{0.912701, 1.161525, -0.012292},{0.910895, 1.162111, -0.011836},{
      0.910707, 1.160923, -0.011836},{0.912606, 1.160923, -0.012292}}],
    Polygon[{{0.910895, 1.162111, -0.011836},{0.909179, 1.162669, -0.011089},{
      0.908903, 1.160923, -0.011089},{0.910707, 1.160923, -0.011836}}],
    Polygon[{{0.909179, 1.162669, -0.011089},{0.907596, 1.163183, -0.010068},{
      0.907238, 1.160923, -0.010068},{0.908903, 1.160923, -0.011089}}],
    Polygon[{{0.907596, 1.163183, -0.010068},{0.906183, 1.163642, -0.008800},{
      0.905753, 1.160923, -0.008800},{0.907238, 1.160923, -0.010068}}],
    Polygon[{{0.906183, 1.163642, -0.008800},{0.904977, 1.164034, -0.007315},{
      0.904484, 1.160923, -0.007315},{0.905753, 1.160923, -0.008800}}],
    Polygon[{{0.904977, 1.164034, -0.007315},{0.904007, 1.164350, -0.005650},{
      0.903464, 1.160923, -0.005650},{0.904484, 1.160923, -0.007315}}],
    Polygon[{{0.904007, 1.164350, -0.005650},{0.903296, 1.164580, -0.003846},{
      0.902717, 1.160923, -0.003846},{0.903464, 1.160923, -0.005650}}],
    Polygon[{{0.903296, 1.164580, -0.003846},{0.902862, 1.164721, -0.001947},{
      0.902261, 1.160923, -0.001947},{0.902717, 1.160923, -0.003846}}],
    Polygon[{{0.902862, 1.164721, -0.001947},{0.902717, 1.164769, 0.000000},{
      0.902108, 1.160923, 0.000000},{0.902261, 1.160923, -0.001947}}],
    Polygon[{{0.902717, 1.164769, 0.000000},{0.902862, 1.164721, 0.001947},{
      0.902261, 1.160923, 0.001947},{0.902108, 1.160923, 0.000000}}],
    Polygon[{{0.902862, 1.164721, 0.001947},{0.903296, 1.164580, 0.003846},{
      0.902717, 1.160923, 0.003846},{0.902261, 1.160923, 0.001947}}],
    Polygon[{{0.903296, 1.164580, 0.003846},{0.904007, 1.164350, 0.005650},{
      0.903464, 1.160923, 0.005650},{0.902717, 1.160923, 0.003846}}],
    Polygon[{{0.904007, 1.164350, 0.005650},{0.904977, 1.164034, 0.007315},{
      0.904484, 1.160923, 0.007315},{0.903464, 1.160923, 0.005650}}],
    Polygon[{{0.904977, 1.164034, 0.007315},{0.906183, 1.163642, 0.008800},{
      0.905753, 1.160923, 0.008800},{0.904484, 1.160923, 0.007315}}],
    Polygon[{{0.906183, 1.163642, 0.008800},{0.907596, 1.163183, 0.010068},{
      0.907238, 1.160923, 0.010068},{0.905753, 1.160923, 0.008800}}],
    Polygon[{{0.907596, 1.163183, 0.010068},{0.909179, 1.162669, 0.011089},{
      0.908903, 1.160923, 0.011089},{0.907238, 1.160923, 0.010068}}],
    Polygon[{{0.909179, 1.162669, 0.011089},{0.910895, 1.162111, 0.011836},{
      0.910707, 1.160923, 0.011836},{0.908903, 1.160923, 0.011089}}],
    Polygon[{{0.910895, 1.162111, 0.011836},{0.912701, 1.161525, 0.012292},{
      0.912606, 1.160923, 0.012292},{0.910707, 1.160923, 0.011836}}],
    Polygon[{{0.912606, 1.160923, -0.012292},{0.910707, 1.160923, -0.011836},{
      0.910895, 1.159735, -0.011836},{0.912701, 1.160321, -0.012292}}],
    Polygon[{{0.910707, 1.160923, -0.011836},{0.908903, 1.160923, -0.011089},{
      0.909179, 1.159177, -0.011089},{0.910895, 1.159735, -0.011836}}],
    Polygon[{{0.908903, 1.160923, -0.011089},{0.907238, 1.160923, -0.010068},{
      0.907596, 1.158663, -0.010068},{0.909179, 1.159177, -0.011089}}],
    Polygon[{{0.907238, 1.160923, -0.010068},{0.905753, 1.160923, -0.008800},{
      0.906183, 1.158204, -0.008800},{0.907596, 1.158663, -0.010068}}],
    Polygon[{{0.905753, 1.160923, -0.008800},{0.904484, 1.160923, -0.007315},{
      0.904977, 1.157812, -0.007315},{0.906183, 1.158204, -0.008800}}],
    Polygon[{{0.904484, 1.160923, -0.007315},{0.903464, 1.160923, -0.005650},{
      0.904007, 1.157496, -0.005650},{0.904977, 1.157812, -0.007315}}],
    Polygon[{{0.903464, 1.160923, -0.005650},{0.902717, 1.160923, -0.003846},{
      0.903296, 1.157266, -0.003846},{0.904007, 1.157496, -0.005650}}],
    Polygon[{{0.902717, 1.160923, -0.003846},{0.902261, 1.160923, -0.001947},{
      0.902862, 1.157125, -0.001947},{0.903296, 1.157266, -0.003846}}],
    Polygon[{{0.902261, 1.160923, -0.001947},{0.902108, 1.160923, 0.000000},{
      0.902717, 1.157077, 0.000000},{0.902862, 1.157125, -0.001947}}],
    Polygon[{{0.902108, 1.160923, 0.000000},{0.902261, 1.160923, 0.001947},{
      0.902862, 1.157125, 0.001947},{0.902717, 1.157077, 0.000000}}],
    Polygon[{{0.902261, 1.160923, 0.001947},{0.902717, 1.160923, 0.003846},{
      0.903296, 1.157266, 0.003846},{0.902862, 1.157125, 0.001947}}],
    Polygon[{{0.902717, 1.160923, 0.003846},{0.903464, 1.160923, 0.005650},{
      0.904007, 1.157496, 0.005650},{0.903296, 1.157266, 0.003846}}],
    Polygon[{{0.903464, 1.160923, 0.005650},{0.904484, 1.160923, 0.007315},{
      0.904977, 1.157812, 0.007315},{0.904007, 1.157496, 0.005650}}],
    Polygon[{{0.904484, 1.160923, 0.007315},{0.905753, 1.160923, 0.008800},{
      0.906183, 1.158204, 0.008800},{0.904977, 1.157812, 0.007315}}],
    Polygon[{{0.905753, 1.160923, 0.008800},{0.907238, 1.160923, 0.010068},{
      0.907596, 1.158663, 0.010068},{0.906183, 1.158204, 0.008800}}],
    Polygon[{{0.907238, 1.160923, 0.010068},{0.908903, 1.160923, 0.011089},{
      0.909179, 1.159177, 0.011089},{0.907596, 1.158663, 0.010068}}],
    Polygon[{{0.908903, 1.160923, 0.011089},{0.910707, 1.160923, 0.011836},{
      0.910895, 1.159735, 0.011836},{0.909179, 1.159177, 0.011089}}],
    Polygon[{{0.910707, 1.160923, 0.011836},{0.912606, 1.160923, 0.012292},{
      0.912701, 1.160321, 0.012292},{0.910895, 1.159735, 0.011836}}],
    Polygon[{{0.912701, 1.160321, -0.012292},{0.910895, 1.159735, -0.011836},{
      0.911441, 1.158663, -0.011836},{0.912978, 1.159779, -0.012292}}],
    Polygon[{{0.910895, 1.159735, -0.011836},{0.909179, 1.159177, -0.011089},{
      0.909982, 1.157602, -0.011089},{0.911441, 1.158663, -0.011836}}],
    Polygon[{{0.909179, 1.159177, -0.011089},{0.907596, 1.158663, -0.010068},{
      0.908635, 1.156623, -0.010068},{0.909982, 1.157602, -0.011089}}],
    Polygon[{{0.907596, 1.158663, -0.010068},{0.906183, 1.158204, -0.008800},{
      0.907433, 1.155751, -0.008800},{0.908635, 1.156623, -0.010068}}],
    Polygon[{{0.906183, 1.158204, -0.008800},{0.904977, 1.157812, -0.007315},{
      0.906407, 1.155005, -0.007315},{0.907433, 1.155751, -0.008800}}],
    Polygon[{{0.904977, 1.157812, -0.007315},{0.904007, 1.157496, -0.005650},{
      0.905582, 1.154405, -0.005650},{0.906407, 1.155005, -0.007315}}],
    Polygon[{{0.904007, 1.157496, -0.005650},{0.903296, 1.157266, -0.003846},{
      0.904977, 1.153966, -0.003846},{0.905582, 1.154405, -0.005650}}],
    Polygon[{{0.903296, 1.157266, -0.003846},{0.902862, 1.157125, -0.001947},{
      0.904608, 1.153698, -0.001947},{0.904977, 1.153966, -0.003846}}],
    Polygon[{{0.902862, 1.157125, -0.001947},{0.902717, 1.157077, 0.000000},{
      0.904484, 1.153608, 0.000000},{0.904608, 1.153698, -0.001947}}],
    Polygon[{{0.902717, 1.157077, 0.000000},{0.902862, 1.157125, 0.001947},{
      0.904608, 1.153698, 0.001947},{0.904484, 1.153608, 0.000000}}],
    Polygon[{{0.902862, 1.157125, 0.001947},{0.903296, 1.157266, 0.003846},{
      0.904977, 1.153966, 0.003846},{0.904608, 1.153698, 0.001947}}],
    Polygon[{{0.903296, 1.157266, 0.003846},{0.904007, 1.157496, 0.005650},{
      0.905582, 1.154405, 0.005650},{0.904977, 1.153966, 0.003846}}],
    Polygon[{{0.904007, 1.157496, 0.005650},{0.904977, 1.157812, 0.007315},{
      0.906407, 1.155005, 0.007315},{0.905582, 1.154405, 0.005650}}],
    Polygon[{{0.904977, 1.157812, 0.007315},{0.906183, 1.158204, 0.008800},{
      0.907433, 1.155751, 0.008800},{0.906407, 1.155005, 0.007315}}],
    Polygon[{{0.906183, 1.158204, 0.008800},{0.907596, 1.158663, 0.010068},{
      0.908635, 1.156623, 0.010068},{0.907433, 1.155751, 0.008800}}],
    Polygon[{{0.907596, 1.158663, 0.010068},{0.909179, 1.159177, 0.011089},{
      0.909982, 1.157602, 0.011089},{0.908635, 1.156623, 0.010068}}],
    Polygon[{{0.909179, 1.159177, 0.011089},{0.910895, 1.159735, 0.011836},{
      0.911441, 1.158663, 0.011836},{0.909982, 1.157602, 0.011089}}],
    Polygon[{{0.910895, 1.159735, 0.011836},{0.912701, 1.160321, 0.012292},{
      0.912978, 1.159779, 0.012292},{0.911441, 1.158663, 0.011836}}],
    Polygon[{{0.912978, 1.159779, -0.012292},{0.911441, 1.158663, -0.011836},{
      0.912292, 1.157812, -0.011836},{0.913408, 1.159348, -0.012292}}],
    Polygon[{{0.911441, 1.158663, -0.011836},{0.909982, 1.157602, -0.011089},{
      0.911232, 1.156352, -0.011089},{0.912292, 1.157812, -0.011836}}],
    Polygon[{{0.909982, 1.157602, -0.011089},{0.908635, 1.156623, -0.010068},{
      0.910253, 1.155005, -0.010068},{0.911232, 1.156352, -0.011089}}],
    Polygon[{{0.908635, 1.156623, -0.010068},{0.907433, 1.155751, -0.008800},{
      0.909380, 1.153804, -0.008800},{0.910253, 1.155005, -0.010068}}],
    Polygon[{{0.907433, 1.155751, -0.008800},{0.906407, 1.155005, -0.007315},{
      0.908635, 1.152778, -0.007315},{0.909380, 1.153804, -0.008800}}],
    Polygon[{{0.906407, 1.155005, -0.007315},{0.905582, 1.154405, -0.005650},{
      0.908035, 1.151952, -0.005650},{0.908635, 1.152778, -0.007315}}],
    Polygon[{{0.905582, 1.154405, -0.005650},{0.904977, 1.153966, -0.003846},{
      0.907596, 1.151348, -0.003846},{0.908035, 1.151952, -0.005650}}],
    Polygon[{{0.904977, 1.153966, -0.003846},{0.904608, 1.153698, -0.001947},{
      0.907328, 1.150979, -0.001947},{0.907596, 1.151348, -0.003846}}],
    Polygon[{{0.904608, 1.153698, -0.001947},{0.904484, 1.153608, 0.000000},{
      0.907238, 1.150855, 0.000000},{0.907328, 1.150979, -0.001947}}],
    Polygon[{{0.904484, 1.153608, 0.000000},{0.904608, 1.153698, 0.001947},{
      0.907328, 1.150979, 0.001947},{0.907238, 1.150855, 0.000000}}],
    Polygon[{{0.904608, 1.153698, 0.001947},{0.904977, 1.153966, 0.003846},{
      0.907596, 1.151348, 0.003846},{0.907328, 1.150979, 0.001947}}],
    Polygon[{{0.904977, 1.153966, 0.003846},{0.905582, 1.154405, 0.005650},{
      0.908035, 1.151952, 0.005650},{0.907596, 1.151348, 0.003846}}],
    Polygon[{{0.905582, 1.154405, 0.005650},{0.906407, 1.155005, 0.007315},{
      0.908635, 1.152778, 0.007315},{0.908035, 1.151952, 0.005650}}],
    Polygon[{{0.906407, 1.155005, 0.007315},{0.907433, 1.155751, 0.008800},{
      0.909380, 1.153804, 0.008800},{0.908635, 1.152778, 0.007315}}],
    Polygon[{{0.907433, 1.155751, 0.008800},{0.908635, 1.156623, 0.010068},{
      0.910253, 1.155005, 0.010068},{0.909380, 1.153804, 0.008800}}],
    Polygon[{{0.908635, 1.156623, 0.010068},{0.909982, 1.157602, 0.011089},{
      0.911232, 1.156352, 0.011089},{0.910253, 1.155005, 0.010068}}],
    Polygon[{{0.909982, 1.157602, 0.011089},{0.911441, 1.158663, 0.011836},{
      0.912292, 1.157812, 0.011836},{0.911232, 1.156352, 0.011089}}],
    Polygon[{{0.911441, 1.158663, 0.011836},{0.912978, 1.159779, 0.012292},{
      0.913408, 1.159348, 0.012292},{0.912292, 1.157812, 0.011836}}],
    Polygon[{{0.913408, 1.159348, -0.012292},{0.912292, 1.157812, -0.011836},{
      0.913364, 1.157266, -0.011836},{0.913951, 1.159071, -0.012292}}],
    Polygon[{{0.912292, 1.157812, -0.011836},{0.911232, 1.156352, -0.011089},{
      0.912807, 1.155550, -0.011089},{0.913364, 1.157266, -0.011836}}],
    Polygon[{{0.911232, 1.156352, -0.011089},{0.910253, 1.155005, -0.010068},{
      0.912292, 1.153966, -0.010068},{0.912807, 1.155550, -0.011089}}],
    Polygon[{{0.910253, 1.155005, -0.010068},{0.909380, 1.153804, -0.008800},{
      0.911833, 1.152554, -0.008800},{0.912292, 1.153966, -0.010068}}],
    Polygon[{{0.909380, 1.153804, -0.008800},{0.908635, 1.152778, -0.007315},{
      0.911441, 1.151348, -0.007315},{0.911833, 1.152554, -0.008800}}],
    Polygon[{{0.908635, 1.152778, -0.007315},{0.908035, 1.151952, -0.005650},{
      0.911126, 1.150377, -0.005650},{0.911441, 1.151348, -0.007315}}],
    Polygon[{{0.908035, 1.151952, -0.005650},{0.907596, 1.151348, -0.003846},{
      0.910895, 1.149666, -0.003846},{0.911126, 1.150377, -0.005650}}],
    Polygon[{{0.907596, 1.151348, -0.003846},{0.907328, 1.150979, -0.001947},{
      0.910754, 1.149233, -0.001947},{0.910895, 1.149666, -0.003846}}],
    Polygon[{{0.907328, 1.150979, -0.001947},{0.907238, 1.150855, 0.000000},{
      0.910707, 1.149087, 0.000000},{0.910754, 1.149233, -0.001947}}],
    Polygon[{{0.907238, 1.150855, 0.000000},{0.907328, 1.150979, 0.001947},{
      0.910754, 1.149233, 0.001947},{0.910707, 1.149087, 0.000000}}],
    Polygon[{{0.907328, 1.150979, 0.001947},{0.907596, 1.151348, 0.003846},{
      0.910895, 1.149666, 0.003846},{0.910754, 1.149233, 0.001947}}],
    Polygon[{{0.907596, 1.151348, 0.003846},{0.908035, 1.151952, 0.005650},{
      0.911126, 1.150377, 0.005650},{0.910895, 1.149666, 0.003846}}],
    Polygon[{{0.908035, 1.151952, 0.005650},{0.908635, 1.152778, 0.007315},{
      0.911441, 1.151348, 0.007315},{0.911126, 1.150377, 0.005650}}],
    Polygon[{{0.908635, 1.152778, 0.007315},{0.909380, 1.153804, 0.008800},{
      0.911833, 1.152554, 0.008800},{0.911441, 1.151348, 0.007315}}],
    Polygon[{{0.909380, 1.153804, 0.008800},{0.910253, 1.155005, 0.010068},{
      0.912292, 1.153966, 0.010068},{0.911833, 1.152554, 0.008800}}],
    Polygon[{{0.910253, 1.155005, 0.010068},{0.911232, 1.156352, 0.011089},{
      0.912807, 1.155550, 0.011089},{0.912292, 1.153966, 0.010068}}],
    Polygon[{{0.911232, 1.156352, 0.011089},{0.912292, 1.157812, 0.011836},{
      0.913364, 1.157266, 0.011836},{0.912807, 1.155550, 0.011089}}],
    Polygon[{{0.912292, 1.157812, 0.011836},{0.913408, 1.159348, 0.012292},{
      0.913951, 1.159071, 0.012292},{0.913364, 1.157266, 0.011836}}],
    Polygon[{{0.913951, 1.159071, -0.012292},{0.913364, 1.157266, -0.011836},{
      0.914553, 1.157077, -0.011836},{0.914553, 1.158976, -0.012292}}],
    Polygon[{{0.913364, 1.157266, -0.011836},{0.912807, 1.155550, -0.011089},{
      0.914553, 1.155273, -0.011089},{0.914553, 1.157077, -0.011836}}],
    Polygon[{{0.912807, 1.155550, -0.011089},{0.912292, 1.153966, -0.010068},{
      0.914553, 1.153608, -0.010068},{0.914553, 1.155273, -0.011089}}],
    Polygon[{{0.912292, 1.153966, -0.010068},{0.911833, 1.152554, -0.008800},{
      0.914553, 1.152123, -0.008800},{0.914553, 1.153608, -0.010068}}],
    Polygon[{{0.911833, 1.152554, -0.008800},{0.911441, 1.151348, -0.007315},{
      0.914553, 1.150855, -0.007315},{0.914553, 1.152123, -0.008800}}],
    Polygon[{{0.911441, 1.151348, -0.007315},{0.911126, 1.150377, -0.005650},{
      0.914553, 1.149835, -0.005650},{0.914553, 1.150855, -0.007315}}],
    Polygon[{{0.911126, 1.150377, -0.005650},{0.910895, 1.149666, -0.003846},{
      0.914553, 1.149087, -0.003846},{0.914553, 1.149835, -0.005650}}],
    Polygon[{{0.910895, 1.149666, -0.003846},{0.910754, 1.149233, -0.001947},{
      0.914553, 1.148631, -0.001947},{0.914553, 1.149087, -0.003846}}],
    Polygon[{{0.910754, 1.149233, -0.001947},{0.910707, 1.149087, 0.000000},{
      0.914553, 1.148478, 0.000000},{0.914553, 1.148631, -0.001947}}],
    Polygon[{{0.910707, 1.149087, 0.000000},{0.910754, 1.149233, 0.001947},{
      0.914553, 1.148631, 0.001947},{0.914553, 1.148478, 0.000000}}],
    Polygon[{{0.910754, 1.149233, 0.001947},{0.910895, 1.149666, 0.003846},{
      0.914553, 1.149087, 0.003846},{0.914553, 1.148631, 0.001947}}],
    Polygon[{{0.910895, 1.149666, 0.003846},{0.911126, 1.150377, 0.005650},{
      0.914553, 1.149835, 0.005650},{0.914553, 1.149087, 0.003846}}],
    Polygon[{{0.911126, 1.150377, 0.005650},{0.911441, 1.151348, 0.007315},{
      0.914553, 1.150855, 0.007315},{0.914553, 1.149835, 0.005650}}],
    Polygon[{{0.911441, 1.151348, 0.007315},{0.911833, 1.152554, 0.008800},{
      0.914553, 1.152123, 0.008800},{0.914553, 1.150855, 0.007315}}],
    Polygon[{{0.911833, 1.152554, 0.008800},{0.912292, 1.153966, 0.010068},{
      0.914553, 1.153608, 0.010068},{0.914553, 1.152123, 0.008800}}],
    Polygon[{{0.912292, 1.153966, 0.010068},{0.912807, 1.155550, 0.011089},{
      0.914553, 1.155273, 0.011089},{0.914553, 1.153608, 0.010068}}],
    Polygon[{{0.912807, 1.155550, 0.011089},{0.913364, 1.157266, 0.011836},{
      0.914553, 1.157077, 0.011836},{0.914553, 1.155273, 0.011089}}],
    Polygon[{{0.913364, 1.157266, 0.011836},{0.913951, 1.159071, 0.012292},{
      0.914553, 1.158976, 0.012292},{0.914553, 1.157077, 0.011836}}],
    Polygon[{{0.914553, 1.158976, -0.012292},{0.914553, 1.157077, -0.011836},{
      0.915741, 1.157266, -0.011836},{0.915154, 1.159071, -0.012292}}],
    Polygon[{{0.914553, 1.157077, -0.011836},{0.914553, 1.155273, -0.011089},{
      0.916299, 1.155550, -0.011089},{0.915741, 1.157266, -0.011836}}],
    Polygon[{{0.914553, 1.155273, -0.011089},{0.914553, 1.153608, -0.010068},{
      0.916813, 1.153966, -0.010068},{0.916299, 1.155550, -0.011089}}],
    Polygon[{{0.914553, 1.153608, -0.010068},{0.914553, 1.152123, -0.008800},{
      0.917272, 1.152554, -0.008800},{0.916813, 1.153966, -0.010068}}],
    Polygon[{{0.914553, 1.152123, -0.008800},{0.914553, 1.150855, -0.007315},{
      0.917664, 1.151348, -0.007315},{0.917272, 1.152554, -0.008800}}],
    Polygon[{{0.914553, 1.150855, -0.007315},{0.914553, 1.149835, -0.005650},{
      0.917979, 1.150377, -0.005650},{0.917664, 1.151348, -0.007315}}],
    Polygon[{{0.914553, 1.149835, -0.005650},{0.914553, 1.149087, -0.003846},{
      0.918210, 1.149666, -0.003846},{0.917979, 1.150377, -0.005650}}],
    Polygon[{{0.914553, 1.149087, -0.003846},{0.914553, 1.148631, -0.001947},{
      0.918351, 1.149233, -0.001947},{0.918210, 1.149666, -0.003846}}],
    Polygon[{{0.914553, 1.148631, -0.001947},{0.914553, 1.148478, 0.000000},{
      0.918398, 1.149087, 0.000000},{0.918351, 1.149233, -0.001947}}],
    Polygon[{{0.914553, 1.148478, 0.000000},{0.914553, 1.148631, 0.001947},{
      0.918351, 1.149233, 0.001947},{0.918398, 1.149087, 0.000000}}],
    Polygon[{{0.914553, 1.148631, 0.001947},{0.914553, 1.149087, 0.003846},{
      0.918210, 1.149666, 0.003846},{0.918351, 1.149233, 0.001947}}],
    Polygon[{{0.914553, 1.149087, 0.003846},{0.914553, 1.149835, 0.005650},{
      0.917979, 1.150377, 0.005650},{0.918210, 1.149666, 0.003846}}],
    Polygon[{{0.914553, 1.149835, 0.005650},{0.914553, 1.150855, 0.007315},{
      0.917664, 1.151348, 0.007315},{0.917979, 1.150377, 0.005650}}],
    Polygon[{{0.914553, 1.150855, 0.007315},{0.914553, 1.152123, 0.008800},{
      0.917272, 1.152554, 0.008800},{0.917664, 1.151348, 0.007315}}],
    Polygon[{{0.914553, 1.152123, 0.008800},{0.914553, 1.153608, 0.010068},{
      0.916813, 1.153966, 0.010068},{0.917272, 1.152554, 0.008800}}],
    Polygon[{{0.914553, 1.153608, 0.010068},{0.914553, 1.155273, 0.011089},{
      0.916299, 1.155550, 0.011089},{0.916813, 1.153966, 0.010068}}],
    Polygon[{{0.914553, 1.155273, 0.011089},{0.914553, 1.157077, 0.011836},{
      0.915741, 1.157266, 0.011836},{0.916299, 1.155550, 0.011089}}],
    Polygon[{{0.914553, 1.157077, 0.011836},{0.914553, 1.158976, 0.012292},{
      0.915154, 1.159071, 0.012292},{0.915741, 1.157266, 0.011836}}],
    Polygon[{{0.915154, 1.159071, -0.012292},{0.915741, 1.157266, -0.011836},{
      0.916813, 1.157812, -0.011836},{0.915697, 1.159348, -0.012292}}],
    Polygon[{{0.915741, 1.157266, -0.011836},{0.916299, 1.155550, -0.011089},{
      0.917874, 1.156352, -0.011089},{0.916813, 1.157812, -0.011836}}],
    Polygon[{{0.916299, 1.155550, -0.011089},{0.916813, 1.153966, -0.010068},{
      0.918852, 1.155005, -0.010068},{0.917874, 1.156352, -0.011089}}],
    Polygon[{{0.916813, 1.153966, -0.010068},{0.917272, 1.152554, -0.008800},{
      0.919725, 1.153804, -0.008800},{0.918852, 1.155005, -0.010068}}],
    Polygon[{{0.917272, 1.152554, -0.008800},{0.917664, 1.151348, -0.007315},{
      0.920471, 1.152778, -0.007315},{0.919725, 1.153804, -0.008800}}],
    Polygon[{{0.917664, 1.151348, -0.007315},{0.917979, 1.150377, -0.005650},{
      0.921070, 1.151952, -0.005650},{0.920471, 1.152778, -0.007315}}],
    Polygon[{{0.917979, 1.150377, -0.005650},{0.918210, 1.149666, -0.003846},{
      0.921510, 1.151348, -0.003846},{0.921070, 1.151952, -0.005650}}],
    Polygon[{{0.918210, 1.149666, -0.003846},{0.918351, 1.149233, -0.001947},{
      0.921777, 1.150979, -0.001947},{0.921510, 1.151348, -0.003846}}],
    Polygon[{{0.918351, 1.149233, -0.001947},{0.918398, 1.149087, 0.000000},{
      0.921868, 1.150855, 0.000000},{0.921777, 1.150979, -0.001947}}],
    Polygon[{{0.918398, 1.149087, 0.000000},{0.918351, 1.149233, 0.001947},{
      0.921777, 1.150979, 0.001947},{0.921868, 1.150855, 0.000000}}],
    Polygon[{{0.918351, 1.149233, 0.001947},{0.918210, 1.149666, 0.003846},{
      0.921510, 1.151348, 0.003846},{0.921777, 1.150979, 0.001947}}],
    Polygon[{{0.918210, 1.149666, 0.003846},{0.917979, 1.150377, 0.005650},{
      0.921070, 1.151952, 0.005650},{0.921510, 1.151348, 0.003846}}],
    Polygon[{{0.917979, 1.150377, 0.005650},{0.917664, 1.151348, 0.007315},{
      0.920471, 1.152778, 0.007315},{0.921070, 1.151952, 0.005650}}],
    Polygon[{{0.917664, 1.151348, 0.007315},{0.917272, 1.152554, 0.008800},{
      0.919725, 1.153804, 0.008800},{0.920471, 1.152778, 0.007315}}],
    Polygon[{{0.917272, 1.152554, 0.008800},{0.916813, 1.153966, 0.010068},{
      0.918852, 1.155005, 0.010068},{0.919725, 1.153804, 0.008800}}],
    Polygon[{{0.916813, 1.153966, 0.010068},{0.916299, 1.155550, 0.011089},{
      0.917874, 1.156352, 0.011089},{0.918852, 1.155005, 0.010068}}],
    Polygon[{{0.916299, 1.155550, 0.011089},{0.915741, 1.157266, 0.011836},{
      0.916813, 1.157812, 0.011836},{0.917874, 1.156352, 0.011089}}],
    Polygon[{{0.915741, 1.157266, 0.011836},{0.915154, 1.159071, 0.012292},{
      0.915697, 1.159348, 0.012292},{0.916813, 1.157812, 0.011836}}],
    Polygon[{{0.915697, 1.159348, -0.012292},{0.916813, 1.157812, -0.011836},{
      0.917664, 1.158663, -0.011836},{0.916128, 1.159779, -0.012292}}],
    Polygon[{{0.916813, 1.157812, -0.011836},{0.917874, 1.156352, -0.011089},{
      0.919123, 1.157602, -0.011089},{0.917664, 1.158663, -0.011836}}],
    Polygon[{{0.917874, 1.156352, -0.011089},{0.918852, 1.155005, -0.010068},{
      0.920471, 1.156623, -0.010068},{0.919123, 1.157602, -0.011089}}],
    Polygon[{{0.918852, 1.155005, -0.010068},{0.919725, 1.153804, -0.008800},{
      0.921672, 1.155751, -0.008800},{0.920471, 1.156623, -0.010068}}],
    Polygon[{{0.919725, 1.153804, -0.008800},{0.920471, 1.152778, -0.007315},{
      0.922698, 1.155005, -0.007315},{0.921672, 1.155751, -0.008800}}],
    Polygon[{{0.920471, 1.152778, -0.007315},{0.921070, 1.151952, -0.005650},{
      0.923523, 1.154405, -0.005650},{0.922698, 1.155005, -0.007315}}],
    Polygon[{{0.921070, 1.151952, -0.005650},{0.921510, 1.151348, -0.003846},{
      0.924128, 1.153966, -0.003846},{0.923523, 1.154405, -0.005650}}],
    Polygon[{{0.921510, 1.151348, -0.003846},{0.921777, 1.150979, -0.001947},{
      0.924497, 1.153698, -0.001947},{0.924128, 1.153966, -0.003846}}],
    Polygon[{{0.921777, 1.150979, -0.001947},{0.921868, 1.150855, 0.000000},{
      0.924621, 1.153608, 0.000000},{0.924497, 1.153698, -0.001947}}],
    Polygon[{{0.921868, 1.150855, 0.000000},{0.921777, 1.150979, 0.001947},{
      0.924497, 1.153698, 0.001947},{0.924621, 1.153608, 0.000000}}],
    Polygon[{{0.921777, 1.150979, 0.001947},{0.921510, 1.151348, 0.003846},{
      0.924128, 1.153966, 0.003846},{0.924497, 1.153698, 0.001947}}],
    Polygon[{{0.921510, 1.151348, 0.003846},{0.921070, 1.151952, 0.005650},{
      0.923523, 1.154405, 0.005650},{0.924128, 1.153966, 0.003846}}],
    Polygon[{{0.921070, 1.151952, 0.005650},{0.920471, 1.152778, 0.007315},{
      0.922698, 1.155005, 0.007315},{0.923523, 1.154405, 0.005650}}],
    Polygon[{{0.920471, 1.152778, 0.007315},{0.919725, 1.153804, 0.008800},{
      0.921672, 1.155751, 0.008800},{0.922698, 1.155005, 0.007315}}],
    Polygon[{{0.919725, 1.153804, 0.008800},{0.918852, 1.155005, 0.010068},{
      0.920471, 1.156623, 0.010068},{0.921672, 1.155751, 0.008800}}],
    Polygon[{{0.918852, 1.155005, 0.010068},{0.917874, 1.156352, 0.011089},{
      0.919123, 1.157602, 0.011089},{0.920471, 1.156623, 0.010068}}],
    Polygon[{{0.917874, 1.156352, 0.011089},{0.916813, 1.157812, 0.011836},{
      0.917664, 1.158663, 0.011836},{0.919123, 1.157602, 0.011089}}],
    Polygon[{{0.916813, 1.157812, 0.011836},{0.915697, 1.159348, 0.012292},{
      0.916128, 1.159779, 0.012292},{0.917664, 1.158663, 0.011836}}],
    Polygon[{{0.916128, 1.159779, -0.012292},{0.917664, 1.158663, -0.011836},{
      0.918210, 1.159735, -0.011836},{0.916404, 1.160321, -0.012292}}],
    Polygon[{{0.917664, 1.158663, -0.011836},{0.919123, 1.157602, -0.011089},{
      0.919926, 1.159177, -0.011089},{0.918210, 1.159735, -0.011836}}],
    Polygon[{{0.919123, 1.157602, -0.011089},{0.920471, 1.156623, -0.010068},{
      0.921510, 1.158663, -0.010068},{0.919926, 1.159177, -0.011089}}],
    Polygon[{{0.920471, 1.156623, -0.010068},{0.921672, 1.155751, -0.008800},{
      0.922922, 1.158204, -0.008800},{0.921510, 1.158663, -0.010068}}],
    Polygon[{{0.921672, 1.155751, -0.008800},{0.922698, 1.155005, -0.007315},{
      0.924128, 1.157812, -0.007315},{0.922922, 1.158204, -0.008800}}],
    Polygon[{{0.922698, 1.155005, -0.007315},{0.923523, 1.154405, -0.005650},{
      0.925098, 1.157496, -0.005650},{0.924128, 1.157812, -0.007315}}],
    Polygon[{{0.923523, 1.154405, -0.005650},{0.924128, 1.153966, -0.003846},{
      0.925809, 1.157266, -0.003846},{0.925098, 1.157496, -0.005650}}],
    Polygon[{{0.924128, 1.153966, -0.003846},{0.924497, 1.153698, -0.001947},{
      0.926243, 1.157125, -0.001947},{0.925809, 1.157266, -0.003846}}],
    Polygon[{{0.924497, 1.153698, -0.001947},{0.924621, 1.153608, 0.000000},{
      0.926388, 1.157077, 0.000000},{0.926243, 1.157125, -0.001947}}],
    Polygon[{{0.924621, 1.153608, 0.000000},{0.924497, 1.153698, 0.001947},{
      0.926243, 1.157125, 0.001947},{0.926388, 1.157077, 0.000000}}],
    Polygon[{{0.924497, 1.153698, 0.001947},{0.924128, 1.153966, 0.003846},{
      0.925809, 1.157266, 0.003846},{0.926243, 1.157125, 0.001947}}],
    Polygon[{{0.924128, 1.153966, 0.003846},{0.923523, 1.154405, 0.005650},{
      0.925098, 1.157496, 0.005650},{0.925809, 1.157266, 0.003846}}],
    Polygon[{{0.923523, 1.154405, 0.005650},{0.922698, 1.155005, 0.007315},{
      0.924128, 1.157812, 0.007315},{0.925098, 1.157496, 0.005650}}],
    Polygon[{{0.922698, 1.155005, 0.007315},{0.921672, 1.155751, 0.008800},{
      0.922922, 1.158204, 0.008800},{0.924128, 1.157812, 0.007315}}],
    Polygon[{{0.921672, 1.155751, 0.008800},{0.920471, 1.156623, 0.010068},{
      0.921510, 1.158663, 0.010068},{0.922922, 1.158204, 0.008800}}],
    Polygon[{{0.920471, 1.156623, 0.010068},{0.919123, 1.157602, 0.011089},{
      0.919926, 1.159177, 0.011089},{0.921510, 1.158663, 0.010068}}],
    Polygon[{{0.919123, 1.157602, 0.011089},{0.917664, 1.158663, 0.011836},{
      0.918210, 1.159735, 0.011836},{0.919926, 1.159177, 0.011089}}],
    Polygon[{{0.917664, 1.158663, 0.011836},{0.916128, 1.159779, 0.012292},{
      0.916404, 1.160321, 0.012292},{0.918210, 1.159735, 0.011836}}],
    Polygon[{{0.916404, 1.160321, -0.012292},{0.918210, 1.159735, -0.011836},{
      0.918398, 1.160923, -0.011836},{0.916499, 1.160923, -0.012292}}],
    Polygon[{{0.918210, 1.159735, -0.011836},{0.919926, 1.159177, -0.011089},{
      0.920202, 1.160923, -0.011089},{0.918398, 1.160923, -0.011836}}],
    Polygon[{{0.919926, 1.159177, -0.011089},{0.921510, 1.158663, -0.010068},{
      0.921868, 1.160923, -0.010068},{0.920202, 1.160923, -0.011089}}],
    Polygon[{{0.921510, 1.158663, -0.010068},{0.922922, 1.158204, -0.008800},{
      0.923353, 1.160923, -0.008800},{0.921868, 1.160923, -0.010068}}],
    Polygon[{{0.922922, 1.158204, -0.008800},{0.924128, 1.157812, -0.007315},{
      0.924621, 1.160923, -0.007315},{0.923353, 1.160923, -0.008800}}],
    Polygon[{{0.924128, 1.157812, -0.007315},{0.925098, 1.157496, -0.005650},{
      0.925641, 1.160923, -0.005650},{0.924621, 1.160923, -0.007315}}],
    Polygon[{{0.925098, 1.157496, -0.005650},{0.925809, 1.157266, -0.003846},{
      0.926388, 1.160923, -0.003846},{0.925641, 1.160923, -0.005650}}],
    Polygon[{{0.925809, 1.157266, -0.003846},{0.926243, 1.157125, -0.001947},{
      0.926844, 1.160923, -0.001947},{0.926388, 1.160923, -0.003846}}],
    Polygon[{{0.926243, 1.157125, -0.001947},{0.926388, 1.157077, 0.000000},{
      0.926998, 1.160923, 0.000000},{0.926844, 1.160923, -0.001947}}],
    Polygon[{{0.926388, 1.157077, 0.000000},{0.926243, 1.157125, 0.001947},{
      0.926844, 1.160923, 0.001947},{0.926998, 1.160923, 0.000000}}],
    Polygon[{{0.926243, 1.157125, 0.001947},{0.925809, 1.157266, 0.003846},{
      0.926388, 1.160923, 0.003846},{0.926844, 1.160923, 0.001947}}],
    Polygon[{{0.925809, 1.157266, 0.003846},{0.925098, 1.157496, 0.005650},{
      0.925641, 1.160923, 0.005650},{0.926388, 1.160923, 0.003846}}],
    Polygon[{{0.925098, 1.157496, 0.005650},{0.924128, 1.157812, 0.007315},{
      0.924621, 1.160923, 0.007315},{0.925641, 1.160923, 0.005650}}],
    Polygon[{{0.924128, 1.157812, 0.007315},{0.922922, 1.158204, 0.008800},{
      0.923353, 1.160923, 0.008800},{0.924621, 1.160923, 0.007315}}],
    Polygon[{{0.922922, 1.158204, 0.008800},{0.921510, 1.158663, 0.010068},{
      0.921868, 1.160923, 0.010068},{0.923353, 1.160923, 0.008800}}],
    Polygon[{{0.921510, 1.158663, 0.010068},{0.919926, 1.159177, 0.011089},{
      0.920202, 1.160923, 0.011089},{0.921868, 1.160923, 0.010068}}],
    Polygon[{{0.919926, 1.159177, 0.011089},{0.918210, 1.159735, 0.011836},{
      0.918398, 1.160923, 0.011836},{0.920202, 1.160923, 0.011089}}],
    Polygon[{{0.918210, 1.159735, 0.011836},{0.916404, 1.160321, 0.012292},{
      0.916499, 1.160923, 0.012292},{0.918398, 1.160923, 0.011836}}],
    Polygon[{{0.852171, 1.145043, -0.009538},{0.853645, 1.145043, -0.009185},{
      0.853499, 1.145966, -0.009185},{0.852097, 1.145510, -0.009538}}],
    Polygon[{{0.853645, 1.145043, -0.009185},{0.855045, 1.145043, -0.008605},{
      0.854830, 1.146398, -0.008605},{0.853499, 1.145966, -0.009185}}],
    Polygon[{{0.855045, 1.145043, -0.008605},{0.856337, 1.145043, -0.007813},{
      0.856059, 1.146797, -0.007813},{0.854830, 1.146398, -0.008605}}],
    Polygon[{{0.856337, 1.145043, -0.007813},{0.857489, 1.145043, -0.006829},{
      0.857155, 1.147153, -0.006829},{0.856059, 1.146797, -0.007813}}],
    Polygon[{{0.857489, 1.145043, -0.006829},{0.858473, 1.145043, -0.005676},{
      0.858091, 1.147458, -0.005676},{0.857155, 1.147153, -0.006829}}],
    Polygon[{{0.858473, 1.145043, -0.005676},{0.859265, 1.145043, -0.004384},{
      0.858844, 1.147702, -0.004384},{0.858091, 1.147458, -0.005676}}],
    Polygon[{{0.859265, 1.145043, -0.004384},{0.859845, 1.145043, -0.002984},{
      0.859396, 1.147882, -0.002984},{0.858844, 1.147702, -0.004384}}],
    Polygon[{{0.859845, 1.145043, -0.002984},{0.860199, 1.145043, -0.001511},{
      0.859732, 1.147991, -0.001511},{0.859396, 1.147882, -0.002984}}],
    Polygon[{{0.860199, 1.145043, -0.001511},{0.860318, 1.145043, 0.000000},{
      0.859845, 1.148028, 0.000000},{0.859732, 1.147991, -0.001511}}],
    Polygon[{{0.860318, 1.145043, 0.000000},{0.860199, 1.145043, 0.001511},{
      0.859732, 1.147991, 0.001511},{0.859845, 1.148028, 0.000000}}],
    Polygon[{{0.860199, 1.145043, 0.001511},{0.859845, 1.145043, 0.002984},{
      0.859396, 1.147882, 0.002984},{0.859732, 1.147991, 0.001511}}],
    Polygon[{{0.859845, 1.145043, 0.002984},{0.859265, 1.145043, 0.004384},{
      0.858844, 1.147702, 0.004384},{0.859396, 1.147882, 0.002984}}],
    Polygon[{{0.859265, 1.145043, 0.004384},{0.858473, 1.145043, 0.005676},{
      0.858091, 1.147458, 0.005676},{0.858844, 1.147702, 0.004384}}],
    Polygon[{{0.858473, 1.145043, 0.005676},{0.857489, 1.145043, 0.006829},{
      0.857155, 1.147153, 0.006829},{0.858091, 1.147458, 0.005676}}],
    Polygon[{{0.857489, 1.145043, 0.006829},{0.856337, 1.145043, 0.007813},{
      0.856059, 1.146797, 0.007813},{0.857155, 1.147153, 0.006829}}],
    Polygon[{{0.856337, 1.145043, 0.007813},{0.855045, 1.145043, 0.008605},{
      0.854830, 1.146398, 0.008605},{0.856059, 1.146797, 0.007813}}],
    Polygon[{{0.855045, 1.145043, 0.008605},{0.853645, 1.145043, 0.009185},{
      0.853499, 1.145966, 0.009185},{0.854830, 1.146398, 0.008605}}],
    Polygon[{{0.853645, 1.145043, 0.009185},{0.852171, 1.145043, 0.009538},{
      0.852097, 1.145510, 0.009538},{0.853499, 1.145966, 0.009185}}],
    Polygon[{{0.852097, 1.145510, -0.009538},{0.853499, 1.145966, -0.009185},{
      0.853075, 1.146797, -0.009185},{0.851883, 1.145931, -0.009538}}],
    Polygon[{{0.853499, 1.145966, -0.009185},{0.854830, 1.146398, -0.008605},{
      0.854207, 1.147620, -0.008605},{0.853075, 1.146797, -0.009185}}],
    Polygon[{{0.854830, 1.146398, -0.008605},{0.856059, 1.146797, -0.007813},{
      0.855253, 1.148380, -0.007813},{0.854207, 1.147620, -0.008605}}],
    Polygon[{{0.856059, 1.146797, -0.007813},{0.857155, 1.147153, -0.006829},{
      0.856185, 1.149057, -0.006829},{0.855253, 1.148380, -0.007813}}],
    Polygon[{{0.857155, 1.147153, -0.006829},{0.858091, 1.147458, -0.005676},{
      0.856981, 1.149636, -0.005676},{0.856185, 1.149057, -0.006829}}],
    Polygon[{{0.858091, 1.147458, -0.005676},{0.858844, 1.147702, -0.004384},{
      0.857622, 1.150101, -0.004384},{0.856981, 1.149636, -0.005676}}],
    Polygon[{{0.858844, 1.147702, -0.004384},{0.859396, 1.147882, -0.002984},{
      0.858091, 1.150442, -0.002984},{0.857622, 1.150101, -0.004384}}],
    Polygon[{{0.859396, 1.147882, -0.002984},{0.859732, 1.147991, -0.001511},{
      0.858377, 1.150650, -0.001511},{0.858091, 1.150442, -0.002984}}],
    Polygon[{{0.859732, 1.147991, -0.001511},{0.859845, 1.148028, 0.000000},{
      0.858473, 1.150720, 0.000000},{0.858377, 1.150650, -0.001511}}],
    Polygon[{{0.859845, 1.148028, 0.000000},{0.859732, 1.147991, 0.001511},{
      0.858377, 1.150650, 0.001511},{0.858473, 1.150720, 0.000000}}],
    Polygon[{{0.859732, 1.147991, 0.001511},{0.859396, 1.147882, 0.002984},{
      0.858091, 1.150442, 0.002984},{0.858377, 1.150650, 0.001511}}],
    Polygon[{{0.859396, 1.147882, 0.002984},{0.858844, 1.147702, 0.004384},{
      0.857622, 1.150101, 0.004384},{0.858091, 1.150442, 0.002984}}],
    Polygon[{{0.858844, 1.147702, 0.004384},{0.858091, 1.147458, 0.005676},{
      0.856981, 1.149636, 0.005676},{0.857622, 1.150101, 0.004384}}],
    Polygon[{{0.858091, 1.147458, 0.005676},{0.857155, 1.147153, 0.006829},{
      0.856185, 1.149057, 0.006829},{0.856981, 1.149636, 0.005676}}],
    Polygon[{{0.857155, 1.147153, 0.006829},{0.856059, 1.146797, 0.007813},{
      0.855253, 1.148380, 0.007813},{0.856185, 1.149057, 0.006829}}],
    Polygon[{{0.856059, 1.146797, 0.007813},{0.854830, 1.146398, 0.008605},{
      0.854207, 1.147620, 0.008605},{0.855253, 1.148380, 0.007813}}],
    Polygon[{{0.854830, 1.146398, 0.008605},{0.853499, 1.145966, 0.009185},{
      0.853075, 1.146797, 0.009185},{0.854207, 1.147620, 0.008605}}],
    Polygon[{{0.853499, 1.145966, 0.009185},{0.852097, 1.145510, 0.009538},{
      0.851883, 1.145931, 0.009538},{0.853075, 1.146797, 0.009185}}],
    Polygon[{{0.851883, 1.145931, -0.009538},{0.853075, 1.146797, -0.009185},{
      0.852415, 1.147458, -0.009185},{0.851548, 1.146266, -0.009538}}],
    Polygon[{{0.853075, 1.146797, -0.009185},{0.854207, 1.147620, -0.008605},{
      0.853238, 1.148590, -0.008605},{0.852415, 1.147458, -0.009185}}],
    Polygon[{{0.854207, 1.147620, -0.008605},{0.855253, 1.148380, -0.007813},{
      0.853997, 1.149636, -0.007813},{0.853238, 1.148590, -0.008605}}],
    Polygon[{{0.855253, 1.148380, -0.007813},{0.856185, 1.149057, -0.006829},{
      0.854674, 1.150568, -0.006829},{0.853997, 1.149636, -0.007813}}],
    Polygon[{{0.856185, 1.149057, -0.006829},{0.856981, 1.149636, -0.005676},{
      0.855253, 1.151364, -0.005676},{0.854674, 1.150568, -0.006829}}],
    Polygon[{{0.856981, 1.149636, -0.005676},{0.857622, 1.150101, -0.004384},{
      0.855718, 1.152005, -0.004384},{0.855253, 1.151364, -0.005676}}],
    Polygon[{{0.857622, 1.150101, -0.004384},{0.858091, 1.150442, -0.002984},{
      0.856059, 1.152474, -0.002984},{0.855718, 1.152005, -0.004384}}],
    Polygon[{{0.858091, 1.150442, -0.002984},{0.858377, 1.150650, -0.001511},{
      0.856267, 1.152760, -0.001511},{0.856059, 1.152474, -0.002984}}],
    Polygon[{{0.858377, 1.150650, -0.001511},{0.858473, 1.150720, 0.000000},{
      0.856337, 1.152856, 0.000000},{0.856267, 1.152760, -0.001511}}],
    Polygon[{{0.858473, 1.150720, 0.000000},{0.858377, 1.150650, 0.001511},{
      0.856267, 1.152760, 0.001511},{0.856337, 1.152856, 0.000000}}],
    Polygon[{{0.858377, 1.150650, 0.001511},{0.858091, 1.150442, 0.002984},{
      0.856059, 1.152474, 0.002984},{0.856267, 1.152760, 0.001511}}],
    Polygon[{{0.858091, 1.150442, 0.002984},{0.857622, 1.150101, 0.004384},{
      0.855718, 1.152005, 0.004384},{0.856059, 1.152474, 0.002984}}],
    Polygon[{{0.857622, 1.150101, 0.004384},{0.856981, 1.149636, 0.005676},{
      0.855253, 1.151364, 0.005676},{0.855718, 1.152005, 0.004384}}],
    Polygon[{{0.856981, 1.149636, 0.005676},{0.856185, 1.149057, 0.006829},{
      0.854674, 1.150568, 0.006829},{0.855253, 1.151364, 0.005676}}],
    Polygon[{{0.856185, 1.149057, 0.006829},{0.855253, 1.148380, 0.007813},{
      0.853997, 1.149636, 0.007813},{0.854674, 1.150568, 0.006829}}],
    Polygon[{{0.855253, 1.148380, 0.007813},{0.854207, 1.147620, 0.008605},{
      0.853238, 1.148590, 0.008605},{0.853997, 1.149636, 0.007813}}],
    Polygon[{{0.854207, 1.147620, 0.008605},{0.853075, 1.146797, 0.009185},{
      0.852415, 1.147458, 0.009185},{0.853238, 1.148590, 0.008605}}],
    Polygon[{{0.853075, 1.146797, 0.009185},{0.851883, 1.145931, 0.009538},{
      0.851548, 1.146266, 0.009538},{0.852415, 1.147458, 0.009185}}],
    Polygon[{{0.851548, 1.146266, -0.009538},{0.852415, 1.147458, -0.009185},{
      0.851583, 1.147882, -0.009185},{0.851127, 1.146480, -0.009538}}],
    Polygon[{{0.852415, 1.147458, -0.009185},{0.853238, 1.148590, -0.008605},{
      0.852015, 1.149213, -0.008605},{0.851583, 1.147882, -0.009185}}],
    Polygon[{{0.853238, 1.148590, -0.008605},{0.853997, 1.149636, -0.007813},{
      0.852415, 1.150442, -0.007813},{0.852015, 1.149213, -0.008605}}],
    Polygon[{{0.853997, 1.149636, -0.007813},{0.854674, 1.150568, -0.006829},{
      0.852771, 1.151538, -0.006829},{0.852415, 1.150442, -0.007813}}],
    Polygon[{{0.854674, 1.150568, -0.006829},{0.855253, 1.151364, -0.005676},{
      0.853075, 1.152474, -0.005676},{0.852771, 1.151538, -0.006829}}],
    Polygon[{{0.855253, 1.151364, -0.005676},{0.855718, 1.152005, -0.004384},{
      0.853319, 1.153227, -0.004384},{0.853075, 1.152474, -0.005676}}],
    Polygon[{{0.855718, 1.152005, -0.004384},{0.856059, 1.152474, -0.002984},{
      0.853499, 1.153778, -0.002984},{0.853319, 1.153227, -0.004384}}],
    Polygon[{{0.856059, 1.152474, -0.002984},{0.856267, 1.152760, -0.001511},{
      0.853608, 1.154115, -0.001511},{0.853499, 1.153778, -0.002984}}],
    Polygon[{{0.856267, 1.152760, -0.001511},{0.856337, 1.152856, 0.000000},{
      0.853645, 1.154228, 0.000000},{0.853608, 1.154115, -0.001511}}],
    Polygon[{{0.856337, 1.152856, 0.000000},{0.856267, 1.152760, 0.001511},{
      0.853608, 1.154115, 0.001511},{0.853645, 1.154228, 0.000000}}],
    Polygon[{{0.856267, 1.152760, 0.001511},{0.856059, 1.152474, 0.002984},{
      0.853499, 1.153778, 0.002984},{0.853608, 1.154115, 0.001511}}],
    Polygon[{{0.856059, 1.152474, 0.002984},{0.855718, 1.152005, 0.004384},{
      0.853319, 1.153227, 0.004384},{0.853499, 1.153778, 0.002984}}],
    Polygon[{{0.855718, 1.152005, 0.004384},{0.855253, 1.151364, 0.005676},{
      0.853075, 1.152474, 0.005676},{0.853319, 1.153227, 0.004384}}],
    Polygon[{{0.855253, 1.151364, 0.005676},{0.854674, 1.150568, 0.006829},{
      0.852771, 1.151538, 0.006829},{0.853075, 1.152474, 0.005676}}],
    Polygon[{{0.854674, 1.150568, 0.006829},{0.853997, 1.149636, 0.007813},{
      0.852415, 1.150442, 0.007813},{0.852771, 1.151538, 0.006829}}],
    Polygon[{{0.853997, 1.149636, 0.007813},{0.853238, 1.148590, 0.008605},{
      0.852015, 1.149213, 0.008605},{0.852415, 1.150442, 0.007813}}],
    Polygon[{{0.853238, 1.148590, 0.008605},{0.852415, 1.147458, 0.009185},{
      0.851583, 1.147882, 0.009185},{0.852015, 1.149213, 0.008605}}],
    Polygon[{{0.852415, 1.147458, 0.009185},{0.851548, 1.146266, 0.009538},{
      0.851127, 1.146480, 0.009538},{0.851583, 1.147882, 0.009185}}],
    Polygon[{{0.851127, 1.146480, -0.009538},{0.851583, 1.147882, -0.009185},{
      0.850661, 1.148028, -0.009185},{0.850661, 1.146554, -0.009538}}],
    Polygon[{{0.851583, 1.147882, -0.009185},{0.852015, 1.149213, -0.008605},{
      0.850661, 1.149428, -0.008605},{0.850661, 1.148028, -0.009185}}],
    Polygon[{{0.852015, 1.149213, -0.008605},{0.852415, 1.150442, -0.007813},{
      0.850661, 1.150720, -0.007813},{0.850661, 1.149428, -0.008605}}],
    Polygon[{{0.852415, 1.150442, -0.007813},{0.852771, 1.151538, -0.006829},{
      0.850661, 1.151872, -0.006829},{0.850661, 1.150720, -0.007813}}],
    Polygon[{{0.852771, 1.151538, -0.006829},{0.853075, 1.152474, -0.005676},{
      0.850661, 1.152856, -0.005676},{0.850661, 1.151872, -0.006829}}],
    Polygon[{{0.853075, 1.152474, -0.005676},{0.853319, 1.153227, -0.004384},{
      0.850661, 1.153648, -0.004384},{0.850661, 1.152856, -0.005676}}],
    Polygon[{{0.853319, 1.153227, -0.004384},{0.853499, 1.153778, -0.002984},{
      0.850661, 1.154228, -0.002984},{0.850661, 1.153648, -0.004384}}],
    Polygon[{{0.853499, 1.153778, -0.002984},{0.853608, 1.154115, -0.001511},{
      0.850661, 1.154582, -0.001511},{0.850661, 1.154228, -0.002984}}],
    Polygon[{{0.853608, 1.154115, -0.001511},{0.853645, 1.154228, 0.000000},{
      0.850661, 1.154701, 0.000000},{0.850661, 1.154582, -0.001511}}],
    Polygon[{{0.853645, 1.154228, 0.000000},{0.853608, 1.154115, 0.001511},{
      0.850661, 1.154582, 0.001511},{0.850661, 1.154701, 0.000000}}],
    Polygon[{{0.853608, 1.154115, 0.001511},{0.853499, 1.153778, 0.002984},{
      0.850661, 1.154228, 0.002984},{0.850661, 1.154582, 0.001511}}],
    Polygon[{{0.853499, 1.153778, 0.002984},{0.853319, 1.153227, 0.004384},{
      0.850661, 1.153648, 0.004384},{0.850661, 1.154228, 0.002984}}],
    Polygon[{{0.853319, 1.153227, 0.004384},{0.853075, 1.152474, 0.005676},{
      0.850661, 1.152856, 0.005676},{0.850661, 1.153648, 0.004384}}],
    Polygon[{{0.853075, 1.152474, 0.005676},{0.852771, 1.151538, 0.006829},{
      0.850661, 1.151872, 0.006829},{0.850661, 1.152856, 0.005676}}],
    Polygon[{{0.852771, 1.151538, 0.006829},{0.852415, 1.150442, 0.007813},{
      0.850661, 1.150720, 0.007813},{0.850661, 1.151872, 0.006829}}],
    Polygon[{{0.852415, 1.150442, 0.007813},{0.852015, 1.149213, 0.008605},{
      0.850661, 1.149428, 0.008605},{0.850661, 1.150720, 0.007813}}],
    Polygon[{{0.852015, 1.149213, 0.008605},{0.851583, 1.147882, 0.009185},{
      0.850661, 1.148028, 0.009185},{0.850661, 1.149428, 0.008605}}],
    Polygon[{{0.851583, 1.147882, 0.009185},{0.851127, 1.146480, 0.009538},{
      0.850661, 1.146554, 0.009538},{0.850661, 1.148028, 0.009185}}],
    Polygon[{{0.850661, 1.146554, -0.009538},{0.850661, 1.148028, -0.009185},{
      0.849738, 1.147882, -0.009185},{0.850194, 1.146480, -0.009538}}],
    Polygon[{{0.850661, 1.148028, -0.009185},{0.850661, 1.149428, -0.008605},{
      0.849306, 1.149213, -0.008605},{0.849738, 1.147882, -0.009185}}],
    Polygon[{{0.850661, 1.149428, -0.008605},{0.850661, 1.150720, -0.007813},{
      0.848906, 1.150442, -0.007813},{0.849306, 1.149213, -0.008605}}],
    Polygon[{{0.850661, 1.150720, -0.007813},{0.850661, 1.151872, -0.006829},{
      0.848550, 1.151538, -0.006829},{0.848906, 1.150442, -0.007813}}],
    Polygon[{{0.850661, 1.151872, -0.006829},{0.850661, 1.152856, -0.005676},{
      0.848246, 1.152474, -0.005676},{0.848550, 1.151538, -0.006829}}],
    Polygon[{{0.850661, 1.152856, -0.005676},{0.850661, 1.153648, -0.004384},{
      0.848002, 1.153227, -0.004384},{0.848246, 1.152474, -0.005676}}],
    Polygon[{{0.850661, 1.153648, -0.004384},{0.850661, 1.154228, -0.002984},{
      0.847822, 1.153778, -0.002984},{0.848002, 1.153227, -0.004384}}],
    Polygon[{{0.850661, 1.154228, -0.002984},{0.850661, 1.154582, -0.001511},{
      0.847713, 1.154115, -0.001511},{0.847822, 1.153778, -0.002984}}],
    Polygon[{{0.850661, 1.154582, -0.001511},{0.850661, 1.154701, 0.000000},{
      0.847676, 1.154228, 0.000000},{0.847713, 1.154115, -0.001511}}],
    Polygon[{{0.850661, 1.154701, 0.000000},{0.850661, 1.154582, 0.001511},{
      0.847713, 1.154115, 0.001511},{0.847676, 1.154228, 0.000000}}],
    Polygon[{{0.850661, 1.154582, 0.001511},{0.850661, 1.154228, 0.002984},{
      0.847822, 1.153778, 0.002984},{0.847713, 1.154115, 0.001511}}],
    Polygon[{{0.850661, 1.154228, 0.002984},{0.850661, 1.153648, 0.004384},{
      0.848002, 1.153227, 0.004384},{0.847822, 1.153778, 0.002984}}],
    Polygon[{{0.850661, 1.153648, 0.004384},{0.850661, 1.152856, 0.005676},{
      0.848246, 1.152474, 0.005676},{0.848002, 1.153227, 0.004384}}],
    Polygon[{{0.850661, 1.152856, 0.005676},{0.850661, 1.151872, 0.006829},{
      0.848550, 1.151538, 0.006829},{0.848246, 1.152474, 0.005676}}],
    Polygon[{{0.850661, 1.151872, 0.006829},{0.850661, 1.150720, 0.007813},{
      0.848906, 1.150442, 0.007813},{0.848550, 1.151538, 0.006829}}],
    Polygon[{{0.850661, 1.150720, 0.007813},{0.850661, 1.149428, 0.008605},{
      0.849306, 1.149213, 0.008605},{0.848906, 1.150442, 0.007813}}],
    Polygon[{{0.850661, 1.149428, 0.008605},{0.850661, 1.148028, 0.009185},{
      0.849738, 1.147882, 0.009185},{0.849306, 1.149213, 0.008605}}],
    Polygon[{{0.850661, 1.148028, 0.009185},{0.850661, 1.146554, 0.009538},{
      0.850194, 1.146480, 0.009538},{0.849738, 1.147882, 0.009185}}],
    Polygon[{{0.850194, 1.146480, -0.009538},{0.849738, 1.147882, -0.009185},{
      0.848906, 1.147458, -0.009185},{0.849773, 1.146266, -0.009538}}],
    Polygon[{{0.849738, 1.147882, -0.009185},{0.849306, 1.149213, -0.008605},{
      0.848083, 1.148590, -0.008605},{0.848906, 1.147458, -0.009185}}],
    Polygon[{{0.849306, 1.149213, -0.008605},{0.848906, 1.150442, -0.007813},{
      0.847324, 1.149636, -0.007813},{0.848083, 1.148590, -0.008605}}],
    Polygon[{{0.848906, 1.150442, -0.007813},{0.848550, 1.151538, -0.006829},{
      0.846647, 1.150568, -0.006829},{0.847324, 1.149636, -0.007813}}],
    Polygon[{{0.848550, 1.151538, -0.006829},{0.848246, 1.152474, -0.005676},{
      0.846068, 1.151364, -0.005676},{0.846647, 1.150568, -0.006829}}],
    Polygon[{{0.848246, 1.152474, -0.005676},{0.848002, 1.153227, -0.004384},{
      0.845603, 1.152005, -0.004384},{0.846068, 1.151364, -0.005676}}],
    Polygon[{{0.848002, 1.153227, -0.004384},{0.847822, 1.153778, -0.002984},{
      0.845262, 1.152474, -0.002984},{0.845603, 1.152005, -0.004384}}],
    Polygon[{{0.847822, 1.153778, -0.002984},{0.847713, 1.154115, -0.001511},{
      0.845054, 1.152760, -0.001511},{0.845262, 1.152474, -0.002984}}],
    Polygon[{{0.847713, 1.154115, -0.001511},{0.847676, 1.154228, 0.000000},{
      0.844984, 1.152856, 0.000000},{0.845054, 1.152760, -0.001511}}],
    Polygon[{{0.847676, 1.154228, 0.000000},{0.847713, 1.154115, 0.001511},{
      0.845054, 1.152760, 0.001511},{0.844984, 1.152856, 0.000000}}],
    Polygon[{{0.847713, 1.154115, 0.001511},{0.847822, 1.153778, 0.002984},{
      0.845262, 1.152474, 0.002984},{0.845054, 1.152760, 0.001511}}],
    Polygon[{{0.847822, 1.153778, 0.002984},{0.848002, 1.153227, 0.004384},{
      0.845603, 1.152005, 0.004384},{0.845262, 1.152474, 0.002984}}],
    Polygon[{{0.848002, 1.153227, 0.004384},{0.848246, 1.152474, 0.005676},{
      0.846068, 1.151364, 0.005676},{0.845603, 1.152005, 0.004384}}],
    Polygon[{{0.848246, 1.152474, 0.005676},{0.848550, 1.151538, 0.006829},{
      0.846647, 1.150568, 0.006829},{0.846068, 1.151364, 0.005676}}],
    Polygon[{{0.848550, 1.151538, 0.006829},{0.848906, 1.150442, 0.007813},{
      0.847324, 1.149636, 0.007813},{0.846647, 1.150568, 0.006829}}],
    Polygon[{{0.848906, 1.150442, 0.007813},{0.849306, 1.149213, 0.008605},{
      0.848083, 1.148590, 0.008605},{0.847324, 1.149636, 0.007813}}],
    Polygon[{{0.849306, 1.149213, 0.008605},{0.849738, 1.147882, 0.009185},{
      0.848906, 1.147458, 0.009185},{0.848083, 1.148590, 0.008605}}],
    Polygon[{{0.849738, 1.147882, 0.009185},{0.850194, 1.146480, 0.009538},{
      0.849773, 1.146266, 0.009538},{0.848906, 1.147458, 0.009185}}],
    Polygon[{{0.849773, 1.146266, -0.009538},{0.848906, 1.147458, -0.009185},{
      0.848246, 1.146797, -0.009185},{0.849438, 1.145931, -0.009538}}],
    Polygon[{{0.848906, 1.147458, -0.009185},{0.848083, 1.148590, -0.008605},{
      0.847114, 1.147620, -0.008605},{0.848246, 1.146797, -0.009185}}],
    Polygon[{{0.848083, 1.148590, -0.008605},{0.847324, 1.149636, -0.007813},{
      0.846068, 1.148380, -0.007813},{0.847114, 1.147620, -0.008605}}],
    Polygon[{{0.847324, 1.149636, -0.007813},{0.846647, 1.150568, -0.006829},{
      0.845136, 1.149057, -0.006829},{0.846068, 1.148380, -0.007813}}],
    Polygon[{{0.846647, 1.150568, -0.006829},{0.846068, 1.151364, -0.005676},{
      0.844340, 1.149636, -0.005676},{0.845136, 1.149057, -0.006829}}],
    Polygon[{{0.846068, 1.151364, -0.005676},{0.845603, 1.152005, -0.004384},{
      0.843699, 1.150101, -0.004384},{0.844340, 1.149636, -0.005676}}],
    Polygon[{{0.845603, 1.152005, -0.004384},{0.845262, 1.152474, -0.002984},{
      0.843230, 1.150442, -0.002984},{0.843699, 1.150101, -0.004384}}],
    Polygon[{{0.845262, 1.152474, -0.002984},{0.845054, 1.152760, -0.001511},{
      0.842944, 1.150650, -0.001511},{0.843230, 1.150442, -0.002984}}],
    Polygon[{{0.845054, 1.152760, -0.001511},{0.844984, 1.152856, 0.000000},{
      0.842848, 1.150720, 0.000000},{0.842944, 1.150650, -0.001511}}],
    Polygon[{{0.844984, 1.152856, 0.000000},{0.845054, 1.152760, 0.001511},{
      0.842944, 1.150650, 0.001511},{0.842848, 1.150720, 0.000000}}],
    Polygon[{{0.845054, 1.152760, 0.001511},{0.845262, 1.152474, 0.002984},{
      0.843230, 1.150442, 0.002984},{0.842944, 1.150650, 0.001511}}],
    Polygon[{{0.845262, 1.152474, 0.002984},{0.845603, 1.152005, 0.004384},{
      0.843699, 1.150101, 0.004384},{0.843230, 1.150442, 0.002984}}],
    Polygon[{{0.845603, 1.152005, 0.004384},{0.846068, 1.151364, 0.005676},{
      0.844340, 1.149636, 0.005676},{0.843699, 1.150101, 0.004384}}],
    Polygon[{{0.846068, 1.151364, 0.005676},{0.846647, 1.150568, 0.006829},{
      0.845136, 1.149057, 0.006829},{0.844340, 1.149636, 0.005676}}],
    Polygon[{{0.846647, 1.150568, 0.006829},{0.847324, 1.149636, 0.007813},{
      0.846068, 1.148380, 0.007813},{0.845136, 1.149057, 0.006829}}],
    Polygon[{{0.847324, 1.149636, 0.007813},{0.848083, 1.148590, 0.008605},{
      0.847114, 1.147620, 0.008605},{0.846068, 1.148380, 0.007813}}],
    Polygon[{{0.848083, 1.148590, 0.008605},{0.848906, 1.147458, 0.009185},{
      0.848246, 1.146797, 0.009185},{0.847114, 1.147620, 0.008605}}],
    Polygon[{{0.848906, 1.147458, 0.009185},{0.849773, 1.146266, 0.009538},{
      0.849438, 1.145931, 0.009538},{0.848246, 1.146797, 0.009185}}],
    Polygon[{{0.849438, 1.145931, -0.009538},{0.848246, 1.146797, -0.009185},{
      0.847822, 1.145966, -0.009185},{0.849224, 1.145510, -0.009538}}],
    Polygon[{{0.848246, 1.146797, -0.009185},{0.847114, 1.147620, -0.008605},{
      0.846491, 1.146398, -0.008605},{0.847822, 1.145966, -0.009185}}],
    Polygon[{{0.847114, 1.147620, -0.008605},{0.846068, 1.148380, -0.007813},{
      0.845262, 1.146797, -0.007813},{0.846491, 1.146398, -0.008605}}],
    Polygon[{{0.846068, 1.148380, -0.007813},{0.845136, 1.149057, -0.006829},{
      0.844166, 1.147153, -0.006829},{0.845262, 1.146797, -0.007813}}],
    Polygon[{{0.845136, 1.149057, -0.006829},{0.844340, 1.149636, -0.005676},{
      0.843230, 1.147458, -0.005676},{0.844166, 1.147153, -0.006829}}],
    Polygon[{{0.844340, 1.149636, -0.005676},{0.843699, 1.150101, -0.004384},{
      0.842477, 1.147702, -0.004384},{0.843230, 1.147458, -0.005676}}],
    Polygon[{{0.843699, 1.150101, -0.004384},{0.843230, 1.150442, -0.002984},{
      0.841926, 1.147882, -0.002984},{0.842477, 1.147702, -0.004384}}],
    Polygon[{{0.843230, 1.150442, -0.002984},{0.842944, 1.150650, -0.001511},{
      0.841589, 1.147991, -0.001511},{0.841926, 1.147882, -0.002984}}],
    Polygon[{{0.842944, 1.150650, -0.001511},{0.842848, 1.150720, 0.000000},{
      0.841476, 1.148028, 0.000000},{0.841589, 1.147991, -0.001511}}],
    Polygon[{{0.842848, 1.150720, 0.000000},{0.842944, 1.150650, 0.001511},{
      0.841589, 1.147991, 0.001511},{0.841476, 1.148028, 0.000000}}],
    Polygon[{{0.842944, 1.150650, 0.001511},{0.843230, 1.150442, 0.002984},{
      0.841926, 1.147882, 0.002984},{0.841589, 1.147991, 0.001511}}],
    Polygon[{{0.843230, 1.150442, 0.002984},{0.843699, 1.150101, 0.004384},{
      0.842477, 1.147702, 0.004384},{0.841926, 1.147882, 0.002984}}],
    Polygon[{{0.843699, 1.150101, 0.004384},{0.844340, 1.149636, 0.005676},{
      0.843230, 1.147458, 0.005676},{0.842477, 1.147702, 0.004384}}],
    Polygon[{{0.844340, 1.149636, 0.005676},{0.845136, 1.149057, 0.006829},{
      0.844166, 1.147153, 0.006829},{0.843230, 1.147458, 0.005676}}],
    Polygon[{{0.845136, 1.149057, 0.006829},{0.846068, 1.148380, 0.007813},{
      0.845262, 1.146797, 0.007813},{0.844166, 1.147153, 0.006829}}],
    Polygon[{{0.846068, 1.148380, 0.007813},{0.847114, 1.147620, 0.008605},{
      0.846491, 1.146398, 0.008605},{0.845262, 1.146797, 0.007813}}],
    Polygon[{{0.847114, 1.147620, 0.008605},{0.848246, 1.146797, 0.009185},{
      0.847822, 1.145966, 0.009185},{0.846491, 1.146398, 0.008605}}],
    Polygon[{{0.848246, 1.146797, 0.009185},{0.849438, 1.145931, 0.009538},{
      0.849224, 1.145510, 0.009538},{0.847822, 1.145966, 0.009185}}],
    Polygon[{{0.849224, 1.145510, -0.009538},{0.847822, 1.145966, -0.009185},{
      0.847676, 1.145043, -0.009185},{0.849150, 1.145043, -0.009538}}],
    Polygon[{{0.847822, 1.145966, -0.009185},{0.846491, 1.146398, -0.008605},{
      0.846276, 1.145043, -0.008605},{0.847676, 1.145043, -0.009185}}],
    Polygon[{{0.846491, 1.146398, -0.008605},{0.845262, 1.146797, -0.007813},{
      0.844984, 1.145043, -0.007813},{0.846276, 1.145043, -0.008605}}],
    Polygon[{{0.845262, 1.146797, -0.007813},{0.844166, 1.147153, -0.006829},{
      0.843832, 1.145043, -0.006829},{0.844984, 1.145043, -0.007813}}],
    Polygon[{{0.844166, 1.147153, -0.006829},{0.843230, 1.147458, -0.005676},{
      0.842848, 1.145043, -0.005676},{0.843832, 1.145043, -0.006829}}],
    Polygon[{{0.843230, 1.147458, -0.005676},{0.842477, 1.147702, -0.004384},{
      0.842056, 1.145043, -0.004384},{0.842848, 1.145043, -0.005676}}],
    Polygon[{{0.842477, 1.147702, -0.004384},{0.841926, 1.147882, -0.002984},{
      0.841476, 1.145043, -0.002984},{0.842056, 1.145043, -0.004384}}],
    Polygon[{{0.841926, 1.147882, -0.002984},{0.841589, 1.147991, -0.001511},{
      0.841122, 1.145043, -0.001511},{0.841476, 1.145043, -0.002984}}],
    Polygon[{{0.841589, 1.147991, -0.001511},{0.841476, 1.148028, 0.000000},{
      0.841003, 1.145043, 0.000000},{0.841122, 1.145043, -0.001511}}],
    Polygon[{{0.841476, 1.148028, 0.000000},{0.841589, 1.147991, 0.001511},{
      0.841122, 1.145043, 0.001511},{0.841003, 1.145043, 0.000000}}],
    Polygon[{{0.841589, 1.147991, 0.001511},{0.841926, 1.147882, 0.002984},{
      0.841476, 1.145043, 0.002984},{0.841122, 1.145043, 0.001511}}],
    Polygon[{{0.841926, 1.147882, 0.002984},{0.842477, 1.147702, 0.004384},{
      0.842056, 1.145043, 0.004384},{0.841476, 1.145043, 0.002984}}],
    Polygon[{{0.842477, 1.147702, 0.004384},{0.843230, 1.147458, 0.005676},{
      0.842848, 1.145043, 0.005676},{0.842056, 1.145043, 0.004384}}],
    Polygon[{{0.843230, 1.147458, 0.005676},{0.844166, 1.147153, 0.006829},{
      0.843832, 1.145043, 0.006829},{0.842848, 1.145043, 0.005676}}],
    Polygon[{{0.844166, 1.147153, 0.006829},{0.845262, 1.146797, 0.007813},{
      0.844984, 1.145043, 0.007813},{0.843832, 1.145043, 0.006829}}],
    Polygon[{{0.845262, 1.146797, 0.007813},{0.846491, 1.146398, 0.008605},{
      0.846276, 1.145043, 0.008605},{0.844984, 1.145043, 0.007813}}],
    Polygon[{{0.846491, 1.146398, 0.008605},{0.847822, 1.145966, 0.009185},{
      0.847676, 1.145043, 0.009185},{0.846276, 1.145043, 0.008605}}],
    Polygon[{{0.847822, 1.145966, 0.009185},{0.849224, 1.145510, 0.009538},{
      0.849150, 1.145043, 0.009538},{0.847676, 1.145043, 0.009185}}],
    Polygon[{{0.849150, 1.145043, -0.009538},{0.847676, 1.145043, -0.009185},{
      0.847822, 1.144121, -0.009185},{0.849224, 1.144577, -0.009538}}],
    Polygon[{{0.847676, 1.145043, -0.009185},{0.846276, 1.145043, -0.008605},{
      0.846491, 1.143689, -0.008605},{0.847822, 1.144121, -0.009185}}],
    Polygon[{{0.846276, 1.145043, -0.008605},{0.844984, 1.145043, -0.007813},{
      0.845262, 1.143289, -0.007813},{0.846491, 1.143689, -0.008605}}],
    Polygon[{{0.844984, 1.145043, -0.007813},{0.843832, 1.145043, -0.006829},{
      0.844166, 1.142933, -0.006829},{0.845262, 1.143289, -0.007813}}],
    Polygon[{{0.843832, 1.145043, -0.006829},{0.842848, 1.145043, -0.005676},{
      0.843230, 1.142629, -0.005676},{0.844166, 1.142933, -0.006829}}],
    Polygon[{{0.842848, 1.145043, -0.005676},{0.842056, 1.145043, -0.004384},{
      0.842477, 1.142384, -0.004384},{0.843230, 1.142629, -0.005676}}],
    Polygon[{{0.842056, 1.145043, -0.004384},{0.841476, 1.145043, -0.002984},{
      0.841926, 1.142205, -0.002984},{0.842477, 1.142384, -0.004384}}],
    Polygon[{{0.841476, 1.145043, -0.002984},{0.841122, 1.145043, -0.001511},{
      0.841589, 1.142096, -0.001511},{0.841926, 1.142205, -0.002984}}],
    Polygon[{{0.841122, 1.145043, -0.001511},{0.841003, 1.145043, 0.000000},{
      0.841476, 1.142059, 0.000000},{0.841589, 1.142096, -0.001511}}],
    Polygon[{{0.841003, 1.145043, 0.000000},{0.841122, 1.145043, 0.001511},{
      0.841589, 1.142096, 0.001511},{0.841476, 1.142059, 0.000000}}],
    Polygon[{{0.841122, 1.145043, 0.001511},{0.841476, 1.145043, 0.002984},{
      0.841926, 1.142205, 0.002984},{0.841589, 1.142096, 0.001511}}],
    Polygon[{{0.841476, 1.145043, 0.002984},{0.842056, 1.145043, 0.004384},{
      0.842477, 1.142384, 0.004384},{0.841926, 1.142205, 0.002984}}],
    Polygon[{{0.842056, 1.145043, 0.004384},{0.842848, 1.145043, 0.005676},{
      0.843230, 1.142629, 0.005676},{0.842477, 1.142384, 0.004384}}],
    Polygon[{{0.842848, 1.145043, 0.005676},{0.843832, 1.145043, 0.006829},{
      0.844166, 1.142933, 0.006829},{0.843230, 1.142629, 0.005676}}],
    Polygon[{{0.843832, 1.145043, 0.006829},{0.844984, 1.145043, 0.007813},{
      0.845262, 1.143289, 0.007813},{0.844166, 1.142933, 0.006829}}],
    Polygon[{{0.844984, 1.145043, 0.007813},{0.846276, 1.145043, 0.008605},{
      0.846491, 1.143689, 0.008605},{0.845262, 1.143289, 0.007813}}],
    Polygon[{{0.846276, 1.145043, 0.008605},{0.847676, 1.145043, 0.009185},{
      0.847822, 1.144121, 0.009185},{0.846491, 1.143689, 0.008605}}],
    Polygon[{{0.847676, 1.145043, 0.009185},{0.849150, 1.145043, 0.009538},{
      0.849224, 1.144577, 0.009538},{0.847822, 1.144121, 0.009185}}],
    Polygon[{{0.849224, 1.144577, -0.009538},{0.847822, 1.144121, -0.009185},{
      0.848246, 1.143289, -0.009185},{0.849438, 1.144155, -0.009538}}],
    Polygon[{{0.847822, 1.144121, -0.009185},{0.846491, 1.143689, -0.008605},{
      0.847114, 1.142466, -0.008605},{0.848246, 1.143289, -0.009185}}],
    Polygon[{{0.846491, 1.143689, -0.008605},{0.845262, 1.143289, -0.007813},{
      0.846068, 1.141707, -0.007813},{0.847114, 1.142466, -0.008605}}],
    Polygon[{{0.845262, 1.143289, -0.007813},{0.844166, 1.142933, -0.006829},{
      0.845136, 1.141030, -0.006829},{0.846068, 1.141707, -0.007813}}],
    Polygon[{{0.844166, 1.142933, -0.006829},{0.843230, 1.142629, -0.005676},{
      0.844340, 1.140451, -0.005676},{0.845136, 1.141030, -0.006829}}],
    Polygon[{{0.843230, 1.142629, -0.005676},{0.842477, 1.142384, -0.004384},{
      0.843699, 1.139986, -0.004384},{0.844340, 1.140451, -0.005676}}],
    Polygon[{{0.842477, 1.142384, -0.004384},{0.841926, 1.142205, -0.002984},{
      0.843230, 1.139645, -0.002984},{0.843699, 1.139986, -0.004384}}],
    Polygon[{{0.841926, 1.142205, -0.002984},{0.841589, 1.142096, -0.001511},{
      0.842944, 1.139437, -0.001511},{0.843230, 1.139645, -0.002984}}],
    Polygon[{{0.841589, 1.142096, -0.001511},{0.841476, 1.142059, 0.000000},{
      0.842848, 1.139367, 0.000000},{0.842944, 1.139437, -0.001511}}],
    Polygon[{{0.841476, 1.142059, 0.000000},{0.841589, 1.142096, 0.001511},{
      0.842944, 1.139437, 0.001511},{0.842848, 1.139367, 0.000000}}],
    Polygon[{{0.841589, 1.142096, 0.001511},{0.841926, 1.142205, 0.002984},{
      0.843230, 1.139645, 0.002984},{0.842944, 1.139437, 0.001511}}],
    Polygon[{{0.841926, 1.142205, 0.002984},{0.842477, 1.142384, 0.004384},{
      0.843699, 1.139986, 0.004384},{0.843230, 1.139645, 0.002984}}],
    Polygon[{{0.842477, 1.142384, 0.004384},{0.843230, 1.142629, 0.005676},{
      0.844340, 1.140451, 0.005676},{0.843699, 1.139986, 0.004384}}],
    Polygon[{{0.843230, 1.142629, 0.005676},{0.844166, 1.142933, 0.006829},{
      0.845136, 1.141030, 0.006829},{0.844340, 1.140451, 0.005676}}],
    Polygon[{{0.844166, 1.142933, 0.006829},{0.845262, 1.143289, 0.007813},{
      0.846068, 1.141707, 0.007813},{0.845136, 1.141030, 0.006829}}],
    Polygon[{{0.845262, 1.143289, 0.007813},{0.846491, 1.143689, 0.008605},{
      0.847114, 1.142466, 0.008605},{0.846068, 1.141707, 0.007813}}],
    Polygon[{{0.846491, 1.143689, 0.008605},{0.847822, 1.144121, 0.009185},{
      0.848246, 1.143289, 0.009185},{0.847114, 1.142466, 0.008605}}],
    Polygon[{{0.847822, 1.144121, 0.009185},{0.849224, 1.144577, 0.009538},{
      0.849438, 1.144155, 0.009538},{0.848246, 1.143289, 0.009185}}],
    Polygon[{{0.849438, 1.144155, -0.009538},{0.848246, 1.143289, -0.009185},{
      0.848906, 1.142629, -0.009185},{0.849773, 1.143821, -0.009538}}],
    Polygon[{{0.848246, 1.143289, -0.009185},{0.847114, 1.142466, -0.008605},{
      0.848083, 1.141496, -0.008605},{0.848906, 1.142629, -0.009185}}],
    Polygon[{{0.847114, 1.142466, -0.008605},{0.846068, 1.141707, -0.007813},{
      0.847324, 1.140451, -0.007813},{0.848083, 1.141496, -0.008605}}],
    Polygon[{{0.846068, 1.141707, -0.007813},{0.845136, 1.141030, -0.006829},{
      0.846647, 1.139519, -0.006829},{0.847324, 1.140451, -0.007813}}],
    Polygon[{{0.845136, 1.141030, -0.006829},{0.844340, 1.140451, -0.005676},{
      0.846068, 1.138723, -0.005676},{0.846647, 1.139519, -0.006829}}],
    Polygon[{{0.844340, 1.140451, -0.005676},{0.843699, 1.139986, -0.004384},{
      0.845603, 1.138082, -0.004384},{0.846068, 1.138723, -0.005676}}],
    Polygon[{{0.843699, 1.139986, -0.004384},{0.843230, 1.139645, -0.002984},{
      0.845262, 1.137613, -0.002984},{0.845603, 1.138082, -0.004384}}],
    Polygon[{{0.843230, 1.139645, -0.002984},{0.842944, 1.139437, -0.001511},{
      0.845054, 1.137327, -0.001511},{0.845262, 1.137613, -0.002984}}],
    Polygon[{{0.842944, 1.139437, -0.001511},{0.842848, 1.139367, 0.000000},{
      0.844984, 1.137231, 0.000000},{0.845054, 1.137327, -0.001511}}],
    Polygon[{{0.842848, 1.139367, 0.000000},{0.842944, 1.139437, 0.001511},{
      0.845054, 1.137327, 0.001511},{0.844984, 1.137231, 0.000000}}],
    Polygon[{{0.842944, 1.139437, 0.001511},{0.843230, 1.139645, 0.002984},{
      0.845262, 1.137613, 0.002984},{0.845054, 1.137327, 0.001511}}],
    Polygon[{{0.843230, 1.139645, 0.002984},{0.843699, 1.139986, 0.004384},{
      0.845603, 1.138082, 0.004384},{0.845262, 1.137613, 0.002984}}],
    Polygon[{{0.843699, 1.139986, 0.004384},{0.844340, 1.140451, 0.005676},{
      0.846068, 1.138723, 0.005676},{0.845603, 1.138082, 0.004384}}],
    Polygon[{{0.844340, 1.140451, 0.005676},{0.845136, 1.141030, 0.006829},{
      0.846647, 1.139519, 0.006829},{0.846068, 1.138723, 0.005676}}],
    Polygon[{{0.845136, 1.141030, 0.006829},{0.846068, 1.141707, 0.007813},{
      0.847324, 1.140451, 0.007813},{0.846647, 1.139519, 0.006829}}],
    Polygon[{{0.846068, 1.141707, 0.007813},{0.847114, 1.142466, 0.008605},{
      0.848083, 1.141496, 0.008605},{0.847324, 1.140451, 0.007813}}],
    Polygon[{{0.847114, 1.142466, 0.008605},{0.848246, 1.143289, 0.009185},{
      0.848906, 1.142629, 0.009185},{0.848083, 1.141496, 0.008605}}],
    Polygon[{{0.848246, 1.143289, 0.009185},{0.849438, 1.144155, 0.009538},{
      0.849773, 1.143821, 0.009538},{0.848906, 1.142629, 0.009185}}],
    Polygon[{{0.849773, 1.143821, -0.009538},{0.848906, 1.142629, -0.009185},{
      0.849738, 1.142205, -0.009185},{0.850194, 1.143607, -0.009538}}],
    Polygon[{{0.848906, 1.142629, -0.009185},{0.848083, 1.141496, -0.008605},{
      0.849306, 1.140874, -0.008605},{0.849738, 1.142205, -0.009185}}],
    Polygon[{{0.848083, 1.141496, -0.008605},{0.847324, 1.140451, -0.007813},{
      0.848906, 1.139645, -0.007813},{0.849306, 1.140874, -0.008605}}],
    Polygon[{{0.847324, 1.140451, -0.007813},{0.846647, 1.139519, -0.006829},{
      0.848550, 1.138549, -0.006829},{0.848906, 1.139645, -0.007813}}],
    Polygon[{{0.846647, 1.139519, -0.006829},{0.846068, 1.138723, -0.005676},{
      0.848246, 1.137613, -0.005676},{0.848550, 1.138549, -0.006829}}],
    Polygon[{{0.846068, 1.138723, -0.005676},{0.845603, 1.138082, -0.004384},{
      0.848002, 1.136860, -0.004384},{0.848246, 1.137613, -0.005676}}],
    Polygon[{{0.845603, 1.138082, -0.004384},{0.845262, 1.137613, -0.002984},{
      0.847822, 1.136308, -0.002984},{0.848002, 1.136860, -0.004384}}],
    Polygon[{{0.845262, 1.137613, -0.002984},{0.845054, 1.137327, -0.001511},{
      0.847713, 1.135972, -0.001511},{0.847822, 1.136308, -0.002984}}],
    Polygon[{{0.845054, 1.137327, -0.001511},{0.844984, 1.137231, 0.000000},{
      0.847676, 1.135859, 0.000000},{0.847713, 1.135972, -0.001511}}],
    Polygon[{{0.844984, 1.137231, 0.000000},{0.845054, 1.137327, 0.001511},{
      0.847713, 1.135972, 0.001511},{0.847676, 1.135859, 0.000000}}],
    Polygon[{{0.845054, 1.137327, 0.001511},{0.845262, 1.137613, 0.002984},{
      0.847822, 1.136308, 0.002984},{0.847713, 1.135972, 0.001511}}],
    Polygon[{{0.845262, 1.137613, 0.002984},{0.845603, 1.138082, 0.004384},{
      0.848002, 1.136860, 0.004384},{0.847822, 1.136308, 0.002984}}],
    Polygon[{{0.845603, 1.138082, 0.004384},{0.846068, 1.138723, 0.005676},{
      0.848246, 1.137613, 0.005676},{0.848002, 1.136860, 0.004384}}],
    Polygon[{{0.846068, 1.138723, 0.005676},{0.846647, 1.139519, 0.006829},{
      0.848550, 1.138549, 0.006829},{0.848246, 1.137613, 0.005676}}],
    Polygon[{{0.846647, 1.139519, 0.006829},{0.847324, 1.140451, 0.007813},{
      0.848906, 1.139645, 0.007813},{0.848550, 1.138549, 0.006829}}],
    Polygon[{{0.847324, 1.140451, 0.007813},{0.848083, 1.141496, 0.008605},{
      0.849306, 1.140874, 0.008605},{0.848906, 1.139645, 0.007813}}],
    Polygon[{{0.848083, 1.141496, 0.008605},{0.848906, 1.142629, 0.009185},{
      0.849738, 1.142205, 0.009185},{0.849306, 1.140874, 0.008605}}],
    Polygon[{{0.848906, 1.142629, 0.009185},{0.849773, 1.143821, 0.009538},{
      0.850194, 1.143607, 0.009538},{0.849738, 1.142205, 0.009185}}],
    Polygon[{{0.850194, 1.143607, -0.009538},{0.849738, 1.142205, -0.009185},{
      0.850661, 1.142059, -0.009185},{0.850661, 1.143533, -0.009538}}],
    Polygon[{{0.849738, 1.142205, -0.009185},{0.849306, 1.140874, -0.008605},{
      0.850661, 1.140659, -0.008605},{0.850661, 1.142059, -0.009185}}],
    Polygon[{{0.849306, 1.140874, -0.008605},{0.848906, 1.139645, -0.007813},{
      0.850661, 1.139367, -0.007813},{0.850661, 1.140659, -0.008605}}],
    Polygon[{{0.848906, 1.139645, -0.007813},{0.848550, 1.138549, -0.006829},{
      0.850661, 1.138215, -0.006829},{0.850661, 1.139367, -0.007813}}],
    Polygon[{{0.848550, 1.138549, -0.006829},{0.848246, 1.137613, -0.005676},{
      0.850661, 1.137231, -0.005676},{0.850661, 1.138215, -0.006829}}],
    Polygon[{{0.848246, 1.137613, -0.005676},{0.848002, 1.136860, -0.004384},{
      0.850661, 1.136439, -0.004384},{0.850661, 1.137231, -0.005676}}],
    Polygon[{{0.848002, 1.136860, -0.004384},{0.847822, 1.136308, -0.002984},{
      0.850661, 1.135859, -0.002984},{0.850661, 1.136439, -0.004384}}],
    Polygon[{{0.847822, 1.136308, -0.002984},{0.847713, 1.135972, -0.001511},{
      0.850661, 1.135505, -0.001511},{0.850661, 1.135859, -0.002984}}],
    Polygon[{{0.847713, 1.135972, -0.001511},{0.847676, 1.135859, 0.000000},{
      0.850661, 1.135386, 0.000000},{0.850661, 1.135505, -0.001511}}],
    Polygon[{{0.847676, 1.135859, 0.000000},{0.847713, 1.135972, 0.001511},{
      0.850661, 1.135505, 0.001511},{0.850661, 1.135386, 0.000000}}],
    Polygon[{{0.847713, 1.135972, 0.001511},{0.847822, 1.136308, 0.002984},{
      0.850661, 1.135859, 0.002984},{0.850661, 1.135505, 0.001511}}],
    Polygon[{{0.847822, 1.136308, 0.002984},{0.848002, 1.136860, 0.004384},{
      0.850661, 1.136439, 0.004384},{0.850661, 1.135859, 0.002984}}],
    Polygon[{{0.848002, 1.136860, 0.004384},{0.848246, 1.137613, 0.005676},{
      0.850661, 1.137231, 0.005676},{0.850661, 1.136439, 0.004384}}],
    Polygon[{{0.848246, 1.137613, 0.005676},{0.848550, 1.138549, 0.006829},{
      0.850661, 1.138215, 0.006829},{0.850661, 1.137231, 0.005676}}],
    Polygon[{{0.848550, 1.138549, 0.006829},{0.848906, 1.139645, 0.007813},{
      0.850661, 1.139367, 0.007813},{0.850661, 1.138215, 0.006829}}],
    Polygon[{{0.848906, 1.139645, 0.007813},{0.849306, 1.140874, 0.008605},{
      0.850661, 1.140659, 0.008605},{0.850661, 1.139367, 0.007813}}],
    Polygon[{{0.849306, 1.140874, 0.008605},{0.849738, 1.142205, 0.009185},{
      0.850661, 1.142059, 0.009185},{0.850661, 1.140659, 0.008605}}],
    Polygon[{{0.849738, 1.142205, 0.009185},{0.850194, 1.143607, 0.009538},{
      0.850661, 1.143533, 0.009538},{0.850661, 1.142059, 0.009185}}],
    Polygon[{{0.850661, 1.143533, -0.009538},{0.850661, 1.142059, -0.009185},{
      0.851583, 1.142205, -0.009185},{0.851127, 1.143607, -0.009538}}],
    Polygon[{{0.850661, 1.142059, -0.009185},{0.850661, 1.140659, -0.008605},{
      0.852015, 1.140874, -0.008605},{0.851583, 1.142205, -0.009185}}],
    Polygon[{{0.850661, 1.140659, -0.008605},{0.850661, 1.139367, -0.007813},{
      0.852415, 1.139645, -0.007813},{0.852015, 1.140874, -0.008605}}],
    Polygon[{{0.850661, 1.139367, -0.007813},{0.850661, 1.138215, -0.006829},{
      0.852771, 1.138549, -0.006829},{0.852415, 1.139645, -0.007813}}],
    Polygon[{{0.850661, 1.138215, -0.006829},{0.850661, 1.137231, -0.005676},{
      0.853075, 1.137613, -0.005676},{0.852771, 1.138549, -0.006829}}],
    Polygon[{{0.850661, 1.137231, -0.005676},{0.850661, 1.136439, -0.004384},{
      0.853319, 1.136860, -0.004384},{0.853075, 1.137613, -0.005676}}],
    Polygon[{{0.850661, 1.136439, -0.004384},{0.850661, 1.135859, -0.002984},{
      0.853499, 1.136308, -0.002984},{0.853319, 1.136860, -0.004384}}],
    Polygon[{{0.850661, 1.135859, -0.002984},{0.850661, 1.135505, -0.001511},{
      0.853608, 1.135972, -0.001511},{0.853499, 1.136308, -0.002984}}],
    Polygon[{{0.850661, 1.135505, -0.001511},{0.850661, 1.135386, 0.000000},{
      0.853645, 1.135859, 0.000000},{0.853608, 1.135972, -0.001511}}],
    Polygon[{{0.850661, 1.135386, 0.000000},{0.850661, 1.135505, 0.001511},{
      0.853608, 1.135972, 0.001511},{0.853645, 1.135859, 0.000000}}],
    Polygon[{{0.850661, 1.135505, 0.001511},{0.850661, 1.135859, 0.002984},{
      0.853499, 1.136308, 0.002984},{0.853608, 1.135972, 0.001511}}],
    Polygon[{{0.850661, 1.135859, 0.002984},{0.850661, 1.136439, 0.004384},{
      0.853319, 1.136860, 0.004384},{0.853499, 1.136308, 0.002984}}],
    Polygon[{{0.850661, 1.136439, 0.004384},{0.850661, 1.137231, 0.005676},{
      0.853075, 1.137613, 0.005676},{0.853319, 1.136860, 0.004384}}],
    Polygon[{{0.850661, 1.137231, 0.005676},{0.850661, 1.138215, 0.006829},{
      0.852771, 1.138549, 0.006829},{0.853075, 1.137613, 0.005676}}],
    Polygon[{{0.850661, 1.138215, 0.006829},{0.850661, 1.139367, 0.007813},{
      0.852415, 1.139645, 0.007813},{0.852771, 1.138549, 0.006829}}],
    Polygon[{{0.850661, 1.139367, 0.007813},{0.850661, 1.140659, 0.008605},{
      0.852015, 1.140874, 0.008605},{0.852415, 1.139645, 0.007813}}],
    Polygon[{{0.850661, 1.140659, 0.008605},{0.850661, 1.142059, 0.009185},{
      0.851583, 1.142205, 0.009185},{0.852015, 1.140874, 0.008605}}],
    Polygon[{{0.850661, 1.142059, 0.009185},{0.850661, 1.143533, 0.009538},{
      0.851127, 1.143607, 0.009538},{0.851583, 1.142205, 0.009185}}],
    Polygon[{{0.851127, 1.143607, -0.009538},{0.851583, 1.142205, -0.009185},{
      0.852415, 1.142629, -0.009185},{0.851548, 1.143821, -0.009538}}],
    Polygon[{{0.851583, 1.142205, -0.009185},{0.852015, 1.140874, -0.008605},{
      0.853238, 1.141496, -0.008605},{0.852415, 1.142629, -0.009185}}],
    Polygon[{{0.852015, 1.140874, -0.008605},{0.852415, 1.139645, -0.007813},{
      0.853997, 1.140451, -0.007813},{0.853238, 1.141496, -0.008605}}],
    Polygon[{{0.852415, 1.139645, -0.007813},{0.852771, 1.138549, -0.006829},{
      0.854674, 1.139519, -0.006829},{0.853997, 1.140451, -0.007813}}],
    Polygon[{{0.852771, 1.138549, -0.006829},{0.853075, 1.137613, -0.005676},{
      0.855253, 1.138723, -0.005676},{0.854674, 1.139519, -0.006829}}],
    Polygon[{{0.853075, 1.137613, -0.005676},{0.853319, 1.136860, -0.004384},{
      0.855718, 1.138082, -0.004384},{0.855253, 1.138723, -0.005676}}],
    Polygon[{{0.853319, 1.136860, -0.004384},{0.853499, 1.136308, -0.002984},{
      0.856059, 1.137613, -0.002984},{0.855718, 1.138082, -0.004384}}],
    Polygon[{{0.853499, 1.136308, -0.002984},{0.853608, 1.135972, -0.001511},{
      0.856267, 1.137327, -0.001511},{0.856059, 1.137613, -0.002984}}],
    Polygon[{{0.853608, 1.135972, -0.001511},{0.853645, 1.135859, 0.000000},{
      0.856337, 1.137231, 0.000000},{0.856267, 1.137327, -0.001511}}],
    Polygon[{{0.853645, 1.135859, 0.000000},{0.853608, 1.135972, 0.001511},{
      0.856267, 1.137327, 0.001511},{0.856337, 1.137231, 0.000000}}],
    Polygon[{{0.853608, 1.135972, 0.001511},{0.853499, 1.136308, 0.002984},{
      0.856059, 1.137613, 0.002984},{0.856267, 1.137327, 0.001511}}],
    Polygon[{{0.853499, 1.136308, 0.002984},{0.853319, 1.136860, 0.004384},{
      0.855718, 1.138082, 0.004384},{0.856059, 1.137613, 0.002984}}],
    Polygon[{{0.853319, 1.136860, 0.004384},{0.853075, 1.137613, 0.005676},{
      0.855253, 1.138723, 0.005676},{0.855718, 1.138082, 0.004384}}],
    Polygon[{{0.853075, 1.137613, 0.005676},{0.852771, 1.138549, 0.006829},{
      0.854674, 1.139519, 0.006829},{0.855253, 1.138723, 0.005676}}],
    Polygon[{{0.852771, 1.138549, 0.006829},{0.852415, 1.139645, 0.007813},{
      0.853997, 1.140451, 0.007813},{0.854674, 1.139519, 0.006829}}],
    Polygon[{{0.852415, 1.139645, 0.007813},{0.852015, 1.140874, 0.008605},{
      0.853238, 1.141496, 0.008605},{0.853997, 1.140451, 0.007813}}],
    Polygon[{{0.852015, 1.140874, 0.008605},{0.851583, 1.142205, 0.009185},{
      0.852415, 1.142629, 0.009185},{0.853238, 1.141496, 0.008605}}],
    Polygon[{{0.851583, 1.142205, 0.009185},{0.851127, 1.143607, 0.009538},{
      0.851548, 1.143821, 0.009538},{0.852415, 1.142629, 0.009185}}],
    Polygon[{{0.851548, 1.143821, -0.009538},{0.852415, 1.142629, -0.009185},{
      0.853075, 1.143289, -0.009185},{0.851883, 1.144155, -0.009538}}],
    Polygon[{{0.852415, 1.142629, -0.009185},{0.853238, 1.141496, -0.008605},{
      0.854207, 1.142466, -0.008605},{0.853075, 1.143289, -0.009185}}],
    Polygon[{{0.853238, 1.141496, -0.008605},{0.853997, 1.140451, -0.007813},{
      0.855253, 1.141707, -0.007813},{0.854207, 1.142466, -0.008605}}],
    Polygon[{{0.853997, 1.140451, -0.007813},{0.854674, 1.139519, -0.006829},{
      0.856185, 1.141030, -0.006829},{0.855253, 1.141707, -0.007813}}],
    Polygon[{{0.854674, 1.139519, -0.006829},{0.855253, 1.138723, -0.005676},{
      0.856981, 1.140451, -0.005676},{0.856185, 1.141030, -0.006829}}],
    Polygon[{{0.855253, 1.138723, -0.005676},{0.855718, 1.138082, -0.004384},{
      0.857622, 1.139986, -0.004384},{0.856981, 1.140451, -0.005676}}],
    Polygon[{{0.855718, 1.138082, -0.004384},{0.856059, 1.137613, -0.002984},{
      0.858091, 1.139645, -0.002984},{0.857622, 1.139986, -0.004384}}],
    Polygon[{{0.856059, 1.137613, -0.002984},{0.856267, 1.137327, -0.001511},{
      0.858377, 1.139437, -0.001511},{0.858091, 1.139645, -0.002984}}],
    Polygon[{{0.856267, 1.137327, -0.001511},{0.856337, 1.137231, 0.000000},{
      0.858473, 1.139367, 0.000000},{0.858377, 1.139437, -0.001511}}],
    Polygon[{{0.856337, 1.137231, 0.000000},{0.856267, 1.137327, 0.001511},{
      0.858377, 1.139437, 0.001511},{0.858473, 1.139367, 0.000000}}],
    Polygon[{{0.856267, 1.137327, 0.001511},{0.856059, 1.137613, 0.002984},{
      0.858091, 1.139645, 0.002984},{0.858377, 1.139437, 0.001511}}],
    Polygon[{{0.856059, 1.137613, 0.002984},{0.855718, 1.138082, 0.004384},{
      0.857622, 1.139986, 0.004384},{0.858091, 1.139645, 0.002984}}],
    Polygon[{{0.855718, 1.138082, 0.004384},{0.855253, 1.138723, 0.005676},{
      0.856981, 1.140451, 0.005676},{0.857622, 1.139986, 0.004384}}],
    Polygon[{{0.855253, 1.138723, 0.005676},{0.854674, 1.139519, 0.006829},{
      0.856185, 1.141030, 0.006829},{0.856981, 1.140451, 0.005676}}],
    Polygon[{{0.854674, 1.139519, 0.006829},{0.853997, 1.140451, 0.007813},{
      0.855253, 1.141707, 0.007813},{0.856185, 1.141030, 0.006829}}],
    Polygon[{{0.853997, 1.140451, 0.007813},{0.853238, 1.141496, 0.008605},{
      0.854207, 1.142466, 0.008605},{0.855253, 1.141707, 0.007813}}],
    Polygon[{{0.853238, 1.141496, 0.008605},{0.852415, 1.142629, 0.009185},{
      0.853075, 1.143289, 0.009185},{0.854207, 1.142466, 0.008605}}],
    Polygon[{{0.852415, 1.142629, 0.009185},{0.851548, 1.143821, 0.009538},{
      0.851883, 1.144155, 0.009538},{0.853075, 1.143289, 0.009185}}],
    Polygon[{{0.851883, 1.144155, -0.009538},{0.853075, 1.143289, -0.009185},{
      0.853499, 1.144121, -0.009185},{0.852097, 1.144577, -0.009538}}],
    Polygon[{{0.853075, 1.143289, -0.009185},{0.854207, 1.142466, -0.008605},{
      0.854830, 1.143689, -0.008605},{0.853499, 1.144121, -0.009185}}],
    Polygon[{{0.854207, 1.142466, -0.008605},{0.855253, 1.141707, -0.007813},{
      0.856059, 1.143289, -0.007813},{0.854830, 1.143689, -0.008605}}],
    Polygon[{{0.855253, 1.141707, -0.007813},{0.856185, 1.141030, -0.006829},{
      0.857155, 1.142933, -0.006829},{0.856059, 1.143289, -0.007813}}],
    Polygon[{{0.856185, 1.141030, -0.006829},{0.856981, 1.140451, -0.005676},{
      0.858091, 1.142629, -0.005676},{0.857155, 1.142933, -0.006829}}],
    Polygon[{{0.856981, 1.140451, -0.005676},{0.857622, 1.139986, -0.004384},{
      0.858844, 1.142384, -0.004384},{0.858091, 1.142629, -0.005676}}],
    Polygon[{{0.857622, 1.139986, -0.004384},{0.858091, 1.139645, -0.002984},{
      0.859396, 1.142205, -0.002984},{0.858844, 1.142384, -0.004384}}],
    Polygon[{{0.858091, 1.139645, -0.002984},{0.858377, 1.139437, -0.001511},{
      0.859732, 1.142096, -0.001511},{0.859396, 1.142205, -0.002984}}],
    Polygon[{{0.858377, 1.139437, -0.001511},{0.858473, 1.139367, 0.000000},{
      0.859845, 1.142059, 0.000000},{0.859732, 1.142096, -0.001511}}],
    Polygon[{{0.858473, 1.139367, 0.000000},{0.858377, 1.139437, 0.001511},{
      0.859732, 1.142096, 0.001511},{0.859845, 1.142059, 0.000000}}],
    Polygon[{{0.858377, 1.139437, 0.001511},{0.858091, 1.139645, 0.002984},{
      0.859396, 1.142205, 0.002984},{0.859732, 1.142096, 0.001511}}],
    Polygon[{{0.858091, 1.139645, 0.002984},{0.857622, 1.139986, 0.004384},{
      0.858844, 1.142384, 0.004384},{0.859396, 1.142205, 0.002984}}],
    Polygon[{{0.857622, 1.139986, 0.004384},{0.856981, 1.140451, 0.005676},{
      0.858091, 1.142629, 0.005676},{0.858844, 1.142384, 0.004384}}],
    Polygon[{{0.856981, 1.140451, 0.005676},{0.856185, 1.141030, 0.006829},{
      0.857155, 1.142933, 0.006829},{0.858091, 1.142629, 0.005676}}],
    Polygon[{{0.856185, 1.141030, 0.006829},{0.855253, 1.141707, 0.007813},{
      0.856059, 1.143289, 0.007813},{0.857155, 1.142933, 0.006829}}],
    Polygon[{{0.855253, 1.141707, 0.007813},{0.854207, 1.142466, 0.008605},{
      0.854830, 1.143689, 0.008605},{0.856059, 1.143289, 0.007813}}],
    Polygon[{{0.854207, 1.142466, 0.008605},{0.853075, 1.143289, 0.009185},{
      0.853499, 1.144121, 0.009185},{0.854830, 1.143689, 0.008605}}],
    Polygon[{{0.853075, 1.143289, 0.009185},{0.851883, 1.144155, 0.009538},{
      0.852097, 1.144577, 0.009538},{0.853499, 1.144121, 0.009185}}],
    Polygon[{{0.852097, 1.144577, -0.009538},{0.853499, 1.144121, -0.009185},{
      0.853645, 1.145043, -0.009185},{0.852171, 1.145043, -0.009538}}],
    Polygon[{{0.853499, 1.144121, -0.009185},{0.854830, 1.143689, -0.008605},{
      0.855045, 1.145043, -0.008605},{0.853645, 1.145043, -0.009185}}],
    Polygon[{{0.854830, 1.143689, -0.008605},{0.856059, 1.143289, -0.007813},{
      0.856337, 1.145043, -0.007813},{0.855045, 1.145043, -0.008605}}],
    Polygon[{{0.856059, 1.143289, -0.007813},{0.857155, 1.142933, -0.006829},{
      0.857489, 1.145043, -0.006829},{0.856337, 1.145043, -0.007813}}],
    Polygon[{{0.857155, 1.142933, -0.006829},{0.858091, 1.142629, -0.005676},{
      0.858473, 1.145043, -0.005676},{0.857489, 1.145043, -0.006829}}],
    Polygon[{{0.858091, 1.142629, -0.005676},{0.858844, 1.142384, -0.004384},{
      0.859265, 1.145043, -0.004384},{0.858473, 1.145043, -0.005676}}],
    Polygon[{{0.858844, 1.142384, -0.004384},{0.859396, 1.142205, -0.002984},{
      0.859845, 1.145043, -0.002984},{0.859265, 1.145043, -0.004384}}],
    Polygon[{{0.859396, 1.142205, -0.002984},{0.859732, 1.142096, -0.001511},{
      0.860199, 1.145043, -0.001511},{0.859845, 1.145043, -0.002984}}],
    Polygon[{{0.859732, 1.142096, -0.001511},{0.859845, 1.142059, 0.000000},{
      0.860318, 1.145043, 0.000000},{0.860199, 1.145043, -0.001511}}],
    Polygon[{{0.859845, 1.142059, 0.000000},{0.859732, 1.142096, 0.001511},{
      0.860199, 1.145043, 0.001511},{0.860318, 1.145043, 0.000000}}],
    Polygon[{{0.859732, 1.142096, 0.001511},{0.859396, 1.142205, 0.002984},{
      0.859845, 1.145043, 0.002984},{0.860199, 1.145043, 0.001511}}],
    Polygon[{{0.859396, 1.142205, 0.002984},{0.858844, 1.142384, 0.004384},{
      0.859265, 1.145043, 0.004384},{0.859845, 1.145043, 0.002984}}],
    Polygon[{{0.858844, 1.142384, 0.004384},{0.858091, 1.142629, 0.005676},{
      0.858473, 1.145043, 0.005676},{0.859265, 1.145043, 0.004384}}],
    Polygon[{{0.858091, 1.142629, 0.005676},{0.857155, 1.142933, 0.006829},{
      0.857489, 1.145043, 0.006829},{0.858473, 1.145043, 0.005676}}],
    Polygon[{{0.857155, 1.142933, 0.006829},{0.856059, 1.143289, 0.007813},{
      0.856337, 1.145043, 0.007813},{0.857489, 1.145043, 0.006829}}],
    Polygon[{{0.856059, 1.143289, 0.007813},{0.854830, 1.143689, 0.008605},{
      0.855045, 1.145043, 0.008605},{0.856337, 1.145043, 0.007813}}],
    Polygon[{{0.854830, 1.143689, 0.008605},{0.853499, 1.144121, 0.009185},{
      0.853645, 1.145043, 0.009185},{0.855045, 1.145043, 0.008605}}],
    Polygon[{{0.853499, 1.144121, 0.009185},{0.852097, 1.144577, 0.009538},{
      0.852171, 1.145043, 0.009538},{0.853645, 1.145043, 0.009185}}],
    Polygon[{{0.865654, 1.198582, -0.008668},{0.866993, 1.198582, -0.008347},{
      0.866861, 1.199420, -0.008347},{0.865587, 1.199007, -0.008668}}],
    Polygon[{{0.866993, 1.198582, -0.008347},{0.868266, 1.198582, -0.007820},{
      0.868071, 1.199814, -0.007820},{0.866861, 1.199420, -0.008347}}],
    Polygon[{{0.868266, 1.198582, -0.007820},{0.869440, 1.198582, -0.007100},{
      0.869187, 1.200176, -0.007100},{0.868071, 1.199814, -0.007820}}],
    Polygon[{{0.869440, 1.198582, -0.007100},{0.870487, 1.198582, -0.006206},{
      0.870183, 1.200500, -0.006206},{0.869187, 1.200176, -0.007100}}],
    Polygon[{{0.870487, 1.198582, -0.006206},{0.871382, 1.198582, -0.005159},{
      0.871034, 1.200776, -0.005159},{0.870183, 1.200500, -0.006206}}],
    Polygon[{{0.871382, 1.198582, -0.005159},{0.872101, 1.198582, -0.003984},{
      0.871718, 1.200999, -0.003984},{0.871034, 1.200776, -0.005159}}],
    Polygon[{{0.872101, 1.198582, -0.003984},{0.872628, 1.198582, -0.002712},{
      0.872220, 1.201162, -0.002712},{0.871718, 1.200999, -0.003984}}],
    Polygon[{{0.872628, 1.198582, -0.002712},{0.872950, 1.198582, -0.001373},{
      0.872525, 1.201261, -0.001373},{0.872220, 1.201162, -0.002712}}],
    Polygon[{{0.872950, 1.198582, -0.001373},{0.873058, 1.198582, 0.000000},{
      0.872628, 1.201294, 0.000000},{0.872525, 1.201261, -0.001373}}],
    Polygon[{{0.873058, 1.198582, 0.000000},{0.872950, 1.198582, 0.001373},{
      0.872525, 1.201261, 0.001373},{0.872628, 1.201294, 0.000000}}],
    Polygon[{{0.872950, 1.198582, 0.001373},{0.872628, 1.198582, 0.002712},{
      0.872220, 1.201162, 0.002712},{0.872525, 1.201261, 0.001373}}],
    Polygon[{{0.872628, 1.198582, 0.002712},{0.872101, 1.198582, 0.003984},{
      0.871718, 1.200999, 0.003984},{0.872220, 1.201162, 0.002712}}],
    Polygon[{{0.872101, 1.198582, 0.003984},{0.871382, 1.198582, 0.005159},{
      0.871034, 1.200776, 0.005159},{0.871718, 1.200999, 0.003984}}],
    Polygon[{{0.871382, 1.198582, 0.005159},{0.870487, 1.198582, 0.006206},{
      0.870183, 1.200500, 0.006206},{0.871034, 1.200776, 0.005159}}],
    Polygon[{{0.870487, 1.198582, 0.006206},{0.869440, 1.198582, 0.007100},{
      0.869187, 1.200176, 0.007100},{0.870183, 1.200500, 0.006206}}],
    Polygon[{{0.869440, 1.198582, 0.007100},{0.868266, 1.198582, 0.007820},{
      0.868071, 1.199814, 0.007820},{0.869187, 1.200176, 0.007100}}],
    Polygon[{{0.868266, 1.198582, 0.007820},{0.866993, 1.198582, 0.008347},{
      0.866861, 1.199420, 0.008347},{0.868071, 1.199814, 0.007820}}],
    Polygon[{{0.866993, 1.198582, 0.008347},{0.865654, 1.198582, 0.008668},{
      0.865587, 1.199007, 0.008668},{0.866861, 1.199420, 0.008347}}],
    Polygon[{{0.865587, 1.199007, -0.008668},{0.866861, 1.199420, -0.008347},{
      0.866475, 1.200176, -0.008347},{0.865392, 1.199389, -0.008668}}],
    Polygon[{{0.866861, 1.199420, -0.008347},{0.868071, 1.199814, -0.007820},{
      0.867505, 1.200924, -0.007820},{0.866475, 1.200176, -0.008347}}],
    Polygon[{{0.868071, 1.199814, -0.007820},{0.869187, 1.200176, -0.007100},{
      0.868455, 1.201615, -0.007100},{0.867505, 1.200924, -0.007820}}],
    Polygon[{{0.869187, 1.200176, -0.007100},{0.870183, 1.200500, -0.006206},{
      0.869302, 1.202230, -0.006206},{0.868455, 1.201615, -0.007100}}],
    Polygon[{{0.870183, 1.200500, -0.006206},{0.871034, 1.200776, -0.005159},{
      0.870026, 1.202756, -0.005159},{0.869302, 1.202230, -0.006206}}],
    Polygon[{{0.871034, 1.200776, -0.005159},{0.871718, 1.200999, -0.003984},{
      0.870608, 1.203179, -0.003984},{0.870026, 1.202756, -0.005159}}],
    Polygon[{{0.871718, 1.200999, -0.003984},{0.872220, 1.201162, -0.002712},{
      0.871034, 1.203489, -0.002712},{0.870608, 1.203179, -0.003984}}],
    Polygon[{{0.872220, 1.201162, -0.002712},{0.872525, 1.201261, -0.001373},{
      0.871294, 1.203678, -0.001373},{0.871034, 1.203489, -0.002712}}],
    Polygon[{{0.872525, 1.201261, -0.001373},{0.872628, 1.201294, 0.000000},{
      0.871382, 1.203741, 0.000000},{0.871294, 1.203678, -0.001373}}],
    Polygon[{{0.872628, 1.201294, 0.000000},{0.872525, 1.201261, 0.001373},{
      0.871294, 1.203678, 0.001373},{0.871382, 1.203741, 0.000000}}],
    Polygon[{{0.872525, 1.201261, 0.001373},{0.872220, 1.201162, 0.002712},{
      0.871034, 1.203489, 0.002712},{0.871294, 1.203678, 0.001373}}],
    Polygon[{{0.872220, 1.201162, 0.002712},{0.871718, 1.200999, 0.003984},{
      0.870608, 1.203179, 0.003984},{0.871034, 1.203489, 0.002712}}],
    Polygon[{{0.871718, 1.200999, 0.003984},{0.871034, 1.200776, 0.005159},{
      0.870026, 1.202756, 0.005159},{0.870608, 1.203179, 0.003984}}],
    Polygon[{{0.871034, 1.200776, 0.005159},{0.870183, 1.200500, 0.006206},{
      0.869302, 1.202230, 0.006206},{0.870026, 1.202756, 0.005159}}],
    Polygon[{{0.870183, 1.200500, 0.006206},{0.869187, 1.200176, 0.007100},{
      0.868455, 1.201615, 0.007100},{0.869302, 1.202230, 0.006206}}],
    Polygon[{{0.869187, 1.200176, 0.007100},{0.868071, 1.199814, 0.007820},{
      0.867505, 1.200924, 0.007820},{0.868455, 1.201615, 0.007100}}],
    Polygon[{{0.868071, 1.199814, 0.007820},{0.866861, 1.199420, 0.008347},{
      0.866475, 1.200176, 0.008347},{0.867505, 1.200924, 0.007820}}],
    Polygon[{{0.866861, 1.199420, 0.008347},{0.865587, 1.199007, 0.008668},{
      0.865392, 1.199389, 0.008668},{0.866475, 1.200176, 0.008347}}],
    Polygon[{{0.865392, 1.199389, -0.008668},{0.866475, 1.200176, -0.008347},{
      0.865875, 1.200776, -0.008347},{0.865088, 1.199693, -0.008668}}],
    Polygon[{{0.866475, 1.200176, -0.008347},{0.867505, 1.200924, -0.007820},{
      0.866623, 1.201806, -0.007820},{0.865875, 1.200776, -0.008347}}],
    Polygon[{{0.867505, 1.200924, -0.007820},{0.868455, 1.201615, -0.007100},{
      0.867313, 1.202756, -0.007100},{0.866623, 1.201806, -0.007820}}],
    Polygon[{{0.868455, 1.201615, -0.007100},{0.869302, 1.202230, -0.006206},{
      0.867929, 1.203603, -0.006206},{0.867313, 1.202756, -0.007100}}],
    Polygon[{{0.869302, 1.202230, -0.006206},{0.870026, 1.202756, -0.005159},{
      0.868455, 1.204327, -0.005159},{0.867929, 1.203603, -0.006206}}],
    Polygon[{{0.870026, 1.202756, -0.005159},{0.870608, 1.203179, -0.003984},{
      0.868878, 1.204909, -0.003984},{0.868455, 1.204327, -0.005159}}],
    Polygon[{{0.870608, 1.203179, -0.003984},{0.871034, 1.203489, -0.002712},{
      0.869187, 1.205335, -0.002712},{0.868878, 1.204909, -0.003984}}],
    Polygon[{{0.871034, 1.203489, -0.002712},{0.871294, 1.203678, -0.001373},{
      0.869376, 1.205595, -0.001373},{0.869187, 1.205335, -0.002712}}],
    Polygon[{{0.871294, 1.203678, -0.001373},{0.871382, 1.203741, 0.000000},{
      0.869440, 1.205683, 0.000000},{0.869376, 1.205595, -0.001373}}],
    Polygon[{{0.871382, 1.203741, 0.000000},{0.871294, 1.203678, 0.001373},{
      0.869376, 1.205595, 0.001373},{0.869440, 1.205683, 0.000000}}],
    Polygon[{{0.871294, 1.203678, 0.001373},{0.871034, 1.203489, 0.002712},{
      0.869187, 1.205335, 0.002712},{0.869376, 1.205595, 0.001373}}],
    Polygon[{{0.871034, 1.203489, 0.002712},{0.870608, 1.203179, 0.003984},{
      0.868878, 1.204909, 0.003984},{0.869187, 1.205335, 0.002712}}],
    Polygon[{{0.870608, 1.203179, 0.003984},{0.870026, 1.202756, 0.005159},{
      0.868455, 1.204327, 0.005159},{0.868878, 1.204909, 0.003984}}],
    Polygon[{{0.870026, 1.202756, 0.005159},{0.869302, 1.202230, 0.006206},{
      0.867929, 1.203603, 0.006206},{0.868455, 1.204327, 0.005159}}],
    Polygon[{{0.869302, 1.202230, 0.006206},{0.868455, 1.201615, 0.007100},{
      0.867313, 1.202756, 0.007100},{0.867929, 1.203603, 0.006206}}],
    Polygon[{{0.868455, 1.201615, 0.007100},{0.867505, 1.200924, 0.007820},{
      0.866623, 1.201806, 0.007820},{0.867313, 1.202756, 0.007100}}],
    Polygon[{{0.867505, 1.200924, 0.007820},{0.866475, 1.200176, 0.008347},{
      0.865875, 1.200776, 0.008347},{0.866623, 1.201806, 0.007820}}],
    Polygon[{{0.866475, 1.200176, 0.008347},{0.865392, 1.199389, 0.008668},{
      0.865088, 1.199693, 0.008668},{0.865875, 1.200776, 0.008347}}],
    Polygon[{{0.865088, 1.199693, -0.008668},{0.865875, 1.200776, -0.008347},{
      0.865119, 1.201162, -0.008347},{0.864706, 1.199888, -0.008668}}],
    Polygon[{{0.865875, 1.200776, -0.008347},{0.866623, 1.201806, -0.007820},{
      0.865513, 1.202372, -0.007820},{0.865119, 1.201162, -0.008347}}],
    Polygon[{{0.866623, 1.201806, -0.007820},{0.867313, 1.202756, -0.007100},{
      0.865875, 1.203489, -0.007100},{0.865513, 1.202372, -0.007820}}],
    Polygon[{{0.867313, 1.202756, -0.007100},{0.867929, 1.203603, -0.006206},{
      0.866199, 1.204484, -0.006206},{0.865875, 1.203489, -0.007100}}],
    Polygon[{{0.867929, 1.203603, -0.006206},{0.868455, 1.204327, -0.005159},{
      0.866475, 1.205335, -0.005159},{0.866199, 1.204484, -0.006206}}],
    Polygon[{{0.868455, 1.204327, -0.005159},{0.868878, 1.204909, -0.003984},{
      0.866698, 1.206020, -0.003984},{0.866475, 1.205335, -0.005159}}],
    Polygon[{{0.868878, 1.204909, -0.003984},{0.869187, 1.205335, -0.002712},{
      0.866861, 1.206521, -0.002712},{0.866698, 1.206020, -0.003984}}],
    Polygon[{{0.869187, 1.205335, -0.002712},{0.869376, 1.205595, -0.001373},{
      0.866960, 1.206826, -0.001373},{0.866861, 1.206521, -0.002712}}],
    Polygon[{{0.869376, 1.205595, -0.001373},{0.869440, 1.205683, 0.000000},{
      0.866993, 1.206929, 0.000000},{0.866960, 1.206826, -0.001373}}],
    Polygon[{{0.869440, 1.205683, 0.000000},{0.869376, 1.205595, 0.001373},{
      0.866960, 1.206826, 0.001373},{0.866993, 1.206929, 0.000000}}],
    Polygon[{{0.869376, 1.205595, 0.001373},{0.869187, 1.205335, 0.002712},{
      0.866861, 1.206521, 0.002712},{0.866960, 1.206826, 0.001373}}],
    Polygon[{{0.869187, 1.205335, 0.002712},{0.868878, 1.204909, 0.003984},{
      0.866698, 1.206020, 0.003984},{0.866861, 1.206521, 0.002712}}],
    Polygon[{{0.868878, 1.204909, 0.003984},{0.868455, 1.204327, 0.005159},{
      0.866475, 1.205335, 0.005159},{0.866698, 1.206020, 0.003984}}],
    Polygon[{{0.868455, 1.204327, 0.005159},{0.867929, 1.203603, 0.006206},{
      0.866199, 1.204484, 0.006206},{0.866475, 1.205335, 0.005159}}],
    Polygon[{{0.867929, 1.203603, 0.006206},{0.867313, 1.202756, 0.007100},{
      0.865875, 1.203489, 0.007100},{0.866199, 1.204484, 0.006206}}],
    Polygon[{{0.867313, 1.202756, 0.007100},{0.866623, 1.201806, 0.007820},{
      0.865513, 1.202372, 0.007820},{0.865875, 1.203489, 0.007100}}],
    Polygon[{{0.866623, 1.201806, 0.007820},{0.865875, 1.200776, 0.008347},{
      0.865119, 1.201162, 0.008347},{0.865513, 1.202372, 0.007820}}],
    Polygon[{{0.865875, 1.200776, 0.008347},{0.865088, 1.199693, 0.008668},{
      0.864706, 1.199888, 0.008668},{0.865119, 1.201162, 0.008347}}],
    Polygon[{{0.864706, 1.199888, -0.008668},{0.865119, 1.201162, -0.008347},{
      0.864281, 1.201294, -0.008347},{0.864281, 1.199955, -0.008668}}],
    Polygon[{{0.865119, 1.201162, -0.008347},{0.865513, 1.202372, -0.007820},{
      0.864281, 1.202567, -0.007820},{0.864281, 1.201294, -0.008347}}],
    Polygon[{{0.865513, 1.202372, -0.007820},{0.865875, 1.203489, -0.007100},{
      0.864281, 1.203741, -0.007100},{0.864281, 1.202567, -0.007820}}],
    Polygon[{{0.865875, 1.203489, -0.007100},{0.866199, 1.204484, -0.006206},{
      0.864281, 1.204788, -0.006206},{0.864281, 1.203741, -0.007100}}],
    Polygon[{{0.866199, 1.204484, -0.006206},{0.866475, 1.205335, -0.005159},{
      0.864281, 1.205683, -0.005159},{0.864281, 1.204788, -0.006206}}],
    Polygon[{{0.866475, 1.205335, -0.005159},{0.866698, 1.206020, -0.003984},{
      0.864281, 1.206402, -0.003984},{0.864281, 1.205683, -0.005159}}],
    Polygon[{{0.866698, 1.206020, -0.003984},{0.866861, 1.206521, -0.002712},{
      0.864281, 1.206929, -0.002712},{0.864281, 1.206402, -0.003984}}],
    Polygon[{{0.866861, 1.206521, -0.002712},{0.866960, 1.206826, -0.001373},{
      0.864281, 1.207251, -0.001373},{0.864281, 1.206929, -0.002712}}],
    Polygon[{{0.866960, 1.206826, -0.001373},{0.866993, 1.206929, 0.000000},{
      0.864281, 1.207359, 0.000000},{0.864281, 1.207251, -0.001373}}],
    Polygon[{{0.866993, 1.206929, 0.000000},{0.866960, 1.206826, 0.001373},{
      0.864281, 1.207251, 0.001373},{0.864281, 1.207359, 0.000000}}],
    Polygon[{{0.866960, 1.206826, 0.001373},{0.866861, 1.206521, 0.002712},{
      0.864281, 1.206929, 0.002712},{0.864281, 1.207251, 0.001373}}],
    Polygon[{{0.866861, 1.206521, 0.002712},{0.866698, 1.206020, 0.003984},{
      0.864281, 1.206402, 0.003984},{0.864281, 1.206929, 0.002712}}],
    Polygon[{{0.866698, 1.206020, 0.003984},{0.866475, 1.205335, 0.005159},{
      0.864281, 1.205683, 0.005159},{0.864281, 1.206402, 0.003984}}],
    Polygon[{{0.866475, 1.205335, 0.005159},{0.866199, 1.204484, 0.006206},{
      0.864281, 1.204788, 0.006206},{0.864281, 1.205683, 0.005159}}],
    Polygon[{{0.866199, 1.204484, 0.006206},{0.865875, 1.203489, 0.007100},{
      0.864281, 1.203741, 0.007100},{0.864281, 1.204788, 0.006206}}],
    Polygon[{{0.865875, 1.203489, 0.007100},{0.865513, 1.202372, 0.007820},{
      0.864281, 1.202567, 0.007820},{0.864281, 1.203741, 0.007100}}],
    Polygon[{{0.865513, 1.202372, 0.007820},{0.865119, 1.201162, 0.008347},{
      0.864281, 1.201294, 0.008347},{0.864281, 1.202567, 0.007820}}],
    Polygon[{{0.865119, 1.201162, 0.008347},{0.864706, 1.199888, 0.008668},{
      0.864281, 1.199955, 0.008668},{0.864281, 1.201294, 0.008347}}],
    Polygon[{{0.864281, 1.199955, -0.008668},{0.864281, 1.201294, -0.008347},{
      0.863443, 1.201162, -0.008347},{0.863857, 1.199888, -0.008668}}],
    Polygon[{{0.864281, 1.201294, -0.008347},{0.864281, 1.202567, -0.007820},{
      0.863050, 1.202372, -0.007820},{0.863443, 1.201162, -0.008347}}],
    Polygon[{{0.864281, 1.202567, -0.007820},{0.864281, 1.203741, -0.007100},{
      0.862687, 1.203489, -0.007100},{0.863050, 1.202372, -0.007820}}],
    Polygon[{{0.864281, 1.203741, -0.007100},{0.864281, 1.204788, -0.006206},{
      0.862364, 1.204484, -0.006206},{0.862687, 1.203489, -0.007100}}],
    Polygon[{{0.864281, 1.204788, -0.006206},{0.864281, 1.205683, -0.005159},{
      0.862087, 1.205335, -0.005159},{0.862364, 1.204484, -0.006206}}],
    Polygon[{{0.864281, 1.205683, -0.005159},{0.864281, 1.206402, -0.003984},{
      0.861865, 1.206020, -0.003984},{0.862087, 1.205335, -0.005159}}],
    Polygon[{{0.864281, 1.206402, -0.003984},{0.864281, 1.206929, -0.002712},{
      0.861702, 1.206521, -0.002712},{0.861865, 1.206020, -0.003984}}],
    Polygon[{{0.864281, 1.206929, -0.002712},{0.864281, 1.207251, -0.001373},{
      0.861603, 1.206826, -0.001373},{0.861702, 1.206521, -0.002712}}],
    Polygon[{{0.864281, 1.207251, -0.001373},{0.864281, 1.207359, 0.000000},{
      0.861569, 1.206929, 0.000000},{0.861603, 1.206826, -0.001373}}],
    Polygon[{{0.864281, 1.207359, 0.000000},{0.864281, 1.207251, 0.001373},{
      0.861603, 1.206826, 0.001373},{0.861569, 1.206929, 0.000000}}],
    Polygon[{{0.864281, 1.207251, 0.001373},{0.864281, 1.206929, 0.002712},{
      0.861702, 1.206521, 0.002712},{0.861603, 1.206826, 0.001373}}],
    Polygon[{{0.864281, 1.206929, 0.002712},{0.864281, 1.206402, 0.003984},{
      0.861865, 1.206020, 0.003984},{0.861702, 1.206521, 0.002712}}],
    Polygon[{{0.864281, 1.206402, 0.003984},{0.864281, 1.205683, 0.005159},{
      0.862087, 1.205335, 0.005159},{0.861865, 1.206020, 0.003984}}],
    Polygon[{{0.864281, 1.205683, 0.005159},{0.864281, 1.204788, 0.006206},{
      0.862364, 1.204484, 0.006206},{0.862087, 1.205335, 0.005159}}],
    Polygon[{{0.864281, 1.204788, 0.006206},{0.864281, 1.203741, 0.007100},{
      0.862687, 1.203489, 0.007100},{0.862364, 1.204484, 0.006206}}],
    Polygon[{{0.864281, 1.203741, 0.007100},{0.864281, 1.202567, 0.007820},{
      0.863050, 1.202372, 0.007820},{0.862687, 1.203489, 0.007100}}],
    Polygon[{{0.864281, 1.202567, 0.007820},{0.864281, 1.201294, 0.008347},{
      0.863443, 1.201162, 0.008347},{0.863050, 1.202372, 0.007820}}],
    Polygon[{{0.864281, 1.201294, 0.008347},{0.864281, 1.199955, 0.008668},{
      0.863857, 1.199888, 0.008668},{0.863443, 1.201162, 0.008347}}],
    Polygon[{{0.863857, 1.199888, -0.008668},{0.863443, 1.201162, -0.008347},{
      0.862687, 1.200776, -0.008347},{0.863474, 1.199693, -0.008668}}],
    Polygon[{{0.863443, 1.201162, -0.008347},{0.863050, 1.202372, -0.007820},{
      0.861939, 1.201806, -0.007820},{0.862687, 1.200776, -0.008347}}],
    Polygon[{{0.863050, 1.202372, -0.007820},{0.862687, 1.203489, -0.007100},{
      0.861249, 1.202756, -0.007100},{0.861939, 1.201806, -0.007820}}],
    Polygon[{{0.862687, 1.203489, -0.007100},{0.862364, 1.204484, -0.006206},{
      0.860634, 1.203603, -0.006206},{0.861249, 1.202756, -0.007100}}],
    Polygon[{{0.862364, 1.204484, -0.006206},{0.862087, 1.205335, -0.005159},{
      0.860108, 1.204327, -0.005159},{0.860634, 1.203603, -0.006206}}],
    Polygon[{{0.862087, 1.205335, -0.005159},{0.861865, 1.206020, -0.003984},{
      0.859685, 1.204909, -0.003984},{0.860108, 1.204327, -0.005159}}],
    Polygon[{{0.861865, 1.206020, -0.003984},{0.861702, 1.206521, -0.002712},{
      0.859375, 1.205335, -0.002712},{0.859685, 1.204909, -0.003984}}],
    Polygon[{{0.861702, 1.206521, -0.002712},{0.861603, 1.206826, -0.001373},{
      0.859186, 1.205595, -0.001373},{0.859375, 1.205335, -0.002712}}],
    Polygon[{{0.861603, 1.206826, -0.001373},{0.861569, 1.206929, 0.000000},{
      0.859123, 1.205683, 0.000000},{0.859186, 1.205595, -0.001373}}],
    Polygon[{{0.861569, 1.206929, 0.000000},{0.861603, 1.206826, 0.001373},{
      0.859186, 1.205595, 0.001373},{0.859123, 1.205683, 0.000000}}],
    Polygon[{{0.861603, 1.206826, 0.001373},{0.861702, 1.206521, 0.002712},{
      0.859375, 1.205335, 0.002712},{0.859186, 1.205595, 0.001373}}],
    Polygon[{{0.861702, 1.206521, 0.002712},{0.861865, 1.206020, 0.003984},{
      0.859685, 1.204909, 0.003984},{0.859375, 1.205335, 0.002712}}],
    Polygon[{{0.861865, 1.206020, 0.003984},{0.862087, 1.205335, 0.005159},{
      0.860108, 1.204327, 0.005159},{0.859685, 1.204909, 0.003984}}],
    Polygon[{{0.862087, 1.205335, 0.005159},{0.862364, 1.204484, 0.006206},{
      0.860634, 1.203603, 0.006206},{0.860108, 1.204327, 0.005159}}],
    Polygon[{{0.862364, 1.204484, 0.006206},{0.862687, 1.203489, 0.007100},{
      0.861249, 1.202756, 0.007100},{0.860634, 1.203603, 0.006206}}],
    Polygon[{{0.862687, 1.203489, 0.007100},{0.863050, 1.202372, 0.007820},{
      0.861939, 1.201806, 0.007820},{0.861249, 1.202756, 0.007100}}],
    Polygon[{{0.863050, 1.202372, 0.007820},{0.863443, 1.201162, 0.008347},{
      0.862687, 1.200776, 0.008347},{0.861939, 1.201806, 0.007820}}],
    Polygon[{{0.863443, 1.201162, 0.008347},{0.863857, 1.199888, 0.008668},{
      0.863474, 1.199693, 0.008668},{0.862687, 1.200776, 0.008347}}],
    Polygon[{{0.863474, 1.199693, -0.008668},{0.862687, 1.200776, -0.008347},{
      0.862087, 1.200176, -0.008347},{0.863171, 1.199389, -0.008668}}],
    Polygon[{{0.862687, 1.200776, -0.008347},{0.861939, 1.201806, -0.007820},{
      0.861058, 1.200924, -0.007820},{0.862087, 1.200176, -0.008347}}],
    Polygon[{{0.861939, 1.201806, -0.007820},{0.861249, 1.202756, -0.007100},{
      0.860108, 1.201615, -0.007100},{0.861058, 1.200924, -0.007820}}],
    Polygon[{{0.861249, 1.202756, -0.007100},{0.860634, 1.203603, -0.006206},{
      0.859261, 1.202230, -0.006206},{0.860108, 1.201615, -0.007100}}],
    Polygon[{{0.860634, 1.203603, -0.006206},{0.860108, 1.204327, -0.005159},{
      0.858537, 1.202756, -0.005159},{0.859261, 1.202230, -0.006206}}],
    Polygon[{{0.860108, 1.204327, -0.005159},{0.859685, 1.204909, -0.003984},{
      0.857955, 1.203179, -0.003984},{0.858537, 1.202756, -0.005159}}],
    Polygon[{{0.859685, 1.204909, -0.003984},{0.859375, 1.205335, -0.002712},{
      0.857529, 1.203489, -0.002712},{0.857955, 1.203179, -0.003984}}],
    Polygon[{{0.859375, 1.205335, -0.002712},{0.859186, 1.205595, -0.001373},{
      0.857268, 1.203678, -0.001373},{0.857529, 1.203489, -0.002712}}],
    Polygon[{{0.859186, 1.205595, -0.001373},{0.859123, 1.205683, 0.000000},{
      0.857181, 1.203741, 0.000000},{0.857268, 1.203678, -0.001373}}],
    Polygon[{{0.859123, 1.205683, 0.000000},{0.859186, 1.205595, 0.001373},{
      0.857268, 1.203678, 0.001373},{0.857181, 1.203741, 0.000000}}],
    Polygon[{{0.859186, 1.205595, 0.001373},{0.859375, 1.205335, 0.002712},{
      0.857529, 1.203489, 0.002712},{0.857268, 1.203678, 0.001373}}],
    Polygon[{{0.859375, 1.205335, 0.002712},{0.859685, 1.204909, 0.003984},{
      0.857955, 1.203179, 0.003984},{0.857529, 1.203489, 0.002712}}],
    Polygon[{{0.859685, 1.204909, 0.003984},{0.860108, 1.204327, 0.005159},{
      0.858537, 1.202756, 0.005159},{0.857955, 1.203179, 0.003984}}],
    Polygon[{{0.860108, 1.204327, 0.005159},{0.860634, 1.203603, 0.006206},{
      0.859261, 1.202230, 0.006206},{0.858537, 1.202756, 0.005159}}],
    Polygon[{{0.860634, 1.203603, 0.006206},{0.861249, 1.202756, 0.007100},{
      0.860108, 1.201615, 0.007100},{0.859261, 1.202230, 0.006206}}],
    Polygon[{{0.861249, 1.202756, 0.007100},{0.861939, 1.201806, 0.007820},{
      0.861058, 1.200924, 0.007820},{0.860108, 1.201615, 0.007100}}],
    Polygon[{{0.861939, 1.201806, 0.007820},{0.862687, 1.200776, 0.008347},{
      0.862087, 1.200176, 0.008347},{0.861058, 1.200924, 0.007820}}],
    Polygon[{{0.862687, 1.200776, 0.008347},{0.863474, 1.199693, 0.008668},{
      0.863171, 1.199389, 0.008668},{0.862087, 1.200176, 0.008347}}],
    Polygon[{{0.863171, 1.199389, -0.008668},{0.862087, 1.200176, -0.008347},{
      0.861702, 1.199420, -0.008347},{0.862976, 1.199007, -0.008668}}],
    Polygon[{{0.862087, 1.200176, -0.008347},{0.861058, 1.200924, -0.007820},{
      0.860492, 1.199814, -0.007820},{0.861702, 1.199420, -0.008347}}],
    Polygon[{{0.861058, 1.200924, -0.007820},{0.860108, 1.201615, -0.007100},{
      0.859375, 1.200176, -0.007100},{0.860492, 1.199814, -0.007820}}],
    Polygon[{{0.860108, 1.201615, -0.007100},{0.859261, 1.202230, -0.006206},{
      0.858379, 1.200500, -0.006206},{0.859375, 1.200176, -0.007100}}],
    Polygon[{{0.859261, 1.202230, -0.006206},{0.858537, 1.202756, -0.005159},{
      0.857529, 1.200776, -0.005159},{0.858379, 1.200500, -0.006206}}],
    Polygon[{{0.858537, 1.202756, -0.005159},{0.857955, 1.203179, -0.003984},{
      0.856844, 1.200999, -0.003984},{0.857529, 1.200776, -0.005159}}],
    Polygon[{{0.857955, 1.203179, -0.003984},{0.857529, 1.203489, -0.002712},{
      0.856343, 1.201162, -0.002712},{0.856844, 1.200999, -0.003984}}],
    Polygon[{{0.857529, 1.203489, -0.002712},{0.857268, 1.203678, -0.001373},{
      0.856037, 1.201261, -0.001373},{0.856343, 1.201162, -0.002712}}],
    Polygon[{{0.857268, 1.203678, -0.001373},{0.857181, 1.203741, 0.000000},{
      0.855934, 1.201294, 0.000000},{0.856037, 1.201261, -0.001373}}],
    Polygon[{{0.857181, 1.203741, 0.000000},{0.857268, 1.203678, 0.001373},{
      0.856037, 1.201261, 0.001373},{0.855934, 1.201294, 0.000000}}],
    Polygon[{{0.857268, 1.203678, 0.001373},{0.857529, 1.203489, 0.002712},{
      0.856343, 1.201162, 0.002712},{0.856037, 1.201261, 0.001373}}],
    Polygon[{{0.857529, 1.203489, 0.002712},{0.857955, 1.203179, 0.003984},{
      0.856844, 1.200999, 0.003984},{0.856343, 1.201162, 0.002712}}],
    Polygon[{{0.857955, 1.203179, 0.003984},{0.858537, 1.202756, 0.005159},{
      0.857529, 1.200776, 0.005159},{0.856844, 1.200999, 0.003984}}],
    Polygon[{{0.858537, 1.202756, 0.005159},{0.859261, 1.202230, 0.006206},{
      0.858379, 1.200500, 0.006206},{0.857529, 1.200776, 0.005159}}],
    Polygon[{{0.859261, 1.202230, 0.006206},{0.860108, 1.201615, 0.007100},{
      0.859375, 1.200176, 0.007100},{0.858379, 1.200500, 0.006206}}],
    Polygon[{{0.860108, 1.201615, 0.007100},{0.861058, 1.200924, 0.007820},{
      0.860492, 1.199814, 0.007820},{0.859375, 1.200176, 0.007100}}],
    Polygon[{{0.861058, 1.200924, 0.007820},{0.862087, 1.200176, 0.008347},{
      0.861702, 1.199420, 0.008347},{0.860492, 1.199814, 0.007820}}],
    Polygon[{{0.862087, 1.200176, 0.008347},{0.863171, 1.199389, 0.008668},{
      0.862976, 1.199007, 0.008668},{0.861702, 1.199420, 0.008347}}],
    Polygon[{{0.862976, 1.199007, -0.008668},{0.861702, 1.199420, -0.008347},{
      0.861569, 1.198582, -0.008347},{0.862908, 1.198582, -0.008668}}],
    Polygon[{{0.861702, 1.199420, -0.008347},{0.860492, 1.199814, -0.007820},{
      0.860297, 1.198582, -0.007820},{0.861569, 1.198582, -0.008347}}],
    Polygon[{{0.860492, 1.199814, -0.007820},{0.859375, 1.200176, -0.007100},{
      0.859123, 1.198582, -0.007100},{0.860297, 1.198582, -0.007820}}],
    Polygon[{{0.859375, 1.200176, -0.007100},{0.858379, 1.200500, -0.006206},{
      0.858075, 1.198582, -0.006206},{0.859123, 1.198582, -0.007100}}],
    Polygon[{{0.858379, 1.200500, -0.006206},{0.857529, 1.200776, -0.005159},{
      0.857181, 1.198582, -0.005159},{0.858075, 1.198582, -0.006206}}],
    Polygon[{{0.857529, 1.200776, -0.005159},{0.856844, 1.200999, -0.003984},{
      0.856461, 1.198582, -0.003984},{0.857181, 1.198582, -0.005159}}],
    Polygon[{{0.856844, 1.200999, -0.003984},{0.856343, 1.201162, -0.002712},{
      0.855934, 1.198582, -0.002712},{0.856461, 1.198582, -0.003984}}],
    Polygon[{{0.856343, 1.201162, -0.002712},{0.856037, 1.201261, -0.001373},{
      0.855613, 1.198582, -0.001373},{0.855934, 1.198582, -0.002712}}],
    Polygon[{{0.856037, 1.201261, -0.001373},{0.855934, 1.201294, 0.000000},{
      0.855505, 1.198582, 0.000000},{0.855613, 1.198582, -0.001373}}],
    Polygon[{{0.855934, 1.201294, 0.000000},{0.856037, 1.201261, 0.001373},{
      0.855613, 1.198582, 0.001373},{0.855505, 1.198582, 0.000000}}],
    Polygon[{{0.856037, 1.201261, 0.001373},{0.856343, 1.201162, 0.002712},{
      0.855934, 1.198582, 0.002712},{0.855613, 1.198582, 0.001373}}],
    Polygon[{{0.856343, 1.201162, 0.002712},{0.856844, 1.200999, 0.003984},{
      0.856461, 1.198582, 0.003984},{0.855934, 1.198582, 0.002712}}],
    Polygon[{{0.856844, 1.200999, 0.003984},{0.857529, 1.200776, 0.005159},{
      0.857181, 1.198582, 0.005159},{0.856461, 1.198582, 0.003984}}],
    Polygon[{{0.857529, 1.200776, 0.005159},{0.858379, 1.200500, 0.006206},{
      0.858075, 1.198582, 0.006206},{0.857181, 1.198582, 0.005159}}],
    Polygon[{{0.858379, 1.200500, 0.006206},{0.859375, 1.200176, 0.007100},{
      0.859123, 1.198582, 0.007100},{0.858075, 1.198582, 0.006206}}],
    Polygon[{{0.859375, 1.200176, 0.007100},{0.860492, 1.199814, 0.007820},{
      0.860297, 1.198582, 0.007820},{0.859123, 1.198582, 0.007100}}],
    Polygon[{{0.860492, 1.199814, 0.007820},{0.861702, 1.199420, 0.008347},{
      0.861569, 1.198582, 0.008347},{0.860297, 1.198582, 0.007820}}],
    Polygon[{{0.861702, 1.199420, 0.008347},{0.862976, 1.199007, 0.008668},{
      0.862908, 1.198582, 0.008668},{0.861569, 1.198582, 0.008347}}],
    Polygon[{{0.862908, 1.198582, -0.008668},{0.861569, 1.198582, -0.008347},{
      0.861702, 1.197744, -0.008347},{0.862976, 1.198158, -0.008668}}],
    Polygon[{{0.861569, 1.198582, -0.008347},{0.860297, 1.198582, -0.007820},{
      0.860492, 1.197351, -0.007820},{0.861702, 1.197744, -0.008347}}],
    Polygon[{{0.860297, 1.198582, -0.007820},{0.859123, 1.198582, -0.007100},{
      0.859375, 1.196988, -0.007100},{0.860492, 1.197351, -0.007820}}],
    Polygon[{{0.859123, 1.198582, -0.007100},{0.858075, 1.198582, -0.006206},{
      0.858379, 1.196665, -0.006206},{0.859375, 1.196988, -0.007100}}],
    Polygon[{{0.858075, 1.198582, -0.006206},{0.857181, 1.198582, -0.005159},{
      0.857529, 1.196388, -0.005159},{0.858379, 1.196665, -0.006206}}],
    Polygon[{{0.857181, 1.198582, -0.005159},{0.856461, 1.198582, -0.003984},{
      0.856844, 1.196166, -0.003984},{0.857529, 1.196388, -0.005159}}],
    Polygon[{{0.856461, 1.198582, -0.003984},{0.855934, 1.198582, -0.002712},{
      0.856343, 1.196003, -0.002712},{0.856844, 1.196166, -0.003984}}],
    Polygon[{{0.855934, 1.198582, -0.002712},{0.855613, 1.198582, -0.001373},{
      0.856037, 1.195904, -0.001373},{0.856343, 1.196003, -0.002712}}],
    Polygon[{{0.855613, 1.198582, -0.001373},{0.855505, 1.198582, 0.000000},{
      0.855934, 1.195870, 0.000000},{0.856037, 1.195904, -0.001373}}],
    Polygon[{{0.855505, 1.198582, 0.000000},{0.855613, 1.198582, 0.001373},{
      0.856037, 1.195904, 0.001373},{0.855934, 1.195870, 0.000000}}],
    Polygon[{{0.855613, 1.198582, 0.001373},{0.855934, 1.198582, 0.002712},{
      0.856343, 1.196003, 0.002712},{0.856037, 1.195904, 0.001373}}],
    Polygon[{{0.855934, 1.198582, 0.002712},{0.856461, 1.198582, 0.003984},{
      0.856844, 1.196166, 0.003984},{0.856343, 1.196003, 0.002712}}],
    Polygon[{{0.856461, 1.198582, 0.003984},{0.857181, 1.198582, 0.005159},{
      0.857529, 1.196388, 0.005159},{0.856844, 1.196166, 0.003984}}],
    Polygon[{{0.857181, 1.198582, 0.005159},{0.858075, 1.198582, 0.006206},{
      0.858379, 1.196665, 0.006206},{0.857529, 1.196388, 0.005159}}],
    Polygon[{{0.858075, 1.198582, 0.006206},{0.859123, 1.198582, 0.007100},{
      0.859375, 1.196988, 0.007100},{0.858379, 1.196665, 0.006206}}],
    Polygon[{{0.859123, 1.198582, 0.007100},{0.860297, 1.198582, 0.007820},{
      0.860492, 1.197351, 0.007820},{0.859375, 1.196988, 0.007100}}],
    Polygon[{{0.860297, 1.198582, 0.007820},{0.861569, 1.198582, 0.008347},{
      0.861702, 1.197744, 0.008347},{0.860492, 1.197351, 0.007820}}],
    Polygon[{{0.861569, 1.198582, 0.008347},{0.862908, 1.198582, 0.008668},{
      0.862976, 1.198158, 0.008668},{0.861702, 1.197744, 0.008347}}],
    Polygon[{{0.862976, 1.198158, -0.008668},{0.861702, 1.197744, -0.008347},{
      0.862087, 1.196988, -0.008347},{0.863171, 1.197775, -0.008668}}],
    Polygon[{{0.861702, 1.197744, -0.008347},{0.860492, 1.197351, -0.007820},{
      0.861058, 1.196240, -0.007820},{0.862087, 1.196988, -0.008347}}],
    Polygon[{{0.860492, 1.197351, -0.007820},{0.859375, 1.196988, -0.007100},{
      0.860108, 1.195550, -0.007100},{0.861058, 1.196240, -0.007820}}],
    Polygon[{{0.859375, 1.196988, -0.007100},{0.858379, 1.196665, -0.006206},{
      0.859261, 1.194935, -0.006206},{0.860108, 1.195550, -0.007100}}],
    Polygon[{{0.858379, 1.196665, -0.006206},{0.857529, 1.196388, -0.005159},{
      0.858537, 1.194409, -0.005159},{0.859261, 1.194935, -0.006206}}],
    Polygon[{{0.857529, 1.196388, -0.005159},{0.856844, 1.196166, -0.003984},{
      0.857955, 1.193986, -0.003984},{0.858537, 1.194409, -0.005159}}],
    Polygon[{{0.856844, 1.196166, -0.003984},{0.856343, 1.196003, -0.002712},{
      0.857529, 1.193676, -0.002712},{0.857955, 1.193986, -0.003984}}],
    Polygon[{{0.856343, 1.196003, -0.002712},{0.856037, 1.195904, -0.001373},{
      0.857268, 1.193487, -0.001373},{0.857529, 1.193676, -0.002712}}],
    Polygon[{{0.856037, 1.195904, -0.001373},{0.855934, 1.195870, 0.000000},{
      0.857181, 1.193424, 0.000000},{0.857268, 1.193487, -0.001373}}],
    Polygon[{{0.855934, 1.195870, 0.000000},{0.856037, 1.195904, 0.001373},{
      0.857268, 1.193487, 0.001373},{0.857181, 1.193424, 0.000000}}],
    Polygon[{{0.856037, 1.195904, 0.001373},{0.856343, 1.196003, 0.002712},{
      0.857529, 1.193676, 0.002712},{0.857268, 1.193487, 0.001373}}],
    Polygon[{{0.856343, 1.196003, 0.002712},{0.856844, 1.196166, 0.003984},{
      0.857955, 1.193986, 0.003984},{0.857529, 1.193676, 0.002712}}],
    Polygon[{{0.856844, 1.196166, 0.003984},{0.857529, 1.196388, 0.005159},{
      0.858537, 1.194409, 0.005159},{0.857955, 1.193986, 0.003984}}],
    Polygon[{{0.857529, 1.196388, 0.005159},{0.858379, 1.196665, 0.006206},{
      0.859261, 1.194935, 0.006206},{0.858537, 1.194409, 0.005159}}],
    Polygon[{{0.858379, 1.196665, 0.006206},{0.859375, 1.196988, 0.007100},{
      0.860108, 1.195550, 0.007100},{0.859261, 1.194935, 0.006206}}],
    Polygon[{{0.859375, 1.196988, 0.007100},{0.860492, 1.197351, 0.007820},{
      0.861058, 1.196240, 0.007820},{0.860108, 1.195550, 0.007100}}],
    Polygon[{{0.860492, 1.197351, 0.007820},{0.861702, 1.197744, 0.008347},{
      0.862087, 1.196988, 0.008347},{0.861058, 1.196240, 0.007820}}],
    Polygon[{{0.861702, 1.197744, 0.008347},{0.862976, 1.198158, 0.008668},{
      0.863171, 1.197775, 0.008668},{0.862087, 1.196988, 0.008347}}],
    Polygon[{{0.863171, 1.197775, -0.008668},{0.862087, 1.196988, -0.008347},{
      0.862687, 1.196388, -0.008347},{0.863474, 1.197472, -0.008668}}],
    Polygon[{{0.862087, 1.196988, -0.008347},{0.861058, 1.196240, -0.007820},{
      0.861939, 1.195359, -0.007820},{0.862687, 1.196388, -0.008347}}],
    Polygon[{{0.861058, 1.196240, -0.007820},{0.860108, 1.195550, -0.007100},{
      0.861249, 1.194409, -0.007100},{0.861939, 1.195359, -0.007820}}],
    Polygon[{{0.860108, 1.195550, -0.007100},{0.859261, 1.194935, -0.006206},{
      0.860634, 1.193562, -0.006206},{0.861249, 1.194409, -0.007100}}],
    Polygon[{{0.859261, 1.194935, -0.006206},{0.858537, 1.194409, -0.005159},{
      0.860108, 1.192838, -0.005159},{0.860634, 1.193562, -0.006206}}],
    Polygon[{{0.858537, 1.194409, -0.005159},{0.857955, 1.193986, -0.003984},{
      0.859685, 1.192256, -0.003984},{0.860108, 1.192838, -0.005159}}],
    Polygon[{{0.857955, 1.193986, -0.003984},{0.857529, 1.193676, -0.002712},{
      0.859375, 1.191830, -0.002712},{0.859685, 1.192256, -0.003984}}],
    Polygon[{{0.857529, 1.193676, -0.002712},{0.857268, 1.193487, -0.001373},{
      0.859186, 1.191570, -0.001373},{0.859375, 1.191830, -0.002712}}],
    Polygon[{{0.857268, 1.193487, -0.001373},{0.857181, 1.193424, 0.000000},{
      0.859123, 1.191482, 0.000000},{0.859186, 1.191570, -0.001373}}],
    Polygon[{{0.857181, 1.193424, 0.000000},{0.857268, 1.193487, 0.001373},{
      0.859186, 1.191570, 0.001373},{0.859123, 1.191482, 0.000000}}],
    Polygon[{{0.857268, 1.193487, 0.001373},{0.857529, 1.193676, 0.002712},{
      0.859375, 1.191830, 0.002712},{0.859186, 1.191570, 0.001373}}],
    Polygon[{{0.857529, 1.193676, 0.002712},{0.857955, 1.193986, 0.003984},{
      0.859685, 1.192256, 0.003984},{0.859375, 1.191830, 0.002712}}],
    Polygon[{{0.857955, 1.193986, 0.003984},{0.858537, 1.194409, 0.005159},{
      0.860108, 1.192838, 0.005159},{0.859685, 1.192256, 0.003984}}],
    Polygon[{{0.858537, 1.194409, 0.005159},{0.859261, 1.194935, 0.006206},{
      0.860634, 1.193562, 0.006206},{0.860108, 1.192838, 0.005159}}],
    Polygon[{{0.859261, 1.194935, 0.006206},{0.860108, 1.195550, 0.007100},{
      0.861249, 1.194409, 0.007100},{0.860634, 1.193562, 0.006206}}],
    Polygon[{{0.860108, 1.195550, 0.007100},{0.861058, 1.196240, 0.007820},{
      0.861939, 1.195359, 0.007820},{0.861249, 1.194409, 0.007100}}],
    Polygon[{{0.861058, 1.196240, 0.007820},{0.862087, 1.196988, 0.008347},{
      0.862687, 1.196388, 0.008347},{0.861939, 1.195359, 0.007820}}],
    Polygon[{{0.862087, 1.196988, 0.008347},{0.863171, 1.197775, 0.008668},{
      0.863474, 1.197472, 0.008668},{0.862687, 1.196388, 0.008347}}],
    Polygon[{{0.863474, 1.197472, -0.008668},{0.862687, 1.196388, -0.008347},{
      0.863443, 1.196003, -0.008347},{0.863857, 1.197277, -0.008668}}],
    Polygon[{{0.862687, 1.196388, -0.008347},{0.861939, 1.195359, -0.007820},{
      0.863050, 1.194793, -0.007820},{0.863443, 1.196003, -0.008347}}],
    Polygon[{{0.861939, 1.195359, -0.007820},{0.861249, 1.194409, -0.007100},{
      0.862687, 1.193676, -0.007100},{0.863050, 1.194793, -0.007820}}],
    Polygon[{{0.861249, 1.194409, -0.007100},{0.860634, 1.193562, -0.006206},{
      0.862364, 1.192680, -0.006206},{0.862687, 1.193676, -0.007100}}],
    Polygon[{{0.860634, 1.193562, -0.006206},{0.860108, 1.192838, -0.005159},{
      0.862087, 1.191830, -0.005159},{0.862364, 1.192680, -0.006206}}],
    Polygon[{{0.860108, 1.192838, -0.005159},{0.859685, 1.192256, -0.003984},{
      0.861865, 1.191145, -0.003984},{0.862087, 1.191830, -0.005159}}],
    Polygon[{{0.859685, 1.192256, -0.003984},{0.859375, 1.191830, -0.002712},{
      0.861702, 1.190644, -0.002712},{0.861865, 1.191145, -0.003984}}],
    Polygon[{{0.859375, 1.191830, -0.002712},{0.859186, 1.191570, -0.001373},{
      0.861603, 1.190338, -0.001373},{0.861702, 1.190644, -0.002712}}],
    Polygon[{{0.859186, 1.191570, -0.001373},{0.859123, 1.191482, 0.000000},{
      0.861569, 1.190236, 0.000000},{0.861603, 1.190338, -0.001373}}],
    Polygon[{{0.859123, 1.191482, 0.000000},{0.859186, 1.191570, 0.001373},{
      0.861603, 1.190338, 0.001373},{0.861569, 1.190236, 0.000000}}],
    Polygon[{{0.859186, 1.191570, 0.001373},{0.859375, 1.191830, 0.002712},{
      0.861702, 1.190644, 0.002712},{0.861603, 1.190338, 0.001373}}],
    Polygon[{{0.859375, 1.191830, 0.002712},{0.859685, 1.192256, 0.003984},{
      0.861865, 1.191145, 0.003984},{0.861702, 1.190644, 0.002712}}],
    Polygon[{{0.859685, 1.192256, 0.003984},{0.860108, 1.192838, 0.005159},{
      0.862087, 1.191830, 0.005159},{0.861865, 1.191145, 0.003984}}],
    Polygon[{{0.860108, 1.192838, 0.005159},{0.860634, 1.193562, 0.006206},{
      0.862364, 1.192680, 0.006206},{0.862087, 1.191830, 0.005159}}],
    Polygon[{{0.860634, 1.193562, 0.006206},{0.861249, 1.194409, 0.007100},{
      0.862687, 1.193676, 0.007100},{0.862364, 1.192680, 0.006206}}],
    Polygon[{{0.861249, 1.194409, 0.007100},{0.861939, 1.195359, 0.007820},{
      0.863050, 1.194793, 0.007820},{0.862687, 1.193676, 0.007100}}],
    Polygon[{{0.861939, 1.195359, 0.007820},{0.862687, 1.196388, 0.008347},{
      0.863443, 1.196003, 0.008347},{0.863050, 1.194793, 0.007820}}],
    Polygon[{{0.862687, 1.196388, 0.008347},{0.863474, 1.197472, 0.008668},{
      0.863857, 1.197277, 0.008668},{0.863443, 1.196003, 0.008347}}],
    Polygon[{{0.863857, 1.197277, -0.008668},{0.863443, 1.196003, -0.008347},{
      0.864281, 1.195870, -0.008347},{0.864281, 1.197209, -0.008668}}],
    Polygon[{{0.863443, 1.196003, -0.008347},{0.863050, 1.194793, -0.007820},{
      0.864281, 1.194598, -0.007820},{0.864281, 1.195870, -0.008347}}],
    Polygon[{{0.863050, 1.194793, -0.007820},{0.862687, 1.193676, -0.007100},{
      0.864281, 1.193424, -0.007100},{0.864281, 1.194598, -0.007820}}],
    Polygon[{{0.862687, 1.193676, -0.007100},{0.862364, 1.192680, -0.006206},{
      0.864281, 1.192377, -0.006206},{0.864281, 1.193424, -0.007100}}],
    Polygon[{{0.862364, 1.192680, -0.006206},{0.862087, 1.191830, -0.005159},{
      0.864281, 1.191482, -0.005159},{0.864281, 1.192377, -0.006206}}],
    Polygon[{{0.862087, 1.191830, -0.005159},{0.861865, 1.191145, -0.003984},{
      0.864281, 1.190763, -0.003984},{0.864281, 1.191482, -0.005159}}],
    Polygon[{{0.861865, 1.191145, -0.003984},{0.861702, 1.190644, -0.002712},{
      0.864281, 1.190236, -0.002712},{0.864281, 1.190763, -0.003984}}],
    Polygon[{{0.861702, 1.190644, -0.002712},{0.861603, 1.190338, -0.001373},{
      0.864281, 1.189914, -0.001373},{0.864281, 1.190236, -0.002712}}],
    Polygon[{{0.861603, 1.190338, -0.001373},{0.861569, 1.190236, 0.000000},{
      0.864281, 1.189806, 0.000000},{0.864281, 1.189914, -0.001373}}],
    Polygon[{{0.861569, 1.190236, 0.000000},{0.861603, 1.190338, 0.001373},{
      0.864281, 1.189914, 0.001373},{0.864281, 1.189806, 0.000000}}],
    Polygon[{{0.861603, 1.190338, 0.001373},{0.861702, 1.190644, 0.002712},{
      0.864281, 1.190236, 0.002712},{0.864281, 1.189914, 0.001373}}],
    Polygon[{{0.861702, 1.190644, 0.002712},{0.861865, 1.191145, 0.003984},{
      0.864281, 1.190763, 0.003984},{0.864281, 1.190236, 0.002712}}],
    Polygon[{{0.861865, 1.191145, 0.003984},{0.862087, 1.191830, 0.005159},{
      0.864281, 1.191482, 0.005159},{0.864281, 1.190763, 0.003984}}],
    Polygon[{{0.862087, 1.191830, 0.005159},{0.862364, 1.192680, 0.006206},{
      0.864281, 1.192377, 0.006206},{0.864281, 1.191482, 0.005159}}],
    Polygon[{{0.862364, 1.192680, 0.006206},{0.862687, 1.193676, 0.007100},{
      0.864281, 1.193424, 0.007100},{0.864281, 1.192377, 0.006206}}],
    Polygon[{{0.862687, 1.193676, 0.007100},{0.863050, 1.194793, 0.007820},{
      0.864281, 1.194598, 0.007820},{0.864281, 1.193424, 0.007100}}],
    Polygon[{{0.863050, 1.194793, 0.007820},{0.863443, 1.196003, 0.008347},{
      0.864281, 1.195870, 0.008347},{0.864281, 1.194598, 0.007820}}],
    Polygon[{{0.863443, 1.196003, 0.008347},{0.863857, 1.197277, 0.008668},{
      0.864281, 1.197209, 0.008668},{0.864281, 1.195870, 0.008347}}],
    Polygon[{{0.864281, 1.197209, -0.008668},{0.864281, 1.195870, -0.008347},{
      0.865119, 1.196003, -0.008347},{0.864706, 1.197277, -0.008668}}],
    Polygon[{{0.864281, 1.195870, -0.008347},{0.864281, 1.194598, -0.007820},{
      0.865513, 1.194793, -0.007820},{0.865119, 1.196003, -0.008347}}],
    Polygon[{{0.864281, 1.194598, -0.007820},{0.864281, 1.193424, -0.007100},{
      0.865875, 1.193676, -0.007100},{0.865513, 1.194793, -0.007820}}],
    Polygon[{{0.864281, 1.193424, -0.007100},{0.864281, 1.192377, -0.006206},{
      0.866199, 1.192680, -0.006206},{0.865875, 1.193676, -0.007100}}],
    Polygon[{{0.864281, 1.192377, -0.006206},{0.864281, 1.191482, -0.005159},{
      0.866475, 1.191830, -0.005159},{0.866199, 1.192680, -0.006206}}],
    Polygon[{{0.864281, 1.191482, -0.005159},{0.864281, 1.190763, -0.003984},{
      0.866698, 1.191145, -0.003984},{0.866475, 1.191830, -0.005159}}],
    Polygon[{{0.864281, 1.190763, -0.003984},{0.864281, 1.190236, -0.002712},{
      0.866861, 1.190644, -0.002712},{0.866698, 1.191145, -0.003984}}],
    Polygon[{{0.864281, 1.190236, -0.002712},{0.864281, 1.189914, -0.001373},{
      0.866960, 1.190338, -0.001373},{0.866861, 1.190644, -0.002712}}],
    Polygon[{{0.864281, 1.189914, -0.001373},{0.864281, 1.189806, 0.000000},{
      0.866993, 1.190236, 0.000000},{0.866960, 1.190338, -0.001373}}],
    Polygon[{{0.864281, 1.189806, 0.000000},{0.864281, 1.189914, 0.001373},{
      0.866960, 1.190338, 0.001373},{0.866993, 1.190236, 0.000000}}],
    Polygon[{{0.864281, 1.189914, 0.001373},{0.864281, 1.190236, 0.002712},{
      0.866861, 1.190644, 0.002712},{0.866960, 1.190338, 0.001373}}],
    Polygon[{{0.864281, 1.190236, 0.002712},{0.864281, 1.190763, 0.003984},{
      0.866698, 1.191145, 0.003984},{0.866861, 1.190644, 0.002712}}],
    Polygon[{{0.864281, 1.190763, 0.003984},{0.864281, 1.191482, 0.005159},{
      0.866475, 1.191830, 0.005159},{0.866698, 1.191145, 0.003984}}],
    Polygon[{{0.864281, 1.191482, 0.005159},{0.864281, 1.192377, 0.006206},{
      0.866199, 1.192680, 0.006206},{0.866475, 1.191830, 0.005159}}],
    Polygon[{{0.864281, 1.192377, 0.006206},{0.864281, 1.193424, 0.007100},{
      0.865875, 1.193676, 0.007100},{0.866199, 1.192680, 0.006206}}],
    Polygon[{{0.864281, 1.193424, 0.007100},{0.864281, 1.194598, 0.007820},{
      0.865513, 1.194793, 0.007820},{0.865875, 1.193676, 0.007100}}],
    Polygon[{{0.864281, 1.194598, 0.007820},{0.864281, 1.195870, 0.008347},{
      0.865119, 1.196003, 0.008347},{0.865513, 1.194793, 0.007820}}],
    Polygon[{{0.864281, 1.195870, 0.008347},{0.864281, 1.197209, 0.008668},{
      0.864706, 1.197277, 0.008668},{0.865119, 1.196003, 0.008347}}],
    Polygon[{{0.864706, 1.197277, -0.008668},{0.865119, 1.196003, -0.008347},{
      0.865875, 1.196388, -0.008347},{0.865088, 1.197472, -0.008668}}],
    Polygon[{{0.865119, 1.196003, -0.008347},{0.865513, 1.194793, -0.007820},{
      0.866623, 1.195359, -0.007820},{0.865875, 1.196388, -0.008347}}],
    Polygon[{{0.865513, 1.194793, -0.007820},{0.865875, 1.193676, -0.007100},{
      0.867313, 1.194409, -0.007100},{0.866623, 1.195359, -0.007820}}],
    Polygon[{{0.865875, 1.193676, -0.007100},{0.866199, 1.192680, -0.006206},{
      0.867929, 1.193562, -0.006206},{0.867313, 1.194409, -0.007100}}],
    Polygon[{{0.866199, 1.192680, -0.006206},{0.866475, 1.191830, -0.005159},{
      0.868455, 1.192838, -0.005159},{0.867929, 1.193562, -0.006206}}],
    Polygon[{{0.866475, 1.191830, -0.005159},{0.866698, 1.191145, -0.003984},{
      0.868878, 1.192256, -0.003984},{0.868455, 1.192838, -0.005159}}],
    Polygon[{{0.866698, 1.191145, -0.003984},{0.866861, 1.190644, -0.002712},{
      0.869187, 1.191830, -0.002712},{0.868878, 1.192256, -0.003984}}],
    Polygon[{{0.866861, 1.190644, -0.002712},{0.866960, 1.190338, -0.001373},{
      0.869376, 1.191570, -0.001373},{0.869187, 1.191830, -0.002712}}],
    Polygon[{{0.866960, 1.190338, -0.001373},{0.866993, 1.190236, 0.000000},{
      0.869440, 1.191482, 0.000000},{0.869376, 1.191570, -0.001373}}],
    Polygon[{{0.866993, 1.190236, 0.000000},{0.866960, 1.190338, 0.001373},{
      0.869376, 1.191570, 0.001373},{0.869440, 1.191482, 0.000000}}],
    Polygon[{{0.866960, 1.190338, 0.001373},{0.866861, 1.190644, 0.002712},{
      0.869187, 1.191830, 0.002712},{0.869376, 1.191570, 0.001373}}],
    Polygon[{{0.866861, 1.190644, 0.002712},{0.866698, 1.191145, 0.003984},{
      0.868878, 1.192256, 0.003984},{0.869187, 1.191830, 0.002712}}],
    Polygon[{{0.866698, 1.191145, 0.003984},{0.866475, 1.191830, 0.005159},{
      0.868455, 1.192838, 0.005159},{0.868878, 1.192256, 0.003984}}],
    Polygon[{{0.866475, 1.191830, 0.005159},{0.866199, 1.192680, 0.006206},{
      0.867929, 1.193562, 0.006206},{0.868455, 1.192838, 0.005159}}],
    Polygon[{{0.866199, 1.192680, 0.006206},{0.865875, 1.193676, 0.007100},{
      0.867313, 1.194409, 0.007100},{0.867929, 1.193562, 0.006206}}],
    Polygon[{{0.865875, 1.193676, 0.007100},{0.865513, 1.194793, 0.007820},{
      0.866623, 1.195359, 0.007820},{0.867313, 1.194409, 0.007100}}],
    Polygon[{{0.865513, 1.194793, 0.007820},{0.865119, 1.196003, 0.008347},{
      0.865875, 1.196388, 0.008347},{0.866623, 1.195359, 0.007820}}],
    Polygon[{{0.865119, 1.196003, 0.008347},{0.864706, 1.197277, 0.008668},{
      0.865088, 1.197472, 0.008668},{0.865875, 1.196388, 0.008347}}],
    Polygon[{{0.865088, 1.197472, -0.008668},{0.865875, 1.196388, -0.008347},{
      0.866475, 1.196988, -0.008347},{0.865392, 1.197775, -0.008668}}],
    Polygon[{{0.865875, 1.196388, -0.008347},{0.866623, 1.195359, -0.007820},{
      0.867505, 1.196240, -0.007820},{0.866475, 1.196988, -0.008347}}],
    Polygon[{{0.866623, 1.195359, -0.007820},{0.867313, 1.194409, -0.007100},{
      0.868455, 1.195550, -0.007100},{0.867505, 1.196240, -0.007820}}],
    Polygon[{{0.867313, 1.194409, -0.007100},{0.867929, 1.193562, -0.006206},{
      0.869302, 1.194935, -0.006206},{0.868455, 1.195550, -0.007100}}],
    Polygon[{{0.867929, 1.193562, -0.006206},{0.868455, 1.192838, -0.005159},{
      0.870026, 1.194409, -0.005159},{0.869302, 1.194935, -0.006206}}],
    Polygon[{{0.868455, 1.192838, -0.005159},{0.868878, 1.192256, -0.003984},{
      0.870608, 1.193986, -0.003984},{0.870026, 1.194409, -0.005159}}],
    Polygon[{{0.868878, 1.192256, -0.003984},{0.869187, 1.191830, -0.002712},{
      0.871034, 1.193676, -0.002712},{0.870608, 1.193986, -0.003984}}],
    Polygon[{{0.869187, 1.191830, -0.002712},{0.869376, 1.191570, -0.001373},{
      0.871294, 1.193487, -0.001373},{0.871034, 1.193676, -0.002712}}],
    Polygon[{{0.869376, 1.191570, -0.001373},{0.869440, 1.191482, 0.000000},{
      0.871382, 1.193424, 0.000000},{0.871294, 1.193487, -0.001373}}],
    Polygon[{{0.869440, 1.191482, 0.000000},{0.869376, 1.191570, 0.001373},{
      0.871294, 1.193487, 0.001373},{0.871382, 1.193424, 0.000000}}],
    Polygon[{{0.869376, 1.191570, 0.001373},{0.869187, 1.191830, 0.002712},{
      0.871034, 1.193676, 0.002712},{0.871294, 1.193487, 0.001373}}],
    Polygon[{{0.869187, 1.191830, 0.002712},{0.868878, 1.192256, 0.003984},{
      0.870608, 1.193986, 0.003984},{0.871034, 1.193676, 0.002712}}],
    Polygon[{{0.868878, 1.192256, 0.003984},{0.868455, 1.192838, 0.005159},{
      0.870026, 1.194409, 0.005159},{0.870608, 1.193986, 0.003984}}],
    Polygon[{{0.868455, 1.192838, 0.005159},{0.867929, 1.193562, 0.006206},{
      0.869302, 1.194935, 0.006206},{0.870026, 1.194409, 0.005159}}],
    Polygon[{{0.867929, 1.193562, 0.006206},{0.867313, 1.194409, 0.007100},{
      0.868455, 1.195550, 0.007100},{0.869302, 1.194935, 0.006206}}],
    Polygon[{{0.867313, 1.194409, 0.007100},{0.866623, 1.195359, 0.007820},{
      0.867505, 1.196240, 0.007820},{0.868455, 1.195550, 0.007100}}],
    Polygon[{{0.866623, 1.195359, 0.007820},{0.865875, 1.196388, 0.008347},{
      0.866475, 1.196988, 0.008347},{0.867505, 1.196240, 0.007820}}],
    Polygon[{{0.865875, 1.196388, 0.008347},{0.865088, 1.197472, 0.008668},{
      0.865392, 1.197775, 0.008668},{0.866475, 1.196988, 0.008347}}],
    Polygon[{{0.865392, 1.197775, -0.008668},{0.866475, 1.196988, -0.008347},{
      0.866861, 1.197744, -0.008347},{0.865587, 1.198158, -0.008668}}],
    Polygon[{{0.866475, 1.196988, -0.008347},{0.867505, 1.196240, -0.007820},{
      0.868071, 1.197351, -0.007820},{0.866861, 1.197744, -0.008347}}],
    Polygon[{{0.867505, 1.196240, -0.007820},{0.868455, 1.195550, -0.007100},{
      0.869187, 1.196988, -0.007100},{0.868071, 1.197351, -0.007820}}],
    Polygon[{{0.868455, 1.195550, -0.007100},{0.869302, 1.194935, -0.006206},{
      0.870183, 1.196665, -0.006206},{0.869187, 1.196988, -0.007100}}],
    Polygon[{{0.869302, 1.194935, -0.006206},{0.870026, 1.194409, -0.005159},{
      0.871034, 1.196388, -0.005159},{0.870183, 1.196665, -0.006206}}],
    Polygon[{{0.870026, 1.194409, -0.005159},{0.870608, 1.193986, -0.003984},{
      0.871718, 1.196166, -0.003984},{0.871034, 1.196388, -0.005159}}],
    Polygon[{{0.870608, 1.193986, -0.003984},{0.871034, 1.193676, -0.002712},{
      0.872220, 1.196003, -0.002712},{0.871718, 1.196166, -0.003984}}],
    Polygon[{{0.871034, 1.193676, -0.002712},{0.871294, 1.193487, -0.001373},{
      0.872525, 1.195904, -0.001373},{0.872220, 1.196003, -0.002712}}],
    Polygon[{{0.871294, 1.193487, -0.001373},{0.871382, 1.193424, 0.000000},{
      0.872628, 1.195870, 0.000000},{0.872525, 1.195904, -0.001373}}],
    Polygon[{{0.871382, 1.193424, 0.000000},{0.871294, 1.193487, 0.001373},{
      0.872525, 1.195904, 0.001373},{0.872628, 1.195870, 0.000000}}],
    Polygon[{{0.871294, 1.193487, 0.001373},{0.871034, 1.193676, 0.002712},{
      0.872220, 1.196003, 0.002712},{0.872525, 1.195904, 0.001373}}],
    Polygon[{{0.871034, 1.193676, 0.002712},{0.870608, 1.193986, 0.003984},{
      0.871718, 1.196166, 0.003984},{0.872220, 1.196003, 0.002712}}],
    Polygon[{{0.870608, 1.193986, 0.003984},{0.870026, 1.194409, 0.005159},{
      0.871034, 1.196388, 0.005159},{0.871718, 1.196166, 0.003984}}],
    Polygon[{{0.870026, 1.194409, 0.005159},{0.869302, 1.194935, 0.006206},{
      0.870183, 1.196665, 0.006206},{0.871034, 1.196388, 0.005159}}],
    Polygon[{{0.869302, 1.194935, 0.006206},{0.868455, 1.195550, 0.007100},{
      0.869187, 1.196988, 0.007100},{0.870183, 1.196665, 0.006206}}],
    Polygon[{{0.868455, 1.195550, 0.007100},{0.867505, 1.196240, 0.007820},{
      0.868071, 1.197351, 0.007820},{0.869187, 1.196988, 0.007100}}],
    Polygon[{{0.867505, 1.196240, 0.007820},{0.866475, 1.196988, 0.008347},{
      0.866861, 1.197744, 0.008347},{0.868071, 1.197351, 0.007820}}],
    Polygon[{{0.866475, 1.196988, 0.008347},{0.865392, 1.197775, 0.008668},{
      0.865587, 1.198158, 0.008668},{0.866861, 1.197744, 0.008347}}],
    Polygon[{{0.865587, 1.198158, -0.008668},{0.866861, 1.197744, -0.008347},{
      0.866993, 1.198582, -0.008347},{0.865654, 1.198582, -0.008668}}],
    Polygon[{{0.866861, 1.197744, -0.008347},{0.868071, 1.197351, -0.007820},{
      0.868266, 1.198582, -0.007820},{0.866993, 1.198582, -0.008347}}],
    Polygon[{{0.868071, 1.197351, -0.007820},{0.869187, 1.196988, -0.007100},{
      0.869440, 1.198582, -0.007100},{0.868266, 1.198582, -0.007820}}],
    Polygon[{{0.869187, 1.196988, -0.007100},{0.870183, 1.196665, -0.006206},{
      0.870487, 1.198582, -0.006206},{0.869440, 1.198582, -0.007100}}],
    Polygon[{{0.870183, 1.196665, -0.006206},{0.871034, 1.196388, -0.005159},{
      0.871382, 1.198582, -0.005159},{0.870487, 1.198582, -0.006206}}],
    Polygon[{{0.871034, 1.196388, -0.005159},{0.871718, 1.196166, -0.003984},{
      0.872101, 1.198582, -0.003984},{0.871382, 1.198582, -0.005159}}],
    Polygon[{{0.871718, 1.196166, -0.003984},{0.872220, 1.196003, -0.002712},{
      0.872628, 1.198582, -0.002712},{0.872101, 1.198582, -0.003984}}],
    Polygon[{{0.872220, 1.196003, -0.002712},{0.872525, 1.195904, -0.001373},{
      0.872950, 1.198582, -0.001373},{0.872628, 1.198582, -0.002712}}],
    Polygon[{{0.872525, 1.195904, -0.001373},{0.872628, 1.195870, 0.000000},{
      0.873058, 1.198582, 0.000000},{0.872950, 1.198582, -0.001373}}],
    Polygon[{{0.872628, 1.195870, 0.000000},{0.872525, 1.195904, 0.001373},{
      0.872950, 1.198582, 0.001373},{0.873058, 1.198582, 0.000000}}],
    Polygon[{{0.872525, 1.195904, 0.001373},{0.872220, 1.196003, 0.002712},{
      0.872628, 1.198582, 0.002712},{0.872950, 1.198582, 0.001373}}],
    Polygon[{{0.872220, 1.196003, 0.002712},{0.871718, 1.196166, 0.003984},{
      0.872101, 1.198582, 0.003984},{0.872628, 1.198582, 0.002712}}],
    Polygon[{{0.871718, 1.196166, 0.003984},{0.871034, 1.196388, 0.005159},{
      0.871382, 1.198582, 0.005159},{0.872101, 1.198582, 0.003984}}],
    Polygon[{{0.871034, 1.196388, 0.005159},{0.870183, 1.196665, 0.006206},{
      0.870487, 1.198582, 0.006206},{0.871382, 1.198582, 0.005159}}],
    Polygon[{{0.870183, 1.196665, 0.006206},{0.869187, 1.196988, 0.007100},{
      0.869440, 1.198582, 0.007100},{0.870487, 1.198582, 0.006206}}],
    Polygon[{{0.869187, 1.196988, 0.007100},{0.868071, 1.197351, 0.007820},{
      0.868266, 1.198582, 0.007820},{0.869440, 1.198582, 0.007100}}],
    Polygon[{{0.868071, 1.197351, 0.007820},{0.866861, 1.197744, 0.008347},{
      0.866993, 1.198582, 0.008347},{0.868266, 1.198582, 0.007820}}],
    Polygon[{{0.866861, 1.197744, 0.008347},{0.865587, 1.198158, 0.008668},{
      0.865654, 1.198582, 0.008668},{0.866993, 1.198582, 0.008347}}],
    Polygon[{{1.233788, 1.193376, -0.076398},{1.245590, 1.193376, -0.073564},{
      1.244421, 1.200762, -0.073564},{1.233196, 1.197115, -0.076398}}],
    Polygon[{{1.245590, 1.193376, -0.073564},{1.256804, 1.193376, -0.068920},{
      1.255085, 1.204227, -0.068920},{1.244421, 1.200762, -0.073564}}],
    Polygon[{{1.256804, 1.193376, -0.068920},{1.267153, 1.193376, -0.062578},{
      1.264928, 1.207425, -0.062578},{1.255085, 1.204227, -0.068920}}],
    Polygon[{{1.267153, 1.193376, -0.062578},{1.276383, 1.193376, -0.054695},{
      1.273706, 1.210277, -0.054695},{1.264928, 1.207425, -0.062578}}],
    Polygon[{{1.276383, 1.193376, -0.054695},{1.284266, 1.193376, -0.045465},{
      1.281203, 1.212713, -0.045465},{1.273706, 1.210277, -0.054695}}],
    Polygon[{{1.284266, 1.193376, -0.045465},{1.290607, 1.193376, -0.035116},{
      1.287234, 1.214673, -0.035116},{1.281203, 1.212713, -0.045465}}],
    Polygon[{{1.290607, 1.193376, -0.035116},{1.295252, 1.193376, -0.023903},{
      1.291652, 1.216108, -0.023903},{1.287234, 1.214673, -0.035116}}],
    Polygon[{{1.295252, 1.193376, -0.023903},{1.298086, 1.193376, -0.012100},{
      1.294347, 1.216984, -0.012100},{1.291652, 1.216108, -0.023903}}],
    Polygon[{{1.298086, 1.193376, -0.012100},{1.299038, 1.193376, 0.000000},{
      1.295252, 1.217278, 0.000000},{1.294347, 1.216984, -0.012100}}],
    Polygon[{{1.299038, 1.193376, 0.000000},{1.298086, 1.193376, 0.012100},{
      1.294347, 1.216984, 0.012100},{1.295252, 1.217278, 0.000000}}],
    Polygon[{{1.298086, 1.193376, 0.012100},{1.295252, 1.193376, 0.023903},{
      1.291652, 1.216108, 0.023903},{1.294347, 1.216984, 0.012100}}],
    Polygon[{{1.295252, 1.193376, 0.023903},{1.290607, 1.193376, 0.035116},{
      1.287234, 1.214673, 0.035116},{1.291652, 1.216108, 0.023903}}],
    Polygon[{{1.290607, 1.193376, 0.035116},{1.284266, 1.193376, 0.045465},{
      1.281203, 1.212713, 0.045465},{1.287234, 1.214673, 0.035116}}],
    Polygon[{{1.284266, 1.193376, 0.045465},{1.276383, 1.193376, 0.054695},{
      1.273706, 1.210277, 0.054695},{1.281203, 1.212713, 0.045465}}],
    Polygon[{{1.276383, 1.193376, 0.054695},{1.267153, 1.193376, 0.062578},{
      1.264928, 1.207425, 0.062578},{1.273706, 1.210277, 0.054695}}],
    Polygon[{{1.267153, 1.193376, 0.062578},{1.256804, 1.193376, 0.068920},{
      1.255085, 1.204227, 0.068920},{1.264928, 1.207425, 0.062578}}],
    Polygon[{{1.256804, 1.193376, 0.068920},{1.245590, 1.193376, 0.073564},{
      1.244421, 1.200762, 0.073564},{1.255085, 1.204227, 0.068920}}],
    Polygon[{{1.245590, 1.193376, 0.073564},{1.233788, 1.193376, 0.076398},{
      1.233196, 1.197115, 0.076398},{1.244421, 1.200762, 0.073564}}],
    Polygon[{{1.233196, 1.197115, -0.076398},{1.244421, 1.200762, -0.073564},{
      1.241025, 1.207425, -0.073564},{1.231477, 1.200488, -0.076398}}],
    Polygon[{{1.244421, 1.200762, -0.073564},{1.255085, 1.204227, -0.068920},{
      1.250098, 1.214017, -0.068920},{1.241025, 1.207425, -0.073564}}],
    Polygon[{{1.255085, 1.204227, -0.068920},{1.264928, 1.207425, -0.062578},{
      1.258470, 1.220100, -0.062578},{1.250098, 1.214017, -0.068920}}],
    Polygon[{{1.264928, 1.207425, -0.062578},{1.273706, 1.210277, -0.054695},{
      1.265937, 1.225525, -0.054695},{1.258470, 1.220100, -0.062578}}],
    Polygon[{{1.273706, 1.210277, -0.054695},{1.281203, 1.212713, -0.045465},{
      1.272314, 1.230158, -0.045465},{1.265937, 1.225525, -0.054695}}],
    Polygon[{{1.281203, 1.212713, -0.045465},{1.287234, 1.214673, -0.035116},{
      1.277445, 1.233886, -0.035116},{1.272314, 1.230158, -0.045465}}],
    Polygon[{{1.287234, 1.214673, -0.035116},{1.291652, 1.216108, -0.023903},{
      1.281203, 1.236616, -0.023903},{1.277445, 1.233886, -0.035116}}],
    Polygon[{{1.291652, 1.216108, -0.023903},{1.294347, 1.216984, -0.012100},{
      1.283495, 1.238281, -0.012100},{1.281203, 1.236616, -0.023903}}],
    Polygon[{{1.294347, 1.216984, -0.012100},{1.295252, 1.217278, 0.000000},{
      1.284266, 1.238841, 0.000000},{1.283495, 1.238281, -0.012100}}],
    Polygon[{{1.295252, 1.217278, 0.000000},{1.294347, 1.216984, 0.012100},{
      1.283495, 1.238281, 0.012100},{1.284266, 1.238841, 0.000000}}],
    Polygon[{{1.294347, 1.216984, 0.012100},{1.291652, 1.216108, 0.023903},{
      1.281203, 1.236616, 0.023903},{1.283495, 1.238281, 0.012100}}],
    Polygon[{{1.291652, 1.216108, 0.023903},{1.287234, 1.214673, 0.035116},{
      1.277445, 1.233886, 0.035116},{1.281203, 1.236616, 0.023903}}],
    Polygon[{{1.287234, 1.214673, 0.035116},{1.281203, 1.212713, 0.045465},{
      1.272314, 1.230158, 0.045465},{1.277445, 1.233886, 0.035116}}],
    Polygon[{{1.281203, 1.212713, 0.045465},{1.273706, 1.210277, 0.054695},{
      1.265937, 1.225525, 0.054695},{1.272314, 1.230158, 0.045465}}],
    Polygon[{{1.273706, 1.210277, 0.054695},{1.264928, 1.207425, 0.062578},{
      1.258470, 1.220100, 0.062578},{1.265937, 1.225525, 0.054695}}],
    Polygon[{{1.264928, 1.207425, 0.062578},{1.255085, 1.204227, 0.068920},{
      1.250098, 1.214017, 0.068920},{1.258470, 1.220100, 0.062578}}],
    Polygon[{{1.255085, 1.204227, 0.068920},{1.244421, 1.200762, 0.073564},{
      1.241025, 1.207425, 0.073564},{1.250098, 1.214017, 0.068920}}],
    Polygon[{{1.244421, 1.200762, 0.073564},{1.233196, 1.197115, 0.076398},{
      1.231477, 1.200488, 0.076398},{1.241025, 1.207425, 0.073564}}],
    Polygon[{{1.231477, 1.200488, -0.076398},{1.241025, 1.207425, -0.073564},{
      1.235737, 1.212713, -0.073564},{1.228800, 1.203165, -0.076398}}],
    Polygon[{{1.241025, 1.207425, -0.073564},{1.250098, 1.214017, -0.068920},{
      1.242329, 1.221785, -0.068920},{1.235737, 1.212713, -0.073564}}],
    Polygon[{{1.250098, 1.214017, -0.068920},{1.258470, 1.220100, -0.062578},{
      1.248412, 1.230158, -0.062578},{1.242329, 1.221785, -0.068920}}],
    Polygon[{{1.258470, 1.220100, -0.062578},{1.265937, 1.225525, -0.054695},{
      1.253837, 1.237625, -0.054695},{1.248412, 1.230158, -0.062578}}],
    Polygon[{{1.265937, 1.225525, -0.054695},{1.272314, 1.230158, -0.045465},{
      1.258470, 1.244002, -0.045465},{1.253837, 1.237625, -0.054695}}],
    Polygon[{{1.272314, 1.230158, -0.045465},{1.277445, 1.233886, -0.035116},{
      1.262198, 1.249133, -0.035116},{1.258470, 1.244002, -0.045465}}],
    Polygon[{{1.277445, 1.233886, -0.035116},{1.281203, 1.236616, -0.023903},{
      1.264928, 1.252891, -0.023903},{1.262198, 1.249133, -0.035116}}],
    Polygon[{{1.281203, 1.236616, -0.023903},{1.283495, 1.238281, -0.012100},{
      1.266593, 1.255183, -0.012100},{1.264928, 1.252891, -0.023903}}],
    Polygon[{{1.283495, 1.238281, -0.012100},{1.284266, 1.238841, 0.000000},{
      1.267153, 1.255953, 0.000000},{1.266593, 1.255183, -0.012100}}],
    Polygon[{{1.284266, 1.238841, 0.000000},{1.283495, 1.238281, 0.012100},{
      1.266593, 1.255183, 0.012100},{1.267153, 1.255953, 0.000000}}],
    Polygon[{{1.283495, 1.238281, 0.012100},{1.281203, 1.236616, 0.023903},{
      1.264928, 1.252891, 0.023903},{1.266593, 1.255183, 0.012100}}],
    Polygon[{{1.281203, 1.236616, 0.023903},{1.277445, 1.233886, 0.035116},{
      1.262198, 1.249133, 0.035116},{1.264928, 1.252891, 0.023903}}],
    Polygon[{{1.277445, 1.233886, 0.035116},{1.272314, 1.230158, 0.045465},{
      1.258470, 1.244002, 0.045465},{1.262198, 1.249133, 0.035116}}],
    Polygon[{{1.272314, 1.230158, 0.045465},{1.265937, 1.225525, 0.054695},{
      1.253837, 1.237625, 0.054695},{1.258470, 1.244002, 0.045465}}],
    Polygon[{{1.265937, 1.225525, 0.054695},{1.258470, 1.220100, 0.062578},{
      1.248412, 1.230158, 0.062578},{1.253837, 1.237625, 0.054695}}],
    Polygon[{{1.258470, 1.220100, 0.062578},{1.250098, 1.214017, 0.068920},{
      1.242329, 1.221785, 0.068920},{1.248412, 1.230158, 0.062578}}],
    Polygon[{{1.250098, 1.214017, 0.068920},{1.241025, 1.207425, 0.073564},{
      1.235737, 1.212713, 0.073564},{1.242329, 1.221785, 0.068920}}],
    Polygon[{{1.241025, 1.207425, 0.073564},{1.231477, 1.200488, 0.076398},{
      1.228800, 1.203165, 0.076398},{1.235737, 1.212713, 0.073564}}],
    Polygon[{{1.228800, 1.203165, -0.076398},{1.235737, 1.212713, -0.073564},{
      1.229074, 1.216108, -0.073564},{1.225427, 1.204884, -0.076398}}],
    Polygon[{{1.235737, 1.212713, -0.073564},{1.242329, 1.221785, -0.068920},{
      1.232539, 1.226773, -0.068920},{1.229074, 1.216108, -0.073564}}],
    Polygon[{{1.242329, 1.221785, -0.068920},{1.248412, 1.230158, -0.062578},{
      1.235737, 1.236616, -0.062578},{1.232539, 1.226773, -0.068920}}],
    Polygon[{{1.248412, 1.230158, -0.062578},{1.253837, 1.237625, -0.054695},{
      1.238590, 1.245394, -0.054695},{1.235737, 1.236616, -0.062578}}],
    Polygon[{{1.253837, 1.237625, -0.054695},{1.258470, 1.244002, -0.045465},{
      1.241025, 1.252891, -0.045465},{1.238590, 1.245394, -0.054695}}],
    Polygon[{{1.258470, 1.244002, -0.045465},{1.262198, 1.249133, -0.035116},{
      1.242985, 1.258922, -0.035116},{1.241025, 1.252891, -0.045465}}],
    Polygon[{{1.262198, 1.249133, -0.035116},{1.264928, 1.252891, -0.023903},{
      1.244421, 1.263340, -0.023903},{1.242985, 1.258922, -0.035116}}],
    Polygon[{{1.264928, 1.252891, -0.023903},{1.266593, 1.255183, -0.012100},{
      1.245296, 1.266034, -0.012100},{1.244421, 1.263340, -0.023903}}],
    Polygon[{{1.266593, 1.255183, -0.012100},{1.267153, 1.255953, 0.000000},{
      1.245590, 1.266940, 0.000000},{1.245296, 1.266034, -0.012100}}],
    Polygon[{{1.267153, 1.255953, 0.000000},{1.266593, 1.255183, 0.012100},{
      1.245296, 1.266034, 0.012100},{1.245590, 1.266940, 0.000000}}],
    Polygon[{{1.266593, 1.255183, 0.012100},{1.264928, 1.252891, 0.023903},{
      1.244421, 1.263340, 0.023903},{1.245296, 1.266034, 0.012100}}],
    Polygon[{{1.264928, 1.252891, 0.023903},{1.262198, 1.249133, 0.035116},{
      1.242985, 1.258922, 0.035116},{1.244421, 1.263340, 0.023903}}],
    Polygon[{{1.262198, 1.249133, 0.035116},{1.258470, 1.244002, 0.045465},{
      1.241025, 1.252891, 0.045465},{1.242985, 1.258922, 0.035116}}],
    Polygon[{{1.258470, 1.244002, 0.045465},{1.253837, 1.237625, 0.054695},{
      1.238590, 1.245394, 0.054695},{1.241025, 1.252891, 0.045465}}],
    Polygon[{{1.253837, 1.237625, 0.054695},{1.248412, 1.230158, 0.062578},{
      1.235737, 1.236616, 0.062578},{1.238590, 1.245394, 0.054695}}],
    Polygon[{{1.248412, 1.230158, 0.062578},{1.242329, 1.221785, 0.068920},{
      1.232539, 1.226773, 0.068920},{1.235737, 1.236616, 0.062578}}],
    Polygon[{{1.242329, 1.221785, 0.068920},{1.235737, 1.212713, 0.073564},{
      1.229074, 1.216108, 0.073564},{1.232539, 1.226773, 0.068920}}],
    Polygon[{{1.235737, 1.212713, 0.073564},{1.228800, 1.203165, 0.076398},{
      1.225427, 1.204884, 0.076398},{1.229074, 1.216108, 0.073564}}],
    Polygon[{{1.225427, 1.204884, -0.076398},{1.229074, 1.216108, -0.073564},{
      1.221688, 1.217278, -0.073564},{1.221688, 1.205476, -0.076398}}],
    Polygon[{{1.229074, 1.216108, -0.073564},{1.232539, 1.226773, -0.068920},{
      1.221688, 1.228492, -0.068920},{1.221688, 1.217278, -0.073564}}],
    Polygon[{{1.232539, 1.226773, -0.068920},{1.235737, 1.236616, -0.062578},{
      1.221688, 1.238841, -0.062578},{1.221688, 1.228492, -0.068920}}],
    Polygon[{{1.235737, 1.236616, -0.062578},{1.238590, 1.245394, -0.054695},{
      1.221688, 1.248071, -0.054695},{1.221688, 1.238841, -0.062578}}],
    Polygon[{{1.238590, 1.245394, -0.054695},{1.241025, 1.252891, -0.045465},{
      1.221688, 1.255953, -0.045465},{1.221688, 1.248071, -0.054695}}],
    Polygon[{{1.241025, 1.252891, -0.045465},{1.242985, 1.258922, -0.035116},{
      1.221688, 1.262295, -0.035116},{1.221688, 1.255953, -0.045465}}],
    Polygon[{{1.242985, 1.258922, -0.035116},{1.244421, 1.263340, -0.023903},{
      1.221688, 1.266940, -0.023903},{1.221688, 1.262295, -0.035116}}],
    Polygon[{{1.244421, 1.263340, -0.023903},{1.245296, 1.266034, -0.012100},{
      1.221688, 1.269774, -0.012100},{1.221688, 1.266940, -0.023903}}],
    Polygon[{{1.245296, 1.266034, -0.012100},{1.245590, 1.266940, 0.000000},{
      1.221688, 1.270726, 0.000000},{1.221688, 1.269774, -0.012100}}],
    Polygon[{{1.245590, 1.266940, 0.000000},{1.245296, 1.266034, 0.012100},{
      1.221688, 1.269774, 0.012100},{1.221688, 1.270726, 0.000000}}],
    Polygon[{{1.245296, 1.266034, 0.012100},{1.244421, 1.263340, 0.023903},{
      1.221688, 1.266940, 0.023903},{1.221688, 1.269774, 0.012100}}],
    Polygon[{{1.244421, 1.263340, 0.023903},{1.242985, 1.258922, 0.035116},{
      1.221688, 1.262295, 0.035116},{1.221688, 1.266940, 0.023903}}],
    Polygon[{{1.242985, 1.258922, 0.035116},{1.241025, 1.252891, 0.045465},{
      1.221688, 1.255953, 0.045465},{1.221688, 1.262295, 0.035116}}],
    Polygon[{{1.241025, 1.252891, 0.045465},{1.238590, 1.245394, 0.054695},{
      1.221688, 1.248071, 0.054695},{1.221688, 1.255953, 0.045465}}],
    Polygon[{{1.238590, 1.245394, 0.054695},{1.235737, 1.236616, 0.062578},{
      1.221688, 1.238841, 0.062578},{1.221688, 1.248071, 0.054695}}],
    Polygon[{{1.235737, 1.236616, 0.062578},{1.232539, 1.226773, 0.068920},{
      1.221688, 1.228492, 0.068920},{1.221688, 1.238841, 0.062578}}],
    Polygon[{{1.232539, 1.226773, 0.068920},{1.229074, 1.216108, 0.073564},{
      1.221688, 1.217278, 0.073564},{1.221688, 1.228492, 0.068920}}],
    Polygon[{{1.229074, 1.216108, 0.073564},{1.225427, 1.204884, 0.076398},{
      1.221688, 1.205476, 0.076398},{1.221688, 1.217278, 0.073564}}],
    Polygon[{{1.221688, 1.205476, -0.076398},{1.221688, 1.217278, -0.073564},{
      1.214302, 1.216108, -0.073564},{1.217949, 1.204884, -0.076398}}],
    Polygon[{{1.221688, 1.217278, -0.073564},{1.221688, 1.228492, -0.068920},{
      1.210836, 1.226773, -0.068920},{1.214302, 1.216108, -0.073564}}],
    Polygon[{{1.221688, 1.228492, -0.068920},{1.221688, 1.238841, -0.062578},{
      1.207638, 1.236616, -0.062578},{1.210836, 1.226773, -0.068920}}],
    Polygon[{{1.221688, 1.238841, -0.062578},{1.221688, 1.248071, -0.054695},{
      1.204786, 1.245394, -0.054695},{1.207638, 1.236616, -0.062578}}],
    Polygon[{{1.221688, 1.248071, -0.054695},{1.221688, 1.255953, -0.045465},{
      1.202350, 1.252891, -0.045465},{1.204786, 1.245394, -0.054695}}],
    Polygon[{{1.221688, 1.255953, -0.045465},{1.221688, 1.262295, -0.035116},{
      1.200390, 1.258922, -0.035116},{1.202350, 1.252891, -0.045465}}],
    Polygon[{{1.221688, 1.262295, -0.035116},{1.221688, 1.266940, -0.023903},{
      1.198955, 1.263340, -0.023903},{1.200390, 1.258922, -0.035116}}],
    Polygon[{{1.221688, 1.266940, -0.023903},{1.221688, 1.269774, -0.012100},{
      1.198080, 1.266034, -0.012100},{1.198955, 1.263340, -0.023903}}],
    Polygon[{{1.221688, 1.269774, -0.012100},{1.221688, 1.270726, 0.000000},{
      1.197785, 1.266940, 0.000000},{1.198080, 1.266034, -0.012100}}],
    Polygon[{{1.221688, 1.270726, 0.000000},{1.221688, 1.269774, 0.012100},{
      1.198080, 1.266034, 0.012100},{1.197785, 1.266940, 0.000000}}],
    Polygon[{{1.221688, 1.269774, 0.012100},{1.221688, 1.266940, 0.023903},{
      1.198955, 1.263340, 0.023903},{1.198080, 1.266034, 0.012100}}],
    Polygon[{{1.221688, 1.266940, 0.023903},{1.221688, 1.262295, 0.035116},{
      1.200390, 1.258922, 0.035116},{1.198955, 1.263340, 0.023903}}],
    Polygon[{{1.221688, 1.262295, 0.035116},{1.221688, 1.255953, 0.045465},{
      1.202350, 1.252891, 0.045465},{1.200390, 1.258922, 0.035116}}],
    Polygon[{{1.221688, 1.255953, 0.045465},{1.221688, 1.248071, 0.054695},{
      1.204786, 1.245394, 0.054695},{1.202350, 1.252891, 0.045465}}],
    Polygon[{{1.221688, 1.248071, 0.054695},{1.221688, 1.238841, 0.062578},{
      1.207638, 1.236616, 0.062578},{1.204786, 1.245394, 0.054695}}],
    Polygon[{{1.221688, 1.238841, 0.062578},{1.221688, 1.228492, 0.068920},{
      1.210836, 1.226773, 0.068920},{1.207638, 1.236616, 0.062578}}],
    Polygon[{{1.221688, 1.228492, 0.068920},{1.221688, 1.217278, 0.073564},{
      1.214302, 1.216108, 0.073564},{1.210836, 1.226773, 0.068920}}],
    Polygon[{{1.221688, 1.217278, 0.073564},{1.221688, 1.205476, 0.076398},{
      1.217949, 1.204884, 0.076398},{1.214302, 1.216108, 0.073564}}],
    Polygon[{{1.217949, 1.204884, -0.076398},{1.214302, 1.216108, -0.073564},{
      1.207638, 1.212713, -0.073564},{1.214576, 1.203165, -0.076398}}],
    Polygon[{{1.214302, 1.216108, -0.073564},{1.210836, 1.226773, -0.068920},{
      1.201047, 1.221785, -0.068920},{1.207638, 1.212713, -0.073564}}],
    Polygon[{{1.210836, 1.226773, -0.068920},{1.207638, 1.236616, -0.062578},{
      1.194964, 1.230158, -0.062578},{1.201047, 1.221785, -0.068920}}],
    Polygon[{{1.207638, 1.236616, -0.062578},{1.204786, 1.245394, -0.054695},{
      1.189539, 1.237625, -0.054695},{1.194964, 1.230158, -0.062578}}],
    Polygon[{{1.204786, 1.245394, -0.054695},{1.202350, 1.252891, -0.045465},{
      1.184906, 1.244002, -0.045465},{1.189539, 1.237625, -0.054695}}],
    Polygon[{{1.202350, 1.252891, -0.045465},{1.200390, 1.258922, -0.035116},{
      1.181178, 1.249133, -0.035116},{1.184906, 1.244002, -0.045465}}],
    Polygon[{{1.200390, 1.258922, -0.035116},{1.198955, 1.263340, -0.023903},{
      1.178448, 1.252891, -0.023903},{1.181178, 1.249133, -0.035116}}],
    Polygon[{{1.198955, 1.263340, -0.023903},{1.198080, 1.266034, -0.012100},{
      1.176782, 1.255183, -0.012100},{1.178448, 1.252891, -0.023903}}],
    Polygon[{{1.198080, 1.266034, -0.012100},{1.197785, 1.266940, 0.000000},{
      1.176222, 1.255953, 0.000000},{1.176782, 1.255183, -0.012100}}],
    Polygon[{{1.197785, 1.266940, 0.000000},{1.198080, 1.266034, 0.012100},{
      1.176782, 1.255183, 0.012100},{1.176222, 1.255953, 0.000000}}],
    Polygon[{{1.198080, 1.266034, 0.012100},{1.198955, 1.263340, 0.023903},{
      1.178448, 1.252891, 0.023903},{1.176782, 1.255183, 0.012100}}],
    Polygon[{{1.198955, 1.263340, 0.023903},{1.200390, 1.258922, 0.035116},{
      1.181178, 1.249133, 0.035116},{1.178448, 1.252891, 0.023903}}],
    Polygon[{{1.200390, 1.258922, 0.035116},{1.202350, 1.252891, 0.045465},{
      1.184906, 1.244002, 0.045465},{1.181178, 1.249133, 0.035116}}],
    Polygon[{{1.202350, 1.252891, 0.045465},{1.204786, 1.245394, 0.054695},{
      1.189539, 1.237625, 0.054695},{1.184906, 1.244002, 0.045465}}],
    Polygon[{{1.204786, 1.245394, 0.054695},{1.207638, 1.236616, 0.062578},{
      1.194964, 1.230158, 0.062578},{1.189539, 1.237625, 0.054695}}],
    Polygon[{{1.207638, 1.236616, 0.062578},{1.210836, 1.226773, 0.068920},{
      1.201047, 1.221785, 0.068920},{1.194964, 1.230158, 0.062578}}],
    Polygon[{{1.210836, 1.226773, 0.068920},{1.214302, 1.216108, 0.073564},{
      1.207638, 1.212713, 0.073564},{1.201047, 1.221785, 0.068920}}],
    Polygon[{{1.214302, 1.216108, 0.073564},{1.217949, 1.204884, 0.076398},{
      1.214576, 1.203165, 0.076398},{1.207638, 1.212713, 0.073564}}],
    Polygon[{{1.214576, 1.203165, -0.076398},{1.207638, 1.212713, -0.073564},{
      1.202350, 1.207425, -0.073564},{1.211899, 1.200488, -0.076398}}],
    Polygon[{{1.207638, 1.212713, -0.073564},{1.201047, 1.221785, -0.068920},{
      1.193278, 1.214017, -0.068920},{1.202350, 1.207425, -0.073564}}],
    Polygon[{{1.201047, 1.221785, -0.068920},{1.194964, 1.230158, -0.062578},{
      1.184906, 1.220100, -0.062578},{1.193278, 1.214017, -0.068920}}],
    Polygon[{{1.194964, 1.230158, -0.062578},{1.189539, 1.237625, -0.054695},{
      1.177439, 1.225525, -0.054695},{1.184906, 1.220100, -0.062578}}],
    Polygon[{{1.189539, 1.237625, -0.054695},{1.184906, 1.244002, -0.045465},{
      1.171061, 1.230158, -0.045465},{1.177439, 1.225525, -0.054695}}],
    Polygon[{{1.184906, 1.244002, -0.045465},{1.181178, 1.249133, -0.035116},{
      1.165931, 1.233886, -0.035116},{1.171061, 1.230158, -0.045465}}],
    Polygon[{{1.181178, 1.249133, -0.035116},{1.178448, 1.252891, -0.023903},{
      1.162173, 1.236616, -0.023903},{1.165931, 1.233886, -0.035116}}],
    Polygon[{{1.178448, 1.252891, -0.023903},{1.176782, 1.255183, -0.012100},{
      1.159881, 1.238281, -0.012100},{1.162173, 1.236616, -0.023903}}],
    Polygon[{{1.176782, 1.255183, -0.012100},{1.176222, 1.255953, 0.000000},{
      1.159110, 1.238841, 0.000000},{1.159881, 1.238281, -0.012100}}],
    Polygon[{{1.176222, 1.255953, 0.000000},{1.176782, 1.255183, 0.012100},{
      1.159881, 1.238281, 0.012100},{1.159110, 1.238841, 0.000000}}],
    Polygon[{{1.176782, 1.255183, 0.012100},{1.178448, 1.252891, 0.023903},{
      1.162173, 1.236616, 0.023903},{1.159881, 1.238281, 0.012100}}],
    Polygon[{{1.178448, 1.252891, 0.023903},{1.181178, 1.249133, 0.035116},{
      1.165931, 1.233886, 0.035116},{1.162173, 1.236616, 0.023903}}],
    Polygon[{{1.181178, 1.249133, 0.035116},{1.184906, 1.244002, 0.045465},{
      1.171061, 1.230158, 0.045465},{1.165931, 1.233886, 0.035116}}],
    Polygon[{{1.184906, 1.244002, 0.045465},{1.189539, 1.237625, 0.054695},{
      1.177439, 1.225525, 0.054695},{1.171061, 1.230158, 0.045465}}],
    Polygon[{{1.189539, 1.237625, 0.054695},{1.194964, 1.230158, 0.062578},{
      1.184906, 1.220100, 0.062578},{1.177439, 1.225525, 0.054695}}],
    Polygon[{{1.194964, 1.230158, 0.062578},{1.201047, 1.221785, 0.068920},{
      1.193278, 1.214017, 0.068920},{1.184906, 1.220100, 0.062578}}],
    Polygon[{{1.201047, 1.221785, 0.068920},{1.207638, 1.212713, 0.073564},{
      1.202350, 1.207425, 0.073564},{1.193278, 1.214017, 0.068920}}],
    Polygon[{{1.207638, 1.212713, 0.073564},{1.214576, 1.203165, 0.076398},{
      1.211899, 1.200488, 0.076398},{1.202350, 1.207425, 0.073564}}],
    Polygon[{{1.211899, 1.200488, -0.076398},{1.202350, 1.207425, -0.073564},{
      1.198955, 1.200762, -0.073564},{1.210180, 1.197115, -0.076398}}],
    Polygon[{{1.202350, 1.207425, -0.073564},{1.193278, 1.214017, -0.068920},{
      1.188290, 1.204227, -0.068920},{1.198955, 1.200762, -0.073564}}],
    Polygon[{{1.193278, 1.214017, -0.068920},{1.184906, 1.220100, -0.062578},{
      1.178448, 1.207425, -0.062578},{1.188290, 1.204227, -0.068920}}],
    Polygon[{{1.184906, 1.220100, -0.062578},{1.177439, 1.225525, -0.054695},{
      1.169670, 1.210277, -0.054695},{1.178448, 1.207425, -0.062578}}],
    Polygon[{{1.177439, 1.225525, -0.054695},{1.171061, 1.230158, -0.045465},{
      1.162173, 1.212713, -0.045465},{1.169670, 1.210277, -0.054695}}],
    Polygon[{{1.171061, 1.230158, -0.045465},{1.165931, 1.233886, -0.035116},{
      1.156141, 1.214673, -0.035116},{1.162173, 1.212713, -0.045465}}],
    Polygon[{{1.165931, 1.233886, -0.035116},{1.162173, 1.236616, -0.023903},{
      1.151724, 1.216108, -0.023903},{1.156141, 1.214673, -0.035116}}],
    Polygon[{{1.162173, 1.236616, -0.023903},{1.159881, 1.238281, -0.012100},{
      1.149029, 1.216984, -0.012100},{1.151724, 1.216108, -0.023903}}],
    Polygon[{{1.159881, 1.238281, -0.012100},{1.159110, 1.238841, 0.000000},{
      1.148123, 1.217278, 0.000000},{1.149029, 1.216984, -0.012100}}],
    Polygon[{{1.159110, 1.238841, 0.000000},{1.159881, 1.238281, 0.012100},{
      1.149029, 1.216984, 0.012100},{1.148123, 1.217278, 0.000000}}],
    Polygon[{{1.159881, 1.238281, 0.012100},{1.162173, 1.236616, 0.023903},{
      1.151724, 1.216108, 0.023903},{1.149029, 1.216984, 0.012100}}],
    Polygon[{{1.162173, 1.236616, 0.023903},{1.165931, 1.233886, 0.035116},{
      1.156141, 1.214673, 0.035116},{1.151724, 1.216108, 0.023903}}],
    Polygon[{{1.165931, 1.233886, 0.035116},{1.171061, 1.230158, 0.045465},{
      1.162173, 1.212713, 0.045465},{1.156141, 1.214673, 0.035116}}],
    Polygon[{{1.171061, 1.230158, 0.045465},{1.177439, 1.225525, 0.054695},{
      1.169670, 1.210277, 0.054695},{1.162173, 1.212713, 0.045465}}],
    Polygon[{{1.177439, 1.225525, 0.054695},{1.184906, 1.220100, 0.062578},{
      1.178448, 1.207425, 0.062578},{1.169670, 1.210277, 0.054695}}],
    Polygon[{{1.184906, 1.220100, 0.062578},{1.193278, 1.214017, 0.068920},{
      1.188290, 1.204227, 0.068920},{1.178448, 1.207425, 0.062578}}],
    Polygon[{{1.193278, 1.214017, 0.068920},{1.202350, 1.207425, 0.073564},{
      1.198955, 1.200762, 0.073564},{1.188290, 1.204227, 0.068920}}],
    Polygon[{{1.202350, 1.207425, 0.073564},{1.211899, 1.200488, 0.076398},{
      1.210180, 1.197115, 0.076398},{1.198955, 1.200762, 0.073564}}],
    Polygon[{{1.210180, 1.197115, -0.076398},{1.198955, 1.200762, -0.073564},{
      1.197785, 1.193376, -0.073564},{1.209588, 1.193376, -0.076398}}],
    Polygon[{{1.198955, 1.200762, -0.073564},{1.188290, 1.204227, -0.068920},{
      1.186572, 1.193376, -0.068920},{1.197785, 1.193376, -0.073564}}],
    Polygon[{{1.188290, 1.204227, -0.068920},{1.178448, 1.207425, -0.062578},{
      1.176222, 1.193376, -0.062578},{1.186572, 1.193376, -0.068920}}],
    Polygon[{{1.178448, 1.207425, -0.062578},{1.169670, 1.210277, -0.054695},{
      1.166993, 1.193376, -0.054695},{1.176222, 1.193376, -0.062578}}],
    Polygon[{{1.169670, 1.210277, -0.054695},{1.162173, 1.212713, -0.045465},{
      1.159110, 1.193376, -0.045465},{1.166993, 1.193376, -0.054695}}],
    Polygon[{{1.162173, 1.212713, -0.045465},{1.156141, 1.214673, -0.035116},{
      1.152768, 1.193376, -0.035116},{1.159110, 1.193376, -0.045465}}],
    Polygon[{{1.156141, 1.214673, -0.035116},{1.151724, 1.216108, -0.023903},{
      1.148123, 1.193376, -0.023903},{1.152768, 1.193376, -0.035116}}],
    Polygon[{{1.151724, 1.216108, -0.023903},{1.149029, 1.216984, -0.012100},{
      1.145290, 1.193376, -0.012100},{1.148123, 1.193376, -0.023903}}],
    Polygon[{{1.149029, 1.216984, -0.012100},{1.148123, 1.217278, 0.000000},{
      1.144338, 1.193376, 0.000000},{1.145290, 1.193376, -0.012100}}],
    Polygon[{{1.148123, 1.217278, 0.000000},{1.149029, 1.216984, 0.012100},{
      1.145290, 1.193376, 0.012100},{1.144338, 1.193376, 0.000000}}],
    Polygon[{{1.149029, 1.216984, 0.012100},{1.151724, 1.216108, 0.023903},{
      1.148123, 1.193376, 0.023903},{1.145290, 1.193376, 0.012100}}],
    Polygon[{{1.151724, 1.216108, 0.023903},{1.156141, 1.214673, 0.035116},{
      1.152768, 1.193376, 0.035116},{1.148123, 1.193376, 0.023903}}],
    Polygon[{{1.156141, 1.214673, 0.035116},{1.162173, 1.212713, 0.045465},{
      1.159110, 1.193376, 0.045465},{1.152768, 1.193376, 0.035116}}],
    Polygon[{{1.162173, 1.212713, 0.045465},{1.169670, 1.210277, 0.054695},{
      1.166993, 1.193376, 0.054695},{1.159110, 1.193376, 0.045465}}],
    Polygon[{{1.169670, 1.210277, 0.054695},{1.178448, 1.207425, 0.062578},{
      1.176222, 1.193376, 0.062578},{1.166993, 1.193376, 0.054695}}],
    Polygon[{{1.178448, 1.207425, 0.062578},{1.188290, 1.204227, 0.068920},{
      1.186572, 1.193376, 0.068920},{1.176222, 1.193376, 0.062578}}],
    Polygon[{{1.188290, 1.204227, 0.068920},{1.198955, 1.200762, 0.073564},{
      1.197785, 1.193376, 0.073564},{1.186572, 1.193376, 0.068920}}],
    Polygon[{{1.198955, 1.200762, 0.073564},{1.210180, 1.197115, 0.076398},{
      1.209588, 1.193376, 0.076398},{1.197785, 1.193376, 0.073564}}],
    Polygon[{{1.209588, 1.193376, -0.076398},{1.197785, 1.193376, -0.073564},{
      1.198955, 1.185989, -0.073564},{1.210180, 1.189636, -0.076398}}],
    Polygon[{{1.197785, 1.193376, -0.073564},{1.186572, 1.193376, -0.068920},{
      1.188290, 1.182524, -0.068920},{1.198955, 1.185989, -0.073564}}],
    Polygon[{{1.186572, 1.193376, -0.068920},{1.176222, 1.193376, -0.062578},{
      1.178448, 1.179326, -0.062578},{1.188290, 1.182524, -0.068920}}],
    Polygon[{{1.176222, 1.193376, -0.062578},{1.166993, 1.193376, -0.054695},{
      1.169670, 1.176474, -0.054695},{1.178448, 1.179326, -0.062578}}],
    Polygon[{{1.166993, 1.193376, -0.054695},{1.159110, 1.193376, -0.045465},{
      1.162173, 1.174038, -0.045465},{1.169670, 1.176474, -0.054695}}],
    Polygon[{{1.159110, 1.193376, -0.045465},{1.152768, 1.193376, -0.035116},{
      1.156141, 1.172078, -0.035116},{1.162173, 1.174038, -0.045465}}],
    Polygon[{{1.152768, 1.193376, -0.035116},{1.148123, 1.193376, -0.023903},{
      1.151724, 1.170643, -0.023903},{1.156141, 1.172078, -0.035116}}],
    Polygon[{{1.148123, 1.193376, -0.023903},{1.145290, 1.193376, -0.012100},{
      1.149029, 1.169767, -0.012100},{1.151724, 1.170643, -0.023903}}],
    Polygon[{{1.145290, 1.193376, -0.012100},{1.144338, 1.193376, 0.000000},{
      1.148123, 1.169473, 0.000000},{1.149029, 1.169767, -0.012100}}],
    Polygon[{{1.144338, 1.193376, 0.000000},{1.145290, 1.193376, 0.012100},{
      1.149029, 1.169767, 0.012100},{1.148123, 1.169473, 0.000000}}],
    Polygon[{{1.145290, 1.193376, 0.012100},{1.148123, 1.193376, 0.023903},{
      1.151724, 1.170643, 0.023903},{1.149029, 1.169767, 0.012100}}],
    Polygon[{{1.148123, 1.193376, 0.023903},{1.152768, 1.193376, 0.035116},{
      1.156141, 1.172078, 0.035116},{1.151724, 1.170643, 0.023903}}],
    Polygon[{{1.152768, 1.193376, 0.035116},{1.159110, 1.193376, 0.045465},{
      1.162173, 1.174038, 0.045465},{1.156141, 1.172078, 0.035116}}],
    Polygon[{{1.159110, 1.193376, 0.045465},{1.166993, 1.193376, 0.054695},{
      1.169670, 1.176474, 0.054695},{1.162173, 1.174038, 0.045465}}],
    Polygon[{{1.166993, 1.193376, 0.054695},{1.176222, 1.193376, 0.062578},{
      1.178448, 1.179326, 0.062578},{1.169670, 1.176474, 0.054695}}],
    Polygon[{{1.176222, 1.193376, 0.062578},{1.186572, 1.193376, 0.068920},{
      1.188290, 1.182524, 0.068920},{1.178448, 1.179326, 0.062578}}],
    Polygon[{{1.186572, 1.193376, 0.068920},{1.197785, 1.193376, 0.073564},{
      1.198955, 1.185989, 0.073564},{1.188290, 1.182524, 0.068920}}],
    Polygon[{{1.197785, 1.193376, 0.073564},{1.209588, 1.193376, 0.076398},{
      1.210180, 1.189636, 0.076398},{1.198955, 1.185989, 0.073564}}],
    Polygon[{{1.210180, 1.189636, -0.076398},{1.198955, 1.185989, -0.073564},{
      1.202350, 1.179326, -0.073564},{1.211899, 1.186263, -0.076398}}],
    Polygon[{{1.198955, 1.185989, -0.073564},{1.188290, 1.182524, -0.068920},{
      1.193278, 1.172735, -0.068920},{1.202350, 1.179326, -0.073564}}],
    Polygon[{{1.188290, 1.182524, -0.068920},{1.178448, 1.179326, -0.062578},{
      1.184906, 1.166652, -0.062578},{1.193278, 1.172735, -0.068920}}],
    Polygon[{{1.178448, 1.179326, -0.062578},{1.169670, 1.176474, -0.054695},{
      1.177439, 1.161227, -0.054695},{1.184906, 1.166652, -0.062578}}],
    Polygon[{{1.169670, 1.176474, -0.054695},{1.162173, 1.174038, -0.045465},{
      1.171061, 1.156593, -0.045465},{1.177439, 1.161227, -0.054695}}],
    Polygon[{{1.162173, 1.174038, -0.045465},{1.156141, 1.172078, -0.035116},{
      1.165931, 1.152866, -0.035116},{1.171061, 1.156593, -0.045465}}],
    Polygon[{{1.156141, 1.172078, -0.035116},{1.151724, 1.170643, -0.023903},{
      1.162173, 1.150136, -0.023903},{1.165931, 1.152866, -0.035116}}],
    Polygon[{{1.151724, 1.170643, -0.023903},{1.149029, 1.169767, -0.012100},{
      1.159881, 1.148470, -0.012100},{1.162173, 1.150136, -0.023903}}],
    Polygon[{{1.149029, 1.169767, -0.012100},{1.148123, 1.169473, 0.000000},{
      1.159110, 1.147910, 0.000000},{1.159881, 1.148470, -0.012100}}],
    Polygon[{{1.148123, 1.169473, 0.000000},{1.149029, 1.169767, 0.012100},{
      1.159881, 1.148470, 0.012100},{1.159110, 1.147910, 0.000000}}],
    Polygon[{{1.149029, 1.169767, 0.012100},{1.151724, 1.170643, 0.023903},{
      1.162173, 1.150136, 0.023903},{1.159881, 1.148470, 0.012100}}],
    Polygon[{{1.151724, 1.170643, 0.023903},{1.156141, 1.172078, 0.035116},{
      1.165931, 1.152866, 0.035116},{1.162173, 1.150136, 0.023903}}],
    Polygon[{{1.156141, 1.172078, 0.035116},{1.162173, 1.174038, 0.045465},{
      1.171061, 1.156593, 0.045465},{1.165931, 1.152866, 0.035116}}],
    Polygon[{{1.162173, 1.174038, 0.045465},{1.169670, 1.176474, 0.054695},{
      1.177439, 1.161227, 0.054695},{1.171061, 1.156593, 0.045465}}],
    Polygon[{{1.169670, 1.176474, 0.054695},{1.178448, 1.179326, 0.062578},{
      1.184906, 1.166652, 0.062578},{1.177439, 1.161227, 0.054695}}],
    Polygon[{{1.178448, 1.179326, 0.062578},{1.188290, 1.182524, 0.068920},{
      1.193278, 1.172735, 0.068920},{1.184906, 1.166652, 0.062578}}],
    Polygon[{{1.188290, 1.182524, 0.068920},{1.198955, 1.185989, 0.073564},{
      1.202350, 1.179326, 0.073564},{1.193278, 1.172735, 0.068920}}],
    Polygon[{{1.198955, 1.185989, 0.073564},{1.210180, 1.189636, 0.076398},{
      1.211899, 1.186263, 0.076398},{1.202350, 1.179326, 0.073564}}],
    Polygon[{{1.211899, 1.186263, -0.076398},{1.202350, 1.179326, -0.073564},{
      1.207638, 1.174038, -0.073564},{1.214576, 1.183586, -0.076398}}],
    Polygon[{{1.202350, 1.179326, -0.073564},{1.193278, 1.172735, -0.068920},{
      1.201047, 1.164966, -0.068920},{1.207638, 1.174038, -0.073564}}],
    Polygon[{{1.193278, 1.172735, -0.068920},{1.184906, 1.166652, -0.062578},{
      1.194964, 1.156593, -0.062578},{1.201047, 1.164966, -0.068920}}],
    Polygon[{{1.184906, 1.166652, -0.062578},{1.177439, 1.161227, -0.054695},{
      1.189539, 1.149127, -0.054695},{1.194964, 1.156593, -0.062578}}],
    Polygon[{{1.177439, 1.161227, -0.054695},{1.171061, 1.156593, -0.045465},{
      1.184906, 1.142749, -0.045465},{1.189539, 1.149127, -0.054695}}],
    Polygon[{{1.171061, 1.156593, -0.045465},{1.165931, 1.152866, -0.035116},{
      1.181178, 1.137619, -0.035116},{1.184906, 1.142749, -0.045465}}],
    Polygon[{{1.165931, 1.152866, -0.035116},{1.162173, 1.150136, -0.023903},{
      1.178448, 1.133861, -0.023903},{1.181178, 1.137619, -0.035116}}],
    Polygon[{{1.162173, 1.150136, -0.023903},{1.159881, 1.148470, -0.012100},{
      1.176782, 1.131568, -0.012100},{1.178448, 1.133861, -0.023903}}],
    Polygon[{{1.159881, 1.148470, -0.012100},{1.159110, 1.147910, 0.000000},{
      1.176222, 1.130798, 0.000000},{1.176782, 1.131568, -0.012100}}],
    Polygon[{{1.159110, 1.147910, 0.000000},{1.159881, 1.148470, 0.012100},{
      1.176782, 1.131568, 0.012100},{1.176222, 1.130798, 0.000000}}],
    Polygon[{{1.159881, 1.148470, 0.012100},{1.162173, 1.150136, 0.023903},{
      1.178448, 1.133861, 0.023903},{1.176782, 1.131568, 0.012100}}],
    Polygon[{{1.162173, 1.150136, 0.023903},{1.165931, 1.152866, 0.035116},{
      1.181178, 1.137619, 0.035116},{1.178448, 1.133861, 0.023903}}],
    Polygon[{{1.165931, 1.152866, 0.035116},{1.171061, 1.156593, 0.045465},{
      1.184906, 1.142749, 0.045465},{1.181178, 1.137619, 0.035116}}],
    Polygon[{{1.171061, 1.156593, 0.045465},{1.177439, 1.161227, 0.054695},{
      1.189539, 1.149127, 0.054695},{1.184906, 1.142749, 0.045465}}],
    Polygon[{{1.177439, 1.161227, 0.054695},{1.184906, 1.166652, 0.062578},{
      1.194964, 1.156593, 0.062578},{1.189539, 1.149127, 0.054695}}],
    Polygon[{{1.184906, 1.166652, 0.062578},{1.193278, 1.172735, 0.068920},{
      1.201047, 1.164966, 0.068920},{1.194964, 1.156593, 0.062578}}],
    Polygon[{{1.193278, 1.172735, 0.068920},{1.202350, 1.179326, 0.073564},{
      1.207638, 1.174038, 0.073564},{1.201047, 1.164966, 0.068920}}],
    Polygon[{{1.202350, 1.179326, 0.073564},{1.211899, 1.186263, 0.076398},{
      1.214576, 1.183586, 0.076398},{1.207638, 1.174038, 0.073564}}],
    Polygon[{{1.214576, 1.183586, -0.076398},{1.207638, 1.174038, -0.073564},{
      1.214302, 1.170643, -0.073564},{1.217949, 1.181868, -0.076398}}],
    Polygon[{{1.207638, 1.174038, -0.073564},{1.201047, 1.164966, -0.068920},{
      1.210836, 1.159978, -0.068920},{1.214302, 1.170643, -0.073564}}],
    Polygon[{{1.201047, 1.164966, -0.068920},{1.194964, 1.156593, -0.062578},{
      1.207638, 1.150136, -0.062578},{1.210836, 1.159978, -0.068920}}],
    Polygon[{{1.194964, 1.156593, -0.062578},{1.189539, 1.149127, -0.054695},{
      1.204786, 1.141358, -0.054695},{1.207638, 1.150136, -0.062578}}],
    Polygon[{{1.189539, 1.149127, -0.054695},{1.184906, 1.142749, -0.045465},{
      1.202350, 1.133861, -0.045465},{1.204786, 1.141358, -0.054695}}],
    Polygon[{{1.184906, 1.142749, -0.045465},{1.181178, 1.137619, -0.035116},{
      1.200390, 1.127829, -0.035116},{1.202350, 1.133861, -0.045465}}],
    Polygon[{{1.181178, 1.137619, -0.035116},{1.178448, 1.133861, -0.023903},{
      1.198955, 1.123412, -0.023903},{1.200390, 1.127829, -0.035116}}],
    Polygon[{{1.178448, 1.133861, -0.023903},{1.176782, 1.131568, -0.012100},{
      1.198080, 1.120717, -0.012100},{1.198955, 1.123412, -0.023903}}],
    Polygon[{{1.176782, 1.131568, -0.012100},{1.176222, 1.130798, 0.000000},{
      1.197785, 1.119811, 0.000000},{1.198080, 1.120717, -0.012100}}],
    Polygon[{{1.176222, 1.130798, 0.000000},{1.176782, 1.131568, 0.012100},{
      1.198080, 1.120717, 0.012100},{1.197785, 1.119811, 0.000000}}],
    Polygon[{{1.176782, 1.131568, 0.012100},{1.178448, 1.133861, 0.023903},{
      1.198955, 1.123412, 0.023903},{1.198080, 1.120717, 0.012100}}],
    Polygon[{{1.178448, 1.133861, 0.023903},{1.181178, 1.137619, 0.035116},{
      1.200390, 1.127829, 0.035116},{1.198955, 1.123412, 0.023903}}],
    Polygon[{{1.181178, 1.137619, 0.035116},{1.184906, 1.142749, 0.045465},{
      1.202350, 1.133861, 0.045465},{1.200390, 1.127829, 0.035116}}],
    Polygon[{{1.184906, 1.142749, 0.045465},{1.189539, 1.149127, 0.054695},{
      1.204786, 1.141358, 0.054695},{1.202350, 1.133861, 0.045465}}],
    Polygon[{{1.189539, 1.149127, 0.054695},{1.194964, 1.156593, 0.062578},{
      1.207638, 1.150136, 0.062578},{1.204786, 1.141358, 0.054695}}],
    Polygon[{{1.194964, 1.156593, 0.062578},{1.201047, 1.164966, 0.068920},{
      1.210836, 1.159978, 0.068920},{1.207638, 1.150136, 0.062578}}],
    Polygon[{{1.201047, 1.164966, 0.068920},{1.207638, 1.174038, 0.073564},{
      1.214302, 1.170643, 0.073564},{1.210836, 1.159978, 0.068920}}],
    Polygon[{{1.207638, 1.174038, 0.073564},{1.214576, 1.183586, 0.076398},{
      1.217949, 1.181868, 0.076398},{1.214302, 1.170643, 0.073564}}],
    Polygon[{{1.217949, 1.181868, -0.076398},{1.214302, 1.170643, -0.073564},{
      1.221688, 1.169473, -0.073564},{1.221688, 1.181275, -0.076398}}],
    Polygon[{{1.214302, 1.170643, -0.073564},{1.210836, 1.159978, -0.068920},{
      1.221688, 1.158259, -0.068920},{1.221688, 1.169473, -0.073564}}],
    Polygon[{{1.210836, 1.159978, -0.068920},{1.207638, 1.150136, -0.062578},{
      1.221688, 1.147910, -0.062578},{1.221688, 1.158259, -0.068920}}],
    Polygon[{{1.207638, 1.150136, -0.062578},{1.204786, 1.141358, -0.054695},{
      1.221688, 1.138681, -0.054695},{1.221688, 1.147910, -0.062578}}],
    Polygon[{{1.204786, 1.141358, -0.054695},{1.202350, 1.133861, -0.045465},{
      1.221688, 1.130798, -0.045465},{1.221688, 1.138681, -0.054695}}],
    Polygon[{{1.202350, 1.133861, -0.045465},{1.200390, 1.127829, -0.035116},{
      1.221688, 1.124456, -0.035116},{1.221688, 1.130798, -0.045465}}],
    Polygon[{{1.200390, 1.127829, -0.035116},{1.198955, 1.123412, -0.023903},{
      1.221688, 1.119811, -0.023903},{1.221688, 1.124456, -0.035116}}],
    Polygon[{{1.198955, 1.123412, -0.023903},{1.198080, 1.120717, -0.012100},{
      1.221688, 1.116978, -0.012100},{1.221688, 1.119811, -0.023903}}],
    Polygon[{{1.198080, 1.120717, -0.012100},{1.197785, 1.119811, 0.000000},{
      1.221688, 1.116025, 0.000000},{1.221688, 1.116978, -0.012100}}],
    Polygon[{{1.197785, 1.119811, 0.000000},{1.198080, 1.120717, 0.012100},{
      1.221688, 1.116978, 0.012100},{1.221688, 1.116025, 0.000000}}],
    Polygon[{{1.198080, 1.120717, 0.012100},{1.198955, 1.123412, 0.023903},{
      1.221688, 1.119811, 0.023903},{1.221688, 1.116978, 0.012100}}],
    Polygon[{{1.198955, 1.123412, 0.023903},{1.200390, 1.127829, 0.035116},{
      1.221688, 1.124456, 0.035116},{1.221688, 1.119811, 0.023903}}],
    Polygon[{{1.200390, 1.127829, 0.035116},{1.202350, 1.133861, 0.045465},{
      1.221688, 1.130798, 0.045465},{1.221688, 1.124456, 0.035116}}],
    Polygon[{{1.202350, 1.133861, 0.045465},{1.204786, 1.141358, 0.054695},{
      1.221688, 1.138681, 0.054695},{1.221688, 1.130798, 0.045465}}],
    Polygon[{{1.204786, 1.141358, 0.054695},{1.207638, 1.150136, 0.062578},{
      1.221688, 1.147910, 0.062578},{1.221688, 1.138681, 0.054695}}],
    Polygon[{{1.207638, 1.150136, 0.062578},{1.210836, 1.159978, 0.068920},{
      1.221688, 1.158259, 0.068920},{1.221688, 1.147910, 0.062578}}],
    Polygon[{{1.210836, 1.159978, 0.068920},{1.214302, 1.170643, 0.073564},{
      1.221688, 1.169473, 0.073564},{1.221688, 1.158259, 0.068920}}],
    Polygon[{{1.214302, 1.170643, 0.073564},{1.217949, 1.181868, 0.076398},{
      1.221688, 1.181275, 0.076398},{1.221688, 1.169473, 0.073564}}],
    Polygon[{{1.221688, 1.181275, -0.076398},{1.221688, 1.169473, -0.073564},{
      1.229074, 1.170643, -0.073564},{1.225427, 1.181868, -0.076398}}],
    Polygon[{{1.221688, 1.169473, -0.073564},{1.221688, 1.158259, -0.068920},{
      1.232539, 1.159978, -0.068920},{1.229074, 1.170643, -0.073564}}],
    Polygon[{{1.221688, 1.158259, -0.068920},{1.221688, 1.147910, -0.062578},{
      1.235737, 1.150136, -0.062578},{1.232539, 1.159978, -0.068920}}],
    Polygon[{{1.221688, 1.147910, -0.062578},{1.221688, 1.138681, -0.054695},{
      1.238590, 1.141358, -0.054695},{1.235737, 1.150136, -0.062578}}],
    Polygon[{{1.221688, 1.138681, -0.054695},{1.221688, 1.130798, -0.045465},{
      1.241025, 1.133861, -0.045465},{1.238590, 1.141358, -0.054695}}],
    Polygon[{{1.221688, 1.130798, -0.045465},{1.221688, 1.124456, -0.035116},{
      1.242985, 1.127829, -0.035116},{1.241025, 1.133861, -0.045465}}],
    Polygon[{{1.221688, 1.124456, -0.035116},{1.221688, 1.119811, -0.023903},{
      1.244421, 1.123412, -0.023903},{1.242985, 1.127829, -0.035116}}],
    Polygon[{{1.221688, 1.119811, -0.023903},{1.221688, 1.116978, -0.012100},{
      1.245296, 1.120717, -0.012100},{1.244421, 1.123412, -0.023903}}],
    Polygon[{{1.221688, 1.116978, -0.012100},{1.221688, 1.116025, 0.000000},{
      1.245590, 1.119811, 0.000000},{1.245296, 1.120717, -0.012100}}],
    Polygon[{{1.221688, 1.116025, 0.000000},{1.221688, 1.116978, 0.012100},{
      1.245296, 1.120717, 0.012100},{1.245590, 1.119811, 0.000000}}],
    Polygon[{{1.221688, 1.116978, 0.012100},{1.221688, 1.119811, 0.023903},{
      1.244421, 1.123412, 0.023903},{1.245296, 1.120717, 0.012100}}],
    Polygon[{{1.221688, 1.119811, 0.023903},{1.221688, 1.124456, 0.035116},{
      1.242985, 1.127829, 0.035116},{1.244421, 1.123412, 0.023903}}],
    Polygon[{{1.221688, 1.124456, 0.035116},{1.221688, 1.130798, 0.045465},{
      1.241025, 1.133861, 0.045465},{1.242985, 1.127829, 0.035116}}],
    Polygon[{{1.221688, 1.130798, 0.045465},{1.221688, 1.138681, 0.054695},{
      1.238590, 1.141358, 0.054695},{1.241025, 1.133861, 0.045465}}],
    Polygon[{{1.221688, 1.138681, 0.054695},{1.221688, 1.147910, 0.062578},{
      1.235737, 1.150136, 0.062578},{1.238590, 1.141358, 0.054695}}],
    Polygon[{{1.221688, 1.147910, 0.062578},{1.221688, 1.158259, 0.068920},{
      1.232539, 1.159978, 0.068920},{1.235737, 1.150136, 0.062578}}],
    Polygon[{{1.221688, 1.158259, 0.068920},{1.221688, 1.169473, 0.073564},{
      1.229074, 1.170643, 0.073564},{1.232539, 1.159978, 0.068920}}],
    Polygon[{{1.221688, 1.169473, 0.073564},{1.221688, 1.181275, 0.076398},{
      1.225427, 1.181868, 0.076398},{1.229074, 1.170643, 0.073564}}],
    Polygon[{{1.225427, 1.181868, -0.076398},{1.229074, 1.170643, -0.073564},{
      1.235737, 1.174038, -0.073564},{1.228800, 1.183586, -0.076398}}],
    Polygon[{{1.229074, 1.170643, -0.073564},{1.232539, 1.159978, -0.068920},{
      1.242329, 1.164966, -0.068920},{1.235737, 1.174038, -0.073564}}],
    Polygon[{{1.232539, 1.159978, -0.068920},{1.235737, 1.150136, -0.062578},{
      1.248412, 1.156593, -0.062578},{1.242329, 1.164966, -0.068920}}],
    Polygon[{{1.235737, 1.150136, -0.062578},{1.238590, 1.141358, -0.054695},{
      1.253837, 1.149127, -0.054695},{1.248412, 1.156593, -0.062578}}],
    Polygon[{{1.238590, 1.141358, -0.054695},{1.241025, 1.133861, -0.045465},{
      1.258470, 1.142749, -0.045465},{1.253837, 1.149127, -0.054695}}],
    Polygon[{{1.241025, 1.133861, -0.045465},{1.242985, 1.127829, -0.035116},{
      1.262198, 1.137619, -0.035116},{1.258470, 1.142749, -0.045465}}],
    Polygon[{{1.242985, 1.127829, -0.035116},{1.244421, 1.123412, -0.023903},{
      1.264928, 1.133861, -0.023903},{1.262198, 1.137619, -0.035116}}],
    Polygon[{{1.244421, 1.123412, -0.023903},{1.245296, 1.120717, -0.012100},{
      1.266593, 1.131568, -0.012100},{1.264928, 1.133861, -0.023903}}],
    Polygon[{{1.245296, 1.120717, -0.012100},{1.245590, 1.119811, 0.000000},{
      1.267153, 1.130798, 0.000000},{1.266593, 1.131568, -0.012100}}],
    Polygon[{{1.245590, 1.119811, 0.000000},{1.245296, 1.120717, 0.012100},{
      1.266593, 1.131568, 0.012100},{1.267153, 1.130798, 0.000000}}],
    Polygon[{{1.245296, 1.120717, 0.012100},{1.244421, 1.123412, 0.023903},{
      1.264928, 1.133861, 0.023903},{1.266593, 1.131568, 0.012100}}],
    Polygon[{{1.244421, 1.123412, 0.023903},{1.242985, 1.127829, 0.035116},{
      1.262198, 1.137619, 0.035116},{1.264928, 1.133861, 0.023903}}],
    Polygon[{{1.242985, 1.127829, 0.035116},{1.241025, 1.133861, 0.045465},{
      1.258470, 1.142749, 0.045465},{1.262198, 1.137619, 0.035116}}],
    Polygon[{{1.241025, 1.133861, 0.045465},{1.238590, 1.141358, 0.054695},{
      1.253837, 1.149127, 0.054695},{1.258470, 1.142749, 0.045465}}],
    Polygon[{{1.238590, 1.141358, 0.054695},{1.235737, 1.150136, 0.062578},{
      1.248412, 1.156593, 0.062578},{1.253837, 1.149127, 0.054695}}],
    Polygon[{{1.235737, 1.150136, 0.062578},{1.232539, 1.159978, 0.068920},{
      1.242329, 1.164966, 0.068920},{1.248412, 1.156593, 0.062578}}],
    Polygon[{{1.232539, 1.159978, 0.068920},{1.229074, 1.170643, 0.073564},{
      1.235737, 1.174038, 0.073564},{1.242329, 1.164966, 0.068920}}],
    Polygon[{{1.229074, 1.170643, 0.073564},{1.225427, 1.181868, 0.076398},{
      1.228800, 1.183586, 0.076398},{1.235737, 1.174038, 0.073564}}],
    Polygon[{{1.228800, 1.183586, -0.076398},{1.235737, 1.174038, -0.073564},{
      1.241025, 1.179326, -0.073564},{1.231477, 1.186263, -0.076398}}],
    Polygon[{{1.235737, 1.174038, -0.073564},{1.242329, 1.164966, -0.068920},{
      1.250098, 1.172735, -0.068920},{1.241025, 1.179326, -0.073564}}],
    Polygon[{{1.242329, 1.164966, -0.068920},{1.248412, 1.156593, -0.062578},{
      1.258470, 1.166652, -0.062578},{1.250098, 1.172735, -0.068920}}],
    Polygon[{{1.248412, 1.156593, -0.062578},{1.253837, 1.149127, -0.054695},{
      1.265937, 1.161227, -0.054695},{1.258470, 1.166652, -0.062578}}],
    Polygon[{{1.253837, 1.149127, -0.054695},{1.258470, 1.142749, -0.045465},{
      1.272314, 1.156593, -0.045465},{1.265937, 1.161227, -0.054695}}],
    Polygon[{{1.258470, 1.142749, -0.045465},{1.262198, 1.137619, -0.035116},{
      1.277445, 1.152866, -0.035116},{1.272314, 1.156593, -0.045465}}],
    Polygon[{{1.262198, 1.137619, -0.035116},{1.264928, 1.133861, -0.023903},{
      1.281203, 1.150136, -0.023903},{1.277445, 1.152866, -0.035116}}],
    Polygon[{{1.264928, 1.133861, -0.023903},{1.266593, 1.131568, -0.012100},{
      1.283495, 1.148470, -0.012100},{1.281203, 1.150136, -0.023903}}],
    Polygon[{{1.266593, 1.131568, -0.012100},{1.267153, 1.130798, 0.000000},{
      1.284266, 1.147910, 0.000000},{1.283495, 1.148470, -0.012100}}],
    Polygon[{{1.267153, 1.130798, 0.000000},{1.266593, 1.131568, 0.012100},{
      1.283495, 1.148470, 0.012100},{1.284266, 1.147910, 0.000000}}],
    Polygon[{{1.266593, 1.131568, 0.012100},{1.264928, 1.133861, 0.023903},{
      1.281203, 1.150136, 0.023903},{1.283495, 1.148470, 0.012100}}],
    Polygon[{{1.264928, 1.133861, 0.023903},{1.262198, 1.137619, 0.035116},{
      1.277445, 1.152866, 0.035116},{1.281203, 1.150136, 0.023903}}],
    Polygon[{{1.262198, 1.137619, 0.035116},{1.258470, 1.142749, 0.045465},{
      1.272314, 1.156593, 0.045465},{1.277445, 1.152866, 0.035116}}],
    Polygon[{{1.258470, 1.142749, 0.045465},{1.253837, 1.149127, 0.054695},{
      1.265937, 1.161227, 0.054695},{1.272314, 1.156593, 0.045465}}],
    Polygon[{{1.253837, 1.149127, 0.054695},{1.248412, 1.156593, 0.062578},{
      1.258470, 1.166652, 0.062578},{1.265937, 1.161227, 0.054695}}],
    Polygon[{{1.248412, 1.156593, 0.062578},{1.242329, 1.164966, 0.068920},{
      1.250098, 1.172735, 0.068920},{1.258470, 1.166652, 0.062578}}],
    Polygon[{{1.242329, 1.164966, 0.068920},{1.235737, 1.174038, 0.073564},{
      1.241025, 1.179326, 0.073564},{1.250098, 1.172735, 0.068920}}],
    Polygon[{{1.235737, 1.174038, 0.073564},{1.228800, 1.183586, 0.076398},{
      1.231477, 1.186263, 0.076398},{1.241025, 1.179326, 0.073564}}],
    Polygon[{{1.231477, 1.186263, -0.076398},{1.241025, 1.179326, -0.073564},{
      1.244421, 1.185989, -0.073564},{1.233196, 1.189636, -0.076398}}],
    Polygon[{{1.241025, 1.179326, -0.073564},{1.250098, 1.172735, -0.068920},{
      1.255085, 1.182524, -0.068920},{1.244421, 1.185989, -0.073564}}],
    Polygon[{{1.250098, 1.172735, -0.068920},{1.258470, 1.166652, -0.062578},{
      1.264928, 1.179326, -0.062578},{1.255085, 1.182524, -0.068920}}],
    Polygon[{{1.258470, 1.166652, -0.062578},{1.265937, 1.161227, -0.054695},{
      1.273706, 1.176474, -0.054695},{1.264928, 1.179326, -0.062578}}],
    Polygon[{{1.265937, 1.161227, -0.054695},{1.272314, 1.156593, -0.045465},{
      1.281203, 1.174038, -0.045465},{1.273706, 1.176474, -0.054695}}],
    Polygon[{{1.272314, 1.156593, -0.045465},{1.277445, 1.152866, -0.035116},{
      1.287234, 1.172078, -0.035116},{1.281203, 1.174038, -0.045465}}],
    Polygon[{{1.277445, 1.152866, -0.035116},{1.281203, 1.150136, -0.023903},{
      1.291652, 1.170643, -0.023903},{1.287234, 1.172078, -0.035116}}],
    Polygon[{{1.281203, 1.150136, -0.023903},{1.283495, 1.148470, -0.012100},{
      1.294347, 1.169767, -0.012100},{1.291652, 1.170643, -0.023903}}],
    Polygon[{{1.283495, 1.148470, -0.012100},{1.284266, 1.147910, 0.000000},{
      1.295252, 1.169473, 0.000000},{1.294347, 1.169767, -0.012100}}],
    Polygon[{{1.284266, 1.147910, 0.000000},{1.283495, 1.148470, 0.012100},{
      1.294347, 1.169767, 0.012100},{1.295252, 1.169473, 0.000000}}],
    Polygon[{{1.283495, 1.148470, 0.012100},{1.281203, 1.150136, 0.023903},{
      1.291652, 1.170643, 0.023903},{1.294347, 1.169767, 0.012100}}],
    Polygon[{{1.281203, 1.150136, 0.023903},{1.277445, 1.152866, 0.035116},{
      1.287234, 1.172078, 0.035116},{1.291652, 1.170643, 0.023903}}],
    Polygon[{{1.277445, 1.152866, 0.035116},{1.272314, 1.156593, 0.045465},{
      1.281203, 1.174038, 0.045465},{1.287234, 1.172078, 0.035116}}],
    Polygon[{{1.272314, 1.156593, 0.045465},{1.265937, 1.161227, 0.054695},{
      1.273706, 1.176474, 0.054695},{1.281203, 1.174038, 0.045465}}],
    Polygon[{{1.265937, 1.161227, 0.054695},{1.258470, 1.166652, 0.062578},{
      1.264928, 1.179326, 0.062578},{1.273706, 1.176474, 0.054695}}],
    Polygon[{{1.258470, 1.166652, 0.062578},{1.250098, 1.172735, 0.068920},{
      1.255085, 1.182524, 0.068920},{1.264928, 1.179326, 0.062578}}],
    Polygon[{{1.250098, 1.172735, 0.068920},{1.241025, 1.179326, 0.073564},{
      1.244421, 1.185989, 0.073564},{1.255085, 1.182524, 0.068920}}],
    Polygon[{{1.241025, 1.179326, 0.073564},{1.231477, 1.186263, 0.076398},{
      1.233196, 1.189636, 0.076398},{1.244421, 1.185989, 0.073564}}],
    Polygon[{{1.233196, 1.189636, -0.076398},{1.244421, 1.185989, -0.073564},{
      1.245590, 1.193376, -0.073564},{1.233788, 1.193376, -0.076398}}],
    Polygon[{{1.244421, 1.185989, -0.073564},{1.255085, 1.182524, -0.068920},{
      1.256804, 1.193376, -0.068920},{1.245590, 1.193376, -0.073564}}],
    Polygon[{{1.255085, 1.182524, -0.068920},{1.264928, 1.179326, -0.062578},{
      1.267153, 1.193376, -0.062578},{1.256804, 1.193376, -0.068920}}],
    Polygon[{{1.264928, 1.179326, -0.062578},{1.273706, 1.176474, -0.054695},{
      1.276383, 1.193376, -0.054695},{1.267153, 1.193376, -0.062578}}],
    Polygon[{{1.273706, 1.176474, -0.054695},{1.281203, 1.174038, -0.045465},{
      1.284266, 1.193376, -0.045465},{1.276383, 1.193376, -0.054695}}],
    Polygon[{{1.281203, 1.174038, -0.045465},{1.287234, 1.172078, -0.035116},{
      1.290607, 1.193376, -0.035116},{1.284266, 1.193376, -0.045465}}],
    Polygon[{{1.287234, 1.172078, -0.035116},{1.291652, 1.170643, -0.023903},{
      1.295252, 1.193376, -0.023903},{1.290607, 1.193376, -0.035116}}],
    Polygon[{{1.291652, 1.170643, -0.023903},{1.294347, 1.169767, -0.012100},{
      1.298086, 1.193376, -0.012100},{1.295252, 1.193376, -0.023903}}],
    Polygon[{{1.294347, 1.169767, -0.012100},{1.295252, 1.169473, 0.000000},{
      1.299038, 1.193376, 0.000000},{1.298086, 1.193376, -0.012100}}],
    Polygon[{{1.295252, 1.169473, 0.000000},{1.294347, 1.169767, 0.012100},{
      1.298086, 1.193376, 0.012100},{1.299038, 1.193376, 0.000000}}],
    Polygon[{{1.294347, 1.169767, 0.012100},{1.291652, 1.170643, 0.023903},{
      1.295252, 1.193376, 0.023903},{1.298086, 1.193376, 0.012100}}],
    Polygon[{{1.291652, 1.170643, 0.023903},{1.287234, 1.172078, 0.035116},{
      1.290607, 1.193376, 0.035116},{1.295252, 1.193376, 0.023903}}],
    Polygon[{{1.287234, 1.172078, 0.035116},{1.281203, 1.174038, 0.045465},{
      1.284266, 1.193376, 0.045465},{1.290607, 1.193376, 0.035116}}],
    Polygon[{{1.281203, 1.174038, 0.045465},{1.273706, 1.176474, 0.054695},{
      1.276383, 1.193376, 0.054695},{1.284266, 1.193376, 0.045465}}],
    Polygon[{{1.273706, 1.176474, 0.054695},{1.264928, 1.179326, 0.062578},{
      1.267153, 1.193376, 0.062578},{1.276383, 1.193376, 0.054695}}],
    Polygon[{{1.264928, 1.179326, 0.062578},{1.255085, 1.182524, 0.068920},{
      1.256804, 1.193376, 0.068920},{1.267153, 1.193376, 0.062578}}],
    Polygon[{{1.255085, 1.182524, 0.068920},{1.244421, 1.185989, 0.073564},{
      1.245590, 1.193376, 0.073564},{1.256804, 1.193376, 0.068920}}],
    Polygon[{{1.244421, 1.185989, 0.073564},{1.233196, 1.189636, 0.076398},{
      1.233788, 1.193376, 0.076398},{1.245590, 1.193376, 0.073564}}],
    Polygon[{{1.315886, 1.113249, -0.040942},{1.322210, 1.113249, -0.039423},{
      1.321584, 1.117207, -0.039423},{1.315568, 1.115252, -0.040942}}],
    Polygon[{{1.322210, 1.113249, -0.039423},{1.328220, 1.113249, -0.036934},{
      1.327299, 1.119064, -0.036934},{1.321584, 1.117207, -0.039423}}],
    Polygon[{{1.328220, 1.113249, -0.036934},{1.333766, 1.113249, -0.033535},{
      1.332573, 1.120778, -0.033535},{1.327299, 1.119064, -0.036934}}],
    Polygon[{{1.333766, 1.113249, -0.033535},{1.338712, 1.113249, -0.029311},{
      1.337277, 1.122306, -0.029311},{1.332573, 1.120778, -0.033535}}],
    Polygon[{{1.338712, 1.113249, -0.029311},{1.342936, 1.113249, -0.024365},{
      1.341295, 1.123612, -0.024365},{1.337277, 1.122306, -0.029311}}],
    Polygon[{{1.342936, 1.113249, -0.024365},{1.346335, 1.113249, -0.018819},{
      1.344527, 1.124662, -0.018819},{1.341295, 1.123612, -0.024365}}],
    Polygon[{{1.346335, 1.113249, -0.018819},{1.348824, 1.113249, -0.012809},{
      1.346895, 1.125431, -0.012809},{1.344527, 1.124662, -0.018819}}],
    Polygon[{{1.348824, 1.113249, -0.012809},{1.350343, 1.113249, -0.006485},{
      1.348339, 1.125900, -0.006485},{1.346895, 1.125431, -0.012809}}],
    Polygon[{{1.350343, 1.113249, -0.006485},{1.350853, 1.113249, 0.000000},{
      1.348824, 1.126058, 0.000000},{1.348339, 1.125900, -0.006485}}],
    Polygon[{{1.350853, 1.113249, 0.000000},{1.350343, 1.113249, 0.006485},{
      1.348339, 1.125900, 0.006485},{1.348824, 1.126058, 0.000000}}],
    Polygon[{{1.350343, 1.113249, 0.006485},{1.348824, 1.113249, 0.012809},{
      1.346895, 1.125431, 0.012809},{1.348339, 1.125900, 0.006485}}],
    Polygon[{{1.348824, 1.113249, 0.012809},{1.346335, 1.113249, 0.018819},{
      1.344527, 1.124662, 0.018819},{1.346895, 1.125431, 0.012809}}],
    Polygon[{{1.346335, 1.113249, 0.018819},{1.342936, 1.113249, 0.024365},{
      1.341295, 1.123612, 0.024365},{1.344527, 1.124662, 0.018819}}],
    Polygon[{{1.342936, 1.113249, 0.024365},{1.338712, 1.113249, 0.029311},{
      1.337277, 1.122306, 0.029311},{1.341295, 1.123612, 0.024365}}],
    Polygon[{{1.338712, 1.113249, 0.029311},{1.333766, 1.113249, 0.033535},{
      1.332573, 1.120778, 0.033535},{1.337277, 1.122306, 0.029311}}],
    Polygon[{{1.333766, 1.113249, 0.033535},{1.328220, 1.113249, 0.036934},{
      1.327299, 1.119064, 0.036934},{1.332573, 1.120778, 0.033535}}],
    Polygon[{{1.328220, 1.113249, 0.036934},{1.322210, 1.113249, 0.039423},{
      1.321584, 1.117207, 0.039423},{1.327299, 1.119064, 0.036934}}],
    Polygon[{{1.322210, 1.113249, 0.039423},{1.315886, 1.113249, 0.040942},{
      1.315568, 1.115252, 0.040942},{1.321584, 1.117207, 0.039423}}],
    Polygon[{{1.315568, 1.115252, -0.040942},{1.321584, 1.117207, -0.039423},{
      1.319764, 1.120778, -0.039423},{1.314647, 1.117060, -0.040942}}],
    Polygon[{{1.321584, 1.117207, -0.039423},{1.327299, 1.119064, -0.036934},{
      1.324626, 1.124310, -0.036934},{1.319764, 1.120778, -0.039423}}],
    Polygon[{{1.327299, 1.119064, -0.036934},{1.332573, 1.120778, -0.033535},{
      1.329113, 1.127570, -0.033535},{1.324626, 1.124310, -0.036934}}],
    Polygon[{{1.332573, 1.120778, -0.033535},{1.337277, 1.122306, -0.029311},{
      1.333114, 1.130477, -0.029311},{1.329113, 1.127570, -0.033535}}],
    Polygon[{{1.337277, 1.122306, -0.029311},{1.341295, 1.123612, -0.024365},{
      1.336532, 1.132960, -0.024365},{1.333114, 1.130477, -0.029311}}],
    Polygon[{{1.341295, 1.123612, -0.024365},{1.344527, 1.124662, -0.018819},{
      1.339281, 1.134958, -0.018819},{1.336532, 1.132960, -0.024365}}],
    Polygon[{{1.344527, 1.124662, -0.018819},{1.346895, 1.125431, -0.012809},{
      1.341295, 1.136421, -0.012809},{1.339281, 1.134958, -0.018819}}],
    Polygon[{{1.346895, 1.125431, -0.012809},{1.348339, 1.125900, -0.006485},{
      1.342523, 1.137313, -0.006485},{1.341295, 1.136421, -0.012809}}],
    Polygon[{{1.348339, 1.125900, -0.006485},{1.348824, 1.126058, 0.000000},{
      1.342936, 1.137613, 0.000000},{1.342523, 1.137313, -0.006485}}],
    Polygon[{{1.348824, 1.126058, 0.000000},{1.348339, 1.125900, 0.006485},{
      1.342523, 1.137313, 0.006485},{1.342936, 1.137613, 0.000000}}],
    Polygon[{{1.348339, 1.125900, 0.006485},{1.346895, 1.125431, 0.012809},{
      1.341295, 1.136421, 0.012809},{1.342523, 1.137313, 0.006485}}],
    Polygon[{{1.346895, 1.125431, 0.012809},{1.344527, 1.124662, 0.018819},{
      1.339281, 1.134958, 0.018819},{1.341295, 1.136421, 0.012809}}],
    Polygon[{{1.344527, 1.124662, 0.018819},{1.341295, 1.123612, 0.024365},{
      1.336532, 1.132960, 0.024365},{1.339281, 1.134958, 0.018819}}],
    Polygon[{{1.341295, 1.123612, 0.024365},{1.337277, 1.122306, 0.029311},{
      1.333114, 1.130477, 0.029311},{1.336532, 1.132960, 0.024365}}],
    Polygon[{{1.337277, 1.122306, 0.029311},{1.332573, 1.120778, 0.033535},{
      1.329113, 1.127570, 0.033535},{1.333114, 1.130477, 0.029311}}],
    Polygon[{{1.332573, 1.120778, 0.033535},{1.327299, 1.119064, 0.036934},{
      1.324626, 1.124310, 0.036934},{1.329113, 1.127570, 0.033535}}],
    Polygon[{{1.327299, 1.119064, 0.036934},{1.321584, 1.117207, 0.039423},{
      1.319764, 1.120778, 0.039423},{1.324626, 1.124310, 0.036934}}],
    Polygon[{{1.321584, 1.117207, 0.039423},{1.315568, 1.115252, 0.040942},{
      1.314647, 1.117060, 0.040942},{1.319764, 1.120778, 0.039423}}],
    Polygon[{{1.314647, 1.117060, -0.040942},{1.319764, 1.120778, -0.039423},{
      1.316930, 1.123612, -0.039423},{1.313213, 1.118495, -0.040942}}],
    Polygon[{{1.319764, 1.120778, -0.039423},{1.324626, 1.124310, -0.036934},{
      1.320462, 1.128473, -0.036934},{1.316930, 1.123612, -0.039423}}],
    Polygon[{{1.324626, 1.124310, -0.036934},{1.329113, 1.127570, -0.033535},{
      1.323722, 1.132960, -0.033535},{1.320462, 1.128473, -0.036934}}],
    Polygon[{{1.329113, 1.127570, -0.033535},{1.333114, 1.130477, -0.029311},{
      1.326630, 1.136962, -0.029311},{1.323722, 1.132960, -0.033535}}],
    Polygon[{{1.333114, 1.130477, -0.029311},{1.336532, 1.132960, -0.024365},{
      1.329113, 1.140379, -0.024365},{1.326630, 1.136962, -0.029311}}],
    Polygon[{{1.336532, 1.132960, -0.024365},{1.339281, 1.134958, -0.018819},{
      1.331110, 1.143129, -0.018819},{1.329113, 1.140379, -0.024365}}],
    Polygon[{{1.339281, 1.134958, -0.018819},{1.341295, 1.136421, -0.012809},{
      1.332573, 1.145143, -0.012809},{1.331110, 1.143129, -0.018819}}],
    Polygon[{{1.341295, 1.136421, -0.012809},{1.342523, 1.137313, -0.006485},{
      1.333466, 1.146371, -0.006485},{1.332573, 1.145143, -0.012809}}],
    Polygon[{{1.342523, 1.137313, -0.006485},{1.342936, 1.137613, 0.000000},{
      1.333766, 1.146784, 0.000000},{1.333466, 1.146371, -0.006485}}],
    Polygon[{{1.342936, 1.137613, 0.000000},{1.342523, 1.137313, 0.006485},{
      1.333466, 1.146371, 0.006485},{1.333766, 1.146784, 0.000000}}],
    Polygon[{{1.342523, 1.137313, 0.006485},{1.341295, 1.136421, 0.012809},{
      1.332573, 1.145143, 0.012809},{1.333466, 1.146371, 0.006485}}],
    Polygon[{{1.341295, 1.136421, 0.012809},{1.339281, 1.134958, 0.018819},{
      1.331110, 1.143129, 0.018819},{1.332573, 1.145143, 0.012809}}],
    Polygon[{{1.339281, 1.134958, 0.018819},{1.336532, 1.132960, 0.024365},{
      1.329113, 1.140379, 0.024365},{1.331110, 1.143129, 0.018819}}],
    Polygon[{{1.336532, 1.132960, 0.024365},{1.333114, 1.130477, 0.029311},{
      1.326630, 1.136962, 0.029311},{1.329113, 1.140379, 0.024365}}],
    Polygon[{{1.333114, 1.130477, 0.029311},{1.329113, 1.127570, 0.033535},{
      1.323722, 1.132960, 0.033535},{1.326630, 1.136962, 0.029311}}],
    Polygon[{{1.329113, 1.127570, 0.033535},{1.324626, 1.124310, 0.036934},{
      1.320462, 1.128473, 0.036934},{1.323722, 1.132960, 0.033535}}],
    Polygon[{{1.324626, 1.124310, 0.036934},{1.319764, 1.120778, 0.039423},{
      1.316930, 1.123612, 0.039423},{1.320462, 1.128473, 0.036934}}],
    Polygon[{{1.319764, 1.120778, 0.039423},{1.314647, 1.117060, 0.040942},{
      1.313213, 1.118495, 0.040942},{1.316930, 1.123612, 0.039423}}],
    Polygon[{{1.313213, 1.118495, -0.040942},{1.316930, 1.123612, -0.039423},{
      1.313359, 1.125431, -0.039423},{1.311405, 1.119416, -0.040942}}],
    Polygon[{{1.316930, 1.123612, -0.039423},{1.320462, 1.128473, -0.036934},{
      1.315216, 1.131146, -0.036934},{1.313359, 1.125431, -0.039423}}],
    Polygon[{{1.320462, 1.128473, -0.036934},{1.323722, 1.132960, -0.033535},{
      1.316930, 1.136421, -0.033535},{1.315216, 1.131146, -0.036934}}],
    Polygon[{{1.323722, 1.132960, -0.033535},{1.326630, 1.136962, -0.029311},{
      1.318459, 1.141125, -0.029311},{1.316930, 1.136421, -0.033535}}],
    Polygon[{{1.326630, 1.136962, -0.029311},{1.329113, 1.140379, -0.024365},{
      1.319764, 1.145143, -0.024365},{1.318459, 1.141125, -0.029311}}],
    Polygon[{{1.329113, 1.140379, -0.024365},{1.331110, 1.143129, -0.018819},{
      1.320814, 1.148375, -0.018819},{1.319764, 1.145143, -0.024365}}],
    Polygon[{{1.331110, 1.143129, -0.018819},{1.332573, 1.145143, -0.012809},{
      1.321584, 1.150742, -0.012809},{1.320814, 1.148375, -0.018819}}],
    Polygon[{{1.332573, 1.145143, -0.012809},{1.333466, 1.146371, -0.006485},{
      1.322053, 1.152186, -0.006485},{1.321584, 1.150742, -0.012809}}],
    Polygon[{{1.333466, 1.146371, -0.006485},{1.333766, 1.146784, 0.000000},{
      1.322210, 1.152672, 0.000000},{1.322053, 1.152186, -0.006485}}],
    Polygon[{{1.333766, 1.146784, 0.000000},{1.333466, 1.146371, 0.006485},{
      1.322053, 1.152186, 0.006485},{1.322210, 1.152672, 0.000000}}],
    Polygon[{{1.333466, 1.146371, 0.006485},{1.332573, 1.145143, 0.012809},{
      1.321584, 1.150742, 0.012809},{1.322053, 1.152186, 0.006485}}],
    Polygon[{{1.332573, 1.145143, 0.012809},{1.331110, 1.143129, 0.018819},{
      1.320814, 1.148375, 0.018819},{1.321584, 1.150742, 0.012809}}],
    Polygon[{{1.331110, 1.143129, 0.018819},{1.329113, 1.140379, 0.024365},{
      1.319764, 1.145143, 0.024365},{1.320814, 1.148375, 0.018819}}],
    Polygon[{{1.329113, 1.140379, 0.024365},{1.326630, 1.136962, 0.029311},{
      1.318459, 1.141125, 0.029311},{1.319764, 1.145143, 0.024365}}],
    Polygon[{{1.326630, 1.136962, 0.029311},{1.323722, 1.132960, 0.033535},{
      1.316930, 1.136421, 0.033535},{1.318459, 1.141125, 0.029311}}],
    Polygon[{{1.323722, 1.132960, 0.033535},{1.320462, 1.128473, 0.036934},{
      1.315216, 1.131146, 0.036934},{1.316930, 1.136421, 0.033535}}],
    Polygon[{{1.320462, 1.128473, 0.036934},{1.316930, 1.123612, 0.039423},{
      1.313359, 1.125431, 0.039423},{1.315216, 1.131146, 0.036934}}],
    Polygon[{{1.316930, 1.123612, 0.039423},{1.313213, 1.118495, 0.040942},{
      1.311405, 1.119416, 0.040942},{1.313359, 1.125431, 0.039423}}],
    Polygon[{{1.311405, 1.119416, -0.040942},{1.313359, 1.125431, -0.039423},{
      1.309401, 1.126058, -0.039423},{1.309401, 1.119733, -0.040942}}],
    Polygon[{{1.313359, 1.125431, -0.039423},{1.315216, 1.131146, -0.036934},{
      1.309401, 1.132067, -0.036934},{1.309401, 1.126058, -0.039423}}],
    Polygon[{{1.315216, 1.131146, -0.036934},{1.316930, 1.136421, -0.033535},{
      1.309401, 1.137613, -0.033535},{1.309401, 1.132067, -0.036934}}],
    Polygon[{{1.316930, 1.136421, -0.033535},{1.318459, 1.141125, -0.029311},{
      1.309401, 1.142560, -0.029311},{1.309401, 1.137613, -0.033535}}],
    Polygon[{{1.318459, 1.141125, -0.029311},{1.319764, 1.145143, -0.024365},{
      1.309401, 1.146784, -0.024365},{1.309401, 1.142560, -0.029311}}],
    Polygon[{{1.319764, 1.145143, -0.024365},{1.320814, 1.148375, -0.018819},{
      1.309401, 1.150183, -0.018819},{1.309401, 1.146784, -0.024365}}],
    Polygon[{{1.320814, 1.148375, -0.018819},{1.321584, 1.150742, -0.012809},{
      1.309401, 1.152672, -0.012809},{1.309401, 1.150183, -0.018819}}],
    Polygon[{{1.321584, 1.150742, -0.012809},{1.322053, 1.152186, -0.006485},{
      1.309401, 1.154190, -0.006485},{1.309401, 1.152672, -0.012809}}],
    Polygon[{{1.322053, 1.152186, -0.006485},{1.322210, 1.152672, 0.000000},{
      1.309401, 1.154701, 0.000000},{1.309401, 1.154190, -0.006485}}],
    Polygon[{{1.322210, 1.152672, 0.000000},{1.322053, 1.152186, 0.006485},{
      1.309401, 1.154190, 0.006485},{1.309401, 1.154701, 0.000000}}],
    Polygon[{{1.322053, 1.152186, 0.006485},{1.321584, 1.150742, 0.012809},{
      1.309401, 1.152672, 0.012809},{1.309401, 1.154190, 0.006485}}],
    Polygon[{{1.321584, 1.150742, 0.012809},{1.320814, 1.148375, 0.018819},{
      1.309401, 1.150183, 0.018819},{1.309401, 1.152672, 0.012809}}],
    Polygon[{{1.320814, 1.148375, 0.018819},{1.319764, 1.145143, 0.024365},{
      1.309401, 1.146784, 0.024365},{1.309401, 1.150183, 0.018819}}],
    Polygon[{{1.319764, 1.145143, 0.024365},{1.318459, 1.141125, 0.029311},{
      1.309401, 1.142560, 0.029311},{1.309401, 1.146784, 0.024365}}],
    Polygon[{{1.318459, 1.141125, 0.029311},{1.316930, 1.136421, 0.033535},{
      1.309401, 1.137613, 0.033535},{1.309401, 1.142560, 0.029311}}],
    Polygon[{{1.316930, 1.136421, 0.033535},{1.315216, 1.131146, 0.036934},{
      1.309401, 1.132067, 0.036934},{1.309401, 1.137613, 0.033535}}],
    Polygon[{{1.315216, 1.131146, 0.036934},{1.313359, 1.125431, 0.039423},{
      1.309401, 1.126058, 0.039423},{1.309401, 1.132067, 0.036934}}],
    Polygon[{{1.313359, 1.125431, 0.039423},{1.311405, 1.119416, 0.040942},{
      1.309401, 1.119733, 0.040942},{1.309401, 1.126058, 0.039423}}],
    Polygon[{{1.309401, 1.119733, -0.040942},{1.309401, 1.126058, -0.039423},{
      1.305443, 1.125431, -0.039423},{1.307397, 1.119416, -0.040942}}],
    Polygon[{{1.309401, 1.126058, -0.039423},{1.309401, 1.132067, -0.036934},{
      1.303586, 1.131146, -0.036934},{1.305443, 1.125431, -0.039423}}],
    Polygon[{{1.309401, 1.132067, -0.036934},{1.309401, 1.137613, -0.033535},{
      1.301872, 1.136421, -0.033535},{1.303586, 1.131146, -0.036934}}],
    Polygon[{{1.309401, 1.137613, -0.033535},{1.309401, 1.142560, -0.029311},{
      1.300344, 1.141125, -0.029311},{1.301872, 1.136421, -0.033535}}],
    Polygon[{{1.309401, 1.142560, -0.029311},{1.309401, 1.146784, -0.024365},{
      1.299038, 1.145143, -0.024365},{1.300344, 1.141125, -0.029311}}],
    Polygon[{{1.309401, 1.146784, -0.024365},{1.309401, 1.150183, -0.018819},{
      1.297988, 1.148375, -0.018819},{1.299038, 1.145143, -0.024365}}],
    Polygon[{{1.309401, 1.150183, -0.018819},{1.309401, 1.152672, -0.012809},{
      1.297219, 1.150742, -0.012809},{1.297988, 1.148375, -0.018819}}],
    Polygon[{{1.309401, 1.152672, -0.012809},{1.309401, 1.154190, -0.006485},{
      1.296749, 1.152186, -0.006485},{1.297219, 1.150742, -0.012809}}],
    Polygon[{{1.309401, 1.154190, -0.006485},{1.309401, 1.154701, 0.000000},{
      1.296592, 1.152672, 0.000000},{1.296749, 1.152186, -0.006485}}],
    Polygon[{{1.309401, 1.154701, 0.000000},{1.309401, 1.154190, 0.006485},{
      1.296749, 1.152186, 0.006485},{1.296592, 1.152672, 0.000000}}],
    Polygon[{{1.309401, 1.154190, 0.006485},{1.309401, 1.152672, 0.012809},{
      1.297219, 1.150742, 0.012809},{1.296749, 1.152186, 0.006485}}],
    Polygon[{{1.309401, 1.152672, 0.012809},{1.309401, 1.150183, 0.018819},{
      1.297988, 1.148375, 0.018819},{1.297219, 1.150742, 0.012809}}],
    Polygon[{{1.309401, 1.150183, 0.018819},{1.309401, 1.146784, 0.024365},{
      1.299038, 1.145143, 0.024365},{1.297988, 1.148375, 0.018819}}],
    Polygon[{{1.309401, 1.146784, 0.024365},{1.309401, 1.142560, 0.029311},{
      1.300344, 1.141125, 0.029311},{1.299038, 1.145143, 0.024365}}],
    Polygon[{{1.309401, 1.142560, 0.029311},{1.309401, 1.137613, 0.033535},{
      1.301872, 1.136421, 0.033535},{1.300344, 1.141125, 0.029311}}],
    Polygon[{{1.309401, 1.137613, 0.033535},{1.309401, 1.132067, 0.036934},{
      1.303586, 1.131146, 0.036934},{1.301872, 1.136421, 0.033535}}],
    Polygon[{{1.309401, 1.132067, 0.036934},{1.309401, 1.126058, 0.039423},{
      1.305443, 1.125431, 0.039423},{1.303586, 1.131146, 0.036934}}],
    Polygon[{{1.309401, 1.126058, 0.039423},{1.309401, 1.119733, 0.040942},{
      1.307397, 1.119416, 0.040942},{1.305443, 1.125431, 0.039423}}],
    Polygon[{{1.307397, 1.119416, -0.040942},{1.305443, 1.125431, -0.039423},{
      1.301872, 1.123612, -0.039423},{1.305590, 1.118495, -0.040942}}],
    Polygon[{{1.305443, 1.125431, -0.039423},{1.303586, 1.131146, -0.036934},{
      1.298340, 1.128473, -0.036934},{1.301872, 1.123612, -0.039423}}],
    Polygon[{{1.303586, 1.131146, -0.036934},{1.301872, 1.136421, -0.033535},{
      1.295080, 1.132960, -0.033535},{1.298340, 1.128473, -0.036934}}],
    Polygon[{{1.301872, 1.136421, -0.033535},{1.300344, 1.141125, -0.029311},{
      1.292173, 1.136962, -0.029311},{1.295080, 1.132960, -0.033535}}],
    Polygon[{{1.300344, 1.141125, -0.029311},{1.299038, 1.145143, -0.024365},{
      1.289690, 1.140379, -0.024365},{1.292173, 1.136962, -0.029311}}],
    Polygon[{{1.299038, 1.145143, -0.024365},{1.297988, 1.148375, -0.018819},{
      1.287692, 1.143129, -0.018819},{1.289690, 1.140379, -0.024365}}],
    Polygon[{{1.297988, 1.148375, -0.018819},{1.297219, 1.150742, -0.012809},{
      1.286229, 1.145143, -0.012809},{1.287692, 1.143129, -0.018819}}],
    Polygon[{{1.297219, 1.150742, -0.012809},{1.296749, 1.152186, -0.006485},{
      1.285336, 1.146371, -0.006485},{1.286229, 1.145143, -0.012809}}],
    Polygon[{{1.296749, 1.152186, -0.006485},{1.296592, 1.152672, 0.000000},{
      1.285036, 1.146784, 0.000000},{1.285336, 1.146371, -0.006485}}],
    Polygon[{{1.296592, 1.152672, 0.000000},{1.296749, 1.152186, 0.006485},{
      1.285336, 1.146371, 0.006485},{1.285036, 1.146784, 0.000000}}],
    Polygon[{{1.296749, 1.152186, 0.006485},{1.297219, 1.150742, 0.012809},{
      1.286229, 1.145143, 0.012809},{1.285336, 1.146371, 0.006485}}],
    Polygon[{{1.297219, 1.150742, 0.012809},{1.297988, 1.148375, 0.018819},{
      1.287692, 1.143129, 0.018819},{1.286229, 1.145143, 0.012809}}],
    Polygon[{{1.297988, 1.148375, 0.018819},{1.299038, 1.145143, 0.024365},{
      1.289690, 1.140379, 0.024365},{1.287692, 1.143129, 0.018819}}],
    Polygon[{{1.299038, 1.145143, 0.024365},{1.300344, 1.141125, 0.029311},{
      1.292173, 1.136962, 0.029311},{1.289690, 1.140379, 0.024365}}],
    Polygon[{{1.300344, 1.141125, 0.029311},{1.301872, 1.136421, 0.033535},{
      1.295080, 1.132960, 0.033535},{1.292173, 1.136962, 0.029311}}],
    Polygon[{{1.301872, 1.136421, 0.033535},{1.303586, 1.131146, 0.036934},{
      1.298340, 1.128473, 0.036934},{1.295080, 1.132960, 0.033535}}],
    Polygon[{{1.303586, 1.131146, 0.036934},{1.305443, 1.125431, 0.039423},{
      1.301872, 1.123612, 0.039423},{1.298340, 1.128473, 0.036934}}],
    Polygon[{{1.305443, 1.125431, 0.039423},{1.307397, 1.119416, 0.040942},{
      1.305590, 1.118495, 0.040942},{1.301872, 1.123612, 0.039423}}],
    Polygon[{{1.305590, 1.118495, -0.040942},{1.301872, 1.123612, -0.039423},{
      1.299038, 1.120778, -0.039423},{1.304155, 1.117060, -0.040942}}],
    Polygon[{{1.301872, 1.123612, -0.039423},{1.298340, 1.128473, -0.036934},{
      1.294176, 1.124310, -0.036934},{1.299038, 1.120778, -0.039423}}],
    Polygon[{{1.298340, 1.128473, -0.036934},{1.295080, 1.132960, -0.033535},{
      1.289690, 1.127570, -0.033535},{1.294176, 1.124310, -0.036934}}],
    Polygon[{{1.295080, 1.132960, -0.033535},{1.292173, 1.136962, -0.029311},{
      1.285688, 1.130477, -0.029311},{1.289690, 1.127570, -0.033535}}],
    Polygon[{{1.292173, 1.136962, -0.029311},{1.289690, 1.140379, -0.024365},{
      1.282270, 1.132960, -0.024365},{1.285688, 1.130477, -0.029311}}],
    Polygon[{{1.289690, 1.140379, -0.024365},{1.287692, 1.143129, -0.018819},{
      1.279521, 1.134958, -0.018819},{1.282270, 1.132960, -0.024365}}],
    Polygon[{{1.287692, 1.143129, -0.018819},{1.286229, 1.145143, -0.012809},{
      1.277507, 1.136421, -0.012809},{1.279521, 1.134958, -0.018819}}],
    Polygon[{{1.286229, 1.145143, -0.012809},{1.285336, 1.146371, -0.006485},{
      1.276279, 1.137313, -0.006485},{1.277507, 1.136421, -0.012809}}],
    Polygon[{{1.285336, 1.146371, -0.006485},{1.285036, 1.146784, 0.000000},{
      1.275866, 1.137613, 0.000000},{1.276279, 1.137313, -0.006485}}],
    Polygon[{{1.285036, 1.146784, 0.000000},{1.285336, 1.146371, 0.006485},{
      1.276279, 1.137313, 0.006485},{1.275866, 1.137613, 0.000000}}],
    Polygon[{{1.285336, 1.146371, 0.006485},{1.286229, 1.145143, 0.012809},{
      1.277507, 1.136421, 0.012809},{1.276279, 1.137313, 0.006485}}],
    Polygon[{{1.286229, 1.145143, 0.012809},{1.287692, 1.143129, 0.018819},{
      1.279521, 1.134958, 0.018819},{1.277507, 1.136421, 0.012809}}],
    Polygon[{{1.287692, 1.143129, 0.018819},{1.289690, 1.140379, 0.024365},{
      1.282270, 1.132960, 0.024365},{1.279521, 1.134958, 0.018819}}],
    Polygon[{{1.289690, 1.140379, 0.024365},{1.292173, 1.136962, 0.029311},{
      1.285688, 1.130477, 0.029311},{1.282270, 1.132960, 0.024365}}],
    Polygon[{{1.292173, 1.136962, 0.029311},{1.295080, 1.132960, 0.033535},{
      1.289690, 1.127570, 0.033535},{1.285688, 1.130477, 0.029311}}],
    Polygon[{{1.295080, 1.132960, 0.033535},{1.298340, 1.128473, 0.036934},{
      1.294176, 1.124310, 0.036934},{1.289690, 1.127570, 0.033535}}],
    Polygon[{{1.298340, 1.128473, 0.036934},{1.301872, 1.123612, 0.039423},{
      1.299038, 1.120778, 0.039423},{1.294176, 1.124310, 0.036934}}],
    Polygon[{{1.301872, 1.123612, 0.039423},{1.305590, 1.118495, 0.040942},{
      1.304155, 1.117060, 0.040942},{1.299038, 1.120778, 0.039423}}],
    Polygon[{{1.304155, 1.117060, -0.040942},{1.299038, 1.120778, -0.039423},{
      1.297219, 1.117207, -0.039423},{1.303234, 1.115252, -0.040942}}],
    Polygon[{{1.299038, 1.120778, -0.039423},{1.294176, 1.124310, -0.036934},{
      1.291503, 1.119064, -0.036934},{1.297219, 1.117207, -0.039423}}],
    Polygon[{{1.294176, 1.124310, -0.036934},{1.289690, 1.127570, -0.033535},{
      1.286229, 1.120778, -0.033535},{1.291503, 1.119064, -0.036934}}],
    Polygon[{{1.289690, 1.127570, -0.033535},{1.285688, 1.130477, -0.029311},{
      1.281525, 1.122306, -0.029311},{1.286229, 1.120778, -0.033535}}],
    Polygon[{{1.285688, 1.130477, -0.029311},{1.282270, 1.132960, -0.024365},{
      1.277507, 1.123612, -0.024365},{1.281525, 1.122306, -0.029311}}],
    Polygon[{{1.282270, 1.132960, -0.024365},{1.279521, 1.134958, -0.018819},{
      1.274275, 1.124662, -0.018819},{1.277507, 1.123612, -0.024365}}],
    Polygon[{{1.279521, 1.134958, -0.018819},{1.277507, 1.136421, -0.012809},{
      1.271907, 1.125431, -0.012809},{1.274275, 1.124662, -0.018819}}],
    Polygon[{{1.277507, 1.136421, -0.012809},{1.276279, 1.137313, -0.006485},{
      1.270463, 1.125900, -0.006485},{1.271907, 1.125431, -0.012809}}],
    Polygon[{{1.276279, 1.137313, -0.006485},{1.275866, 1.137613, 0.000000},{
      1.269978, 1.126058, 0.000000},{1.270463, 1.125900, -0.006485}}],
    Polygon[{{1.275866, 1.137613, 0.000000},{1.276279, 1.137313, 0.006485},{
      1.270463, 1.125900, 0.006485},{1.269978, 1.126058, 0.000000}}],
    Polygon[{{1.276279, 1.137313, 0.006485},{1.277507, 1.136421, 0.012809},{
      1.271907, 1.125431, 0.012809},{1.270463, 1.125900, 0.006485}}],
    Polygon[{{1.277507, 1.136421, 0.012809},{1.279521, 1.134958, 0.018819},{
      1.274275, 1.124662, 0.018819},{1.271907, 1.125431, 0.012809}}],
    Polygon[{{1.279521, 1.134958, 0.018819},{1.282270, 1.132960, 0.024365},{
      1.277507, 1.123612, 0.024365},{1.274275, 1.124662, 0.018819}}],
    Polygon[{{1.282270, 1.132960, 0.024365},{1.285688, 1.130477, 0.029311},{
      1.281525, 1.122306, 0.029311},{1.277507, 1.123612, 0.024365}}],
    Polygon[{{1.285688, 1.130477, 0.029311},{1.289690, 1.127570, 0.033535},{
      1.286229, 1.120778, 0.033535},{1.281525, 1.122306, 0.029311}}],
    Polygon[{{1.289690, 1.127570, 0.033535},{1.294176, 1.124310, 0.036934},{
      1.291503, 1.119064, 0.036934},{1.286229, 1.120778, 0.033535}}],
    Polygon[{{1.294176, 1.124310, 0.036934},{1.299038, 1.120778, 0.039423},{
      1.297219, 1.117207, 0.039423},{1.291503, 1.119064, 0.036934}}],
    Polygon[{{1.299038, 1.120778, 0.039423},{1.304155, 1.117060, 0.040942},{
      1.303234, 1.115252, 0.040942},{1.297219, 1.117207, 0.039423}}],
    Polygon[{{1.303234, 1.115252, -0.040942},{1.297219, 1.117207, -0.039423},{
      1.296592, 1.113249, -0.039423},{1.302917, 1.113249, -0.040942}}],
    Polygon[{{1.297219, 1.117207, -0.039423},{1.291503, 1.119064, -0.036934},{
      1.290582, 1.113249, -0.036934},{1.296592, 1.113249, -0.039423}}],
    Polygon[{{1.291503, 1.119064, -0.036934},{1.286229, 1.120778, -0.033535},{
      1.285036, 1.113249, -0.033535},{1.290582, 1.113249, -0.036934}}],
    Polygon[{{1.286229, 1.120778, -0.033535},{1.281525, 1.122306, -0.029311},{
      1.280090, 1.113249, -0.029311},{1.285036, 1.113249, -0.033535}}],
    Polygon[{{1.281525, 1.122306, -0.029311},{1.277507, 1.123612, -0.024365},{
      1.275866, 1.113249, -0.024365},{1.280090, 1.113249, -0.029311}}],
    Polygon[{{1.277507, 1.123612, -0.024365},{1.274275, 1.124662, -0.018819},{
      1.272467, 1.113249, -0.018819},{1.275866, 1.113249, -0.024365}}],
    Polygon[{{1.274275, 1.124662, -0.018819},{1.271907, 1.125431, -0.012809},{
      1.269978, 1.113249, -0.012809},{1.272467, 1.113249, -0.018819}}],
    Polygon[{{1.271907, 1.125431, -0.012809},{1.270463, 1.125900, -0.006485},{
      1.268460, 1.113249, -0.006485},{1.269978, 1.113249, -0.012809}}],
    Polygon[{{1.270463, 1.125900, -0.006485},{1.269978, 1.126058, 0.000000},{
      1.267949, 1.113249, 0.000000},{1.268460, 1.113249, -0.006485}}],
    Polygon[{{1.269978, 1.126058, 0.000000},{1.270463, 1.125900, 0.006485},{
      1.268460, 1.113249, 0.006485},{1.267949, 1.113249, 0.000000}}],
    Polygon[{{1.270463, 1.125900, 0.006485},{1.271907, 1.125431, 0.012809},{
      1.269978, 1.113249, 0.012809},{1.268460, 1.113249, 0.006485}}],
    Polygon[{{1.271907, 1.125431, 0.012809},{1.274275, 1.124662, 0.018819},{
      1.272467, 1.113249, 0.018819},{1.269978, 1.113249, 0.012809}}],
    Polygon[{{1.274275, 1.124662, 0.018819},{1.277507, 1.123612, 0.024365},{
      1.275866, 1.113249, 0.024365},{1.272467, 1.113249, 0.018819}}],
    Polygon[{{1.277507, 1.123612, 0.024365},{1.281525, 1.122306, 0.029311},{
      1.280090, 1.113249, 0.029311},{1.275866, 1.113249, 0.024365}}],
    Polygon[{{1.281525, 1.122306, 0.029311},{1.286229, 1.120778, 0.033535},{
      1.285036, 1.113249, 0.033535},{1.280090, 1.113249, 0.029311}}],
    Polygon[{{1.286229, 1.120778, 0.033535},{1.291503, 1.119064, 0.036934},{
      1.290582, 1.113249, 0.036934},{1.285036, 1.113249, 0.033535}}],
    Polygon[{{1.291503, 1.119064, 0.036934},{1.297219, 1.117207, 0.039423},{
      1.296592, 1.113249, 0.039423},{1.290582, 1.113249, 0.036934}}],
    Polygon[{{1.297219, 1.117207, 0.039423},{1.303234, 1.115252, 0.040942},{
      1.302917, 1.113249, 0.040942},{1.296592, 1.113249, 0.039423}}],
    Polygon[{{1.302917, 1.113249, -0.040942},{1.296592, 1.113249, -0.039423},{
      1.297219, 1.109290, -0.039423},{1.303234, 1.111245, -0.040942}}],
    Polygon[{{1.296592, 1.113249, -0.039423},{1.290582, 1.113249, -0.036934},{
      1.291503, 1.107433, -0.036934},{1.297219, 1.109290, -0.039423}}],
    Polygon[{{1.290582, 1.113249, -0.036934},{1.285036, 1.113249, -0.033535},{
      1.286229, 1.105720, -0.033535},{1.291503, 1.107433, -0.036934}}],
    Polygon[{{1.285036, 1.113249, -0.033535},{1.280090, 1.113249, -0.029311},{
      1.281525, 1.104191, -0.029311},{1.286229, 1.105720, -0.033535}}],
    Polygon[{{1.280090, 1.113249, -0.029311},{1.275866, 1.113249, -0.024365},{
      1.277507, 1.102886, -0.024365},{1.281525, 1.104191, -0.029311}}],
    Polygon[{{1.275866, 1.113249, -0.024365},{1.272467, 1.113249, -0.018819},{
      1.274275, 1.101835, -0.018819},{1.277507, 1.102886, -0.024365}}],
    Polygon[{{1.272467, 1.113249, -0.018819},{1.269978, 1.113249, -0.012809},{
      1.271907, 1.101066, -0.012809},{1.274275, 1.101835, -0.018819}}],
    Polygon[{{1.269978, 1.113249, -0.012809},{1.268460, 1.113249, -0.006485},{
      1.270463, 1.100597, -0.006485},{1.271907, 1.101066, -0.012809}}],
    Polygon[{{1.268460, 1.113249, -0.006485},{1.267949, 1.113249, 0.000000},{
      1.269978, 1.100439, 0.000000},{1.270463, 1.100597, -0.006485}}],
    Polygon[{{1.267949, 1.113249, 0.000000},{1.268460, 1.113249, 0.006485},{
      1.270463, 1.100597, 0.006485},{1.269978, 1.100439, 0.000000}}],
    Polygon[{{1.268460, 1.113249, 0.006485},{1.269978, 1.113249, 0.012809},{
      1.271907, 1.101066, 0.012809},{1.270463, 1.100597, 0.006485}}],
    Polygon[{{1.269978, 1.113249, 0.012809},{1.272467, 1.113249, 0.018819},{
      1.274275, 1.101835, 0.018819},{1.271907, 1.101066, 0.012809}}],
    Polygon[{{1.272467, 1.113249, 0.018819},{1.275866, 1.113249, 0.024365},{
      1.277507, 1.102886, 0.024365},{1.274275, 1.101835, 0.018819}}],
    Polygon[{{1.275866, 1.113249, 0.024365},{1.280090, 1.113249, 0.029311},{
      1.281525, 1.104191, 0.029311},{1.277507, 1.102886, 0.024365}}],
    Polygon[{{1.280090, 1.113249, 0.029311},{1.285036, 1.113249, 0.033535},{
      1.286229, 1.105720, 0.033535},{1.281525, 1.104191, 0.029311}}],
    Polygon[{{1.285036, 1.113249, 0.033535},{1.290582, 1.113249, 0.036934},{
      1.291503, 1.107433, 0.036934},{1.286229, 1.105720, 0.033535}}],
    Polygon[{{1.290582, 1.113249, 0.036934},{1.296592, 1.113249, 0.039423},{
      1.297219, 1.109290, 0.039423},{1.291503, 1.107433, 0.036934}}],
    Polygon[{{1.296592, 1.113249, 0.039423},{1.302917, 1.113249, 0.040942},{
      1.303234, 1.111245, 0.040942},{1.297219, 1.109290, 0.039423}}],
    Polygon[{{1.303234, 1.111245, -0.040942},{1.297219, 1.109290, -0.039423},{
      1.299038, 1.105720, -0.039423},{1.304155, 1.109437, -0.040942}}],
    Polygon[{{1.297219, 1.109290, -0.039423},{1.291503, 1.107433, -0.036934},{
      1.294176, 1.102187, -0.036934},{1.299038, 1.105720, -0.039423}}],
    Polygon[{{1.291503, 1.107433, -0.036934},{1.286229, 1.105720, -0.033535},{
      1.289690, 1.098927, -0.033535},{1.294176, 1.102187, -0.036934}}],
    Polygon[{{1.286229, 1.105720, -0.033535},{1.281525, 1.104191, -0.029311},{
      1.285688, 1.096020, -0.029311},{1.289690, 1.098927, -0.033535}}],
    Polygon[{{1.281525, 1.104191, -0.029311},{1.277507, 1.102886, -0.024365},{
      1.282270, 1.093537, -0.024365},{1.285688, 1.096020, -0.029311}}],
    Polygon[{{1.277507, 1.102886, -0.024365},{1.274275, 1.101835, -0.018819},{
      1.279521, 1.091540, -0.018819},{1.282270, 1.093537, -0.024365}}],
    Polygon[{{1.274275, 1.101835, -0.018819},{1.271907, 1.101066, -0.012809},{
      1.277507, 1.090076, -0.012809},{1.279521, 1.091540, -0.018819}}],
    Polygon[{{1.271907, 1.101066, -0.012809},{1.270463, 1.100597, -0.006485},{
      1.276279, 1.089184, -0.006485},{1.277507, 1.090076, -0.012809}}],
    Polygon[{{1.270463, 1.100597, -0.006485},{1.269978, 1.100439, 0.000000},{
      1.275866, 1.088884, 0.000000},{1.276279, 1.089184, -0.006485}}],
    Polygon[{{1.269978, 1.100439, 0.000000},{1.270463, 1.100597, 0.006485},{
      1.276279, 1.089184, 0.006485},{1.275866, 1.088884, 0.000000}}],
    Polygon[{{1.270463, 1.100597, 0.006485},{1.271907, 1.101066, 0.012809},{
      1.277507, 1.090076, 0.012809},{1.276279, 1.089184, 0.006485}}],
    Polygon[{{1.271907, 1.101066, 0.012809},{1.274275, 1.101835, 0.018819},{
      1.279521, 1.091540, 0.018819},{1.277507, 1.090076, 0.012809}}],
    Polygon[{{1.274275, 1.101835, 0.018819},{1.277507, 1.102886, 0.024365},{
      1.282270, 1.093537, 0.024365},{1.279521, 1.091540, 0.018819}}],
    Polygon[{{1.277507, 1.102886, 0.024365},{1.281525, 1.104191, 0.029311},{
      1.285688, 1.096020, 0.029311},{1.282270, 1.093537, 0.024365}}],
    Polygon[{{1.281525, 1.104191, 0.029311},{1.286229, 1.105720, 0.033535},{
      1.289690, 1.098927, 0.033535},{1.285688, 1.096020, 0.029311}}],
    Polygon[{{1.286229, 1.105720, 0.033535},{1.291503, 1.107433, 0.036934},{
      1.294176, 1.102187, 0.036934},{1.289690, 1.098927, 0.033535}}],
    Polygon[{{1.291503, 1.107433, 0.036934},{1.297219, 1.109290, 0.039423},{
      1.299038, 1.105720, 0.039423},{1.294176, 1.102187, 0.036934}}],
    Polygon[{{1.297219, 1.109290, 0.039423},{1.303234, 1.111245, 0.040942},{
      1.304155, 1.109437, 0.040942},{1.299038, 1.105720, 0.039423}}],
    Polygon[{{1.304155, 1.109437, -0.040942},{1.299038, 1.105720, -0.039423},{
      1.301872, 1.102886, -0.039423},{1.305590, 1.108003, -0.040942}}],
    Polygon[{{1.299038, 1.105720, -0.039423},{1.294176, 1.102187, -0.036934},{
      1.298340, 1.098024, -0.036934},{1.301872, 1.102886, -0.039423}}],
    Polygon[{{1.294176, 1.102187, -0.036934},{1.289690, 1.098927, -0.033535},{
      1.295080, 1.093537, -0.033535},{1.298340, 1.098024, -0.036934}}],
    Polygon[{{1.289690, 1.098927, -0.033535},{1.285688, 1.096020, -0.029311},{
      1.292173, 1.089536, -0.029311},{1.295080, 1.093537, -0.033535}}],
    Polygon[{{1.285688, 1.096020, -0.029311},{1.282270, 1.093537, -0.024365},{
      1.289690, 1.086118, -0.024365},{1.292173, 1.089536, -0.029311}}],
    Polygon[{{1.282270, 1.093537, -0.024365},{1.279521, 1.091540, -0.018819},{
      1.287692, 1.083369, -0.018819},{1.289690, 1.086118, -0.024365}}],
    Polygon[{{1.279521, 1.091540, -0.018819},{1.277507, 1.090076, -0.012809},{
      1.286229, 1.081355, -0.012809},{1.287692, 1.083369, -0.018819}}],
    Polygon[{{1.277507, 1.090076, -0.012809},{1.276279, 1.089184, -0.006485},{
      1.285336, 1.080126, -0.006485},{1.286229, 1.081355, -0.012809}}],
    Polygon[{{1.276279, 1.089184, -0.006485},{1.275866, 1.088884, 0.000000},{
      1.285036, 1.079713, 0.000000},{1.285336, 1.080126, -0.006485}}],
    Polygon[{{1.275866, 1.088884, 0.000000},{1.276279, 1.089184, 0.006485},{
      1.285336, 1.080126, 0.006485},{1.285036, 1.079713, 0.000000}}],
    Polygon[{{1.276279, 1.089184, 0.006485},{1.277507, 1.090076, 0.012809},{
      1.286229, 1.081355, 0.012809},{1.285336, 1.080126, 0.006485}}],
    Polygon[{{1.277507, 1.090076, 0.012809},{1.279521, 1.091540, 0.018819},{
      1.287692, 1.083369, 0.018819},{1.286229, 1.081355, 0.012809}}],
    Polygon[{{1.279521, 1.091540, 0.018819},{1.282270, 1.093537, 0.024365},{
      1.289690, 1.086118, 0.024365},{1.287692, 1.083369, 0.018819}}],
    Polygon[{{1.282270, 1.093537, 0.024365},{1.285688, 1.096020, 0.029311},{
      1.292173, 1.089536, 0.029311},{1.289690, 1.086118, 0.024365}}],
    Polygon[{{1.285688, 1.096020, 0.029311},{1.289690, 1.098927, 0.033535},{
      1.295080, 1.093537, 0.033535},{1.292173, 1.089536, 0.029311}}],
    Polygon[{{1.289690, 1.098927, 0.033535},{1.294176, 1.102187, 0.036934},{
      1.298340, 1.098024, 0.036934},{1.295080, 1.093537, 0.033535}}],
    Polygon[{{1.294176, 1.102187, 0.036934},{1.299038, 1.105720, 0.039423},{
      1.301872, 1.102886, 0.039423},{1.298340, 1.098024, 0.036934}}],
    Polygon[{{1.299038, 1.105720, 0.039423},{1.304155, 1.109437, 0.040942},{
      1.305590, 1.108003, 0.040942},{1.301872, 1.102886, 0.039423}}],
    Polygon[{{1.305590, 1.108003, -0.040942},{1.301872, 1.102886, -0.039423},{
      1.305443, 1.101066, -0.039423},{1.307397, 1.107082, -0.040942}}],
    Polygon[{{1.301872, 1.102886, -0.039423},{1.298340, 1.098024, -0.036934},{
      1.303586, 1.095351, -0.036934},{1.305443, 1.101066, -0.039423}}],
    Polygon[{{1.298340, 1.098024, -0.036934},{1.295080, 1.093537, -0.033535},{
      1.301872, 1.090076, -0.033535},{1.303586, 1.095351, -0.036934}}],
    Polygon[{{1.295080, 1.093537, -0.033535},{1.292173, 1.089536, -0.029311},{
      1.300344, 1.085372, -0.029311},{1.301872, 1.090076, -0.033535}}],
    Polygon[{{1.292173, 1.089536, -0.029311},{1.289690, 1.086118, -0.024365},{
      1.299038, 1.081355, -0.024365},{1.300344, 1.085372, -0.029311}}],
    Polygon[{{1.289690, 1.086118, -0.024365},{1.287692, 1.083369, -0.018819},{
      1.297988, 1.078122, -0.018819},{1.299038, 1.081355, -0.024365}}],
    Polygon[{{1.287692, 1.083369, -0.018819},{1.286229, 1.081355, -0.012809},{
      1.297219, 1.075755, -0.012809},{1.297988, 1.078122, -0.018819}}],
    Polygon[{{1.286229, 1.081355, -0.012809},{1.285336, 1.080126, -0.006485},{
      1.296749, 1.074311, -0.006485},{1.297219, 1.075755, -0.012809}}],
    Polygon[{{1.285336, 1.080126, -0.006485},{1.285036, 1.079713, 0.000000},{
      1.296592, 1.073826, 0.000000},{1.296749, 1.074311, -0.006485}}],
    Polygon[{{1.285036, 1.079713, 0.000000},{1.285336, 1.080126, 0.006485},{
      1.296749, 1.074311, 0.006485},{1.296592, 1.073826, 0.000000}}],
    Polygon[{{1.285336, 1.080126, 0.006485},{1.286229, 1.081355, 0.012809},{
      1.297219, 1.075755, 0.012809},{1.296749, 1.074311, 0.006485}}],
    Polygon[{{1.286229, 1.081355, 0.012809},{1.287692, 1.083369, 0.018819},{
      1.297988, 1.078122, 0.018819},{1.297219, 1.075755, 0.012809}}],
    Polygon[{{1.287692, 1.083369, 0.018819},{1.289690, 1.086118, 0.024365},{
      1.299038, 1.081355, 0.024365},{1.297988, 1.078122, 0.018819}}],
    Polygon[{{1.289690, 1.086118, 0.024365},{1.292173, 1.089536, 0.029311},{
      1.300344, 1.085372, 0.029311},{1.299038, 1.081355, 0.024365}}],
    Polygon[{{1.292173, 1.089536, 0.029311},{1.295080, 1.093537, 0.033535},{
      1.301872, 1.090076, 0.033535},{1.300344, 1.085372, 0.029311}}],
    Polygon[{{1.295080, 1.093537, 0.033535},{1.298340, 1.098024, 0.036934},{
      1.303586, 1.095351, 0.036934},{1.301872, 1.090076, 0.033535}}],
    Polygon[{{1.298340, 1.098024, 0.036934},{1.301872, 1.102886, 0.039423},{
      1.305443, 1.101066, 0.039423},{1.303586, 1.095351, 0.036934}}],
    Polygon[{{1.301872, 1.102886, 0.039423},{1.305590, 1.108003, 0.040942},{
      1.307397, 1.107082, 0.040942},{1.305443, 1.101066, 0.039423}}],
    Polygon[{{1.307397, 1.107082, -0.040942},{1.305443, 1.101066, -0.039423},{
      1.309401, 1.100439, -0.039423},{1.309401, 1.106764, -0.040942}}],
    Polygon[{{1.305443, 1.101066, -0.039423},{1.303586, 1.095351, -0.036934},{
      1.309401, 1.094430, -0.036934},{1.309401, 1.100439, -0.039423}}],
    Polygon[{{1.303586, 1.095351, -0.036934},{1.301872, 1.090076, -0.033535},{
      1.309401, 1.088884, -0.033535},{1.309401, 1.094430, -0.036934}}],
    Polygon[{{1.301872, 1.090076, -0.033535},{1.300344, 1.085372, -0.029311},{
      1.309401, 1.083938, -0.029311},{1.309401, 1.088884, -0.033535}}],
    Polygon[{{1.300344, 1.085372, -0.029311},{1.299038, 1.081355, -0.024365},{
      1.309401, 1.079713, -0.024365},{1.309401, 1.083938, -0.029311}}],
    Polygon[{{1.299038, 1.081355, -0.024365},{1.297988, 1.078122, -0.018819},{
      1.309401, 1.076315, -0.018819},{1.309401, 1.079713, -0.024365}}],
    Polygon[{{1.297988, 1.078122, -0.018819},{1.297219, 1.075755, -0.012809},{
      1.309401, 1.073826, -0.012809},{1.309401, 1.076315, -0.018819}}],
    Polygon[{{1.297219, 1.075755, -0.012809},{1.296749, 1.074311, -0.006485},{
      1.309401, 1.072307, -0.006485},{1.309401, 1.073826, -0.012809}}],
    Polygon[{{1.296749, 1.074311, -0.006485},{1.296592, 1.073826, 0.000000},{
      1.309401, 1.071797, 0.000000},{1.309401, 1.072307, -0.006485}}],
    Polygon[{{1.296592, 1.073826, 0.000000},{1.296749, 1.074311, 0.006485},{
      1.309401, 1.072307, 0.006485},{1.309401, 1.071797, 0.000000}}],
    Polygon[{{1.296749, 1.074311, 0.006485},{1.297219, 1.075755, 0.012809},{
      1.309401, 1.073826, 0.012809},{1.309401, 1.072307, 0.006485}}],
    Polygon[{{1.297219, 1.075755, 0.012809},{1.297988, 1.078122, 0.018819},{
      1.309401, 1.076315, 0.018819},{1.309401, 1.073826, 0.012809}}],
    Polygon[{{1.297988, 1.078122, 0.018819},{1.299038, 1.081355, 0.024365},{
      1.309401, 1.079713, 0.024365},{1.309401, 1.076315, 0.018819}}],
    Polygon[{{1.299038, 1.081355, 0.024365},{1.300344, 1.085372, 0.029311},{
      1.309401, 1.083938, 0.029311},{1.309401, 1.079713, 0.024365}}],
    Polygon[{{1.300344, 1.085372, 0.029311},{1.301872, 1.090076, 0.033535},{
      1.309401, 1.088884, 0.033535},{1.309401, 1.083938, 0.029311}}],
    Polygon[{{1.301872, 1.090076, 0.033535},{1.303586, 1.095351, 0.036934},{
      1.309401, 1.094430, 0.036934},{1.309401, 1.088884, 0.033535}}],
    Polygon[{{1.303586, 1.095351, 0.036934},{1.305443, 1.101066, 0.039423},{
      1.309401, 1.100439, 0.039423},{1.309401, 1.094430, 0.036934}}],
    Polygon[{{1.305443, 1.101066, 0.039423},{1.307397, 1.107082, 0.040942},{
      1.309401, 1.106764, 0.040942},{1.309401, 1.100439, 0.039423}}],
    Polygon[{{1.309401, 1.106764, -0.040942},{1.309401, 1.100439, -0.039423},{
      1.313359, 1.101066, -0.039423},{1.311405, 1.107082, -0.040942}}],
    Polygon[{{1.309401, 1.100439, -0.039423},{1.309401, 1.094430, -0.036934},{
      1.315216, 1.095351, -0.036934},{1.313359, 1.101066, -0.039423}}],
    Polygon[{{1.309401, 1.094430, -0.036934},{1.309401, 1.088884, -0.033535},{
      1.316930, 1.090076, -0.033535},{1.315216, 1.095351, -0.036934}}],
    Polygon[{{1.309401, 1.088884, -0.033535},{1.309401, 1.083938, -0.029311},{
      1.318459, 1.085372, -0.029311},{1.316930, 1.090076, -0.033535}}],
    Polygon[{{1.309401, 1.083938, -0.029311},{1.309401, 1.079713, -0.024365},{
      1.319764, 1.081355, -0.024365},{1.318459, 1.085372, -0.029311}}],
    Polygon[{{1.309401, 1.079713, -0.024365},{1.309401, 1.076315, -0.018819},{
      1.320814, 1.078122, -0.018819},{1.319764, 1.081355, -0.024365}}],
    Polygon[{{1.309401, 1.076315, -0.018819},{1.309401, 1.073826, -0.012809},{
      1.321584, 1.075755, -0.012809},{1.320814, 1.078122, -0.018819}}],
    Polygon[{{1.309401, 1.073826, -0.012809},{1.309401, 1.072307, -0.006485},{
      1.322053, 1.074311, -0.006485},{1.321584, 1.075755, -0.012809}}],
    Polygon[{{1.309401, 1.072307, -0.006485},{1.309401, 1.071797, 0.000000},{
      1.322210, 1.073826, 0.000000},{1.322053, 1.074311, -0.006485}}],
    Polygon[{{1.309401, 1.071797, 0.000000},{1.309401, 1.072307, 0.006485},{
      1.322053, 1.074311, 0.006485},{1.322210, 1.073826, 0.000000}}],
    Polygon[{{1.309401, 1.072307, 0.006485},{1.309401, 1.073826, 0.012809},{
      1.321584, 1.075755, 0.012809},{1.322053, 1.074311, 0.006485}}],
    Polygon[{{1.309401, 1.073826, 0.012809},{1.309401, 1.076315, 0.018819},{
      1.320814, 1.078122, 0.018819},{1.321584, 1.075755, 0.012809}}],
    Polygon[{{1.309401, 1.076315, 0.018819},{1.309401, 1.079713, 0.024365},{
      1.319764, 1.081355, 0.024365},{1.320814, 1.078122, 0.018819}}],
    Polygon[{{1.309401, 1.079713, 0.024365},{1.309401, 1.083938, 0.029311},{
      1.318459, 1.085372, 0.029311},{1.319764, 1.081355, 0.024365}}],
    Polygon[{{1.309401, 1.083938, 0.029311},{1.309401, 1.088884, 0.033535},{
      1.316930, 1.090076, 0.033535},{1.318459, 1.085372, 0.029311}}],
    Polygon[{{1.309401, 1.088884, 0.033535},{1.309401, 1.094430, 0.036934},{
      1.315216, 1.095351, 0.036934},{1.316930, 1.090076, 0.033535}}],
    Polygon[{{1.309401, 1.094430, 0.036934},{1.309401, 1.100439, 0.039423},{
      1.313359, 1.101066, 0.039423},{1.315216, 1.095351, 0.036934}}],
    Polygon[{{1.309401, 1.100439, 0.039423},{1.309401, 1.106764, 0.040942},{
      1.311405, 1.107082, 0.040942},{1.313359, 1.101066, 0.039423}}],
    Polygon[{{1.311405, 1.107082, -0.040942},{1.313359, 1.101066, -0.039423},{
      1.316930, 1.102886, -0.039423},{1.313213, 1.108003, -0.040942}}],
    Polygon[{{1.313359, 1.101066, -0.039423},{1.315216, 1.095351, -0.036934},{
      1.320462, 1.098024, -0.036934},{1.316930, 1.102886, -0.039423}}],
    Polygon[{{1.315216, 1.095351, -0.036934},{1.316930, 1.090076, -0.033535},{
      1.323722, 1.093537, -0.033535},{1.320462, 1.098024, -0.036934}}],
    Polygon[{{1.316930, 1.090076, -0.033535},{1.318459, 1.085372, -0.029311},{
      1.326630, 1.089536, -0.029311},{1.323722, 1.093537, -0.033535}}],
    Polygon[{{1.318459, 1.085372, -0.029311},{1.319764, 1.081355, -0.024365},{
      1.329113, 1.086118, -0.024365},{1.326630, 1.089536, -0.029311}}],
    Polygon[{{1.319764, 1.081355, -0.024365},{1.320814, 1.078122, -0.018819},{
      1.331110, 1.083369, -0.018819},{1.329113, 1.086118, -0.024365}}],
    Polygon[{{1.320814, 1.078122, -0.018819},{1.321584, 1.075755, -0.012809},{
      1.332573, 1.081355, -0.012809},{1.331110, 1.083369, -0.018819}}],
    Polygon[{{1.321584, 1.075755, -0.012809},{1.322053, 1.074311, -0.006485},{
      1.333466, 1.080126, -0.006485},{1.332573, 1.081355, -0.012809}}],
    Polygon[{{1.322053, 1.074311, -0.006485},{1.322210, 1.073826, 0.000000},{
      1.333766, 1.079713, 0.000000},{1.333466, 1.080126, -0.006485}}],
    Polygon[{{1.322210, 1.073826, 0.000000},{1.322053, 1.074311, 0.006485},{
      1.333466, 1.080126, 0.006485},{1.333766, 1.079713, 0.000000}}],
    Polygon[{{1.322053, 1.074311, 0.006485},{1.321584, 1.075755, 0.012809},{
      1.332573, 1.081355, 0.012809},{1.333466, 1.080126, 0.006485}}],
    Polygon[{{1.321584, 1.075755, 0.012809},{1.320814, 1.078122, 0.018819},{
      1.331110, 1.083369, 0.018819},{1.332573, 1.081355, 0.012809}}],
    Polygon[{{1.320814, 1.078122, 0.018819},{1.319764, 1.081355, 0.024365},{
      1.329113, 1.086118, 0.024365},{1.331110, 1.083369, 0.018819}}],
    Polygon[{{1.319764, 1.081355, 0.024365},{1.318459, 1.085372, 0.029311},{
      1.326630, 1.089536, 0.029311},{1.329113, 1.086118, 0.024365}}],
    Polygon[{{1.318459, 1.085372, 0.029311},{1.316930, 1.090076, 0.033535},{
      1.323722, 1.093537, 0.033535},{1.326630, 1.089536, 0.029311}}],
    Polygon[{{1.316930, 1.090076, 0.033535},{1.315216, 1.095351, 0.036934},{
      1.320462, 1.098024, 0.036934},{1.323722, 1.093537, 0.033535}}],
    Polygon[{{1.315216, 1.095351, 0.036934},{1.313359, 1.101066, 0.039423},{
      1.316930, 1.102886, 0.039423},{1.320462, 1.098024, 0.036934}}],
    Polygon[{{1.313359, 1.101066, 0.039423},{1.311405, 1.107082, 0.040942},{
      1.313213, 1.108003, 0.040942},{1.316930, 1.102886, 0.039423}}],
    Polygon[{{1.313213, 1.108003, -0.040942},{1.316930, 1.102886, -0.039423},{
      1.319764, 1.105720, -0.039423},{1.314647, 1.109437, -0.040942}}],
    Polygon[{{1.316930, 1.102886, -0.039423},{1.320462, 1.098024, -0.036934},{
      1.324626, 1.102187, -0.036934},{1.319764, 1.105720, -0.039423}}],
    Polygon[{{1.320462, 1.098024, -0.036934},{1.323722, 1.093537, -0.033535},{
      1.329113, 1.098927, -0.033535},{1.324626, 1.102187, -0.036934}}],
    Polygon[{{1.323722, 1.093537, -0.033535},{1.326630, 1.089536, -0.029311},{
      1.333114, 1.096020, -0.029311},{1.329113, 1.098927, -0.033535}}],
    Polygon[{{1.326630, 1.089536, -0.029311},{1.329113, 1.086118, -0.024365},{
      1.336532, 1.093537, -0.024365},{1.333114, 1.096020, -0.029311}}],
    Polygon[{{1.329113, 1.086118, -0.024365},{1.331110, 1.083369, -0.018819},{
      1.339281, 1.091540, -0.018819},{1.336532, 1.093537, -0.024365}}],
    Polygon[{{1.331110, 1.083369, -0.018819},{1.332573, 1.081355, -0.012809},{
      1.341295, 1.090076, -0.012809},{1.339281, 1.091540, -0.018819}}],
    Polygon[{{1.332573, 1.081355, -0.012809},{1.333466, 1.080126, -0.006485},{
      1.342523, 1.089184, -0.006485},{1.341295, 1.090076, -0.012809}}],
    Polygon[{{1.333466, 1.080126, -0.006485},{1.333766, 1.079713, 0.000000},{
      1.342936, 1.088884, 0.000000},{1.342523, 1.089184, -0.006485}}],
    Polygon[{{1.333766, 1.079713, 0.000000},{1.333466, 1.080126, 0.006485},{
      1.342523, 1.089184, 0.006485},{1.342936, 1.088884, 0.000000}}],
    Polygon[{{1.333466, 1.080126, 0.006485},{1.332573, 1.081355, 0.012809},{
      1.341295, 1.090076, 0.012809},{1.342523, 1.089184, 0.006485}}],
    Polygon[{{1.332573, 1.081355, 0.012809},{1.331110, 1.083369, 0.018819},{
      1.339281, 1.091540, 0.018819},{1.341295, 1.090076, 0.012809}}],
    Polygon[{{1.331110, 1.083369, 0.018819},{1.329113, 1.086118, 0.024365},{
      1.336532, 1.093537, 0.024365},{1.339281, 1.091540, 0.018819}}],
    Polygon[{{1.329113, 1.086118, 0.024365},{1.326630, 1.089536, 0.029311},{
      1.333114, 1.096020, 0.029311},{1.336532, 1.093537, 0.024365}}],
    Polygon[{{1.326630, 1.089536, 0.029311},{1.323722, 1.093537, 0.033535},{
      1.329113, 1.098927, 0.033535},{1.333114, 1.096020, 0.029311}}],
    Polygon[{{1.323722, 1.093537, 0.033535},{1.320462, 1.098024, 0.036934},{
      1.324626, 1.102187, 0.036934},{1.329113, 1.098927, 0.033535}}],
    Polygon[{{1.320462, 1.098024, 0.036934},{1.316930, 1.102886, 0.039423},{
      1.319764, 1.105720, 0.039423},{1.324626, 1.102187, 0.036934}}],
    Polygon[{{1.316930, 1.102886, 0.039423},{1.313213, 1.108003, 0.040942},{
      1.314647, 1.109437, 0.040942},{1.319764, 1.105720, 0.039423}}],
    Polygon[{{1.314647, 1.109437, -0.040942},{1.319764, 1.105720, -0.039423},{
      1.321584, 1.109290, -0.039423},{1.315568, 1.111245, -0.040942}}],
    Polygon[{{1.319764, 1.105720, -0.039423},{1.324626, 1.102187, -0.036934},{
      1.327299, 1.107433, -0.036934},{1.321584, 1.109290, -0.039423}}],
    Polygon[{{1.324626, 1.102187, -0.036934},{1.329113, 1.098927, -0.033535},{
      1.332573, 1.105720, -0.033535},{1.327299, 1.107433, -0.036934}}],
    Polygon[{{1.329113, 1.098927, -0.033535},{1.333114, 1.096020, -0.029311},{
      1.337277, 1.104191, -0.029311},{1.332573, 1.105720, -0.033535}}],
    Polygon[{{1.333114, 1.096020, -0.029311},{1.336532, 1.093537, -0.024365},{
      1.341295, 1.102886, -0.024365},{1.337277, 1.104191, -0.029311}}],
    Polygon[{{1.336532, 1.093537, -0.024365},{1.339281, 1.091540, -0.018819},{
      1.344527, 1.101835, -0.018819},{1.341295, 1.102886, -0.024365}}],
    Polygon[{{1.339281, 1.091540, -0.018819},{1.341295, 1.090076, -0.012809},{
      1.346895, 1.101066, -0.012809},{1.344527, 1.101835, -0.018819}}],
    Polygon[{{1.341295, 1.090076, -0.012809},{1.342523, 1.089184, -0.006485},{
      1.348339, 1.100597, -0.006485},{1.346895, 1.101066, -0.012809}}],
    Polygon[{{1.342523, 1.089184, -0.006485},{1.342936, 1.088884, 0.000000},{
      1.348824, 1.100439, 0.000000},{1.348339, 1.100597, -0.006485}}],
    Polygon[{{1.342936, 1.088884, 0.000000},{1.342523, 1.089184, 0.006485},{
      1.348339, 1.100597, 0.006485},{1.348824, 1.100439, 0.000000}}],
    Polygon[{{1.342523, 1.089184, 0.006485},{1.341295, 1.090076, 0.012809},{
      1.346895, 1.101066, 0.012809},{1.348339, 1.100597, 0.006485}}],
    Polygon[{{1.341295, 1.090076, 0.012809},{1.339281, 1.091540, 0.018819},{
      1.344527, 1.101835, 0.018819},{1.346895, 1.101066, 0.012809}}],
    Polygon[{{1.339281, 1.091540, 0.018819},{1.336532, 1.093537, 0.024365},{
      1.341295, 1.102886, 0.024365},{1.344527, 1.101835, 0.018819}}],
    Polygon[{{1.336532, 1.093537, 0.024365},{1.333114, 1.096020, 0.029311},{
      1.337277, 1.104191, 0.029311},{1.341295, 1.102886, 0.024365}}],
    Polygon[{{1.333114, 1.096020, 0.029311},{1.329113, 1.098927, 0.033535},{
      1.332573, 1.105720, 0.033535},{1.337277, 1.104191, 0.029311}}],
    Polygon[{{1.329113, 1.098927, 0.033535},{1.324626, 1.102187, 0.036934},{
      1.327299, 1.107433, 0.036934},{1.332573, 1.105720, 0.033535}}],
    Polygon[{{1.324626, 1.102187, 0.036934},{1.319764, 1.105720, 0.039423},{
      1.321584, 1.109290, 0.039423},{1.327299, 1.107433, 0.036934}}],
    Polygon[{{1.319764, 1.105720, 0.039423},{1.314647, 1.109437, 0.040942},{
      1.315568, 1.111245, 0.040942},{1.321584, 1.109290, 0.039423}}],
    Polygon[{{1.315568, 1.111245, -0.040942},{1.321584, 1.109290, -0.039423},{
      1.322210, 1.113249, -0.039423},{1.315886, 1.113249, -0.040942}}],
    Polygon[{{1.321584, 1.109290, -0.039423},{1.327299, 1.107433, -0.036934},{
      1.328220, 1.113249, -0.036934},{1.322210, 1.113249, -0.039423}}],
    Polygon[{{1.327299, 1.107433, -0.036934},{1.332573, 1.105720, -0.033535},{
      1.333766, 1.113249, -0.033535},{1.328220, 1.113249, -0.036934}}],
    Polygon[{{1.332573, 1.105720, -0.033535},{1.337277, 1.104191, -0.029311},{
      1.338712, 1.113249, -0.029311},{1.333766, 1.113249, -0.033535}}],
    Polygon[{{1.337277, 1.104191, -0.029311},{1.341295, 1.102886, -0.024365},{
      1.342936, 1.113249, -0.024365},{1.338712, 1.113249, -0.029311}}],
    Polygon[{{1.341295, 1.102886, -0.024365},{1.344527, 1.101835, -0.018819},{
      1.346335, 1.113249, -0.018819},{1.342936, 1.113249, -0.024365}}],
    Polygon[{{1.344527, 1.101835, -0.018819},{1.346895, 1.101066, -0.012809},{
      1.348824, 1.113249, -0.012809},{1.346335, 1.113249, -0.018819}}],
    Polygon[{{1.346895, 1.101066, -0.012809},{1.348339, 1.100597, -0.006485},{
      1.350343, 1.113249, -0.006485},{1.348824, 1.113249, -0.012809}}],
    Polygon[{{1.348339, 1.100597, -0.006485},{1.348824, 1.100439, 0.000000},{
      1.350853, 1.113249, 0.000000},{1.350343, 1.113249, -0.006485}}],
    Polygon[{{1.348824, 1.100439, 0.000000},{1.348339, 1.100597, 0.006485},{
      1.350343, 1.113249, 0.006485},{1.350853, 1.113249, 0.000000}}],
    Polygon[{{1.348339, 1.100597, 0.006485},{1.346895, 1.101066, 0.012809},{
      1.348824, 1.113249, 0.012809},{1.350343, 1.113249, 0.006485}}],
    Polygon[{{1.346895, 1.101066, 0.012809},{1.344527, 1.101835, 0.018819},{
      1.346335, 1.113249, 0.018819},{1.348824, 1.113249, 0.012809}}],
    Polygon[{{1.344527, 1.101835, 0.018819},{1.341295, 1.102886, 0.024365},{
      1.342936, 1.113249, 0.024365},{1.346335, 1.113249, 0.018819}}],
    Polygon[{{1.341295, 1.102886, 0.024365},{1.337277, 1.104191, 0.029311},{
      1.338712, 1.113249, 0.029311},{1.342936, 1.113249, 0.024365}}],
    Polygon[{{1.337277, 1.104191, 0.029311},{1.332573, 1.105720, 0.033535},{
      1.333766, 1.113249, 0.033535},{1.338712, 1.113249, 0.029311}}],
    Polygon[{{1.332573, 1.105720, 0.033535},{1.327299, 1.107433, 0.036934},{
      1.328220, 1.113249, 0.036934},{1.333766, 1.113249, 0.033535}}],
    Polygon[{{1.327299, 1.107433, 0.036934},{1.321584, 1.109290, 0.039423},{
      1.322210, 1.113249, 0.039423},{1.328220, 1.113249, 0.036934}}],
    Polygon[{{1.321584, 1.109290, 0.039423},{1.315568, 1.111245, 0.040942},{
      1.315886, 1.113249, 0.040942},{1.322210, 1.113249, 0.039423}}],
    Polygon[{{1.359696, 1.064459, -0.025466},{1.363630, 1.064459, -0.024521},{
      1.363240, 1.066921, -0.024521},{1.359498, 1.065705, -0.025466}}],
    Polygon[{{1.363630, 1.064459, -0.024521},{1.367368, 1.064459, -0.022973},{
      1.366795, 1.068076, -0.022973},{1.363240, 1.066921, -0.024521}}],
    Polygon[{{1.367368, 1.064459, -0.022973},{1.370818, 1.064459, -0.020859},{
      1.370076, 1.069142, -0.020859},{1.366795, 1.068076, -0.022973}}],
    Polygon[{{1.370818, 1.064459, -0.020859},{1.373894, 1.064459, -0.018232},{
      1.373002, 1.070092, -0.018232},{1.370076, 1.069142, -0.020859}}],
    Polygon[{{1.373894, 1.064459, -0.018232},{1.376522, 1.064459, -0.015155},{
      1.375501, 1.070904, -0.015155},{1.373002, 1.070092, -0.018232}}],
    Polygon[{{1.376522, 1.064459, -0.015155},{1.378636, 1.064459, -0.011705},{
      1.377511, 1.071558, -0.011705},{1.375501, 1.070904, -0.015155}}],
    Polygon[{{1.378636, 1.064459, -0.011705},{1.380184, 1.064459, -0.007968},{
      1.378984, 1.072036, -0.007968},{1.377511, 1.071558, -0.011705}}],
    Polygon[{{1.380184, 1.064459, -0.007968},{1.381128, 1.064459, -0.004033},{
      1.379882, 1.072328, -0.004033},{1.378984, 1.072036, -0.007968}}],
    Polygon[{{1.381128, 1.064459, -0.004033},{1.381446, 1.064459, 0.000000},{
      1.380184, 1.072426, 0.000000},{1.379882, 1.072328, -0.004033}}],
    Polygon[{{1.381446, 1.064459, 0.000000},{1.381128, 1.064459, 0.004033},{
      1.379882, 1.072328, 0.004033},{1.380184, 1.072426, 0.000000}}],
    Polygon[{{1.381128, 1.064459, 0.004033},{1.380184, 1.064459, 0.007968},{
      1.378984, 1.072036, 0.007968},{1.379882, 1.072328, 0.004033}}],
    Polygon[{{1.380184, 1.064459, 0.007968},{1.378636, 1.064459, 0.011705},{
      1.377511, 1.071558, 0.011705},{1.378984, 1.072036, 0.007968}}],
    Polygon[{{1.378636, 1.064459, 0.011705},{1.376522, 1.064459, 0.015155},{
      1.375501, 1.070904, 0.015155},{1.377511, 1.071558, 0.011705}}],
    Polygon[{{1.376522, 1.064459, 0.015155},{1.373894, 1.064459, 0.018232},{
      1.373002, 1.070092, 0.018232},{1.375501, 1.070904, 0.015155}}],
    Polygon[{{1.373894, 1.064459, 0.018232},{1.370818, 1.064459, 0.020859},{
      1.370076, 1.069142, 0.020859},{1.373002, 1.070092, 0.018232}}],
    Polygon[{{1.370818, 1.064459, 0.020859},{1.367368, 1.064459, 0.022973},{
      1.366795, 1.068076, 0.022973},{1.370076, 1.069142, 0.020859}}],
    Polygon[{{1.367368, 1.064459, 0.022973},{1.363630, 1.064459, 0.024521},{
      1.363240, 1.066921, 0.024521},{1.366795, 1.068076, 0.022973}}],
    Polygon[{{1.363630, 1.064459, 0.024521},{1.359696, 1.064459, 0.025466},{
      1.359498, 1.065705, 0.025466},{1.363240, 1.066921, 0.024521}}],
    Polygon[{{1.359498, 1.065705, -0.025466},{1.363240, 1.066921, -0.024521},{
      1.362108, 1.069142, -0.024521},{1.358926, 1.066829, -0.025466}}],
    Polygon[{{1.363240, 1.066921, -0.024521},{1.366795, 1.068076, -0.022973},{
      1.365132, 1.071339, -0.022973},{1.362108, 1.069142, -0.024521}}],
    Polygon[{{1.366795, 1.068076, -0.022973},{1.370076, 1.069142, -0.020859},{
      1.367923, 1.073367, -0.020859},{1.365132, 1.071339, -0.022973}}],
    Polygon[{{1.370076, 1.069142, -0.020859},{1.373002, 1.070092, -0.018232},{
      1.370412, 1.075175, -0.018232},{1.367923, 1.073367, -0.020859}}],
    Polygon[{{1.373002, 1.070092, -0.018232},{1.375501, 1.070904, -0.015155},{
      1.372538, 1.076719, -0.015155},{1.370412, 1.075175, -0.018232}}],
    Polygon[{{1.375501, 1.070904, -0.015155},{1.377511, 1.071558, -0.011705},{
      1.374248, 1.077962, -0.011705},{1.372538, 1.076719, -0.015155}}],
    Polygon[{{1.377511, 1.071558, -0.011705},{1.378984, 1.072036, -0.007968},{
      1.375501, 1.078872, -0.007968},{1.374248, 1.077962, -0.011705}}],
    Polygon[{{1.378984, 1.072036, -0.007968},{1.379882, 1.072328, -0.004033},{
      1.376265, 1.079427, -0.004033},{1.375501, 1.078872, -0.007968}}],
    Polygon[{{1.379882, 1.072328, -0.004033},{1.380184, 1.072426, 0.000000},{
      1.376522, 1.079614, 0.000000},{1.376265, 1.079427, -0.004033}}],
    Polygon[{{1.380184, 1.072426, 0.000000},{1.379882, 1.072328, 0.004033},{
      1.376265, 1.079427, 0.004033},{1.376522, 1.079614, 0.000000}}],
    Polygon[{{1.379882, 1.072328, 0.004033},{1.378984, 1.072036, 0.007968},{
      1.375501, 1.078872, 0.007968},{1.376265, 1.079427, 0.004033}}],
    Polygon[{{1.378984, 1.072036, 0.007968},{1.377511, 1.071558, 0.011705},{
      1.374248, 1.077962, 0.011705},{1.375501, 1.078872, 0.007968}}],
    Polygon[{{1.377511, 1.071558, 0.011705},{1.375501, 1.070904, 0.015155},{
      1.372538, 1.076719, 0.015155},{1.374248, 1.077962, 0.011705}}],
    Polygon[{{1.375501, 1.070904, 0.015155},{1.373002, 1.070092, 0.018232},{
      1.370412, 1.075175, 0.018232},{1.372538, 1.076719, 0.015155}}],
    Polygon[{{1.373002, 1.070092, 0.018232},{1.370076, 1.069142, 0.020859},{
      1.367923, 1.073367, 0.020859},{1.370412, 1.075175, 0.018232}}],
    Polygon[{{1.370076, 1.069142, 0.020859},{1.366795, 1.068076, 0.022973},{
      1.365132, 1.071339, 0.022973},{1.367923, 1.073367, 0.020859}}],
    Polygon[{{1.366795, 1.068076, 0.022973},{1.363240, 1.066921, 0.024521},{
      1.362108, 1.069142, 0.024521},{1.365132, 1.071339, 0.022973}}],
    Polygon[{{1.363240, 1.066921, 0.024521},{1.359498, 1.065705, 0.025466},{
      1.358926, 1.066829, 0.025466},{1.362108, 1.069142, 0.024521}}],
    Polygon[{{1.358926, 1.066829, -0.025466},{1.362108, 1.069142, -0.024521},{
      1.360346, 1.070904, -0.024521},{1.358033, 1.067722, -0.025466}}],
    Polygon[{{1.362108, 1.069142, -0.024521},{1.365132, 1.071339, -0.022973},{
      1.362543, 1.073928, -0.022973},{1.360346, 1.070904, -0.024521}}],
    Polygon[{{1.365132, 1.071339, -0.022973},{1.367923, 1.073367, -0.020859},{
      1.364570, 1.076719, -0.020859},{1.362543, 1.073928, -0.022973}}],
    Polygon[{{1.367923, 1.073367, -0.020859},{1.370412, 1.075175, -0.018232},{
      1.366379, 1.079208, -0.018232},{1.364570, 1.076719, -0.020859}}],
    Polygon[{{1.370412, 1.075175, -0.018232},{1.372538, 1.076719, -0.015155},{
      1.367923, 1.081334, -0.015155},{1.366379, 1.079208, -0.018232}}],
    Polygon[{{1.372538, 1.076719, -0.015155},{1.374248, 1.077962, -0.011705},{
      1.369166, 1.083044, -0.011705},{1.367923, 1.081334, -0.015155}}],
    Polygon[{{1.374248, 1.077962, -0.011705},{1.375501, 1.078872, -0.007968},{
      1.370076, 1.084297, -0.007968},{1.369166, 1.083044, -0.011705}}],
    Polygon[{{1.375501, 1.078872, -0.007968},{1.376265, 1.079427, -0.004033},{
      1.370631, 1.085061, -0.004033},{1.370076, 1.084297, -0.007968}}],
    Polygon[{{1.376265, 1.079427, -0.004033},{1.376522, 1.079614, 0.000000},{
      1.370818, 1.085318, 0.000000},{1.370631, 1.085061, -0.004033}}],
    Polygon[{{1.376522, 1.079614, 0.000000},{1.376265, 1.079427, 0.004033},{
      1.370631, 1.085061, 0.004033},{1.370818, 1.085318, 0.000000}}],
    Polygon[{{1.376265, 1.079427, 0.004033},{1.375501, 1.078872, 0.007968},{
      1.370076, 1.084297, 0.007968},{1.370631, 1.085061, 0.004033}}],
    Polygon[{{1.375501, 1.078872, 0.007968},{1.374248, 1.077962, 0.011705},{
      1.369166, 1.083044, 0.011705},{1.370076, 1.084297, 0.007968}}],
    Polygon[{{1.374248, 1.077962, 0.011705},{1.372538, 1.076719, 0.015155},{
      1.367923, 1.081334, 0.015155},{1.369166, 1.083044, 0.011705}}],
    Polygon[{{1.372538, 1.076719, 0.015155},{1.370412, 1.075175, 0.018232},{
      1.366379, 1.079208, 0.018232},{1.367923, 1.081334, 0.015155}}],
    Polygon[{{1.370412, 1.075175, 0.018232},{1.367923, 1.073367, 0.020859},{
      1.364570, 1.076719, 0.020859},{1.366379, 1.079208, 0.018232}}],
    Polygon[{{1.367923, 1.073367, 0.020859},{1.365132, 1.071339, 0.022973},{
      1.362543, 1.073928, 0.022973},{1.364570, 1.076719, 0.020859}}],
    Polygon[{{1.365132, 1.071339, 0.022973},{1.362108, 1.069142, 0.024521},{
      1.360346, 1.070904, 0.024521},{1.362543, 1.073928, 0.022973}}],
    Polygon[{{1.362108, 1.069142, 0.024521},{1.358926, 1.066829, 0.025466},{
      1.358033, 1.067722, 0.025466},{1.360346, 1.070904, 0.024521}}],
    Polygon[{{1.358033, 1.067722, -0.025466},{1.360346, 1.070904, -0.024521},{
      1.358124, 1.072036, -0.024521},{1.356909, 1.068295, -0.025466}}],
    Polygon[{{1.360346, 1.070904, -0.024521},{1.362543, 1.073928, -0.022973},{
      1.359280, 1.075591, -0.022973},{1.358124, 1.072036, -0.024521}}],
    Polygon[{{1.362543, 1.073928, -0.022973},{1.364570, 1.076719, -0.020859},{
      1.360346, 1.078872, -0.020859},{1.359280, 1.075591, -0.022973}}],
    Polygon[{{1.364570, 1.076719, -0.020859},{1.366379, 1.079208, -0.018232},{
      1.361296, 1.081798, -0.018232},{1.360346, 1.078872, -0.020859}}],
    Polygon[{{1.366379, 1.079208, -0.018232},{1.367923, 1.081334, -0.015155},{
      1.362108, 1.084297, -0.015155},{1.361296, 1.081798, -0.018232}}],
    Polygon[{{1.367923, 1.081334, -0.015155},{1.369166, 1.083044, -0.011705},{
      1.362761, 1.086307, -0.011705},{1.362108, 1.084297, -0.015155}}],
    Polygon[{{1.369166, 1.083044, -0.011705},{1.370076, 1.084297, -0.007968},{
      1.363240, 1.087780, -0.007968},{1.362761, 1.086307, -0.011705}}],
    Polygon[{{1.370076, 1.084297, -0.007968},{1.370631, 1.085061, -0.004033},{
      1.363532, 1.088678, -0.004033},{1.363240, 1.087780, -0.007968}}],
    Polygon[{{1.370631, 1.085061, -0.004033},{1.370818, 1.085318, 0.000000},{
      1.363630, 1.088980, 0.000000},{1.363532, 1.088678, -0.004033}}],
    Polygon[{{1.370818, 1.085318, 0.000000},{1.370631, 1.085061, 0.004033},{
      1.363532, 1.088678, 0.004033},{1.363630, 1.088980, 0.000000}}],
    Polygon[{{1.370631, 1.085061, 0.004033},{1.370076, 1.084297, 0.007968},{
      1.363240, 1.087780, 0.007968},{1.363532, 1.088678, 0.004033}}],
    Polygon[{{1.370076, 1.084297, 0.007968},{1.369166, 1.083044, 0.011705},{
      1.362761, 1.086307, 0.011705},{1.363240, 1.087780, 0.007968}}],
    Polygon[{{1.369166, 1.083044, 0.011705},{1.367923, 1.081334, 0.015155},{
      1.362108, 1.084297, 0.015155},{1.362761, 1.086307, 0.011705}}],
    Polygon[{{1.367923, 1.081334, 0.015155},{1.366379, 1.079208, 0.018232},{
      1.361296, 1.081798, 0.018232},{1.362108, 1.084297, 0.015155}}],
    Polygon[{{1.366379, 1.079208, 0.018232},{1.364570, 1.076719, 0.020859},{
      1.360346, 1.078872, 0.020859},{1.361296, 1.081798, 0.018232}}],
    Polygon[{{1.364570, 1.076719, 0.020859},{1.362543, 1.073928, 0.022973},{
      1.359280, 1.075591, 0.022973},{1.360346, 1.078872, 0.020859}}],
    Polygon[{{1.362543, 1.073928, 0.022973},{1.360346, 1.070904, 0.024521},{
      1.358124, 1.072036, 0.024521},{1.359280, 1.075591, 0.022973}}],
    Polygon[{{1.360346, 1.070904, 0.024521},{1.358033, 1.067722, 0.025466},{
      1.356909, 1.068295, 0.025466},{1.358124, 1.072036, 0.024521}}],
    Polygon[{{1.356909, 1.068295, -0.025466},{1.358124, 1.072036, -0.024521},{
      1.355662, 1.072426, -0.024521},{1.355662, 1.068492, -0.025466}}],
    Polygon[{{1.358124, 1.072036, -0.024521},{1.359280, 1.075591, -0.022973},{
      1.355662, 1.076164, -0.022973},{1.355662, 1.072426, -0.024521}}],
    Polygon[{{1.359280, 1.075591, -0.022973},{1.360346, 1.078872, -0.020859},{
      1.355662, 1.079614, -0.020859},{1.355662, 1.076164, -0.022973}}],
    Polygon[{{1.360346, 1.078872, -0.020859},{1.361296, 1.081798, -0.018232},{
      1.355662, 1.082690, -0.018232},{1.355662, 1.079614, -0.020859}}],
    Polygon[{{1.361296, 1.081798, -0.018232},{1.362108, 1.084297, -0.015155},{
      1.355662, 1.085318, -0.015155},{1.355662, 1.082690, -0.018232}}],
    Polygon[{{1.362108, 1.084297, -0.015155},{1.362761, 1.086307, -0.011705},{
      1.355662, 1.087432, -0.011705},{1.355662, 1.085318, -0.015155}}],
    Polygon[{{1.362761, 1.086307, -0.011705},{1.363240, 1.087780, -0.007968},{
      1.355662, 1.088980, -0.007968},{1.355662, 1.087432, -0.011705}}],
    Polygon[{{1.363240, 1.087780, -0.007968},{1.363532, 1.088678, -0.004033},{
      1.355662, 1.089925, -0.004033},{1.355662, 1.088980, -0.007968}}],
    Polygon[{{1.363532, 1.088678, -0.004033},{1.363630, 1.088980, 0.000000},{
      1.355662, 1.090242, 0.000000},{1.355662, 1.089925, -0.004033}}],
    Polygon[{{1.363630, 1.088980, 0.000000},{1.363532, 1.088678, 0.004033},{
      1.355662, 1.089925, 0.004033},{1.355662, 1.090242, 0.000000}}],
    Polygon[{{1.363532, 1.088678, 0.004033},{1.363240, 1.087780, 0.007968},{
      1.355662, 1.088980, 0.007968},{1.355662, 1.089925, 0.004033}}],
    Polygon[{{1.363240, 1.087780, 0.007968},{1.362761, 1.086307, 0.011705},{
      1.355662, 1.087432, 0.011705},{1.355662, 1.088980, 0.007968}}],
    Polygon[{{1.362761, 1.086307, 0.011705},{1.362108, 1.084297, 0.015155},{
      1.355662, 1.085318, 0.015155},{1.355662, 1.087432, 0.011705}}],
    Polygon[{{1.362108, 1.084297, 0.015155},{1.361296, 1.081798, 0.018232},{
      1.355662, 1.082690, 0.018232},{1.355662, 1.085318, 0.015155}}],
    Polygon[{{1.361296, 1.081798, 0.018232},{1.360346, 1.078872, 0.020859},{
      1.355662, 1.079614, 0.020859},{1.355662, 1.082690, 0.018232}}],
    Polygon[{{1.360346, 1.078872, 0.020859},{1.359280, 1.075591, 0.022973},{
      1.355662, 1.076164, 0.022973},{1.355662, 1.079614, 0.020859}}],
    Polygon[{{1.359280, 1.075591, 0.022973},{1.358124, 1.072036, 0.024521},{
      1.355662, 1.072426, 0.024521},{1.355662, 1.076164, 0.022973}}],
    Polygon[{{1.358124, 1.072036, 0.024521},{1.356909, 1.068295, 0.025466},{
      1.355662, 1.068492, 0.025466},{1.355662, 1.072426, 0.024521}}],
    Polygon[{{1.355662, 1.068492, -0.025466},{1.355662, 1.072426, -0.024521},{
      1.353200, 1.072036, -0.024521},{1.354416, 1.068295, -0.025466}}],
    Polygon[{{1.355662, 1.072426, -0.024521},{1.355662, 1.076164, -0.022973},{
      1.352045, 1.075591, -0.022973},{1.353200, 1.072036, -0.024521}}],
    Polygon[{{1.355662, 1.076164, -0.022973},{1.355662, 1.079614, -0.020859},{
      1.350979, 1.078872, -0.020859},{1.352045, 1.075591, -0.022973}}],
    Polygon[{{1.355662, 1.079614, -0.020859},{1.355662, 1.082690, -0.018232},{
      1.350029, 1.081798, -0.018232},{1.350979, 1.078872, -0.020859}}],
    Polygon[{{1.355662, 1.082690, -0.018232},{1.355662, 1.085318, -0.015155},{
      1.349217, 1.084297, -0.015155},{1.350029, 1.081798, -0.018232}}],
    Polygon[{{1.355662, 1.085318, -0.015155},{1.355662, 1.087432, -0.011705},{
      1.348563, 1.086307, -0.011705},{1.349217, 1.084297, -0.015155}}],
    Polygon[{{1.355662, 1.087432, -0.011705},{1.355662, 1.088980, -0.007968},{
      1.348085, 1.087780, -0.007968},{1.348563, 1.086307, -0.011705}}],
    Polygon[{{1.355662, 1.088980, -0.007968},{1.355662, 1.089925, -0.004033},{
      1.347793, 1.088678, -0.004033},{1.348085, 1.087780, -0.007968}}],
    Polygon[{{1.355662, 1.089925, -0.004033},{1.355662, 1.090242, 0.000000},{
      1.347695, 1.088980, 0.000000},{1.347793, 1.088678, -0.004033}}],
    Polygon[{{1.355662, 1.090242, 0.000000},{1.355662, 1.089925, 0.004033},{
      1.347793, 1.088678, 0.004033},{1.347695, 1.088980, 0.000000}}],
    Polygon[{{1.355662, 1.089925, 0.004033},{1.355662, 1.088980, 0.007968},{
      1.348085, 1.087780, 0.007968},{1.347793, 1.088678, 0.004033}}],
    Polygon[{{1.355662, 1.088980, 0.007968},{1.355662, 1.087432, 0.011705},{
      1.348563, 1.086307, 0.011705},{1.348085, 1.087780, 0.007968}}],
    Polygon[{{1.355662, 1.087432, 0.011705},{1.355662, 1.085318, 0.015155},{
      1.349217, 1.084297, 0.015155},{1.348563, 1.086307, 0.011705}}],
    Polygon[{{1.355662, 1.085318, 0.015155},{1.355662, 1.082690, 0.018232},{
      1.350029, 1.081798, 0.018232},{1.349217, 1.084297, 0.015155}}],
    Polygon[{{1.355662, 1.082690, 0.018232},{1.355662, 1.079614, 0.020859},{
      1.350979, 1.078872, 0.020859},{1.350029, 1.081798, 0.018232}}],
    Polygon[{{1.355662, 1.079614, 0.020859},{1.355662, 1.076164, 0.022973},{
      1.352045, 1.075591, 0.022973},{1.350979, 1.078872, 0.020859}}],
    Polygon[{{1.355662, 1.076164, 0.022973},{1.355662, 1.072426, 0.024521},{
      1.353200, 1.072036, 0.024521},{1.352045, 1.075591, 0.022973}}],
    Polygon[{{1.355662, 1.072426, 0.024521},{1.355662, 1.068492, 0.025466},{
      1.354416, 1.068295, 0.025466},{1.353200, 1.072036, 0.024521}}],
    Polygon[{{1.354416, 1.068295, -0.025466},{1.353200, 1.072036, -0.024521},{
      1.350979, 1.070904, -0.024521},{1.353292, 1.067722, -0.025466}}],
    Polygon[{{1.353200, 1.072036, -0.024521},{1.352045, 1.075591, -0.022973},{
      1.348782, 1.073928, -0.022973},{1.350979, 1.070904, -0.024521}}],
    Polygon[{{1.352045, 1.075591, -0.022973},{1.350979, 1.078872, -0.020859},{
      1.346754, 1.076719, -0.020859},{1.348782, 1.073928, -0.022973}}],
    Polygon[{{1.350979, 1.078872, -0.020859},{1.350029, 1.081798, -0.018232},{
      1.344946, 1.079208, -0.018232},{1.346754, 1.076719, -0.020859}}],
    Polygon[{{1.350029, 1.081798, -0.018232},{1.349217, 1.084297, -0.015155},{
      1.343402, 1.081334, -0.015155},{1.344946, 1.079208, -0.018232}}],
    Polygon[{{1.349217, 1.084297, -0.015155},{1.348563, 1.086307, -0.011705},{
      1.342159, 1.083044, -0.011705},{1.343402, 1.081334, -0.015155}}],
    Polygon[{{1.348563, 1.086307, -0.011705},{1.348085, 1.087780, -0.007968},{
      1.341249, 1.084297, -0.007968},{1.342159, 1.083044, -0.011705}}],
    Polygon[{{1.348085, 1.087780, -0.007968},{1.347793, 1.088678, -0.004033},{
      1.340694, 1.085061, -0.004033},{1.341249, 1.084297, -0.007968}}],
    Polygon[{{1.347793, 1.088678, -0.004033},{1.347695, 1.088980, 0.000000},{
      1.340507, 1.085318, 0.000000},{1.340694, 1.085061, -0.004033}}],
    Polygon[{{1.347695, 1.088980, 0.000000},{1.347793, 1.088678, 0.004033},{
      1.340694, 1.085061, 0.004033},{1.340507, 1.085318, 0.000000}}],
    Polygon[{{1.347793, 1.088678, 0.004033},{1.348085, 1.087780, 0.007968},{
      1.341249, 1.084297, 0.007968},{1.340694, 1.085061, 0.004033}}],
    Polygon[{{1.348085, 1.087780, 0.007968},{1.348563, 1.086307, 0.011705},{
      1.342159, 1.083044, 0.011705},{1.341249, 1.084297, 0.007968}}],
    Polygon[{{1.348563, 1.086307, 0.011705},{1.349217, 1.084297, 0.015155},{
      1.343402, 1.081334, 0.015155},{1.342159, 1.083044, 0.011705}}],
    Polygon[{{1.349217, 1.084297, 0.015155},{1.350029, 1.081798, 0.018232},{
      1.344946, 1.079208, 0.018232},{1.343402, 1.081334, 0.015155}}],
    Polygon[{{1.350029, 1.081798, 0.018232},{1.350979, 1.078872, 0.020859},{
      1.346754, 1.076719, 0.020859},{1.344946, 1.079208, 0.018232}}],
    Polygon[{{1.350979, 1.078872, 0.020859},{1.352045, 1.075591, 0.022973},{
      1.348782, 1.073928, 0.022973},{1.346754, 1.076719, 0.020859}}],
    Polygon[{{1.352045, 1.075591, 0.022973},{1.353200, 1.072036, 0.024521},{
      1.350979, 1.070904, 0.024521},{1.348782, 1.073928, 0.022973}}],
    Polygon[{{1.353200, 1.072036, 0.024521},{1.354416, 1.068295, 0.025466},{
      1.353292, 1.067722, 0.025466},{1.350979, 1.070904, 0.024521}}],
    Polygon[{{1.353292, 1.067722, -0.025466},{1.350979, 1.070904, -0.024521},{
      1.349217, 1.069142, -0.024521},{1.352399, 1.066829, -0.025466}}],
    Polygon[{{1.350979, 1.070904, -0.024521},{1.348782, 1.073928, -0.022973},{
      1.346193, 1.071339, -0.022973},{1.349217, 1.069142, -0.024521}}],
    Polygon[{{1.348782, 1.073928, -0.022973},{1.346754, 1.076719, -0.020859},{
      1.343402, 1.073367, -0.020859},{1.346193, 1.071339, -0.022973}}],
    Polygon[{{1.346754, 1.076719, -0.020859},{1.344946, 1.079208, -0.018232},{
      1.340913, 1.075175, -0.018232},{1.343402, 1.073367, -0.020859}}],
    Polygon[{{1.344946, 1.079208, -0.018232},{1.343402, 1.081334, -0.015155},{
      1.338787, 1.076719, -0.015155},{1.340913, 1.075175, -0.018232}}],
    Polygon[{{1.343402, 1.081334, -0.015155},{1.342159, 1.083044, -0.011705},{
      1.337077, 1.077962, -0.011705},{1.338787, 1.076719, -0.015155}}],
    Polygon[{{1.342159, 1.083044, -0.011705},{1.341249, 1.084297, -0.007968},{
      1.335824, 1.078872, -0.007968},{1.337077, 1.077962, -0.011705}}],
    Polygon[{{1.341249, 1.084297, -0.007968},{1.340694, 1.085061, -0.004033},{
      1.335060, 1.079427, -0.004033},{1.335824, 1.078872, -0.007968}}],
    Polygon[{{1.340694, 1.085061, -0.004033},{1.340507, 1.085318, 0.000000},{
      1.334803, 1.079614, 0.000000},{1.335060, 1.079427, -0.004033}}],
    Polygon[{{1.340507, 1.085318, 0.000000},{1.340694, 1.085061, 0.004033},{
      1.335060, 1.079427, 0.004033},{1.334803, 1.079614, 0.000000}}],
    Polygon[{{1.340694, 1.085061, 0.004033},{1.341249, 1.084297, 0.007968},{
      1.335824, 1.078872, 0.007968},{1.335060, 1.079427, 0.004033}}],
    Polygon[{{1.341249, 1.084297, 0.007968},{1.342159, 1.083044, 0.011705},{
      1.337077, 1.077962, 0.011705},{1.335824, 1.078872, 0.007968}}],
    Polygon[{{1.342159, 1.083044, 0.011705},{1.343402, 1.081334, 0.015155},{
      1.338787, 1.076719, 0.015155},{1.337077, 1.077962, 0.011705}}],
    Polygon[{{1.343402, 1.081334, 0.015155},{1.344946, 1.079208, 0.018232},{
      1.340913, 1.075175, 0.018232},{1.338787, 1.076719, 0.015155}}],
    Polygon[{{1.344946, 1.079208, 0.018232},{1.346754, 1.076719, 0.020859},{
      1.343402, 1.073367, 0.020859},{1.340913, 1.075175, 0.018232}}],
    Polygon[{{1.346754, 1.076719, 0.020859},{1.348782, 1.073928, 0.022973},{
      1.346193, 1.071339, 0.022973},{1.343402, 1.073367, 0.020859}}],
    Polygon[{{1.348782, 1.073928, 0.022973},{1.350979, 1.070904, 0.024521},{
      1.349217, 1.069142, 0.024521},{1.346193, 1.071339, 0.022973}}],
    Polygon[{{1.350979, 1.070904, 0.024521},{1.353292, 1.067722, 0.025466},{
      1.352399, 1.066829, 0.025466},{1.349217, 1.069142, 0.024521}}],
    Polygon[{{1.352399, 1.066829, -0.025466},{1.349217, 1.069142, -0.024521},{
      1.348085, 1.066921, -0.024521},{1.351826, 1.065705, -0.025466}}],
    Polygon[{{1.349217, 1.069142, -0.024521},{1.346193, 1.071339, -0.022973},{
      1.344530, 1.068076, -0.022973},{1.348085, 1.066921, -0.024521}}],
    Polygon[{{1.346193, 1.071339, -0.022973},{1.343402, 1.073367, -0.020859},{
      1.341249, 1.069142, -0.020859},{1.344530, 1.068076, -0.022973}}],
    Polygon[{{1.343402, 1.073367, -0.020859},{1.340913, 1.075175, -0.018232},{
      1.338323, 1.070092, -0.018232},{1.341249, 1.069142, -0.020859}}],
    Polygon[{{1.340913, 1.075175, -0.018232},{1.338787, 1.076719, -0.015155},{
      1.335824, 1.070904, -0.015155},{1.338323, 1.070092, -0.018232}}],
    Polygon[{{1.338787, 1.076719, -0.015155},{1.337077, 1.077962, -0.011705},{
      1.333814, 1.071558, -0.011705},{1.335824, 1.070904, -0.015155}}],
    Polygon[{{1.337077, 1.077962, -0.011705},{1.335824, 1.078872, -0.007968},{
      1.332341, 1.072036, -0.007968},{1.333814, 1.071558, -0.011705}}],
    Polygon[{{1.335824, 1.078872, -0.007968},{1.335060, 1.079427, -0.004033},{
      1.331443, 1.072328, -0.004033},{1.332341, 1.072036, -0.007968}}],
    Polygon[{{1.335060, 1.079427, -0.004033},{1.334803, 1.079614, 0.000000},{
      1.331141, 1.072426, 0.000000},{1.331443, 1.072328, -0.004033}}],
    Polygon[{{1.334803, 1.079614, 0.000000},{1.335060, 1.079427, 0.004033},{
      1.331443, 1.072328, 0.004033},{1.331141, 1.072426, 0.000000}}],
    Polygon[{{1.335060, 1.079427, 0.004033},{1.335824, 1.078872, 0.007968},{
      1.332341, 1.072036, 0.007968},{1.331443, 1.072328, 0.004033}}],
    Polygon[{{1.335824, 1.078872, 0.007968},{1.337077, 1.077962, 0.011705},{
      1.333814, 1.071558, 0.011705},{1.332341, 1.072036, 0.007968}}],
    Polygon[{{1.337077, 1.077962, 0.011705},{1.338787, 1.076719, 0.015155},{
      1.335824, 1.070904, 0.015155},{1.333814, 1.071558, 0.011705}}],
    Polygon[{{1.338787, 1.076719, 0.015155},{1.340913, 1.075175, 0.018232},{
      1.338323, 1.070092, 0.018232},{1.335824, 1.070904, 0.015155}}],
    Polygon[{{1.340913, 1.075175, 0.018232},{1.343402, 1.073367, 0.020859},{
      1.341249, 1.069142, 0.020859},{1.338323, 1.070092, 0.018232}}],
    Polygon[{{1.343402, 1.073367, 0.020859},{1.346193, 1.071339, 0.022973},{
      1.344530, 1.068076, 0.022973},{1.341249, 1.069142, 0.020859}}],
    Polygon[{{1.346193, 1.071339, 0.022973},{1.349217, 1.069142, 0.024521},{
      1.348085, 1.066921, 0.024521},{1.344530, 1.068076, 0.022973}}],
    Polygon[{{1.349217, 1.069142, 0.024521},{1.352399, 1.066829, 0.025466},{
      1.351826, 1.065705, 0.025466},{1.348085, 1.066921, 0.024521}}],
    Polygon[{{1.351826, 1.065705, -0.025466},{1.348085, 1.066921, -0.024521},{
      1.347695, 1.064459, -0.024521},{1.351629, 1.064459, -0.025466}}],
    Polygon[{{1.348085, 1.066921, -0.024521},{1.344530, 1.068076, -0.022973},{
      1.343957, 1.064459, -0.022973},{1.347695, 1.064459, -0.024521}}],
    Polygon[{{1.344530, 1.068076, -0.022973},{1.341249, 1.069142, -0.020859},{
      1.340507, 1.064459, -0.020859},{1.343957, 1.064459, -0.022973}}],
    Polygon[{{1.341249, 1.069142, -0.020859},{1.338323, 1.070092, -0.018232},{
      1.337431, 1.064459, -0.018232},{1.340507, 1.064459, -0.020859}}],
    Polygon[{{1.338323, 1.070092, -0.018232},{1.335824, 1.070904, -0.015155},{
      1.334803, 1.064459, -0.015155},{1.337431, 1.064459, -0.018232}}],
    Polygon[{{1.335824, 1.070904, -0.015155},{1.333814, 1.071558, -0.011705},{
      1.332689, 1.064459, -0.011705},{1.334803, 1.064459, -0.015155}}],
    Polygon[{{1.333814, 1.071558, -0.011705},{1.332341, 1.072036, -0.007968},{
      1.331141, 1.064459, -0.007968},{1.332689, 1.064459, -0.011705}}],
    Polygon[{{1.332341, 1.072036, -0.007968},{1.331443, 1.072328, -0.004033},{
      1.330196, 1.064459, -0.004033},{1.331141, 1.064459, -0.007968}}],
    Polygon[{{1.331443, 1.072328, -0.004033},{1.331141, 1.072426, 0.000000},{
      1.329879, 1.064459, 0.000000},{1.330196, 1.064459, -0.004033}}],
    Polygon[{{1.331141, 1.072426, 0.000000},{1.331443, 1.072328, 0.004033},{
      1.330196, 1.064459, 0.004033},{1.329879, 1.064459, 0.000000}}],
    Polygon[{{1.331443, 1.072328, 0.004033},{1.332341, 1.072036, 0.007968},{
      1.331141, 1.064459, 0.007968},{1.330196, 1.064459, 0.004033}}],
    Polygon[{{1.332341, 1.072036, 0.007968},{1.333814, 1.071558, 0.011705},{
      1.332689, 1.064459, 0.011705},{1.331141, 1.064459, 0.007968}}],
    Polygon[{{1.333814, 1.071558, 0.011705},{1.335824, 1.070904, 0.015155},{
      1.334803, 1.064459, 0.015155},{1.332689, 1.064459, 0.011705}}],
    Polygon[{{1.335824, 1.070904, 0.015155},{1.338323, 1.070092, 0.018232},{
      1.337431, 1.064459, 0.018232},{1.334803, 1.064459, 0.015155}}],
    Polygon[{{1.338323, 1.070092, 0.018232},{1.341249, 1.069142, 0.020859},{
      1.340507, 1.064459, 0.020859},{1.337431, 1.064459, 0.018232}}],
    Polygon[{{1.341249, 1.069142, 0.020859},{1.344530, 1.068076, 0.022973},{
      1.343957, 1.064459, 0.022973},{1.340507, 1.064459, 0.020859}}],
    Polygon[{{1.344530, 1.068076, 0.022973},{1.348085, 1.066921, 0.024521},{
      1.347695, 1.064459, 0.024521},{1.343957, 1.064459, 0.022973}}],
    Polygon[{{1.348085, 1.066921, 0.024521},{1.351826, 1.065705, 0.025466},{
      1.351629, 1.064459, 0.025466},{1.347695, 1.064459, 0.024521}}],
    Polygon[{{1.351629, 1.064459, -0.025466},{1.347695, 1.064459, -0.024521},{
      1.348085, 1.061996, -0.024521},{1.351826, 1.063212, -0.025466}}],
    Polygon[{{1.347695, 1.064459, -0.024521},{1.343957, 1.064459, -0.022973},{
      1.344530, 1.060841, -0.022973},{1.348085, 1.061996, -0.024521}}],
    Polygon[{{1.343957, 1.064459, -0.022973},{1.340507, 1.064459, -0.020859},{
      1.341249, 1.059775, -0.020859},{1.344530, 1.060841, -0.022973}}],
    Polygon[{{1.340507, 1.064459, -0.020859},{1.337431, 1.064459, -0.018232},{
      1.338323, 1.058825, -0.018232},{1.341249, 1.059775, -0.020859}}],
    Polygon[{{1.337431, 1.064459, -0.018232},{1.334803, 1.064459, -0.015155},{
      1.335824, 1.058013, -0.015155},{1.338323, 1.058825, -0.018232}}],
    Polygon[{{1.334803, 1.064459, -0.015155},{1.332689, 1.064459, -0.011705},{
      1.333814, 1.057359, -0.011705},{1.335824, 1.058013, -0.015155}}],
    Polygon[{{1.332689, 1.064459, -0.011705},{1.331141, 1.064459, -0.007968},{
      1.332341, 1.056881, -0.007968},{1.333814, 1.057359, -0.011705}}],
    Polygon[{{1.331141, 1.064459, -0.007968},{1.330196, 1.064459, -0.004033},{
      1.331443, 1.056589, -0.004033},{1.332341, 1.056881, -0.007968}}],
    Polygon[{{1.330196, 1.064459, -0.004033},{1.329879, 1.064459, 0.000000},{
      1.331141, 1.056491, 0.000000},{1.331443, 1.056589, -0.004033}}],
    Polygon[{{1.329879, 1.064459, 0.000000},{1.330196, 1.064459, 0.004033},{
      1.331443, 1.056589, 0.004033},{1.331141, 1.056491, 0.000000}}],
    Polygon[{{1.330196, 1.064459, 0.004033},{1.331141, 1.064459, 0.007968},{
      1.332341, 1.056881, 0.007968},{1.331443, 1.056589, 0.004033}}],
    Polygon[{{1.331141, 1.064459, 0.007968},{1.332689, 1.064459, 0.011705},{
      1.333814, 1.057359, 0.011705},{1.332341, 1.056881, 0.007968}}],
    Polygon[{{1.332689, 1.064459, 0.011705},{1.334803, 1.064459, 0.015155},{
      1.335824, 1.058013, 0.015155},{1.333814, 1.057359, 0.011705}}],
    Polygon[{{1.334803, 1.064459, 0.015155},{1.337431, 1.064459, 0.018232},{
      1.338323, 1.058825, 0.018232},{1.335824, 1.058013, 0.015155}}],
    Polygon[{{1.337431, 1.064459, 0.018232},{1.340507, 1.064459, 0.020859},{
      1.341249, 1.059775, 0.020859},{1.338323, 1.058825, 0.018232}}],
    Polygon[{{1.340507, 1.064459, 0.020859},{1.343957, 1.064459, 0.022973},{
      1.344530, 1.060841, 0.022973},{1.341249, 1.059775, 0.020859}}],
    Polygon[{{1.343957, 1.064459, 0.022973},{1.347695, 1.064459, 0.024521},{
      1.348085, 1.061996, 0.024521},{1.344530, 1.060841, 0.022973}}],
    Polygon[{{1.347695, 1.064459, 0.024521},{1.351629, 1.064459, 0.025466},{
      1.351826, 1.063212, 0.025466},{1.348085, 1.061996, 0.024521}}],
    Polygon[{{1.351826, 1.063212, -0.025466},{1.348085, 1.061996, -0.024521},{
      1.349217, 1.059775, -0.024521},{1.352399, 1.062088, -0.025466}}],
    Polygon[{{1.348085, 1.061996, -0.024521},{1.344530, 1.060841, -0.022973},{
      1.346193, 1.057578, -0.022973},{1.349217, 1.059775, -0.024521}}],
    Polygon[{{1.344530, 1.060841, -0.022973},{1.341249, 1.059775, -0.020859},{
      1.343402, 1.055551, -0.020859},{1.346193, 1.057578, -0.022973}}],
    Polygon[{{1.341249, 1.059775, -0.020859},{1.338323, 1.058825, -0.018232},{
      1.340913, 1.053742, -0.018232},{1.343402, 1.055551, -0.020859}}],
    Polygon[{{1.338323, 1.058825, -0.018232},{1.335824, 1.058013, -0.015155},{
      1.338787, 1.052198, -0.015155},{1.340913, 1.053742, -0.018232}}],
    Polygon[{{1.335824, 1.058013, -0.015155},{1.333814, 1.057359, -0.011705},{
      1.337077, 1.050955, -0.011705},{1.338787, 1.052198, -0.015155}}],
    Polygon[{{1.333814, 1.057359, -0.011705},{1.332341, 1.056881, -0.007968},{
      1.335824, 1.050045, -0.007968},{1.337077, 1.050955, -0.011705}}],
    Polygon[{{1.332341, 1.056881, -0.007968},{1.331443, 1.056589, -0.004033},{
      1.335060, 1.049490, -0.004033},{1.335824, 1.050045, -0.007968}}],
    Polygon[{{1.331443, 1.056589, -0.004033},{1.331141, 1.056491, 0.000000},{
      1.334803, 1.049303, 0.000000},{1.335060, 1.049490, -0.004033}}],
    Polygon[{{1.331141, 1.056491, 0.000000},{1.331443, 1.056589, 0.004033},{
      1.335060, 1.049490, 0.004033},{1.334803, 1.049303, 0.000000}}],
    Polygon[{{1.331443, 1.056589, 0.004033},{1.332341, 1.056881, 0.007968},{
      1.335824, 1.050045, 0.007968},{1.335060, 1.049490, 0.004033}}],
    Polygon[{{1.332341, 1.056881, 0.007968},{1.333814, 1.057359, 0.011705},{
      1.337077, 1.050955, 0.011705},{1.335824, 1.050045, 0.007968}}],
    Polygon[{{1.333814, 1.057359, 0.011705},{1.335824, 1.058013, 0.015155},{
      1.338787, 1.052198, 0.015155},{1.337077, 1.050955, 0.011705}}],
    Polygon[{{1.335824, 1.058013, 0.015155},{1.338323, 1.058825, 0.018232},{
      1.340913, 1.053742, 0.018232},{1.338787, 1.052198, 0.015155}}],
    Polygon[{{1.338323, 1.058825, 0.018232},{1.341249, 1.059775, 0.020859},{
      1.343402, 1.055551, 0.020859},{1.340913, 1.053742, 0.018232}}],
    Polygon[{{1.341249, 1.059775, 0.020859},{1.344530, 1.060841, 0.022973},{
      1.346193, 1.057578, 0.022973},{1.343402, 1.055551, 0.020859}}],
    Polygon[{{1.344530, 1.060841, 0.022973},{1.348085, 1.061996, 0.024521},{
      1.349217, 1.059775, 0.024521},{1.346193, 1.057578, 0.022973}}],
    Polygon[{{1.348085, 1.061996, 0.024521},{1.351826, 1.063212, 0.025466},{
      1.352399, 1.062088, 0.025466},{1.349217, 1.059775, 0.024521}}],
    Polygon[{{1.352399, 1.062088, -0.025466},{1.349217, 1.059775, -0.024521},{
      1.350979, 1.058013, -0.024521},{1.353292, 1.061195, -0.025466}}],
    Polygon[{{1.349217, 1.059775, -0.024521},{1.346193, 1.057578, -0.022973},{
      1.348782, 1.054989, -0.022973},{1.350979, 1.058013, -0.024521}}],
    Polygon[{{1.346193, 1.057578, -0.022973},{1.343402, 1.055551, -0.020859},{
      1.346754, 1.052198, -0.020859},{1.348782, 1.054989, -0.022973}}],
    Polygon[{{1.343402, 1.055551, -0.020859},{1.340913, 1.053742, -0.018232},{
      1.344946, 1.049709, -0.018232},{1.346754, 1.052198, -0.020859}}],
    Polygon[{{1.340913, 1.053742, -0.018232},{1.338787, 1.052198, -0.015155},{
      1.343402, 1.047583, -0.015155},{1.344946, 1.049709, -0.018232}}],
    Polygon[{{1.338787, 1.052198, -0.015155},{1.337077, 1.050955, -0.011705},{
      1.342159, 1.045873, -0.011705},{1.343402, 1.047583, -0.015155}}],
    Polygon[{{1.337077, 1.050955, -0.011705},{1.335824, 1.050045, -0.007968},{
      1.341249, 1.044620, -0.007968},{1.342159, 1.045873, -0.011705}}],
    Polygon[{{1.335824, 1.050045, -0.007968},{1.335060, 1.049490, -0.004033},{
      1.340694, 1.043856, -0.004033},{1.341249, 1.044620, -0.007968}}],
    Polygon[{{1.335060, 1.049490, -0.004033},{1.334803, 1.049303, 0.000000},{
      1.340507, 1.043599, 0.000000},{1.340694, 1.043856, -0.004033}}],
    Polygon[{{1.334803, 1.049303, 0.000000},{1.335060, 1.049490, 0.004033},{
      1.340694, 1.043856, 0.004033},{1.340507, 1.043599, 0.000000}}],
    Polygon[{{1.335060, 1.049490, 0.004033},{1.335824, 1.050045, 0.007968},{
      1.341249, 1.044620, 0.007968},{1.340694, 1.043856, 0.004033}}],
    Polygon[{{1.335824, 1.050045, 0.007968},{1.337077, 1.050955, 0.011705},{
      1.342159, 1.045873, 0.011705},{1.341249, 1.044620, 0.007968}}],
    Polygon[{{1.337077, 1.050955, 0.011705},{1.338787, 1.052198, 0.015155},{
      1.343402, 1.047583, 0.015155},{1.342159, 1.045873, 0.011705}}],
    Polygon[{{1.338787, 1.052198, 0.015155},{1.340913, 1.053742, 0.018232},{
      1.344946, 1.049709, 0.018232},{1.343402, 1.047583, 0.015155}}],
    Polygon[{{1.340913, 1.053742, 0.018232},{1.343402, 1.055551, 0.020859},{
      1.346754, 1.052198, 0.020859},{1.344946, 1.049709, 0.018232}}],
    Polygon[{{1.343402, 1.055551, 0.020859},{1.346193, 1.057578, 0.022973},{
      1.348782, 1.054989, 0.022973},{1.346754, 1.052198, 0.020859}}],
    Polygon[{{1.346193, 1.057578, 0.022973},{1.349217, 1.059775, 0.024521},{
      1.350979, 1.058013, 0.024521},{1.348782, 1.054989, 0.022973}}],
    Polygon[{{1.349217, 1.059775, 0.024521},{1.352399, 1.062088, 0.025466},{
      1.353292, 1.061195, 0.025466},{1.350979, 1.058013, 0.024521}}],
    Polygon[{{1.353292, 1.061195, -0.025466},{1.350979, 1.058013, -0.024521},{
      1.353200, 1.056881, -0.024521},{1.354416, 1.060623, -0.025466}}],
    Polygon[{{1.350979, 1.058013, -0.024521},{1.348782, 1.054989, -0.022973},{
      1.352045, 1.053326, -0.022973},{1.353200, 1.056881, -0.024521}}],
    Polygon[{{1.348782, 1.054989, -0.022973},{1.346754, 1.052198, -0.020859},{
      1.350979, 1.050045, -0.020859},{1.352045, 1.053326, -0.022973}}],
    Polygon[{{1.346754, 1.052198, -0.020859},{1.344946, 1.049709, -0.018232},{
      1.350029, 1.047119, -0.018232},{1.350979, 1.050045, -0.020859}}],
    Polygon[{{1.344946, 1.049709, -0.018232},{1.343402, 1.047583, -0.015155},{
      1.349217, 1.044620, -0.015155},{1.350029, 1.047119, -0.018232}}],
    Polygon[{{1.343402, 1.047583, -0.015155},{1.342159, 1.045873, -0.011705},{
      1.348563, 1.042610, -0.011705},{1.349217, 1.044620, -0.015155}}],
    Polygon[{{1.342159, 1.045873, -0.011705},{1.341249, 1.044620, -0.007968},{
      1.348085, 1.041137, -0.007968},{1.348563, 1.042610, -0.011705}}],
    Polygon[{{1.341249, 1.044620, -0.007968},{1.340694, 1.043856, -0.004033},{
      1.347793, 1.040239, -0.004033},{1.348085, 1.041137, -0.007968}}],
    Polygon[{{1.340694, 1.043856, -0.004033},{1.340507, 1.043599, 0.000000},{
      1.347695, 1.039937, 0.000000},{1.347793, 1.040239, -0.004033}}],
    Polygon[{{1.340507, 1.043599, 0.000000},{1.340694, 1.043856, 0.004033},{
      1.347793, 1.040239, 0.004033},{1.347695, 1.039937, 0.000000}}],
    Polygon[{{1.340694, 1.043856, 0.004033},{1.341249, 1.044620, 0.007968},{
      1.348085, 1.041137, 0.007968},{1.347793, 1.040239, 0.004033}}],
    Polygon[{{1.341249, 1.044620, 0.007968},{1.342159, 1.045873, 0.011705},{
      1.348563, 1.042610, 0.011705},{1.348085, 1.041137, 0.007968}}],
    Polygon[{{1.342159, 1.045873, 0.011705},{1.343402, 1.047583, 0.015155},{
      1.349217, 1.044620, 0.015155},{1.348563, 1.042610, 0.011705}}],
    Polygon[{{1.343402, 1.047583, 0.015155},{1.344946, 1.049709, 0.018232},{
      1.350029, 1.047119, 0.018232},{1.349217, 1.044620, 0.015155}}],
    Polygon[{{1.344946, 1.049709, 0.018232},{1.346754, 1.052198, 0.020859},{
      1.350979, 1.050045, 0.020859},{1.350029, 1.047119, 0.018232}}],
    Polygon[{{1.346754, 1.052198, 0.020859},{1.348782, 1.054989, 0.022973},{
      1.352045, 1.053326, 0.022973},{1.350979, 1.050045, 0.020859}}],
    Polygon[{{1.348782, 1.054989, 0.022973},{1.350979, 1.058013, 0.024521},{
      1.353200, 1.056881, 0.024521},{1.352045, 1.053326, 0.022973}}],
    Polygon[{{1.350979, 1.058013, 0.024521},{1.353292, 1.061195, 0.025466},{
      1.354416, 1.060623, 0.025466},{1.353200, 1.056881, 0.024521}}],
    Polygon[{{1.354416, 1.060623, -0.025466},{1.353200, 1.056881, -0.024521},{
      1.355662, 1.056491, -0.024521},{1.355662, 1.060425, -0.025466}}],
    Polygon[{{1.353200, 1.056881, -0.024521},{1.352045, 1.053326, -0.022973},{
      1.355662, 1.052753, -0.022973},{1.355662, 1.056491, -0.024521}}],
    Polygon[{{1.352045, 1.053326, -0.022973},{1.350979, 1.050045, -0.020859},{
      1.355662, 1.049303, -0.020859},{1.355662, 1.052753, -0.022973}}],
    Polygon[{{1.350979, 1.050045, -0.020859},{1.350029, 1.047119, -0.018232},{
      1.355662, 1.046227, -0.018232},{1.355662, 1.049303, -0.020859}}],
    Polygon[{{1.350029, 1.047119, -0.018232},{1.349217, 1.044620, -0.015155},{
      1.355662, 1.043599, -0.015155},{1.355662, 1.046227, -0.018232}}],
    Polygon[{{1.349217, 1.044620, -0.015155},{1.348563, 1.042610, -0.011705},{
      1.355662, 1.041485, -0.011705},{1.355662, 1.043599, -0.015155}}],
    Polygon[{{1.348563, 1.042610, -0.011705},{1.348085, 1.041137, -0.007968},{
      1.355662, 1.039937, -0.007968},{1.355662, 1.041485, -0.011705}}],
    Polygon[{{1.348085, 1.041137, -0.007968},{1.347793, 1.040239, -0.004033},{
      1.355662, 1.038993, -0.004033},{1.355662, 1.039937, -0.007968}}],
    Polygon[{{1.347793, 1.040239, -0.004033},{1.347695, 1.039937, 0.000000},{
      1.355662, 1.038675, 0.000000},{1.355662, 1.038993, -0.004033}}],
    Polygon[{{1.347695, 1.039937, 0.000000},{1.347793, 1.040239, 0.004033},{
      1.355662, 1.038993, 0.004033},{1.355662, 1.038675, 0.000000}}],
    Polygon[{{1.347793, 1.040239, 0.004033},{1.348085, 1.041137, 0.007968},{
      1.355662, 1.039937, 0.007968},{1.355662, 1.038993, 0.004033}}],
    Polygon[{{1.348085, 1.041137, 0.007968},{1.348563, 1.042610, 0.011705},{
      1.355662, 1.041485, 0.011705},{1.355662, 1.039937, 0.007968}}],
    Polygon[{{1.348563, 1.042610, 0.011705},{1.349217, 1.044620, 0.015155},{
      1.355662, 1.043599, 0.015155},{1.355662, 1.041485, 0.011705}}],
    Polygon[{{1.349217, 1.044620, 0.015155},{1.350029, 1.047119, 0.018232},{
      1.355662, 1.046227, 0.018232},{1.355662, 1.043599, 0.015155}}],
    Polygon[{{1.350029, 1.047119, 0.018232},{1.350979, 1.050045, 0.020859},{
      1.355662, 1.049303, 0.020859},{1.355662, 1.046227, 0.018232}}],
    Polygon[{{1.350979, 1.050045, 0.020859},{1.352045, 1.053326, 0.022973},{
      1.355662, 1.052753, 0.022973},{1.355662, 1.049303, 0.020859}}],
    Polygon[{{1.352045, 1.053326, 0.022973},{1.353200, 1.056881, 0.024521},{
      1.355662, 1.056491, 0.024521},{1.355662, 1.052753, 0.022973}}],
    Polygon[{{1.353200, 1.056881, 0.024521},{1.354416, 1.060623, 0.025466},{
      1.355662, 1.060425, 0.025466},{1.355662, 1.056491, 0.024521}}],
    Polygon[{{1.355662, 1.060425, -0.025466},{1.355662, 1.056491, -0.024521},{
      1.358124, 1.056881, -0.024521},{1.356909, 1.060623, -0.025466}}],
    Polygon[{{1.355662, 1.056491, -0.024521},{1.355662, 1.052753, -0.022973},{
      1.359280, 1.053326, -0.022973},{1.358124, 1.056881, -0.024521}}],
    Polygon[{{1.355662, 1.052753, -0.022973},{1.355662, 1.049303, -0.020859},{
      1.360346, 1.050045, -0.020859},{1.359280, 1.053326, -0.022973}}],
    Polygon[{{1.355662, 1.049303, -0.020859},{1.355662, 1.046227, -0.018232},{
      1.361296, 1.047119, -0.018232},{1.360346, 1.050045, -0.020859}}],
    Polygon[{{1.355662, 1.046227, -0.018232},{1.355662, 1.043599, -0.015155},{
      1.362108, 1.044620, -0.015155},{1.361296, 1.047119, -0.018232}}],
    Polygon[{{1.355662, 1.043599, -0.015155},{1.355662, 1.041485, -0.011705},{
      1.362761, 1.042610, -0.011705},{1.362108, 1.044620, -0.015155}}],
    Polygon[{{1.355662, 1.041485, -0.011705},{1.355662, 1.039937, -0.007968},{
      1.363240, 1.041137, -0.007968},{1.362761, 1.042610, -0.011705}}],
    Polygon[{{1.355662, 1.039937, -0.007968},{1.355662, 1.038993, -0.004033},{
      1.363532, 1.040239, -0.004033},{1.363240, 1.041137, -0.007968}}],
    Polygon[{{1.355662, 1.038993, -0.004033},{1.355662, 1.038675, 0.000000},{
      1.363630, 1.039937, 0.000000},{1.363532, 1.040239, -0.004033}}],
    Polygon[{{1.355662, 1.038675, 0.000000},{1.355662, 1.038993, 0.004033},{
      1.363532, 1.040239, 0.004033},{1.363630, 1.039937, 0.000000}}],
    Polygon[{{1.355662, 1.038993, 0.004033},{1.355662, 1.039937, 0.007968},{
      1.363240, 1.041137, 0.007968},{1.363532, 1.040239, 0.004033}}],
    Polygon[{{1.355662, 1.039937, 0.007968},{1.355662, 1.041485, 0.011705},{
      1.362761, 1.042610, 0.011705},{1.363240, 1.041137, 0.007968}}],
    Polygon[{{1.355662, 1.041485, 0.011705},{1.355662, 1.043599, 0.015155},{
      1.362108, 1.044620, 0.015155},{1.362761, 1.042610, 0.011705}}],
    Polygon[{{1.355662, 1.043599, 0.015155},{1.355662, 1.046227, 0.018232},{
      1.361296, 1.047119, 0.018232},{1.362108, 1.044620, 0.015155}}],
    Polygon[{{1.355662, 1.046227, 0.018232},{1.355662, 1.049303, 0.020859},{
      1.360346, 1.050045, 0.020859},{1.361296, 1.047119, 0.018232}}],
    Polygon[{{1.355662, 1.049303, 0.020859},{1.355662, 1.052753, 0.022973},{
      1.359280, 1.053326, 0.022973},{1.360346, 1.050045, 0.020859}}],
    Polygon[{{1.355662, 1.052753, 0.022973},{1.355662, 1.056491, 0.024521},{
      1.358124, 1.056881, 0.024521},{1.359280, 1.053326, 0.022973}}],
    Polygon[{{1.355662, 1.056491, 0.024521},{1.355662, 1.060425, 0.025466},{
      1.356909, 1.060623, 0.025466},{1.358124, 1.056881, 0.024521}}],
    Polygon[{{1.356909, 1.060623, -0.025466},{1.358124, 1.056881, -0.024521},{
      1.360346, 1.058013, -0.024521},{1.358033, 1.061195, -0.025466}}],
    Polygon[{{1.358124, 1.056881, -0.024521},{1.359280, 1.053326, -0.022973},{
      1.362543, 1.054989, -0.022973},{1.360346, 1.058013, -0.024521}}],
    Polygon[{{1.359280, 1.053326, -0.022973},{1.360346, 1.050045, -0.020859},{
      1.364570, 1.052198, -0.020859},{1.362543, 1.054989, -0.022973}}],
    Polygon[{{1.360346, 1.050045, -0.020859},{1.361296, 1.047119, -0.018232},{
      1.366379, 1.049709, -0.018232},{1.364570, 1.052198, -0.020859}}],
    Polygon[{{1.361296, 1.047119, -0.018232},{1.362108, 1.044620, -0.015155},{
      1.367923, 1.047583, -0.015155},{1.366379, 1.049709, -0.018232}}],
    Polygon[{{1.362108, 1.044620, -0.015155},{1.362761, 1.042610, -0.011705},{
      1.369166, 1.045873, -0.011705},{1.367923, 1.047583, -0.015155}}],
    Polygon[{{1.362761, 1.042610, -0.011705},{1.363240, 1.041137, -0.007968},{
      1.370076, 1.044620, -0.007968},{1.369166, 1.045873, -0.011705}}],
    Polygon[{{1.363240, 1.041137, -0.007968},{1.363532, 1.040239, -0.004033},{
      1.370631, 1.043856, -0.004033},{1.370076, 1.044620, -0.007968}}],
    Polygon[{{1.363532, 1.040239, -0.004033},{1.363630, 1.039937, 0.000000},{
      1.370818, 1.043599, 0.000000},{1.370631, 1.043856, -0.004033}}],
    Polygon[{{1.363630, 1.039937, 0.000000},{1.363532, 1.040239, 0.004033},{
      1.370631, 1.043856, 0.004033},{1.370818, 1.043599, 0.000000}}],
    Polygon[{{1.363532, 1.040239, 0.004033},{1.363240, 1.041137, 0.007968},{
      1.370076, 1.044620, 0.007968},{1.370631, 1.043856, 0.004033}}],
    Polygon[{{1.363240, 1.041137, 0.007968},{1.362761, 1.042610, 0.011705},{
      1.369166, 1.045873, 0.011705},{1.370076, 1.044620, 0.007968}}],
    Polygon[{{1.362761, 1.042610, 0.011705},{1.362108, 1.044620, 0.015155},{
      1.367923, 1.047583, 0.015155},{1.369166, 1.045873, 0.011705}}],
    Polygon[{{1.362108, 1.044620, 0.015155},{1.361296, 1.047119, 0.018232},{
      1.366379, 1.049709, 0.018232},{1.367923, 1.047583, 0.015155}}],
    Polygon[{{1.361296, 1.047119, 0.018232},{1.360346, 1.050045, 0.020859},{
      1.364570, 1.052198, 0.020859},{1.366379, 1.049709, 0.018232}}],
    Polygon[{{1.360346, 1.050045, 0.020859},{1.359280, 1.053326, 0.022973},{
      1.362543, 1.054989, 0.022973},{1.364570, 1.052198, 0.020859}}],
    Polygon[{{1.359280, 1.053326, 0.022973},{1.358124, 1.056881, 0.024521},{
      1.360346, 1.058013, 0.024521},{1.362543, 1.054989, 0.022973}}],
    Polygon[{{1.358124, 1.056881, 0.024521},{1.356909, 1.060623, 0.025466},{
      1.358033, 1.061195, 0.025466},{1.360346, 1.058013, 0.024521}}],
    Polygon[{{1.358033, 1.061195, -0.025466},{1.360346, 1.058013, -0.024521},{
      1.362108, 1.059775, -0.024521},{1.358926, 1.062088, -0.025466}}],
    Polygon[{{1.360346, 1.058013, -0.024521},{1.362543, 1.054989, -0.022973},{
      1.365132, 1.057578, -0.022973},{1.362108, 1.059775, -0.024521}}],
    Polygon[{{1.362543, 1.054989, -0.022973},{1.364570, 1.052198, -0.020859},{
      1.367923, 1.055551, -0.020859},{1.365132, 1.057578, -0.022973}}],
    Polygon[{{1.364570, 1.052198, -0.020859},{1.366379, 1.049709, -0.018232},{
      1.370412, 1.053742, -0.018232},{1.367923, 1.055551, -0.020859}}],
    Polygon[{{1.366379, 1.049709, -0.018232},{1.367923, 1.047583, -0.015155},{
      1.372538, 1.052198, -0.015155},{1.370412, 1.053742, -0.018232}}],
    Polygon[{{1.367923, 1.047583, -0.015155},{1.369166, 1.045873, -0.011705},{
      1.374248, 1.050955, -0.011705},{1.372538, 1.052198, -0.015155}}],
    Polygon[{{1.369166, 1.045873, -0.011705},{1.370076, 1.044620, -0.007968},{
      1.375501, 1.050045, -0.007968},{1.374248, 1.050955, -0.011705}}],
    Polygon[{{1.370076, 1.044620, -0.007968},{1.370631, 1.043856, -0.004033},{
      1.376265, 1.049490, -0.004033},{1.375501, 1.050045, -0.007968}}],
    Polygon[{{1.370631, 1.043856, -0.004033},{1.370818, 1.043599, 0.000000},{
      1.376522, 1.049303, 0.000000},{1.376265, 1.049490, -0.004033}}],
    Polygon[{{1.370818, 1.043599, 0.000000},{1.370631, 1.043856, 0.004033},{
      1.376265, 1.049490, 0.004033},{1.376522, 1.049303, 0.000000}}],
    Polygon[{{1.370631, 1.043856, 0.004033},{1.370076, 1.044620, 0.007968},{
      1.375501, 1.050045, 0.007968},{1.376265, 1.049490, 0.004033}}],
    Polygon[{{1.370076, 1.044620, 0.007968},{1.369166, 1.045873, 0.011705},{
      1.374248, 1.050955, 0.011705},{1.375501, 1.050045, 0.007968}}],
    Polygon[{{1.369166, 1.045873, 0.011705},{1.367923, 1.047583, 0.015155},{
      1.372538, 1.052198, 0.015155},{1.374248, 1.050955, 0.011705}}],
    Polygon[{{1.367923, 1.047583, 0.015155},{1.366379, 1.049709, 0.018232},{
      1.370412, 1.053742, 0.018232},{1.372538, 1.052198, 0.015155}}],
    Polygon[{{1.366379, 1.049709, 0.018232},{1.364570, 1.052198, 0.020859},{
      1.367923, 1.055551, 0.020859},{1.370412, 1.053742, 0.018232}}],
    Polygon[{{1.364570, 1.052198, 0.020859},{1.362543, 1.054989, 0.022973},{
      1.365132, 1.057578, 0.022973},{1.367923, 1.055551, 0.020859}}],
    Polygon[{{1.362543, 1.054989, 0.022973},{1.360346, 1.058013, 0.024521},{
      1.362108, 1.059775, 0.024521},{1.365132, 1.057578, 0.022973}}],
    Polygon[{{1.360346, 1.058013, 0.024521},{1.358033, 1.061195, 0.025466},{
      1.358926, 1.062088, 0.025466},{1.362108, 1.059775, 0.024521}}],
    Polygon[{{1.358926, 1.062088, -0.025466},{1.362108, 1.059775, -0.024521},{
      1.363240, 1.061996, -0.024521},{1.359498, 1.063212, -0.025466}}],
    Polygon[{{1.362108, 1.059775, -0.024521},{1.365132, 1.057578, -0.022973},{
      1.366795, 1.060841, -0.022973},{1.363240, 1.061996, -0.024521}}],
    Polygon[{{1.365132, 1.057578, -0.022973},{1.367923, 1.055551, -0.020859},{
      1.370076, 1.059775, -0.020859},{1.366795, 1.060841, -0.022973}}],
    Polygon[{{1.367923, 1.055551, -0.020859},{1.370412, 1.053742, -0.018232},{
      1.373002, 1.058825, -0.018232},{1.370076, 1.059775, -0.020859}}],
    Polygon[{{1.370412, 1.053742, -0.018232},{1.372538, 1.052198, -0.015155},{
      1.375501, 1.058013, -0.015155},{1.373002, 1.058825, -0.018232}}],
    Polygon[{{1.372538, 1.052198, -0.015155},{1.374248, 1.050955, -0.011705},{
      1.377511, 1.057359, -0.011705},{1.375501, 1.058013, -0.015155}}],
    Polygon[{{1.374248, 1.050955, -0.011705},{1.375501, 1.050045, -0.007968},{
      1.378984, 1.056881, -0.007968},{1.377511, 1.057359, -0.011705}}],
    Polygon[{{1.375501, 1.050045, -0.007968},{1.376265, 1.049490, -0.004033},{
      1.379882, 1.056589, -0.004033},{1.378984, 1.056881, -0.007968}}],
    Polygon[{{1.376265, 1.049490, -0.004033},{1.376522, 1.049303, 0.000000},{
      1.380184, 1.056491, 0.000000},{1.379882, 1.056589, -0.004033}}],
    Polygon[{{1.376522, 1.049303, 0.000000},{1.376265, 1.049490, 0.004033},{
      1.379882, 1.056589, 0.004033},{1.380184, 1.056491, 0.000000}}],
    Polygon[{{1.376265, 1.049490, 0.004033},{1.375501, 1.050045, 0.007968},{
      1.378984, 1.056881, 0.007968},{1.379882, 1.056589, 0.004033}}],
    Polygon[{{1.375501, 1.050045, 0.007968},{1.374248, 1.050955, 0.011705},{
      1.377511, 1.057359, 0.011705},{1.378984, 1.056881, 0.007968}}],
    Polygon[{{1.374248, 1.050955, 0.011705},{1.372538, 1.052198, 0.015155},{
      1.375501, 1.058013, 0.015155},{1.377511, 1.057359, 0.011705}}],
    Polygon[{{1.372538, 1.052198, 0.015155},{1.370412, 1.053742, 0.018232},{
      1.373002, 1.058825, 0.018232},{1.375501, 1.058013, 0.015155}}],
    Polygon[{{1.370412, 1.053742, 0.018232},{1.367923, 1.055551, 0.020859},{
      1.370076, 1.059775, 0.020859},{1.373002, 1.058825, 0.018232}}],
    Polygon[{{1.367923, 1.055551, 0.020859},{1.365132, 1.057578, 0.022973},{
      1.366795, 1.060841, 0.022973},{1.370076, 1.059775, 0.020859}}],
    Polygon[{{1.365132, 1.057578, 0.022973},{1.362108, 1.059775, 0.024521},{
      1.363240, 1.061996, 0.024521},{1.366795, 1.060841, 0.022973}}],
    Polygon[{{1.362108, 1.059775, 0.024521},{1.358926, 1.062088, 0.025466},{
      1.359498, 1.063212, 0.025466},{1.363240, 1.061996, 0.024521}}],
    Polygon[{{1.359498, 1.063212, -0.025466},{1.363240, 1.061996, -0.024521},{
      1.363630, 1.064459, -0.024521},{1.359696, 1.064459, -0.025466}}],
    Polygon[{{1.363240, 1.061996, -0.024521},{1.366795, 1.060841, -0.022973},{
      1.367368, 1.064459, -0.022973},{1.363630, 1.064459, -0.024521}}],
    Polygon[{{1.366795, 1.060841, -0.022973},{1.370076, 1.059775, -0.020859},{
      1.370818, 1.064459, -0.020859},{1.367368, 1.064459, -0.022973}}],
    Polygon[{{1.370076, 1.059775, -0.020859},{1.373002, 1.058825, -0.018232},{
      1.373894, 1.064459, -0.018232},{1.370818, 1.064459, -0.020859}}],
    Polygon[{{1.373002, 1.058825, -0.018232},{1.375501, 1.058013, -0.015155},{
      1.376522, 1.064459, -0.015155},{1.373894, 1.064459, -0.018232}}],
    Polygon[{{1.375501, 1.058013, -0.015155},{1.377511, 1.057359, -0.011705},{
      1.378636, 1.064459, -0.011705},{1.376522, 1.064459, -0.015155}}],
    Polygon[{{1.377511, 1.057359, -0.011705},{1.378984, 1.056881, -0.007968},{
      1.380184, 1.064459, -0.007968},{1.378636, 1.064459, -0.011705}}],
    Polygon[{{1.378984, 1.056881, -0.007968},{1.379882, 1.056589, -0.004033},{
      1.381128, 1.064459, -0.004033},{1.380184, 1.064459, -0.007968}}],
    Polygon[{{1.379882, 1.056589, -0.004033},{1.380184, 1.056491, 0.000000},{
      1.381446, 1.064459, 0.000000},{1.381128, 1.064459, -0.004033}}],
    Polygon[{{1.380184, 1.056491, 0.000000},{1.379882, 1.056589, 0.004033},{
      1.381128, 1.064459, 0.004033},{1.381446, 1.064459, 0.000000}}],
    Polygon[{{1.379882, 1.056589, 0.004033},{1.378984, 1.056881, 0.007968},{
      1.380184, 1.064459, 0.007968},{1.381128, 1.064459, 0.004033}}],
    Polygon[{{1.378984, 1.056881, 0.007968},{1.377511, 1.057359, 0.011705},{
      1.378636, 1.064459, 0.011705},{1.380184, 1.064459, 0.007968}}],
    Polygon[{{1.377511, 1.057359, 0.011705},{1.375501, 1.058013, 0.015155},{
      1.376522, 1.064459, 0.015155},{1.378636, 1.064459, 0.011705}}],
    Polygon[{{1.375501, 1.058013, 0.015155},{1.373002, 1.058825, 0.018232},{
      1.373894, 1.064459, 0.018232},{1.376522, 1.064459, 0.015155}}],
    Polygon[{{1.373002, 1.058825, 0.018232},{1.370076, 1.059775, 0.020859},{
      1.370818, 1.064459, 0.020859},{1.373894, 1.064459, 0.018232}}],
    Polygon[{{1.370076, 1.059775, 0.020859},{1.366795, 1.060841, 0.022973},{
      1.367368, 1.064459, 0.022973},{1.370818, 1.064459, 0.020859}}],
    Polygon[{{1.366795, 1.060841, 0.022973},{1.363240, 1.061996, 0.024521},{
      1.363630, 1.064459, 0.024521},{1.367368, 1.064459, 0.022973}}],
    Polygon[{{1.363240, 1.061996, 0.024521},{1.359498, 1.063212, 0.025466},{
      1.359696, 1.064459, 0.025466},{1.363630, 1.064459, 0.024521}}],
    Polygon[{{1.311563, 1.168518, -0.013647},{1.313671, 1.168518, -0.013141},{
      1.313462, 1.169837, -0.013141},{1.311457, 1.169186, -0.013647}}],
    Polygon[{{1.313671, 1.168518, -0.013141},{1.315674, 1.168518, -0.012311},{
      1.315367, 1.170456, -0.012311},{1.313462, 1.169837, -0.013141}}],
    Polygon[{{1.315674, 1.168518, -0.012311},{1.317523, 1.168518, -0.011178},{
      1.317125, 1.171028, -0.011178},{1.315367, 1.170456, -0.012311}}],
    Polygon[{{1.317523, 1.168518, -0.011178},{1.319171, 1.168518, -0.009770},{
      1.318693, 1.171537, -0.009770},{1.317125, 1.171028, -0.011178}}],
    Polygon[{{1.319171, 1.168518, -0.009770},{1.320580, 1.168518, -0.008122},{
      1.320032, 1.171972, -0.008122},{1.318693, 1.171537, -0.009770}}],
    Polygon[{{1.320580, 1.168518, -0.008122},{1.321712, 1.168518, -0.006273},{
      1.321110, 1.172322, -0.006273},{1.320032, 1.171972, -0.008122}}],
    Polygon[{{1.321712, 1.168518, -0.006273},{1.322542, 1.168518, -0.004270},{
      1.321899, 1.172579, -0.004270},{1.321110, 1.172322, -0.006273}}],
    Polygon[{{1.322542, 1.168518, -0.004270},{1.323048, 1.168518, -0.002162},{
      1.322380, 1.172735, -0.002162},{1.321899, 1.172579, -0.004270}}],
    Polygon[{{1.323048, 1.168518, -0.002162},{1.323218, 1.168518, 0.000000},{
      1.322542, 1.172788, 0.000000},{1.322380, 1.172735, -0.002162}}],
    Polygon[{{1.323218, 1.168518, 0.000000},{1.323048, 1.168518, 0.002162},{
      1.322380, 1.172735, 0.002162},{1.322542, 1.172788, 0.000000}}],
    Polygon[{{1.323048, 1.168518, 0.002162},{1.322542, 1.168518, 0.004270},{
      1.321899, 1.172579, 0.004270},{1.322380, 1.172735, 0.002162}}],
    Polygon[{{1.322542, 1.168518, 0.004270},{1.321712, 1.168518, 0.006273},{
      1.321110, 1.172322, 0.006273},{1.321899, 1.172579, 0.004270}}],
    Polygon[{{1.321712, 1.168518, 0.006273},{1.320580, 1.168518, 0.008122},{
      1.320032, 1.171972, 0.008122},{1.321110, 1.172322, 0.006273}}],
    Polygon[{{1.320580, 1.168518, 0.008122},{1.319171, 1.168518, 0.009770},{
      1.318693, 1.171537, 0.009770},{1.320032, 1.171972, 0.008122}}],
    Polygon[{{1.319171, 1.168518, 0.009770},{1.317523, 1.168518, 0.011178},{
      1.317125, 1.171028, 0.011178},{1.318693, 1.171537, 0.009770}}],
    Polygon[{{1.317523, 1.168518, 0.011178},{1.315674, 1.168518, 0.012311},{
      1.315367, 1.170456, 0.012311},{1.317125, 1.171028, 0.011178}}],
    Polygon[{{1.315674, 1.168518, 0.012311},{1.313671, 1.168518, 0.013141},{
      1.313462, 1.169837, 0.013141},{1.315367, 1.170456, 0.012311}}],
    Polygon[{{1.313671, 1.168518, 0.013141},{1.311563, 1.168518, 0.013647},{
      1.311457, 1.169186, 0.013647},{1.313462, 1.169837, 0.013141}}],
    Polygon[{{1.311457, 1.169186, -0.013647},{1.313462, 1.169837, -0.013141},{
      1.312855, 1.171028, -0.013141},{1.311150, 1.169788, -0.013647}}],
    Polygon[{{1.313462, 1.169837, -0.013141},{1.315367, 1.170456, -0.012311},{
      1.314476, 1.172205, -0.012311},{1.312855, 1.171028, -0.013141}}],
    Polygon[{{1.315367, 1.170456, -0.012311},{1.317125, 1.171028, -0.011178},{
      1.315972, 1.173292, -0.011178},{1.314476, 1.172205, -0.012311}}],
    Polygon[{{1.317125, 1.171028, -0.011178},{1.318693, 1.171537, -0.009770},{
      1.317305, 1.174261, -0.009770},{1.315972, 1.173292, -0.011178}}],
    Polygon[{{1.318693, 1.171537, -0.009770},{1.320032, 1.171972, -0.008122},{
      1.318445, 1.175088, -0.008122},{1.317305, 1.174261, -0.009770}}],
    Polygon[{{1.320032, 1.171972, -0.008122},{1.321110, 1.172322, -0.006273},{
      1.319361, 1.175754, -0.006273},{1.318445, 1.175088, -0.008122}}],
    Polygon[{{1.321110, 1.172322, -0.006273},{1.321899, 1.172579, -0.004270},{
      1.320032, 1.176242, -0.004270},{1.319361, 1.175754, -0.006273}}],
    Polygon[{{1.321899, 1.172579, -0.004270},{1.322380, 1.172735, -0.002162},{
      1.320442, 1.176539, -0.002162},{1.320032, 1.176242, -0.004270}}],
    Polygon[{{1.322380, 1.172735, -0.002162},{1.322542, 1.172788, 0.000000},{
      1.320580, 1.176639, 0.000000},{1.320442, 1.176539, -0.002162}}],
    Polygon[{{1.322542, 1.172788, 0.000000},{1.322380, 1.172735, 0.002162},{
      1.320442, 1.176539, 0.002162},{1.320580, 1.176639, 0.000000}}],
    Polygon[{{1.322380, 1.172735, 0.002162},{1.321899, 1.172579, 0.004270},{
      1.320032, 1.176242, 0.004270},{1.320442, 1.176539, 0.002162}}],
    Polygon[{{1.321899, 1.172579, 0.004270},{1.321110, 1.172322, 0.006273},{
      1.319361, 1.175754, 0.006273},{1.320032, 1.176242, 0.004270}}],
    Polygon[{{1.321110, 1.172322, 0.006273},{1.320032, 1.171972, 0.008122},{
      1.318445, 1.175088, 0.008122},{1.319361, 1.175754, 0.006273}}],
    Polygon[{{1.320032, 1.171972, 0.008122},{1.318693, 1.171537, 0.009770},{
      1.317305, 1.174261, 0.009770},{1.318445, 1.175088, 0.008122}}],
    Polygon[{{1.318693, 1.171537, 0.009770},{1.317125, 1.171028, 0.011178},{
      1.315972, 1.173292, 0.011178},{1.317305, 1.174261, 0.009770}}],
    Polygon[{{1.317125, 1.171028, 0.011178},{1.315367, 1.170456, 0.012311},{
      1.314476, 1.172205, 0.012311},{1.315972, 1.173292, 0.011178}}],
    Polygon[{{1.315367, 1.170456, 0.012311},{1.313462, 1.169837, 0.013141},{
      1.312855, 1.171028, 0.013141},{1.314476, 1.172205, 0.012311}}],
    Polygon[{{1.313462, 1.169837, 0.013141},{1.311457, 1.169186, 0.013647},{
      1.311150, 1.169788, 0.013647},{1.312855, 1.171028, 0.013141}}],
    Polygon[{{1.311150, 1.169788, -0.013647},{1.312855, 1.171028, -0.013141},{
      1.311911, 1.171972, -0.013141},{1.310672, 1.170267, -0.013647}}],
    Polygon[{{1.312855, 1.171028, -0.013141},{1.314476, 1.172205, -0.012311},{
      1.313088, 1.173593, -0.012311},{1.311911, 1.171972, -0.013141}}],
    Polygon[{{1.314476, 1.172205, -0.012311},{1.315972, 1.173292, -0.011178},{
      1.314175, 1.175088, -0.011178},{1.313088, 1.173593, -0.012311}}],
    Polygon[{{1.315972, 1.173292, -0.011178},{1.317305, 1.174261, -0.009770},{
      1.315144, 1.176422, -0.009770},{1.314175, 1.175088, -0.011178}}],
    Polygon[{{1.317305, 1.174261, -0.009770},{1.318445, 1.175088, -0.008122},{
      1.315972, 1.177561, -0.008122},{1.315144, 1.176422, -0.009770}}],
    Polygon[{{1.318445, 1.175088, -0.008122},{1.319361, 1.175754, -0.006273},{
      1.316638, 1.178478, -0.006273},{1.315972, 1.177561, -0.008122}}],
    Polygon[{{1.319361, 1.175754, -0.006273},{1.320032, 1.176242, -0.004270},{
      1.317125, 1.179149, -0.004270},{1.316638, 1.178478, -0.006273}}],
    Polygon[{{1.320032, 1.176242, -0.004270},{1.320442, 1.176539, -0.002162},{
      1.317423, 1.179559, -0.002162},{1.317125, 1.179149, -0.004270}}],
    Polygon[{{1.320442, 1.176539, -0.002162},{1.320580, 1.176639, 0.000000},{
      1.317523, 1.179696, 0.000000},{1.317423, 1.179559, -0.002162}}],
    Polygon[{{1.320580, 1.176639, 0.000000},{1.320442, 1.176539, 0.002162},{
      1.317423, 1.179559, 0.002162},{1.317523, 1.179696, 0.000000}}],
    Polygon[{{1.320442, 1.176539, 0.002162},{1.320032, 1.176242, 0.004270},{
      1.317125, 1.179149, 0.004270},{1.317423, 1.179559, 0.002162}}],
    Polygon[{{1.320032, 1.176242, 0.004270},{1.319361, 1.175754, 0.006273},{
      1.316638, 1.178478, 0.006273},{1.317125, 1.179149, 0.004270}}],
    Polygon[{{1.319361, 1.175754, 0.006273},{1.318445, 1.175088, 0.008122},{
      1.315972, 1.177561, 0.008122},{1.316638, 1.178478, 0.006273}}],
    Polygon[{{1.318445, 1.175088, 0.008122},{1.317305, 1.174261, 0.009770},{
      1.315144, 1.176422, 0.009770},{1.315972, 1.177561, 0.008122}}],
    Polygon[{{1.317305, 1.174261, 0.009770},{1.315972, 1.173292, 0.011178},{
      1.314175, 1.175088, 0.011178},{1.315144, 1.176422, 0.009770}}],
    Polygon[{{1.315972, 1.173292, 0.011178},{1.314476, 1.172205, 0.012311},{
      1.313088, 1.173593, 0.012311},{1.314175, 1.175088, 0.011178}}],
    Polygon[{{1.314476, 1.172205, 0.012311},{1.312855, 1.171028, 0.013141},{
      1.311911, 1.171972, 0.013141},{1.313088, 1.173593, 0.012311}}],
    Polygon[{{1.312855, 1.171028, 0.013141},{1.311150, 1.169788, 0.013647},{
      1.310672, 1.170267, 0.013647},{1.311911, 1.171972, 0.013141}}],
    Polygon[{{1.310672, 1.170267, -0.013647},{1.311911, 1.171972, -0.013141},{
      1.310721, 1.172579, -0.013141},{1.310069, 1.170574, -0.013647}}],
    Polygon[{{1.311911, 1.171972, -0.013141},{1.313088, 1.173593, -0.012311},{
      1.311339, 1.174484, -0.012311},{1.310721, 1.172579, -0.013141}}],
    Polygon[{{1.313088, 1.173593, -0.012311},{1.314175, 1.175088, -0.011178},{
      1.311911, 1.176242, -0.011178},{1.311339, 1.174484, -0.012311}}],
    Polygon[{{1.314175, 1.175088, -0.011178},{1.315144, 1.176422, -0.009770},{
      1.312420, 1.177810, -0.009770},{1.311911, 1.176242, -0.011178}}],
    Polygon[{{1.315144, 1.176422, -0.009770},{1.315972, 1.177561, -0.008122},{
      1.312855, 1.179149, -0.008122},{1.312420, 1.177810, -0.009770}}],
    Polygon[{{1.315972, 1.177561, -0.008122},{1.316638, 1.178478, -0.006273},{
      1.313205, 1.180227, -0.006273},{1.312855, 1.179149, -0.008122}}],
    Polygon[{{1.316638, 1.178478, -0.006273},{1.317125, 1.179149, -0.004270},{
      1.313462, 1.181016, -0.004270},{1.313205, 1.180227, -0.006273}}],
    Polygon[{{1.317125, 1.179149, -0.004270},{1.317423, 1.179559, -0.002162},{
      1.313618, 1.181497, -0.002162},{1.313462, 1.181016, -0.004270}}],
    Polygon[{{1.317423, 1.179559, -0.002162},{1.317523, 1.179696, 0.000000},{
      1.313671, 1.181659, 0.000000},{1.313618, 1.181497, -0.002162}}],
    Polygon[{{1.317523, 1.179696, 0.000000},{1.317423, 1.179559, 0.002162},{
      1.313618, 1.181497, 0.002162},{1.313671, 1.181659, 0.000000}}],
    Polygon[{{1.317423, 1.179559, 0.002162},{1.317125, 1.179149, 0.004270},{
      1.313462, 1.181016, 0.004270},{1.313618, 1.181497, 0.002162}}],
    Polygon[{{1.317125, 1.179149, 0.004270},{1.316638, 1.178478, 0.006273},{
      1.313205, 1.180227, 0.006273},{1.313462, 1.181016, 0.004270}}],
    Polygon[{{1.316638, 1.178478, 0.006273},{1.315972, 1.177561, 0.008122},{
      1.312855, 1.179149, 0.008122},{1.313205, 1.180227, 0.006273}}],
    Polygon[{{1.315972, 1.177561, 0.008122},{1.315144, 1.176422, 0.009770},{
      1.312420, 1.177810, 0.009770},{1.312855, 1.179149, 0.008122}}],
    Polygon[{{1.315144, 1.176422, 0.009770},{1.314175, 1.175088, 0.011178},{
      1.311911, 1.176242, 0.011178},{1.312420, 1.177810, 0.009770}}],
    Polygon[{{1.314175, 1.175088, 0.011178},{1.313088, 1.173593, 0.012311},{
      1.311339, 1.174484, 0.012311},{1.311911, 1.176242, 0.011178}}],
    Polygon[{{1.313088, 1.173593, 0.012311},{1.311911, 1.171972, 0.013141},{
      1.310721, 1.172579, 0.013141},{1.311339, 1.174484, 0.012311}}],
    Polygon[{{1.311911, 1.171972, 0.013141},{1.310672, 1.170267, 0.013647},{
      1.310069, 1.170574, 0.013647},{1.310721, 1.172579, 0.013141}}],
    Polygon[{{1.310069, 1.170574, -0.013647},{1.310721, 1.172579, -0.013141},{
      1.309401, 1.172788, -0.013141},{1.309401, 1.170679, -0.013647}}],
    Polygon[{{1.310721, 1.172579, -0.013141},{1.311339, 1.174484, -0.012311},{
      1.309401, 1.174791, -0.012311},{1.309401, 1.172788, -0.013141}}],
    Polygon[{{1.311339, 1.174484, -0.012311},{1.311911, 1.176242, -0.011178},{
      1.309401, 1.176639, -0.011178},{1.309401, 1.174791, -0.012311}}],
    Polygon[{{1.311911, 1.176242, -0.011178},{1.312420, 1.177810, -0.009770},{
      1.309401, 1.178288, -0.009770},{1.309401, 1.176639, -0.011178}}],
    Polygon[{{1.312420, 1.177810, -0.009770},{1.312855, 1.179149, -0.008122},{
      1.309401, 1.179696, -0.008122},{1.309401, 1.178288, -0.009770}}],
    Polygon[{{1.312855, 1.179149, -0.008122},{1.313205, 1.180227, -0.006273},{
      1.309401, 1.180829, -0.006273},{1.309401, 1.179696, -0.008122}}],
    Polygon[{{1.313205, 1.180227, -0.006273},{1.313462, 1.181016, -0.004270},{
      1.309401, 1.181659, -0.004270},{1.309401, 1.180829, -0.006273}}],
    Polygon[{{1.313462, 1.181016, -0.004270},{1.313618, 1.181497, -0.002162},{
      1.309401, 1.182165, -0.002162},{1.309401, 1.181659, -0.004270}}],
    Polygon[{{1.313618, 1.181497, -0.002162},{1.313671, 1.181659, 0.000000},{
      1.309401, 1.182335, 0.000000},{1.309401, 1.182165, -0.002162}}],
    Polygon[{{1.313671, 1.181659, 0.000000},{1.313618, 1.181497, 0.002162},{
      1.309401, 1.182165, 0.002162},{1.309401, 1.182335, 0.000000}}],
    Polygon[{{1.313618, 1.181497, 0.002162},{1.313462, 1.181016, 0.004270},{
      1.309401, 1.181659, 0.004270},{1.309401, 1.182165, 0.002162}}],
    Polygon[{{1.313462, 1.181016, 0.004270},{1.313205, 1.180227, 0.006273},{
      1.309401, 1.180829, 0.006273},{1.309401, 1.181659, 0.004270}}],
    Polygon[{{1.313205, 1.180227, 0.006273},{1.312855, 1.179149, 0.008122},{
      1.309401, 1.179696, 0.008122},{1.309401, 1.180829, 0.006273}}],
    Polygon[{{1.312855, 1.179149, 0.008122},{1.312420, 1.177810, 0.009770},{
      1.309401, 1.178288, 0.009770},{1.309401, 1.179696, 0.008122}}],
    Polygon[{{1.312420, 1.177810, 0.009770},{1.311911, 1.176242, 0.011178},{
      1.309401, 1.176639, 0.011178},{1.309401, 1.178288, 0.009770}}],
    Polygon[{{1.311911, 1.176242, 0.011178},{1.311339, 1.174484, 0.012311},{
      1.309401, 1.174791, 0.012311},{1.309401, 1.176639, 0.011178}}],
    Polygon[{{1.311339, 1.174484, 0.012311},{1.310721, 1.172579, 0.013141},{
      1.309401, 1.172788, 0.013141},{1.309401, 1.174791, 0.012311}}],
    Polygon[{{1.310721, 1.172579, 0.013141},{1.310069, 1.170574, 0.013647},{
      1.309401, 1.170679, 0.013647},{1.309401, 1.172788, 0.013141}}],
    Polygon[{{1.309401, 1.170679, -0.013647},{1.309401, 1.172788, -0.013141},{
      1.308082, 1.172579, -0.013141},{1.308733, 1.170574, -0.013647}}],
    Polygon[{{1.309401, 1.172788, -0.013141},{1.309401, 1.174791, -0.012311},{
      1.307463, 1.174484, -0.012311},{1.308082, 1.172579, -0.013141}}],
    Polygon[{{1.309401, 1.174791, -0.012311},{1.309401, 1.176639, -0.011178},{
      1.306891, 1.176242, -0.011178},{1.307463, 1.174484, -0.012311}}],
    Polygon[{{1.309401, 1.176639, -0.011178},{1.309401, 1.178288, -0.009770},{
      1.306382, 1.177810, -0.009770},{1.306891, 1.176242, -0.011178}}],
    Polygon[{{1.309401, 1.178288, -0.009770},{1.309401, 1.179696, -0.008122},{
      1.305947, 1.179149, -0.008122},{1.306382, 1.177810, -0.009770}}],
    Polygon[{{1.309401, 1.179696, -0.008122},{1.309401, 1.180829, -0.006273},{
      1.305597, 1.180227, -0.006273},{1.305947, 1.179149, -0.008122}}],
    Polygon[{{1.309401, 1.180829, -0.006273},{1.309401, 1.181659, -0.004270},{
      1.305340, 1.181016, -0.004270},{1.305597, 1.180227, -0.006273}}],
    Polygon[{{1.309401, 1.181659, -0.004270},{1.309401, 1.182165, -0.002162},{
      1.305184, 1.181497, -0.002162},{1.305340, 1.181016, -0.004270}}],
    Polygon[{{1.309401, 1.182165, -0.002162},{1.309401, 1.182335, 0.000000},{
      1.305131, 1.181659, 0.000000},{1.305184, 1.181497, -0.002162}}],
    Polygon[{{1.309401, 1.182335, 0.000000},{1.309401, 1.182165, 0.002162},{
      1.305184, 1.181497, 0.002162},{1.305131, 1.181659, 0.000000}}],
    Polygon[{{1.309401, 1.182165, 0.002162},{1.309401, 1.181659, 0.004270},{
      1.305340, 1.181016, 0.004270},{1.305184, 1.181497, 0.002162}}],
    Polygon[{{1.309401, 1.181659, 0.004270},{1.309401, 1.180829, 0.006273},{
      1.305597, 1.180227, 0.006273},{1.305340, 1.181016, 0.004270}}],
    Polygon[{{1.309401, 1.180829, 0.006273},{1.309401, 1.179696, 0.008122},{
      1.305947, 1.179149, 0.008122},{1.305597, 1.180227, 0.006273}}],
    Polygon[{{1.309401, 1.179696, 0.008122},{1.309401, 1.178288, 0.009770},{
      1.306382, 1.177810, 0.009770},{1.305947, 1.179149, 0.008122}}],
    Polygon[{{1.309401, 1.178288, 0.009770},{1.309401, 1.176639, 0.011178},{
      1.306891, 1.176242, 0.011178},{1.306382, 1.177810, 0.009770}}],
    Polygon[{{1.309401, 1.176639, 0.011178},{1.309401, 1.174791, 0.012311},{
      1.307463, 1.174484, 0.012311},{1.306891, 1.176242, 0.011178}}],
    Polygon[{{1.309401, 1.174791, 0.012311},{1.309401, 1.172788, 0.013141},{
      1.308082, 1.172579, 0.013141},{1.307463, 1.174484, 0.012311}}],
    Polygon[{{1.309401, 1.172788, 0.013141},{1.309401, 1.170679, 0.013647},{
      1.308733, 1.170574, 0.013647},{1.308082, 1.172579, 0.013141}}],
    Polygon[{{1.308733, 1.170574, -0.013647},{1.308082, 1.172579, -0.013141},{
      1.306891, 1.171972, -0.013141},{1.308131, 1.170267, -0.013647}}],
    Polygon[{{1.308082, 1.172579, -0.013141},{1.307463, 1.174484, -0.012311},{
      1.305714, 1.173593, -0.012311},{1.306891, 1.171972, -0.013141}}],
    Polygon[{{1.307463, 1.174484, -0.012311},{1.306891, 1.176242, -0.011178},{
      1.304627, 1.175088, -0.011178},{1.305714, 1.173593, -0.012311}}],
    Polygon[{{1.306891, 1.176242, -0.011178},{1.306382, 1.177810, -0.009770},{
      1.303658, 1.176422, -0.009770},{1.304627, 1.175088, -0.011178}}],
    Polygon[{{1.306382, 1.177810, -0.009770},{1.305947, 1.179149, -0.008122},{
      1.302831, 1.177561, -0.008122},{1.303658, 1.176422, -0.009770}}],
    Polygon[{{1.305947, 1.179149, -0.008122},{1.305597, 1.180227, -0.006273},{
      1.302165, 1.178478, -0.006273},{1.302831, 1.177561, -0.008122}}],
    Polygon[{{1.305597, 1.180227, -0.006273},{1.305340, 1.181016, -0.004270},{
      1.301677, 1.179149, -0.004270},{1.302165, 1.178478, -0.006273}}],
    Polygon[{{1.305340, 1.181016, -0.004270},{1.305184, 1.181497, -0.002162},{
      1.301379, 1.179559, -0.002162},{1.301677, 1.179149, -0.004270}}],
    Polygon[{{1.305184, 1.181497, -0.002162},{1.305131, 1.181659, 0.000000},{
      1.301279, 1.179696, 0.000000},{1.301379, 1.179559, -0.002162}}],
    Polygon[{{1.305131, 1.181659, 0.000000},{1.305184, 1.181497, 0.002162},{
      1.301379, 1.179559, 0.002162},{1.301279, 1.179696, 0.000000}}],
    Polygon[{{1.305184, 1.181497, 0.002162},{1.305340, 1.181016, 0.004270},{
      1.301677, 1.179149, 0.004270},{1.301379, 1.179559, 0.002162}}],
    Polygon[{{1.305340, 1.181016, 0.004270},{1.305597, 1.180227, 0.006273},{
      1.302165, 1.178478, 0.006273},{1.301677, 1.179149, 0.004270}}],
    Polygon[{{1.305597, 1.180227, 0.006273},{1.305947, 1.179149, 0.008122},{
      1.302831, 1.177561, 0.008122},{1.302165, 1.178478, 0.006273}}],
    Polygon[{{1.305947, 1.179149, 0.008122},{1.306382, 1.177810, 0.009770},{
      1.303658, 1.176422, 0.009770},{1.302831, 1.177561, 0.008122}}],
    Polygon[{{1.306382, 1.177810, 0.009770},{1.306891, 1.176242, 0.011178},{
      1.304627, 1.175088, 0.011178},{1.303658, 1.176422, 0.009770}}],
    Polygon[{{1.306891, 1.176242, 0.011178},{1.307463, 1.174484, 0.012311},{
      1.305714, 1.173593, 0.012311},{1.304627, 1.175088, 0.011178}}],
    Polygon[{{1.307463, 1.174484, 0.012311},{1.308082, 1.172579, 0.013141},{
      1.306891, 1.171972, 0.013141},{1.305714, 1.173593, 0.012311}}],
    Polygon[{{1.308082, 1.172579, 0.013141},{1.308733, 1.170574, 0.013647},{
      1.308131, 1.170267, 0.013647},{1.306891, 1.171972, 0.013141}}],
    Polygon[{{1.308131, 1.170267, -0.013647},{1.306891, 1.171972, -0.013141},{
      1.305947, 1.171028, -0.013141},{1.307652, 1.169788, -0.013647}}],
    Polygon[{{1.306891, 1.171972, -0.013141},{1.305714, 1.173593, -0.012311},{
      1.304326, 1.172205, -0.012311},{1.305947, 1.171028, -0.013141}}],
    Polygon[{{1.305714, 1.173593, -0.012311},{1.304627, 1.175088, -0.011178},{
      1.302831, 1.173292, -0.011178},{1.304326, 1.172205, -0.012311}}],
    Polygon[{{1.304627, 1.175088, -0.011178},{1.303658, 1.176422, -0.009770},{
      1.301497, 1.174261, -0.009770},{1.302831, 1.173292, -0.011178}}],
    Polygon[{{1.303658, 1.176422, -0.009770},{1.302831, 1.177561, -0.008122},{
      1.300358, 1.175088, -0.008122},{1.301497, 1.174261, -0.009770}}],
    Polygon[{{1.302831, 1.177561, -0.008122},{1.302165, 1.178478, -0.006273},{
      1.299441, 1.175754, -0.006273},{1.300358, 1.175088, -0.008122}}],
    Polygon[{{1.302165, 1.178478, -0.006273},{1.301677, 1.179149, -0.004270},{
      1.298770, 1.176242, -0.004270},{1.299441, 1.175754, -0.006273}}],
    Polygon[{{1.301677, 1.179149, -0.004270},{1.301379, 1.179559, -0.002162},{
      1.298360, 1.176539, -0.002162},{1.298770, 1.176242, -0.004270}}],
    Polygon[{{1.301379, 1.179559, -0.002162},{1.301279, 1.179696, 0.000000},{
      1.298223, 1.176639, 0.000000},{1.298360, 1.176539, -0.002162}}],
    Polygon[{{1.301279, 1.179696, 0.000000},{1.301379, 1.179559, 0.002162},{
      1.298360, 1.176539, 0.002162},{1.298223, 1.176639, 0.000000}}],
    Polygon[{{1.301379, 1.179559, 0.002162},{1.301677, 1.179149, 0.004270},{
      1.298770, 1.176242, 0.004270},{1.298360, 1.176539, 0.002162}}],
    Polygon[{{1.301677, 1.179149, 0.004270},{1.302165, 1.178478, 0.006273},{
      1.299441, 1.175754, 0.006273},{1.298770, 1.176242, 0.004270}}],
    Polygon[{{1.302165, 1.178478, 0.006273},{1.302831, 1.177561, 0.008122},{
      1.300358, 1.175088, 0.008122},{1.299441, 1.175754, 0.006273}}],
    Polygon[{{1.302831, 1.177561, 0.008122},{1.303658, 1.176422, 0.009770},{
      1.301497, 1.174261, 0.009770},{1.300358, 1.175088, 0.008122}}],
    Polygon[{{1.303658, 1.176422, 0.009770},{1.304627, 1.175088, 0.011178},{
      1.302831, 1.173292, 0.011178},{1.301497, 1.174261, 0.009770}}],
    Polygon[{{1.304627, 1.175088, 0.011178},{1.305714, 1.173593, 0.012311},{
      1.304326, 1.172205, 0.012311},{1.302831, 1.173292, 0.011178}}],
    Polygon[{{1.305714, 1.173593, 0.012311},{1.306891, 1.171972, 0.013141},{
      1.305947, 1.171028, 0.013141},{1.304326, 1.172205, 0.012311}}],
    Polygon[{{1.306891, 1.171972, 0.013141},{1.308131, 1.170267, 0.013647},{
      1.307652, 1.169788, 0.013647},{1.305947, 1.171028, 0.013141}}],
    Polygon[{{1.307652, 1.169788, -0.013647},{1.305947, 1.171028, -0.013141},{
      1.305340, 1.169837, -0.013141},{1.307345, 1.169186, -0.013647}}],
    Polygon[{{1.305947, 1.171028, -0.013141},{1.304326, 1.172205, -0.012311},{
      1.303435, 1.170456, -0.012311},{1.305340, 1.169837, -0.013141}}],
    Polygon[{{1.304326, 1.172205, -0.012311},{1.302831, 1.173292, -0.011178},{
      1.301677, 1.171028, -0.011178},{1.303435, 1.170456, -0.012311}}],
    Polygon[{{1.302831, 1.173292, -0.011178},{1.301497, 1.174261, -0.009770},{
      1.300109, 1.171537, -0.009770},{1.301677, 1.171028, -0.011178}}],
    Polygon[{{1.301497, 1.174261, -0.009770},{1.300358, 1.175088, -0.008122},{
      1.298770, 1.171972, -0.008122},{1.300109, 1.171537, -0.009770}}],
    Polygon[{{1.300358, 1.175088, -0.008122},{1.299441, 1.175754, -0.006273},{
      1.297692, 1.172322, -0.006273},{1.298770, 1.171972, -0.008122}}],
    Polygon[{{1.299441, 1.175754, -0.006273},{1.298770, 1.176242, -0.004270},{
      1.296903, 1.172579, -0.004270},{1.297692, 1.172322, -0.006273}}],
    Polygon[{{1.298770, 1.176242, -0.004270},{1.298360, 1.176539, -0.002162},{
      1.296422, 1.172735, -0.002162},{1.296903, 1.172579, -0.004270}}],
    Polygon[{{1.298360, 1.176539, -0.002162},{1.298223, 1.176639, 0.000000},{
      1.296260, 1.172788, 0.000000},{1.296422, 1.172735, -0.002162}}],
    Polygon[{{1.298223, 1.176639, 0.000000},{1.298360, 1.176539, 0.002162},{
      1.296422, 1.172735, 0.002162},{1.296260, 1.172788, 0.000000}}],
    Polygon[{{1.298360, 1.176539, 0.002162},{1.298770, 1.176242, 0.004270},{
      1.296903, 1.172579, 0.004270},{1.296422, 1.172735, 0.002162}}],
    Polygon[{{1.298770, 1.176242, 0.004270},{1.299441, 1.175754, 0.006273},{
      1.297692, 1.172322, 0.006273},{1.296903, 1.172579, 0.004270}}],
    Polygon[{{1.299441, 1.175754, 0.006273},{1.300358, 1.175088, 0.008122},{
      1.298770, 1.171972, 0.008122},{1.297692, 1.172322, 0.006273}}],
    Polygon[{{1.300358, 1.175088, 0.008122},{1.301497, 1.174261, 0.009770},{
      1.300109, 1.171537, 0.009770},{1.298770, 1.171972, 0.008122}}],
    Polygon[{{1.301497, 1.174261, 0.009770},{1.302831, 1.173292, 0.011178},{
      1.301677, 1.171028, 0.011178},{1.300109, 1.171537, 0.009770}}],
    Polygon[{{1.302831, 1.173292, 0.011178},{1.304326, 1.172205, 0.012311},{
      1.303435, 1.170456, 0.012311},{1.301677, 1.171028, 0.011178}}],
    Polygon[{{1.304326, 1.172205, 0.012311},{1.305947, 1.171028, 0.013141},{
      1.305340, 1.169837, 0.013141},{1.303435, 1.170456, 0.012311}}],
    Polygon[{{1.305947, 1.171028, 0.013141},{1.307652, 1.169788, 0.013647},{
      1.307345, 1.169186, 0.013647},{1.305340, 1.169837, 0.013141}}],
    Polygon[{{1.307345, 1.169186, -0.013647},{1.305340, 1.169837, -0.013141},{
      1.305131, 1.168518, -0.013141},{1.307240, 1.168518, -0.013647}}],
    Polygon[{{1.305340, 1.169837, -0.013141},{1.303435, 1.170456, -0.012311},{
      1.303128, 1.168518, -0.012311},{1.305131, 1.168518, -0.013141}}],
    Polygon[{{1.303435, 1.170456, -0.012311},{1.301677, 1.171028, -0.011178},{
      1.301279, 1.168518, -0.011178},{1.303128, 1.168518, -0.012311}}],
    Polygon[{{1.301677, 1.171028, -0.011178},{1.300109, 1.171537, -0.009770},{
      1.299631, 1.168518, -0.009770},{1.301279, 1.168518, -0.011178}}],
    Polygon[{{1.300109, 1.171537, -0.009770},{1.298770, 1.171972, -0.008122},{
      1.298223, 1.168518, -0.008122},{1.299631, 1.168518, -0.009770}}],
    Polygon[{{1.298770, 1.171972, -0.008122},{1.297692, 1.172322, -0.006273},{
      1.297090, 1.168518, -0.006273},{1.298223, 1.168518, -0.008122}}],
    Polygon[{{1.297692, 1.172322, -0.006273},{1.296903, 1.172579, -0.004270},{
      1.296260, 1.168518, -0.004270},{1.297090, 1.168518, -0.006273}}],
    Polygon[{{1.296903, 1.172579, -0.004270},{1.296422, 1.172735, -0.002162},{
      1.295754, 1.168518, -0.002162},{1.296260, 1.168518, -0.004270}}],
    Polygon[{{1.296422, 1.172735, -0.002162},{1.296260, 1.172788, 0.000000},{
      1.295584, 1.168518, 0.000000},{1.295754, 1.168518, -0.002162}}],
    Polygon[{{1.296260, 1.172788, 0.000000},{1.296422, 1.172735, 0.002162},{
      1.295754, 1.168518, 0.002162},{1.295584, 1.168518, 0.000000}}],
    Polygon[{{1.296422, 1.172735, 0.002162},{1.296903, 1.172579, 0.004270},{
      1.296260, 1.168518, 0.004270},{1.295754, 1.168518, 0.002162}}],
    Polygon[{{1.296903, 1.172579, 0.004270},{1.297692, 1.172322, 0.006273},{
      1.297090, 1.168518, 0.006273},{1.296260, 1.168518, 0.004270}}],
    Polygon[{{1.297692, 1.172322, 0.006273},{1.298770, 1.171972, 0.008122},{
      1.298223, 1.168518, 0.008122},{1.297090, 1.168518, 0.006273}}],
    Polygon[{{1.298770, 1.171972, 0.008122},{1.300109, 1.171537, 0.009770},{
      1.299631, 1.168518, 0.009770},{1.298223, 1.168518, 0.008122}}],
    Polygon[{{1.300109, 1.171537, 0.009770},{1.301677, 1.171028, 0.011178},{
      1.301279, 1.168518, 0.011178},{1.299631, 1.168518, 0.009770}}],
    Polygon[{{1.301677, 1.171028, 0.011178},{1.303435, 1.170456, 0.012311},{
      1.303128, 1.168518, 0.012311},{1.301279, 1.168518, 0.011178}}],
    Polygon[{{1.303435, 1.170456, 0.012311},{1.305340, 1.169837, 0.013141},{
      1.305131, 1.168518, 0.013141},{1.303128, 1.168518, 0.012311}}],
    Polygon[{{1.305340, 1.169837, 0.013141},{1.307345, 1.169186, 0.013647},{
      1.307240, 1.168518, 0.013647},{1.305131, 1.168518, 0.013141}}],
    Polygon[{{1.307240, 1.168518, -0.013647},{1.305131, 1.168518, -0.013141},{
      1.305340, 1.167198, -0.013141},{1.307345, 1.167850, -0.013647}}],
    Polygon[{{1.305131, 1.168518, -0.013141},{1.303128, 1.168518, -0.012311},{
      1.303435, 1.166579, -0.012311},{1.305340, 1.167198, -0.013141}}],
    Polygon[{{1.303128, 1.168518, -0.012311},{1.301279, 1.168518, -0.011178},{
      1.301677, 1.166008, -0.011178},{1.303435, 1.166579, -0.012311}}],
    Polygon[{{1.301279, 1.168518, -0.011178},{1.299631, 1.168518, -0.009770},{
      1.300109, 1.165499, -0.009770},{1.301677, 1.166008, -0.011178}}],
    Polygon[{{1.299631, 1.168518, -0.009770},{1.298223, 1.168518, -0.008122},{
      1.298770, 1.165064, -0.008122},{1.300109, 1.165499, -0.009770}}],
    Polygon[{{1.298223, 1.168518, -0.008122},{1.297090, 1.168518, -0.006273},{
      1.297692, 1.164713, -0.006273},{1.298770, 1.165064, -0.008122}}],
    Polygon[{{1.297090, 1.168518, -0.006273},{1.296260, 1.168518, -0.004270},{
      1.296903, 1.164457, -0.004270},{1.297692, 1.164713, -0.006273}}],
    Polygon[{{1.296260, 1.168518, -0.004270},{1.295754, 1.168518, -0.002162},{
      1.296422, 1.164301, -0.002162},{1.296903, 1.164457, -0.004270}}],
    Polygon[{{1.295754, 1.168518, -0.002162},{1.295584, 1.168518, 0.000000},{
      1.296260, 1.164248, 0.000000},{1.296422, 1.164301, -0.002162}}],
    Polygon[{{1.295584, 1.168518, 0.000000},{1.295754, 1.168518, 0.002162},{
      1.296422, 1.164301, 0.002162},{1.296260, 1.164248, 0.000000}}],
    Polygon[{{1.295754, 1.168518, 0.002162},{1.296260, 1.168518, 0.004270},{
      1.296903, 1.164457, 0.004270},{1.296422, 1.164301, 0.002162}}],
    Polygon[{{1.296260, 1.168518, 0.004270},{1.297090, 1.168518, 0.006273},{
      1.297692, 1.164713, 0.006273},{1.296903, 1.164457, 0.004270}}],
    Polygon[{{1.297090, 1.168518, 0.006273},{1.298223, 1.168518, 0.008122},{
      1.298770, 1.165064, 0.008122},{1.297692, 1.164713, 0.006273}}],
    Polygon[{{1.298223, 1.168518, 0.008122},{1.299631, 1.168518, 0.009770},{
      1.300109, 1.165499, 0.009770},{1.298770, 1.165064, 0.008122}}],
    Polygon[{{1.299631, 1.168518, 0.009770},{1.301279, 1.168518, 0.011178},{
      1.301677, 1.166008, 0.011178},{1.300109, 1.165499, 0.009770}}],
    Polygon[{{1.301279, 1.168518, 0.011178},{1.303128, 1.168518, 0.012311},{
      1.303435, 1.166579, 0.012311},{1.301677, 1.166008, 0.011178}}],
    Polygon[{{1.303128, 1.168518, 0.012311},{1.305131, 1.168518, 0.013141},{
      1.305340, 1.167198, 0.013141},{1.303435, 1.166579, 0.012311}}],
    Polygon[{{1.305131, 1.168518, 0.013141},{1.307240, 1.168518, 0.013647},{
      1.307345, 1.167850, 0.013647},{1.305340, 1.167198, 0.013141}}],
    Polygon[{{1.307345, 1.167850, -0.013647},{1.305340, 1.167198, -0.013141},{
      1.305947, 1.166008, -0.013141},{1.307652, 1.167247, -0.013647}}],
    Polygon[{{1.305340, 1.167198, -0.013141},{1.303435, 1.166579, -0.012311},{
      1.304326, 1.164831, -0.012311},{1.305947, 1.166008, -0.013141}}],
    Polygon[{{1.303435, 1.166579, -0.012311},{1.301677, 1.166008, -0.011178},{
      1.302831, 1.163744, -0.011178},{1.304326, 1.164831, -0.012311}}],
    Polygon[{{1.301677, 1.166008, -0.011178},{1.300109, 1.165499, -0.009770},{
      1.301497, 1.162775, -0.009770},{1.302831, 1.163744, -0.011178}}],
    Polygon[{{1.300109, 1.165499, -0.009770},{1.298770, 1.165064, -0.008122},{
      1.300358, 1.161947, -0.008122},{1.301497, 1.162775, -0.009770}}],
    Polygon[{{1.298770, 1.165064, -0.008122},{1.297692, 1.164713, -0.006273},{
      1.299441, 1.161281, -0.006273},{1.300358, 1.161947, -0.008122}}],
    Polygon[{{1.297692, 1.164713, -0.006273},{1.296903, 1.164457, -0.004270},{
      1.298770, 1.160794, -0.004270},{1.299441, 1.161281, -0.006273}}],
    Polygon[{{1.296903, 1.164457, -0.004270},{1.296422, 1.164301, -0.002162},{
      1.298360, 1.160496, -0.002162},{1.298770, 1.160794, -0.004270}}],
    Polygon[{{1.296422, 1.164301, -0.002162},{1.296260, 1.164248, 0.000000},{
      1.298223, 1.160396, 0.000000},{1.298360, 1.160496, -0.002162}}],
    Polygon[{{1.296260, 1.164248, 0.000000},{1.296422, 1.164301, 0.002162},{
      1.298360, 1.160496, 0.002162},{1.298223, 1.160396, 0.000000}}],
    Polygon[{{1.296422, 1.164301, 0.002162},{1.296903, 1.164457, 0.004270},{
      1.298770, 1.160794, 0.004270},{1.298360, 1.160496, 0.002162}}],
    Polygon[{{1.296903, 1.164457, 0.004270},{1.297692, 1.164713, 0.006273},{
      1.299441, 1.161281, 0.006273},{1.298770, 1.160794, 0.004270}}],
    Polygon[{{1.297692, 1.164713, 0.006273},{1.298770, 1.165064, 0.008122},{
      1.300358, 1.161947, 0.008122},{1.299441, 1.161281, 0.006273}}],
    Polygon[{{1.298770, 1.165064, 0.008122},{1.300109, 1.165499, 0.009770},{
      1.301497, 1.162775, 0.009770},{1.300358, 1.161947, 0.008122}}],
    Polygon[{{1.300109, 1.165499, 0.009770},{1.301677, 1.166008, 0.011178},{
      1.302831, 1.163744, 0.011178},{1.301497, 1.162775, 0.009770}}],
    Polygon[{{1.301677, 1.166008, 0.011178},{1.303435, 1.166579, 0.012311},{
      1.304326, 1.164831, 0.012311},{1.302831, 1.163744, 0.011178}}],
    Polygon[{{1.303435, 1.166579, 0.012311},{1.305340, 1.167198, 0.013141},{
      1.305947, 1.166008, 0.013141},{1.304326, 1.164831, 0.012311}}],
    Polygon[{{1.305340, 1.167198, 0.013141},{1.307345, 1.167850, 0.013647},{
      1.307652, 1.167247, 0.013647},{1.305947, 1.166008, 0.013141}}],
    Polygon[{{1.307652, 1.167247, -0.013647},{1.305947, 1.166008, -0.013141},{
      1.306891, 1.165064, -0.013141},{1.308131, 1.166769, -0.013647}}],
    Polygon[{{1.305947, 1.166008, -0.013141},{1.304326, 1.164831, -0.012311},{
      1.305714, 1.163443, -0.012311},{1.306891, 1.165064, -0.013141}}],
    Polygon[{{1.304326, 1.164831, -0.012311},{1.302831, 1.163744, -0.011178},{
      1.304627, 1.161947, -0.011178},{1.305714, 1.163443, -0.012311}}],
    Polygon[{{1.302831, 1.163744, -0.011178},{1.301497, 1.162775, -0.009770},{
      1.303658, 1.160614, -0.009770},{1.304627, 1.161947, -0.011178}}],
    Polygon[{{1.301497, 1.162775, -0.009770},{1.300358, 1.161947, -0.008122},{
      1.302831, 1.159474, -0.008122},{1.303658, 1.160614, -0.009770}}],
    Polygon[{{1.300358, 1.161947, -0.008122},{1.299441, 1.161281, -0.006273},{
      1.302165, 1.158558, -0.006273},{1.302831, 1.159474, -0.008122}}],
    Polygon[{{1.299441, 1.161281, -0.006273},{1.298770, 1.160794, -0.004270},{
      1.301677, 1.157887, -0.004270},{1.302165, 1.158558, -0.006273}}],
    Polygon[{{1.298770, 1.160794, -0.004270},{1.298360, 1.160496, -0.002162},{
      1.301379, 1.157477, -0.002162},{1.301677, 1.157887, -0.004270}}],
    Polygon[{{1.298360, 1.160496, -0.002162},{1.298223, 1.160396, 0.000000},{
      1.301279, 1.157339, 0.000000},{1.301379, 1.157477, -0.002162}}],
    Polygon[{{1.298223, 1.160396, 0.000000},{1.298360, 1.160496, 0.002162},{
      1.301379, 1.157477, 0.002162},{1.301279, 1.157339, 0.000000}}],
    Polygon[{{1.298360, 1.160496, 0.002162},{1.298770, 1.160794, 0.004270},{
      1.301677, 1.157887, 0.004270},{1.301379, 1.157477, 0.002162}}],
    Polygon[{{1.298770, 1.160794, 0.004270},{1.299441, 1.161281, 0.006273},{
      1.302165, 1.158558, 0.006273},{1.301677, 1.157887, 0.004270}}],
    Polygon[{{1.299441, 1.161281, 0.006273},{1.300358, 1.161947, 0.008122},{
      1.302831, 1.159474, 0.008122},{1.302165, 1.158558, 0.006273}}],
    Polygon[{{1.300358, 1.161947, 0.008122},{1.301497, 1.162775, 0.009770},{
      1.303658, 1.160614, 0.009770},{1.302831, 1.159474, 0.008122}}],
    Polygon[{{1.301497, 1.162775, 0.009770},{1.302831, 1.163744, 0.011178},{
      1.304627, 1.161947, 0.011178},{1.303658, 1.160614, 0.009770}}],
    Polygon[{{1.302831, 1.163744, 0.011178},{1.304326, 1.164831, 0.012311},{
      1.305714, 1.163443, 0.012311},{1.304627, 1.161947, 0.011178}}],
    Polygon[{{1.304326, 1.164831, 0.012311},{1.305947, 1.166008, 0.013141},{
      1.306891, 1.165064, 0.013141},{1.305714, 1.163443, 0.012311}}],
    Polygon[{{1.305947, 1.166008, 0.013141},{1.307652, 1.167247, 0.013647},{
      1.308131, 1.166769, 0.013647},{1.306891, 1.165064, 0.013141}}],
    Polygon[{{1.308131, 1.166769, -0.013647},{1.306891, 1.165064, -0.013141},{
      1.308082, 1.164457, -0.013141},{1.308733, 1.166462, -0.013647}}],
    Polygon[{{1.306891, 1.165064, -0.013141},{1.305714, 1.163443, -0.012311},{
      1.307463, 1.162552, -0.012311},{1.308082, 1.164457, -0.013141}}],
    Polygon[{{1.305714, 1.163443, -0.012311},{1.304627, 1.161947, -0.011178},{
      1.306891, 1.160794, -0.011178},{1.307463, 1.162552, -0.012311}}],
    Polygon[{{1.304627, 1.161947, -0.011178},{1.303658, 1.160614, -0.009770},{
      1.306382, 1.159226, -0.009770},{1.306891, 1.160794, -0.011178}}],
    Polygon[{{1.303658, 1.160614, -0.009770},{1.302831, 1.159474, -0.008122},{
      1.305947, 1.157887, -0.008122},{1.306382, 1.159226, -0.009770}}],
    Polygon[{{1.302831, 1.159474, -0.008122},{1.302165, 1.158558, -0.006273},{
      1.305597, 1.156809, -0.006273},{1.305947, 1.157887, -0.008122}}],
    Polygon[{{1.302165, 1.158558, -0.006273},{1.301677, 1.157887, -0.004270},{
      1.305340, 1.156020, -0.004270},{1.305597, 1.156809, -0.006273}}],
    Polygon[{{1.301677, 1.157887, -0.004270},{1.301379, 1.157477, -0.002162},{
      1.305184, 1.155539, -0.002162},{1.305340, 1.156020, -0.004270}}],
    Polygon[{{1.301379, 1.157477, -0.002162},{1.301279, 1.157339, 0.000000},{
      1.305131, 1.155377, 0.000000},{1.305184, 1.155539, -0.002162}}],
    Polygon[{{1.301279, 1.157339, 0.000000},{1.301379, 1.157477, 0.002162},{
      1.305184, 1.155539, 0.002162},{1.305131, 1.155377, 0.000000}}],
    Polygon[{{1.301379, 1.157477, 0.002162},{1.301677, 1.157887, 0.004270},{
      1.305340, 1.156020, 0.004270},{1.305184, 1.155539, 0.002162}}],
    Polygon[{{1.301677, 1.157887, 0.004270},{1.302165, 1.158558, 0.006273},{
      1.305597, 1.156809, 0.006273},{1.305340, 1.156020, 0.004270}}],
    Polygon[{{1.302165, 1.158558, 0.006273},{1.302831, 1.159474, 0.008122},{
      1.305947, 1.157887, 0.008122},{1.305597, 1.156809, 0.006273}}],
    Polygon[{{1.302831, 1.159474, 0.008122},{1.303658, 1.160614, 0.009770},{
      1.306382, 1.159226, 0.009770},{1.305947, 1.157887, 0.008122}}],
    Polygon[{{1.303658, 1.160614, 0.009770},{1.304627, 1.161947, 0.011178},{
      1.306891, 1.160794, 0.011178},{1.306382, 1.159226, 0.009770}}],
    Polygon[{{1.304627, 1.161947, 0.011178},{1.305714, 1.163443, 0.012311},{
      1.307463, 1.162552, 0.012311},{1.306891, 1.160794, 0.011178}}],
    Polygon[{{1.305714, 1.163443, 0.012311},{1.306891, 1.165064, 0.013141},{
      1.308082, 1.164457, 0.013141},{1.307463, 1.162552, 0.012311}}],
    Polygon[{{1.306891, 1.165064, 0.013141},{1.308131, 1.166769, 0.013647},{
      1.308733, 1.166462, 0.013647},{1.308082, 1.164457, 0.013141}}],
    Polygon[{{1.308733, 1.166462, -0.013647},{1.308082, 1.164457, -0.013141},{
      1.309401, 1.164248, -0.013141},{1.309401, 1.166356, -0.013647}}],
    Polygon[{{1.308082, 1.164457, -0.013141},{1.307463, 1.162552, -0.012311},{
      1.309401, 1.162245, -0.012311},{1.309401, 1.164248, -0.013141}}],
    Polygon[{{1.307463, 1.162552, -0.012311},{1.306891, 1.160794, -0.011178},{
      1.309401, 1.160396, -0.011178},{1.309401, 1.162245, -0.012311}}],
    Polygon[{{1.306891, 1.160794, -0.011178},{1.306382, 1.159226, -0.009770},{
      1.309401, 1.158748, -0.009770},{1.309401, 1.160396, -0.011178}}],
    Polygon[{{1.306382, 1.159226, -0.009770},{1.305947, 1.157887, -0.008122},{
      1.309401, 1.157339, -0.008122},{1.309401, 1.158748, -0.009770}}],
    Polygon[{{1.305947, 1.157887, -0.008122},{1.305597, 1.156809, -0.006273},{
      1.309401, 1.156206, -0.006273},{1.309401, 1.157339, -0.008122}}],
    Polygon[{{1.305597, 1.156809, -0.006273},{1.305340, 1.156020, -0.004270},{
      1.309401, 1.155377, -0.004270},{1.309401, 1.156206, -0.006273}}],
    Polygon[{{1.305340, 1.156020, -0.004270},{1.305184, 1.155539, -0.002162},{
      1.309401, 1.154871, -0.002162},{1.309401, 1.155377, -0.004270}}],
    Polygon[{{1.305184, 1.155539, -0.002162},{1.305131, 1.155377, 0.000000},{
      1.309401, 1.154701, 0.000000},{1.309401, 1.154871, -0.002162}}],
    Polygon[{{1.305131, 1.155377, 0.000000},{1.305184, 1.155539, 0.002162},{
      1.309401, 1.154871, 0.002162},{1.309401, 1.154701, 0.000000}}],
    Polygon[{{1.305184, 1.155539, 0.002162},{1.305340, 1.156020, 0.004270},{
      1.309401, 1.155377, 0.004270},{1.309401, 1.154871, 0.002162}}],
    Polygon[{{1.305340, 1.156020, 0.004270},{1.305597, 1.156809, 0.006273},{
      1.309401, 1.156206, 0.006273},{1.309401, 1.155377, 0.004270}}],
    Polygon[{{1.305597, 1.156809, 0.006273},{1.305947, 1.157887, 0.008122},{
      1.309401, 1.157339, 0.008122},{1.309401, 1.156206, 0.006273}}],
    Polygon[{{1.305947, 1.157887, 0.008122},{1.306382, 1.159226, 0.009770},{
      1.309401, 1.158748, 0.009770},{1.309401, 1.157339, 0.008122}}],
    Polygon[{{1.306382, 1.159226, 0.009770},{1.306891, 1.160794, 0.011178},{
      1.309401, 1.160396, 0.011178},{1.309401, 1.158748, 0.009770}}],
    Polygon[{{1.306891, 1.160794, 0.011178},{1.307463, 1.162552, 0.012311},{
      1.309401, 1.162245, 0.012311},{1.309401, 1.160396, 0.011178}}],
    Polygon[{{1.307463, 1.162552, 0.012311},{1.308082, 1.164457, 0.013141},{
      1.309401, 1.164248, 0.013141},{1.309401, 1.162245, 0.012311}}],
    Polygon[{{1.308082, 1.164457, 0.013141},{1.308733, 1.166462, 0.013647},{
      1.309401, 1.166356, 0.013647},{1.309401, 1.164248, 0.013141}}],
    Polygon[{{1.309401, 1.166356, -0.013647},{1.309401, 1.164248, -0.013141},{
      1.310721, 1.164457, -0.013141},{1.310069, 1.166462, -0.013647}}],
    Polygon[{{1.309401, 1.164248, -0.013141},{1.309401, 1.162245, -0.012311},{
      1.311339, 1.162552, -0.012311},{1.310721, 1.164457, -0.013141}}],
    Polygon[{{1.309401, 1.162245, -0.012311},{1.309401, 1.160396, -0.011178},{
      1.311911, 1.160794, -0.011178},{1.311339, 1.162552, -0.012311}}],
    Polygon[{{1.309401, 1.160396, -0.011178},{1.309401, 1.158748, -0.009770},{
      1.312420, 1.159226, -0.009770},{1.311911, 1.160794, -0.011178}}],
    Polygon[{{1.309401, 1.158748, -0.009770},{1.309401, 1.157339, -0.008122},{
      1.312855, 1.157887, -0.008122},{1.312420, 1.159226, -0.009770}}],
    Polygon[{{1.309401, 1.157339, -0.008122},{1.309401, 1.156206, -0.006273},{
      1.313205, 1.156809, -0.006273},{1.312855, 1.157887, -0.008122}}],
    Polygon[{{1.309401, 1.156206, -0.006273},{1.309401, 1.155377, -0.004270},{
      1.313462, 1.156020, -0.004270},{1.313205, 1.156809, -0.006273}}],
    Polygon[{{1.309401, 1.155377, -0.004270},{1.309401, 1.154871, -0.002162},{
      1.313618, 1.155539, -0.002162},{1.313462, 1.156020, -0.004270}}],
    Polygon[{{1.309401, 1.154871, -0.002162},{1.309401, 1.154701, 0.000000},{
      1.313671, 1.155377, 0.000000},{1.313618, 1.155539, -0.002162}}],
    Polygon[{{1.309401, 1.154701, 0.000000},{1.309401, 1.154871, 0.002162},{
      1.313618, 1.155539, 0.002162},{1.313671, 1.155377, 0.000000}}],
    Polygon[{{1.309401, 1.154871, 0.002162},{1.309401, 1.155377, 0.004270},{
      1.313462, 1.156020, 0.004270},{1.313618, 1.155539, 0.002162}}],
    Polygon[{{1.309401, 1.155377, 0.004270},{1.309401, 1.156206, 0.006273},{
      1.313205, 1.156809, 0.006273},{1.313462, 1.156020, 0.004270}}],
    Polygon[{{1.309401, 1.156206, 0.006273},{1.309401, 1.157339, 0.008122},{
      1.312855, 1.157887, 0.008122},{1.313205, 1.156809, 0.006273}}],
    Polygon[{{1.309401, 1.157339, 0.008122},{1.309401, 1.158748, 0.009770},{
      1.312420, 1.159226, 0.009770},{1.312855, 1.157887, 0.008122}}],
    Polygon[{{1.309401, 1.158748, 0.009770},{1.309401, 1.160396, 0.011178},{
      1.311911, 1.160794, 0.011178},{1.312420, 1.159226, 0.009770}}],
    Polygon[{{1.309401, 1.160396, 0.011178},{1.309401, 1.162245, 0.012311},{
      1.311339, 1.162552, 0.012311},{1.311911, 1.160794, 0.011178}}],
    Polygon[{{1.309401, 1.162245, 0.012311},{1.309401, 1.164248, 0.013141},{
      1.310721, 1.164457, 0.013141},{1.311339, 1.162552, 0.012311}}],
    Polygon[{{1.309401, 1.164248, 0.013141},{1.309401, 1.166356, 0.013647},{
      1.310069, 1.166462, 0.013647},{1.310721, 1.164457, 0.013141}}],
    Polygon[{{1.310069, 1.166462, -0.013647},{1.310721, 1.164457, -0.013141},{
      1.311911, 1.165064, -0.013141},{1.310672, 1.166769, -0.013647}}],
    Polygon[{{1.310721, 1.164457, -0.013141},{1.311339, 1.162552, -0.012311},{
      1.313088, 1.163443, -0.012311},{1.311911, 1.165064, -0.013141}}],
    Polygon[{{1.311339, 1.162552, -0.012311},{1.311911, 1.160794, -0.011178},{
      1.314175, 1.161947, -0.011178},{1.313088, 1.163443, -0.012311}}],
    Polygon[{{1.311911, 1.160794, -0.011178},{1.312420, 1.159226, -0.009770},{
      1.315144, 1.160614, -0.009770},{1.314175, 1.161947, -0.011178}}],
    Polygon[{{1.312420, 1.159226, -0.009770},{1.312855, 1.157887, -0.008122},{
      1.315972, 1.159474, -0.008122},{1.315144, 1.160614, -0.009770}}],
    Polygon[{{1.312855, 1.157887, -0.008122},{1.313205, 1.156809, -0.006273},{
      1.316638, 1.158558, -0.006273},{1.315972, 1.159474, -0.008122}}],
    Polygon[{{1.313205, 1.156809, -0.006273},{1.313462, 1.156020, -0.004270},{
      1.317125, 1.157887, -0.004270},{1.316638, 1.158558, -0.006273}}],
    Polygon[{{1.313462, 1.156020, -0.004270},{1.313618, 1.155539, -0.002162},{
      1.317423, 1.157477, -0.002162},{1.317125, 1.157887, -0.004270}}],
    Polygon[{{1.313618, 1.155539, -0.002162},{1.313671, 1.155377, 0.000000},{
      1.317523, 1.157339, 0.000000},{1.317423, 1.157477, -0.002162}}],
    Polygon[{{1.313671, 1.155377, 0.000000},{1.313618, 1.155539, 0.002162},{
      1.317423, 1.157477, 0.002162},{1.317523, 1.157339, 0.000000}}],
    Polygon[{{1.313618, 1.155539, 0.002162},{1.313462, 1.156020, 0.004270},{
      1.317125, 1.157887, 0.004270},{1.317423, 1.157477, 0.002162}}],
    Polygon[{{1.313462, 1.156020, 0.004270},{1.313205, 1.156809, 0.006273},{
      1.316638, 1.158558, 0.006273},{1.317125, 1.157887, 0.004270}}],
    Polygon[{{1.313205, 1.156809, 0.006273},{1.312855, 1.157887, 0.008122},{
      1.315972, 1.159474, 0.008122},{1.316638, 1.158558, 0.006273}}],
    Polygon[{{1.312855, 1.157887, 0.008122},{1.312420, 1.159226, 0.009770},{
      1.315144, 1.160614, 0.009770},{1.315972, 1.159474, 0.008122}}],
    Polygon[{{1.312420, 1.159226, 0.009770},{1.311911, 1.160794, 0.011178},{
      1.314175, 1.161947, 0.011178},{1.315144, 1.160614, 0.009770}}],
    Polygon[{{1.311911, 1.160794, 0.011178},{1.311339, 1.162552, 0.012311},{
      1.313088, 1.163443, 0.012311},{1.314175, 1.161947, 0.011178}}],
    Polygon[{{1.311339, 1.162552, 0.012311},{1.310721, 1.164457, 0.013141},{
      1.311911, 1.165064, 0.013141},{1.313088, 1.163443, 0.012311}}],
    Polygon[{{1.310721, 1.164457, 0.013141},{1.310069, 1.166462, 0.013647},{
      1.310672, 1.166769, 0.013647},{1.311911, 1.165064, 0.013141}}],
    Polygon[{{1.310672, 1.166769, -0.013647},{1.311911, 1.165064, -0.013141},{
      1.312855, 1.166008, -0.013141},{1.311150, 1.167247, -0.013647}}],
    Polygon[{{1.311911, 1.165064, -0.013141},{1.313088, 1.163443, -0.012311},{
      1.314476, 1.164831, -0.012311},{1.312855, 1.166008, -0.013141}}],
    Polygon[{{1.313088, 1.163443, -0.012311},{1.314175, 1.161947, -0.011178},{
      1.315972, 1.163744, -0.011178},{1.314476, 1.164831, -0.012311}}],
    Polygon[{{1.314175, 1.161947, -0.011178},{1.315144, 1.160614, -0.009770},{
      1.317305, 1.162775, -0.009770},{1.315972, 1.163744, -0.011178}}],
    Polygon[{{1.315144, 1.160614, -0.009770},{1.315972, 1.159474, -0.008122},{
      1.318445, 1.161947, -0.008122},{1.317305, 1.162775, -0.009770}}],
    Polygon[{{1.315972, 1.159474, -0.008122},{1.316638, 1.158558, -0.006273},{
      1.319361, 1.161281, -0.006273},{1.318445, 1.161947, -0.008122}}],
    Polygon[{{1.316638, 1.158558, -0.006273},{1.317125, 1.157887, -0.004270},{
      1.320032, 1.160794, -0.004270},{1.319361, 1.161281, -0.006273}}],
    Polygon[{{1.317125, 1.157887, -0.004270},{1.317423, 1.157477, -0.002162},{
      1.320442, 1.160496, -0.002162},{1.320032, 1.160794, -0.004270}}],
    Polygon[{{1.317423, 1.157477, -0.002162},{1.317523, 1.157339, 0.000000},{
      1.320580, 1.160396, 0.000000},{1.320442, 1.160496, -0.002162}}],
    Polygon[{{1.317523, 1.157339, 0.000000},{1.317423, 1.157477, 0.002162},{
      1.320442, 1.160496, 0.002162},{1.320580, 1.160396, 0.000000}}],
    Polygon[{{1.317423, 1.157477, 0.002162},{1.317125, 1.157887, 0.004270},{
      1.320032, 1.160794, 0.004270},{1.320442, 1.160496, 0.002162}}],
    Polygon[{{1.317125, 1.157887, 0.004270},{1.316638, 1.158558, 0.006273},{
      1.319361, 1.161281, 0.006273},{1.320032, 1.160794, 0.004270}}],
    Polygon[{{1.316638, 1.158558, 0.006273},{1.315972, 1.159474, 0.008122},{
      1.318445, 1.161947, 0.008122},{1.319361, 1.161281, 0.006273}}],
    Polygon[{{1.315972, 1.159474, 0.008122},{1.315144, 1.160614, 0.009770},{
      1.317305, 1.162775, 0.009770},{1.318445, 1.161947, 0.008122}}],
    Polygon[{{1.315144, 1.160614, 0.009770},{1.314175, 1.161947, 0.011178},{
      1.315972, 1.163744, 0.011178},{1.317305, 1.162775, 0.009770}}],
    Polygon[{{1.314175, 1.161947, 0.011178},{1.313088, 1.163443, 0.012311},{
      1.314476, 1.164831, 0.012311},{1.315972, 1.163744, 0.011178}}],
    Polygon[{{1.313088, 1.163443, 0.012311},{1.311911, 1.165064, 0.013141},{
      1.312855, 1.166008, 0.013141},{1.314476, 1.164831, 0.012311}}],
    Polygon[{{1.311911, 1.165064, 0.013141},{1.310672, 1.166769, 0.013647},{
      1.311150, 1.167247, 0.013647},{1.312855, 1.166008, 0.013141}}],
    Polygon[{{1.311150, 1.167247, -0.013647},{1.312855, 1.166008, -0.013141},{
      1.313462, 1.167198, -0.013141},{1.311457, 1.167850, -0.013647}}],
    Polygon[{{1.312855, 1.166008, -0.013141},{1.314476, 1.164831, -0.012311},{
      1.315367, 1.166579, -0.012311},{1.313462, 1.167198, -0.013141}}],
    Polygon[{{1.314476, 1.164831, -0.012311},{1.315972, 1.163744, -0.011178},{
      1.317125, 1.166008, -0.011178},{1.315367, 1.166579, -0.012311}}],
    Polygon[{{1.315972, 1.163744, -0.011178},{1.317305, 1.162775, -0.009770},{
      1.318693, 1.165499, -0.009770},{1.317125, 1.166008, -0.011178}}],
    Polygon[{{1.317305, 1.162775, -0.009770},{1.318445, 1.161947, -0.008122},{
      1.320032, 1.165064, -0.008122},{1.318693, 1.165499, -0.009770}}],
    Polygon[{{1.318445, 1.161947, -0.008122},{1.319361, 1.161281, -0.006273},{
      1.321110, 1.164713, -0.006273},{1.320032, 1.165064, -0.008122}}],
    Polygon[{{1.319361, 1.161281, -0.006273},{1.320032, 1.160794, -0.004270},{
      1.321899, 1.164457, -0.004270},{1.321110, 1.164713, -0.006273}}],
    Polygon[{{1.320032, 1.160794, -0.004270},{1.320442, 1.160496, -0.002162},{
      1.322380, 1.164301, -0.002162},{1.321899, 1.164457, -0.004270}}],
    Polygon[{{1.320442, 1.160496, -0.002162},{1.320580, 1.160396, 0.000000},{
      1.322542, 1.164248, 0.000000},{1.322380, 1.164301, -0.002162}}],
    Polygon[{{1.320580, 1.160396, 0.000000},{1.320442, 1.160496, 0.002162},{
      1.322380, 1.164301, 0.002162},{1.322542, 1.164248, 0.000000}}],
    Polygon[{{1.320442, 1.160496, 0.002162},{1.320032, 1.160794, 0.004270},{
      1.321899, 1.164457, 0.004270},{1.322380, 1.164301, 0.002162}}],
    Polygon[{{1.320032, 1.160794, 0.004270},{1.319361, 1.161281, 0.006273},{
      1.321110, 1.164713, 0.006273},{1.321899, 1.164457, 0.004270}}],
    Polygon[{{1.319361, 1.161281, 0.006273},{1.318445, 1.161947, 0.008122},{
      1.320032, 1.165064, 0.008122},{1.321110, 1.164713, 0.006273}}],
    Polygon[{{1.318445, 1.161947, 0.008122},{1.317305, 1.162775, 0.009770},{
      1.318693, 1.165499, 0.009770},{1.320032, 1.165064, 0.008122}}],
    Polygon[{{1.317305, 1.162775, 0.009770},{1.315972, 1.163744, 0.011178},{
      1.317125, 1.166008, 0.011178},{1.318693, 1.165499, 0.009770}}],
    Polygon[{{1.315972, 1.163744, 0.011178},{1.314476, 1.164831, 0.012311},{
      1.315367, 1.166579, 0.012311},{1.317125, 1.166008, 0.011178}}],
    Polygon[{{1.314476, 1.164831, 0.012311},{1.312855, 1.166008, 0.013141},{
      1.313462, 1.167198, 0.013141},{1.315367, 1.166579, 0.012311}}],
    Polygon[{{1.312855, 1.166008, 0.013141},{1.311150, 1.167247, 0.013647},{
      1.311457, 1.167850, 0.013647},{1.313462, 1.167198, 0.013141}}],
    Polygon[{{1.311457, 1.167850, -0.013647},{1.313462, 1.167198, -0.013141},{
      1.313671, 1.168518, -0.013141},{1.311563, 1.168518, -0.013647}}],
    Polygon[{{1.313462, 1.167198, -0.013141},{1.315367, 1.166579, -0.012311},{
      1.315674, 1.168518, -0.012311},{1.313671, 1.168518, -0.013141}}],
    Polygon[{{1.315367, 1.166579, -0.012311},{1.317125, 1.166008, -0.011178},{
      1.317523, 1.168518, -0.011178},{1.315674, 1.168518, -0.012311}}],
    Polygon[{{1.317125, 1.166008, -0.011178},{1.318693, 1.165499, -0.009770},{
      1.319171, 1.168518, -0.009770},{1.317523, 1.168518, -0.011178}}],
    Polygon[{{1.318693, 1.165499, -0.009770},{1.320032, 1.165064, -0.008122},{
      1.320580, 1.168518, -0.008122},{1.319171, 1.168518, -0.009770}}],
    Polygon[{{1.320032, 1.165064, -0.008122},{1.321110, 1.164713, -0.006273},{
      1.321712, 1.168518, -0.006273},{1.320580, 1.168518, -0.008122}}],
    Polygon[{{1.321110, 1.164713, -0.006273},{1.321899, 1.164457, -0.004270},{
      1.322542, 1.168518, -0.004270},{1.321712, 1.168518, -0.006273}}],
    Polygon[{{1.321899, 1.164457, -0.004270},{1.322380, 1.164301, -0.002162},{
      1.323048, 1.168518, -0.002162},{1.322542, 1.168518, -0.004270}}],
    Polygon[{{1.322380, 1.164301, -0.002162},{1.322542, 1.164248, 0.000000},{
      1.323218, 1.168518, 0.000000},{1.323048, 1.168518, -0.002162}}],
    Polygon[{{1.322542, 1.164248, 0.000000},{1.322380, 1.164301, 0.002162},{
      1.323048, 1.168518, 0.002162},{1.323218, 1.168518, 0.000000}}],
    Polygon[{{1.322380, 1.164301, 0.002162},{1.321899, 1.164457, 0.004270},{
      1.322542, 1.168518, 0.004270},{1.323048, 1.168518, 0.002162}}],
    Polygon[{{1.321899, 1.164457, 0.004270},{1.321110, 1.164713, 0.006273},{
      1.321712, 1.168518, 0.006273},{1.322542, 1.168518, 0.004270}}],
    Polygon[{{1.321110, 1.164713, 0.006273},{1.320032, 1.165064, 0.008122},{
      1.320580, 1.168518, 0.008122},{1.321712, 1.168518, 0.006273}}],
    Polygon[{{1.320032, 1.165064, 0.008122},{1.318693, 1.165499, 0.009770},{
      1.319171, 1.168518, 0.009770},{1.320580, 1.168518, 0.008122}}],
    Polygon[{{1.318693, 1.165499, 0.009770},{1.317125, 1.166008, 0.011178},{
      1.317523, 1.168518, 0.011178},{1.319171, 1.168518, 0.009770}}],
    Polygon[{{1.317125, 1.166008, 0.011178},{1.315367, 1.166579, 0.012311},{
      1.315674, 1.168518, 0.012311},{1.317523, 1.168518, 0.011178}}],
    Polygon[{{1.315367, 1.166579, 0.012311},{1.313462, 1.167198, 0.013141},{
      1.313671, 1.168518, 0.013141},{1.315674, 1.168518, 0.012311}}],
    Polygon[{{1.313462, 1.167198, 0.013141},{1.311457, 1.167850, 0.013647},{
      1.311563, 1.168518, 0.013647},{1.313671, 1.168518, 0.013141}}],
    Polygon[{{1.257198, 1.109580, -0.012733},{1.259165, 1.109580, -0.012261},{
      1.258970, 1.110811, -0.012261},{1.257100, 1.110203, -0.012733}}],
    Polygon[{{1.259165, 1.109580, -0.012261},{1.261034, 1.109580, -0.011487},{
      1.260748, 1.111388, -0.011487},{1.258970, 1.110811, -0.012261}}],
    Polygon[{{1.261034, 1.109580, -0.011487},{1.262759, 1.109580, -0.010430},{
      1.262388, 1.111921, -0.010430},{1.260748, 1.111388, -0.011487}}],
    Polygon[{{1.262759, 1.109580, -0.010430},{1.264297, 1.109580, -0.009116},{
      1.263851, 1.112396, -0.009116},{1.262388, 1.111921, -0.010430}}],
    Polygon[{{1.264297, 1.109580, -0.009116},{1.265611, 1.109580, -0.007578},{
      1.265101, 1.112803, -0.007578},{1.263851, 1.112396, -0.009116}}],
    Polygon[{{1.265611, 1.109580, -0.007578},{1.266668, 1.109580, -0.005853},{
      1.266106, 1.113129, -0.005853},{1.265101, 1.112803, -0.007578}}],
    Polygon[{{1.266668, 1.109580, -0.005853},{1.267442, 1.109580, -0.003984},{
      1.266842, 1.113368, -0.003984},{1.266106, 1.113129, -0.005853}}],
    Polygon[{{1.267442, 1.109580, -0.003984},{1.267915, 1.109580, -0.002017},{
      1.267291, 1.113514, -0.002017},{1.266842, 1.113368, -0.003984}}],
    Polygon[{{1.267915, 1.109580, -0.002017},{1.268073, 1.109580, 0.000000},{
      1.267442, 1.113563, 0.000000},{1.267291, 1.113514, -0.002017}}],
    Polygon[{{1.268073, 1.109580, 0.000000},{1.267915, 1.109580, 0.002017},{
      1.267291, 1.113514, 0.002017},{1.267442, 1.113563, 0.000000}}],
    Polygon[{{1.267915, 1.109580, 0.002017},{1.267442, 1.109580, 0.003984},{
      1.266842, 1.113368, 0.003984},{1.267291, 1.113514, 0.002017}}],
    Polygon[{{1.267442, 1.109580, 0.003984},{1.266668, 1.109580, 0.005853},{
      1.266106, 1.113129, 0.005853},{1.266842, 1.113368, 0.003984}}],
    Polygon[{{1.266668, 1.109580, 0.005853},{1.265611, 1.109580, 0.007578},{
      1.265101, 1.112803, 0.007578},{1.266106, 1.113129, 0.005853}}],
    Polygon[{{1.265611, 1.109580, 0.007578},{1.264297, 1.109580, 0.009116},{
      1.263851, 1.112396, 0.009116},{1.265101, 1.112803, 0.007578}}],
    Polygon[{{1.264297, 1.109580, 0.009116},{1.262759, 1.109580, 0.010430},{
      1.262388, 1.111921, 0.010430},{1.263851, 1.112396, 0.009116}}],
    Polygon[{{1.262759, 1.109580, 0.010430},{1.261034, 1.109580, 0.011487},{
      1.260748, 1.111388, 0.011487},{1.262388, 1.111921, 0.010430}}],
    Polygon[{{1.261034, 1.109580, 0.011487},{1.259165, 1.109580, 0.012261},{
      1.258970, 1.110811, 0.012261},{1.260748, 1.111388, 0.011487}}],
    Polygon[{{1.259165, 1.109580, 0.012261},{1.257198, 1.109580, 0.012733},{
      1.257100, 1.110203, 0.012733},{1.258970, 1.110811, 0.012261}}],
    Polygon[{{1.257100, 1.110203, -0.012733},{1.258970, 1.110811, -0.012261},{
      1.258404, 1.111921, -0.012261},{1.256813, 1.110765, -0.012733}}],
    Polygon[{{1.258970, 1.110811, -0.012261},{1.260748, 1.111388, -0.011487},{
      1.259916, 1.113020, -0.011487},{1.258404, 1.111921, -0.012261}}],
    Polygon[{{1.260748, 1.111388, -0.011487},{1.262388, 1.111921, -0.010430},{
      1.261312, 1.114034, -0.010430},{1.259916, 1.113020, -0.011487}}],
    Polygon[{{1.262388, 1.111921, -0.010430},{1.263851, 1.112396, -0.009116},{
      1.262556, 1.114938, -0.009116},{1.261312, 1.114034, -0.010430}}],
    Polygon[{{1.263851, 1.112396, -0.009116},{1.265101, 1.112803, -0.007578},{
      1.263619, 1.115710, -0.007578},{1.262556, 1.114938, -0.009116}}],
    Polygon[{{1.265101, 1.112803, -0.007578},{1.266106, 1.113129, -0.005853},{
      1.264474, 1.116331, -0.005853},{1.263619, 1.115710, -0.007578}}],
    Polygon[{{1.266106, 1.113129, -0.005853},{1.266842, 1.113368, -0.003984},{
      1.265101, 1.116786, -0.003984},{1.264474, 1.116331, -0.005853}}],
    Polygon[{{1.266842, 1.113368, -0.003984},{1.267291, 1.113514, -0.002017},{
      1.265483, 1.117064, -0.002017},{1.265101, 1.116786, -0.003984}}],
    Polygon[{{1.267291, 1.113514, -0.002017},{1.267442, 1.113563, 0.000000},{
      1.265611, 1.117157, 0.000000},{1.265483, 1.117064, -0.002017}}],
    Polygon[{{1.267442, 1.113563, 0.000000},{1.267291, 1.113514, 0.002017},{
      1.265483, 1.117064, 0.002017},{1.265611, 1.117157, 0.000000}}],
    Polygon[{{1.267291, 1.113514, 0.002017},{1.266842, 1.113368, 0.003984},{
      1.265101, 1.116786, 0.003984},{1.265483, 1.117064, 0.002017}}],
    Polygon[{{1.266842, 1.113368, 0.003984},{1.266106, 1.113129, 0.005853},{
      1.264474, 1.116331, 0.005853},{1.265101, 1.116786, 0.003984}}],
    Polygon[{{1.266106, 1.113129, 0.005853},{1.265101, 1.112803, 0.007578},{
      1.263619, 1.115710, 0.007578},{1.264474, 1.116331, 0.005853}}],
    Polygon[{{1.265101, 1.112803, 0.007578},{1.263851, 1.112396, 0.009116},{
      1.262556, 1.114938, 0.009116},{1.263619, 1.115710, 0.007578}}],
    Polygon[{{1.263851, 1.112396, 0.009116},{1.262388, 1.111921, 0.010430},{
      1.261312, 1.114034, 0.010430},{1.262556, 1.114938, 0.009116}}],
    Polygon[{{1.262388, 1.111921, 0.010430},{1.260748, 1.111388, 0.011487},{
      1.259916, 1.113020, 0.011487},{1.261312, 1.114034, 0.010430}}],
    Polygon[{{1.260748, 1.111388, 0.011487},{1.258970, 1.110811, 0.012261},{
      1.258404, 1.111921, 0.012261},{1.259916, 1.113020, 0.011487}}],
    Polygon[{{1.258970, 1.110811, 0.012261},{1.257100, 1.110203, 0.012733},{
      1.256813, 1.110765, 0.012733},{1.258404, 1.111921, 0.012261}}],
    Polygon[{{1.256813, 1.110765, -0.012733},{1.258404, 1.111921, -0.012261},{
      1.257523, 1.112803, -0.012261},{1.256367, 1.111211, -0.012733}}],
    Polygon[{{1.258404, 1.111921, -0.012261},{1.259916, 1.113020, -0.011487},{
      1.258622, 1.114314, -0.011487},{1.257523, 1.112803, -0.012261}}],
    Polygon[{{1.259916, 1.113020, -0.011487},{1.261312, 1.114034, -0.010430},{
      1.259635, 1.115710, -0.010430},{1.258622, 1.114314, -0.011487}}],
    Polygon[{{1.261312, 1.114034, -0.010430},{1.262556, 1.114938, -0.009116},{
      1.260540, 1.116954, -0.009116},{1.259635, 1.115710, -0.010430}}],
    Polygon[{{1.262556, 1.114938, -0.009116},{1.263619, 1.115710, -0.007578},{
      1.261312, 1.118017, -0.007578},{1.260540, 1.116954, -0.009116}}],
    Polygon[{{1.263619, 1.115710, -0.007578},{1.264474, 1.116331, -0.005853},{
      1.261933, 1.118872, -0.005853},{1.261312, 1.118017, -0.007578}}],
    Polygon[{{1.264474, 1.116331, -0.005853},{1.265101, 1.116786, -0.003984},{
      1.262388, 1.119499, -0.003984},{1.261933, 1.118872, -0.005853}}],
    Polygon[{{1.265101, 1.116786, -0.003984},{1.265483, 1.117064, -0.002017},{
      1.262666, 1.119881, -0.002017},{1.262388, 1.119499, -0.003984}}],
    Polygon[{{1.265483, 1.117064, -0.002017},{1.265611, 1.117157, 0.000000},{
      1.262759, 1.120009, 0.000000},{1.262666, 1.119881, -0.002017}}],
    Polygon[{{1.265611, 1.117157, 0.000000},{1.265483, 1.117064, 0.002017},{
      1.262666, 1.119881, 0.002017},{1.262759, 1.120009, 0.000000}}],
    Polygon[{{1.265483, 1.117064, 0.002017},{1.265101, 1.116786, 0.003984},{
      1.262388, 1.119499, 0.003984},{1.262666, 1.119881, 0.002017}}],
    Polygon[{{1.265101, 1.116786, 0.003984},{1.264474, 1.116331, 0.005853},{
      1.261933, 1.118872, 0.005853},{1.262388, 1.119499, 0.003984}}],
    Polygon[{{1.264474, 1.116331, 0.005853},{1.263619, 1.115710, 0.007578},{
      1.261312, 1.118017, 0.007578},{1.261933, 1.118872, 0.005853}}],
    Polygon[{{1.263619, 1.115710, 0.007578},{1.262556, 1.114938, 0.009116},{
      1.260540, 1.116954, 0.009116},{1.261312, 1.118017, 0.007578}}],
    Polygon[{{1.262556, 1.114938, 0.009116},{1.261312, 1.114034, 0.010430},{
      1.259635, 1.115710, 0.010430},{1.260540, 1.116954, 0.009116}}],
    Polygon[{{1.261312, 1.114034, 0.010430},{1.259916, 1.113020, 0.011487},{
      1.258622, 1.114314, 0.011487},{1.259635, 1.115710, 0.010430}}],
    Polygon[{{1.259916, 1.113020, 0.011487},{1.258404, 1.111921, 0.012261},{
      1.257523, 1.112803, 0.012261},{1.258622, 1.114314, 0.011487}}],
    Polygon[{{1.258404, 1.111921, 0.012261},{1.256813, 1.110765, 0.012733},{
      1.256367, 1.111211, 0.012733},{1.257523, 1.112803, 0.012261}}],
    Polygon[{{1.256367, 1.111211, -0.012733},{1.257523, 1.112803, -0.012261},{
      1.256413, 1.113368, -0.012261},{1.255805, 1.111498, -0.012733}}],
    Polygon[{{1.257523, 1.112803, -0.012261},{1.258622, 1.114314, -0.011487},{
      1.256990, 1.115146, -0.011487},{1.256413, 1.113368, -0.012261}}],
    Polygon[{{1.258622, 1.114314, -0.011487},{1.259635, 1.115710, -0.010430},{
      1.257523, 1.116786, -0.010430},{1.256990, 1.115146, -0.011487}}],
    Polygon[{{1.259635, 1.115710, -0.010430},{1.260540, 1.116954, -0.009116},{
      1.257998, 1.118249, -0.009116},{1.257523, 1.116786, -0.010430}}],
    Polygon[{{1.260540, 1.116954, -0.009116},{1.261312, 1.118017, -0.007578},{
      1.258404, 1.119499, -0.007578},{1.257998, 1.118249, -0.009116}}],
    Polygon[{{1.261312, 1.118017, -0.007578},{1.261933, 1.118872, -0.005853},{
      1.258731, 1.120504, -0.005853},{1.258404, 1.119499, -0.007578}}],
    Polygon[{{1.261933, 1.118872, -0.005853},{1.262388, 1.119499, -0.003984},{
      1.258970, 1.121240, -0.003984},{1.258731, 1.120504, -0.005853}}],
    Polygon[{{1.262388, 1.119499, -0.003984},{1.262666, 1.119881, -0.002017},{
      1.259116, 1.121689, -0.002017},{1.258970, 1.121240, -0.003984}}],
    Polygon[{{1.262666, 1.119881, -0.002017},{1.262759, 1.120009, 0.000000},{
      1.259165, 1.121840, 0.000000},{1.259116, 1.121689, -0.002017}}],
    Polygon[{{1.262759, 1.120009, 0.000000},{1.262666, 1.119881, 0.002017},{
      1.259116, 1.121689, 0.002017},{1.259165, 1.121840, 0.000000}}],
    Polygon[{{1.262666, 1.119881, 0.002017},{1.262388, 1.119499, 0.003984},{
      1.258970, 1.121240, 0.003984},{1.259116, 1.121689, 0.002017}}],
    Polygon[{{1.262388, 1.119499, 0.003984},{1.261933, 1.118872, 0.005853},{
      1.258731, 1.120504, 0.005853},{1.258970, 1.121240, 0.003984}}],
    Polygon[{{1.261933, 1.118872, 0.005853},{1.261312, 1.118017, 0.007578},{
      1.258404, 1.119499, 0.007578},{1.258731, 1.120504, 0.005853}}],
    Polygon[{{1.261312, 1.118017, 0.007578},{1.260540, 1.116954, 0.009116},{
      1.257998, 1.118249, 0.009116},{1.258404, 1.119499, 0.007578}}],
    Polygon[{{1.260540, 1.116954, 0.009116},{1.259635, 1.115710, 0.010430},{
      1.257523, 1.116786, 0.010430},{1.257998, 1.118249, 0.009116}}],
    Polygon[{{1.259635, 1.115710, 0.010430},{1.258622, 1.114314, 0.011487},{
      1.256990, 1.115146, 0.011487},{1.257523, 1.116786, 0.010430}}],
    Polygon[{{1.258622, 1.114314, 0.011487},{1.257523, 1.112803, 0.012261},{
      1.256413, 1.113368, 0.012261},{1.256990, 1.115146, 0.011487}}],
    Polygon[{{1.257523, 1.112803, 0.012261},{1.256367, 1.111211, 0.012733},{
      1.255805, 1.111498, 0.012733},{1.256413, 1.113368, 0.012261}}],
    Polygon[{{1.255805, 1.111498, -0.012733},{1.256413, 1.113368, -0.012261},{
      1.255181, 1.113563, -0.012261},{1.255181, 1.111596, -0.012733}}],
    Polygon[{{1.256413, 1.113368, -0.012261},{1.256990, 1.115146, -0.011487},{
      1.255181, 1.115432, -0.011487},{1.255181, 1.113563, -0.012261}}],
    Polygon[{{1.256990, 1.115146, -0.011487},{1.257523, 1.116786, -0.010430},{
      1.255181, 1.117157, -0.010430},{1.255181, 1.115432, -0.011487}}],
    Polygon[{{1.257523, 1.116786, -0.010430},{1.257998, 1.118249, -0.009116},{
      1.255181, 1.118695, -0.009116},{1.255181, 1.117157, -0.010430}}],
    Polygon[{{1.257998, 1.118249, -0.009116},{1.258404, 1.119499, -0.007578},{
      1.255181, 1.120009, -0.007578},{1.255181, 1.118695, -0.009116}}],
    Polygon[{{1.258404, 1.119499, -0.007578},{1.258731, 1.120504, -0.005853},{
      1.255181, 1.121066, -0.005853},{1.255181, 1.120009, -0.007578}}],
    Polygon[{{1.258731, 1.120504, -0.005853},{1.258970, 1.121240, -0.003984},{
      1.255181, 1.121840, -0.003984},{1.255181, 1.121066, -0.005853}}],
    Polygon[{{1.258970, 1.121240, -0.003984},{1.259116, 1.121689, -0.002017},{
      1.255181, 1.122313, -0.002017},{1.255181, 1.121840, -0.003984}}],
    Polygon[{{1.259116, 1.121689, -0.002017},{1.259165, 1.121840, 0.000000},{
      1.255181, 1.122471, 0.000000},{1.255181, 1.122313, -0.002017}}],
    Polygon[{{1.259165, 1.121840, 0.000000},{1.259116, 1.121689, 0.002017},{
      1.255181, 1.122313, 0.002017},{1.255181, 1.122471, 0.000000}}],
    Polygon[{{1.259116, 1.121689, 0.002017},{1.258970, 1.121240, 0.003984},{
      1.255181, 1.121840, 0.003984},{1.255181, 1.122313, 0.002017}}],
    Polygon[{{1.258970, 1.121240, 0.003984},{1.258731, 1.120504, 0.005853},{
      1.255181, 1.121066, 0.005853},{1.255181, 1.121840, 0.003984}}],
    Polygon[{{1.258731, 1.120504, 0.005853},{1.258404, 1.119499, 0.007578},{
      1.255181, 1.120009, 0.007578},{1.255181, 1.121066, 0.005853}}],
    Polygon[{{1.258404, 1.119499, 0.007578},{1.257998, 1.118249, 0.009116},{
      1.255181, 1.118695, 0.009116},{1.255181, 1.120009, 0.007578}}],
    Polygon[{{1.257998, 1.118249, 0.009116},{1.257523, 1.116786, 0.010430},{
      1.255181, 1.117157, 0.010430},{1.255181, 1.118695, 0.009116}}],
    Polygon[{{1.257523, 1.116786, 0.010430},{1.256990, 1.115146, 0.011487},{
      1.255181, 1.115432, 0.011487},{1.255181, 1.117157, 0.010430}}],
    Polygon[{{1.256990, 1.115146, 0.011487},{1.256413, 1.113368, 0.012261},{
      1.255181, 1.113563, 0.012261},{1.255181, 1.115432, 0.011487}}],
    Polygon[{{1.256413, 1.113368, 0.012261},{1.255805, 1.111498, 0.012733},{
      1.255181, 1.111596, 0.012733},{1.255181, 1.113563, 0.012261}}],
    Polygon[{{1.255181, 1.111596, -0.012733},{1.255181, 1.113563, -0.012261},{
      1.253950, 1.113368, -0.012261},{1.254558, 1.111498, -0.012733}}],
    Polygon[{{1.255181, 1.113563, -0.012261},{1.255181, 1.115432, -0.011487},{
      1.253373, 1.115146, -0.011487},{1.253950, 1.113368, -0.012261}}],
    Polygon[{{1.255181, 1.115432, -0.011487},{1.255181, 1.117157, -0.010430},{
      1.252840, 1.116786, -0.010430},{1.253373, 1.115146, -0.011487}}],
    Polygon[{{1.255181, 1.117157, -0.010430},{1.255181, 1.118695, -0.009116},{
      1.252365, 1.118249, -0.009116},{1.252840, 1.116786, -0.010430}}],
    Polygon[{{1.255181, 1.118695, -0.009116},{1.255181, 1.120009, -0.007578},{
      1.251959, 1.119499, -0.007578},{1.252365, 1.118249, -0.009116}}],
    Polygon[{{1.255181, 1.120009, -0.007578},{1.255181, 1.121066, -0.005853},{
      1.251632, 1.120504, -0.005853},{1.251959, 1.119499, -0.007578}}],
    Polygon[{{1.255181, 1.121066, -0.005853},{1.255181, 1.121840, -0.003984},{
      1.251393, 1.121240, -0.003984},{1.251632, 1.120504, -0.005853}}],
    Polygon[{{1.255181, 1.121840, -0.003984},{1.255181, 1.122313, -0.002017},{
      1.251247, 1.121689, -0.002017},{1.251393, 1.121240, -0.003984}}],
    Polygon[{{1.255181, 1.122313, -0.002017},{1.255181, 1.122471, 0.000000},{
      1.251198, 1.121840, 0.000000},{1.251247, 1.121689, -0.002017}}],
    Polygon[{{1.255181, 1.122471, 0.000000},{1.255181, 1.122313, 0.002017},{
      1.251247, 1.121689, 0.002017},{1.251198, 1.121840, 0.000000}}],
    Polygon[{{1.255181, 1.122313, 0.002017},{1.255181, 1.121840, 0.003984},{
      1.251393, 1.121240, 0.003984},{1.251247, 1.121689, 0.002017}}],
    Polygon[{{1.255181, 1.121840, 0.003984},{1.255181, 1.121066, 0.005853},{
      1.251632, 1.120504, 0.005853},{1.251393, 1.121240, 0.003984}}],
    Polygon[{{1.255181, 1.121066, 0.005853},{1.255181, 1.120009, 0.007578},{
      1.251959, 1.119499, 0.007578},{1.251632, 1.120504, 0.005853}}],
    Polygon[{{1.255181, 1.120009, 0.007578},{1.255181, 1.118695, 0.009116},{
      1.252365, 1.118249, 0.009116},{1.251959, 1.119499, 0.007578}}],
    Polygon[{{1.255181, 1.118695, 0.009116},{1.255181, 1.117157, 0.010430},{
      1.252840, 1.116786, 0.010430},{1.252365, 1.118249, 0.009116}}],
    Polygon[{{1.255181, 1.117157, 0.010430},{1.255181, 1.115432, 0.011487},{
      1.253373, 1.115146, 0.011487},{1.252840, 1.116786, 0.010430}}],
    Polygon[{{1.255181, 1.115432, 0.011487},{1.255181, 1.113563, 0.012261},{
      1.253950, 1.113368, 0.012261},{1.253373, 1.115146, 0.011487}}],
    Polygon[{{1.255181, 1.113563, 0.012261},{1.255181, 1.111596, 0.012733},{
      1.254558, 1.111498, 0.012733},{1.253950, 1.113368, 0.012261}}],
    Polygon[{{1.254558, 1.111498, -0.012733},{1.253950, 1.113368, -0.012261},{
      1.252840, 1.112803, -0.012261},{1.253996, 1.111211, -0.012733}}],
    Polygon[{{1.253950, 1.113368, -0.012261},{1.253373, 1.115146, -0.011487},{
      1.251741, 1.114314, -0.011487},{1.252840, 1.112803, -0.012261}}],
    Polygon[{{1.253373, 1.115146, -0.011487},{1.252840, 1.116786, -0.010430},{
      1.250728, 1.115710, -0.010430},{1.251741, 1.114314, -0.011487}}],
    Polygon[{{1.252840, 1.116786, -0.010430},{1.252365, 1.118249, -0.009116},{
      1.249823, 1.116954, -0.009116},{1.250728, 1.115710, -0.010430}}],
    Polygon[{{1.252365, 1.118249, -0.009116},{1.251959, 1.119499, -0.007578},{
      1.249051, 1.118017, -0.007578},{1.249823, 1.116954, -0.009116}}],
    Polygon[{{1.251959, 1.119499, -0.007578},{1.251632, 1.120504, -0.005853},{
      1.248430, 1.118872, -0.005853},{1.249051, 1.118017, -0.007578}}],
    Polygon[{{1.251632, 1.120504, -0.005853},{1.251393, 1.121240, -0.003984},{
      1.247975, 1.119499, -0.003984},{1.248430, 1.118872, -0.005853}}],
    Polygon[{{1.251393, 1.121240, -0.003984},{1.251247, 1.121689, -0.002017},{
      1.247697, 1.119881, -0.002017},{1.247975, 1.119499, -0.003984}}],
    Polygon[{{1.251247, 1.121689, -0.002017},{1.251198, 1.121840, 0.000000},{
      1.247604, 1.120009, 0.000000},{1.247697, 1.119881, -0.002017}}],
    Polygon[{{1.251198, 1.121840, 0.000000},{1.251247, 1.121689, 0.002017},{
      1.247697, 1.119881, 0.002017},{1.247604, 1.120009, 0.000000}}],
    Polygon[{{1.251247, 1.121689, 0.002017},{1.251393, 1.121240, 0.003984},{
      1.247975, 1.119499, 0.003984},{1.247697, 1.119881, 0.002017}}],
    Polygon[{{1.251393, 1.121240, 0.003984},{1.251632, 1.120504, 0.005853},{
      1.248430, 1.118872, 0.005853},{1.247975, 1.119499, 0.003984}}],
    Polygon[{{1.251632, 1.120504, 0.005853},{1.251959, 1.119499, 0.007578},{
      1.249051, 1.118017, 0.007578},{1.248430, 1.118872, 0.005853}}],
    Polygon[{{1.251959, 1.119499, 0.007578},{1.252365, 1.118249, 0.009116},{
      1.249823, 1.116954, 0.009116},{1.249051, 1.118017, 0.007578}}],
    Polygon[{{1.252365, 1.118249, 0.009116},{1.252840, 1.116786, 0.010430},{
      1.250728, 1.115710, 0.010430},{1.249823, 1.116954, 0.009116}}],
    Polygon[{{1.252840, 1.116786, 0.010430},{1.253373, 1.115146, 0.011487},{
      1.251741, 1.114314, 0.011487},{1.250728, 1.115710, 0.010430}}],
    Polygon[{{1.253373, 1.115146, 0.011487},{1.253950, 1.113368, 0.012261},{
      1.252840, 1.112803, 0.012261},{1.251741, 1.114314, 0.011487}}],
    Polygon[{{1.253950, 1.113368, 0.012261},{1.254558, 1.111498, 0.012733},{
      1.253996, 1.111211, 0.012733},{1.252840, 1.112803, 0.012261}}],
    Polygon[{{1.253996, 1.111211, -0.012733},{1.252840, 1.112803, -0.012261},{
      1.251959, 1.111921, -0.012261},{1.253550, 1.110765, -0.012733}}],
    Polygon[{{1.252840, 1.112803, -0.012261},{1.251741, 1.114314, -0.011487},{
      1.250447, 1.113020, -0.011487},{1.251959, 1.111921, -0.012261}}],
    Polygon[{{1.251741, 1.114314, -0.011487},{1.250728, 1.115710, -0.010430},{
      1.249051, 1.114034, -0.010430},{1.250447, 1.113020, -0.011487}}],
    Polygon[{{1.250728, 1.115710, -0.010430},{1.249823, 1.116954, -0.009116},{
      1.247807, 1.114938, -0.009116},{1.249051, 1.114034, -0.010430}}],
    Polygon[{{1.249823, 1.116954, -0.009116},{1.249051, 1.118017, -0.007578},{
      1.246744, 1.115710, -0.007578},{1.247807, 1.114938, -0.009116}}],
    Polygon[{{1.249051, 1.118017, -0.007578},{1.248430, 1.118872, -0.005853},{
      1.245889, 1.116331, -0.005853},{1.246744, 1.115710, -0.007578}}],
    Polygon[{{1.248430, 1.118872, -0.005853},{1.247975, 1.119499, -0.003984},{
      1.245262, 1.116786, -0.003984},{1.245889, 1.116331, -0.005853}}],
    Polygon[{{1.247975, 1.119499, -0.003984},{1.247697, 1.119881, -0.002017},{
      1.244880, 1.117064, -0.002017},{1.245262, 1.116786, -0.003984}}],
    Polygon[{{1.247697, 1.119881, -0.002017},{1.247604, 1.120009, 0.000000},{
      1.244752, 1.117157, 0.000000},{1.244880, 1.117064, -0.002017}}],
    Polygon[{{1.247604, 1.120009, 0.000000},{1.247697, 1.119881, 0.002017},{
      1.244880, 1.117064, 0.002017},{1.244752, 1.117157, 0.000000}}],
    Polygon[{{1.247697, 1.119881, 0.002017},{1.247975, 1.119499, 0.003984},{
      1.245262, 1.116786, 0.003984},{1.244880, 1.117064, 0.002017}}],
    Polygon[{{1.247975, 1.119499, 0.003984},{1.248430, 1.118872, 0.005853},{
      1.245889, 1.116331, 0.005853},{1.245262, 1.116786, 0.003984}}],
    Polygon[{{1.248430, 1.118872, 0.005853},{1.249051, 1.118017, 0.007578},{
      1.246744, 1.115710, 0.007578},{1.245889, 1.116331, 0.005853}}],
    Polygon[{{1.249051, 1.118017, 0.007578},{1.249823, 1.116954, 0.009116},{
      1.247807, 1.114938, 0.009116},{1.246744, 1.115710, 0.007578}}],
    Polygon[{{1.249823, 1.116954, 0.009116},{1.250728, 1.115710, 0.010430},{
      1.249051, 1.114034, 0.010430},{1.247807, 1.114938, 0.009116}}],
    Polygon[{{1.250728, 1.115710, 0.010430},{1.251741, 1.114314, 0.011487},{
      1.250447, 1.113020, 0.011487},{1.249051, 1.114034, 0.010430}}],
    Polygon[{{1.251741, 1.114314, 0.011487},{1.252840, 1.112803, 0.012261},{
      1.251959, 1.111921, 0.012261},{1.250447, 1.113020, 0.011487}}],
    Polygon[{{1.252840, 1.112803, 0.012261},{1.253996, 1.111211, 0.012733},{
      1.253550, 1.110765, 0.012733},{1.251959, 1.111921, 0.012261}}],
    Polygon[{{1.253550, 1.110765, -0.012733},{1.251959, 1.111921, -0.012261},{
      1.251393, 1.110811, -0.012261},{1.253263, 1.110203, -0.012733}}],
    Polygon[{{1.251959, 1.111921, -0.012261},{1.250447, 1.113020, -0.011487},{
      1.249615, 1.111388, -0.011487},{1.251393, 1.110811, -0.012261}}],
    Polygon[{{1.250447, 1.113020, -0.011487},{1.249051, 1.114034, -0.010430},{
      1.247975, 1.111921, -0.010430},{1.249615, 1.111388, -0.011487}}],
    Polygon[{{1.249051, 1.114034, -0.010430},{1.247807, 1.114938, -0.009116},{
      1.246512, 1.112396, -0.009116},{1.247975, 1.111921, -0.010430}}],
    Polygon[{{1.247807, 1.114938, -0.009116},{1.246744, 1.115710, -0.007578},{
      1.245262, 1.112803, -0.007578},{1.246512, 1.112396, -0.009116}}],
    Polygon[{{1.246744, 1.115710, -0.007578},{1.245889, 1.116331, -0.005853},{
      1.244257, 1.113129, -0.005853},{1.245262, 1.112803, -0.007578}}],
    Polygon[{{1.245889, 1.116331, -0.005853},{1.245262, 1.116786, -0.003984},{
      1.243521, 1.113368, -0.003984},{1.244257, 1.113129, -0.005853}}],
    Polygon[{{1.245262, 1.116786, -0.003984},{1.244880, 1.117064, -0.002017},{
      1.243072, 1.113514, -0.002017},{1.243521, 1.113368, -0.003984}}],
    Polygon[{{1.244880, 1.117064, -0.002017},{1.244752, 1.117157, 0.000000},{
      1.242921, 1.113563, 0.000000},{1.243072, 1.113514, -0.002017}}],
    Polygon[{{1.244752, 1.117157, 0.000000},{1.244880, 1.117064, 0.002017},{
      1.243072, 1.113514, 0.002017},{1.242921, 1.113563, 0.000000}}],
    Polygon[{{1.244880, 1.117064, 0.002017},{1.245262, 1.116786, 0.003984},{
      1.243521, 1.113368, 0.003984},{1.243072, 1.113514, 0.002017}}],
    Polygon[{{1.245262, 1.116786, 0.003984},{1.245889, 1.116331, 0.005853},{
      1.244257, 1.113129, 0.005853},{1.243521, 1.113368, 0.003984}}],
    Polygon[{{1.245889, 1.116331, 0.005853},{1.246744, 1.115710, 0.007578},{
      1.245262, 1.112803, 0.007578},{1.244257, 1.113129, 0.005853}}],
    Polygon[{{1.246744, 1.115710, 0.007578},{1.247807, 1.114938, 0.009116},{
      1.246512, 1.112396, 0.009116},{1.245262, 1.112803, 0.007578}}],
    Polygon[{{1.247807, 1.114938, 0.009116},{1.249051, 1.114034, 0.010430},{
      1.247975, 1.111921, 0.010430},{1.246512, 1.112396, 0.009116}}],
    Polygon[{{1.249051, 1.114034, 0.010430},{1.250447, 1.113020, 0.011487},{
      1.249615, 1.111388, 0.011487},{1.247975, 1.111921, 0.010430}}],
    Polygon[{{1.250447, 1.113020, 0.011487},{1.251959, 1.111921, 0.012261},{
      1.251393, 1.110811, 0.012261},{1.249615, 1.111388, 0.011487}}],
    Polygon[{{1.251959, 1.111921, 0.012261},{1.253550, 1.110765, 0.012733},{
      1.253263, 1.110203, 0.012733},{1.251393, 1.110811, 0.012261}}],
    Polygon[{{1.253263, 1.110203, -0.012733},{1.251393, 1.110811, -0.012261},{
      1.251198, 1.109580, -0.012261},{1.253165, 1.109580, -0.012733}}],
    Polygon[{{1.251393, 1.110811, -0.012261},{1.249615, 1.111388, -0.011487},{
      1.249329, 1.109580, -0.011487},{1.251198, 1.109580, -0.012261}}],
    Polygon[{{1.249615, 1.111388, -0.011487},{1.247975, 1.111921, -0.010430},{
      1.247604, 1.109580, -0.010430},{1.249329, 1.109580, -0.011487}}],
    Polygon[{{1.247975, 1.111921, -0.010430},{1.246512, 1.112396, -0.009116},{
      1.246066, 1.109580, -0.009116},{1.247604, 1.109580, -0.010430}}],
    Polygon[{{1.246512, 1.112396, -0.009116},{1.245262, 1.112803, -0.007578},{
      1.244752, 1.109580, -0.007578},{1.246066, 1.109580, -0.009116}}],
    Polygon[{{1.245262, 1.112803, -0.007578},{1.244257, 1.113129, -0.005853},{
      1.243695, 1.109580, -0.005853},{1.244752, 1.109580, -0.007578}}],
    Polygon[{{1.244257, 1.113129, -0.005853},{1.243521, 1.113368, -0.003984},{
      1.242921, 1.109580, -0.003984},{1.243695, 1.109580, -0.005853}}],
    Polygon[{{1.243521, 1.113368, -0.003984},{1.243072, 1.113514, -0.002017},{
      1.242448, 1.109580, -0.002017},{1.242921, 1.109580, -0.003984}}],
    Polygon[{{1.243072, 1.113514, -0.002017},{1.242921, 1.113563, 0.000000},{
      1.242290, 1.109580, 0.000000},{1.242448, 1.109580, -0.002017}}],
    Polygon[{{1.242921, 1.113563, 0.000000},{1.243072, 1.113514, 0.002017},{
      1.242448, 1.109580, 0.002017},{1.242290, 1.109580, 0.000000}}],
    Polygon[{{1.243072, 1.113514, 0.002017},{1.243521, 1.113368, 0.003984},{
      1.242921, 1.109580, 0.003984},{1.242448, 1.109580, 0.002017}}],
    Polygon[{{1.243521, 1.113368, 0.003984},{1.244257, 1.113129, 0.005853},{
      1.243695, 1.109580, 0.005853},{1.242921, 1.109580, 0.003984}}],
    Polygon[{{1.244257, 1.113129, 0.005853},{1.245262, 1.112803, 0.007578},{
      1.244752, 1.109580, 0.007578},{1.243695, 1.109580, 0.005853}}],
    Polygon[{{1.245262, 1.112803, 0.007578},{1.246512, 1.112396, 0.009116},{
      1.246066, 1.109580, 0.009116},{1.244752, 1.109580, 0.007578}}],
    Polygon[{{1.246512, 1.112396, 0.009116},{1.247975, 1.111921, 0.010430},{
      1.247604, 1.109580, 0.010430},{1.246066, 1.109580, 0.009116}}],
    Polygon[{{1.247975, 1.111921, 0.010430},{1.249615, 1.111388, 0.011487},{
      1.249329, 1.109580, 0.011487},{1.247604, 1.109580, 0.010430}}],
    Polygon[{{1.249615, 1.111388, 0.011487},{1.251393, 1.110811, 0.012261},{
      1.251198, 1.109580, 0.012261},{1.249329, 1.109580, 0.011487}}],
    Polygon[{{1.251393, 1.110811, 0.012261},{1.253263, 1.110203, 0.012733},{
      1.253165, 1.109580, 0.012733},{1.251198, 1.109580, 0.012261}}],
    Polygon[{{1.253165, 1.109580, -0.012733},{1.251198, 1.109580, -0.012261},{
      1.251393, 1.108348, -0.012261},{1.253263, 1.108956, -0.012733}}],
    Polygon[{{1.251198, 1.109580, -0.012261},{1.249329, 1.109580, -0.011487},{
      1.249615, 1.107771, -0.011487},{1.251393, 1.108348, -0.012261}}],
    Polygon[{{1.249329, 1.109580, -0.011487},{1.247604, 1.109580, -0.010430},{
      1.247975, 1.107238, -0.010430},{1.249615, 1.107771, -0.011487}}],
    Polygon[{{1.247604, 1.109580, -0.010430},{1.246066, 1.109580, -0.009116},{
      1.246512, 1.106763, -0.009116},{1.247975, 1.107238, -0.010430}}],
    Polygon[{{1.246066, 1.109580, -0.009116},{1.244752, 1.109580, -0.007578},{
      1.245262, 1.106357, -0.007578},{1.246512, 1.106763, -0.009116}}],
    Polygon[{{1.244752, 1.109580, -0.007578},{1.243695, 1.109580, -0.005853},{
      1.244257, 1.106030, -0.005853},{1.245262, 1.106357, -0.007578}}],
    Polygon[{{1.243695, 1.109580, -0.005853},{1.242921, 1.109580, -0.003984},{
      1.243521, 1.105791, -0.003984},{1.244257, 1.106030, -0.005853}}],
    Polygon[{{1.242921, 1.109580, -0.003984},{1.242448, 1.109580, -0.002017},{
      1.243072, 1.105645, -0.002017},{1.243521, 1.105791, -0.003984}}],
    Polygon[{{1.242448, 1.109580, -0.002017},{1.242290, 1.109580, 0.000000},{
      1.242921, 1.105596, 0.000000},{1.243072, 1.105645, -0.002017}}],
    Polygon[{{1.242290, 1.109580, 0.000000},{1.242448, 1.109580, 0.002017},{
      1.243072, 1.105645, 0.002017},{1.242921, 1.105596, 0.000000}}],
    Polygon[{{1.242448, 1.109580, 0.002017},{1.242921, 1.109580, 0.003984},{
      1.243521, 1.105791, 0.003984},{1.243072, 1.105645, 0.002017}}],
    Polygon[{{1.242921, 1.109580, 0.003984},{1.243695, 1.109580, 0.005853},{
      1.244257, 1.106030, 0.005853},{1.243521, 1.105791, 0.003984}}],
    Polygon[{{1.243695, 1.109580, 0.005853},{1.244752, 1.109580, 0.007578},{
      1.245262, 1.106357, 0.007578},{1.244257, 1.106030, 0.005853}}],
    Polygon[{{1.244752, 1.109580, 0.007578},{1.246066, 1.109580, 0.009116},{
      1.246512, 1.106763, 0.009116},{1.245262, 1.106357, 0.007578}}],
    Polygon[{{1.246066, 1.109580, 0.009116},{1.247604, 1.109580, 0.010430},{
      1.247975, 1.107238, 0.010430},{1.246512, 1.106763, 0.009116}}],
    Polygon[{{1.247604, 1.109580, 0.010430},{1.249329, 1.109580, 0.011487},{
      1.249615, 1.107771, 0.011487},{1.247975, 1.107238, 0.010430}}],
    Polygon[{{1.249329, 1.109580, 0.011487},{1.251198, 1.109580, 0.012261},{
      1.251393, 1.108348, 0.012261},{1.249615, 1.107771, 0.011487}}],
    Polygon[{{1.251198, 1.109580, 0.012261},{1.253165, 1.109580, 0.012733},{
      1.253263, 1.108956, 0.012733},{1.251393, 1.108348, 0.012261}}],
    Polygon[{{1.253263, 1.108956, -0.012733},{1.251393, 1.108348, -0.012261},{
      1.251959, 1.107238, -0.012261},{1.253550, 1.108394, -0.012733}}],
    Polygon[{{1.251393, 1.108348, -0.012261},{1.249615, 1.107771, -0.011487},{
      1.250447, 1.106139, -0.011487},{1.251959, 1.107238, -0.012261}}],
    Polygon[{{1.249615, 1.107771, -0.011487},{1.247975, 1.107238, -0.010430},{
      1.249051, 1.105126, -0.010430},{1.250447, 1.106139, -0.011487}}],
    Polygon[{{1.247975, 1.107238, -0.010430},{1.246512, 1.106763, -0.009116},{
      1.247807, 1.104221, -0.009116},{1.249051, 1.105126, -0.010430}}],
    Polygon[{{1.246512, 1.106763, -0.009116},{1.245262, 1.106357, -0.007578},{
      1.246744, 1.103449, -0.007578},{1.247807, 1.104221, -0.009116}}],
    Polygon[{{1.245262, 1.106357, -0.007578},{1.244257, 1.106030, -0.005853},{
      1.245889, 1.102828, -0.005853},{1.246744, 1.103449, -0.007578}}],
    Polygon[{{1.244257, 1.106030, -0.005853},{1.243521, 1.105791, -0.003984},{
      1.245262, 1.102373, -0.003984},{1.245889, 1.102828, -0.005853}}],
    Polygon[{{1.243521, 1.105791, -0.003984},{1.243072, 1.105645, -0.002017},{
      1.244880, 1.102095, -0.002017},{1.245262, 1.102373, -0.003984}}],
    Polygon[{{1.243072, 1.105645, -0.002017},{1.242921, 1.105596, 0.000000},{
      1.244752, 1.102002, 0.000000},{1.244880, 1.102095, -0.002017}}],
    Polygon[{{1.242921, 1.105596, 0.000000},{1.243072, 1.105645, 0.002017},{
      1.244880, 1.102095, 0.002017},{1.244752, 1.102002, 0.000000}}],
    Polygon[{{1.243072, 1.105645, 0.002017},{1.243521, 1.105791, 0.003984},{
      1.245262, 1.102373, 0.003984},{1.244880, 1.102095, 0.002017}}],
    Polygon[{{1.243521, 1.105791, 0.003984},{1.244257, 1.106030, 0.005853},{
      1.245889, 1.102828, 0.005853},{1.245262, 1.102373, 0.003984}}],
    Polygon[{{1.244257, 1.106030, 0.005853},{1.245262, 1.106357, 0.007578},{
      1.246744, 1.103449, 0.007578},{1.245889, 1.102828, 0.005853}}],
    Polygon[{{1.245262, 1.106357, 0.007578},{1.246512, 1.106763, 0.009116},{
      1.247807, 1.104221, 0.009116},{1.246744, 1.103449, 0.007578}}],
    Polygon[{{1.246512, 1.106763, 0.009116},{1.247975, 1.107238, 0.010430},{
      1.249051, 1.105126, 0.010430},{1.247807, 1.104221, 0.009116}}],
    Polygon[{{1.247975, 1.107238, 0.010430},{1.249615, 1.107771, 0.011487},{
      1.250447, 1.106139, 0.011487},{1.249051, 1.105126, 0.010430}}],
    Polygon[{{1.249615, 1.107771, 0.011487},{1.251393, 1.108348, 0.012261},{
      1.251959, 1.107238, 0.012261},{1.250447, 1.106139, 0.011487}}],
    Polygon[{{1.251393, 1.108348, 0.012261},{1.253263, 1.108956, 0.012733},{
      1.253550, 1.108394, 0.012733},{1.251959, 1.107238, 0.012261}}],
    Polygon[{{1.253550, 1.108394, -0.012733},{1.251959, 1.107238, -0.012261},{
      1.252840, 1.106357, -0.012261},{1.253996, 1.107948, -0.012733}}],
    Polygon[{{1.251959, 1.107238, -0.012261},{1.250447, 1.106139, -0.011487},{
      1.251741, 1.104845, -0.011487},{1.252840, 1.106357, -0.012261}}],
    Polygon[{{1.250447, 1.106139, -0.011487},{1.249051, 1.105126, -0.010430},{
      1.250728, 1.103449, -0.010430},{1.251741, 1.104845, -0.011487}}],
    Polygon[{{1.249051, 1.105126, -0.010430},{1.247807, 1.104221, -0.009116},{
      1.249823, 1.102205, -0.009116},{1.250728, 1.103449, -0.010430}}],
    Polygon[{{1.247807, 1.104221, -0.009116},{1.246744, 1.103449, -0.007578},{
      1.249051, 1.101142, -0.007578},{1.249823, 1.102205, -0.009116}}],
    Polygon[{{1.246744, 1.103449, -0.007578},{1.245889, 1.102828, -0.005853},{
      1.248430, 1.100287, -0.005853},{1.249051, 1.101142, -0.007578}}],
    Polygon[{{1.245889, 1.102828, -0.005853},{1.245262, 1.102373, -0.003984},{
      1.247975, 1.099660, -0.003984},{1.248430, 1.100287, -0.005853}}],
    Polygon[{{1.245262, 1.102373, -0.003984},{1.244880, 1.102095, -0.002017},{
      1.247697, 1.099278, -0.002017},{1.247975, 1.099660, -0.003984}}],
    Polygon[{{1.244880, 1.102095, -0.002017},{1.244752, 1.102002, 0.000000},{
      1.247604, 1.099150, 0.000000},{1.247697, 1.099278, -0.002017}}],
    Polygon[{{1.244752, 1.102002, 0.000000},{1.244880, 1.102095, 0.002017},{
      1.247697, 1.099278, 0.002017},{1.247604, 1.099150, 0.000000}}],
    Polygon[{{1.244880, 1.102095, 0.002017},{1.245262, 1.102373, 0.003984},{
      1.247975, 1.099660, 0.003984},{1.247697, 1.099278, 0.002017}}],
    Polygon[{{1.245262, 1.102373, 0.003984},{1.245889, 1.102828, 0.005853},{
      1.248430, 1.100287, 0.005853},{1.247975, 1.099660, 0.003984}}],
    Polygon[{{1.245889, 1.102828, 0.005853},{1.246744, 1.103449, 0.007578},{
      1.249051, 1.101142, 0.007578},{1.248430, 1.100287, 0.005853}}],
    Polygon[{{1.246744, 1.103449, 0.007578},{1.247807, 1.104221, 0.009116},{
      1.249823, 1.102205, 0.009116},{1.249051, 1.101142, 0.007578}}],
    Polygon[{{1.247807, 1.104221, 0.009116},{1.249051, 1.105126, 0.010430},{
      1.250728, 1.103449, 0.010430},{1.249823, 1.102205, 0.009116}}],
    Polygon[{{1.249051, 1.105126, 0.010430},{1.250447, 1.106139, 0.011487},{
      1.251741, 1.104845, 0.011487},{1.250728, 1.103449, 0.010430}}],
    Polygon[{{1.250447, 1.106139, 0.011487},{1.251959, 1.107238, 0.012261},{
      1.252840, 1.106357, 0.012261},{1.251741, 1.104845, 0.011487}}],
    Polygon[{{1.251959, 1.107238, 0.012261},{1.253550, 1.108394, 0.012733},{
      1.253996, 1.107948, 0.012733},{1.252840, 1.106357, 0.012261}}],
    Polygon[{{1.253996, 1.107948, -0.012733},{1.252840, 1.106357, -0.012261},{
      1.253950, 1.105791, -0.012261},{1.254558, 1.107661, -0.012733}}],
    Polygon[{{1.252840, 1.106357, -0.012261},{1.251741, 1.104845, -0.011487},{
      1.253373, 1.104013, -0.011487},{1.253950, 1.105791, -0.012261}}],
    Polygon[{{1.251741, 1.104845, -0.011487},{1.250728, 1.103449, -0.010430},{
      1.252840, 1.102373, -0.010430},{1.253373, 1.104013, -0.011487}}],
    Polygon[{{1.250728, 1.103449, -0.010430},{1.249823, 1.102205, -0.009116},{
      1.252365, 1.100910, -0.009116},{1.252840, 1.102373, -0.010430}}],
    Polygon[{{1.249823, 1.102205, -0.009116},{1.249051, 1.101142, -0.007578},{
      1.251959, 1.099660, -0.007578},{1.252365, 1.100910, -0.009116}}],
    Polygon[{{1.249051, 1.101142, -0.007578},{1.248430, 1.100287, -0.005853},{
      1.251632, 1.098655, -0.005853},{1.251959, 1.099660, -0.007578}}],
    Polygon[{{1.248430, 1.100287, -0.005853},{1.247975, 1.099660, -0.003984},{
      1.251393, 1.097919, -0.003984},{1.251632, 1.098655, -0.005853}}],
    Polygon[{{1.247975, 1.099660, -0.003984},{1.247697, 1.099278, -0.002017},{
      1.251247, 1.097470, -0.002017},{1.251393, 1.097919, -0.003984}}],
    Polygon[{{1.247697, 1.099278, -0.002017},{1.247604, 1.099150, 0.000000},{
      1.251198, 1.097319, 0.000000},{1.251247, 1.097470, -0.002017}}],
    Polygon[{{1.247604, 1.099150, 0.000000},{1.247697, 1.099278, 0.002017},{
      1.251247, 1.097470, 0.002017},{1.251198, 1.097319, 0.000000}}],
    Polygon[{{1.247697, 1.099278, 0.002017},{1.247975, 1.099660, 0.003984},{
      1.251393, 1.097919, 0.003984},{1.251247, 1.097470, 0.002017}}],
    Polygon[{{1.247975, 1.099660, 0.003984},{1.248430, 1.100287, 0.005853},{
      1.251632, 1.098655, 0.005853},{1.251393, 1.097919, 0.003984}}],
    Polygon[{{1.248430, 1.100287, 0.005853},{1.249051, 1.101142, 0.007578},{
      1.251959, 1.099660, 0.007578},{1.251632, 1.098655, 0.005853}}],
    Polygon[{{1.249051, 1.101142, 0.007578},{1.249823, 1.102205, 0.009116},{
      1.252365, 1.100910, 0.009116},{1.251959, 1.099660, 0.007578}}],
    Polygon[{{1.249823, 1.102205, 0.009116},{1.250728, 1.103449, 0.010430},{
      1.252840, 1.102373, 0.010430},{1.252365, 1.100910, 0.009116}}],
    Polygon[{{1.250728, 1.103449, 0.010430},{1.251741, 1.104845, 0.011487},{
      1.253373, 1.104013, 0.011487},{1.252840, 1.102373, 0.010430}}],
    Polygon[{{1.251741, 1.104845, 0.011487},{1.252840, 1.106357, 0.012261},{
      1.253950, 1.105791, 0.012261},{1.253373, 1.104013, 0.011487}}],
    Polygon[{{1.252840, 1.106357, 0.012261},{1.253996, 1.107948, 0.012733},{
      1.254558, 1.107661, 0.012733},{1.253950, 1.105791, 0.012261}}],
    Polygon[{{1.254558, 1.107661, -0.012733},{1.253950, 1.105791, -0.012261},{
      1.255181, 1.105596, -0.012261},{1.255181, 1.107563, -0.012733}}],
    Polygon[{{1.253950, 1.105791, -0.012261},{1.253373, 1.104013, -0.011487},{
      1.255181, 1.103727, -0.011487},{1.255181, 1.105596, -0.012261}}],
    Polygon[{{1.253373, 1.104013, -0.011487},{1.252840, 1.102373, -0.010430},{
      1.255181, 1.102002, -0.010430},{1.255181, 1.103727, -0.011487}}],
    Polygon[{{1.252840, 1.102373, -0.010430},{1.252365, 1.100910, -0.009116},{
      1.255181, 1.100464, -0.009116},{1.255181, 1.102002, -0.010430}}],
    Polygon[{{1.252365, 1.100910, -0.009116},{1.251959, 1.099660, -0.007578},{
      1.255181, 1.099150, -0.007578},{1.255181, 1.100464, -0.009116}}],
    Polygon[{{1.251959, 1.099660, -0.007578},{1.251632, 1.098655, -0.005853},{
      1.255181, 1.098093, -0.005853},{1.255181, 1.099150, -0.007578}}],
    Polygon[{{1.251632, 1.098655, -0.005853},{1.251393, 1.097919, -0.003984},{
      1.255181, 1.097319, -0.003984},{1.255181, 1.098093, -0.005853}}],
    Polygon[{{1.251393, 1.097919, -0.003984},{1.251247, 1.097470, -0.002017},{
      1.255181, 1.096847, -0.002017},{1.255181, 1.097319, -0.003984}}],
    Polygon[{{1.251247, 1.097470, -0.002017},{1.251198, 1.097319, 0.000000},{
      1.255181, 1.096688, 0.000000},{1.255181, 1.096847, -0.002017}}],
    Polygon[{{1.251198, 1.097319, 0.000000},{1.251247, 1.097470, 0.002017},{
      1.255181, 1.096847, 0.002017},{1.255181, 1.096688, 0.000000}}],
    Polygon[{{1.251247, 1.097470, 0.002017},{1.251393, 1.097919, 0.003984},{
      1.255181, 1.097319, 0.003984},{1.255181, 1.096847, 0.002017}}],
    Polygon[{{1.251393, 1.097919, 0.003984},{1.251632, 1.098655, 0.005853},{
      1.255181, 1.098093, 0.005853},{1.255181, 1.097319, 0.003984}}],
    Polygon[{{1.251632, 1.098655, 0.005853},{1.251959, 1.099660, 0.007578},{
      1.255181, 1.099150, 0.007578},{1.255181, 1.098093, 0.005853}}],
    Polygon[{{1.251959, 1.099660, 0.007578},{1.252365, 1.100910, 0.009116},{
      1.255181, 1.100464, 0.009116},{1.255181, 1.099150, 0.007578}}],
    Polygon[{{1.252365, 1.100910, 0.009116},{1.252840, 1.102373, 0.010430},{
      1.255181, 1.102002, 0.010430},{1.255181, 1.100464, 0.009116}}],
    Polygon[{{1.252840, 1.102373, 0.010430},{1.253373, 1.104013, 0.011487},{
      1.255181, 1.103727, 0.011487},{1.255181, 1.102002, 0.010430}}],
    Polygon[{{1.253373, 1.104013, 0.011487},{1.253950, 1.105791, 0.012261},{
      1.255181, 1.105596, 0.012261},{1.255181, 1.103727, 0.011487}}],
    Polygon[{{1.253950, 1.105791, 0.012261},{1.254558, 1.107661, 0.012733},{
      1.255181, 1.107563, 0.012733},{1.255181, 1.105596, 0.012261}}],
    Polygon[{{1.255181, 1.107563, -0.012733},{1.255181, 1.105596, -0.012261},{
      1.256413, 1.105791, -0.012261},{1.255805, 1.107661, -0.012733}}],
    Polygon[{{1.255181, 1.105596, -0.012261},{1.255181, 1.103727, -0.011487},{
      1.256990, 1.104013, -0.011487},{1.256413, 1.105791, -0.012261}}],
    Polygon[{{1.255181, 1.103727, -0.011487},{1.255181, 1.102002, -0.010430},{
      1.257523, 1.102373, -0.010430},{1.256990, 1.104013, -0.011487}}],
    Polygon[{{1.255181, 1.102002, -0.010430},{1.255181, 1.100464, -0.009116},{
      1.257998, 1.100910, -0.009116},{1.257523, 1.102373, -0.010430}}],
    Polygon[{{1.255181, 1.100464, -0.009116},{1.255181, 1.099150, -0.007578},{
      1.258404, 1.099660, -0.007578},{1.257998, 1.100910, -0.009116}}],
    Polygon[{{1.255181, 1.099150, -0.007578},{1.255181, 1.098093, -0.005853},{
      1.258731, 1.098655, -0.005853},{1.258404, 1.099660, -0.007578}}],
    Polygon[{{1.255181, 1.098093, -0.005853},{1.255181, 1.097319, -0.003984},{
      1.258970, 1.097919, -0.003984},{1.258731, 1.098655, -0.005853}}],
    Polygon[{{1.255181, 1.097319, -0.003984},{1.255181, 1.096847, -0.002017},{
      1.259116, 1.097470, -0.002017},{1.258970, 1.097919, -0.003984}}],
    Polygon[{{1.255181, 1.096847, -0.002017},{1.255181, 1.096688, 0.000000},{
      1.259165, 1.097319, 0.000000},{1.259116, 1.097470, -0.002017}}],
    Polygon[{{1.255181, 1.096688, 0.000000},{1.255181, 1.096847, 0.002017},{
      1.259116, 1.097470, 0.002017},{1.259165, 1.097319, 0.000000}}],
    Polygon[{{1.255181, 1.096847, 0.002017},{1.255181, 1.097319, 0.003984},{
      1.258970, 1.097919, 0.003984},{1.259116, 1.097470, 0.002017}}],
    Polygon[{{1.255181, 1.097319, 0.003984},{1.255181, 1.098093, 0.005853},{
      1.258731, 1.098655, 0.005853},{1.258970, 1.097919, 0.003984}}],
    Polygon[{{1.255181, 1.098093, 0.005853},{1.255181, 1.099150, 0.007578},{
      1.258404, 1.099660, 0.007578},{1.258731, 1.098655, 0.005853}}],
    Polygon[{{1.255181, 1.099150, 0.007578},{1.255181, 1.100464, 0.009116},{
      1.257998, 1.100910, 0.009116},{1.258404, 1.099660, 0.007578}}],
    Polygon[{{1.255181, 1.100464, 0.009116},{1.255181, 1.102002, 0.010430},{
      1.257523, 1.102373, 0.010430},{1.257998, 1.100910, 0.009116}}],
    Polygon[{{1.255181, 1.102002, 0.010430},{1.255181, 1.103727, 0.011487},{
      1.256990, 1.104013, 0.011487},{1.257523, 1.102373, 0.010430}}],
    Polygon[{{1.255181, 1.103727, 0.011487},{1.255181, 1.105596, 0.012261},{
      1.256413, 1.105791, 0.012261},{1.256990, 1.104013, 0.011487}}],
    Polygon[{{1.255181, 1.105596, 0.012261},{1.255181, 1.107563, 0.012733},{
      1.255805, 1.107661, 0.012733},{1.256413, 1.105791, 0.012261}}],
    Polygon[{{1.255805, 1.107661, -0.012733},{1.256413, 1.105791, -0.012261},{
      1.257523, 1.106357, -0.012261},{1.256367, 1.107948, -0.012733}}],
    Polygon[{{1.256413, 1.105791, -0.012261},{1.256990, 1.104013, -0.011487},{
      1.258622, 1.104845, -0.011487},{1.257523, 1.106357, -0.012261}}],
    Polygon[{{1.256990, 1.104013, -0.011487},{1.257523, 1.102373, -0.010430},{
      1.259635, 1.103449, -0.010430},{1.258622, 1.104845, -0.011487}}],
    Polygon[{{1.257523, 1.102373, -0.010430},{1.257998, 1.100910, -0.009116},{
      1.260540, 1.102205, -0.009116},{1.259635, 1.103449, -0.010430}}],
    Polygon[{{1.257998, 1.100910, -0.009116},{1.258404, 1.099660, -0.007578},{
      1.261312, 1.101142, -0.007578},{1.260540, 1.102205, -0.009116}}],
    Polygon[{{1.258404, 1.099660, -0.007578},{1.258731, 1.098655, -0.005853},{
      1.261933, 1.100287, -0.005853},{1.261312, 1.101142, -0.007578}}],
    Polygon[{{1.258731, 1.098655, -0.005853},{1.258970, 1.097919, -0.003984},{
      1.262388, 1.099660, -0.003984},{1.261933, 1.100287, -0.005853}}],
    Polygon[{{1.258970, 1.097919, -0.003984},{1.259116, 1.097470, -0.002017},{
      1.262666, 1.099278, -0.002017},{1.262388, 1.099660, -0.003984}}],
    Polygon[{{1.259116, 1.097470, -0.002017},{1.259165, 1.097319, 0.000000},{
      1.262759, 1.099150, 0.000000},{1.262666, 1.099278, -0.002017}}],
    Polygon[{{1.259165, 1.097319, 0.000000},{1.259116, 1.097470, 0.002017},{
      1.262666, 1.099278, 0.002017},{1.262759, 1.099150, 0.000000}}],
    Polygon[{{1.259116, 1.097470, 0.002017},{1.258970, 1.097919, 0.003984},{
      1.262388, 1.099660, 0.003984},{1.262666, 1.099278, 0.002017}}],
    Polygon[{{1.258970, 1.097919, 0.003984},{1.258731, 1.098655, 0.005853},{
      1.261933, 1.100287, 0.005853},{1.262388, 1.099660, 0.003984}}],
    Polygon[{{1.258731, 1.098655, 0.005853},{1.258404, 1.099660, 0.007578},{
      1.261312, 1.101142, 0.007578},{1.261933, 1.100287, 0.005853}}],
    Polygon[{{1.258404, 1.099660, 0.007578},{1.257998, 1.100910, 0.009116},{
      1.260540, 1.102205, 0.009116},{1.261312, 1.101142, 0.007578}}],
    Polygon[{{1.257998, 1.100910, 0.009116},{1.257523, 1.102373, 0.010430},{
      1.259635, 1.103449, 0.010430},{1.260540, 1.102205, 0.009116}}],
    Polygon[{{1.257523, 1.102373, 0.010430},{1.256990, 1.104013, 0.011487},{
      1.258622, 1.104845, 0.011487},{1.259635, 1.103449, 0.010430}}],
    Polygon[{{1.256990, 1.104013, 0.011487},{1.256413, 1.105791, 0.012261},{
      1.257523, 1.106357, 0.012261},{1.258622, 1.104845, 0.011487}}],
    Polygon[{{1.256413, 1.105791, 0.012261},{1.255805, 1.107661, 0.012733},{
      1.256367, 1.107948, 0.012733},{1.257523, 1.106357, 0.012261}}],
    Polygon[{{1.256367, 1.107948, -0.012733},{1.257523, 1.106357, -0.012261},{
      1.258404, 1.107238, -0.012261},{1.256813, 1.108394, -0.012733}}],
    Polygon[{{1.257523, 1.106357, -0.012261},{1.258622, 1.104845, -0.011487},{
      1.259916, 1.106139, -0.011487},{1.258404, 1.107238, -0.012261}}],
    Polygon[{{1.258622, 1.104845, -0.011487},{1.259635, 1.103449, -0.010430},{
      1.261312, 1.105126, -0.010430},{1.259916, 1.106139, -0.011487}}],
    Polygon[{{1.259635, 1.103449, -0.010430},{1.260540, 1.102205, -0.009116},{
      1.262556, 1.104221, -0.009116},{1.261312, 1.105126, -0.010430}}],
    Polygon[{{1.260540, 1.102205, -0.009116},{1.261312, 1.101142, -0.007578},{
      1.263619, 1.103449, -0.007578},{1.262556, 1.104221, -0.009116}}],
    Polygon[{{1.261312, 1.101142, -0.007578},{1.261933, 1.100287, -0.005853},{
      1.264474, 1.102828, -0.005853},{1.263619, 1.103449, -0.007578}}],
    Polygon[{{1.261933, 1.100287, -0.005853},{1.262388, 1.099660, -0.003984},{
      1.265101, 1.102373, -0.003984},{1.264474, 1.102828, -0.005853}}],
    Polygon[{{1.262388, 1.099660, -0.003984},{1.262666, 1.099278, -0.002017},{
      1.265483, 1.102095, -0.002017},{1.265101, 1.102373, -0.003984}}],
    Polygon[{{1.262666, 1.099278, -0.002017},{1.262759, 1.099150, 0.000000},{
      1.265611, 1.102002, 0.000000},{1.265483, 1.102095, -0.002017}}],
    Polygon[{{1.262759, 1.099150, 0.000000},{1.262666, 1.099278, 0.002017},{
      1.265483, 1.102095, 0.002017},{1.265611, 1.102002, 0.000000}}],
    Polygon[{{1.262666, 1.099278, 0.002017},{1.262388, 1.099660, 0.003984},{
      1.265101, 1.102373, 0.003984},{1.265483, 1.102095, 0.002017}}],
    Polygon[{{1.262388, 1.099660, 0.003984},{1.261933, 1.100287, 0.005853},{
      1.264474, 1.102828, 0.005853},{1.265101, 1.102373, 0.003984}}],
    Polygon[{{1.261933, 1.100287, 0.005853},{1.261312, 1.101142, 0.007578},{
      1.263619, 1.103449, 0.007578},{1.264474, 1.102828, 0.005853}}],
    Polygon[{{1.261312, 1.101142, 0.007578},{1.260540, 1.102205, 0.009116},{
      1.262556, 1.104221, 0.009116},{1.263619, 1.103449, 0.007578}}],
    Polygon[{{1.260540, 1.102205, 0.009116},{1.259635, 1.103449, 0.010430},{
      1.261312, 1.105126, 0.010430},{1.262556, 1.104221, 0.009116}}],
    Polygon[{{1.259635, 1.103449, 0.010430},{1.258622, 1.104845, 0.011487},{
      1.259916, 1.106139, 0.011487},{1.261312, 1.105126, 0.010430}}],
    Polygon[{{1.258622, 1.104845, 0.011487},{1.257523, 1.106357, 0.012261},{
      1.258404, 1.107238, 0.012261},{1.259916, 1.106139, 0.011487}}],
    Polygon[{{1.257523, 1.106357, 0.012261},{1.256367, 1.107948, 0.012733},{
      1.256813, 1.108394, 0.012733},{1.258404, 1.107238, 0.012261}}],
    Polygon[{{1.256813, 1.108394, -0.012733},{1.258404, 1.107238, -0.012261},{
      1.258970, 1.108348, -0.012261},{1.257100, 1.108956, -0.012733}}],
    Polygon[{{1.258404, 1.107238, -0.012261},{1.259916, 1.106139, -0.011487},{
      1.260748, 1.107771, -0.011487},{1.258970, 1.108348, -0.012261}}],
    Polygon[{{1.259916, 1.106139, -0.011487},{1.261312, 1.105126, -0.010430},{
      1.262388, 1.107238, -0.010430},{1.260748, 1.107771, -0.011487}}],
    Polygon[{{1.261312, 1.105126, -0.010430},{1.262556, 1.104221, -0.009116},{
      1.263851, 1.106763, -0.009116},{1.262388, 1.107238, -0.010430}}],
    Polygon[{{1.262556, 1.104221, -0.009116},{1.263619, 1.103449, -0.007578},{
      1.265101, 1.106357, -0.007578},{1.263851, 1.106763, -0.009116}}],
    Polygon[{{1.263619, 1.103449, -0.007578},{1.264474, 1.102828, -0.005853},{
      1.266106, 1.106030, -0.005853},{1.265101, 1.106357, -0.007578}}],
    Polygon[{{1.264474, 1.102828, -0.005853},{1.265101, 1.102373, -0.003984},{
      1.266842, 1.105791, -0.003984},{1.266106, 1.106030, -0.005853}}],
    Polygon[{{1.265101, 1.102373, -0.003984},{1.265483, 1.102095, -0.002017},{
      1.267291, 1.105645, -0.002017},{1.266842, 1.105791, -0.003984}}],
    Polygon[{{1.265483, 1.102095, -0.002017},{1.265611, 1.102002, 0.000000},{
      1.267442, 1.105596, 0.000000},{1.267291, 1.105645, -0.002017}}],
    Polygon[{{1.265611, 1.102002, 0.000000},{1.265483, 1.102095, 0.002017},{
      1.267291, 1.105645, 0.002017},{1.267442, 1.105596, 0.000000}}],
    Polygon[{{1.265483, 1.102095, 0.002017},{1.265101, 1.102373, 0.003984},{
      1.266842, 1.105791, 0.003984},{1.267291, 1.105645, 0.002017}}],
    Polygon[{{1.265101, 1.102373, 0.003984},{1.264474, 1.102828, 0.005853},{
      1.266106, 1.106030, 0.005853},{1.266842, 1.105791, 0.003984}}],
    Polygon[{{1.264474, 1.102828, 0.005853},{1.263619, 1.103449, 0.007578},{
      1.265101, 1.106357, 0.007578},{1.266106, 1.106030, 0.005853}}],
    Polygon[{{1.263619, 1.103449, 0.007578},{1.262556, 1.104221, 0.009116},{
      1.263851, 1.106763, 0.009116},{1.265101, 1.106357, 0.007578}}],
    Polygon[{{1.262556, 1.104221, 0.009116},{1.261312, 1.105126, 0.010430},{
      1.262388, 1.107238, 0.010430},{1.263851, 1.106763, 0.009116}}],
    Polygon[{{1.261312, 1.105126, 0.010430},{1.259916, 1.106139, 0.011487},{
      1.260748, 1.107771, 0.011487},{1.262388, 1.107238, 0.010430}}],
    Polygon[{{1.259916, 1.106139, 0.011487},{1.258404, 1.107238, 0.012261},{
      1.258970, 1.108348, 0.012261},{1.260748, 1.107771, 0.011487}}],
    Polygon[{{1.258404, 1.107238, 0.012261},{1.256813, 1.108394, 0.012733},{
      1.257100, 1.108956, 0.012733},{1.258970, 1.108348, 0.012261}}],
    Polygon[{{1.257100, 1.108956, -0.012733},{1.258970, 1.108348, -0.012261},{
      1.259165, 1.109580, -0.012261},{1.257198, 1.109580, -0.012733}}],
    Polygon[{{1.258970, 1.108348, -0.012261},{1.260748, 1.107771, -0.011487},{
      1.261034, 1.109580, -0.011487},{1.259165, 1.109580, -0.012261}}],
    Polygon[{{1.260748, 1.107771, -0.011487},{1.262388, 1.107238, -0.010430},{
      1.262759, 1.109580, -0.010430},{1.261034, 1.109580, -0.011487}}],
    Polygon[{{1.262388, 1.107238, -0.010430},{1.263851, 1.106763, -0.009116},{
      1.264297, 1.109580, -0.009116},{1.262759, 1.109580, -0.010430}}],
    Polygon[{{1.263851, 1.106763, -0.009116},{1.265101, 1.106357, -0.007578},{
      1.265611, 1.109580, -0.007578},{1.264297, 1.109580, -0.009116}}],
    Polygon[{{1.265101, 1.106357, -0.007578},{1.266106, 1.106030, -0.005853},{
      1.266668, 1.109580, -0.005853},{1.265611, 1.109580, -0.007578}}],
    Polygon[{{1.266106, 1.106030, -0.005853},{1.266842, 1.105791, -0.003984},{
      1.267442, 1.109580, -0.003984},{1.266668, 1.109580, -0.005853}}],
    Polygon[{{1.266842, 1.105791, -0.003984},{1.267291, 1.105645, -0.002017},{
      1.267915, 1.109580, -0.002017},{1.267442, 1.109580, -0.003984}}],
    Polygon[{{1.267291, 1.105645, -0.002017},{1.267442, 1.105596, 0.000000},{
      1.268073, 1.109580, 0.000000},{1.267915, 1.109580, -0.002017}}],
    Polygon[{{1.267442, 1.105596, 0.000000},{1.267291, 1.105645, 0.002017},{
      1.267915, 1.109580, 0.002017},{1.268073, 1.109580, 0.000000}}],
    Polygon[{{1.267291, 1.105645, 0.002017},{1.266842, 1.105791, 0.003984},{
      1.267442, 1.109580, 0.003984},{1.267915, 1.109580, 0.002017}}],
    Polygon[{{1.266842, 1.105791, 0.003984},{1.266106, 1.106030, 0.005853},{
      1.266668, 1.109580, 0.005853},{1.267442, 1.109580, 0.003984}}],
    Polygon[{{1.266106, 1.106030, 0.005853},{1.265101, 1.106357, 0.007578},{
      1.265611, 1.109580, 0.007578},{1.266668, 1.109580, 0.005853}}],
    Polygon[{{1.265101, 1.106357, 0.007578},{1.263851, 1.106763, 0.009116},{
      1.264297, 1.109580, 0.009116},{1.265611, 1.109580, 0.007578}}],
    Polygon[{{1.263851, 1.106763, 0.009116},{1.262388, 1.107238, 0.010430},{
      1.262759, 1.109580, 0.010430},{1.264297, 1.109580, 0.009116}}],
    Polygon[{{1.262388, 1.107238, 0.010430},{1.260748, 1.107771, 0.011487},{
      1.261034, 1.109580, 0.011487},{1.262759, 1.109580, 0.010430}}],
    Polygon[{{1.260748, 1.107771, 0.011487},{1.258970, 1.108348, 0.012261},{
      1.259165, 1.109580, 0.012261},{1.261034, 1.109580, 0.011487}}],
    Polygon[{{1.258970, 1.108348, 0.012261},{1.257100, 1.108956, 0.012733},{
      1.257198, 1.109580, 0.012733},{1.259165, 1.109580, 0.012261}}],
    Polygon[{{1.220778, 1.299558, -0.028615},{1.225199, 1.299558, -0.027554},{
      1.224761, 1.302325, -0.027554},{1.220557, 1.300959, -0.028615}}],
    Polygon[{{1.225199, 1.299558, -0.027554},{1.229399, 1.299558, -0.025814},{
      1.228755, 1.303623, -0.025814},{1.224761, 1.302325, -0.027554}}],
    Polygon[{{1.229399, 1.299558, -0.025814},{1.233275, 1.299558, -0.023438},{
      1.232442, 1.304820, -0.023438},{1.228755, 1.303623, -0.025814}}],
    Polygon[{{1.233275, 1.299558, -0.023438},{1.236732, 1.299558, -0.020486},{
      1.235730, 1.305889, -0.020486},{1.232442, 1.304820, -0.023438}}],
    Polygon[{{1.236732, 1.299558, -0.020486},{1.239685, 1.299558, -0.017029},{
      1.238538, 1.306801, -0.017029},{1.235730, 1.305889, -0.020486}}],
    Polygon[{{1.239685, 1.299558, -0.017029},{1.242060, 1.299558, -0.013153},{
      1.240797, 1.307535, -0.013153},{1.238538, 1.306801, -0.017029}}],
    Polygon[{{1.242060, 1.299558, -0.013153},{1.243800, 1.299558, -0.008953},{
      1.242451, 1.308073, -0.008953},{1.240797, 1.307535, -0.013153}}],
    Polygon[{{1.243800, 1.299558, -0.008953},{1.244861, 1.299558, -0.004532},{
      1.243461, 1.308401, -0.004532},{1.242451, 1.308073, -0.008953}}],
    Polygon[{{1.244861, 1.299558, -0.004532},{1.245218, 1.299558, 0.000000},{
      1.243800, 1.308511, 0.000000},{1.243461, 1.308401, -0.004532}}],
    Polygon[{{1.245218, 1.299558, 0.000000},{1.244861, 1.299558, 0.004532},{
      1.243461, 1.308401, 0.004532},{1.243800, 1.308511, 0.000000}}],
    Polygon[{{1.244861, 1.299558, 0.004532},{1.243800, 1.299558, 0.008953},{
      1.242451, 1.308073, 0.008953},{1.243461, 1.308401, 0.004532}}],
    Polygon[{{1.243800, 1.299558, 0.008953},{1.242060, 1.299558, 0.013153},{
      1.240797, 1.307535, 0.013153},{1.242451, 1.308073, 0.008953}}],
    Polygon[{{1.242060, 1.299558, 0.013153},{1.239685, 1.299558, 0.017029},{
      1.238538, 1.306801, 0.017029},{1.240797, 1.307535, 0.013153}}],
    Polygon[{{1.239685, 1.299558, 0.017029},{1.236732, 1.299558, 0.020486},{
      1.235730, 1.305889, 0.020486},{1.238538, 1.306801, 0.017029}}],
    Polygon[{{1.236732, 1.299558, 0.020486},{1.233275, 1.299558, 0.023438},{
      1.232442, 1.304820, 0.023438},{1.235730, 1.305889, 0.020486}}],
    Polygon[{{1.233275, 1.299558, 0.023438},{1.229399, 1.299558, 0.025814},{
      1.228755, 1.303623, 0.025814},{1.232442, 1.304820, 0.023438}}],
    Polygon[{{1.229399, 1.299558, 0.025814},{1.225199, 1.299558, 0.027554},{
      1.224761, 1.302325, 0.027554},{1.228755, 1.303623, 0.025814}}],
    Polygon[{{1.225199, 1.299558, 0.027554},{1.220778, 1.299558, 0.028615},{
      1.220557, 1.300959, 0.028615},{1.224761, 1.302325, 0.027554}}],
    Polygon[{{1.220557, 1.300959, -0.028615},{1.224761, 1.302325, -0.027554},{
      1.223489, 1.304820, -0.027554},{1.219913, 1.302222, -0.028615}}],
    Polygon[{{1.224761, 1.302325, -0.027554},{1.228755, 1.303623, -0.025814},{
      1.226887, 1.307289, -0.025814},{1.223489, 1.304820, -0.027554}}],
    Polygon[{{1.228755, 1.303623, -0.025814},{1.232442, 1.304820, -0.023438},{
      1.230023, 1.309568, -0.023438},{1.226887, 1.307289, -0.025814}}],
    Polygon[{{1.232442, 1.304820, -0.023438},{1.235730, 1.305889, -0.020486},{
      1.232820, 1.311599, -0.020486},{1.230023, 1.309568, -0.023438}}],
    Polygon[{{1.235730, 1.305889, -0.020486},{1.238538, 1.306801, -0.017029},{
      1.235208, 1.313335, -0.017029},{1.232820, 1.311599, -0.020486}}],
    Polygon[{{1.238538, 1.306801, -0.017029},{1.240797, 1.307535, -0.013153},{
      1.237130, 1.314731, -0.013153},{1.235208, 1.313335, -0.017029}}],
    Polygon[{{1.240797, 1.307535, -0.013153},{1.242451, 1.308073, -0.008953},{
      1.238538, 1.315754, -0.008953},{1.237130, 1.314731, -0.013153}}],
    Polygon[{{1.242451, 1.308073, -0.008953},{1.243461, 1.308401, -0.004532},{
      1.239396, 1.316378, -0.004532},{1.238538, 1.315754, -0.008953}}],
    Polygon[{{1.243461, 1.308401, -0.004532},{1.243800, 1.308511, 0.000000},{
      1.239685, 1.316587, 0.000000},{1.239396, 1.316378, -0.004532}}],
    Polygon[{{1.243800, 1.308511, 0.000000},{1.243461, 1.308401, 0.004532},{
      1.239396, 1.316378, 0.004532},{1.239685, 1.316587, 0.000000}}],
    Polygon[{{1.243461, 1.308401, 0.004532},{1.242451, 1.308073, 0.008953},{
      1.238538, 1.315754, 0.008953},{1.239396, 1.316378, 0.004532}}],
    Polygon[{{1.242451, 1.308073, 0.008953},{1.240797, 1.307535, 0.013153},{
      1.237130, 1.314731, 0.013153},{1.238538, 1.315754, 0.008953}}],
    Polygon[{{1.240797, 1.307535, 0.013153},{1.238538, 1.306801, 0.017029},{
      1.235208, 1.313335, 0.017029},{1.237130, 1.314731, 0.013153}}],
    Polygon[{{1.238538, 1.306801, 0.017029},{1.235730, 1.305889, 0.020486},{
      1.232820, 1.311599, 0.020486},{1.235208, 1.313335, 0.017029}}],
    Polygon[{{1.235730, 1.305889, 0.020486},{1.232442, 1.304820, 0.023438},{
      1.230023, 1.309568, 0.023438},{1.232820, 1.311599, 0.020486}}],
    Polygon[{{1.232442, 1.304820, 0.023438},{1.228755, 1.303623, 0.025814},{
      1.226887, 1.307289, 0.025814},{1.230023, 1.309568, 0.023438}}],
    Polygon[{{1.228755, 1.303623, 0.025814},{1.224761, 1.302325, 0.027554},{
      1.223489, 1.304820, 0.027554},{1.226887, 1.307289, 0.025814}}],
    Polygon[{{1.224761, 1.302325, 0.027554},{1.220557, 1.300959, 0.028615},{
      1.219913, 1.302222, 0.028615},{1.223489, 1.304820, 0.027554}}],
    Polygon[{{1.219913, 1.302222, -0.028615},{1.223489, 1.304820, -0.027554},{
      1.221509, 1.306801, -0.027554},{1.218910, 1.303225, -0.028615}}],
    Polygon[{{1.223489, 1.304820, -0.027554},{1.226887, 1.307289, -0.025814},{
      1.223977, 1.310199, -0.025814},{1.221509, 1.306801, -0.027554}}],
    Polygon[{{1.226887, 1.307289, -0.025814},{1.230023, 1.309568, -0.023438},{
      1.226256, 1.313335, -0.023438},{1.223977, 1.310199, -0.025814}}],
    Polygon[{{1.230023, 1.309568, -0.023438},{1.232820, 1.311599, -0.020486},{
      1.228288, 1.316132, -0.020486},{1.226256, 1.313335, -0.023438}}],
    Polygon[{{1.232820, 1.311599, -0.020486},{1.235208, 1.313335, -0.017029},{
      1.230023, 1.318520, -0.017029},{1.228288, 1.316132, -0.020486}}],
    Polygon[{{1.235208, 1.313335, -0.017029},{1.237130, 1.314731, -0.013153},{
      1.231419, 1.320442, -0.013153},{1.230023, 1.318520, -0.017029}}],
    Polygon[{{1.237130, 1.314731, -0.013153},{1.238538, 1.315754, -0.008953},{
      1.232442, 1.321849, -0.008953},{1.231419, 1.320442, -0.013153}}],
    Polygon[{{1.238538, 1.315754, -0.008953},{1.239396, 1.316378, -0.004532},{
      1.233066, 1.322708, -0.004532},{1.232442, 1.321849, -0.008953}}],
    Polygon[{{1.239396, 1.316378, -0.004532},{1.239685, 1.316587, 0.000000},{
      1.233275, 1.322997, 0.000000},{1.233066, 1.322708, -0.004532}}],
    Polygon[{{1.239685, 1.316587, 0.000000},{1.239396, 1.316378, 0.004532},{
      1.233066, 1.322708, 0.004532},{1.233275, 1.322997, 0.000000}}],
    Polygon[{{1.239396, 1.316378, 0.004532},{1.238538, 1.315754, 0.008953},{
      1.232442, 1.321849, 0.008953},{1.233066, 1.322708, 0.004532}}],
    Polygon[{{1.238538, 1.315754, 0.008953},{1.237130, 1.314731, 0.013153},{
      1.231419, 1.320442, 0.013153},{1.232442, 1.321849, 0.008953}}],
    Polygon[{{1.237130, 1.314731, 0.013153},{1.235208, 1.313335, 0.017029},{
      1.230023, 1.318520, 0.017029},{1.231419, 1.320442, 0.013153}}],
    Polygon[{{1.235208, 1.313335, 0.017029},{1.232820, 1.311599, 0.020486},{
      1.228288, 1.316132, 0.020486},{1.230023, 1.318520, 0.017029}}],
    Polygon[{{1.232820, 1.311599, 0.020486},{1.230023, 1.309568, 0.023438},{
      1.226256, 1.313335, 0.023438},{1.228288, 1.316132, 0.020486}}],
    Polygon[{{1.230023, 1.309568, 0.023438},{1.226887, 1.307289, 0.025814},{
      1.223977, 1.310199, 0.025814},{1.226256, 1.313335, 0.023438}}],
    Polygon[{{1.226887, 1.307289, 0.025814},{1.223489, 1.304820, 0.027554},{
      1.221509, 1.306801, 0.027554},{1.223977, 1.310199, 0.025814}}],
    Polygon[{{1.223489, 1.304820, 0.027554},{1.219913, 1.302222, 0.028615},{
      1.218910, 1.303225, 0.028615},{1.221509, 1.306801, 0.027554}}],
    Polygon[{{1.218910, 1.303225, -0.028615},{1.221509, 1.306801, -0.027554},{
      1.219013, 1.308073, -0.027554},{1.217647, 1.303868, -0.028615}}],
    Polygon[{{1.221509, 1.306801, -0.027554},{1.223977, 1.310199, -0.025814},{
      1.220311, 1.312067, -0.025814},{1.219013, 1.308073, -0.027554}}],
    Polygon[{{1.223977, 1.310199, -0.025814},{1.226256, 1.313335, -0.023438},{
      1.221509, 1.315754, -0.023438},{1.220311, 1.312067, -0.025814}}],
    Polygon[{{1.226256, 1.313335, -0.023438},{1.228288, 1.316132, -0.020486},{
      1.222577, 1.319041, -0.020486},{1.221509, 1.315754, -0.023438}}],
    Polygon[{{1.228288, 1.316132, -0.020486},{1.230023, 1.318520, -0.017029},{
      1.223489, 1.321849, -0.017029},{1.222577, 1.319041, -0.020486}}],
    Polygon[{{1.230023, 1.318520, -0.017029},{1.231419, 1.320442, -0.013153},{
      1.224223, 1.324108, -0.013153},{1.223489, 1.321849, -0.017029}}],
    Polygon[{{1.231419, 1.320442, -0.013153},{1.232442, 1.321849, -0.008953},{
      1.224761, 1.325763, -0.008953},{1.224223, 1.324108, -0.013153}}],
    Polygon[{{1.232442, 1.321849, -0.008953},{1.233066, 1.322708, -0.004532},{
      1.225089, 1.326772, -0.004532},{1.224761, 1.325763, -0.008953}}],
    Polygon[{{1.233066, 1.322708, -0.004532},{1.233275, 1.322997, 0.000000},{
      1.225199, 1.327112, 0.000000},{1.225089, 1.326772, -0.004532}}],
    Polygon[{{1.233275, 1.322997, 0.000000},{1.233066, 1.322708, 0.004532},{
      1.225089, 1.326772, 0.004532},{1.225199, 1.327112, 0.000000}}],
    Polygon[{{1.233066, 1.322708, 0.004532},{1.232442, 1.321849, 0.008953},{
      1.224761, 1.325763, 0.008953},{1.225089, 1.326772, 0.004532}}],
    Polygon[{{1.232442, 1.321849, 0.008953},{1.231419, 1.320442, 0.013153},{
      1.224223, 1.324108, 0.013153},{1.224761, 1.325763, 0.008953}}],
    Polygon[{{1.231419, 1.320442, 0.013153},{1.230023, 1.318520, 0.017029},{
      1.223489, 1.321849, 0.017029},{1.224223, 1.324108, 0.013153}}],
    Polygon[{{1.230023, 1.318520, 0.017029},{1.228288, 1.316132, 0.020486},{
      1.222577, 1.319041, 0.020486},{1.223489, 1.321849, 0.017029}}],
    Polygon[{{1.228288, 1.316132, 0.020486},{1.226256, 1.313335, 0.023438},{
      1.221509, 1.315754, 0.023438},{1.222577, 1.319041, 0.020486}}],
    Polygon[{{1.226256, 1.313335, 0.023438},{1.223977, 1.310199, 0.025814},{
      1.220311, 1.312067, 0.025814},{1.221509, 1.315754, 0.023438}}],
    Polygon[{{1.223977, 1.310199, 0.025814},{1.221509, 1.306801, 0.027554},{
      1.219013, 1.308073, 0.027554},{1.220311, 1.312067, 0.025814}}],
    Polygon[{{1.221509, 1.306801, 0.027554},{1.218910, 1.303225, 0.028615},{
      1.217647, 1.303868, 0.028615},{1.219013, 1.308073, 0.027554}}],
    Polygon[{{1.217647, 1.303868, -0.028615},{1.219013, 1.308073, -0.027554},{
      1.216246, 1.308511, -0.027554},{1.216246, 1.304090, -0.028615}}],
    Polygon[{{1.219013, 1.308073, -0.027554},{1.220311, 1.312067, -0.025814},{
      1.216246, 1.312711, -0.025814},{1.216246, 1.308511, -0.027554}}],
    Polygon[{{1.220311, 1.312067, -0.025814},{1.221509, 1.315754, -0.023438},{
      1.216246, 1.316587, -0.023438},{1.216246, 1.312711, -0.025814}}],
    Polygon[{{1.221509, 1.315754, -0.023438},{1.222577, 1.319041, -0.020486},{
      1.216246, 1.320044, -0.020486},{1.216246, 1.316587, -0.023438}}],
    Polygon[{{1.222577, 1.319041, -0.020486},{1.223489, 1.321849, -0.017029},{
      1.216246, 1.322997, -0.017029},{1.216246, 1.320044, -0.020486}}],
    Polygon[{{1.223489, 1.321849, -0.017029},{1.224223, 1.324108, -0.013153},{
      1.216246, 1.325372, -0.013153},{1.216246, 1.322997, -0.017029}}],
    Polygon[{{1.224223, 1.324108, -0.013153},{1.224761, 1.325763, -0.008953},{
      1.216246, 1.327112, -0.008953},{1.216246, 1.325372, -0.013153}}],
    Polygon[{{1.224761, 1.325763, -0.008953},{1.225089, 1.326772, -0.004532},{
      1.216246, 1.328173, -0.004532},{1.216246, 1.327112, -0.008953}}],
    Polygon[{{1.225089, 1.326772, -0.004532},{1.225199, 1.327112, 0.000000},{
      1.216246, 1.328530, 0.000000},{1.216246, 1.328173, -0.004532}}],
    Polygon[{{1.225199, 1.327112, 0.000000},{1.225089, 1.326772, 0.004532},{
      1.216246, 1.328173, 0.004532},{1.216246, 1.328530, 0.000000}}],
    Polygon[{{1.225089, 1.326772, 0.004532},{1.224761, 1.325763, 0.008953},{
      1.216246, 1.327112, 0.008953},{1.216246, 1.328173, 0.004532}}],
    Polygon[{{1.224761, 1.325763, 0.008953},{1.224223, 1.324108, 0.013153},{
      1.216246, 1.325372, 0.013153},{1.216246, 1.327112, 0.008953}}],
    Polygon[{{1.224223, 1.324108, 0.013153},{1.223489, 1.321849, 0.017029},{
      1.216246, 1.322997, 0.017029},{1.216246, 1.325372, 0.013153}}],
    Polygon[{{1.223489, 1.321849, 0.017029},{1.222577, 1.319041, 0.020486},{
      1.216246, 1.320044, 0.020486},{1.216246, 1.322997, 0.017029}}],
    Polygon[{{1.222577, 1.319041, 0.020486},{1.221509, 1.315754, 0.023438},{
      1.216246, 1.316587, 0.023438},{1.216246, 1.320044, 0.020486}}],
    Polygon[{{1.221509, 1.315754, 0.023438},{1.220311, 1.312067, 0.025814},{
      1.216246, 1.312711, 0.025814},{1.216246, 1.316587, 0.023438}}],
    Polygon[{{1.220311, 1.312067, 0.025814},{1.219013, 1.308073, 0.027554},{
      1.216246, 1.308511, 0.027554},{1.216246, 1.312711, 0.025814}}],
    Polygon[{{1.219013, 1.308073, 0.027554},{1.217647, 1.303868, 0.028615},{
      1.216246, 1.304090, 0.028615},{1.216246, 1.308511, 0.027554}}],
    Polygon[{{1.216246, 1.304090, -0.028615},{1.216246, 1.308511, -0.027554},{
      1.213480, 1.308073, -0.027554},{1.214846, 1.303868, -0.028615}}],
    Polygon[{{1.216246, 1.308511, -0.027554},{1.216246, 1.312711, -0.025814},{
      1.212182, 1.312067, -0.025814},{1.213480, 1.308073, -0.027554}}],
    Polygon[{{1.216246, 1.312711, -0.025814},{1.216246, 1.316587, -0.023438},{
      1.210984, 1.315754, -0.023438},{1.212182, 1.312067, -0.025814}}],
    Polygon[{{1.216246, 1.316587, -0.023438},{1.216246, 1.320044, -0.020486},{
      1.209916, 1.319041, -0.020486},{1.210984, 1.315754, -0.023438}}],
    Polygon[{{1.216246, 1.320044, -0.020486},{1.216246, 1.322997, -0.017029},{
      1.209003, 1.321849, -0.017029},{1.209916, 1.319041, -0.020486}}],
    Polygon[{{1.216246, 1.322997, -0.017029},{1.216246, 1.325372, -0.013153},{
      1.208269, 1.324108, -0.013153},{1.209003, 1.321849, -0.017029}}],
    Polygon[{{1.216246, 1.325372, -0.013153},{1.216246, 1.327112, -0.008953},{
      1.207732, 1.325763, -0.008953},{1.208269, 1.324108, -0.013153}}],
    Polygon[{{1.216246, 1.327112, -0.008953},{1.216246, 1.328173, -0.004532},{
      1.207404, 1.326772, -0.004532},{1.207732, 1.325763, -0.008953}}],
    Polygon[{{1.216246, 1.328173, -0.004532},{1.216246, 1.328530, 0.000000},{
      1.207294, 1.327112, 0.000000},{1.207404, 1.326772, -0.004532}}],
    Polygon[{{1.216246, 1.328530, 0.000000},{1.216246, 1.328173, 0.004532},{
      1.207404, 1.326772, 0.004532},{1.207294, 1.327112, 0.000000}}],
    Polygon[{{1.216246, 1.328173, 0.004532},{1.216246, 1.327112, 0.008953},{
      1.207732, 1.325763, 0.008953},{1.207404, 1.326772, 0.004532}}],
    Polygon[{{1.216246, 1.327112, 0.008953},{1.216246, 1.325372, 0.013153},{
      1.208269, 1.324108, 0.013153},{1.207732, 1.325763, 0.008953}}],
    Polygon[{{1.216246, 1.325372, 0.013153},{1.216246, 1.322997, 0.017029},{
      1.209003, 1.321849, 0.017029},{1.208269, 1.324108, 0.013153}}],
    Polygon[{{1.216246, 1.322997, 0.017029},{1.216246, 1.320044, 0.020486},{
      1.209916, 1.319041, 0.020486},{1.209003, 1.321849, 0.017029}}],
    Polygon[{{1.216246, 1.320044, 0.020486},{1.216246, 1.316587, 0.023438},{
      1.210984, 1.315754, 0.023438},{1.209916, 1.319041, 0.020486}}],
    Polygon[{{1.216246, 1.316587, 0.023438},{1.216246, 1.312711, 0.025814},{
      1.212182, 1.312067, 0.025814},{1.210984, 1.315754, 0.023438}}],
    Polygon[{{1.216246, 1.312711, 0.025814},{1.216246, 1.308511, 0.027554},{
      1.213480, 1.308073, 0.027554},{1.212182, 1.312067, 0.025814}}],
    Polygon[{{1.216246, 1.308511, 0.027554},{1.216246, 1.304090, 0.028615},{
      1.214846, 1.303868, 0.028615},{1.213480, 1.308073, 0.027554}}],
    Polygon[{{1.214846, 1.303868, -0.028615},{1.213480, 1.308073, -0.027554},{
      1.210984, 1.306801, -0.027554},{1.213582, 1.303225, -0.028615}}],
    Polygon[{{1.213480, 1.308073, -0.027554},{1.212182, 1.312067, -0.025814},{
      1.208515, 1.310199, -0.025814},{1.210984, 1.306801, -0.027554}}],
    Polygon[{{1.212182, 1.312067, -0.025814},{1.210984, 1.315754, -0.023438},{
      1.206237, 1.313335, -0.023438},{1.208515, 1.310199, -0.025814}}],
    Polygon[{{1.210984, 1.315754, -0.023438},{1.209916, 1.319041, -0.020486},{
      1.204205, 1.316132, -0.020486},{1.206237, 1.313335, -0.023438}}],
    Polygon[{{1.209916, 1.319041, -0.020486},{1.209003, 1.321849, -0.017029},{
      1.202470, 1.318520, -0.017029},{1.204205, 1.316132, -0.020486}}],
    Polygon[{{1.209003, 1.321849, -0.017029},{1.208269, 1.324108, -0.013153},{
      1.201073, 1.320442, -0.013153},{1.202470, 1.318520, -0.017029}}],
    Polygon[{{1.208269, 1.324108, -0.013153},{1.207732, 1.325763, -0.008953},{
      1.200051, 1.321849, -0.008953},{1.201073, 1.320442, -0.013153}}],
    Polygon[{{1.207732, 1.325763, -0.008953},{1.207404, 1.326772, -0.004532},{
      1.199427, 1.322708, -0.004532},{1.200051, 1.321849, -0.008953}}],
    Polygon[{{1.207404, 1.326772, -0.004532},{1.207294, 1.327112, 0.000000},{
      1.199217, 1.322997, 0.000000},{1.199427, 1.322708, -0.004532}}],
    Polygon[{{1.207294, 1.327112, 0.000000},{1.207404, 1.326772, 0.004532},{
      1.199427, 1.322708, 0.004532},{1.199217, 1.322997, 0.000000}}],
    Polygon[{{1.207404, 1.326772, 0.004532},{1.207732, 1.325763, 0.008953},{
      1.200051, 1.321849, 0.008953},{1.199427, 1.322708, 0.004532}}],
    Polygon[{{1.207732, 1.325763, 0.008953},{1.208269, 1.324108, 0.013153},{
      1.201073, 1.320442, 0.013153},{1.200051, 1.321849, 0.008953}}],
    Polygon[{{1.208269, 1.324108, 0.013153},{1.209003, 1.321849, 0.017029},{
      1.202470, 1.318520, 0.017029},{1.201073, 1.320442, 0.013153}}],
    Polygon[{{1.209003, 1.321849, 0.017029},{1.209916, 1.319041, 0.020486},{
      1.204205, 1.316132, 0.020486},{1.202470, 1.318520, 0.017029}}],
    Polygon[{{1.209916, 1.319041, 0.020486},{1.210984, 1.315754, 0.023438},{
      1.206237, 1.313335, 0.023438},{1.204205, 1.316132, 0.020486}}],
    Polygon[{{1.210984, 1.315754, 0.023438},{1.212182, 1.312067, 0.025814},{
      1.208515, 1.310199, 0.025814},{1.206237, 1.313335, 0.023438}}],
    Polygon[{{1.212182, 1.312067, 0.025814},{1.213480, 1.308073, 0.027554},{
      1.210984, 1.306801, 0.027554},{1.208515, 1.310199, 0.025814}}],
    Polygon[{{1.213480, 1.308073, 0.027554},{1.214846, 1.303868, 0.028615},{
      1.213582, 1.303225, 0.028615},{1.210984, 1.306801, 0.027554}}],
    Polygon[{{1.213582, 1.303225, -0.028615},{1.210984, 1.306801, -0.027554},{
      1.209003, 1.304820, -0.027554},{1.212580, 1.302222, -0.028615}}],
    Polygon[{{1.210984, 1.306801, -0.027554},{1.208515, 1.310199, -0.025814},{
      1.205606, 1.307289, -0.025814},{1.209003, 1.304820, -0.027554}}],
    Polygon[{{1.208515, 1.310199, -0.025814},{1.206237, 1.313335, -0.023438},{
      1.202470, 1.309568, -0.023438},{1.205606, 1.307289, -0.025814}}],
    Polygon[{{1.206237, 1.313335, -0.023438},{1.204205, 1.316132, -0.020486},{
      1.199673, 1.311599, -0.020486},{1.202470, 1.309568, -0.023438}}],
    Polygon[{{1.204205, 1.316132, -0.020486},{1.202470, 1.318520, -0.017029},{
      1.197284, 1.313335, -0.017029},{1.199673, 1.311599, -0.020486}}],
    Polygon[{{1.202470, 1.318520, -0.017029},{1.201073, 1.320442, -0.013153},{
      1.195363, 1.314731, -0.013153},{1.197284, 1.313335, -0.017029}}],
    Polygon[{{1.201073, 1.320442, -0.013153},{1.200051, 1.321849, -0.008953},{
      1.193955, 1.315754, -0.008953},{1.195363, 1.314731, -0.013153}}],
    Polygon[{{1.200051, 1.321849, -0.008953},{1.199427, 1.322708, -0.004532},{
      1.193097, 1.316378, -0.004532},{1.193955, 1.315754, -0.008953}}],
    Polygon[{{1.199427, 1.322708, -0.004532},{1.199217, 1.322997, 0.000000},{
      1.192808, 1.316587, 0.000000},{1.193097, 1.316378, -0.004532}}],
    Polygon[{{1.199217, 1.322997, 0.000000},{1.199427, 1.322708, 0.004532},{
      1.193097, 1.316378, 0.004532},{1.192808, 1.316587, 0.000000}}],
    Polygon[{{1.199427, 1.322708, 0.004532},{1.200051, 1.321849, 0.008953},{
      1.193955, 1.315754, 0.008953},{1.193097, 1.316378, 0.004532}}],
    Polygon[{{1.200051, 1.321849, 0.008953},{1.201073, 1.320442, 0.013153},{
      1.195363, 1.314731, 0.013153},{1.193955, 1.315754, 0.008953}}],
    Polygon[{{1.201073, 1.320442, 0.013153},{1.202470, 1.318520, 0.017029},{
      1.197284, 1.313335, 0.017029},{1.195363, 1.314731, 0.013153}}],
    Polygon[{{1.202470, 1.318520, 0.017029},{1.204205, 1.316132, 0.020486},{
      1.199673, 1.311599, 0.020486},{1.197284, 1.313335, 0.017029}}],
    Polygon[{{1.204205, 1.316132, 0.020486},{1.206237, 1.313335, 0.023438},{
      1.202470, 1.309568, 0.023438},{1.199673, 1.311599, 0.020486}}],
    Polygon[{{1.206237, 1.313335, 0.023438},{1.208515, 1.310199, 0.025814},{
      1.205606, 1.307289, 0.025814},{1.202470, 1.309568, 0.023438}}],
    Polygon[{{1.208515, 1.310199, 0.025814},{1.210984, 1.306801, 0.027554},{
      1.209003, 1.304820, 0.027554},{1.205606, 1.307289, 0.025814}}],
    Polygon[{{1.210984, 1.306801, 0.027554},{1.213582, 1.303225, 0.028615},{
      1.212580, 1.302222, 0.028615},{1.209003, 1.304820, 0.027554}}],
    Polygon[{{1.212580, 1.302222, -0.028615},{1.209003, 1.304820, -0.027554},{
      1.207732, 1.302325, -0.027554},{1.211936, 1.300959, -0.028615}}],
    Polygon[{{1.209003, 1.304820, -0.027554},{1.205606, 1.307289, -0.025814},{
      1.203737, 1.303623, -0.025814},{1.207732, 1.302325, -0.027554}}],
    Polygon[{{1.205606, 1.307289, -0.025814},{1.202470, 1.309568, -0.023438},{
      1.200051, 1.304820, -0.023438},{1.203737, 1.303623, -0.025814}}],
    Polygon[{{1.202470, 1.309568, -0.023438},{1.199673, 1.311599, -0.020486},{
      1.196763, 1.305889, -0.020486},{1.200051, 1.304820, -0.023438}}],
    Polygon[{{1.199673, 1.311599, -0.020486},{1.197284, 1.313335, -0.017029},{
      1.193955, 1.306801, -0.017029},{1.196763, 1.305889, -0.020486}}],
    Polygon[{{1.197284, 1.313335, -0.017029},{1.195363, 1.314731, -0.013153},{
      1.191696, 1.307535, -0.013153},{1.193955, 1.306801, -0.017029}}],
    Polygon[{{1.195363, 1.314731, -0.013153},{1.193955, 1.315754, -0.008953},{
      1.190041, 1.308073, -0.008953},{1.191696, 1.307535, -0.013153}}],
    Polygon[{{1.193955, 1.315754, -0.008953},{1.193097, 1.316378, -0.004532},{
      1.189032, 1.308401, -0.004532},{1.190041, 1.308073, -0.008953}}],
    Polygon[{{1.193097, 1.316378, -0.004532},{1.192808, 1.316587, 0.000000},{
      1.188693, 1.308511, 0.000000},{1.189032, 1.308401, -0.004532}}],
    Polygon[{{1.192808, 1.316587, 0.000000},{1.193097, 1.316378, 0.004532},{
      1.189032, 1.308401, 0.004532},{1.188693, 1.308511, 0.000000}}],
    Polygon[{{1.193097, 1.316378, 0.004532},{1.193955, 1.315754, 0.008953},{
      1.190041, 1.308073, 0.008953},{1.189032, 1.308401, 0.004532}}],
    Polygon[{{1.193955, 1.315754, 0.008953},{1.195363, 1.314731, 0.013153},{
      1.191696, 1.307535, 0.013153},{1.190041, 1.308073, 0.008953}}],
    Polygon[{{1.195363, 1.314731, 0.013153},{1.197284, 1.313335, 0.017029},{
      1.193955, 1.306801, 0.017029},{1.191696, 1.307535, 0.013153}}],
    Polygon[{{1.197284, 1.313335, 0.017029},{1.199673, 1.311599, 0.020486},{
      1.196763, 1.305889, 0.020486},{1.193955, 1.306801, 0.017029}}],
    Polygon[{{1.199673, 1.311599, 0.020486},{1.202470, 1.309568, 0.023438},{
      1.200051, 1.304820, 0.023438},{1.196763, 1.305889, 0.020486}}],
    Polygon[{{1.202470, 1.309568, 0.023438},{1.205606, 1.307289, 0.025814},{
      1.203737, 1.303623, 0.025814},{1.200051, 1.304820, 0.023438}}],
    Polygon[{{1.205606, 1.307289, 0.025814},{1.209003, 1.304820, 0.027554},{
      1.207732, 1.302325, 0.027554},{1.203737, 1.303623, 0.025814}}],
    Polygon[{{1.209003, 1.304820, 0.027554},{1.212580, 1.302222, 0.028615},{
      1.211936, 1.300959, 0.028615},{1.207732, 1.302325, 0.027554}}],
    Polygon[{{1.211936, 1.300959, -0.028615},{1.207732, 1.302325, -0.027554},{
      1.207294, 1.299558, -0.027554},{1.211714, 1.299558, -0.028615}}],
    Polygon[{{1.207732, 1.302325, -0.027554},{1.203737, 1.303623, -0.025814},{
      1.203094, 1.299558, -0.025814},{1.207294, 1.299558, -0.027554}}],
    Polygon[{{1.203737, 1.303623, -0.025814},{1.200051, 1.304820, -0.023438},{
      1.199217, 1.299558, -0.023438},{1.203094, 1.299558, -0.025814}}],
    Polygon[{{1.200051, 1.304820, -0.023438},{1.196763, 1.305889, -0.020486},{
      1.195760, 1.299558, -0.020486},{1.199217, 1.299558, -0.023438}}],
    Polygon[{{1.196763, 1.305889, -0.020486},{1.193955, 1.306801, -0.017029},{
      1.192808, 1.299558, -0.017029},{1.195760, 1.299558, -0.020486}}],
    Polygon[{{1.193955, 1.306801, -0.017029},{1.191696, 1.307535, -0.013153},{
      1.190433, 1.299558, -0.013153},{1.192808, 1.299558, -0.017029}}],
    Polygon[{{1.191696, 1.307535, -0.013153},{1.190041, 1.308073, -0.008953},{
      1.188693, 1.299558, -0.008953},{1.190433, 1.299558, -0.013153}}],
    Polygon[{{1.190041, 1.308073, -0.008953},{1.189032, 1.308401, -0.004532},{
      1.187631, 1.299558, -0.004532},{1.188693, 1.299558, -0.008953}}],
    Polygon[{{1.189032, 1.308401, -0.004532},{1.188693, 1.308511, 0.000000},{
      1.187275, 1.299558, 0.000000},{1.187631, 1.299558, -0.004532}}],
    Polygon[{{1.188693, 1.308511, 0.000000},{1.189032, 1.308401, 0.004532},{
      1.187631, 1.299558, 0.004532},{1.187275, 1.299558, 0.000000}}],
    Polygon[{{1.189032, 1.308401, 0.004532},{1.190041, 1.308073, 0.008953},{
      1.188693, 1.299558, 0.008953},{1.187631, 1.299558, 0.004532}}],
    Polygon[{{1.190041, 1.308073, 0.008953},{1.191696, 1.307535, 0.013153},{
      1.190433, 1.299558, 0.013153},{1.188693, 1.299558, 0.008953}}],
    Polygon[{{1.191696, 1.307535, 0.013153},{1.193955, 1.306801, 0.017029},{
      1.192808, 1.299558, 0.017029},{1.190433, 1.299558, 0.013153}}],
    Polygon[{{1.193955, 1.306801, 0.017029},{1.196763, 1.305889, 0.020486},{
      1.195760, 1.299558, 0.020486},{1.192808, 1.299558, 0.017029}}],
    Polygon[{{1.196763, 1.305889, 0.020486},{1.200051, 1.304820, 0.023438},{
      1.199217, 1.299558, 0.023438},{1.195760, 1.299558, 0.020486}}],
    Polygon[{{1.200051, 1.304820, 0.023438},{1.203737, 1.303623, 0.025814},{
      1.203094, 1.299558, 0.025814},{1.199217, 1.299558, 0.023438}}],
    Polygon[{{1.203737, 1.303623, 0.025814},{1.207732, 1.302325, 0.027554},{
      1.207294, 1.299558, 0.027554},{1.203094, 1.299558, 0.025814}}],
    Polygon[{{1.207732, 1.302325, 0.027554},{1.211936, 1.300959, 0.028615},{
      1.211714, 1.299558, 0.028615},{1.207294, 1.299558, 0.027554}}],
    Polygon[{{1.211714, 1.299558, -0.028615},{1.207294, 1.299558, -0.027554},{
      1.207732, 1.296792, -0.027554},{1.211936, 1.298158, -0.028615}}],
    Polygon[{{1.207294, 1.299558, -0.027554},{1.203094, 1.299558, -0.025814},{
      1.203737, 1.295494, -0.025814},{1.207732, 1.296792, -0.027554}}],
    Polygon[{{1.203094, 1.299558, -0.025814},{1.199217, 1.299558, -0.023438},{
      1.200051, 1.294296, -0.023438},{1.203737, 1.295494, -0.025814}}],
    Polygon[{{1.199217, 1.299558, -0.023438},{1.195760, 1.299558, -0.020486},{
      1.196763, 1.293228, -0.020486},{1.200051, 1.294296, -0.023438}}],
    Polygon[{{1.195760, 1.299558, -0.020486},{1.192808, 1.299558, -0.017029},{
      1.193955, 1.292315, -0.017029},{1.196763, 1.293228, -0.020486}}],
    Polygon[{{1.192808, 1.299558, -0.017029},{1.190433, 1.299558, -0.013153},{
      1.191696, 1.291581, -0.013153},{1.193955, 1.292315, -0.017029}}],
    Polygon[{{1.190433, 1.299558, -0.013153},{1.188693, 1.299558, -0.008953},{
      1.190041, 1.291044, -0.008953},{1.191696, 1.291581, -0.013153}}],
    Polygon[{{1.188693, 1.299558, -0.008953},{1.187631, 1.299558, -0.004532},{
      1.189032, 1.290716, -0.004532},{1.190041, 1.291044, -0.008953}}],
    Polygon[{{1.187631, 1.299558, -0.004532},{1.187275, 1.299558, 0.000000},{
      1.188693, 1.290605, 0.000000},{1.189032, 1.290716, -0.004532}}],
    Polygon[{{1.187275, 1.299558, 0.000000},{1.187631, 1.299558, 0.004532},{
      1.189032, 1.290716, 0.004532},{1.188693, 1.290605, 0.000000}}],
    Polygon[{{1.187631, 1.299558, 0.004532},{1.188693, 1.299558, 0.008953},{
      1.190041, 1.291044, 0.008953},{1.189032, 1.290716, 0.004532}}],
    Polygon[{{1.188693, 1.299558, 0.008953},{1.190433, 1.299558, 0.013153},{
      1.191696, 1.291581, 0.013153},{1.190041, 1.291044, 0.008953}}],
    Polygon[{{1.190433, 1.299558, 0.013153},{1.192808, 1.299558, 0.017029},{
      1.193955, 1.292315, 0.017029},{1.191696, 1.291581, 0.013153}}],
    Polygon[{{1.192808, 1.299558, 0.017029},{1.195760, 1.299558, 0.020486},{
      1.196763, 1.293228, 0.020486},{1.193955, 1.292315, 0.017029}}],
    Polygon[{{1.195760, 1.299558, 0.020486},{1.199217, 1.299558, 0.023438},{
      1.200051, 1.294296, 0.023438},{1.196763, 1.293228, 0.020486}}],
    Polygon[{{1.199217, 1.299558, 0.023438},{1.203094, 1.299558, 0.025814},{
      1.203737, 1.295494, 0.025814},{1.200051, 1.294296, 0.023438}}],
    Polygon[{{1.203094, 1.299558, 0.025814},{1.207294, 1.299558, 0.027554},{
      1.207732, 1.296792, 0.027554},{1.203737, 1.295494, 0.025814}}],
    Polygon[{{1.207294, 1.299558, 0.027554},{1.211714, 1.299558, 0.028615},{
      1.211936, 1.298158, 0.028615},{1.207732, 1.296792, 0.027554}}],
    Polygon[{{1.211936, 1.298158, -0.028615},{1.207732, 1.296792, -0.027554},{
      1.209003, 1.294296, -0.027554},{1.212580, 1.296894, -0.028615}}],
    Polygon[{{1.207732, 1.296792, -0.027554},{1.203737, 1.295494, -0.025814},{
      1.205606, 1.291827, -0.025814},{1.209003, 1.294296, -0.027554}}],
    Polygon[{{1.203737, 1.295494, -0.025814},{1.200051, 1.294296, -0.023438},{
      1.202470, 1.289549, -0.023438},{1.205606, 1.291827, -0.025814}}],
    Polygon[{{1.200051, 1.294296, -0.023438},{1.196763, 1.293228, -0.020486},{
      1.199673, 1.287517, -0.020486},{1.202470, 1.289549, -0.023438}}],
    Polygon[{{1.196763, 1.293228, -0.020486},{1.193955, 1.292315, -0.017029},{
      1.197284, 1.285781, -0.017029},{1.199673, 1.287517, -0.020486}}],
    Polygon[{{1.193955, 1.292315, -0.017029},{1.191696, 1.291581, -0.013153},{
      1.195363, 1.284385, -0.013153},{1.197284, 1.285781, -0.017029}}],
    Polygon[{{1.191696, 1.291581, -0.013153},{1.190041, 1.291044, -0.008953},{
      1.193955, 1.283363, -0.008953},{1.195363, 1.284385, -0.013153}}],
    Polygon[{{1.190041, 1.291044, -0.008953},{1.189032, 1.290716, -0.004532},{
      1.193097, 1.282739, -0.004532},{1.193955, 1.283363, -0.008953}}],
    Polygon[{{1.189032, 1.290716, -0.004532},{1.188693, 1.290605, 0.000000},{
      1.192808, 1.282529, 0.000000},{1.193097, 1.282739, -0.004532}}],
    Polygon[{{1.188693, 1.290605, 0.000000},{1.189032, 1.290716, 0.004532},{
      1.193097, 1.282739, 0.004532},{1.192808, 1.282529, 0.000000}}],
    Polygon[{{1.189032, 1.290716, 0.004532},{1.190041, 1.291044, 0.008953},{
      1.193955, 1.283363, 0.008953},{1.193097, 1.282739, 0.004532}}],
    Polygon[{{1.190041, 1.291044, 0.008953},{1.191696, 1.291581, 0.013153},{
      1.195363, 1.284385, 0.013153},{1.193955, 1.283363, 0.008953}}],
    Polygon[{{1.191696, 1.291581, 0.013153},{1.193955, 1.292315, 0.017029},{
      1.197284, 1.285781, 0.017029},{1.195363, 1.284385, 0.013153}}],
    Polygon[{{1.193955, 1.292315, 0.017029},{1.196763, 1.293228, 0.020486},{
      1.199673, 1.287517, 0.020486},{1.197284, 1.285781, 0.017029}}],
    Polygon[{{1.196763, 1.293228, 0.020486},{1.200051, 1.294296, 0.023438},{
      1.202470, 1.289549, 0.023438},{1.199673, 1.287517, 0.020486}}],
    Polygon[{{1.200051, 1.294296, 0.023438},{1.203737, 1.295494, 0.025814},{
      1.205606, 1.291827, 0.025814},{1.202470, 1.289549, 0.023438}}],
    Polygon[{{1.203737, 1.295494, 0.025814},{1.207732, 1.296792, 0.027554},{
      1.209003, 1.294296, 0.027554},{1.205606, 1.291827, 0.025814}}],
    Polygon[{{1.207732, 1.296792, 0.027554},{1.211936, 1.298158, 0.028615},{
      1.212580, 1.296894, 0.028615},{1.209003, 1.294296, 0.027554}}],
    Polygon[{{1.212580, 1.296894, -0.028615},{1.209003, 1.294296, -0.027554},{
      1.210984, 1.292315, -0.027554},{1.213582, 1.295892, -0.028615}}],
    Polygon[{{1.209003, 1.294296, -0.027554},{1.205606, 1.291827, -0.025814},{
      1.208515, 1.288917, -0.025814},{1.210984, 1.292315, -0.027554}}],
    Polygon[{{1.205606, 1.291827, -0.025814},{1.202470, 1.289549, -0.023438},{
      1.206237, 1.285781, -0.023438},{1.208515, 1.288917, -0.025814}}],
    Polygon[{{1.202470, 1.289549, -0.023438},{1.199673, 1.287517, -0.020486},{
      1.204205, 1.282985, -0.020486},{1.206237, 1.285781, -0.023438}}],
    Polygon[{{1.199673, 1.287517, -0.020486},{1.197284, 1.285781, -0.017029},{
      1.202470, 1.280596, -0.017029},{1.204205, 1.282985, -0.020486}}],
    Polygon[{{1.197284, 1.285781, -0.017029},{1.195363, 1.284385, -0.013153},{
      1.201073, 1.278674, -0.013153},{1.202470, 1.280596, -0.017029}}],
    Polygon[{{1.195363, 1.284385, -0.013153},{1.193955, 1.283363, -0.008953},{
      1.200051, 1.277267, -0.008953},{1.201073, 1.278674, -0.013153}}],
    Polygon[{{1.193955, 1.283363, -0.008953},{1.193097, 1.282739, -0.004532},{
      1.199427, 1.276408, -0.004532},{1.200051, 1.277267, -0.008953}}],
    Polygon[{{1.193097, 1.282739, -0.004532},{1.192808, 1.282529, 0.000000},{
      1.199217, 1.276120, 0.000000},{1.199427, 1.276408, -0.004532}}],
    Polygon[{{1.192808, 1.282529, 0.000000},{1.193097, 1.282739, 0.004532},{
      1.199427, 1.276408, 0.004532},{1.199217, 1.276120, 0.000000}}],
    Polygon[{{1.193097, 1.282739, 0.004532},{1.193955, 1.283363, 0.008953},{
      1.200051, 1.277267, 0.008953},{1.199427, 1.276408, 0.004532}}],
    Polygon[{{1.193955, 1.283363, 0.008953},{1.195363, 1.284385, 0.013153},{
      1.201073, 1.278674, 0.013153},{1.200051, 1.277267, 0.008953}}],
    Polygon[{{1.195363, 1.284385, 0.013153},{1.197284, 1.285781, 0.017029},{
      1.202470, 1.280596, 0.017029},{1.201073, 1.278674, 0.013153}}],
    Polygon[{{1.197284, 1.285781, 0.017029},{1.199673, 1.287517, 0.020486},{
      1.204205, 1.282985, 0.020486},{1.202470, 1.280596, 0.017029}}],
    Polygon[{{1.199673, 1.287517, 0.020486},{1.202470, 1.289549, 0.023438},{
      1.206237, 1.285781, 0.023438},{1.204205, 1.282985, 0.020486}}],
    Polygon[{{1.202470, 1.289549, 0.023438},{1.205606, 1.291827, 0.025814},{
      1.208515, 1.288917, 0.025814},{1.206237, 1.285781, 0.023438}}],
    Polygon[{{1.205606, 1.291827, 0.025814},{1.209003, 1.294296, 0.027554},{
      1.210984, 1.292315, 0.027554},{1.208515, 1.288917, 0.025814}}],
    Polygon[{{1.209003, 1.294296, 0.027554},{1.212580, 1.296894, 0.028615},{
      1.213582, 1.295892, 0.028615},{1.210984, 1.292315, 0.027554}}],
    Polygon[{{1.213582, 1.295892, -0.028615},{1.210984, 1.292315, -0.027554},{
      1.213480, 1.291044, -0.027554},{1.214846, 1.295248, -0.028615}}],
    Polygon[{{1.210984, 1.292315, -0.027554},{1.208515, 1.288917, -0.025814},{
      1.212182, 1.287049, -0.025814},{1.213480, 1.291044, -0.027554}}],
    Polygon[{{1.208515, 1.288917, -0.025814},{1.206237, 1.285781, -0.023438},{
      1.210984, 1.283363, -0.023438},{1.212182, 1.287049, -0.025814}}],
    Polygon[{{1.206237, 1.285781, -0.023438},{1.204205, 1.282985, -0.020486},{
      1.209916, 1.280075, -0.020486},{1.210984, 1.283363, -0.023438}}],
    Polygon[{{1.204205, 1.282985, -0.020486},{1.202470, 1.280596, -0.017029},{
      1.209003, 1.277267, -0.017029},{1.209916, 1.280075, -0.020486}}],
    Polygon[{{1.202470, 1.280596, -0.017029},{1.201073, 1.278674, -0.013153},{
      1.208269, 1.275008, -0.013153},{1.209003, 1.277267, -0.017029}}],
    Polygon[{{1.201073, 1.278674, -0.013153},{1.200051, 1.277267, -0.008953},{
      1.207732, 1.273353, -0.008953},{1.208269, 1.275008, -0.013153}}],
    Polygon[{{1.200051, 1.277267, -0.008953},{1.199427, 1.276408, -0.004532},{
      1.207404, 1.272344, -0.004532},{1.207732, 1.273353, -0.008953}}],
    Polygon[{{1.199427, 1.276408, -0.004532},{1.199217, 1.276120, 0.000000},{
      1.207294, 1.272005, 0.000000},{1.207404, 1.272344, -0.004532}}],
    Polygon[{{1.199217, 1.276120, 0.000000},{1.199427, 1.276408, 0.004532},{
      1.207404, 1.272344, 0.004532},{1.207294, 1.272005, 0.000000}}],
    Polygon[{{1.199427, 1.276408, 0.004532},{1.200051, 1.277267, 0.008953},{
      1.207732, 1.273353, 0.008953},{1.207404, 1.272344, 0.004532}}],
    Polygon[{{1.200051, 1.277267, 0.008953},{1.201073, 1.278674, 0.013153},{
      1.208269, 1.275008, 0.013153},{1.207732, 1.273353, 0.008953}}],
    Polygon[{{1.201073, 1.278674, 0.013153},{1.202470, 1.280596, 0.017029},{
      1.209003, 1.277267, 0.017029},{1.208269, 1.275008, 0.013153}}],
    Polygon[{{1.202470, 1.280596, 0.017029},{1.204205, 1.282985, 0.020486},{
      1.209916, 1.280075, 0.020486},{1.209003, 1.277267, 0.017029}}],
    Polygon[{{1.204205, 1.282985, 0.020486},{1.206237, 1.285781, 0.023438},{
      1.210984, 1.283363, 0.023438},{1.209916, 1.280075, 0.020486}}],
    Polygon[{{1.206237, 1.285781, 0.023438},{1.208515, 1.288917, 0.025814},{
      1.212182, 1.287049, 0.025814},{1.210984, 1.283363, 0.023438}}],
    Polygon[{{1.208515, 1.288917, 0.025814},{1.210984, 1.292315, 0.027554},{
      1.213480, 1.291044, 0.027554},{1.212182, 1.287049, 0.025814}}],
    Polygon[{{1.210984, 1.292315, 0.027554},{1.213582, 1.295892, 0.028615},{
      1.214846, 1.295248, 0.028615},{1.213480, 1.291044, 0.027554}}],
    Polygon[{{1.214846, 1.295248, -0.028615},{1.213480, 1.291044, -0.027554},{
      1.216246, 1.290605, -0.027554},{1.216246, 1.295026, -0.028615}}],
    Polygon[{{1.213480, 1.291044, -0.027554},{1.212182, 1.287049, -0.025814},{
      1.216246, 1.286405, -0.025814},{1.216246, 1.290605, -0.027554}}],
    Polygon[{{1.212182, 1.287049, -0.025814},{1.210984, 1.283363, -0.023438},{
      1.216246, 1.282529, -0.023438},{1.216246, 1.286405, -0.025814}}],
    Polygon[{{1.210984, 1.283363, -0.023438},{1.209916, 1.280075, -0.020486},{
      1.216246, 1.279072, -0.020486},{1.216246, 1.282529, -0.023438}}],
    Polygon[{{1.209916, 1.280075, -0.020486},{1.209003, 1.277267, -0.017029},{
      1.216246, 1.276120, -0.017029},{1.216246, 1.279072, -0.020486}}],
    Polygon[{{1.209003, 1.277267, -0.017029},{1.208269, 1.275008, -0.013153},{
      1.216246, 1.273744, -0.013153},{1.216246, 1.276120, -0.017029}}],
    Polygon[{{1.208269, 1.275008, -0.013153},{1.207732, 1.273353, -0.008953},{
      1.216246, 1.272005, -0.008953},{1.216246, 1.273744, -0.013153}}],
    Polygon[{{1.207732, 1.273353, -0.008953},{1.207404, 1.272344, -0.004532},{
      1.216246, 1.270943, -0.004532},{1.216246, 1.272005, -0.008953}}],
    Polygon[{{1.207404, 1.272344, -0.004532},{1.207294, 1.272005, 0.000000},{
      1.216246, 1.270587, 0.000000},{1.216246, 1.270943, -0.004532}}],
    Polygon[{{1.207294, 1.272005, 0.000000},{1.207404, 1.272344, 0.004532},{
      1.216246, 1.270943, 0.004532},{1.216246, 1.270587, 0.000000}}],
    Polygon[{{1.207404, 1.272344, 0.004532},{1.207732, 1.273353, 0.008953},{
      1.216246, 1.272005, 0.008953},{1.216246, 1.270943, 0.004532}}],
    Polygon[{{1.207732, 1.273353, 0.008953},{1.208269, 1.275008, 0.013153},{
      1.216246, 1.273744, 0.013153},{1.216246, 1.272005, 0.008953}}],
    Polygon[{{1.208269, 1.275008, 0.013153},{1.209003, 1.277267, 0.017029},{
      1.216246, 1.276120, 0.017029},{1.216246, 1.273744, 0.013153}}],
    Polygon[{{1.209003, 1.277267, 0.017029},{1.209916, 1.280075, 0.020486},{
      1.216246, 1.279072, 0.020486},{1.216246, 1.276120, 0.017029}}],
    Polygon[{{1.209916, 1.280075, 0.020486},{1.210984, 1.283363, 0.023438},{
      1.216246, 1.282529, 0.023438},{1.216246, 1.279072, 0.020486}}],
    Polygon[{{1.210984, 1.283363, 0.023438},{1.212182, 1.287049, 0.025814},{
      1.216246, 1.286405, 0.025814},{1.216246, 1.282529, 0.023438}}],
    Polygon[{{1.212182, 1.287049, 0.025814},{1.213480, 1.291044, 0.027554},{
      1.216246, 1.290605, 0.027554},{1.216246, 1.286405, 0.025814}}],
    Polygon[{{1.213480, 1.291044, 0.027554},{1.214846, 1.295248, 0.028615},{
      1.216246, 1.295026, 0.028615},{1.216246, 1.290605, 0.027554}}],
    Polygon[{{1.216246, 1.295026, -0.028615},{1.216246, 1.290605, -0.027554},{
      1.219013, 1.291044, -0.027554},{1.217647, 1.295248, -0.028615}}],
    Polygon[{{1.216246, 1.290605, -0.027554},{1.216246, 1.286405, -0.025814},{
      1.220311, 1.287049, -0.025814},{1.219013, 1.291044, -0.027554}}],
    Polygon[{{1.216246, 1.286405, -0.025814},{1.216246, 1.282529, -0.023438},{
      1.221509, 1.283363, -0.023438},{1.220311, 1.287049, -0.025814}}],
    Polygon[{{1.216246, 1.282529, -0.023438},{1.216246, 1.279072, -0.020486},{
      1.222577, 1.280075, -0.020486},{1.221509, 1.283363, -0.023438}}],
    Polygon[{{1.216246, 1.279072, -0.020486},{1.216246, 1.276120, -0.017029},{
      1.223489, 1.277267, -0.017029},{1.222577, 1.280075, -0.020486}}],
    Polygon[{{1.216246, 1.276120, -0.017029},{1.216246, 1.273744, -0.013153},{
      1.224223, 1.275008, -0.013153},{1.223489, 1.277267, -0.017029}}],
    Polygon[{{1.216246, 1.273744, -0.013153},{1.216246, 1.272005, -0.008953},{
      1.224761, 1.273353, -0.008953},{1.224223, 1.275008, -0.013153}}],
    Polygon[{{1.216246, 1.272005, -0.008953},{1.216246, 1.270943, -0.004532},{
      1.225089, 1.272344, -0.004532},{1.224761, 1.273353, -0.008953}}],
    Polygon[{{1.216246, 1.270943, -0.004532},{1.216246, 1.270587, 0.000000},{
      1.225199, 1.272005, 0.000000},{1.225089, 1.272344, -0.004532}}],
    Polygon[{{1.216246, 1.270587, 0.000000},{1.216246, 1.270943, 0.004532},{
      1.225089, 1.272344, 0.004532},{1.225199, 1.272005, 0.000000}}],
    Polygon[{{1.216246, 1.270943, 0.004532},{1.216246, 1.272005, 0.008953},{
      1.224761, 1.273353, 0.008953},{1.225089, 1.272344, 0.004532}}],
    Polygon[{{1.216246, 1.272005, 0.008953},{1.216246, 1.273744, 0.013153},{
      1.224223, 1.275008, 0.013153},{1.224761, 1.273353, 0.008953}}],
    Polygon[{{1.216246, 1.273744, 0.013153},{1.216246, 1.276120, 0.017029},{
      1.223489, 1.277267, 0.017029},{1.224223, 1.275008, 0.013153}}],
    Polygon[{{1.216246, 1.276120, 0.017029},{1.216246, 1.279072, 0.020486},{
      1.222577, 1.280075, 0.020486},{1.223489, 1.277267, 0.017029}}],
    Polygon[{{1.216246, 1.279072, 0.020486},{1.216246, 1.282529, 0.023438},{
      1.221509, 1.283363, 0.023438},{1.222577, 1.280075, 0.020486}}],
    Polygon[{{1.216246, 1.282529, 0.023438},{1.216246, 1.286405, 0.025814},{
      1.220311, 1.287049, 0.025814},{1.221509, 1.283363, 0.023438}}],
    Polygon[{{1.216246, 1.286405, 0.025814},{1.216246, 1.290605, 0.027554},{
      1.219013, 1.291044, 0.027554},{1.220311, 1.287049, 0.025814}}],
    Polygon[{{1.216246, 1.290605, 0.027554},{1.216246, 1.295026, 0.028615},{
      1.217647, 1.295248, 0.028615},{1.219013, 1.291044, 0.027554}}],
    Polygon[{{1.217647, 1.295248, -0.028615},{1.219013, 1.291044, -0.027554},{
      1.221509, 1.292315, -0.027554},{1.218910, 1.295892, -0.028615}}],
    Polygon[{{1.219013, 1.291044, -0.027554},{1.220311, 1.287049, -0.025814},{
      1.223977, 1.288917, -0.025814},{1.221509, 1.292315, -0.027554}}],
    Polygon[{{1.220311, 1.287049, -0.025814},{1.221509, 1.283363, -0.023438},{
      1.226256, 1.285781, -0.023438},{1.223977, 1.288917, -0.025814}}],
    Polygon[{{1.221509, 1.283363, -0.023438},{1.222577, 1.280075, -0.020486},{
      1.228288, 1.282985, -0.020486},{1.226256, 1.285781, -0.023438}}],
    Polygon[{{1.222577, 1.280075, -0.020486},{1.223489, 1.277267, -0.017029},{
      1.230023, 1.280596, -0.017029},{1.228288, 1.282985, -0.020486}}],
    Polygon[{{1.223489, 1.277267, -0.017029},{1.224223, 1.275008, -0.013153},{
      1.231419, 1.278674, -0.013153},{1.230023, 1.280596, -0.017029}}],
    Polygon[{{1.224223, 1.275008, -0.013153},{1.224761, 1.273353, -0.008953},{
      1.232442, 1.277267, -0.008953},{1.231419, 1.278674, -0.013153}}],
    Polygon[{{1.224761, 1.273353, -0.008953},{1.225089, 1.272344, -0.004532},{
      1.233066, 1.276408, -0.004532},{1.232442, 1.277267, -0.008953}}],
    Polygon[{{1.225089, 1.272344, -0.004532},{1.225199, 1.272005, 0.000000},{
      1.233275, 1.276120, 0.000000},{1.233066, 1.276408, -0.004532}}],
    Polygon[{{1.225199, 1.272005, 0.000000},{1.225089, 1.272344, 0.004532},{
      1.233066, 1.276408, 0.004532},{1.233275, 1.276120, 0.000000}}],
    Polygon[{{1.225089, 1.272344, 0.004532},{1.224761, 1.273353, 0.008953},{
      1.232442, 1.277267, 0.008953},{1.233066, 1.276408, 0.004532}}],
    Polygon[{{1.224761, 1.273353, 0.008953},{1.224223, 1.275008, 0.013153},{
      1.231419, 1.278674, 0.013153},{1.232442, 1.277267, 0.008953}}],
    Polygon[{{1.224223, 1.275008, 0.013153},{1.223489, 1.277267, 0.017029},{
      1.230023, 1.280596, 0.017029},{1.231419, 1.278674, 0.013153}}],
    Polygon[{{1.223489, 1.277267, 0.017029},{1.222577, 1.280075, 0.020486},{
      1.228288, 1.282985, 0.020486},{1.230023, 1.280596, 0.017029}}],
    Polygon[{{1.222577, 1.280075, 0.020486},{1.221509, 1.283363, 0.023438},{
      1.226256, 1.285781, 0.023438},{1.228288, 1.282985, 0.020486}}],
    Polygon[{{1.221509, 1.283363, 0.023438},{1.220311, 1.287049, 0.025814},{
      1.223977, 1.288917, 0.025814},{1.226256, 1.285781, 0.023438}}],
    Polygon[{{1.220311, 1.287049, 0.025814},{1.219013, 1.291044, 0.027554},{
      1.221509, 1.292315, 0.027554},{1.223977, 1.288917, 0.025814}}],
    Polygon[{{1.219013, 1.291044, 0.027554},{1.217647, 1.295248, 0.028615},{
      1.218910, 1.295892, 0.028615},{1.221509, 1.292315, 0.027554}}],
    Polygon[{{1.218910, 1.295892, -0.028615},{1.221509, 1.292315, -0.027554},{
      1.223489, 1.294296, -0.027554},{1.219913, 1.296894, -0.028615}}],
    Polygon[{{1.221509, 1.292315, -0.027554},{1.223977, 1.288917, -0.025814},{
      1.226887, 1.291827, -0.025814},{1.223489, 1.294296, -0.027554}}],
    Polygon[{{1.223977, 1.288917, -0.025814},{1.226256, 1.285781, -0.023438},{
      1.230023, 1.289549, -0.023438},{1.226887, 1.291827, -0.025814}}],
    Polygon[{{1.226256, 1.285781, -0.023438},{1.228288, 1.282985, -0.020486},{
      1.232820, 1.287517, -0.020486},{1.230023, 1.289549, -0.023438}}],
    Polygon[{{1.228288, 1.282985, -0.020486},{1.230023, 1.280596, -0.017029},{
      1.235208, 1.285781, -0.017029},{1.232820, 1.287517, -0.020486}}],
    Polygon[{{1.230023, 1.280596, -0.017029},{1.231419, 1.278674, -0.013153},{
      1.237130, 1.284385, -0.013153},{1.235208, 1.285781, -0.017029}}],
    Polygon[{{1.231419, 1.278674, -0.013153},{1.232442, 1.277267, -0.008953},{
      1.238538, 1.283363, -0.008953},{1.237130, 1.284385, -0.013153}}],
    Polygon[{{1.232442, 1.277267, -0.008953},{1.233066, 1.276408, -0.004532},{
      1.239396, 1.282739, -0.004532},{1.238538, 1.283363, -0.008953}}],
    Polygon[{{1.233066, 1.276408, -0.004532},{1.233275, 1.276120, 0.000000},{
      1.239685, 1.282529, 0.000000},{1.239396, 1.282739, -0.004532}}],
    Polygon[{{1.233275, 1.276120, 0.000000},{1.233066, 1.276408, 0.004532},{
      1.239396, 1.282739, 0.004532},{1.239685, 1.282529, 0.000000}}],
    Polygon[{{1.233066, 1.276408, 0.004532},{1.232442, 1.277267, 0.008953},{
      1.238538, 1.283363, 0.008953},{1.239396, 1.282739, 0.004532}}],
    Polygon[{{1.232442, 1.277267, 0.008953},{1.231419, 1.278674, 0.013153},{
      1.237130, 1.284385, 0.013153},{1.238538, 1.283363, 0.008953}}],
    Polygon[{{1.231419, 1.278674, 0.013153},{1.230023, 1.280596, 0.017029},{
      1.235208, 1.285781, 0.017029},{1.237130, 1.284385, 0.013153}}],
    Polygon[{{1.230023, 1.280596, 0.017029},{1.228288, 1.282985, 0.020486},{
      1.232820, 1.287517, 0.020486},{1.235208, 1.285781, 0.017029}}],
    Polygon[{{1.228288, 1.282985, 0.020486},{1.226256, 1.285781, 0.023438},{
      1.230023, 1.289549, 0.023438},{1.232820, 1.287517, 0.020486}}],
    Polygon[{{1.226256, 1.285781, 0.023438},{1.223977, 1.288917, 0.025814},{
      1.226887, 1.291827, 0.025814},{1.230023, 1.289549, 0.023438}}],
    Polygon[{{1.223977, 1.288917, 0.025814},{1.221509, 1.292315, 0.027554},{
      1.223489, 1.294296, 0.027554},{1.226887, 1.291827, 0.025814}}],
    Polygon[{{1.221509, 1.292315, 0.027554},{1.218910, 1.295892, 0.028615},{
      1.219913, 1.296894, 0.028615},{1.223489, 1.294296, 0.027554}}],
    Polygon[{{1.219913, 1.296894, -0.028615},{1.223489, 1.294296, -0.027554},{
      1.224761, 1.296792, -0.027554},{1.220557, 1.298158, -0.028615}}],
    Polygon[{{1.223489, 1.294296, -0.027554},{1.226887, 1.291827, -0.025814},{
      1.228755, 1.295494, -0.025814},{1.224761, 1.296792, -0.027554}}],
    Polygon[{{1.226887, 1.291827, -0.025814},{1.230023, 1.289549, -0.023438},{
      1.232442, 1.294296, -0.023438},{1.228755, 1.295494, -0.025814}}],
    Polygon[{{1.230023, 1.289549, -0.023438},{1.232820, 1.287517, -0.020486},{
      1.235730, 1.293228, -0.020486},{1.232442, 1.294296, -0.023438}}],
    Polygon[{{1.232820, 1.287517, -0.020486},{1.235208, 1.285781, -0.017029},{
      1.238538, 1.292315, -0.017029},{1.235730, 1.293228, -0.020486}}],
    Polygon[{{1.235208, 1.285781, -0.017029},{1.237130, 1.284385, -0.013153},{
      1.240797, 1.291581, -0.013153},{1.238538, 1.292315, -0.017029}}],
    Polygon[{{1.237130, 1.284385, -0.013153},{1.238538, 1.283363, -0.008953},{
      1.242451, 1.291044, -0.008953},{1.240797, 1.291581, -0.013153}}],
    Polygon[{{1.238538, 1.283363, -0.008953},{1.239396, 1.282739, -0.004532},{
      1.243461, 1.290716, -0.004532},{1.242451, 1.291044, -0.008953}}],
    Polygon[{{1.239396, 1.282739, -0.004532},{1.239685, 1.282529, 0.000000},{
      1.243800, 1.290605, 0.000000},{1.243461, 1.290716, -0.004532}}],
    Polygon[{{1.239685, 1.282529, 0.000000},{1.239396, 1.282739, 0.004532},{
      1.243461, 1.290716, 0.004532},{1.243800, 1.290605, 0.000000}}],
    Polygon[{{1.239396, 1.282739, 0.004532},{1.238538, 1.283363, 0.008953},{
      1.242451, 1.291044, 0.008953},{1.243461, 1.290716, 0.004532}}],
    Polygon[{{1.238538, 1.283363, 0.008953},{1.237130, 1.284385, 0.013153},{
      1.240797, 1.291581, 0.013153},{1.242451, 1.291044, 0.008953}}],
    Polygon[{{1.237130, 1.284385, 0.013153},{1.235208, 1.285781, 0.017029},{
      1.238538, 1.292315, 0.017029},{1.240797, 1.291581, 0.013153}}],
    Polygon[{{1.235208, 1.285781, 0.017029},{1.232820, 1.287517, 0.020486},{
      1.235730, 1.293228, 0.020486},{1.238538, 1.292315, 0.017029}}],
    Polygon[{{1.232820, 1.287517, 0.020486},{1.230023, 1.289549, 0.023438},{
      1.232442, 1.294296, 0.023438},{1.235730, 1.293228, 0.020486}}],
    Polygon[{{1.230023, 1.289549, 0.023438},{1.226887, 1.291827, 0.025814},{
      1.228755, 1.295494, 0.025814},{1.232442, 1.294296, 0.023438}}],
    Polygon[{{1.226887, 1.291827, 0.025814},{1.223489, 1.294296, 0.027554},{
      1.224761, 1.296792, 0.027554},{1.228755, 1.295494, 0.025814}}],
    Polygon[{{1.223489, 1.294296, 0.027554},{1.219913, 1.296894, 0.028615},{
      1.220557, 1.298158, 0.028615},{1.224761, 1.296792, 0.027554}}],
    Polygon[{{1.220557, 1.298158, -0.028615},{1.224761, 1.296792, -0.027554},{
      1.225199, 1.299558, -0.027554},{1.220778, 1.299558, -0.028615}}],
    Polygon[{{1.224761, 1.296792, -0.027554},{1.228755, 1.295494, -0.025814},{
      1.229399, 1.299558, -0.025814},{1.225199, 1.299558, -0.027554}}],
    Polygon[{{1.228755, 1.295494, -0.025814},{1.232442, 1.294296, -0.023438},{
      1.233275, 1.299558, -0.023438},{1.229399, 1.299558, -0.025814}}],
    Polygon[{{1.232442, 1.294296, -0.023438},{1.235730, 1.293228, -0.020486},{
      1.236732, 1.299558, -0.020486},{1.233275, 1.299558, -0.023438}}],
    Polygon[{{1.235730, 1.293228, -0.020486},{1.238538, 1.292315, -0.017029},{
      1.239685, 1.299558, -0.017029},{1.236732, 1.299558, -0.020486}}],
    Polygon[{{1.238538, 1.292315, -0.017029},{1.240797, 1.291581, -0.013153},{
      1.242060, 1.299558, -0.013153},{1.239685, 1.299558, -0.017029}}],
    Polygon[{{1.240797, 1.291581, -0.013153},{1.242451, 1.291044, -0.008953},{
      1.243800, 1.299558, -0.008953},{1.242060, 1.299558, -0.013153}}],
    Polygon[{{1.242451, 1.291044, -0.008953},{1.243461, 1.290716, -0.004532},{
      1.244861, 1.299558, -0.004532},{1.243800, 1.299558, -0.008953}}],
    Polygon[{{1.243461, 1.290716, -0.004532},{1.243800, 1.290605, 0.000000},{
      1.245218, 1.299558, 0.000000},{1.244861, 1.299558, -0.004532}}],
    Polygon[{{1.243800, 1.290605, 0.000000},{1.243461, 1.290716, 0.004532},{
      1.244861, 1.299558, 0.004532},{1.245218, 1.299558, 0.000000}}],
    Polygon[{{1.243461, 1.290716, 0.004532},{1.242451, 1.291044, 0.008953},{
      1.243800, 1.299558, 0.008953},{1.244861, 1.299558, 0.004532}}],
    Polygon[{{1.242451, 1.291044, 0.008953},{1.240797, 1.291581, 0.013153},{
      1.242060, 1.299558, 0.013153},{1.243800, 1.299558, 0.008953}}],
    Polygon[{{1.240797, 1.291581, 0.013153},{1.238538, 1.292315, 0.017029},{
      1.239685, 1.299558, 0.017029},{1.242060, 1.299558, 0.013153}}],
    Polygon[{{1.238538, 1.292315, 0.017029},{1.235730, 1.293228, 0.020486},{
      1.236732, 1.299558, 0.020486},{1.239685, 1.299558, 0.017029}}],
    Polygon[{{1.235730, 1.293228, 0.020486},{1.232442, 1.294296, 0.023438},{
      1.233275, 1.299558, 0.023438},{1.236732, 1.299558, 0.020486}}],
    Polygon[{{1.232442, 1.294296, 0.023438},{1.228755, 1.295494, 0.025814},{
      1.229399, 1.299558, 0.025814},{1.233275, 1.299558, 0.023438}}],
    Polygon[{{1.228755, 1.295494, 0.025814},{1.224761, 1.296792, 0.027554},{
      1.225199, 1.299558, 0.027554},{1.229399, 1.299558, 0.025814}}],
    Polygon[{{1.224761, 1.296792, 0.027554},{1.220557, 1.298158, 0.028615},{
      1.220778, 1.299558, 0.028615},{1.225199, 1.299558, 0.027554}}],
    Polygon[{{1.209792, 1.342678, -0.014853},{1.212087, 1.342678, -0.014302},{
      1.211860, 1.344114, -0.014302},{1.209677, 1.343405, -0.014853}}],
    Polygon[{{1.212087, 1.342678, -0.014302},{1.214267, 1.342678, -0.013399},{
      1.213933, 1.344787, -0.013399},{1.211860, 1.344114, -0.014302}}],
    Polygon[{{1.214267, 1.342678, -0.013399},{1.216279, 1.342678, -0.012166},{
      1.215847, 1.345409, -0.012166},{1.213933, 1.344787, -0.013399}}],
    Polygon[{{1.216279, 1.342678, -0.012166},{1.218074, 1.342678, -0.010634},{
      1.217553, 1.345964, -0.010634},{1.215847, 1.345409, -0.012166}}],
    Polygon[{{1.218074, 1.342678, -0.010634},{1.219606, 1.342678, -0.008839},{
      1.219011, 1.346437, -0.008839},{1.217553, 1.345964, -0.010634}}],
    Polygon[{{1.219606, 1.342678, -0.008839},{1.220839, 1.342678, -0.006827},{
      1.220183, 1.346818, -0.006827},{1.219011, 1.346437, -0.008839}}],
    Polygon[{{1.220839, 1.342678, -0.006827},{1.221742, 1.342678, -0.004647},{
      1.221042, 1.347097, -0.004647},{1.220183, 1.346818, -0.006827}}],
    Polygon[{{1.221742, 1.342678, -0.004647},{1.222293, 1.342678, -0.002352},{
      1.221566, 1.347268, -0.002352},{1.221042, 1.347097, -0.004647}}],
    Polygon[{{1.222293, 1.342678, -0.002352},{1.222478, 1.342678, 0.000000},{
      1.221742, 1.347325, 0.000000},{1.221566, 1.347268, -0.002352}}],
    Polygon[{{1.222478, 1.342678, 0.000000},{1.222293, 1.342678, 0.002352},{
      1.221566, 1.347268, 0.002352},{1.221742, 1.347325, 0.000000}}],
    Polygon[{{1.222293, 1.342678, 0.002352},{1.221742, 1.342678, 0.004647},{
      1.221042, 1.347097, 0.004647},{1.221566, 1.347268, 0.002352}}],
    Polygon[{{1.221742, 1.342678, 0.004647},{1.220839, 1.342678, 0.006827},{
      1.220183, 1.346818, 0.006827},{1.221042, 1.347097, 0.004647}}],
    Polygon[{{1.220839, 1.342678, 0.006827},{1.219606, 1.342678, 0.008839},{
      1.219011, 1.346437, 0.008839},{1.220183, 1.346818, 0.006827}}],
    Polygon[{{1.219606, 1.342678, 0.008839},{1.218074, 1.342678, 0.010634},{
      1.217553, 1.345964, 0.010634},{1.219011, 1.346437, 0.008839}}],
    Polygon[{{1.218074, 1.342678, 0.010634},{1.216279, 1.342678, 0.012166},{
      1.215847, 1.345409, 0.012166},{1.217553, 1.345964, 0.010634}}],
    Polygon[{{1.216279, 1.342678, 0.012166},{1.214267, 1.342678, 0.013399},{
      1.213933, 1.344787, 0.013399},{1.215847, 1.345409, 0.012166}}],
    Polygon[{{1.214267, 1.342678, 0.013399},{1.212087, 1.342678, 0.014302},{
      1.211860, 1.344114, 0.014302},{1.213933, 1.344787, 0.013399}}],
    Polygon[{{1.212087, 1.342678, 0.014302},{1.209792, 1.342678, 0.014853},{
      1.209677, 1.343405, 0.014853},{1.211860, 1.344114, 0.014302}}],
    Polygon[{{1.209677, 1.343405, -0.014853},{1.211860, 1.344114, -0.014302},{
      1.211200, 1.345409, -0.014302},{1.209343, 1.344061, -0.014853}}],
    Polygon[{{1.211860, 1.344114, -0.014302},{1.213933, 1.344787, -0.013399},{
      1.212963, 1.346691, -0.013399},{1.211200, 1.345409, -0.014302}}],
    Polygon[{{1.213933, 1.344787, -0.013399},{1.215847, 1.345409, -0.012166},{
      1.214591, 1.347873, -0.012166},{1.212963, 1.346691, -0.013399}}],
    Polygon[{{1.215847, 1.345409, -0.012166},{1.217553, 1.345964, -0.010634},{
      1.216043, 1.348928, -0.010634},{1.214591, 1.347873, -0.012166}}],
    Polygon[{{1.217553, 1.345964, -0.010634},{1.219011, 1.346437, -0.008839},{
      1.217283, 1.349829, -0.008839},{1.216043, 1.348928, -0.010634}}],
    Polygon[{{1.219011, 1.346437, -0.008839},{1.220183, 1.346818, -0.006827},{
      1.218280, 1.350554, -0.006827},{1.217283, 1.349829, -0.008839}}],
    Polygon[{{1.220183, 1.346818, -0.006827},{1.221042, 1.347097, -0.004647},{
      1.219011, 1.351084, -0.004647},{1.218280, 1.350554, -0.006827}}],
    Polygon[{{1.221042, 1.347097, -0.004647},{1.221566, 1.347268, -0.002352},{
      1.219456, 1.351408, -0.002352},{1.219011, 1.351084, -0.004647}}],
    Polygon[{{1.221566, 1.347268, -0.002352},{1.221742, 1.347325, 0.000000},{
      1.219606, 1.351517, 0.000000},{1.219456, 1.351408, -0.002352}}],
    Polygon[{{1.221742, 1.347325, 0.000000},{1.221566, 1.347268, 0.002352},{
      1.219456, 1.351408, 0.002352},{1.219606, 1.351517, 0.000000}}],
    Polygon[{{1.221566, 1.347268, 0.002352},{1.221042, 1.347097, 0.004647},{
      1.219011, 1.351084, 0.004647},{1.219456, 1.351408, 0.002352}}],
    Polygon[{{1.221042, 1.347097, 0.004647},{1.220183, 1.346818, 0.006827},{
      1.218280, 1.350554, 0.006827},{1.219011, 1.351084, 0.004647}}],
    Polygon[{{1.220183, 1.346818, 0.006827},{1.219011, 1.346437, 0.008839},{
      1.217283, 1.349829, 0.008839},{1.218280, 1.350554, 0.006827}}],
    Polygon[{{1.219011, 1.346437, 0.008839},{1.217553, 1.345964, 0.010634},{
      1.216043, 1.348928, 0.010634},{1.217283, 1.349829, 0.008839}}],
    Polygon[{{1.217553, 1.345964, 0.010634},{1.215847, 1.345409, 0.012166},{
      1.214591, 1.347873, 0.012166},{1.216043, 1.348928, 0.010634}}],
    Polygon[{{1.215847, 1.345409, 0.012166},{1.213933, 1.344787, 0.013399},{
      1.212963, 1.346691, 0.013399},{1.214591, 1.347873, 0.012166}}],
    Polygon[{{1.213933, 1.344787, 0.013399},{1.211860, 1.344114, 0.014302},{
      1.211200, 1.345409, 0.014302},{1.212963, 1.346691, 0.013399}}],
    Polygon[{{1.211860, 1.344114, 0.014302},{1.209677, 1.343405, 0.014853},{
      1.209343, 1.344061, 0.014853},{1.211200, 1.345409, 0.014302}}],
    Polygon[{{1.209343, 1.344061, -0.014853},{1.211200, 1.345409, -0.014302},{
      1.210171, 1.346437, -0.014302},{1.208823, 1.344581, -0.014853}}],
    Polygon[{{1.211200, 1.345409, -0.014302},{1.212963, 1.346691, -0.013399},{
      1.211453, 1.348201, -0.013399},{1.210171, 1.346437, -0.014302}}],
    Polygon[{{1.212963, 1.346691, -0.013399},{1.214591, 1.347873, -0.012166},{
      1.212636, 1.349829, -0.012166},{1.211453, 1.348201, -0.013399}}],
    Polygon[{{1.214591, 1.347873, -0.012166},{1.216043, 1.348928, -0.010634},{
      1.213690, 1.351280, -0.010634},{1.212636, 1.349829, -0.012166}}],
    Polygon[{{1.216043, 1.348928, -0.010634},{1.217283, 1.349829, -0.008839},{
      1.214591, 1.352520, -0.008839},{1.213690, 1.351280, -0.010634}}],
    Polygon[{{1.217283, 1.349829, -0.008839},{1.218280, 1.350554, -0.006827},{
      1.215316, 1.353518, -0.006827},{1.214591, 1.352520, -0.008839}}],
    Polygon[{{1.218280, 1.350554, -0.006827},{1.219011, 1.351084, -0.004647},{
      1.215847, 1.354248, -0.004647},{1.215316, 1.353518, -0.006827}}],
    Polygon[{{1.219011, 1.351084, -0.004647},{1.219456, 1.351408, -0.002352},{
      1.216170, 1.354694, -0.002352},{1.215847, 1.354248, -0.004647}}],
    Polygon[{{1.219456, 1.351408, -0.002352},{1.219606, 1.351517, 0.000000},{
      1.216279, 1.354844, 0.000000},{1.216170, 1.354694, -0.002352}}],
    Polygon[{{1.219606, 1.351517, 0.000000},{1.219456, 1.351408, 0.002352},{
      1.216170, 1.354694, 0.002352},{1.216279, 1.354844, 0.000000}}],
    Polygon[{{1.219456, 1.351408, 0.002352},{1.219011, 1.351084, 0.004647},{
      1.215847, 1.354248, 0.004647},{1.216170, 1.354694, 0.002352}}],
    Polygon[{{1.219011, 1.351084, 0.004647},{1.218280, 1.350554, 0.006827},{
      1.215316, 1.353518, 0.006827},{1.215847, 1.354248, 0.004647}}],
    Polygon[{{1.218280, 1.350554, 0.006827},{1.217283, 1.349829, 0.008839},{
      1.214591, 1.352520, 0.008839},{1.215316, 1.353518, 0.006827}}],
    Polygon[{{1.217283, 1.349829, 0.008839},{1.216043, 1.348928, 0.010634},{
      1.213690, 1.351280, 0.010634},{1.214591, 1.352520, 0.008839}}],
    Polygon[{{1.216043, 1.348928, 0.010634},{1.214591, 1.347873, 0.012166},{
      1.212636, 1.349829, 0.012166},{1.213690, 1.351280, 0.010634}}],
    Polygon[{{1.214591, 1.347873, 0.012166},{1.212963, 1.346691, 0.013399},{
      1.211453, 1.348201, 0.013399},{1.212636, 1.349829, 0.012166}}],
    Polygon[{{1.212963, 1.346691, 0.013399},{1.211200, 1.345409, 0.014302},{
      1.210171, 1.346437, 0.014302},{1.211453, 1.348201, 0.013399}}],
    Polygon[{{1.211200, 1.345409, 0.014302},{1.209343, 1.344061, 0.014853},{
      1.208823, 1.344581, 0.014853},{1.210171, 1.346437, 0.014302}}],
    Polygon[{{1.208823, 1.344581, -0.014853},{1.210171, 1.346437, -0.014302},{
      1.208876, 1.347097, -0.014302},{1.208167, 1.344915, -0.014853}}],
    Polygon[{{1.210171, 1.346437, -0.014302},{1.211453, 1.348201, -0.013399},{
      1.209550, 1.349171, -0.013399},{1.208876, 1.347097, -0.014302}}],
    Polygon[{{1.211453, 1.348201, -0.013399},{1.212636, 1.349829, -0.012166},{
      1.210171, 1.351084, -0.012166},{1.209550, 1.349171, -0.013399}}],
    Polygon[{{1.212636, 1.349829, -0.012166},{1.213690, 1.351280, -0.010634},{
      1.210726, 1.352791, -0.010634},{1.210171, 1.351084, -0.012166}}],
    Polygon[{{1.213690, 1.351280, -0.010634},{1.214591, 1.352520, -0.008839},{
      1.211200, 1.354248, -0.008839},{1.210726, 1.352791, -0.010634}}],
    Polygon[{{1.214591, 1.352520, -0.008839},{1.215316, 1.353518, -0.006827},{
      1.211581, 1.355421, -0.006827},{1.211200, 1.354248, -0.008839}}],
    Polygon[{{1.215316, 1.353518, -0.006827},{1.215847, 1.354248, -0.004647},{
      1.211860, 1.356280, -0.004647},{1.211581, 1.355421, -0.006827}}],
    Polygon[{{1.215847, 1.354248, -0.004647},{1.216170, 1.354694, -0.002352},{
      1.212030, 1.356804, -0.002352},{1.211860, 1.356280, -0.004647}}],
    Polygon[{{1.216170, 1.354694, -0.002352},{1.216279, 1.354844, 0.000000},{
      1.212087, 1.356980, 0.000000},{1.212030, 1.356804, -0.002352}}],
    Polygon[{{1.216279, 1.354844, 0.000000},{1.216170, 1.354694, 0.002352},{
      1.212030, 1.356804, 0.002352},{1.212087, 1.356980, 0.000000}}],
    Polygon[{{1.216170, 1.354694, 0.002352},{1.215847, 1.354248, 0.004647},{
      1.211860, 1.356280, 0.004647},{1.212030, 1.356804, 0.002352}}],
    Polygon[{{1.215847, 1.354248, 0.004647},{1.215316, 1.353518, 0.006827},{
      1.211581, 1.355421, 0.006827},{1.211860, 1.356280, 0.004647}}],
    Polygon[{{1.215316, 1.353518, 0.006827},{1.214591, 1.352520, 0.008839},{
      1.211200, 1.354248, 0.008839},{1.211581, 1.355421, 0.006827}}],
    Polygon[{{1.214591, 1.352520, 0.008839},{1.213690, 1.351280, 0.010634},{
      1.210726, 1.352791, 0.010634},{1.211200, 1.354248, 0.008839}}],
    Polygon[{{1.213690, 1.351280, 0.010634},{1.212636, 1.349829, 0.012166},{
      1.210171, 1.351084, 0.012166},{1.210726, 1.352791, 0.010634}}],
    Polygon[{{1.212636, 1.349829, 0.012166},{1.211453, 1.348201, 0.013399},{
      1.209550, 1.349171, 0.013399},{1.210171, 1.351084, 0.012166}}],
    Polygon[{{1.211453, 1.348201, 0.013399},{1.210171, 1.346437, 0.014302},{
      1.208876, 1.347097, 0.014302},{1.209550, 1.349171, 0.013399}}],
    Polygon[{{1.210171, 1.346437, 0.014302},{1.208823, 1.344581, 0.014853},{
      1.208167, 1.344915, 0.014853},{1.208876, 1.347097, 0.014302}}],
    Polygon[{{1.208167, 1.344915, -0.014853},{1.208876, 1.347097, -0.014302},{
      1.207440, 1.347325, -0.014302},{1.207440, 1.345030, -0.014853}}],
    Polygon[{{1.208876, 1.347097, -0.014302},{1.209550, 1.349171, -0.013399},{
      1.207440, 1.349505, -0.013399},{1.207440, 1.347325, -0.014302}}],
    Polygon[{{1.209550, 1.349171, -0.013399},{1.210171, 1.351084, -0.012166},{
      1.207440, 1.351517, -0.012166},{1.207440, 1.349505, -0.013399}}],
    Polygon[{{1.210171, 1.351084, -0.012166},{1.210726, 1.352791, -0.010634},{
      1.207440, 1.353311, -0.010634},{1.207440, 1.351517, -0.012166}}],
    Polygon[{{1.210726, 1.352791, -0.010634},{1.211200, 1.354248, -0.008839},{
      1.207440, 1.354844, -0.008839},{1.207440, 1.353311, -0.010634}}],
    Polygon[{{1.211200, 1.354248, -0.008839},{1.211581, 1.355421, -0.006827},{
      1.207440, 1.356077, -0.006827},{1.207440, 1.354844, -0.008839}}],
    Polygon[{{1.211581, 1.355421, -0.006827},{1.211860, 1.356280, -0.004647},{
      1.207440, 1.356980, -0.004647},{1.207440, 1.356077, -0.006827}}],
    Polygon[{{1.211860, 1.356280, -0.004647},{1.212030, 1.356804, -0.002352},{
      1.207440, 1.357531, -0.002352},{1.207440, 1.356980, -0.004647}}],
    Polygon[{{1.212030, 1.356804, -0.002352},{1.212087, 1.356980, 0.000000},{
      1.207440, 1.357716, 0.000000},{1.207440, 1.357531, -0.002352}}],
    Polygon[{{1.212087, 1.356980, 0.000000},{1.212030, 1.356804, 0.002352},{
      1.207440, 1.357531, 0.002352},{1.207440, 1.357716, 0.000000}}],
    Polygon[{{1.212030, 1.356804, 0.002352},{1.211860, 1.356280, 0.004647},{
      1.207440, 1.356980, 0.004647},{1.207440, 1.357531, 0.002352}}],
    Polygon[{{1.211860, 1.356280, 0.004647},{1.211581, 1.355421, 0.006827},{
      1.207440, 1.356077, 0.006827},{1.207440, 1.356980, 0.004647}}],
    Polygon[{{1.211581, 1.355421, 0.006827},{1.211200, 1.354248, 0.008839},{
      1.207440, 1.354844, 0.008839},{1.207440, 1.356077, 0.006827}}],
    Polygon[{{1.211200, 1.354248, 0.008839},{1.210726, 1.352791, 0.010634},{
      1.207440, 1.353311, 0.010634},{1.207440, 1.354844, 0.008839}}],
    Polygon[{{1.210726, 1.352791, 0.010634},{1.210171, 1.351084, 0.012166},{
      1.207440, 1.351517, 0.012166},{1.207440, 1.353311, 0.010634}}],
    Polygon[{{1.210171, 1.351084, 0.012166},{1.209550, 1.349171, 0.013399},{
      1.207440, 1.349505, 0.013399},{1.207440, 1.351517, 0.012166}}],
    Polygon[{{1.209550, 1.349171, 0.013399},{1.208876, 1.347097, 0.014302},{
      1.207440, 1.347325, 0.014302},{1.207440, 1.349505, 0.013399}}],
    Polygon[{{1.208876, 1.347097, 0.014302},{1.208167, 1.344915, 0.014853},{
      1.207440, 1.345030, 0.014853},{1.207440, 1.347325, 0.014302}}],
    Polygon[{{1.207440, 1.345030, -0.014853},{1.207440, 1.347325, -0.014302},{
      1.206004, 1.347097, -0.014302},{1.206713, 1.344915, -0.014853}}],
    Polygon[{{1.207440, 1.347325, -0.014302},{1.207440, 1.349505, -0.013399},{
      1.205330, 1.349171, -0.013399},{1.206004, 1.347097, -0.014302}}],
    Polygon[{{1.207440, 1.349505, -0.013399},{1.207440, 1.351517, -0.012166},{
      1.204709, 1.351084, -0.012166},{1.205330, 1.349171, -0.013399}}],
    Polygon[{{1.207440, 1.351517, -0.012166},{1.207440, 1.353311, -0.010634},{
      1.204154, 1.352791, -0.010634},{1.204709, 1.351084, -0.012166}}],
    Polygon[{{1.207440, 1.353311, -0.010634},{1.207440, 1.354844, -0.008839},{
      1.203681, 1.354248, -0.008839},{1.204154, 1.352791, -0.010634}}],
    Polygon[{{1.207440, 1.354844, -0.008839},{1.207440, 1.356077, -0.006827},{
      1.203300, 1.355421, -0.006827},{1.203681, 1.354248, -0.008839}}],
    Polygon[{{1.207440, 1.356077, -0.006827},{1.207440, 1.356980, -0.004647},{
      1.203020, 1.356280, -0.004647},{1.203300, 1.355421, -0.006827}}],
    Polygon[{{1.207440, 1.356980, -0.004647},{1.207440, 1.357531, -0.002352},{
      1.202850, 1.356804, -0.002352},{1.203020, 1.356280, -0.004647}}],
    Polygon[{{1.207440, 1.357531, -0.002352},{1.207440, 1.357716, 0.000000},{
      1.202793, 1.356980, 0.000000},{1.202850, 1.356804, -0.002352}}],
    Polygon[{{1.207440, 1.357716, 0.000000},{1.207440, 1.357531, 0.002352},{
      1.202850, 1.356804, 0.002352},{1.202793, 1.356980, 0.000000}}],
    Polygon[{{1.207440, 1.357531, 0.002352},{1.207440, 1.356980, 0.004647},{
      1.203020, 1.356280, 0.004647},{1.202850, 1.356804, 0.002352}}],
    Polygon[{{1.207440, 1.356980, 0.004647},{1.207440, 1.356077, 0.006827},{
      1.203300, 1.355421, 0.006827},{1.203020, 1.356280, 0.004647}}],
    Polygon[{{1.207440, 1.356077, 0.006827},{1.207440, 1.354844, 0.008839},{
      1.203681, 1.354248, 0.008839},{1.203300, 1.355421, 0.006827}}],
    Polygon[{{1.207440, 1.354844, 0.008839},{1.207440, 1.353311, 0.010634},{
      1.204154, 1.352791, 0.010634},{1.203681, 1.354248, 0.008839}}],
    Polygon[{{1.207440, 1.353311, 0.010634},{1.207440, 1.351517, 0.012166},{
      1.204709, 1.351084, 0.012166},{1.204154, 1.352791, 0.010634}}],
    Polygon[{{1.207440, 1.351517, 0.012166},{1.207440, 1.349505, 0.013399},{
      1.205330, 1.349171, 0.013399},{1.204709, 1.351084, 0.012166}}],
    Polygon[{{1.207440, 1.349505, 0.013399},{1.207440, 1.347325, 0.014302},{
      1.206004, 1.347097, 0.014302},{1.205330, 1.349171, 0.013399}}],
    Polygon[{{1.207440, 1.347325, 0.014302},{1.207440, 1.345030, 0.014853},{
      1.206713, 1.344915, 0.014853},{1.206004, 1.347097, 0.014302}}],
    Polygon[{{1.206713, 1.344915, -0.014853},{1.206004, 1.347097, -0.014302},{
      1.204709, 1.346437, -0.014302},{1.206057, 1.344581, -0.014853}}],
    Polygon[{{1.206004, 1.347097, -0.014302},{1.205330, 1.349171, -0.013399},{
      1.203427, 1.348201, -0.013399},{1.204709, 1.346437, -0.014302}}],
    Polygon[{{1.205330, 1.349171, -0.013399},{1.204709, 1.351084, -0.012166},{
      1.202245, 1.349829, -0.012166},{1.203427, 1.348201, -0.013399}}],
    Polygon[{{1.204709, 1.351084, -0.012166},{1.204154, 1.352791, -0.010634},{
      1.201190, 1.351280, -0.010634},{1.202245, 1.349829, -0.012166}}],
    Polygon[{{1.204154, 1.352791, -0.010634},{1.203681, 1.354248, -0.008839},{
      1.200289, 1.352520, -0.008839},{1.201190, 1.351280, -0.010634}}],
    Polygon[{{1.203681, 1.354248, -0.008839},{1.203300, 1.355421, -0.006827},{
      1.199564, 1.353518, -0.006827},{1.200289, 1.352520, -0.008839}}],
    Polygon[{{1.203300, 1.355421, -0.006827},{1.203020, 1.356280, -0.004647},{
      1.199033, 1.354248, -0.004647},{1.199564, 1.353518, -0.006827}}],
    Polygon[{{1.203020, 1.356280, -0.004647},{1.202850, 1.356804, -0.002352},{
      1.198710, 1.354694, -0.002352},{1.199033, 1.354248, -0.004647}}],
    Polygon[{{1.202850, 1.356804, -0.002352},{1.202793, 1.356980, 0.000000},{
      1.198601, 1.354844, 0.000000},{1.198710, 1.354694, -0.002352}}],
    Polygon[{{1.202793, 1.356980, 0.000000},{1.202850, 1.356804, 0.002352},{
      1.198710, 1.354694, 0.002352},{1.198601, 1.354844, 0.000000}}],
    Polygon[{{1.202850, 1.356804, 0.002352},{1.203020, 1.356280, 0.004647},{
      1.199033, 1.354248, 0.004647},{1.198710, 1.354694, 0.002352}}],
    Polygon[{{1.203020, 1.356280, 0.004647},{1.203300, 1.355421, 0.006827},{
      1.199564, 1.353518, 0.006827},{1.199033, 1.354248, 0.004647}}],
    Polygon[{{1.203300, 1.355421, 0.006827},{1.203681, 1.354248, 0.008839},{
      1.200289, 1.352520, 0.008839},{1.199564, 1.353518, 0.006827}}],
    Polygon[{{1.203681, 1.354248, 0.008839},{1.204154, 1.352791, 0.010634},{
      1.201190, 1.351280, 0.010634},{1.200289, 1.352520, 0.008839}}],
    Polygon[{{1.204154, 1.352791, 0.010634},{1.204709, 1.351084, 0.012166},{
      1.202245, 1.349829, 0.012166},{1.201190, 1.351280, 0.010634}}],
    Polygon[{{1.204709, 1.351084, 0.012166},{1.205330, 1.349171, 0.013399},{
      1.203427, 1.348201, 0.013399},{1.202245, 1.349829, 0.012166}}],
    Polygon[{{1.205330, 1.349171, 0.013399},{1.206004, 1.347097, 0.014302},{
      1.204709, 1.346437, 0.014302},{1.203427, 1.348201, 0.013399}}],
    Polygon[{{1.206004, 1.347097, 0.014302},{1.206713, 1.344915, 0.014853},{
      1.206057, 1.344581, 0.014853},{1.204709, 1.346437, 0.014302}}],
    Polygon[{{1.206057, 1.344581, -0.014853},{1.204709, 1.346437, -0.014302},{
      1.203681, 1.345409, -0.014302},{1.205537, 1.344061, -0.014853}}],
    Polygon[{{1.204709, 1.346437, -0.014302},{1.203427, 1.348201, -0.013399},{
      1.201917, 1.346691, -0.013399},{1.203681, 1.345409, -0.014302}}],
    Polygon[{{1.203427, 1.348201, -0.013399},{1.202245, 1.349829, -0.012166},{
      1.200289, 1.347873, -0.012166},{1.201917, 1.346691, -0.013399}}],
    Polygon[{{1.202245, 1.349829, -0.012166},{1.201190, 1.351280, -0.010634},{
      1.198837, 1.348928, -0.010634},{1.200289, 1.347873, -0.012166}}],
    Polygon[{{1.201190, 1.351280, -0.010634},{1.200289, 1.352520, -0.008839},{
      1.197597, 1.349829, -0.008839},{1.198837, 1.348928, -0.010634}}],
    Polygon[{{1.200289, 1.352520, -0.008839},{1.199564, 1.353518, -0.006827},{
      1.196600, 1.350554, -0.006827},{1.197597, 1.349829, -0.008839}}],
    Polygon[{{1.199564, 1.353518, -0.006827},{1.199033, 1.354248, -0.004647},{
      1.195869, 1.351084, -0.004647},{1.196600, 1.350554, -0.006827}}],
    Polygon[{{1.199033, 1.354248, -0.004647},{1.198710, 1.354694, -0.002352},{
      1.195424, 1.351408, -0.002352},{1.195869, 1.351084, -0.004647}}],
    Polygon[{{1.198710, 1.354694, -0.002352},{1.198601, 1.354844, 0.000000},{
      1.195274, 1.351517, 0.000000},{1.195424, 1.351408, -0.002352}}],
    Polygon[{{1.198601, 1.354844, 0.000000},{1.198710, 1.354694, 0.002352},{
      1.195424, 1.351408, 0.002352},{1.195274, 1.351517, 0.000000}}],
    Polygon[{{1.198710, 1.354694, 0.002352},{1.199033, 1.354248, 0.004647},{
      1.195869, 1.351084, 0.004647},{1.195424, 1.351408, 0.002352}}],
    Polygon[{{1.199033, 1.354248, 0.004647},{1.199564, 1.353518, 0.006827},{
      1.196600, 1.350554, 0.006827},{1.195869, 1.351084, 0.004647}}],
    Polygon[{{1.199564, 1.353518, 0.006827},{1.200289, 1.352520, 0.008839},{
      1.197597, 1.349829, 0.008839},{1.196600, 1.350554, 0.006827}}],
    Polygon[{{1.200289, 1.352520, 0.008839},{1.201190, 1.351280, 0.010634},{
      1.198837, 1.348928, 0.010634},{1.197597, 1.349829, 0.008839}}],
    Polygon[{{1.201190, 1.351280, 0.010634},{1.202245, 1.349829, 0.012166},{
      1.200289, 1.347873, 0.012166},{1.198837, 1.348928, 0.010634}}],
    Polygon[{{1.202245, 1.349829, 0.012166},{1.203427, 1.348201, 0.013399},{
      1.201917, 1.346691, 0.013399},{1.200289, 1.347873, 0.012166}}],
    Polygon[{{1.203427, 1.348201, 0.013399},{1.204709, 1.346437, 0.014302},{
      1.203681, 1.345409, 0.014302},{1.201917, 1.346691, 0.013399}}],
    Polygon[{{1.204709, 1.346437, 0.014302},{1.206057, 1.344581, 0.014853},{
      1.205537, 1.344061, 0.014853},{1.203681, 1.345409, 0.014302}}],
    Polygon[{{1.205537, 1.344061, -0.014853},{1.203681, 1.345409, -0.014302},{
      1.203020, 1.344114, -0.014302},{1.205203, 1.343405, -0.014853}}],
    Polygon[{{1.203681, 1.345409, -0.014302},{1.201917, 1.346691, -0.013399},{
      1.200947, 1.344787, -0.013399},{1.203020, 1.344114, -0.014302}}],
    Polygon[{{1.201917, 1.346691, -0.013399},{1.200289, 1.347873, -0.012166},{
      1.199033, 1.345409, -0.012166},{1.200947, 1.344787, -0.013399}}],
    Polygon[{{1.200289, 1.347873, -0.012166},{1.198837, 1.348928, -0.010634},{
      1.197327, 1.345964, -0.010634},{1.199033, 1.345409, -0.012166}}],
    Polygon[{{1.198837, 1.348928, -0.010634},{1.197597, 1.349829, -0.008839},{
      1.195869, 1.346437, -0.008839},{1.197327, 1.345964, -0.010634}}],
    Polygon[{{1.197597, 1.349829, -0.008839},{1.196600, 1.350554, -0.006827},{
      1.194697, 1.346818, -0.006827},{1.195869, 1.346437, -0.008839}}],
    Polygon[{{1.196600, 1.350554, -0.006827},{1.195869, 1.351084, -0.004647},{
      1.193838, 1.347097, -0.004647},{1.194697, 1.346818, -0.006827}}],
    Polygon[{{1.195869, 1.351084, -0.004647},{1.195424, 1.351408, -0.002352},{
      1.193314, 1.347268, -0.002352},{1.193838, 1.347097, -0.004647}}],
    Polygon[{{1.195424, 1.351408, -0.002352},{1.195274, 1.351517, 0.000000},{
      1.193138, 1.347325, 0.000000},{1.193314, 1.347268, -0.002352}}],
    Polygon[{{1.195274, 1.351517, 0.000000},{1.195424, 1.351408, 0.002352},{
      1.193314, 1.347268, 0.002352},{1.193138, 1.347325, 0.000000}}],
    Polygon[{{1.195424, 1.351408, 0.002352},{1.195869, 1.351084, 0.004647},{
      1.193838, 1.347097, 0.004647},{1.193314, 1.347268, 0.002352}}],
    Polygon[{{1.195869, 1.351084, 0.004647},{1.196600, 1.350554, 0.006827},{
      1.194697, 1.346818, 0.006827},{1.193838, 1.347097, 0.004647}}],
    Polygon[{{1.196600, 1.350554, 0.006827},{1.197597, 1.349829, 0.008839},{
      1.195869, 1.346437, 0.008839},{1.194697, 1.346818, 0.006827}}],
    Polygon[{{1.197597, 1.349829, 0.008839},{1.198837, 1.348928, 0.010634},{
      1.197327, 1.345964, 0.010634},{1.195869, 1.346437, 0.008839}}],
    Polygon[{{1.198837, 1.348928, 0.010634},{1.200289, 1.347873, 0.012166},{
      1.199033, 1.345409, 0.012166},{1.197327, 1.345964, 0.010634}}],
    Polygon[{{1.200289, 1.347873, 0.012166},{1.201917, 1.346691, 0.013399},{
      1.200947, 1.344787, 0.013399},{1.199033, 1.345409, 0.012166}}],
    Polygon[{{1.201917, 1.346691, 0.013399},{1.203681, 1.345409, 0.014302},{
      1.203020, 1.344114, 0.014302},{1.200947, 1.344787, 0.013399}}],
    Polygon[{{1.203681, 1.345409, 0.014302},{1.205537, 1.344061, 0.014853},{
      1.205203, 1.343405, 0.014853},{1.203020, 1.344114, 0.014302}}],
    Polygon[{{1.205203, 1.343405, -0.014853},{1.203020, 1.344114, -0.014302},{
      1.202793, 1.342678, -0.014302},{1.205088, 1.342678, -0.014853}}],
    Polygon[{{1.203020, 1.344114, -0.014302},{1.200947, 1.344787, -0.013399},{
      1.200613, 1.342678, -0.013399},{1.202793, 1.342678, -0.014302}}],
    Polygon[{{1.200947, 1.344787, -0.013399},{1.199033, 1.345409, -0.012166},{
      1.198601, 1.342678, -0.012166},{1.200613, 1.342678, -0.013399}}],
    Polygon[{{1.199033, 1.345409, -0.012166},{1.197327, 1.345964, -0.010634},{
      1.196806, 1.342678, -0.010634},{1.198601, 1.342678, -0.012166}}],
    Polygon[{{1.197327, 1.345964, -0.010634},{1.195869, 1.346437, -0.008839},{
      1.195274, 1.342678, -0.008839},{1.196806, 1.342678, -0.010634}}],
    Polygon[{{1.195869, 1.346437, -0.008839},{1.194697, 1.346818, -0.006827},{
      1.194041, 1.342678, -0.006827},{1.195274, 1.342678, -0.008839}}],
    Polygon[{{1.194697, 1.346818, -0.006827},{1.193838, 1.347097, -0.004647},{
      1.193138, 1.342678, -0.004647},{1.194041, 1.342678, -0.006827}}],
    Polygon[{{1.193838, 1.347097, -0.004647},{1.193314, 1.347268, -0.002352},{
      1.192587, 1.342678, -0.002352},{1.193138, 1.342678, -0.004647}}],
    Polygon[{{1.193314, 1.347268, -0.002352},{1.193138, 1.347325, 0.000000},{
      1.192402, 1.342678, 0.000000},{1.192587, 1.342678, -0.002352}}],
    Polygon[{{1.193138, 1.347325, 0.000000},{1.193314, 1.347268, 0.002352},{
      1.192587, 1.342678, 0.002352},{1.192402, 1.342678, 0.000000}}],
    Polygon[{{1.193314, 1.347268, 0.002352},{1.193838, 1.347097, 0.004647},{
      1.193138, 1.342678, 0.004647},{1.192587, 1.342678, 0.002352}}],
    Polygon[{{1.193838, 1.347097, 0.004647},{1.194697, 1.346818, 0.006827},{
      1.194041, 1.342678, 0.006827},{1.193138, 1.342678, 0.004647}}],
    Polygon[{{1.194697, 1.346818, 0.006827},{1.195869, 1.346437, 0.008839},{
      1.195274, 1.342678, 0.008839},{1.194041, 1.342678, 0.006827}}],
    Polygon[{{1.195869, 1.346437, 0.008839},{1.197327, 1.345964, 0.010634},{
      1.196806, 1.342678, 0.010634},{1.195274, 1.342678, 0.008839}}],
    Polygon[{{1.197327, 1.345964, 0.010634},{1.199033, 1.345409, 0.012166},{
      1.198601, 1.342678, 0.012166},{1.196806, 1.342678, 0.010634}}],
    Polygon[{{1.199033, 1.345409, 0.012166},{1.200947, 1.344787, 0.013399},{
      1.200613, 1.342678, 0.013399},{1.198601, 1.342678, 0.012166}}],
    Polygon[{{1.200947, 1.344787, 0.013399},{1.203020, 1.344114, 0.014302},{
      1.202793, 1.342678, 0.014302},{1.200613, 1.342678, 0.013399}}],
    Polygon[{{1.203020, 1.344114, 0.014302},{1.205203, 1.343405, 0.014853},{
      1.205088, 1.342678, 0.014853},{1.202793, 1.342678, 0.014302}}],
    Polygon[{{1.205088, 1.342678, -0.014853},{1.202793, 1.342678, -0.014302},{
      1.203020, 1.341242, -0.014302},{1.205203, 1.341951, -0.014853}}],
    Polygon[{{1.202793, 1.342678, -0.014302},{1.200613, 1.342678, -0.013399},{
      1.200947, 1.340568, -0.013399},{1.203020, 1.341242, -0.014302}}],
    Polygon[{{1.200613, 1.342678, -0.013399},{1.198601, 1.342678, -0.012166},{
      1.199033, 1.339946, -0.012166},{1.200947, 1.340568, -0.013399}}],
    Polygon[{{1.198601, 1.342678, -0.012166},{1.196806, 1.342678, -0.010634},{
      1.197327, 1.339392, -0.010634},{1.199033, 1.339946, -0.012166}}],
    Polygon[{{1.196806, 1.342678, -0.010634},{1.195274, 1.342678, -0.008839},{
      1.195869, 1.338918, -0.008839},{1.197327, 1.339392, -0.010634}}],
    Polygon[{{1.195274, 1.342678, -0.008839},{1.194041, 1.342678, -0.006827},{
      1.194697, 1.338537, -0.006827},{1.195869, 1.338918, -0.008839}}],
    Polygon[{{1.194041, 1.342678, -0.006827},{1.193138, 1.342678, -0.004647},{
      1.193838, 1.338258, -0.004647},{1.194697, 1.338537, -0.006827}}],
    Polygon[{{1.193138, 1.342678, -0.004647},{1.192587, 1.342678, -0.002352},{
      1.193314, 1.338088, -0.002352},{1.193838, 1.338258, -0.004647}}],
    Polygon[{{1.192587, 1.342678, -0.002352},{1.192402, 1.342678, 0.000000},{
      1.193138, 1.338031, 0.000000},{1.193314, 1.338088, -0.002352}}],
    Polygon[{{1.192402, 1.342678, 0.000000},{1.192587, 1.342678, 0.002352},{
      1.193314, 1.338088, 0.002352},{1.193138, 1.338031, 0.000000}}],
    Polygon[{{1.192587, 1.342678, 0.002352},{1.193138, 1.342678, 0.004647},{
      1.193838, 1.338258, 0.004647},{1.193314, 1.338088, 0.002352}}],
    Polygon[{{1.193138, 1.342678, 0.004647},{1.194041, 1.342678, 0.006827},{
      1.194697, 1.338537, 0.006827},{1.193838, 1.338258, 0.004647}}],
    Polygon[{{1.194041, 1.342678, 0.006827},{1.195274, 1.342678, 0.008839},{
      1.195869, 1.338918, 0.008839},{1.194697, 1.338537, 0.006827}}],
    Polygon[{{1.195274, 1.342678, 0.008839},{1.196806, 1.342678, 0.010634},{
      1.197327, 1.339392, 0.010634},{1.195869, 1.338918, 0.008839}}],
    Polygon[{{1.196806, 1.342678, 0.010634},{1.198601, 1.342678, 0.012166},{
      1.199033, 1.339946, 0.012166},{1.197327, 1.339392, 0.010634}}],
    Polygon[{{1.198601, 1.342678, 0.012166},{1.200613, 1.342678, 0.013399},{
      1.200947, 1.340568, 0.013399},{1.199033, 1.339946, 0.012166}}],
    Polygon[{{1.200613, 1.342678, 0.013399},{1.202793, 1.342678, 0.014302},{
      1.203020, 1.341242, 0.014302},{1.200947, 1.340568, 0.013399}}],
    Polygon[{{1.202793, 1.342678, 0.014302},{1.205088, 1.342678, 0.014853},{
      1.205203, 1.341951, 0.014853},{1.203020, 1.341242, 0.014302}}],
    Polygon[{{1.205203, 1.341951, -0.014853},{1.203020, 1.341242, -0.014302},{
      1.203681, 1.339946, -0.014302},{1.205537, 1.341295, -0.014853}}],
    Polygon[{{1.203020, 1.341242, -0.014302},{1.200947, 1.340568, -0.013399},{
      1.201917, 1.338665, -0.013399},{1.203681, 1.339946, -0.014302}}],
    Polygon[{{1.200947, 1.340568, -0.013399},{1.199033, 1.339946, -0.012166},{
      1.200289, 1.337482, -0.012166},{1.201917, 1.338665, -0.013399}}],
    Polygon[{{1.199033, 1.339946, -0.012166},{1.197327, 1.339392, -0.010634},{
      1.198837, 1.336427, -0.010634},{1.200289, 1.337482, -0.012166}}],
    Polygon[{{1.197327, 1.339392, -0.010634},{1.195869, 1.338918, -0.008839},{
      1.197597, 1.335527, -0.008839},{1.198837, 1.336427, -0.010634}}],
    Polygon[{{1.195869, 1.338918, -0.008839},{1.194697, 1.338537, -0.006827},{
      1.196600, 1.334802, -0.006827},{1.197597, 1.335527, -0.008839}}],
    Polygon[{{1.194697, 1.338537, -0.006827},{1.193838, 1.338258, -0.004647},{
      1.195869, 1.334271, -0.004647},{1.196600, 1.334802, -0.006827}}],
    Polygon[{{1.193838, 1.338258, -0.004647},{1.193314, 1.338088, -0.002352},{
      1.195424, 1.333947, -0.002352},{1.195869, 1.334271, -0.004647}}],
    Polygon[{{1.193314, 1.338088, -0.002352},{1.193138, 1.338031, 0.000000},{
      1.195274, 1.333839, 0.000000},{1.195424, 1.333947, -0.002352}}],
    Polygon[{{1.193138, 1.338031, 0.000000},{1.193314, 1.338088, 0.002352},{
      1.195424, 1.333947, 0.002352},{1.195274, 1.333839, 0.000000}}],
    Polygon[{{1.193314, 1.338088, 0.002352},{1.193838, 1.338258, 0.004647},{
      1.195869, 1.334271, 0.004647},{1.195424, 1.333947, 0.002352}}],
    Polygon[{{1.193838, 1.338258, 0.004647},{1.194697, 1.338537, 0.006827},{
      1.196600, 1.334802, 0.006827},{1.195869, 1.334271, 0.004647}}],
    Polygon[{{1.194697, 1.338537, 0.006827},{1.195869, 1.338918, 0.008839},{
      1.197597, 1.335527, 0.008839},{1.196600, 1.334802, 0.006827}}],
    Polygon[{{1.195869, 1.338918, 0.008839},{1.197327, 1.339392, 0.010634},{
      1.198837, 1.336427, 0.010634},{1.197597, 1.335527, 0.008839}}],
    Polygon[{{1.197327, 1.339392, 0.010634},{1.199033, 1.339946, 0.012166},{
      1.200289, 1.337482, 0.012166},{1.198837, 1.336427, 0.010634}}],
    Polygon[{{1.199033, 1.339946, 0.012166},{1.200947, 1.340568, 0.013399},{
      1.201917, 1.338665, 0.013399},{1.200289, 1.337482, 0.012166}}],
    Polygon[{{1.200947, 1.340568, 0.013399},{1.203020, 1.341242, 0.014302},{
      1.203681, 1.339946, 0.014302},{1.201917, 1.338665, 0.013399}}],
    Polygon[{{1.203020, 1.341242, 0.014302},{1.205203, 1.341951, 0.014853},{
      1.205537, 1.341295, 0.014853},{1.203681, 1.339946, 0.014302}}],
    Polygon[{{1.205537, 1.341295, -0.014853},{1.203681, 1.339946, -0.014302},{
      1.204709, 1.338918, -0.014302},{1.206057, 1.340775, -0.014853}}],
    Polygon[{{1.203681, 1.339946, -0.014302},{1.201917, 1.338665, -0.013399},{
      1.203427, 1.337154, -0.013399},{1.204709, 1.338918, -0.014302}}],
    Polygon[{{1.201917, 1.338665, -0.013399},{1.200289, 1.337482, -0.012166},{
      1.202245, 1.335527, -0.012166},{1.203427, 1.337154, -0.013399}}],
    Polygon[{{1.200289, 1.337482, -0.012166},{1.198837, 1.336427, -0.010634},{
      1.201190, 1.334075, -0.010634},{1.202245, 1.335527, -0.012166}}],
    Polygon[{{1.198837, 1.336427, -0.010634},{1.197597, 1.335527, -0.008839},{
      1.200289, 1.332835, -0.008839},{1.201190, 1.334075, -0.010634}}],
    Polygon[{{1.197597, 1.335527, -0.008839},{1.196600, 1.334802, -0.006827},{
      1.199564, 1.331838, -0.006827},{1.200289, 1.332835, -0.008839}}],
    Polygon[{{1.196600, 1.334802, -0.006827},{1.195869, 1.334271, -0.004647},{
      1.199033, 1.331107, -0.004647},{1.199564, 1.331838, -0.006827}}],
    Polygon[{{1.195869, 1.334271, -0.004647},{1.195424, 1.333947, -0.002352},{
      1.198710, 1.330661, -0.002352},{1.199033, 1.331107, -0.004647}}],
    Polygon[{{1.195424, 1.333947, -0.002352},{1.195274, 1.333839, 0.000000},{
      1.198601, 1.330512, 0.000000},{1.198710, 1.330661, -0.002352}}],
    Polygon[{{1.195274, 1.333839, 0.000000},{1.195424, 1.333947, 0.002352},{
      1.198710, 1.330661, 0.002352},{1.198601, 1.330512, 0.000000}}],
    Polygon[{{1.195424, 1.333947, 0.002352},{1.195869, 1.334271, 0.004647},{
      1.199033, 1.331107, 0.004647},{1.198710, 1.330661, 0.002352}}],
    Polygon[{{1.195869, 1.334271, 0.004647},{1.196600, 1.334802, 0.006827},{
      1.199564, 1.331838, 0.006827},{1.199033, 1.331107, 0.004647}}],
    Polygon[{{1.196600, 1.334802, 0.006827},{1.197597, 1.335527, 0.008839},{
      1.200289, 1.332835, 0.008839},{1.199564, 1.331838, 0.006827}}],
    Polygon[{{1.197597, 1.335527, 0.008839},{1.198837, 1.336427, 0.010634},{
      1.201190, 1.334075, 0.010634},{1.200289, 1.332835, 0.008839}}],
    Polygon[{{1.198837, 1.336427, 0.010634},{1.200289, 1.337482, 0.012166},{
      1.202245, 1.335527, 0.012166},{1.201190, 1.334075, 0.010634}}],
    Polygon[{{1.200289, 1.337482, 0.012166},{1.201917, 1.338665, 0.013399},{
      1.203427, 1.337154, 0.013399},{1.202245, 1.335527, 0.012166}}],
    Polygon[{{1.201917, 1.338665, 0.013399},{1.203681, 1.339946, 0.014302},{
      1.204709, 1.338918, 0.014302},{1.203427, 1.337154, 0.013399}}],
    Polygon[{{1.203681, 1.339946, 0.014302},{1.205537, 1.341295, 0.014853},{
      1.206057, 1.340775, 0.014853},{1.204709, 1.338918, 0.014302}}],
    Polygon[{{1.206057, 1.340775, -0.014853},{1.204709, 1.338918, -0.014302},{
      1.206004, 1.338258, -0.014302},{1.206713, 1.340440, -0.014853}}],
    Polygon[{{1.204709, 1.338918, -0.014302},{1.203427, 1.337154, -0.013399},{
      1.205330, 1.336185, -0.013399},{1.206004, 1.338258, -0.014302}}],
    Polygon[{{1.203427, 1.337154, -0.013399},{1.202245, 1.335527, -0.012166},{
      1.204709, 1.334271, -0.012166},{1.205330, 1.336185, -0.013399}}],
    Polygon[{{1.202245, 1.335527, -0.012166},{1.201190, 1.334075, -0.010634},{
      1.204154, 1.332565, -0.010634},{1.204709, 1.334271, -0.012166}}],
    Polygon[{{1.201190, 1.334075, -0.010634},{1.200289, 1.332835, -0.008839},{
      1.203681, 1.331107, -0.008839},{1.204154, 1.332565, -0.010634}}],
    Polygon[{{1.200289, 1.332835, -0.008839},{1.199564, 1.331838, -0.006827},{
      1.203300, 1.329934, -0.006827},{1.203681, 1.331107, -0.008839}}],
    Polygon[{{1.199564, 1.331838, -0.006827},{1.199033, 1.331107, -0.004647},{
      1.203020, 1.329076, -0.004647},{1.203300, 1.329934, -0.006827}}],
    Polygon[{{1.199033, 1.331107, -0.004647},{1.198710, 1.330661, -0.002352},{
      1.202850, 1.328552, -0.002352},{1.203020, 1.329076, -0.004647}}],
    Polygon[{{1.198710, 1.330661, -0.002352},{1.198601, 1.330512, 0.000000},{
      1.202793, 1.328376, 0.000000},{1.202850, 1.328552, -0.002352}}],
    Polygon[{{1.198601, 1.330512, 0.000000},{1.198710, 1.330661, 0.002352},{
      1.202850, 1.328552, 0.002352},{1.202793, 1.328376, 0.000000}}],
    Polygon[{{1.198710, 1.330661, 0.002352},{1.199033, 1.331107, 0.004647},{
      1.203020, 1.329076, 0.004647},{1.202850, 1.328552, 0.002352}}],
    Polygon[{{1.199033, 1.331107, 0.004647},{1.199564, 1.331838, 0.006827},{
      1.203300, 1.329934, 0.006827},{1.203020, 1.329076, 0.004647}}],
    Polygon[{{1.199564, 1.331838, 0.006827},{1.200289, 1.332835, 0.008839},{
      1.203681, 1.331107, 0.008839},{1.203300, 1.329934, 0.006827}}],
    Polygon[{{1.200289, 1.332835, 0.008839},{1.201190, 1.334075, 0.010634},{
      1.204154, 1.332565, 0.010634},{1.203681, 1.331107, 0.008839}}],
    Polygon[{{1.201190, 1.334075, 0.010634},{1.202245, 1.335527, 0.012166},{
      1.204709, 1.334271, 0.012166},{1.204154, 1.332565, 0.010634}}],
    Polygon[{{1.202245, 1.335527, 0.012166},{1.203427, 1.337154, 0.013399},{
      1.205330, 1.336185, 0.013399},{1.204709, 1.334271, 0.012166}}],
    Polygon[{{1.203427, 1.337154, 0.013399},{1.204709, 1.338918, 0.014302},{
      1.206004, 1.338258, 0.014302},{1.205330, 1.336185, 0.013399}}],
    Polygon[{{1.204709, 1.338918, 0.014302},{1.206057, 1.340775, 0.014853},{
      1.206713, 1.340440, 0.014853},{1.206004, 1.338258, 0.014302}}],
    Polygon[{{1.206713, 1.340440, -0.014853},{1.206004, 1.338258, -0.014302},{
      1.207440, 1.338031, -0.014302},{1.207440, 1.340325, -0.014853}}],
    Polygon[{{1.206004, 1.338258, -0.014302},{1.205330, 1.336185, -0.013399},{
      1.207440, 1.335851, -0.013399},{1.207440, 1.338031, -0.014302}}],
    Polygon[{{1.205330, 1.336185, -0.013399},{1.204709, 1.334271, -0.012166},{
      1.207440, 1.333839, -0.012166},{1.207440, 1.335851, -0.013399}}],
    Polygon[{{1.204709, 1.334271, -0.012166},{1.204154, 1.332565, -0.010634},{
      1.207440, 1.332044, -0.010634},{1.207440, 1.333839, -0.012166}}],
    Polygon[{{1.204154, 1.332565, -0.010634},{1.203681, 1.331107, -0.008839},{
      1.207440, 1.330512, -0.008839},{1.207440, 1.332044, -0.010634}}],
    Polygon[{{1.203681, 1.331107, -0.008839},{1.203300, 1.329934, -0.006827},{
      1.207440, 1.329279, -0.006827},{1.207440, 1.330512, -0.008839}}],
    Polygon[{{1.203300, 1.329934, -0.006827},{1.203020, 1.329076, -0.004647},{
      1.207440, 1.328376, -0.004647},{1.207440, 1.329279, -0.006827}}],
    Polygon[{{1.203020, 1.329076, -0.004647},{1.202850, 1.328552, -0.002352},{
      1.207440, 1.327825, -0.002352},{1.207440, 1.328376, -0.004647}}],
    Polygon[{{1.202850, 1.328552, -0.002352},{1.202793, 1.328376, 0.000000},{
      1.207440, 1.327640, 0.000000},{1.207440, 1.327825, -0.002352}}],
    Polygon[{{1.202793, 1.328376, 0.000000},{1.202850, 1.328552, 0.002352},{
      1.207440, 1.327825, 0.002352},{1.207440, 1.327640, 0.000000}}],
    Polygon[{{1.202850, 1.328552, 0.002352},{1.203020, 1.329076, 0.004647},{
      1.207440, 1.328376, 0.004647},{1.207440, 1.327825, 0.002352}}],
    Polygon[{{1.203020, 1.329076, 0.004647},{1.203300, 1.329934, 0.006827},{
      1.207440, 1.329279, 0.006827},{1.207440, 1.328376, 0.004647}}],
    Polygon[{{1.203300, 1.329934, 0.006827},{1.203681, 1.331107, 0.008839},{
      1.207440, 1.330512, 0.008839},{1.207440, 1.329279, 0.006827}}],
    Polygon[{{1.203681, 1.331107, 0.008839},{1.204154, 1.332565, 0.010634},{
      1.207440, 1.332044, 0.010634},{1.207440, 1.330512, 0.008839}}],
    Polygon[{{1.204154, 1.332565, 0.010634},{1.204709, 1.334271, 0.012166},{
      1.207440, 1.333839, 0.012166},{1.207440, 1.332044, 0.010634}}],
    Polygon[{{1.204709, 1.334271, 0.012166},{1.205330, 1.336185, 0.013399},{
      1.207440, 1.335851, 0.013399},{1.207440, 1.333839, 0.012166}}],
    Polygon[{{1.205330, 1.336185, 0.013399},{1.206004, 1.338258, 0.014302},{
      1.207440, 1.338031, 0.014302},{1.207440, 1.335851, 0.013399}}],
    Polygon[{{1.206004, 1.338258, 0.014302},{1.206713, 1.340440, 0.014853},{
      1.207440, 1.340325, 0.014853},{1.207440, 1.338031, 0.014302}}],
    Polygon[{{1.207440, 1.340325, -0.014853},{1.207440, 1.338031, -0.014302},{
      1.208876, 1.338258, -0.014302},{1.208167, 1.340440, -0.014853}}],
    Polygon[{{1.207440, 1.338031, -0.014302},{1.207440, 1.335851, -0.013399},{
      1.209550, 1.336185, -0.013399},{1.208876, 1.338258, -0.014302}}],
    Polygon[{{1.207440, 1.335851, -0.013399},{1.207440, 1.333839, -0.012166},{
      1.210171, 1.334271, -0.012166},{1.209550, 1.336185, -0.013399}}],
    Polygon[{{1.207440, 1.333839, -0.012166},{1.207440, 1.332044, -0.010634},{
      1.210726, 1.332565, -0.010634},{1.210171, 1.334271, -0.012166}}],
    Polygon[{{1.207440, 1.332044, -0.010634},{1.207440, 1.330512, -0.008839},{
      1.211200, 1.331107, -0.008839},{1.210726, 1.332565, -0.010634}}],
    Polygon[{{1.207440, 1.330512, -0.008839},{1.207440, 1.329279, -0.006827},{
      1.211581, 1.329934, -0.006827},{1.211200, 1.331107, -0.008839}}],
    Polygon[{{1.207440, 1.329279, -0.006827},{1.207440, 1.328376, -0.004647},{
      1.211860, 1.329076, -0.004647},{1.211581, 1.329934, -0.006827}}],
    Polygon[{{1.207440, 1.328376, -0.004647},{1.207440, 1.327825, -0.002352},{
      1.212030, 1.328552, -0.002352},{1.211860, 1.329076, -0.004647}}],
    Polygon[{{1.207440, 1.327825, -0.002352},{1.207440, 1.327640, 0.000000},{
      1.212087, 1.328376, 0.000000},{1.212030, 1.328552, -0.002352}}],
    Polygon[{{1.207440, 1.327640, 0.000000},{1.207440, 1.327825, 0.002352},{
      1.212030, 1.328552, 0.002352},{1.212087, 1.328376, 0.000000}}],
    Polygon[{{1.207440, 1.327825, 0.002352},{1.207440, 1.328376, 0.004647},{
      1.211860, 1.329076, 0.004647},{1.212030, 1.328552, 0.002352}}],
    Polygon[{{1.207440, 1.328376, 0.004647},{1.207440, 1.329279, 0.006827},{
      1.211581, 1.329934, 0.006827},{1.211860, 1.329076, 0.004647}}],
    Polygon[{{1.207440, 1.329279, 0.006827},{1.207440, 1.330512, 0.008839},{
      1.211200, 1.331107, 0.008839},{1.211581, 1.329934, 0.006827}}],
    Polygon[{{1.207440, 1.330512, 0.008839},{1.207440, 1.332044, 0.010634},{
      1.210726, 1.332565, 0.010634},{1.211200, 1.331107, 0.008839}}],
    Polygon[{{1.207440, 1.332044, 0.010634},{1.207440, 1.333839, 0.012166},{
      1.210171, 1.334271, 0.012166},{1.210726, 1.332565, 0.010634}}],
    Polygon[{{1.207440, 1.333839, 0.012166},{1.207440, 1.335851, 0.013399},{
      1.209550, 1.336185, 0.013399},{1.210171, 1.334271, 0.012166}}],
    Polygon[{{1.207440, 1.335851, 0.013399},{1.207440, 1.338031, 0.014302},{
      1.208876, 1.338258, 0.014302},{1.209550, 1.336185, 0.013399}}],
    Polygon[{{1.207440, 1.338031, 0.014302},{1.207440, 1.340325, 0.014853},{
      1.208167, 1.340440, 0.014853},{1.208876, 1.338258, 0.014302}}],
    Polygon[{{1.208167, 1.340440, -0.014853},{1.208876, 1.338258, -0.014302},{
      1.210171, 1.338918, -0.014302},{1.208823, 1.340775, -0.014853}}],
    Polygon[{{1.208876, 1.338258, -0.014302},{1.209550, 1.336185, -0.013399},{
      1.211453, 1.337154, -0.013399},{1.210171, 1.338918, -0.014302}}],
    Polygon[{{1.209550, 1.336185, -0.013399},{1.210171, 1.334271, -0.012166},{
      1.212636, 1.335527, -0.012166},{1.211453, 1.337154, -0.013399}}],
    Polygon[{{1.210171, 1.334271, -0.012166},{1.210726, 1.332565, -0.010634},{
      1.213690, 1.334075, -0.010634},{1.212636, 1.335527, -0.012166}}],
    Polygon[{{1.210726, 1.332565, -0.010634},{1.211200, 1.331107, -0.008839},{
      1.214591, 1.332835, -0.008839},{1.213690, 1.334075, -0.010634}}],
    Polygon[{{1.211200, 1.331107, -0.008839},{1.211581, 1.329934, -0.006827},{
      1.215316, 1.331838, -0.006827},{1.214591, 1.332835, -0.008839}}],
    Polygon[{{1.211581, 1.329934, -0.006827},{1.211860, 1.329076, -0.004647},{
      1.215847, 1.331107, -0.004647},{1.215316, 1.331838, -0.006827}}],
    Polygon[{{1.211860, 1.329076, -0.004647},{1.212030, 1.328552, -0.002352},{
      1.216170, 1.330661, -0.002352},{1.215847, 1.331107, -0.004647}}],
    Polygon[{{1.212030, 1.328552, -0.002352},{1.212087, 1.328376, 0.000000},{
      1.216279, 1.330512, 0.000000},{1.216170, 1.330661, -0.002352}}],
    Polygon[{{1.212087, 1.328376, 0.000000},{1.212030, 1.328552, 0.002352},{
      1.216170, 1.330661, 0.002352},{1.216279, 1.330512, 0.000000}}],
    Polygon[{{1.212030, 1.328552, 0.002352},{1.211860, 1.329076, 0.004647},{
      1.215847, 1.331107, 0.004647},{1.216170, 1.330661, 0.002352}}],
    Polygon[{{1.211860, 1.329076, 0.004647},{1.211581, 1.329934, 0.006827},{
      1.215316, 1.331838, 0.006827},{1.215847, 1.331107, 0.004647}}],
    Polygon[{{1.211581, 1.329934, 0.006827},{1.211200, 1.331107, 0.008839},{
      1.214591, 1.332835, 0.008839},{1.215316, 1.331838, 0.006827}}],
    Polygon[{{1.211200, 1.331107, 0.008839},{1.210726, 1.332565, 0.010634},{
      1.213690, 1.334075, 0.010634},{1.214591, 1.332835, 0.008839}}],
    Polygon[{{1.210726, 1.332565, 0.010634},{1.210171, 1.334271, 0.012166},{
      1.212636, 1.335527, 0.012166},{1.213690, 1.334075, 0.010634}}],
    Polygon[{{1.210171, 1.334271, 0.012166},{1.209550, 1.336185, 0.013399},{
      1.211453, 1.337154, 0.013399},{1.212636, 1.335527, 0.012166}}],
    Polygon[{{1.209550, 1.336185, 0.013399},{1.208876, 1.338258, 0.014302},{
      1.210171, 1.338918, 0.014302},{1.211453, 1.337154, 0.013399}}],
    Polygon[{{1.208876, 1.338258, 0.014302},{1.208167, 1.340440, 0.014853},{
      1.208823, 1.340775, 0.014853},{1.210171, 1.338918, 0.014302}}],
    Polygon[{{1.208823, 1.340775, -0.014853},{1.210171, 1.338918, -0.014302},{
      1.211200, 1.339946, -0.014302},{1.209343, 1.341295, -0.014853}}],
    Polygon[{{1.210171, 1.338918, -0.014302},{1.211453, 1.337154, -0.013399},{
      1.212963, 1.338665, -0.013399},{1.211200, 1.339946, -0.014302}}],
    Polygon[{{1.211453, 1.337154, -0.013399},{1.212636, 1.335527, -0.012166},{
      1.214591, 1.337482, -0.012166},{1.212963, 1.338665, -0.013399}}],
    Polygon[{{1.212636, 1.335527, -0.012166},{1.213690, 1.334075, -0.010634},{
      1.216043, 1.336427, -0.010634},{1.214591, 1.337482, -0.012166}}],
    Polygon[{{1.213690, 1.334075, -0.010634},{1.214591, 1.332835, -0.008839},{
      1.217283, 1.335527, -0.008839},{1.216043, 1.336427, -0.010634}}],
    Polygon[{{1.214591, 1.332835, -0.008839},{1.215316, 1.331838, -0.006827},{
      1.218280, 1.334802, -0.006827},{1.217283, 1.335527, -0.008839}}],
    Polygon[{{1.215316, 1.331838, -0.006827},{1.215847, 1.331107, -0.004647},{
      1.219011, 1.334271, -0.004647},{1.218280, 1.334802, -0.006827}}],
    Polygon[{{1.215847, 1.331107, -0.004647},{1.216170, 1.330661, -0.002352},{
      1.219456, 1.333947, -0.002352},{1.219011, 1.334271, -0.004647}}],
    Polygon[{{1.216170, 1.330661, -0.002352},{1.216279, 1.330512, 0.000000},{
      1.219606, 1.333839, 0.000000},{1.219456, 1.333947, -0.002352}}],
    Polygon[{{1.216279, 1.330512, 0.000000},{1.216170, 1.330661, 0.002352},{
      1.219456, 1.333947, 0.002352},{1.219606, 1.333839, 0.000000}}],
    Polygon[{{1.216170, 1.330661, 0.002352},{1.215847, 1.331107, 0.004647},{
      1.219011, 1.334271, 0.004647},{1.219456, 1.333947, 0.002352}}],
    Polygon[{{1.215847, 1.331107, 0.004647},{1.215316, 1.331838, 0.006827},{
      1.218280, 1.334802, 0.006827},{1.219011, 1.334271, 0.004647}}],
    Polygon[{{1.215316, 1.331838, 0.006827},{1.214591, 1.332835, 0.008839},{
      1.217283, 1.335527, 0.008839},{1.218280, 1.334802, 0.006827}}],
    Polygon[{{1.214591, 1.332835, 0.008839},{1.213690, 1.334075, 0.010634},{
      1.216043, 1.336427, 0.010634},{1.217283, 1.335527, 0.008839}}],
    Polygon[{{1.213690, 1.334075, 0.010634},{1.212636, 1.335527, 0.012166},{
      1.214591, 1.337482, 0.012166},{1.216043, 1.336427, 0.010634}}],
    Polygon[{{1.212636, 1.335527, 0.012166},{1.211453, 1.337154, 0.013399},{
      1.212963, 1.338665, 0.013399},{1.214591, 1.337482, 0.012166}}],
    Polygon[{{1.211453, 1.337154, 0.013399},{1.210171, 1.338918, 0.014302},{
      1.211200, 1.339946, 0.014302},{1.212963, 1.338665, 0.013399}}],
    Polygon[{{1.210171, 1.338918, 0.014302},{1.208823, 1.340775, 0.014853},{
      1.209343, 1.341295, 0.014853},{1.211200, 1.339946, 0.014302}}],
    Polygon[{{1.209343, 1.341295, -0.014853},{1.211200, 1.339946, -0.014302},{
      1.211860, 1.341242, -0.014302},{1.209677, 1.341951, -0.014853}}],
    Polygon[{{1.211200, 1.339946, -0.014302},{1.212963, 1.338665, -0.013399},{
      1.213933, 1.340568, -0.013399},{1.211860, 1.341242, -0.014302}}],
    Polygon[{{1.212963, 1.338665, -0.013399},{1.214591, 1.337482, -0.012166},{
      1.215847, 1.339946, -0.012166},{1.213933, 1.340568, -0.013399}}],
    Polygon[{{1.214591, 1.337482, -0.012166},{1.216043, 1.336427, -0.010634},{
      1.217553, 1.339392, -0.010634},{1.215847, 1.339946, -0.012166}}],
    Polygon[{{1.216043, 1.336427, -0.010634},{1.217283, 1.335527, -0.008839},{
      1.219011, 1.338918, -0.008839},{1.217553, 1.339392, -0.010634}}],
    Polygon[{{1.217283, 1.335527, -0.008839},{1.218280, 1.334802, -0.006827},{
      1.220183, 1.338537, -0.006827},{1.219011, 1.338918, -0.008839}}],
    Polygon[{{1.218280, 1.334802, -0.006827},{1.219011, 1.334271, -0.004647},{
      1.221042, 1.338258, -0.004647},{1.220183, 1.338537, -0.006827}}],
    Polygon[{{1.219011, 1.334271, -0.004647},{1.219456, 1.333947, -0.002352},{
      1.221566, 1.338088, -0.002352},{1.221042, 1.338258, -0.004647}}],
    Polygon[{{1.219456, 1.333947, -0.002352},{1.219606, 1.333839, 0.000000},{
      1.221742, 1.338031, 0.000000},{1.221566, 1.338088, -0.002352}}],
    Polygon[{{1.219606, 1.333839, 0.000000},{1.219456, 1.333947, 0.002352},{
      1.221566, 1.338088, 0.002352},{1.221742, 1.338031, 0.000000}}],
    Polygon[{{1.219456, 1.333947, 0.002352},{1.219011, 1.334271, 0.004647},{
      1.221042, 1.338258, 0.004647},{1.221566, 1.338088, 0.002352}}],
    Polygon[{{1.219011, 1.334271, 0.004647},{1.218280, 1.334802, 0.006827},{
      1.220183, 1.338537, 0.006827},{1.221042, 1.338258, 0.004647}}],
    Polygon[{{1.218280, 1.334802, 0.006827},{1.217283, 1.335527, 0.008839},{
      1.219011, 1.338918, 0.008839},{1.220183, 1.338537, 0.006827}}],
    Polygon[{{1.217283, 1.335527, 0.008839},{1.216043, 1.336427, 0.010634},{
      1.217553, 1.339392, 0.010634},{1.219011, 1.338918, 0.008839}}],
    Polygon[{{1.216043, 1.336427, 0.010634},{1.214591, 1.337482, 0.012166},{
      1.215847, 1.339946, 0.012166},{1.217553, 1.339392, 0.010634}}],
    Polygon[{{1.214591, 1.337482, 0.012166},{1.212963, 1.338665, 0.013399},{
      1.213933, 1.340568, 0.013399},{1.215847, 1.339946, 0.012166}}],
    Polygon[{{1.212963, 1.338665, 0.013399},{1.211200, 1.339946, 0.014302},{
      1.211860, 1.341242, 0.014302},{1.213933, 1.340568, 0.013399}}],
    Polygon[{{1.211200, 1.339946, 0.014302},{1.209343, 1.341295, 0.014853},{
      1.209677, 1.341951, 0.014853},{1.211860, 1.341242, 0.014302}}],
    Polygon[{{1.209677, 1.341951, -0.014853},{1.211860, 1.341242, -0.014302},{
      1.212087, 1.342678, -0.014302},{1.209792, 1.342678, -0.014853}}],
    Polygon[{{1.211860, 1.341242, -0.014302},{1.213933, 1.340568, -0.013399},{
      1.214267, 1.342678, -0.013399},{1.212087, 1.342678, -0.014302}}],
    Polygon[{{1.213933, 1.340568, -0.013399},{1.215847, 1.339946, -0.012166},{
      1.216279, 1.342678, -0.012166},{1.214267, 1.342678, -0.013399}}],
    Polygon[{{1.215847, 1.339946, -0.012166},{1.217553, 1.339392, -0.010634},{
      1.218074, 1.342678, -0.010634},{1.216279, 1.342678, -0.012166}}],
    Polygon[{{1.217553, 1.339392, -0.010634},{1.219011, 1.338918, -0.008839},{
      1.219606, 1.342678, -0.008839},{1.218074, 1.342678, -0.010634}}],
    Polygon[{{1.219011, 1.338918, -0.008839},{1.220183, 1.338537, -0.006827},{
      1.220839, 1.342678, -0.006827},{1.219606, 1.342678, -0.008839}}],
    Polygon[{{1.220183, 1.338537, -0.006827},{1.221042, 1.338258, -0.004647},{
      1.221742, 1.342678, -0.004647},{1.220839, 1.342678, -0.006827}}],
    Polygon[{{1.221042, 1.338258, -0.004647},{1.221566, 1.338088, -0.002352},{
      1.222293, 1.342678, -0.002352},{1.221742, 1.342678, -0.004647}}],
    Polygon[{{1.221566, 1.338088, -0.002352},{1.221742, 1.338031, 0.000000},{
      1.222478, 1.342678, 0.000000},{1.222293, 1.342678, -0.002352}}],
    Polygon[{{1.221742, 1.338031, 0.000000},{1.221566, 1.338088, 0.002352},{
      1.222293, 1.342678, 0.002352},{1.222478, 1.342678, 0.000000}}],
    Polygon[{{1.221566, 1.338088, 0.002352},{1.221042, 1.338258, 0.004647},{
      1.221742, 1.342678, 0.004647},{1.222293, 1.342678, 0.002352}}],
    Polygon[{{1.221042, 1.338258, 0.004647},{1.220183, 1.338537, 0.006827},{
      1.220839, 1.342678, 0.006827},{1.221742, 1.342678, 0.004647}}],
    Polygon[{{1.220183, 1.338537, 0.006827},{1.219011, 1.338918, 0.008839},{
      1.219606, 1.342678, 0.008839},{1.220839, 1.342678, 0.006827}}],
    Polygon[{{1.219011, 1.338918, 0.008839},{1.217553, 1.339392, 0.010634},{
      1.218074, 1.342678, 0.010634},{1.219606, 1.342678, 0.008839}}],
    Polygon[{{1.217553, 1.339392, 0.010634},{1.215847, 1.339946, 0.012166},{
      1.216279, 1.342678, 0.012166},{1.218074, 1.342678, 0.010634}}],
    Polygon[{{1.215847, 1.339946, 0.012166},{1.213933, 1.340568, 0.013399},{
      1.214267, 1.342678, 0.013399},{1.216279, 1.342678, 0.012166}}],
    Polygon[{{1.213933, 1.340568, 0.013399},{1.211860, 1.341242, 0.014302},{
      1.212087, 1.342678, 0.014302},{1.214267, 1.342678, 0.013399}}],
    Polygon[{{1.211860, 1.341242, 0.014302},{1.209677, 1.341951, 0.014853},{
      1.209792, 1.342678, 0.014853},{1.212087, 1.342678, 0.014302}}],
    Polygon[{{1.251397, 1.277340, -0.011012},{1.253099, 1.277340, -0.010603},{
      1.252930, 1.278405, -0.010603},{1.251312, 1.277879, -0.011012}}],
    Polygon[{{1.253099, 1.277340, -0.010603},{1.254715, 1.277340, -0.009934},{
      1.254467, 1.278904, -0.009934},{1.252930, 1.278405, -0.010603}}],
    Polygon[{{1.254715, 1.277340, -0.009934},{1.256207, 1.277340, -0.009020},{
      1.255886, 1.279365, -0.009020},{1.254467, 1.278904, -0.009934}}],
    Polygon[{{1.256207, 1.277340, -0.009020},{1.257537, 1.277340, -0.007884},{
      1.257151, 1.279776, -0.007884},{1.255886, 1.279365, -0.009020}}],
    Polygon[{{1.257537, 1.277340, -0.007884},{1.258673, 1.277340, -0.006553},{
      1.258232, 1.280128, -0.006553},{1.257151, 1.279776, -0.007884}}],
    Polygon[{{1.258673, 1.277340, -0.006553},{1.259587, 1.277340, -0.005062},{
      1.259101, 1.280410, -0.005062},{1.258232, 1.280128, -0.006553}}],
    Polygon[{{1.259587, 1.277340, -0.005062},{1.260257, 1.277340, -0.003445},{
      1.259738, 1.280617, -0.003445},{1.259101, 1.280410, -0.005062}}],
    Polygon[{{1.260257, 1.277340, -0.003445},{1.260665, 1.277340, -0.001744},{
      1.260126, 1.280743, -0.001744},{1.259738, 1.280617, -0.003445}}],
    Polygon[{{1.260665, 1.277340, -0.001744},{1.260803, 1.277340, 0.000000},{
      1.260257, 1.280786, 0.000000},{1.260126, 1.280743, -0.001744}}],
    Polygon[{{1.260803, 1.277340, 0.000000},{1.260665, 1.277340, 0.001744},{
      1.260126, 1.280743, 0.001744},{1.260257, 1.280786, 0.000000}}],
    Polygon[{{1.260665, 1.277340, 0.001744},{1.260257, 1.277340, 0.003445},{
      1.259738, 1.280617, 0.003445},{1.260126, 1.280743, 0.001744}}],
    Polygon[{{1.260257, 1.277340, 0.003445},{1.259587, 1.277340, 0.005062},{
      1.259101, 1.280410, 0.005062},{1.259738, 1.280617, 0.003445}}],
    Polygon[{{1.259587, 1.277340, 0.005062},{1.258673, 1.277340, 0.006553},{
      1.258232, 1.280128, 0.006553},{1.259101, 1.280410, 0.005062}}],
    Polygon[{{1.258673, 1.277340, 0.006553},{1.257537, 1.277340, 0.007884},{
      1.257151, 1.279776, 0.007884},{1.258232, 1.280128, 0.006553}}],
    Polygon[{{1.257537, 1.277340, 0.007884},{1.256207, 1.277340, 0.009020},{
      1.255886, 1.279365, 0.009020},{1.257151, 1.279776, 0.007884}}],
    Polygon[{{1.256207, 1.277340, 0.009020},{1.254715, 1.277340, 0.009934},{
      1.254467, 1.278904, 0.009934},{1.255886, 1.279365, 0.009020}}],
    Polygon[{{1.254715, 1.277340, 0.009934},{1.253099, 1.277340, 0.010603},{
      1.252930, 1.278405, 0.010603},{1.254467, 1.278904, 0.009934}}],
    Polygon[{{1.253099, 1.277340, 0.010603},{1.251397, 1.277340, 0.011012},{
      1.251312, 1.277879, 0.011012},{1.252930, 1.278405, 0.010603}}],
    Polygon[{{1.251312, 1.277879, -0.011012},{1.252930, 1.278405, -0.010603},{
      1.252441, 1.279365, -0.010603},{1.251064, 1.278365, -0.011012}}],
    Polygon[{{1.252930, 1.278405, -0.010603},{1.254467, 1.278904, -0.009934},{
      1.253748, 1.280315, -0.009934},{1.252441, 1.279365, -0.010603}}],
    Polygon[{{1.254467, 1.278904, -0.009934},{1.255886, 1.279365, -0.009020},{
      1.254955, 1.281192, -0.009020},{1.253748, 1.280315, -0.009934}}],
    Polygon[{{1.255886, 1.279365, -0.009020},{1.257151, 1.279776, -0.007884},{
      1.256031, 1.281974, -0.007884},{1.254955, 1.281192, -0.009020}}],
    Polygon[{{1.257151, 1.279776, -0.007884},{1.258232, 1.280128, -0.006553},{
      1.256950, 1.282642, -0.006553},{1.256031, 1.281974, -0.007884}}],
    Polygon[{{1.258232, 1.280128, -0.006553},{1.259101, 1.280410, -0.005062},{
      1.257690, 1.283179, -0.005062},{1.256950, 1.282642, -0.006553}}],
    Polygon[{{1.259101, 1.280410, -0.005062},{1.259738, 1.280617, -0.003445},{
      1.258232, 1.283573, -0.003445},{1.257690, 1.283179, -0.005062}}],
    Polygon[{{1.259738, 1.280617, -0.003445},{1.260126, 1.280743, -0.001744},{
      1.258562, 1.283813, -0.001744},{1.258232, 1.283573, -0.003445}}],
    Polygon[{{1.260126, 1.280743, -0.001744},{1.260257, 1.280786, 0.000000},{
      1.258673, 1.283894, 0.000000},{1.258562, 1.283813, -0.001744}}],
    Polygon[{{1.260257, 1.280786, 0.000000},{1.260126, 1.280743, 0.001744},{
      1.258562, 1.283813, 0.001744},{1.258673, 1.283894, 0.000000}}],
    Polygon[{{1.260126, 1.280743, 0.001744},{1.259738, 1.280617, 0.003445},{
      1.258232, 1.283573, 0.003445},{1.258562, 1.283813, 0.001744}}],
    Polygon[{{1.259738, 1.280617, 0.003445},{1.259101, 1.280410, 0.005062},{
      1.257690, 1.283179, 0.005062},{1.258232, 1.283573, 0.003445}}],
    Polygon[{{1.259101, 1.280410, 0.005062},{1.258232, 1.280128, 0.006553},{
      1.256950, 1.282642, 0.006553},{1.257690, 1.283179, 0.005062}}],
    Polygon[{{1.258232, 1.280128, 0.006553},{1.257151, 1.279776, 0.007884},{
      1.256031, 1.281974, 0.007884},{1.256950, 1.282642, 0.006553}}],
    Polygon[{{1.257151, 1.279776, 0.007884},{1.255886, 1.279365, 0.009020},{
      1.254955, 1.281192, 0.009020},{1.256031, 1.281974, 0.007884}}],
    Polygon[{{1.255886, 1.279365, 0.009020},{1.254467, 1.278904, 0.009934},{
      1.253748, 1.280315, 0.009934},{1.254955, 1.281192, 0.009020}}],
    Polygon[{{1.254467, 1.278904, 0.009934},{1.252930, 1.278405, 0.010603},{
      1.252441, 1.279365, 0.010603},{1.253748, 1.280315, 0.009934}}],
    Polygon[{{1.252930, 1.278405, 0.010603},{1.251312, 1.277879, 0.011012},{
      1.251064, 1.278365, 0.011012},{1.252441, 1.279365, 0.010603}}],
    Polygon[{{1.251064, 1.278365, -0.011012},{1.252441, 1.279365, -0.010603},{
      1.251678, 1.280128, -0.010603},{1.250679, 1.278751, -0.011012}}],
    Polygon[{{1.252441, 1.279365, -0.010603},{1.253748, 1.280315, -0.009934},{
      1.252628, 1.281435, -0.009934},{1.251678, 1.280128, -0.010603}}],
    Polygon[{{1.253748, 1.280315, -0.009934},{1.254955, 1.281192, -0.009020},{
      1.253505, 1.282642, -0.009020},{1.252628, 1.281435, -0.009934}}],
    Polygon[{{1.254955, 1.281192, -0.009020},{1.256031, 1.281974, -0.007884},{
      1.254287, 1.283718, -0.007884},{1.253505, 1.282642, -0.009020}}],
    Polygon[{{1.256031, 1.281974, -0.007884},{1.256950, 1.282642, -0.006553},{
      1.254955, 1.284637, -0.006553},{1.254287, 1.283718, -0.007884}}],
    Polygon[{{1.256950, 1.282642, -0.006553},{1.257690, 1.283179, -0.005062},{
      1.255492, 1.285377, -0.005062},{1.254955, 1.284637, -0.006553}}],
    Polygon[{{1.257690, 1.283179, -0.005062},{1.258232, 1.283573, -0.003445},{
      1.255886, 1.285919, -0.003445},{1.255492, 1.285377, -0.005062}}],
    Polygon[{{1.258232, 1.283573, -0.003445},{1.258562, 1.283813, -0.001744},{
      1.256126, 1.286249, -0.001744},{1.255886, 1.285919, -0.003445}}],
    Polygon[{{1.258562, 1.283813, -0.001744},{1.258673, 1.283894, 0.000000},{
      1.256207, 1.286360, 0.000000},{1.256126, 1.286249, -0.001744}}],
    Polygon[{{1.258673, 1.283894, 0.000000},{1.258562, 1.283813, 0.001744},{
      1.256126, 1.286249, 0.001744},{1.256207, 1.286360, 0.000000}}],
    Polygon[{{1.258562, 1.283813, 0.001744},{1.258232, 1.283573, 0.003445},{
      1.255886, 1.285919, 0.003445},{1.256126, 1.286249, 0.001744}}],
    Polygon[{{1.258232, 1.283573, 0.003445},{1.257690, 1.283179, 0.005062},{
      1.255492, 1.285377, 0.005062},{1.255886, 1.285919, 0.003445}}],
    Polygon[{{1.257690, 1.283179, 0.005062},{1.256950, 1.282642, 0.006553},{
      1.254955, 1.284637, 0.006553},{1.255492, 1.285377, 0.005062}}],
    Polygon[{{1.256950, 1.282642, 0.006553},{1.256031, 1.281974, 0.007884},{
      1.254287, 1.283718, 0.007884},{1.254955, 1.284637, 0.006553}}],
    Polygon[{{1.256031, 1.281974, 0.007884},{1.254955, 1.281192, 0.009020},{
      1.253505, 1.282642, 0.009020},{1.254287, 1.283718, 0.007884}}],
    Polygon[{{1.254955, 1.281192, 0.009020},{1.253748, 1.280315, 0.009934},{
      1.252628, 1.281435, 0.009934},{1.253505, 1.282642, 0.009020}}],
    Polygon[{{1.253748, 1.280315, 0.009934},{1.252441, 1.279365, 0.010603},{
      1.251678, 1.280128, 0.010603},{1.252628, 1.281435, 0.009934}}],
    Polygon[{{1.252441, 1.279365, 0.010603},{1.251064, 1.278365, 0.011012},{
      1.250679, 1.278751, 0.011012},{1.251678, 1.280128, 0.010603}}],
    Polygon[{{1.250679, 1.278751, -0.011012},{1.251678, 1.280128, -0.010603},{
      1.250718, 1.280617, -0.010603},{1.250192, 1.278999, -0.011012}}],
    Polygon[{{1.251678, 1.280128, -0.010603},{1.252628, 1.281435, -0.009934},{
      1.251217, 1.282154, -0.009934},{1.250718, 1.280617, -0.010603}}],
    Polygon[{{1.252628, 1.281435, -0.009934},{1.253505, 1.282642, -0.009020},{
      1.251678, 1.283573, -0.009020},{1.251217, 1.282154, -0.009934}}],
    Polygon[{{1.253505, 1.282642, -0.009020},{1.254287, 1.283718, -0.007884},{
      1.252090, 1.284838, -0.007884},{1.251678, 1.283573, -0.009020}}],
    Polygon[{{1.254287, 1.283718, -0.007884},{1.254955, 1.284637, -0.006553},{
      1.252441, 1.285919, -0.006553},{1.252090, 1.284838, -0.007884}}],
    Polygon[{{1.254955, 1.284637, -0.006553},{1.255492, 1.285377, -0.005062},{
      1.252723, 1.286788, -0.005062},{1.252441, 1.285919, -0.006553}}],
    Polygon[{{1.255492, 1.285377, -0.005062},{1.255886, 1.285919, -0.003445},{
      1.252930, 1.287425, -0.003445},{1.252723, 1.286788, -0.005062}}],
    Polygon[{{1.255886, 1.285919, -0.003445},{1.256126, 1.286249, -0.001744},{
      1.253056, 1.287813, -0.001744},{1.252930, 1.287425, -0.003445}}],
    Polygon[{{1.256126, 1.286249, -0.001744},{1.256207, 1.286360, 0.000000},{
      1.253099, 1.287944, 0.000000},{1.253056, 1.287813, -0.001744}}],
    Polygon[{{1.256207, 1.286360, 0.000000},{1.256126, 1.286249, 0.001744},{
      1.253056, 1.287813, 0.001744},{1.253099, 1.287944, 0.000000}}],
    Polygon[{{1.256126, 1.286249, 0.001744},{1.255886, 1.285919, 0.003445},{
      1.252930, 1.287425, 0.003445},{1.253056, 1.287813, 0.001744}}],
    Polygon[{{1.255886, 1.285919, 0.003445},{1.255492, 1.285377, 0.005062},{
      1.252723, 1.286788, 0.005062},{1.252930, 1.287425, 0.003445}}],
    Polygon[{{1.255492, 1.285377, 0.005062},{1.254955, 1.284637, 0.006553},{
      1.252441, 1.285919, 0.006553},{1.252723, 1.286788, 0.005062}}],
    Polygon[{{1.254955, 1.284637, 0.006553},{1.254287, 1.283718, 0.007884},{
      1.252090, 1.284838, 0.007884},{1.252441, 1.285919, 0.006553}}],
    Polygon[{{1.254287, 1.283718, 0.007884},{1.253505, 1.282642, 0.009020},{
      1.251678, 1.283573, 0.009020},{1.252090, 1.284838, 0.007884}}],
    Polygon[{{1.253505, 1.282642, 0.009020},{1.252628, 1.281435, 0.009934},{
      1.251217, 1.282154, 0.009934},{1.251678, 1.283573, 0.009020}}],
    Polygon[{{1.252628, 1.281435, 0.009934},{1.251678, 1.280128, 0.010603},{
      1.250718, 1.280617, 0.010603},{1.251217, 1.282154, 0.009934}}],
    Polygon[{{1.251678, 1.280128, 0.010603},{1.250679, 1.278751, 0.011012},{
      1.250192, 1.278999, 0.011012},{1.250718, 1.280617, 0.010603}}],
    Polygon[{{1.250192, 1.278999, -0.011012},{1.250718, 1.280617, -0.010603},{
      1.249653, 1.280786, -0.010603},{1.249653, 1.279084, -0.011012}}],
    Polygon[{{1.250718, 1.280617, -0.010603},{1.251217, 1.282154, -0.009934},{
      1.249653, 1.282402, -0.009934},{1.249653, 1.280786, -0.010603}}],
    Polygon[{{1.251217, 1.282154, -0.009934},{1.251678, 1.283573, -0.009020},{
      1.249653, 1.283894, -0.009020},{1.249653, 1.282402, -0.009934}}],
    Polygon[{{1.251678, 1.283573, -0.009020},{1.252090, 1.284838, -0.007884},{
      1.249653, 1.285224, -0.007884},{1.249653, 1.283894, -0.009020}}],
    Polygon[{{1.252090, 1.284838, -0.007884},{1.252441, 1.285919, -0.006553},{
      1.249653, 1.286360, -0.006553},{1.249653, 1.285224, -0.007884}}],
    Polygon[{{1.252441, 1.285919, -0.006553},{1.252723, 1.286788, -0.005062},{
      1.249653, 1.287274, -0.005062},{1.249653, 1.286360, -0.006553}}],
    Polygon[{{1.252723, 1.286788, -0.005062},{1.252930, 1.287425, -0.003445},{
      1.249653, 1.287944, -0.003445},{1.249653, 1.287274, -0.005062}}],
    Polygon[{{1.252930, 1.287425, -0.003445},{1.253056, 1.287813, -0.001744},{
      1.249653, 1.288352, -0.001744},{1.249653, 1.287944, -0.003445}}],
    Polygon[{{1.253056, 1.287813, -0.001744},{1.253099, 1.287944, 0.000000},{
      1.249653, 1.288489, 0.000000},{1.249653, 1.288352, -0.001744}}],
    Polygon[{{1.253099, 1.287944, 0.000000},{1.253056, 1.287813, 0.001744},{
      1.249653, 1.288352, 0.001744},{1.249653, 1.288489, 0.000000}}],
    Polygon[{{1.253056, 1.287813, 0.001744},{1.252930, 1.287425, 0.003445},{
      1.249653, 1.287944, 0.003445},{1.249653, 1.288352, 0.001744}}],
    Polygon[{{1.252930, 1.287425, 0.003445},{1.252723, 1.286788, 0.005062},{
      1.249653, 1.287274, 0.005062},{1.249653, 1.287944, 0.003445}}],
    Polygon[{{1.252723, 1.286788, 0.005062},{1.252441, 1.285919, 0.006553},{
      1.249653, 1.286360, 0.006553},{1.249653, 1.287274, 0.005062}}],
    Polygon[{{1.252441, 1.285919, 0.006553},{1.252090, 1.284838, 0.007884},{
      1.249653, 1.285224, 0.007884},{1.249653, 1.286360, 0.006553}}],
    Polygon[{{1.252090, 1.284838, 0.007884},{1.251678, 1.283573, 0.009020},{
      1.249653, 1.283894, 0.009020},{1.249653, 1.285224, 0.007884}}],
    Polygon[{{1.251678, 1.283573, 0.009020},{1.251217, 1.282154, 0.009934},{
      1.249653, 1.282402, 0.009934},{1.249653, 1.283894, 0.009020}}],
    Polygon[{{1.251217, 1.282154, 0.009934},{1.250718, 1.280617, 0.010603},{
      1.249653, 1.280786, 0.010603},{1.249653, 1.282402, 0.009934}}],
    Polygon[{{1.250718, 1.280617, 0.010603},{1.250192, 1.278999, 0.011012},{
      1.249653, 1.279084, 0.011012},{1.249653, 1.280786, 0.010603}}],
    Polygon[{{1.249653, 1.279084, -0.011012},{1.249653, 1.280786, -0.010603},{
      1.248589, 1.280617, -0.010603},{1.249114, 1.278999, -0.011012}}],
    Polygon[{{1.249653, 1.280786, -0.010603},{1.249653, 1.282402, -0.009934},{
      1.248089, 1.282154, -0.009934},{1.248589, 1.280617, -0.010603}}],
    Polygon[{{1.249653, 1.282402, -0.009934},{1.249653, 1.283894, -0.009020},{
      1.247628, 1.283573, -0.009020},{1.248089, 1.282154, -0.009934}}],
    Polygon[{{1.249653, 1.283894, -0.009020},{1.249653, 1.285224, -0.007884},{
      1.247217, 1.284838, -0.007884},{1.247628, 1.283573, -0.009020}}],
    Polygon[{{1.249653, 1.285224, -0.007884},{1.249653, 1.286360, -0.006553},{
      1.246866, 1.285919, -0.006553},{1.247217, 1.284838, -0.007884}}],
    Polygon[{{1.249653, 1.286360, -0.006553},{1.249653, 1.287274, -0.005062},{
      1.246584, 1.286788, -0.005062},{1.246866, 1.285919, -0.006553}}],
    Polygon[{{1.249653, 1.287274, -0.005062},{1.249653, 1.287944, -0.003445},{
      1.246377, 1.287425, -0.003445},{1.246584, 1.286788, -0.005062}}],
    Polygon[{{1.249653, 1.287944, -0.003445},{1.249653, 1.288352, -0.001744},{
      1.246251, 1.287813, -0.001744},{1.246377, 1.287425, -0.003445}}],
    Polygon[{{1.249653, 1.288352, -0.001744},{1.249653, 1.288489, 0.000000},{
      1.246208, 1.287944, 0.000000},{1.246251, 1.287813, -0.001744}}],
    Polygon[{{1.249653, 1.288489, 0.000000},{1.249653, 1.288352, 0.001744},{
      1.246251, 1.287813, 0.001744},{1.246208, 1.287944, 0.000000}}],
    Polygon[{{1.249653, 1.288352, 0.001744},{1.249653, 1.287944, 0.003445},{
      1.246377, 1.287425, 0.003445},{1.246251, 1.287813, 0.001744}}],
    Polygon[{{1.249653, 1.287944, 0.003445},{1.249653, 1.287274, 0.005062},{
      1.246584, 1.286788, 0.005062},{1.246377, 1.287425, 0.003445}}],
    Polygon[{{1.249653, 1.287274, 0.005062},{1.249653, 1.286360, 0.006553},{
      1.246866, 1.285919, 0.006553},{1.246584, 1.286788, 0.005062}}],
    Polygon[{{1.249653, 1.286360, 0.006553},{1.249653, 1.285224, 0.007884},{
      1.247217, 1.284838, 0.007884},{1.246866, 1.285919, 0.006553}}],
    Polygon[{{1.249653, 1.285224, 0.007884},{1.249653, 1.283894, 0.009020},{
      1.247628, 1.283573, 0.009020},{1.247217, 1.284838, 0.007884}}],
    Polygon[{{1.249653, 1.283894, 0.009020},{1.249653, 1.282402, 0.009934},{
      1.248089, 1.282154, 0.009934},{1.247628, 1.283573, 0.009020}}],
    Polygon[{{1.249653, 1.282402, 0.009934},{1.249653, 1.280786, 0.010603},{
      1.248589, 1.280617, 0.010603},{1.248089, 1.282154, 0.009934}}],
    Polygon[{{1.249653, 1.280786, 0.010603},{1.249653, 1.279084, 0.011012},{
      1.249114, 1.278999, 0.011012},{1.248589, 1.280617, 0.010603}}],
    Polygon[{{1.249114, 1.278999, -0.011012},{1.248589, 1.280617, -0.010603},{
      1.247628, 1.280128, -0.010603},{1.248628, 1.278751, -0.011012}}],
    Polygon[{{1.248589, 1.280617, -0.010603},{1.248089, 1.282154, -0.009934},{
      1.246678, 1.281435, -0.009934},{1.247628, 1.280128, -0.010603}}],
    Polygon[{{1.248089, 1.282154, -0.009934},{1.247628, 1.283573, -0.009020},{
      1.245801, 1.282642, -0.009020},{1.246678, 1.281435, -0.009934}}],
    Polygon[{{1.247628, 1.283573, -0.009020},{1.247217, 1.284838, -0.007884},{
      1.245020, 1.283718, -0.007884},{1.245801, 1.282642, -0.009020}}],
    Polygon[{{1.247217, 1.284838, -0.007884},{1.246866, 1.285919, -0.006553},{
      1.244352, 1.284637, -0.006553},{1.245020, 1.283718, -0.007884}}],
    Polygon[{{1.246866, 1.285919, -0.006553},{1.246584, 1.286788, -0.005062},{
      1.243814, 1.285377, -0.005062},{1.244352, 1.284637, -0.006553}}],
    Polygon[{{1.246584, 1.286788, -0.005062},{1.246377, 1.287425, -0.003445},{
      1.243421, 1.285919, -0.003445},{1.243814, 1.285377, -0.005062}}],
    Polygon[{{1.246377, 1.287425, -0.003445},{1.246251, 1.287813, -0.001744},{
      1.243181, 1.286249, -0.001744},{1.243421, 1.285919, -0.003445}}],
    Polygon[{{1.246251, 1.287813, -0.001744},{1.246208, 1.287944, 0.000000},{
      1.243100, 1.286360, 0.000000},{1.243181, 1.286249, -0.001744}}],
    Polygon[{{1.246208, 1.287944, 0.000000},{1.246251, 1.287813, 0.001744},{
      1.243181, 1.286249, 0.001744},{1.243100, 1.286360, 0.000000}}],
    Polygon[{{1.246251, 1.287813, 0.001744},{1.246377, 1.287425, 0.003445},{
      1.243421, 1.285919, 0.003445},{1.243181, 1.286249, 0.001744}}],
    Polygon[{{1.246377, 1.287425, 0.003445},{1.246584, 1.286788, 0.005062},{
      1.243814, 1.285377, 0.005062},{1.243421, 1.285919, 0.003445}}],
    Polygon[{{1.246584, 1.286788, 0.005062},{1.246866, 1.285919, 0.006553},{
      1.244352, 1.284637, 0.006553},{1.243814, 1.285377, 0.005062}}],
    Polygon[{{1.246866, 1.285919, 0.006553},{1.247217, 1.284838, 0.007884},{
      1.245020, 1.283718, 0.007884},{1.244352, 1.284637, 0.006553}}],
    Polygon[{{1.247217, 1.284838, 0.007884},{1.247628, 1.283573, 0.009020},{
      1.245801, 1.282642, 0.009020},{1.245020, 1.283718, 0.007884}}],
    Polygon[{{1.247628, 1.283573, 0.009020},{1.248089, 1.282154, 0.009934},{
      1.246678, 1.281435, 0.009934},{1.245801, 1.282642, 0.009020}}],
    Polygon[{{1.248089, 1.282154, 0.009934},{1.248589, 1.280617, 0.010603},{
      1.247628, 1.280128, 0.010603},{1.246678, 1.281435, 0.009934}}],
    Polygon[{{1.248589, 1.280617, 0.010603},{1.249114, 1.278999, 0.011012},{
      1.248628, 1.278751, 0.011012},{1.247628, 1.280128, 0.010603}}],
    Polygon[{{1.248628, 1.278751, -0.011012},{1.247628, 1.280128, -0.010603},{
      1.246866, 1.279365, -0.010603},{1.248242, 1.278365, -0.011012}}],
    Polygon[{{1.247628, 1.280128, -0.010603},{1.246678, 1.281435, -0.009934},{
      1.245559, 1.280315, -0.009934},{1.246866, 1.279365, -0.010603}}],
    Polygon[{{1.246678, 1.281435, -0.009934},{1.245801, 1.282642, -0.009020},{
      1.244352, 1.281192, -0.009020},{1.245559, 1.280315, -0.009934}}],
    Polygon[{{1.245801, 1.282642, -0.009020},{1.245020, 1.283718, -0.007884},{
      1.243275, 1.281974, -0.007884},{1.244352, 1.281192, -0.009020}}],
    Polygon[{{1.245020, 1.283718, -0.007884},{1.244352, 1.284637, -0.006553},{
      1.242356, 1.282642, -0.006553},{1.243275, 1.281974, -0.007884}}],
    Polygon[{{1.244352, 1.284637, -0.006553},{1.243814, 1.285377, -0.005062},{
      1.241617, 1.283179, -0.005062},{1.242356, 1.282642, -0.006553}}],
    Polygon[{{1.243814, 1.285377, -0.005062},{1.243421, 1.285919, -0.003445},{
      1.241075, 1.283573, -0.003445},{1.241617, 1.283179, -0.005062}}],
    Polygon[{{1.243421, 1.285919, -0.003445},{1.243181, 1.286249, -0.001744},{
      1.240745, 1.283813, -0.001744},{1.241075, 1.283573, -0.003445}}],
    Polygon[{{1.243181, 1.286249, -0.001744},{1.243100, 1.286360, 0.000000},{
      1.240634, 1.283894, 0.000000},{1.240745, 1.283813, -0.001744}}],
    Polygon[{{1.243100, 1.286360, 0.000000},{1.243181, 1.286249, 0.001744},{
      1.240745, 1.283813, 0.001744},{1.240634, 1.283894, 0.000000}}],
    Polygon[{{1.243181, 1.286249, 0.001744},{1.243421, 1.285919, 0.003445},{
      1.241075, 1.283573, 0.003445},{1.240745, 1.283813, 0.001744}}],
    Polygon[{{1.243421, 1.285919, 0.003445},{1.243814, 1.285377, 0.005062},{
      1.241617, 1.283179, 0.005062},{1.241075, 1.283573, 0.003445}}],
    Polygon[{{1.243814, 1.285377, 0.005062},{1.244352, 1.284637, 0.006553},{
      1.242356, 1.282642, 0.006553},{1.241617, 1.283179, 0.005062}}],
    Polygon[{{1.244352, 1.284637, 0.006553},{1.245020, 1.283718, 0.007884},{
      1.243275, 1.281974, 0.007884},{1.242356, 1.282642, 0.006553}}],
    Polygon[{{1.245020, 1.283718, 0.007884},{1.245801, 1.282642, 0.009020},{
      1.244352, 1.281192, 0.009020},{1.243275, 1.281974, 0.007884}}],
    Polygon[{{1.245801, 1.282642, 0.009020},{1.246678, 1.281435, 0.009934},{
      1.245559, 1.280315, 0.009934},{1.244352, 1.281192, 0.009020}}],
    Polygon[{{1.246678, 1.281435, 0.009934},{1.247628, 1.280128, 0.010603},{
      1.246866, 1.279365, 0.010603},{1.245559, 1.280315, 0.009934}}],
    Polygon[{{1.247628, 1.280128, 0.010603},{1.248628, 1.278751, 0.011012},{
      1.248242, 1.278365, 0.011012},{1.246866, 1.279365, 0.010603}}],
    Polygon[{{1.248242, 1.278365, -0.011012},{1.246866, 1.279365, -0.010603},{
      1.246377, 1.278405, -0.010603},{1.247995, 1.277879, -0.011012}}],
    Polygon[{{1.246866, 1.279365, -0.010603},{1.245559, 1.280315, -0.009934},{
      1.244840, 1.278904, -0.009934},{1.246377, 1.278405, -0.010603}}],
    Polygon[{{1.245559, 1.280315, -0.009934},{1.244352, 1.281192, -0.009020},{
      1.243421, 1.279365, -0.009020},{1.244840, 1.278904, -0.009934}}],
    Polygon[{{1.244352, 1.281192, -0.009020},{1.243275, 1.281974, -0.007884},{
      1.242156, 1.279776, -0.007884},{1.243421, 1.279365, -0.009020}}],
    Polygon[{{1.243275, 1.281974, -0.007884},{1.242356, 1.282642, -0.006553},{
      1.241075, 1.280128, -0.006553},{1.242156, 1.279776, -0.007884}}],
    Polygon[{{1.242356, 1.282642, -0.006553},{1.241617, 1.283179, -0.005062},{
      1.240206, 1.280410, -0.005062},{1.241075, 1.280128, -0.006553}}],
    Polygon[{{1.241617, 1.283179, -0.005062},{1.241075, 1.283573, -0.003445},{
      1.239569, 1.280617, -0.003445},{1.240206, 1.280410, -0.005062}}],
    Polygon[{{1.241075, 1.283573, -0.003445},{1.240745, 1.283813, -0.001744},{
      1.239181, 1.280743, -0.001744},{1.239569, 1.280617, -0.003445}}],
    Polygon[{{1.240745, 1.283813, -0.001744},{1.240634, 1.283894, 0.000000},{
      1.239050, 1.280786, 0.000000},{1.239181, 1.280743, -0.001744}}],
    Polygon[{{1.240634, 1.283894, 0.000000},{1.240745, 1.283813, 0.001744},{
      1.239181, 1.280743, 0.001744},{1.239050, 1.280786, 0.000000}}],
    Polygon[{{1.240745, 1.283813, 0.001744},{1.241075, 1.283573, 0.003445},{
      1.239569, 1.280617, 0.003445},{1.239181, 1.280743, 0.001744}}],
    Polygon[{{1.241075, 1.283573, 0.003445},{1.241617, 1.283179, 0.005062},{
      1.240206, 1.280410, 0.005062},{1.239569, 1.280617, 0.003445}}],
    Polygon[{{1.241617, 1.283179, 0.005062},{1.242356, 1.282642, 0.006553},{
      1.241075, 1.280128, 0.006553},{1.240206, 1.280410, 0.005062}}],
    Polygon[{{1.242356, 1.282642, 0.006553},{1.243275, 1.281974, 0.007884},{
      1.242156, 1.279776, 0.007884},{1.241075, 1.280128, 0.006553}}],
    Polygon[{{1.243275, 1.281974, 0.007884},{1.244352, 1.281192, 0.009020},{
      1.243421, 1.279365, 0.009020},{1.242156, 1.279776, 0.007884}}],
    Polygon[{{1.244352, 1.281192, 0.009020},{1.245559, 1.280315, 0.009934},{
      1.244840, 1.278904, 0.009934},{1.243421, 1.279365, 0.009020}}],
    Polygon[{{1.245559, 1.280315, 0.009934},{1.246866, 1.279365, 0.010603},{
      1.246377, 1.278405, 0.010603},{1.244840, 1.278904, 0.009934}}],
    Polygon[{{1.246866, 1.279365, 0.010603},{1.248242, 1.278365, 0.011012},{
      1.247995, 1.277879, 0.011012},{1.246377, 1.278405, 0.010603}}],
    Polygon[{{1.247995, 1.277879, -0.011012},{1.246377, 1.278405, -0.010603},{
      1.246208, 1.277340, -0.010603},{1.247909, 1.277340, -0.011012}}],
    Polygon[{{1.246377, 1.278405, -0.010603},{1.244840, 1.278904, -0.009934},{
      1.244592, 1.277340, -0.009934},{1.246208, 1.277340, -0.010603}}],
    Polygon[{{1.244840, 1.278904, -0.009934},{1.243421, 1.279365, -0.009020},{
      1.243100, 1.277340, -0.009020},{1.244592, 1.277340, -0.009934}}],
    Polygon[{{1.243421, 1.279365, -0.009020},{1.242156, 1.279776, -0.007884},{
      1.241770, 1.277340, -0.007884},{1.243100, 1.277340, -0.009020}}],
    Polygon[{{1.242156, 1.279776, -0.007884},{1.241075, 1.280128, -0.006553},{
      1.240634, 1.277340, -0.006553},{1.241770, 1.277340, -0.007884}}],
    Polygon[{{1.241075, 1.280128, -0.006553},{1.240206, 1.280410, -0.005062},{
      1.239720, 1.277340, -0.005062},{1.240634, 1.277340, -0.006553}}],
    Polygon[{{1.240206, 1.280410, -0.005062},{1.239569, 1.280617, -0.003445},{
      1.239050, 1.277340, -0.003445},{1.239720, 1.277340, -0.005062}}],
    Polygon[{{1.239569, 1.280617, -0.003445},{1.239181, 1.280743, -0.001744},{
      1.238642, 1.277340, -0.001744},{1.239050, 1.277340, -0.003445}}],
    Polygon[{{1.239181, 1.280743, -0.001744},{1.239050, 1.280786, 0.000000},{
      1.238504, 1.277340, 0.000000},{1.238642, 1.277340, -0.001744}}],
    Polygon[{{1.239050, 1.280786, 0.000000},{1.239181, 1.280743, 0.001744},{
      1.238642, 1.277340, 0.001744},{1.238504, 1.277340, 0.000000}}],
    Polygon[{{1.239181, 1.280743, 0.001744},{1.239569, 1.280617, 0.003445},{
      1.239050, 1.277340, 0.003445},{1.238642, 1.277340, 0.001744}}],
    Polygon[{{1.239569, 1.280617, 0.003445},{1.240206, 1.280410, 0.005062},{
      1.239720, 1.277340, 0.005062},{1.239050, 1.277340, 0.003445}}],
    Polygon[{{1.240206, 1.280410, 0.005062},{1.241075, 1.280128, 0.006553},{
      1.240634, 1.277340, 0.006553},{1.239720, 1.277340, 0.005062}}],
    Polygon[{{1.241075, 1.280128, 0.006553},{1.242156, 1.279776, 0.007884},{
      1.241770, 1.277340, 0.007884},{1.240634, 1.277340, 0.006553}}],
    Polygon[{{1.242156, 1.279776, 0.007884},{1.243421, 1.279365, 0.009020},{
      1.243100, 1.277340, 0.009020},{1.241770, 1.277340, 0.007884}}],
    Polygon[{{1.243421, 1.279365, 0.009020},{1.244840, 1.278904, 0.009934},{
      1.244592, 1.277340, 0.009934},{1.243100, 1.277340, 0.009020}}],
    Polygon[{{1.244840, 1.278904, 0.009934},{1.246377, 1.278405, 0.010603},{
      1.246208, 1.277340, 0.010603},{1.244592, 1.277340, 0.009934}}],
    Polygon[{{1.246377, 1.278405, 0.010603},{1.247995, 1.277879, 0.011012},{
      1.247909, 1.277340, 0.011012},{1.246208, 1.277340, 0.010603}}],
    Polygon[{{1.247909, 1.277340, -0.011012},{1.246208, 1.277340, -0.010603},{
      1.246377, 1.276276, -0.010603},{1.247995, 1.276801, -0.011012}}],
    Polygon[{{1.246208, 1.277340, -0.010603},{1.244592, 1.277340, -0.009934},{
      1.244840, 1.275776, -0.009934},{1.246377, 1.276276, -0.010603}}],
    Polygon[{{1.244592, 1.277340, -0.009934},{1.243100, 1.277340, -0.009020},{
      1.243421, 1.275315, -0.009020},{1.244840, 1.275776, -0.009934}}],
    Polygon[{{1.243100, 1.277340, -0.009020},{1.241770, 1.277340, -0.007884},{
      1.242156, 1.274904, -0.007884},{1.243421, 1.275315, -0.009020}}],
    Polygon[{{1.241770, 1.277340, -0.007884},{1.240634, 1.277340, -0.006553},{
      1.241075, 1.274553, -0.006553},{1.242156, 1.274904, -0.007884}}],
    Polygon[{{1.240634, 1.277340, -0.006553},{1.239720, 1.277340, -0.005062},{
      1.240206, 1.274271, -0.005062},{1.241075, 1.274553, -0.006553}}],
    Polygon[{{1.239720, 1.277340, -0.005062},{1.239050, 1.277340, -0.003445},{
      1.239569, 1.274064, -0.003445},{1.240206, 1.274271, -0.005062}}],
    Polygon[{{1.239050, 1.277340, -0.003445},{1.238642, 1.277340, -0.001744},{
      1.239181, 1.273937, -0.001744},{1.239569, 1.274064, -0.003445}}],
    Polygon[{{1.238642, 1.277340, -0.001744},{1.238504, 1.277340, 0.000000},{
      1.239050, 1.273895, 0.000000},{1.239181, 1.273937, -0.001744}}],
    Polygon[{{1.238504, 1.277340, 0.000000},{1.238642, 1.277340, 0.001744},{
      1.239181, 1.273937, 0.001744},{1.239050, 1.273895, 0.000000}}],
    Polygon[{{1.238642, 1.277340, 0.001744},{1.239050, 1.277340, 0.003445},{
      1.239569, 1.274064, 0.003445},{1.239181, 1.273937, 0.001744}}],
    Polygon[{{1.239050, 1.277340, 0.003445},{1.239720, 1.277340, 0.005062},{
      1.240206, 1.274271, 0.005062},{1.239569, 1.274064, 0.003445}}],
    Polygon[{{1.239720, 1.277340, 0.005062},{1.240634, 1.277340, 0.006553},{
      1.241075, 1.274553, 0.006553},{1.240206, 1.274271, 0.005062}}],
    Polygon[{{1.240634, 1.277340, 0.006553},{1.241770, 1.277340, 0.007884},{
      1.242156, 1.274904, 0.007884},{1.241075, 1.274553, 0.006553}}],
    Polygon[{{1.241770, 1.277340, 0.007884},{1.243100, 1.277340, 0.009020},{
      1.243421, 1.275315, 0.009020},{1.242156, 1.274904, 0.007884}}],
    Polygon[{{1.243100, 1.277340, 0.009020},{1.244592, 1.277340, 0.009934},{
      1.244840, 1.275776, 0.009934},{1.243421, 1.275315, 0.009020}}],
    Polygon[{{1.244592, 1.277340, 0.009934},{1.246208, 1.277340, 0.010603},{
      1.246377, 1.276276, 0.010603},{1.244840, 1.275776, 0.009934}}],
    Polygon[{{1.246208, 1.277340, 0.010603},{1.247909, 1.277340, 0.011012},{
      1.247995, 1.276801, 0.011012},{1.246377, 1.276276, 0.010603}}],
    Polygon[{{1.247995, 1.276801, -0.011012},{1.246377, 1.276276, -0.010603},{
      1.246866, 1.275315, -0.010603},{1.248242, 1.276315, -0.011012}}],
    Polygon[{{1.246377, 1.276276, -0.010603},{1.244840, 1.275776, -0.009934},{
      1.245559, 1.274365, -0.009934},{1.246866, 1.275315, -0.010603}}],
    Polygon[{{1.244840, 1.275776, -0.009934},{1.243421, 1.275315, -0.009020},{
      1.244352, 1.273488, -0.009020},{1.245559, 1.274365, -0.009934}}],
    Polygon[{{1.243421, 1.275315, -0.009020},{1.242156, 1.274904, -0.007884},{
      1.243275, 1.272707, -0.007884},{1.244352, 1.273488, -0.009020}}],
    Polygon[{{1.242156, 1.274904, -0.007884},{1.241075, 1.274553, -0.006553},{
      1.242356, 1.272039, -0.006553},{1.243275, 1.272707, -0.007884}}],
    Polygon[{{1.241075, 1.274553, -0.006553},{1.240206, 1.274271, -0.005062},{
      1.241617, 1.271501, -0.005062},{1.242356, 1.272039, -0.006553}}],
    Polygon[{{1.240206, 1.274271, -0.005062},{1.239569, 1.274064, -0.003445},{
      1.241075, 1.271108, -0.003445},{1.241617, 1.271501, -0.005062}}],
    Polygon[{{1.239569, 1.274064, -0.003445},{1.239181, 1.273937, -0.001744},{
      1.240745, 1.270868, -0.001744},{1.241075, 1.271108, -0.003445}}],
    Polygon[{{1.239181, 1.273937, -0.001744},{1.239050, 1.273895, 0.000000},{
      1.240634, 1.270787, 0.000000},{1.240745, 1.270868, -0.001744}}],
    Polygon[{{1.239050, 1.273895, 0.000000},{1.239181, 1.273937, 0.001744},{
      1.240745, 1.270868, 0.001744},{1.240634, 1.270787, 0.000000}}],
    Polygon[{{1.239181, 1.273937, 0.001744},{1.239569, 1.274064, 0.003445},{
      1.241075, 1.271108, 0.003445},{1.240745, 1.270868, 0.001744}}],
    Polygon[{{1.239569, 1.274064, 0.003445},{1.240206, 1.274271, 0.005062},{
      1.241617, 1.271501, 0.005062},{1.241075, 1.271108, 0.003445}}],
    Polygon[{{1.240206, 1.274271, 0.005062},{1.241075, 1.274553, 0.006553},{
      1.242356, 1.272039, 0.006553},{1.241617, 1.271501, 0.005062}}],
    Polygon[{{1.241075, 1.274553, 0.006553},{1.242156, 1.274904, 0.007884},{
      1.243275, 1.272707, 0.007884},{1.242356, 1.272039, 0.006553}}],
    Polygon[{{1.242156, 1.274904, 0.007884},{1.243421, 1.275315, 0.009020},{
      1.244352, 1.273488, 0.009020},{1.243275, 1.272707, 0.007884}}],
    Polygon[{{1.243421, 1.275315, 0.009020},{1.244840, 1.275776, 0.009934},{
      1.245559, 1.274365, 0.009934},{1.244352, 1.273488, 0.009020}}],
    Polygon[{{1.244840, 1.275776, 0.009934},{1.246377, 1.276276, 0.010603},{
      1.246866, 1.275315, 0.010603},{1.245559, 1.274365, 0.009934}}],
    Polygon[{{1.246377, 1.276276, 0.010603},{1.247995, 1.276801, 0.011012},{
      1.248242, 1.276315, 0.011012},{1.246866, 1.275315, 0.010603}}],
    Polygon[{{1.248242, 1.276315, -0.011012},{1.246866, 1.275315, -0.010603},{
      1.247628, 1.274553, -0.010603},{1.248628, 1.275929, -0.011012}}],
    Polygon[{{1.246866, 1.275315, -0.010603},{1.245559, 1.274365, -0.009934},{
      1.246678, 1.273245, -0.009934},{1.247628, 1.274553, -0.010603}}],
    Polygon[{{1.245559, 1.274365, -0.009934},{1.244352, 1.273488, -0.009020},{
      1.245801, 1.272039, -0.009020},{1.246678, 1.273245, -0.009934}}],
    Polygon[{{1.244352, 1.273488, -0.009020},{1.243275, 1.272707, -0.007884},{
      1.245020, 1.270962, -0.007884},{1.245801, 1.272039, -0.009020}}],
    Polygon[{{1.243275, 1.272707, -0.007884},{1.242356, 1.272039, -0.006553},{
      1.244352, 1.270043, -0.006553},{1.245020, 1.270962, -0.007884}}],
    Polygon[{{1.242356, 1.272039, -0.006553},{1.241617, 1.271501, -0.005062},{
      1.243814, 1.269304, -0.005062},{1.244352, 1.270043, -0.006553}}],
    Polygon[{{1.241617, 1.271501, -0.005062},{1.241075, 1.271108, -0.003445},{
      1.243421, 1.268762, -0.003445},{1.243814, 1.269304, -0.005062}}],
    Polygon[{{1.241075, 1.271108, -0.003445},{1.240745, 1.270868, -0.001744},{
      1.243181, 1.268432, -0.001744},{1.243421, 1.268762, -0.003445}}],
    Polygon[{{1.240745, 1.270868, -0.001744},{1.240634, 1.270787, 0.000000},{
      1.243100, 1.268321, 0.000000},{1.243181, 1.268432, -0.001744}}],
    Polygon[{{1.240634, 1.270787, 0.000000},{1.240745, 1.270868, 0.001744},{
      1.243181, 1.268432, 0.001744},{1.243100, 1.268321, 0.000000}}],
    Polygon[{{1.240745, 1.270868, 0.001744},{1.241075, 1.271108, 0.003445},{
      1.243421, 1.268762, 0.003445},{1.243181, 1.268432, 0.001744}}],
    Polygon[{{1.241075, 1.271108, 0.003445},{1.241617, 1.271501, 0.005062},{
      1.243814, 1.269304, 0.005062},{1.243421, 1.268762, 0.003445}}],
    Polygon[{{1.241617, 1.271501, 0.005062},{1.242356, 1.272039, 0.006553},{
      1.244352, 1.270043, 0.006553},{1.243814, 1.269304, 0.005062}}],
    Polygon[{{1.242356, 1.272039, 0.006553},{1.243275, 1.272707, 0.007884},{
      1.245020, 1.270962, 0.007884},{1.244352, 1.270043, 0.006553}}],
    Polygon[{{1.243275, 1.272707, 0.007884},{1.244352, 1.273488, 0.009020},{
      1.245801, 1.272039, 0.009020},{1.245020, 1.270962, 0.007884}}],
    Polygon[{{1.244352, 1.273488, 0.009020},{1.245559, 1.274365, 0.009934},{
      1.246678, 1.273245, 0.009934},{1.245801, 1.272039, 0.009020}}],
    Polygon[{{1.245559, 1.274365, 0.009934},{1.246866, 1.275315, 0.010603},{
      1.247628, 1.274553, 0.010603},{1.246678, 1.273245, 0.009934}}],
    Polygon[{{1.246866, 1.275315, 0.010603},{1.248242, 1.276315, 0.011012},{
      1.248628, 1.275929, 0.011012},{1.247628, 1.274553, 0.010603}}],
    Polygon[{{1.248628, 1.275929, -0.011012},{1.247628, 1.274553, -0.010603},{
      1.248589, 1.274064, -0.010603},{1.249114, 1.275682, -0.011012}}],
    Polygon[{{1.247628, 1.274553, -0.010603},{1.246678, 1.273245, -0.009934},{
      1.248089, 1.272527, -0.009934},{1.248589, 1.274064, -0.010603}}],
    Polygon[{{1.246678, 1.273245, -0.009934},{1.245801, 1.272039, -0.009020},{
      1.247628, 1.271108, -0.009020},{1.248089, 1.272527, -0.009934}}],
    Polygon[{{1.245801, 1.272039, -0.009020},{1.245020, 1.270962, -0.007884},{
      1.247217, 1.269843, -0.007884},{1.247628, 1.271108, -0.009020}}],
    Polygon[{{1.245020, 1.270962, -0.007884},{1.244352, 1.270043, -0.006553},{
      1.246866, 1.268762, -0.006553},{1.247217, 1.269843, -0.007884}}],
    Polygon[{{1.244352, 1.270043, -0.006553},{1.243814, 1.269304, -0.005062},{
      1.246584, 1.267893, -0.005062},{1.246866, 1.268762, -0.006553}}],
    Polygon[{{1.243814, 1.269304, -0.005062},{1.243421, 1.268762, -0.003445},{
      1.246377, 1.267256, -0.003445},{1.246584, 1.267893, -0.005062}}],
    Polygon[{{1.243421, 1.268762, -0.003445},{1.243181, 1.268432, -0.001744},{
      1.246251, 1.266868, -0.001744},{1.246377, 1.267256, -0.003445}}],
    Polygon[{{1.243181, 1.268432, -0.001744},{1.243100, 1.268321, 0.000000},{
      1.246208, 1.266737, 0.000000},{1.246251, 1.266868, -0.001744}}],
    Polygon[{{1.243100, 1.268321, 0.000000},{1.243181, 1.268432, 0.001744},{
      1.246251, 1.266868, 0.001744},{1.246208, 1.266737, 0.000000}}],
    Polygon[{{1.243181, 1.268432, 0.001744},{1.243421, 1.268762, 0.003445},{
      1.246377, 1.267256, 0.003445},{1.246251, 1.266868, 0.001744}}],
    Polygon[{{1.243421, 1.268762, 0.003445},{1.243814, 1.269304, 0.005062},{
      1.246584, 1.267893, 0.005062},{1.246377, 1.267256, 0.003445}}],
    Polygon[{{1.243814, 1.269304, 0.005062},{1.244352, 1.270043, 0.006553},{
      1.246866, 1.268762, 0.006553},{1.246584, 1.267893, 0.005062}}],
    Polygon[{{1.244352, 1.270043, 0.006553},{1.245020, 1.270962, 0.007884},{
      1.247217, 1.269843, 0.007884},{1.246866, 1.268762, 0.006553}}],
    Polygon[{{1.245020, 1.270962, 0.007884},{1.245801, 1.272039, 0.009020},{
      1.247628, 1.271108, 0.009020},{1.247217, 1.269843, 0.007884}}],
    Polygon[{{1.245801, 1.272039, 0.009020},{1.246678, 1.273245, 0.009934},{
      1.248089, 1.272527, 0.009934},{1.247628, 1.271108, 0.009020}}],
    Polygon[{{1.246678, 1.273245, 0.009934},{1.247628, 1.274553, 0.010603},{
      1.248589, 1.274064, 0.010603},{1.248089, 1.272527, 0.009934}}],
    Polygon[{{1.247628, 1.274553, 0.010603},{1.248628, 1.275929, 0.011012},{
      1.249114, 1.275682, 0.011012},{1.248589, 1.274064, 0.010603}}],
    Polygon[{{1.249114, 1.275682, -0.011012},{1.248589, 1.274064, -0.010603},{
      1.249653, 1.273895, -0.010603},{1.249653, 1.275596, -0.011012}}],
    Polygon[{{1.248589, 1.274064, -0.010603},{1.248089, 1.272527, -0.009934},{
      1.249653, 1.272279, -0.009934},{1.249653, 1.273895, -0.010603}}],
    Polygon[{{1.248089, 1.272527, -0.009934},{1.247628, 1.271108, -0.009020},{
      1.249653, 1.270787, -0.009020},{1.249653, 1.272279, -0.009934}}],
    Polygon[{{1.247628, 1.271108, -0.009020},{1.247217, 1.269843, -0.007884},{
      1.249653, 1.269457, -0.007884},{1.249653, 1.270787, -0.009020}}],
    Polygon[{{1.247217, 1.269843, -0.007884},{1.246866, 1.268762, -0.006553},{
      1.249653, 1.268321, -0.006553},{1.249653, 1.269457, -0.007884}}],
    Polygon[{{1.246866, 1.268762, -0.006553},{1.246584, 1.267893, -0.005062},{
      1.249653, 1.267406, -0.005062},{1.249653, 1.268321, -0.006553}}],
    Polygon[{{1.246584, 1.267893, -0.005062},{1.246377, 1.267256, -0.003445},{
      1.249653, 1.266737, -0.003445},{1.249653, 1.267406, -0.005062}}],
    Polygon[{{1.246377, 1.267256, -0.003445},{1.246251, 1.266868, -0.001744},{
      1.249653, 1.266328, -0.001744},{1.249653, 1.266737, -0.003445}}],
    Polygon[{{1.246251, 1.266868, -0.001744},{1.246208, 1.266737, 0.000000},{
      1.249653, 1.266191, 0.000000},{1.249653, 1.266328, -0.001744}}],
    Polygon[{{1.246208, 1.266737, 0.000000},{1.246251, 1.266868, 0.001744},{
      1.249653, 1.266328, 0.001744},{1.249653, 1.266191, 0.000000}}],
    Polygon[{{1.246251, 1.266868, 0.001744},{1.246377, 1.267256, 0.003445},{
      1.249653, 1.266737, 0.003445},{1.249653, 1.266328, 0.001744}}],
    Polygon[{{1.246377, 1.267256, 0.003445},{1.246584, 1.267893, 0.005062},{
      1.249653, 1.267406, 0.005062},{1.249653, 1.266737, 0.003445}}],
    Polygon[{{1.246584, 1.267893, 0.005062},{1.246866, 1.268762, 0.006553},{
      1.249653, 1.268321, 0.006553},{1.249653, 1.267406, 0.005062}}],
    Polygon[{{1.246866, 1.268762, 0.006553},{1.247217, 1.269843, 0.007884},{
      1.249653, 1.269457, 0.007884},{1.249653, 1.268321, 0.006553}}],
    Polygon[{{1.247217, 1.269843, 0.007884},{1.247628, 1.271108, 0.009020},{
      1.249653, 1.270787, 0.009020},{1.249653, 1.269457, 0.007884}}],
    Polygon[{{1.247628, 1.271108, 0.009020},{1.248089, 1.272527, 0.009934},{
      1.249653, 1.272279, 0.009934},{1.249653, 1.270787, 0.009020}}],
    Polygon[{{1.248089, 1.272527, 0.009934},{1.248589, 1.274064, 0.010603},{
      1.249653, 1.273895, 0.010603},{1.249653, 1.272279, 0.009934}}],
    Polygon[{{1.248589, 1.274064, 0.010603},{1.249114, 1.275682, 0.011012},{
      1.249653, 1.275596, 0.011012},{1.249653, 1.273895, 0.010603}}],
    Polygon[{{1.249653, 1.275596, -0.011012},{1.249653, 1.273895, -0.010603},{
      1.250718, 1.274064, -0.010603},{1.250192, 1.275682, -0.011012}}],
    Polygon[{{1.249653, 1.273895, -0.010603},{1.249653, 1.272279, -0.009934},{
      1.251217, 1.272527, -0.009934},{1.250718, 1.274064, -0.010603}}],
    Polygon[{{1.249653, 1.272279, -0.009934},{1.249653, 1.270787, -0.009020},{
      1.251678, 1.271108, -0.009020},{1.251217, 1.272527, -0.009934}}],
    Polygon[{{1.249653, 1.270787, -0.009020},{1.249653, 1.269457, -0.007884},{
      1.252090, 1.269843, -0.007884},{1.251678, 1.271108, -0.009020}}],
    Polygon[{{1.249653, 1.269457, -0.007884},{1.249653, 1.268321, -0.006553},{
      1.252441, 1.268762, -0.006553},{1.252090, 1.269843, -0.007884}}],
    Polygon[{{1.249653, 1.268321, -0.006553},{1.249653, 1.267406, -0.005062},{
      1.252723, 1.267893, -0.005062},{1.252441, 1.268762, -0.006553}}],
    Polygon[{{1.249653, 1.267406, -0.005062},{1.249653, 1.266737, -0.003445},{
      1.252930, 1.267256, -0.003445},{1.252723, 1.267893, -0.005062}}],
    Polygon[{{1.249653, 1.266737, -0.003445},{1.249653, 1.266328, -0.001744},{
      1.253056, 1.266868, -0.001744},{1.252930, 1.267256, -0.003445}}],
    Polygon[{{1.249653, 1.266328, -0.001744},{1.249653, 1.266191, 0.000000},{
      1.253099, 1.266737, 0.000000},{1.253056, 1.266868, -0.001744}}],
    Polygon[{{1.249653, 1.266191, 0.000000},{1.249653, 1.266328, 0.001744},{
      1.253056, 1.266868, 0.001744},{1.253099, 1.266737, 0.000000}}],
    Polygon[{{1.249653, 1.266328, 0.001744},{1.249653, 1.266737, 0.003445},{
      1.252930, 1.267256, 0.003445},{1.253056, 1.266868, 0.001744}}],
    Polygon[{{1.249653, 1.266737, 0.003445},{1.249653, 1.267406, 0.005062},{
      1.252723, 1.267893, 0.005062},{1.252930, 1.267256, 0.003445}}],
    Polygon[{{1.249653, 1.267406, 0.005062},{1.249653, 1.268321, 0.006553},{
      1.252441, 1.268762, 0.006553},{1.252723, 1.267893, 0.005062}}],
    Polygon[{{1.249653, 1.268321, 0.006553},{1.249653, 1.269457, 0.007884},{
      1.252090, 1.269843, 0.007884},{1.252441, 1.268762, 0.006553}}],
    Polygon[{{1.249653, 1.269457, 0.007884},{1.249653, 1.270787, 0.009020},{
      1.251678, 1.271108, 0.009020},{1.252090, 1.269843, 0.007884}}],
    Polygon[{{1.249653, 1.270787, 0.009020},{1.249653, 1.272279, 0.009934},{
      1.251217, 1.272527, 0.009934},{1.251678, 1.271108, 0.009020}}],
    Polygon[{{1.249653, 1.272279, 0.009934},{1.249653, 1.273895, 0.010603},{
      1.250718, 1.274064, 0.010603},{1.251217, 1.272527, 0.009934}}],
    Polygon[{{1.249653, 1.273895, 0.010603},{1.249653, 1.275596, 0.011012},{
      1.250192, 1.275682, 0.011012},{1.250718, 1.274064, 0.010603}}],
    Polygon[{{1.250192, 1.275682, -0.011012},{1.250718, 1.274064, -0.010603},{
      1.251678, 1.274553, -0.010603},{1.250679, 1.275929, -0.011012}}],
    Polygon[{{1.250718, 1.274064, -0.010603},{1.251217, 1.272527, -0.009934},{
      1.252628, 1.273245, -0.009934},{1.251678, 1.274553, -0.010603}}],
    Polygon[{{1.251217, 1.272527, -0.009934},{1.251678, 1.271108, -0.009020},{
      1.253505, 1.272039, -0.009020},{1.252628, 1.273245, -0.009934}}],
    Polygon[{{1.251678, 1.271108, -0.009020},{1.252090, 1.269843, -0.007884},{
      1.254287, 1.270962, -0.007884},{1.253505, 1.272039, -0.009020}}],
    Polygon[{{1.252090, 1.269843, -0.007884},{1.252441, 1.268762, -0.006553},{
      1.254955, 1.270043, -0.006553},{1.254287, 1.270962, -0.007884}}],
    Polygon[{{1.252441, 1.268762, -0.006553},{1.252723, 1.267893, -0.005062},{
      1.255492, 1.269304, -0.005062},{1.254955, 1.270043, -0.006553}}],
    Polygon[{{1.252723, 1.267893, -0.005062},{1.252930, 1.267256, -0.003445},{
      1.255886, 1.268762, -0.003445},{1.255492, 1.269304, -0.005062}}],
    Polygon[{{1.252930, 1.267256, -0.003445},{1.253056, 1.266868, -0.001744},{
      1.256126, 1.268432, -0.001744},{1.255886, 1.268762, -0.003445}}],
    Polygon[{{1.253056, 1.266868, -0.001744},{1.253099, 1.266737, 0.000000},{
      1.256207, 1.268321, 0.000000},{1.256126, 1.268432, -0.001744}}],
    Polygon[{{1.253099, 1.266737, 0.000000},{1.253056, 1.266868, 0.001744},{
      1.256126, 1.268432, 0.001744},{1.256207, 1.268321, 0.000000}}],
    Polygon[{{1.253056, 1.266868, 0.001744},{1.252930, 1.267256, 0.003445},{
      1.255886, 1.268762, 0.003445},{1.256126, 1.268432, 0.001744}}],
    Polygon[{{1.252930, 1.267256, 0.003445},{1.252723, 1.267893, 0.005062},{
      1.255492, 1.269304, 0.005062},{1.255886, 1.268762, 0.003445}}],
    Polygon[{{1.252723, 1.267893, 0.005062},{1.252441, 1.268762, 0.006553},{
      1.254955, 1.270043, 0.006553},{1.255492, 1.269304, 0.005062}}],
    Polygon[{{1.252441, 1.268762, 0.006553},{1.252090, 1.269843, 0.007884},{
      1.254287, 1.270962, 0.007884},{1.254955, 1.270043, 0.006553}}],
    Polygon[{{1.252090, 1.269843, 0.007884},{1.251678, 1.271108, 0.009020},{
      1.253505, 1.272039, 0.009020},{1.254287, 1.270962, 0.007884}}],
    Polygon[{{1.251678, 1.271108, 0.009020},{1.251217, 1.272527, 0.009934},{
      1.252628, 1.273245, 0.009934},{1.253505, 1.272039, 0.009020}}],
    Polygon[{{1.251217, 1.272527, 0.009934},{1.250718, 1.274064, 0.010603},{
      1.251678, 1.274553, 0.010603},{1.252628, 1.273245, 0.009934}}],
    Polygon[{{1.250718, 1.274064, 0.010603},{1.250192, 1.275682, 0.011012},{
      1.250679, 1.275929, 0.011012},{1.251678, 1.274553, 0.010603}}],
    Polygon[{{1.250679, 1.275929, -0.011012},{1.251678, 1.274553, -0.010603},{
      1.252441, 1.275315, -0.010603},{1.251064, 1.276315, -0.011012}}],
    Polygon[{{1.251678, 1.274553, -0.010603},{1.252628, 1.273245, -0.009934},{
      1.253748, 1.274365, -0.009934},{1.252441, 1.275315, -0.010603}}],
    Polygon[{{1.252628, 1.273245, -0.009934},{1.253505, 1.272039, -0.009020},{
      1.254955, 1.273488, -0.009020},{1.253748, 1.274365, -0.009934}}],
    Polygon[{{1.253505, 1.272039, -0.009020},{1.254287, 1.270962, -0.007884},{
      1.256031, 1.272707, -0.007884},{1.254955, 1.273488, -0.009020}}],
    Polygon[{{1.254287, 1.270962, -0.007884},{1.254955, 1.270043, -0.006553},{
      1.256950, 1.272039, -0.006553},{1.256031, 1.272707, -0.007884}}],
    Polygon[{{1.254955, 1.270043, -0.006553},{1.255492, 1.269304, -0.005062},{
      1.257690, 1.271501, -0.005062},{1.256950, 1.272039, -0.006553}}],
    Polygon[{{1.255492, 1.269304, -0.005062},{1.255886, 1.268762, -0.003445},{
      1.258232, 1.271108, -0.003445},{1.257690, 1.271501, -0.005062}}],
    Polygon[{{1.255886, 1.268762, -0.003445},{1.256126, 1.268432, -0.001744},{
      1.258562, 1.270868, -0.001744},{1.258232, 1.271108, -0.003445}}],
    Polygon[{{1.256126, 1.268432, -0.001744},{1.256207, 1.268321, 0.000000},{
      1.258673, 1.270787, 0.000000},{1.258562, 1.270868, -0.001744}}],
    Polygon[{{1.256207, 1.268321, 0.000000},{1.256126, 1.268432, 0.001744},{
      1.258562, 1.270868, 0.001744},{1.258673, 1.270787, 0.000000}}],
    Polygon[{{1.256126, 1.268432, 0.001744},{1.255886, 1.268762, 0.003445},{
      1.258232, 1.271108, 0.003445},{1.258562, 1.270868, 0.001744}}],
    Polygon[{{1.255886, 1.268762, 0.003445},{1.255492, 1.269304, 0.005062},{
      1.257690, 1.271501, 0.005062},{1.258232, 1.271108, 0.003445}}],
    Polygon[{{1.255492, 1.269304, 0.005062},{1.254955, 1.270043, 0.006553},{
      1.256950, 1.272039, 0.006553},{1.257690, 1.271501, 0.005062}}],
    Polygon[{{1.254955, 1.270043, 0.006553},{1.254287, 1.270962, 0.007884},{
      1.256031, 1.272707, 0.007884},{1.256950, 1.272039, 0.006553}}],
    Polygon[{{1.254287, 1.270962, 0.007884},{1.253505, 1.272039, 0.009020},{
      1.254955, 1.273488, 0.009020},{1.256031, 1.272707, 0.007884}}],
    Polygon[{{1.253505, 1.272039, 0.009020},{1.252628, 1.273245, 0.009934},{
      1.253748, 1.274365, 0.009934},{1.254955, 1.273488, 0.009020}}],
    Polygon[{{1.252628, 1.273245, 0.009934},{1.251678, 1.274553, 0.010603},{
      1.252441, 1.275315, 0.010603},{1.253748, 1.274365, 0.009934}}],
    Polygon[{{1.251678, 1.274553, 0.010603},{1.250679, 1.275929, 0.011012},{
      1.251064, 1.276315, 0.011012},{1.252441, 1.275315, 0.010603}}],
    Polygon[{{1.251064, 1.276315, -0.011012},{1.252441, 1.275315, -0.010603},{
      1.252930, 1.276276, -0.010603},{1.251312, 1.276801, -0.011012}}],
    Polygon[{{1.252441, 1.275315, -0.010603},{1.253748, 1.274365, -0.009934},{
      1.254467, 1.275776, -0.009934},{1.252930, 1.276276, -0.010603}}],
    Polygon[{{1.253748, 1.274365, -0.009934},{1.254955, 1.273488, -0.009020},{
      1.255886, 1.275315, -0.009020},{1.254467, 1.275776, -0.009934}}],
    Polygon[{{1.254955, 1.273488, -0.009020},{1.256031, 1.272707, -0.007884},{
      1.257151, 1.274904, -0.007884},{1.255886, 1.275315, -0.009020}}],
    Polygon[{{1.256031, 1.272707, -0.007884},{1.256950, 1.272039, -0.006553},{
      1.258232, 1.274553, -0.006553},{1.257151, 1.274904, -0.007884}}],
    Polygon[{{1.256950, 1.272039, -0.006553},{1.257690, 1.271501, -0.005062},{
      1.259101, 1.274271, -0.005062},{1.258232, 1.274553, -0.006553}}],
    Polygon[{{1.257690, 1.271501, -0.005062},{1.258232, 1.271108, -0.003445},{
      1.259738, 1.274064, -0.003445},{1.259101, 1.274271, -0.005062}}],
    Polygon[{{1.258232, 1.271108, -0.003445},{1.258562, 1.270868, -0.001744},{
      1.260126, 1.273937, -0.001744},{1.259738, 1.274064, -0.003445}}],
    Polygon[{{1.258562, 1.270868, -0.001744},{1.258673, 1.270787, 0.000000},{
      1.260257, 1.273895, 0.000000},{1.260126, 1.273937, -0.001744}}],
    Polygon[{{1.258673, 1.270787, 0.000000},{1.258562, 1.270868, 0.001744},{
      1.260126, 1.273937, 0.001744},{1.260257, 1.273895, 0.000000}}],
    Polygon[{{1.258562, 1.270868, 0.001744},{1.258232, 1.271108, 0.003445},{
      1.259738, 1.274064, 0.003445},{1.260126, 1.273937, 0.001744}}],
    Polygon[{{1.258232, 1.271108, 0.003445},{1.257690, 1.271501, 0.005062},{
      1.259101, 1.274271, 0.005062},{1.259738, 1.274064, 0.003445}}],
    Polygon[{{1.257690, 1.271501, 0.005062},{1.256950, 1.272039, 0.006553},{
      1.258232, 1.274553, 0.006553},{1.259101, 1.274271, 0.005062}}],
    Polygon[{{1.256950, 1.272039, 0.006553},{1.256031, 1.272707, 0.007884},{
      1.257151, 1.274904, 0.007884},{1.258232, 1.274553, 0.006553}}],
    Polygon[{{1.256031, 1.272707, 0.007884},{1.254955, 1.273488, 0.009020},{
      1.255886, 1.275315, 0.009020},{1.257151, 1.274904, 0.007884}}],
    Polygon[{{1.254955, 1.273488, 0.009020},{1.253748, 1.274365, 0.009934},{
      1.254467, 1.275776, 0.009934},{1.255886, 1.275315, 0.009020}}],
    Polygon[{{1.253748, 1.274365, 0.009934},{1.252441, 1.275315, 0.010603},{
      1.252930, 1.276276, 0.010603},{1.254467, 1.275776, 0.009934}}],
    Polygon[{{1.252441, 1.275315, 0.010603},{1.251064, 1.276315, 0.011012},{
      1.251312, 1.276801, 0.011012},{1.252930, 1.276276, 0.010603}}],
    Polygon[{{1.251312, 1.276801, -0.011012},{1.252930, 1.276276, -0.010603},{
      1.253099, 1.277340, -0.010603},{1.251397, 1.277340, -0.011012}}],
    Polygon[{{1.252930, 1.276276, -0.010603},{1.254467, 1.275776, -0.009934},{
      1.254715, 1.277340, -0.009934},{1.253099, 1.277340, -0.010603}}],
    Polygon[{{1.254467, 1.275776, -0.009934},{1.255886, 1.275315, -0.009020},{
      1.256207, 1.277340, -0.009020},{1.254715, 1.277340, -0.009934}}],
    Polygon[{{1.255886, 1.275315, -0.009020},{1.257151, 1.274904, -0.007884},{
      1.257537, 1.277340, -0.007884},{1.256207, 1.277340, -0.009020}}],
    Polygon[{{1.257151, 1.274904, -0.007884},{1.258232, 1.274553, -0.006553},{
      1.258673, 1.277340, -0.006553},{1.257537, 1.277340, -0.007884}}],
    Polygon[{{1.258232, 1.274553, -0.006553},{1.259101, 1.274271, -0.005062},{
      1.259587, 1.277340, -0.005062},{1.258673, 1.277340, -0.006553}}],
    Polygon[{{1.259101, 1.274271, -0.005062},{1.259738, 1.274064, -0.003445},{
      1.260257, 1.277340, -0.003445},{1.259587, 1.277340, -0.005062}}],
    Polygon[{{1.259738, 1.274064, -0.003445},{1.260126, 1.273937, -0.001744},{
      1.260665, 1.277340, -0.001744},{1.260257, 1.277340, -0.003445}}],
    Polygon[{{1.260126, 1.273937, -0.001744},{1.260257, 1.273895, 0.000000},{
      1.260803, 1.277340, 0.000000},{1.260665, 1.277340, -0.001744}}],
    Polygon[{{1.260257, 1.273895, 0.000000},{1.260126, 1.273937, 0.001744},{
      1.260665, 1.277340, 0.001744},{1.260803, 1.277340, 0.000000}}],
    Polygon[{{1.260126, 1.273937, 0.001744},{1.259738, 1.274064, 0.003445},{
      1.260257, 1.277340, 0.003445},{1.260665, 1.277340, 0.001744}}],
    Polygon[{{1.259738, 1.274064, 0.003445},{1.259101, 1.274271, 0.005062},{
      1.259587, 1.277340, 0.005062},{1.260257, 1.277340, 0.003445}}],
    Polygon[{{1.259101, 1.274271, 0.005062},{1.258232, 1.274553, 0.006553},{
      1.258673, 1.277340, 0.006553},{1.259587, 1.277340, 0.005062}}],
    Polygon[{{1.258232, 1.274553, 0.006553},{1.257151, 1.274904, 0.007884},{
      1.257537, 1.277340, 0.007884},{1.258673, 1.277340, 0.006553}}],
    Polygon[{{1.257151, 1.274904, 0.007884},{1.255886, 1.275315, 0.009020},{
      1.256207, 1.277340, 0.009020},{1.257537, 1.277340, 0.007884}}],
    Polygon[{{1.255886, 1.275315, 0.009020},{1.254467, 1.275776, 0.009934},{
      1.254715, 1.277340, 0.009934},{1.256207, 1.277340, 0.009020}}],
    Polygon[{{1.254467, 1.275776, 0.009934},{1.252930, 1.276276, 0.010603},{
      1.253099, 1.277340, 0.010603},{1.254715, 1.277340, 0.009934}}],
    Polygon[{{1.252930, 1.276276, 0.010603},{1.251312, 1.276801, 0.011012},{
      1.251397, 1.277340, 0.011012},{1.253099, 1.277340, 0.010603}}],
    Polygon[{{1.189497, 1.273429, -0.009381},{1.190947, 1.273429, -0.009033},{
      1.190803, 1.274336, -0.009033},{1.189425, 1.273888, -0.009381}}],
    Polygon[{{1.190947, 1.273429, -0.009033},{1.192324, 1.273429, -0.008463},{
      1.192113, 1.274762, -0.008463},{1.190803, 1.274336, -0.009033}}],
    Polygon[{{1.192324, 1.273429, -0.008463},{1.193594, 1.273429, -0.007684},{
      1.193321, 1.275154, -0.007684},{1.192113, 1.274762, -0.008463}}],
    Polygon[{{1.193594, 1.273429, -0.007684},{1.194728, 1.273429, -0.006716},{
      1.194399, 1.275505, -0.006716},{1.193321, 1.275154, -0.007684}}],
    Polygon[{{1.194728, 1.273429, -0.006716},{1.195696, 1.273429, -0.005583},{
      1.195320, 1.275804, -0.005583},{1.194399, 1.275505, -0.006716}}],
    Polygon[{{1.195696, 1.273429, -0.005583},{1.196475, 1.273429, -0.004312},{
      1.196060, 1.276044, -0.004312},{1.195320, 1.275804, -0.005583}}],
    Polygon[{{1.196475, 1.273429, -0.004312},{1.197045, 1.273429, -0.002935},{
      1.196603, 1.276221, -0.002935},{1.196060, 1.276044, -0.004312}}],
    Polygon[{{1.197045, 1.273429, -0.002935},{1.197393, 1.273429, -0.001486},{
      1.196934, 1.276328, -0.001486},{1.196603, 1.276221, -0.002935}}],
    Polygon[{{1.197393, 1.273429, -0.001486},{1.197510, 1.273429, 0.000000},{
      1.197045, 1.276364, 0.000000},{1.196934, 1.276328, -0.001486}}],
    Polygon[{{1.197510, 1.273429, 0.000000},{1.197393, 1.273429, 0.001486},{
      1.196934, 1.276328, 0.001486},{1.197045, 1.276364, 0.000000}}],
    Polygon[{{1.197393, 1.273429, 0.001486},{1.197045, 1.273429, 0.002935},{
      1.196603, 1.276221, 0.002935},{1.196934, 1.276328, 0.001486}}],
    Polygon[{{1.197045, 1.273429, 0.002935},{1.196475, 1.273429, 0.004312},{
      1.196060, 1.276044, 0.004312},{1.196603, 1.276221, 0.002935}}],
    Polygon[{{1.196475, 1.273429, 0.004312},{1.195696, 1.273429, 0.005583},{
      1.195320, 1.275804, 0.005583},{1.196060, 1.276044, 0.004312}}],
    Polygon[{{1.195696, 1.273429, 0.005583},{1.194728, 1.273429, 0.006716},{
      1.194399, 1.275505, 0.006716},{1.195320, 1.275804, 0.005583}}],
    Polygon[{{1.194728, 1.273429, 0.006716},{1.193594, 1.273429, 0.007684},{
      1.193321, 1.275154, 0.007684},{1.194399, 1.275505, 0.006716}}],
    Polygon[{{1.193594, 1.273429, 0.007684},{1.192324, 1.273429, 0.008463},{
      1.192113, 1.274762, 0.008463},{1.193321, 1.275154, 0.007684}}],
    Polygon[{{1.192324, 1.273429, 0.008463},{1.190947, 1.273429, 0.009033},{
      1.190803, 1.274336, 0.009033},{1.192113, 1.274762, 0.008463}}],
    Polygon[{{1.190947, 1.273429, 0.009033},{1.189497, 1.273429, 0.009381},{
      1.189425, 1.273888, 0.009381},{1.190803, 1.274336, 0.009033}}],
    Polygon[{{1.189425, 1.273888, -0.009381},{1.190803, 1.274336, -0.009033},{
      1.190386, 1.275154, -0.009033},{1.189214, 1.274303, -0.009381}}],
    Polygon[{{1.190803, 1.274336, -0.009033},{1.192113, 1.274762, -0.008463},{
      1.191500, 1.275964, -0.008463},{1.190386, 1.275154, -0.009033}}],
    Polygon[{{1.192113, 1.274762, -0.008463},{1.193321, 1.275154, -0.007684},{
      1.192528, 1.276711, -0.007684},{1.191500, 1.275964, -0.008463}}],
    Polygon[{{1.193321, 1.275154, -0.007684},{1.194399, 1.275505, -0.006716},{
      1.193445, 1.277377, -0.006716},{1.192528, 1.276711, -0.007684}}],
    Polygon[{{1.194399, 1.275505, -0.006716},{1.195320, 1.275804, -0.005583},{
      1.194228, 1.277946, -0.005583},{1.193445, 1.277377, -0.006716}}],
    Polygon[{{1.195320, 1.275804, -0.005583},{1.196060, 1.276044, -0.004312},{
      1.194858, 1.278404, -0.004312},{1.194228, 1.277946, -0.005583}}],
    Polygon[{{1.196060, 1.276044, -0.004312},{1.196603, 1.276221, -0.002935},{
      1.195320, 1.278739, -0.002935},{1.194858, 1.278404, -0.004312}}],
    Polygon[{{1.196603, 1.276221, -0.002935},{1.196934, 1.276328, -0.001486},{
      1.195601, 1.278943, -0.001486},{1.195320, 1.278739, -0.002935}}],
    Polygon[{{1.196934, 1.276328, -0.001486},{1.197045, 1.276364, 0.000000},{
      1.195696, 1.279012, 0.000000},{1.195601, 1.278943, -0.001486}}],
    Polygon[{{1.197045, 1.276364, 0.000000},{1.196934, 1.276328, 0.001486},{
      1.195601, 1.278943, 0.001486},{1.195696, 1.279012, 0.000000}}],
    Polygon[{{1.196934, 1.276328, 0.001486},{1.196603, 1.276221, 0.002935},{
      1.195320, 1.278739, 0.002935},{1.195601, 1.278943, 0.001486}}],
    Polygon[{{1.196603, 1.276221, 0.002935},{1.196060, 1.276044, 0.004312},{
      1.194858, 1.278404, 0.004312},{1.195320, 1.278739, 0.002935}}],
    Polygon[{{1.196060, 1.276044, 0.004312},{1.195320, 1.275804, 0.005583},{
      1.194228, 1.277946, 0.005583},{1.194858, 1.278404, 0.004312}}],
    Polygon[{{1.195320, 1.275804, 0.005583},{1.194399, 1.275505, 0.006716},{
      1.193445, 1.277377, 0.006716},{1.194228, 1.277946, 0.005583}}],
    Polygon[{{1.194399, 1.275505, 0.006716},{1.193321, 1.275154, 0.007684},{
      1.192528, 1.276711, 0.007684},{1.193445, 1.277377, 0.006716}}],
    Polygon[{{1.193321, 1.275154, 0.007684},{1.192113, 1.274762, 0.008463},{
      1.191500, 1.275964, 0.008463},{1.192528, 1.276711, 0.007684}}],
    Polygon[{{1.192113, 1.274762, 0.008463},{1.190803, 1.274336, 0.009033},{
      1.190386, 1.275154, 0.009033},{1.191500, 1.275964, 0.008463}}],
    Polygon[{{1.190803, 1.274336, 0.009033},{1.189425, 1.273888, 0.009381},{
      1.189214, 1.274303, 0.009381},{1.190386, 1.275154, 0.009033}}],
    Polygon[{{1.189214, 1.274303, -0.009381},{1.190386, 1.275154, -0.009033},{
      1.189737, 1.275804, -0.009033},{1.188885, 1.274631, -0.009381}}],
    Polygon[{{1.190386, 1.275154, -0.009033},{1.191500, 1.275964, -0.008463},{
      1.190546, 1.276918, -0.008463},{1.189737, 1.275804, -0.009033}}],
    Polygon[{{1.191500, 1.275964, -0.008463},{1.192528, 1.276711, -0.007684},{
      1.191293, 1.277946, -0.007684},{1.190546, 1.276918, -0.008463}}],
    Polygon[{{1.192528, 1.276711, -0.007684},{1.193445, 1.277377, -0.006716},{
      1.191959, 1.278863, -0.006716},{1.191293, 1.277946, -0.007684}}],
    Polygon[{{1.193445, 1.277377, -0.006716},{1.194228, 1.277946, -0.005583},{
      1.192528, 1.279646, -0.005583},{1.191959, 1.278863, -0.006716}}],
    Polygon[{{1.194228, 1.277946, -0.005583},{1.194858, 1.278404, -0.004312},{
      1.192986, 1.280276, -0.004312},{1.192528, 1.279646, -0.005583}}],
    Polygon[{{1.194858, 1.278404, -0.004312},{1.195320, 1.278739, -0.002935},{
      1.193321, 1.280737, -0.002935},{1.192986, 1.280276, -0.004312}}],
    Polygon[{{1.195320, 1.278739, -0.002935},{1.195601, 1.278943, -0.001486},{
      1.193526, 1.281019, -0.001486},{1.193321, 1.280737, -0.002935}}],
    Polygon[{{1.195601, 1.278943, -0.001486},{1.195696, 1.279012, 0.000000},{
      1.193594, 1.281114, 0.000000},{1.193526, 1.281019, -0.001486}}],
    Polygon[{{1.195696, 1.279012, 0.000000},{1.195601, 1.278943, 0.001486},{
      1.193526, 1.281019, 0.001486},{1.193594, 1.281114, 0.000000}}],
    Polygon[{{1.195601, 1.278943, 0.001486},{1.195320, 1.278739, 0.002935},{
      1.193321, 1.280737, 0.002935},{1.193526, 1.281019, 0.001486}}],
    Polygon[{{1.195320, 1.278739, 0.002935},{1.194858, 1.278404, 0.004312},{
      1.192986, 1.280276, 0.004312},{1.193321, 1.280737, 0.002935}}],
    Polygon[{{1.194858, 1.278404, 0.004312},{1.194228, 1.277946, 0.005583},{
      1.192528, 1.279646, 0.005583},{1.192986, 1.280276, 0.004312}}],
    Polygon[{{1.194228, 1.277946, 0.005583},{1.193445, 1.277377, 0.006716},{
      1.191959, 1.278863, 0.006716},{1.192528, 1.279646, 0.005583}}],
    Polygon[{{1.193445, 1.277377, 0.006716},{1.192528, 1.276711, 0.007684},{
      1.191293, 1.277946, 0.007684},{1.191959, 1.278863, 0.006716}}],
    Polygon[{{1.192528, 1.276711, 0.007684},{1.191500, 1.275964, 0.008463},{
      1.190546, 1.276918, 0.008463},{1.191293, 1.277946, 0.007684}}],
    Polygon[{{1.191500, 1.275964, 0.008463},{1.190386, 1.275154, 0.009033},{
      1.189737, 1.275804, 0.009033},{1.190546, 1.276918, 0.008463}}],
    Polygon[{{1.190386, 1.275154, 0.009033},{1.189214, 1.274303, 0.009381},{
      1.188885, 1.274631, 0.009381},{1.189737, 1.275804, 0.009033}}],
    Polygon[{{1.188885, 1.274631, -0.009381},{1.189737, 1.275804, -0.009033},{
      1.188918, 1.276221, -0.009033},{1.188471, 1.274842, -0.009381}}],
    Polygon[{{1.189737, 1.275804, -0.009033},{1.190546, 1.276918, -0.008463},{
      1.189344, 1.277530, -0.008463},{1.188918, 1.276221, -0.009033}}],
    Polygon[{{1.190546, 1.276918, -0.008463},{1.191293, 1.277946, -0.007684},{
      1.189737, 1.278739, -0.007684},{1.189344, 1.277530, -0.008463}}],
    Polygon[{{1.191293, 1.277946, -0.007684},{1.191959, 1.278863, -0.006716},{
      1.190087, 1.279817, -0.006716},{1.189737, 1.278739, -0.007684}}],
    Polygon[{{1.191959, 1.278863, -0.006716},{1.192528, 1.279646, -0.005583},{
      1.190386, 1.280737, -0.005583},{1.190087, 1.279817, -0.006716}}],
    Polygon[{{1.192528, 1.279646, -0.005583},{1.192986, 1.280276, -0.004312},{
      1.190627, 1.281478, -0.004312},{1.190386, 1.280737, -0.005583}}],
    Polygon[{{1.192986, 1.280276, -0.004312},{1.193321, 1.280737, -0.002935},{
      1.190803, 1.282021, -0.002935},{1.190627, 1.281478, -0.004312}}],
    Polygon[{{1.193321, 1.280737, -0.002935},{1.193526, 1.281019, -0.001486},{
      1.190910, 1.282351, -0.001486},{1.190803, 1.282021, -0.002935}}],
    Polygon[{{1.193526, 1.281019, -0.001486},{1.193594, 1.281114, 0.000000},{
      1.190947, 1.282463, 0.000000},{1.190910, 1.282351, -0.001486}}],
    Polygon[{{1.193594, 1.281114, 0.000000},{1.193526, 1.281019, 0.001486},{
      1.190910, 1.282351, 0.001486},{1.190947, 1.282463, 0.000000}}],
    Polygon[{{1.193526, 1.281019, 0.001486},{1.193321, 1.280737, 0.002935},{
      1.190803, 1.282021, 0.002935},{1.190910, 1.282351, 0.001486}}],
    Polygon[{{1.193321, 1.280737, 0.002935},{1.192986, 1.280276, 0.004312},{
      1.190627, 1.281478, 0.004312},{1.190803, 1.282021, 0.002935}}],
    Polygon[{{1.192986, 1.280276, 0.004312},{1.192528, 1.279646, 0.005583},{
      1.190386, 1.280737, 0.005583},{1.190627, 1.281478, 0.004312}}],
    Polygon[{{1.192528, 1.279646, 0.005583},{1.191959, 1.278863, 0.006716},{
      1.190087, 1.279817, 0.006716},{1.190386, 1.280737, 0.005583}}],
    Polygon[{{1.191959, 1.278863, 0.006716},{1.191293, 1.277946, 0.007684},{
      1.189737, 1.278739, 0.007684},{1.190087, 1.279817, 0.006716}}],
    Polygon[{{1.191293, 1.277946, 0.007684},{1.190546, 1.276918, 0.008463},{
      1.189344, 1.277530, 0.008463},{1.189737, 1.278739, 0.007684}}],
    Polygon[{{1.190546, 1.276918, 0.008463},{1.189737, 1.275804, 0.009033},{
      1.188918, 1.276221, 0.009033},{1.189344, 1.277530, 0.008463}}],
    Polygon[{{1.189737, 1.275804, 0.009033},{1.188885, 1.274631, 0.009381},{
      1.188471, 1.274842, 0.009381},{1.188918, 1.276221, 0.009033}}],
    Polygon[{{1.188471, 1.274842, -0.009381},{1.188918, 1.276221, -0.009033},{
      1.188011, 1.276364, -0.009033},{1.188011, 1.274915, -0.009381}}],
    Polygon[{{1.188918, 1.276221, -0.009033},{1.189344, 1.277530, -0.008463},{
      1.188011, 1.277741, -0.008463},{1.188011, 1.276364, -0.009033}}],
    Polygon[{{1.189344, 1.277530, -0.008463},{1.189737, 1.278739, -0.007684},{
      1.188011, 1.279012, -0.007684},{1.188011, 1.277741, -0.008463}}],
    Polygon[{{1.189737, 1.278739, -0.007684},{1.190087, 1.279817, -0.006716},{
      1.188011, 1.280146, -0.006716},{1.188011, 1.279012, -0.007684}}],
    Polygon[{{1.190087, 1.279817, -0.006716},{1.190386, 1.280737, -0.005583},{
      1.188011, 1.281114, -0.005583},{1.188011, 1.280146, -0.006716}}],
    Polygon[{{1.190386, 1.280737, -0.005583},{1.190627, 1.281478, -0.004312},{
      1.188011, 1.281892, -0.004312},{1.188011, 1.281114, -0.005583}}],
    Polygon[{{1.190627, 1.281478, -0.004312},{1.190803, 1.282021, -0.002935},{
      1.188011, 1.282463, -0.002935},{1.188011, 1.281892, -0.004312}}],
    Polygon[{{1.190803, 1.282021, -0.002935},{1.190910, 1.282351, -0.001486},{
      1.188011, 1.282811, -0.001486},{1.188011, 1.282463, -0.002935}}],
    Polygon[{{1.190910, 1.282351, -0.001486},{1.190947, 1.282463, 0.000000},{
      1.188011, 1.282928, 0.000000},{1.188011, 1.282811, -0.001486}}],
    Polygon[{{1.190947, 1.282463, 0.000000},{1.190910, 1.282351, 0.001486},{
      1.188011, 1.282811, 0.001486},{1.188011, 1.282928, 0.000000}}],
    Polygon[{{1.190910, 1.282351, 0.001486},{1.190803, 1.282021, 0.002935},{
      1.188011, 1.282463, 0.002935},{1.188011, 1.282811, 0.001486}}],
    Polygon[{{1.190803, 1.282021, 0.002935},{1.190627, 1.281478, 0.004312},{
      1.188011, 1.281892, 0.004312},{1.188011, 1.282463, 0.002935}}],
    Polygon[{{1.190627, 1.281478, 0.004312},{1.190386, 1.280737, 0.005583},{
      1.188011, 1.281114, 0.005583},{1.188011, 1.281892, 0.004312}}],
    Polygon[{{1.190386, 1.280737, 0.005583},{1.190087, 1.279817, 0.006716},{
      1.188011, 1.280146, 0.006716},{1.188011, 1.281114, 0.005583}}],
    Polygon[{{1.190087, 1.279817, 0.006716},{1.189737, 1.278739, 0.007684},{
      1.188011, 1.279012, 0.007684},{1.188011, 1.280146, 0.006716}}],
    Polygon[{{1.189737, 1.278739, 0.007684},{1.189344, 1.277530, 0.008463},{
      1.188011, 1.277741, 0.008463},{1.188011, 1.279012, 0.007684}}],
    Polygon[{{1.189344, 1.277530, 0.008463},{1.188918, 1.276221, 0.009033},{
      1.188011, 1.276364, 0.009033},{1.188011, 1.277741, 0.008463}}],
    Polygon[{{1.188918, 1.276221, 0.009033},{1.188471, 1.274842, 0.009381},{
      1.188011, 1.274915, 0.009381},{1.188011, 1.276364, 0.009033}}],
    Polygon[{{1.188011, 1.274915, -0.009381},{1.188011, 1.276364, -0.009033},{
      1.187104, 1.276221, -0.009033},{1.187552, 1.274842, -0.009381}}],
    Polygon[{{1.188011, 1.276364, -0.009033},{1.188011, 1.277741, -0.008463},{
      1.186679, 1.277530, -0.008463},{1.187104, 1.276221, -0.009033}}],
    Polygon[{{1.188011, 1.277741, -0.008463},{1.188011, 1.279012, -0.007684},{
      1.186286, 1.278739, -0.007684},{1.186679, 1.277530, -0.008463}}],
    Polygon[{{1.188011, 1.279012, -0.007684},{1.188011, 1.280146, -0.006716},{
      1.185936, 1.279817, -0.006716},{1.186286, 1.278739, -0.007684}}],
    Polygon[{{1.188011, 1.280146, -0.006716},{1.188011, 1.281114, -0.005583},{
      1.185637, 1.280737, -0.005583},{1.185936, 1.279817, -0.006716}}],
    Polygon[{{1.188011, 1.281114, -0.005583},{1.188011, 1.281892, -0.004312},{
      1.185396, 1.281478, -0.004312},{1.185637, 1.280737, -0.005583}}],
    Polygon[{{1.188011, 1.281892, -0.004312},{1.188011, 1.282463, -0.002935},{
      1.185220, 1.282021, -0.002935},{1.185396, 1.281478, -0.004312}}],
    Polygon[{{1.188011, 1.282463, -0.002935},{1.188011, 1.282811, -0.001486},{
      1.185112, 1.282351, -0.001486},{1.185220, 1.282021, -0.002935}}],
    Polygon[{{1.188011, 1.282811, -0.001486},{1.188011, 1.282928, 0.000000},{
      1.185076, 1.282463, 0.000000},{1.185112, 1.282351, -0.001486}}],
    Polygon[{{1.188011, 1.282928, 0.000000},{1.188011, 1.282811, 0.001486},{
      1.185112, 1.282351, 0.001486},{1.185076, 1.282463, 0.000000}}],
    Polygon[{{1.188011, 1.282811, 0.001486},{1.188011, 1.282463, 0.002935},{
      1.185220, 1.282021, 0.002935},{1.185112, 1.282351, 0.001486}}],
    Polygon[{{1.188011, 1.282463, 0.002935},{1.188011, 1.281892, 0.004312},{
      1.185396, 1.281478, 0.004312},{1.185220, 1.282021, 0.002935}}],
    Polygon[{{1.188011, 1.281892, 0.004312},{1.188011, 1.281114, 0.005583},{
      1.185637, 1.280737, 0.005583},{1.185396, 1.281478, 0.004312}}],
    Polygon[{{1.188011, 1.281114, 0.005583},{1.188011, 1.280146, 0.006716},{
      1.185936, 1.279817, 0.006716},{1.185637, 1.280737, 0.005583}}],
    Polygon[{{1.188011, 1.280146, 0.006716},{1.188011, 1.279012, 0.007684},{
      1.186286, 1.278739, 0.007684},{1.185936, 1.279817, 0.006716}}],
    Polygon[{{1.188011, 1.279012, 0.007684},{1.188011, 1.277741, 0.008463},{
      1.186679, 1.277530, 0.008463},{1.186286, 1.278739, 0.007684}}],
    Polygon[{{1.188011, 1.277741, 0.008463},{1.188011, 1.276364, 0.009033},{
      1.187104, 1.276221, 0.009033},{1.186679, 1.277530, 0.008463}}],
    Polygon[{{1.188011, 1.276364, 0.009033},{1.188011, 1.274915, 0.009381},{
      1.187552, 1.274842, 0.009381},{1.187104, 1.276221, 0.009033}}],
    Polygon[{{1.187552, 1.274842, -0.009381},{1.187104, 1.276221, -0.009033},{
      1.186286, 1.275804, -0.009033},{1.187138, 1.274631, -0.009381}}],
    Polygon[{{1.187104, 1.276221, -0.009033},{1.186679, 1.277530, -0.008463},{
      1.185477, 1.276918, -0.008463},{1.186286, 1.275804, -0.009033}}],
    Polygon[{{1.186679, 1.277530, -0.008463},{1.186286, 1.278739, -0.007684},{
      1.184730, 1.277946, -0.007684},{1.185477, 1.276918, -0.008463}}],
    Polygon[{{1.186286, 1.278739, -0.007684},{1.185936, 1.279817, -0.006716},{
      1.184064, 1.278863, -0.006716},{1.184730, 1.277946, -0.007684}}],
    Polygon[{{1.185936, 1.279817, -0.006716},{1.185637, 1.280737, -0.005583},{
      1.183495, 1.279646, -0.005583},{1.184064, 1.278863, -0.006716}}],
    Polygon[{{1.185637, 1.280737, -0.005583},{1.185396, 1.281478, -0.004312},{
      1.183037, 1.280276, -0.004312},{1.183495, 1.279646, -0.005583}}],
    Polygon[{{1.185396, 1.281478, -0.004312},{1.185220, 1.282021, -0.002935},{
      1.182702, 1.280737, -0.002935},{1.183037, 1.280276, -0.004312}}],
    Polygon[{{1.185220, 1.282021, -0.002935},{1.185112, 1.282351, -0.001486},{
      1.182497, 1.281019, -0.001486},{1.182702, 1.280737, -0.002935}}],
    Polygon[{{1.185112, 1.282351, -0.001486},{1.185076, 1.282463, 0.000000},{
      1.182428, 1.281114, 0.000000},{1.182497, 1.281019, -0.001486}}],
    Polygon[{{1.185076, 1.282463, 0.000000},{1.185112, 1.282351, 0.001486},{
      1.182497, 1.281019, 0.001486},{1.182428, 1.281114, 0.000000}}],
    Polygon[{{1.185112, 1.282351, 0.001486},{1.185220, 1.282021, 0.002935},{
      1.182702, 1.280737, 0.002935},{1.182497, 1.281019, 0.001486}}],
    Polygon[{{1.185220, 1.282021, 0.002935},{1.185396, 1.281478, 0.004312},{
      1.183037, 1.280276, 0.004312},{1.182702, 1.280737, 0.002935}}],
    Polygon[{{1.185396, 1.281478, 0.004312},{1.185637, 1.280737, 0.005583},{
      1.183495, 1.279646, 0.005583},{1.183037, 1.280276, 0.004312}}],
    Polygon[{{1.185637, 1.280737, 0.005583},{1.185936, 1.279817, 0.006716},{
      1.184064, 1.278863, 0.006716},{1.183495, 1.279646, 0.005583}}],
    Polygon[{{1.185936, 1.279817, 0.006716},{1.186286, 1.278739, 0.007684},{
      1.184730, 1.277946, 0.007684},{1.184064, 1.278863, 0.006716}}],
    Polygon[{{1.186286, 1.278739, 0.007684},{1.186679, 1.277530, 0.008463},{
      1.185477, 1.276918, 0.008463},{1.184730, 1.277946, 0.007684}}],
    Polygon[{{1.186679, 1.277530, 0.008463},{1.187104, 1.276221, 0.009033},{
      1.186286, 1.275804, 0.009033},{1.185477, 1.276918, 0.008463}}],
    Polygon[{{1.187104, 1.276221, 0.009033},{1.187552, 1.274842, 0.009381},{
      1.187138, 1.274631, 0.009381},{1.186286, 1.275804, 0.009033}}],
    Polygon[{{1.187138, 1.274631, -0.009381},{1.186286, 1.275804, -0.009033},{
      1.185637, 1.275154, -0.009033},{1.186809, 1.274303, -0.009381}}],
    Polygon[{{1.186286, 1.275804, -0.009033},{1.185477, 1.276918, -0.008463},{
      1.184523, 1.275964, -0.008463},{1.185637, 1.275154, -0.009033}}],
    Polygon[{{1.185477, 1.276918, -0.008463},{1.184730, 1.277946, -0.007684},{
      1.183495, 1.276711, -0.007684},{1.184523, 1.275964, -0.008463}}],
    Polygon[{{1.184730, 1.277946, -0.007684},{1.184064, 1.278863, -0.006716},{
      1.182578, 1.277377, -0.006716},{1.183495, 1.276711, -0.007684}}],
    Polygon[{{1.184064, 1.278863, -0.006716},{1.183495, 1.279646, -0.005583},{
      1.181795, 1.277946, -0.005583},{1.182578, 1.277377, -0.006716}}],
    Polygon[{{1.183495, 1.279646, -0.005583},{1.183037, 1.280276, -0.004312},{
      1.181165, 1.278404, -0.004312},{1.181795, 1.277946, -0.005583}}],
    Polygon[{{1.183037, 1.280276, -0.004312},{1.182702, 1.280737, -0.002935},{
      1.180703, 1.278739, -0.002935},{1.181165, 1.278404, -0.004312}}],
    Polygon[{{1.182702, 1.280737, -0.002935},{1.182497, 1.281019, -0.001486},{
      1.180422, 1.278943, -0.001486},{1.180703, 1.278739, -0.002935}}],
    Polygon[{{1.182497, 1.281019, -0.001486},{1.182428, 1.281114, 0.000000},{
      1.180327, 1.279012, 0.000000},{1.180422, 1.278943, -0.001486}}],
    Polygon[{{1.182428, 1.281114, 0.000000},{1.182497, 1.281019, 0.001486},{
      1.180422, 1.278943, 0.001486},{1.180327, 1.279012, 0.000000}}],
    Polygon[{{1.182497, 1.281019, 0.001486},{1.182702, 1.280737, 0.002935},{
      1.180703, 1.278739, 0.002935},{1.180422, 1.278943, 0.001486}}],
    Polygon[{{1.182702, 1.280737, 0.002935},{1.183037, 1.280276, 0.004312},{
      1.181165, 1.278404, 0.004312},{1.180703, 1.278739, 0.002935}}],
    Polygon[{{1.183037, 1.280276, 0.004312},{1.183495, 1.279646, 0.005583},{
      1.181795, 1.277946, 0.005583},{1.181165, 1.278404, 0.004312}}],
    Polygon[{{1.183495, 1.279646, 0.005583},{1.184064, 1.278863, 0.006716},{
      1.182578, 1.277377, 0.006716},{1.181795, 1.277946, 0.005583}}],
    Polygon[{{1.184064, 1.278863, 0.006716},{1.184730, 1.277946, 0.007684},{
      1.183495, 1.276711, 0.007684},{1.182578, 1.277377, 0.006716}}],
    Polygon[{{1.184730, 1.277946, 0.007684},{1.185477, 1.276918, 0.008463},{
      1.184523, 1.275964, 0.008463},{1.183495, 1.276711, 0.007684}}],
    Polygon[{{1.185477, 1.276918, 0.008463},{1.186286, 1.275804, 0.009033},{
      1.185637, 1.275154, 0.009033},{1.184523, 1.275964, 0.008463}}],
    Polygon[{{1.186286, 1.275804, 0.009033},{1.187138, 1.274631, 0.009381},{
      1.186809, 1.274303, 0.009381},{1.185637, 1.275154, 0.009033}}],
    Polygon[{{1.186809, 1.274303, -0.009381},{1.185637, 1.275154, -0.009033},{
      1.185220, 1.274336, -0.009033},{1.186598, 1.273888, -0.009381}}],
    Polygon[{{1.185637, 1.275154, -0.009033},{1.184523, 1.275964, -0.008463},{
      1.183910, 1.274762, -0.008463},{1.185220, 1.274336, -0.009033}}],
    Polygon[{{1.184523, 1.275964, -0.008463},{1.183495, 1.276711, -0.007684},{
      1.182702, 1.275154, -0.007684},{1.183910, 1.274762, -0.008463}}],
    Polygon[{{1.183495, 1.276711, -0.007684},{1.182578, 1.277377, -0.006716},{
      1.181624, 1.275505, -0.006716},{1.182702, 1.275154, -0.007684}}],
    Polygon[{{1.182578, 1.277377, -0.006716},{1.181795, 1.277946, -0.005583},{
      1.180703, 1.275804, -0.005583},{1.181624, 1.275505, -0.006716}}],
    Polygon[{{1.181795, 1.277946, -0.005583},{1.181165, 1.278404, -0.004312},{
      1.179963, 1.276044, -0.004312},{1.180703, 1.275804, -0.005583}}],
    Polygon[{{1.181165, 1.278404, -0.004312},{1.180703, 1.278739, -0.002935},{
      1.179420, 1.276221, -0.002935},{1.179963, 1.276044, -0.004312}}],
    Polygon[{{1.180703, 1.278739, -0.002935},{1.180422, 1.278943, -0.001486},{
      1.179089, 1.276328, -0.001486},{1.179420, 1.276221, -0.002935}}],
    Polygon[{{1.180422, 1.278943, -0.001486},{1.180327, 1.279012, 0.000000},{
      1.178978, 1.276364, 0.000000},{1.179089, 1.276328, -0.001486}}],
    Polygon[{{1.180327, 1.279012, 0.000000},{1.180422, 1.278943, 0.001486},{
      1.179089, 1.276328, 0.001486},{1.178978, 1.276364, 0.000000}}],
    Polygon[{{1.180422, 1.278943, 0.001486},{1.180703, 1.278739, 0.002935},{
      1.179420, 1.276221, 0.002935},{1.179089, 1.276328, 0.001486}}],
    Polygon[{{1.180703, 1.278739, 0.002935},{1.181165, 1.278404, 0.004312},{
      1.179963, 1.276044, 0.004312},{1.179420, 1.276221, 0.002935}}],
    Polygon[{{1.181165, 1.278404, 0.004312},{1.181795, 1.277946, 0.005583},{
      1.180703, 1.275804, 0.005583},{1.179963, 1.276044, 0.004312}}],
    Polygon[{{1.181795, 1.277946, 0.005583},{1.182578, 1.277377, 0.006716},{
      1.181624, 1.275505, 0.006716},{1.180703, 1.275804, 0.005583}}],
    Polygon[{{1.182578, 1.277377, 0.006716},{1.183495, 1.276711, 0.007684},{
      1.182702, 1.275154, 0.007684},{1.181624, 1.275505, 0.006716}}],
    Polygon[{{1.183495, 1.276711, 0.007684},{1.184523, 1.275964, 0.008463},{
      1.183910, 1.274762, 0.008463},{1.182702, 1.275154, 0.007684}}],
    Polygon[{{1.184523, 1.275964, 0.008463},{1.185637, 1.275154, 0.009033},{
      1.185220, 1.274336, 0.009033},{1.183910, 1.274762, 0.008463}}],
    Polygon[{{1.185637, 1.275154, 0.009033},{1.186809, 1.274303, 0.009381},{
      1.186598, 1.273888, 0.009381},{1.185220, 1.274336, 0.009033}}],
    Polygon[{{1.186598, 1.273888, -0.009381},{1.185220, 1.274336, -0.009033},{
      1.185076, 1.273429, -0.009033},{1.186526, 1.273429, -0.009381}}],
    Polygon[{{1.185220, 1.274336, -0.009033},{1.183910, 1.274762, -0.008463},{
      1.183699, 1.273429, -0.008463},{1.185076, 1.273429, -0.009033}}],
    Polygon[{{1.183910, 1.274762, -0.008463},{1.182702, 1.275154, -0.007684},{
      1.182428, 1.273429, -0.007684},{1.183699, 1.273429, -0.008463}}],
    Polygon[{{1.182702, 1.275154, -0.007684},{1.181624, 1.275505, -0.006716},{
      1.181295, 1.273429, -0.006716},{1.182428, 1.273429, -0.007684}}],
    Polygon[{{1.181624, 1.275505, -0.006716},{1.180703, 1.275804, -0.005583},{
      1.180327, 1.273429, -0.005583},{1.181295, 1.273429, -0.006716}}],
    Polygon[{{1.180703, 1.275804, -0.005583},{1.179963, 1.276044, -0.004312},{
      1.179548, 1.273429, -0.004312},{1.180327, 1.273429, -0.005583}}],
    Polygon[{{1.179963, 1.276044, -0.004312},{1.179420, 1.276221, -0.002935},{
      1.178978, 1.273429, -0.002935},{1.179548, 1.273429, -0.004312}}],
    Polygon[{{1.179420, 1.276221, -0.002935},{1.179089, 1.276328, -0.001486},{
      1.178630, 1.273429, -0.001486},{1.178978, 1.273429, -0.002935}}],
    Polygon[{{1.179089, 1.276328, -0.001486},{1.178978, 1.276364, 0.000000},{
      1.178513, 1.273429, 0.000000},{1.178630, 1.273429, -0.001486}}],
    Polygon[{{1.178978, 1.276364, 0.000000},{1.179089, 1.276328, 0.001486},{
      1.178630, 1.273429, 0.001486},{1.178513, 1.273429, 0.000000}}],
    Polygon[{{1.179089, 1.276328, 0.001486},{1.179420, 1.276221, 0.002935},{
      1.178978, 1.273429, 0.002935},{1.178630, 1.273429, 0.001486}}],
    Polygon[{{1.179420, 1.276221, 0.002935},{1.179963, 1.276044, 0.004312},{
      1.179548, 1.273429, 0.004312},{1.178978, 1.273429, 0.002935}}],
    Polygon[{{1.179963, 1.276044, 0.004312},{1.180703, 1.275804, 0.005583},{
      1.180327, 1.273429, 0.005583},{1.179548, 1.273429, 0.004312}}],
    Polygon[{{1.180703, 1.275804, 0.005583},{1.181624, 1.275505, 0.006716},{
      1.181295, 1.273429, 0.006716},{1.180327, 1.273429, 0.005583}}],
    Polygon[{{1.181624, 1.275505, 0.006716},{1.182702, 1.275154, 0.007684},{
      1.182428, 1.273429, 0.007684},{1.181295, 1.273429, 0.006716}}],
    Polygon[{{1.182702, 1.275154, 0.007684},{1.183910, 1.274762, 0.008463},{
      1.183699, 1.273429, 0.008463},{1.182428, 1.273429, 0.007684}}],
    Polygon[{{1.183910, 1.274762, 0.008463},{1.185220, 1.274336, 0.009033},{
      1.185076, 1.273429, 0.009033},{1.183699, 1.273429, 0.008463}}],
    Polygon[{{1.185220, 1.274336, 0.009033},{1.186598, 1.273888, 0.009381},{
      1.186526, 1.273429, 0.009381},{1.185076, 1.273429, 0.009033}}],
    Polygon[{{1.186526, 1.273429, -0.009381},{1.185076, 1.273429, -0.009033},{
      1.185220, 1.272522, -0.009033},{1.186598, 1.272970, -0.009381}}],
    Polygon[{{1.185076, 1.273429, -0.009033},{1.183699, 1.273429, -0.008463},{
      1.183910, 1.272097, -0.008463},{1.185220, 1.272522, -0.009033}}],
    Polygon[{{1.183699, 1.273429, -0.008463},{1.182428, 1.273429, -0.007684},{
      1.182702, 1.271704, -0.007684},{1.183910, 1.272097, -0.008463}}],
    Polygon[{{1.182428, 1.273429, -0.007684},{1.181295, 1.273429, -0.006716},{
      1.181624, 1.271354, -0.006716},{1.182702, 1.271704, -0.007684}}],
    Polygon[{{1.181295, 1.273429, -0.006716},{1.180327, 1.273429, -0.005583},{
      1.180703, 1.271055, -0.005583},{1.181624, 1.271354, -0.006716}}],
    Polygon[{{1.180327, 1.273429, -0.005583},{1.179548, 1.273429, -0.004312},{
      1.179963, 1.270814, -0.004312},{1.180703, 1.271055, -0.005583}}],
    Polygon[{{1.179548, 1.273429, -0.004312},{1.178978, 1.273429, -0.002935},{
      1.179420, 1.270638, -0.002935},{1.179963, 1.270814, -0.004312}}],
    Polygon[{{1.178978, 1.273429, -0.002935},{1.178630, 1.273429, -0.001486},{
      1.179089, 1.270530, -0.001486},{1.179420, 1.270638, -0.002935}}],
    Polygon[{{1.178630, 1.273429, -0.001486},{1.178513, 1.273429, 0.000000},{
      1.178978, 1.270494, 0.000000},{1.179089, 1.270530, -0.001486}}],
    Polygon[{{1.178513, 1.273429, 0.000000},{1.178630, 1.273429, 0.001486},{
      1.179089, 1.270530, 0.001486},{1.178978, 1.270494, 0.000000}}],
    Polygon[{{1.178630, 1.273429, 0.001486},{1.178978, 1.273429, 0.002935},{
      1.179420, 1.270638, 0.002935},{1.179089, 1.270530, 0.001486}}],
    Polygon[{{1.178978, 1.273429, 0.002935},{1.179548, 1.273429, 0.004312},{
      1.179963, 1.270814, 0.004312},{1.179420, 1.270638, 0.002935}}],
    Polygon[{{1.179548, 1.273429, 0.004312},{1.180327, 1.273429, 0.005583},{
      1.180703, 1.271055, 0.005583},{1.179963, 1.270814, 0.004312}}],
    Polygon[{{1.180327, 1.273429, 0.005583},{1.181295, 1.273429, 0.006716},{
      1.181624, 1.271354, 0.006716},{1.180703, 1.271055, 0.005583}}],
    Polygon[{{1.181295, 1.273429, 0.006716},{1.182428, 1.273429, 0.007684},{
      1.182702, 1.271704, 0.007684},{1.181624, 1.271354, 0.006716}}],
    Polygon[{{1.182428, 1.273429, 0.007684},{1.183699, 1.273429, 0.008463},{
      1.183910, 1.272097, 0.008463},{1.182702, 1.271704, 0.007684}}],
    Polygon[{{1.183699, 1.273429, 0.008463},{1.185076, 1.273429, 0.009033},{
      1.185220, 1.272522, 0.009033},{1.183910, 1.272097, 0.008463}}],
    Polygon[{{1.185076, 1.273429, 0.009033},{1.186526, 1.273429, 0.009381},{
      1.186598, 1.272970, 0.009381},{1.185220, 1.272522, 0.009033}}],
    Polygon[{{1.186598, 1.272970, -0.009381},{1.185220, 1.272522, -0.009033},{
      1.185637, 1.271704, -0.009033},{1.186809, 1.272556, -0.009381}}],
    Polygon[{{1.185220, 1.272522, -0.009033},{1.183910, 1.272097, -0.008463},{
      1.184523, 1.270895, -0.008463},{1.185637, 1.271704, -0.009033}}],
    Polygon[{{1.183910, 1.272097, -0.008463},{1.182702, 1.271704, -0.007684},{
      1.183495, 1.270148, -0.007684},{1.184523, 1.270895, -0.008463}}],
    Polygon[{{1.182702, 1.271704, -0.007684},{1.181624, 1.271354, -0.006716},{
      1.182578, 1.269482, -0.006716},{1.183495, 1.270148, -0.007684}}],
    Polygon[{{1.181624, 1.271354, -0.006716},{1.180703, 1.271055, -0.005583},{
      1.181795, 1.268913, -0.005583},{1.182578, 1.269482, -0.006716}}],
    Polygon[{{1.180703, 1.271055, -0.005583},{1.179963, 1.270814, -0.004312},{
      1.181165, 1.268455, -0.004312},{1.181795, 1.268913, -0.005583}}],
    Polygon[{{1.179963, 1.270814, -0.004312},{1.179420, 1.270638, -0.002935},{
      1.180703, 1.268120, -0.002935},{1.181165, 1.268455, -0.004312}}],
    Polygon[{{1.179420, 1.270638, -0.002935},{1.179089, 1.270530, -0.001486},{
      1.180422, 1.267915, -0.001486},{1.180703, 1.268120, -0.002935}}],
    Polygon[{{1.179089, 1.270530, -0.001486},{1.178978, 1.270494, 0.000000},{
      1.180327, 1.267846, 0.000000},{1.180422, 1.267915, -0.001486}}],
    Polygon[{{1.178978, 1.270494, 0.000000},{1.179089, 1.270530, 0.001486},{
      1.180422, 1.267915, 0.001486},{1.180327, 1.267846, 0.000000}}],
    Polygon[{{1.179089, 1.270530, 0.001486},{1.179420, 1.270638, 0.002935},{
      1.180703, 1.268120, 0.002935},{1.180422, 1.267915, 0.001486}}],
    Polygon[{{1.179420, 1.270638, 0.002935},{1.179963, 1.270814, 0.004312},{
      1.181165, 1.268455, 0.004312},{1.180703, 1.268120, 0.002935}}],
    Polygon[{{1.179963, 1.270814, 0.004312},{1.180703, 1.271055, 0.005583},{
      1.181795, 1.268913, 0.005583},{1.181165, 1.268455, 0.004312}}],
    Polygon[{{1.180703, 1.271055, 0.005583},{1.181624, 1.271354, 0.006716},{
      1.182578, 1.269482, 0.006716},{1.181795, 1.268913, 0.005583}}],
    Polygon[{{1.181624, 1.271354, 0.006716},{1.182702, 1.271704, 0.007684},{
      1.183495, 1.270148, 0.007684},{1.182578, 1.269482, 0.006716}}],
    Polygon[{{1.182702, 1.271704, 0.007684},{1.183910, 1.272097, 0.008463},{
      1.184523, 1.270895, 0.008463},{1.183495, 1.270148, 0.007684}}],
    Polygon[{{1.183910, 1.272097, 0.008463},{1.185220, 1.272522, 0.009033},{
      1.185637, 1.271704, 0.009033},{1.184523, 1.270895, 0.008463}}],
    Polygon[{{1.185220, 1.272522, 0.009033},{1.186598, 1.272970, 0.009381},{
      1.186809, 1.272556, 0.009381},{1.185637, 1.271704, 0.009033}}],
    Polygon[{{1.186809, 1.272556, -0.009381},{1.185637, 1.271704, -0.009033},{
      1.186286, 1.271055, -0.009033},{1.187138, 1.272227, -0.009381}}],
    Polygon[{{1.185637, 1.271704, -0.009033},{1.184523, 1.270895, -0.008463},{
      1.185477, 1.269941, -0.008463},{1.186286, 1.271055, -0.009033}}],
    Polygon[{{1.184523, 1.270895, -0.008463},{1.183495, 1.270148, -0.007684},{
      1.184730, 1.268913, -0.007684},{1.185477, 1.269941, -0.008463}}],
    Polygon[{{1.183495, 1.270148, -0.007684},{1.182578, 1.269482, -0.006716},{
      1.184064, 1.267996, -0.006716},{1.184730, 1.268913, -0.007684}}],
    Polygon[{{1.182578, 1.269482, -0.006716},{1.181795, 1.268913, -0.005583},{
      1.183495, 1.267213, -0.005583},{1.184064, 1.267996, -0.006716}}],
    Polygon[{{1.181795, 1.268913, -0.005583},{1.181165, 1.268455, -0.004312},{
      1.183037, 1.266582, -0.004312},{1.183495, 1.267213, -0.005583}}],
    Polygon[{{1.181165, 1.268455, -0.004312},{1.180703, 1.268120, -0.002935},{
      1.182702, 1.266121, -0.002935},{1.183037, 1.266582, -0.004312}}],
    Polygon[{{1.180703, 1.268120, -0.002935},{1.180422, 1.267915, -0.001486},{
      1.182497, 1.265840, -0.001486},{1.182702, 1.266121, -0.002935}}],
    Polygon[{{1.180422, 1.267915, -0.001486},{1.180327, 1.267846, 0.000000},{
      1.182428, 1.265745, 0.000000},{1.182497, 1.265840, -0.001486}}],
    Polygon[{{1.180327, 1.267846, 0.000000},{1.180422, 1.267915, 0.001486},{
      1.182497, 1.265840, 0.001486},{1.182428, 1.265745, 0.000000}}],
    Polygon[{{1.180422, 1.267915, 0.001486},{1.180703, 1.268120, 0.002935},{
      1.182702, 1.266121, 0.002935},{1.182497, 1.265840, 0.001486}}],
    Polygon[{{1.180703, 1.268120, 0.002935},{1.181165, 1.268455, 0.004312},{
      1.183037, 1.266582, 0.004312},{1.182702, 1.266121, 0.002935}}],
    Polygon[{{1.181165, 1.268455, 0.004312},{1.181795, 1.268913, 0.005583},{
      1.183495, 1.267213, 0.005583},{1.183037, 1.266582, 0.004312}}],
    Polygon[{{1.181795, 1.268913, 0.005583},{1.182578, 1.269482, 0.006716},{
      1.184064, 1.267996, 0.006716},{1.183495, 1.267213, 0.005583}}],
    Polygon[{{1.182578, 1.269482, 0.006716},{1.183495, 1.270148, 0.007684},{
      1.184730, 1.268913, 0.007684},{1.184064, 1.267996, 0.006716}}],
    Polygon[{{1.183495, 1.270148, 0.007684},{1.184523, 1.270895, 0.008463},{
      1.185477, 1.269941, 0.008463},{1.184730, 1.268913, 0.007684}}],
    Polygon[{{1.184523, 1.270895, 0.008463},{1.185637, 1.271704, 0.009033},{
      1.186286, 1.271055, 0.009033},{1.185477, 1.269941, 0.008463}}],
    Polygon[{{1.185637, 1.271704, 0.009033},{1.186809, 1.272556, 0.009381},{
      1.187138, 1.272227, 0.009381},{1.186286, 1.271055, 0.009033}}],
    Polygon[{{1.187138, 1.272227, -0.009381},{1.186286, 1.271055, -0.009033},{
      1.187104, 1.270638, -0.009033},{1.187552, 1.272016, -0.009381}}],
    Polygon[{{1.186286, 1.271055, -0.009033},{1.185477, 1.269941, -0.008463},{
      1.186679, 1.269328, -0.008463},{1.187104, 1.270638, -0.009033}}],
    Polygon[{{1.185477, 1.269941, -0.008463},{1.184730, 1.268913, -0.007684},{
      1.186286, 1.268120, -0.007684},{1.186679, 1.269328, -0.008463}}],
    Polygon[{{1.184730, 1.268913, -0.007684},{1.184064, 1.267996, -0.006716},{
      1.185936, 1.267042, -0.006716},{1.186286, 1.268120, -0.007684}}],
    Polygon[{{1.184064, 1.267996, -0.006716},{1.183495, 1.267213, -0.005583},{
      1.185637, 1.266121, -0.005583},{1.185936, 1.267042, -0.006716}}],
    Polygon[{{1.183495, 1.267213, -0.005583},{1.183037, 1.266582, -0.004312},{
      1.185396, 1.265380, -0.004312},{1.185637, 1.266121, -0.005583}}],
    Polygon[{{1.183037, 1.266582, -0.004312},{1.182702, 1.266121, -0.002935},{
      1.185220, 1.264838, -0.002935},{1.185396, 1.265380, -0.004312}}],
    Polygon[{{1.182702, 1.266121, -0.002935},{1.182497, 1.265840, -0.001486},{
      1.185112, 1.264507, -0.001486},{1.185220, 1.264838, -0.002935}}],
    Polygon[{{1.182497, 1.265840, -0.001486},{1.182428, 1.265745, 0.000000},{
      1.185076, 1.264396, 0.000000},{1.185112, 1.264507, -0.001486}}],
    Polygon[{{1.182428, 1.265745, 0.000000},{1.182497, 1.265840, 0.001486},{
      1.185112, 1.264507, 0.001486},{1.185076, 1.264396, 0.000000}}],
    Polygon[{{1.182497, 1.265840, 0.001486},{1.182702, 1.266121, 0.002935},{
      1.185220, 1.264838, 0.002935},{1.185112, 1.264507, 0.001486}}],
    Polygon[{{1.182702, 1.266121, 0.002935},{1.183037, 1.266582, 0.004312},{
      1.185396, 1.265380, 0.004312},{1.185220, 1.264838, 0.002935}}],
    Polygon[{{1.183037, 1.266582, 0.004312},{1.183495, 1.267213, 0.005583},{
      1.185637, 1.266121, 0.005583},{1.185396, 1.265380, 0.004312}}],
    Polygon[{{1.183495, 1.267213, 0.005583},{1.184064, 1.267996, 0.006716},{
      1.185936, 1.267042, 0.006716},{1.185637, 1.266121, 0.005583}}],
    Polygon[{{1.184064, 1.267996, 0.006716},{1.184730, 1.268913, 0.007684},{
      1.186286, 1.268120, 0.007684},{1.185936, 1.267042, 0.006716}}],
    Polygon[{{1.184730, 1.268913, 0.007684},{1.185477, 1.269941, 0.008463},{
      1.186679, 1.269328, 0.008463},{1.186286, 1.268120, 0.007684}}],
    Polygon[{{1.185477, 1.269941, 0.008463},{1.186286, 1.271055, 0.009033},{
      1.187104, 1.270638, 0.009033},{1.186679, 1.269328, 0.008463}}],
    Polygon[{{1.186286, 1.271055, 0.009033},{1.187138, 1.272227, 0.009381},{
      1.187552, 1.272016, 0.009381},{1.187104, 1.270638, 0.009033}}],
    Polygon[{{1.187552, 1.272016, -0.009381},{1.187104, 1.270638, -0.009033},{
      1.188011, 1.270494, -0.009033},{1.188011, 1.271943, -0.009381}}],
    Polygon[{{1.187104, 1.270638, -0.009033},{1.186679, 1.269328, -0.008463},{
      1.188011, 1.269117, -0.008463},{1.188011, 1.270494, -0.009033}}],
    Polygon[{{1.186679, 1.269328, -0.008463},{1.186286, 1.268120, -0.007684},{
      1.188011, 1.267846, -0.007684},{1.188011, 1.269117, -0.008463}}],
    Polygon[{{1.186286, 1.268120, -0.007684},{1.185936, 1.267042, -0.006716},{
      1.188011, 1.266713, -0.006716},{1.188011, 1.267846, -0.007684}}],
    Polygon[{{1.185936, 1.267042, -0.006716},{1.185637, 1.266121, -0.005583},{
      1.188011, 1.265745, -0.005583},{1.188011, 1.266713, -0.006716}}],
    Polygon[{{1.185637, 1.266121, -0.005583},{1.185396, 1.265380, -0.004312},{
      1.188011, 1.264966, -0.004312},{1.188011, 1.265745, -0.005583}}],
    Polygon[{{1.185396, 1.265380, -0.004312},{1.185220, 1.264838, -0.002935},{
      1.188011, 1.264396, -0.002935},{1.188011, 1.264966, -0.004312}}],
    Polygon[{{1.185220, 1.264838, -0.002935},{1.185112, 1.264507, -0.001486},{
      1.188011, 1.264048, -0.001486},{1.188011, 1.264396, -0.002935}}],
    Polygon[{{1.185112, 1.264507, -0.001486},{1.185076, 1.264396, 0.000000},{
      1.188011, 1.263931, 0.000000},{1.188011, 1.264048, -0.001486}}],
    Polygon[{{1.185076, 1.264396, 0.000000},{1.185112, 1.264507, 0.001486},{
      1.188011, 1.264048, 0.001486},{1.188011, 1.263931, 0.000000}}],
    Polygon[{{1.185112, 1.264507, 0.001486},{1.185220, 1.264838, 0.002935},{
      1.188011, 1.264396, 0.002935},{1.188011, 1.264048, 0.001486}}],
    Polygon[{{1.185220, 1.264838, 0.002935},{1.185396, 1.265380, 0.004312},{
      1.188011, 1.264966, 0.004312},{1.188011, 1.264396, 0.002935}}],
    Polygon[{{1.185396, 1.265380, 0.004312},{1.185637, 1.266121, 0.005583},{
      1.188011, 1.265745, 0.005583},{1.188011, 1.264966, 0.004312}}],
    Polygon[{{1.185637, 1.266121, 0.005583},{1.185936, 1.267042, 0.006716},{
      1.188011, 1.266713, 0.006716},{1.188011, 1.265745, 0.005583}}],
    Polygon[{{1.185936, 1.267042, 0.006716},{1.186286, 1.268120, 0.007684},{
      1.188011, 1.267846, 0.007684},{1.188011, 1.266713, 0.006716}}],
    Polygon[{{1.186286, 1.268120, 0.007684},{1.186679, 1.269328, 0.008463},{
      1.188011, 1.269117, 0.008463},{1.188011, 1.267846, 0.007684}}],
    Polygon[{{1.186679, 1.269328, 0.008463},{1.187104, 1.270638, 0.009033},{
      1.188011, 1.270494, 0.009033},{1.188011, 1.269117, 0.008463}}],
    Polygon[{{1.187104, 1.270638, 0.009033},{1.187552, 1.272016, 0.009381},{
      1.188011, 1.271943, 0.009381},{1.188011, 1.270494, 0.009033}}],
    Polygon[{{1.188011, 1.271943, -0.009381},{1.188011, 1.270494, -0.009033},{
      1.188918, 1.270638, -0.009033},{1.188471, 1.272016, -0.009381}}],
    Polygon[{{1.188011, 1.270494, -0.009033},{1.188011, 1.269117, -0.008463},{
      1.189344, 1.269328, -0.008463},{1.188918, 1.270638, -0.009033}}],
    Polygon[{{1.188011, 1.269117, -0.008463},{1.188011, 1.267846, -0.007684},{
      1.189737, 1.268120, -0.007684},{1.189344, 1.269328, -0.008463}}],
    Polygon[{{1.188011, 1.267846, -0.007684},{1.188011, 1.266713, -0.006716},{
      1.190087, 1.267042, -0.006716},{1.189737, 1.268120, -0.007684}}],
    Polygon[{{1.188011, 1.266713, -0.006716},{1.188011, 1.265745, -0.005583},{
      1.190386, 1.266121, -0.005583},{1.190087, 1.267042, -0.006716}}],
    Polygon[{{1.188011, 1.265745, -0.005583},{1.188011, 1.264966, -0.004312},{
      1.190627, 1.265380, -0.004312},{1.190386, 1.266121, -0.005583}}],
    Polygon[{{1.188011, 1.264966, -0.004312},{1.188011, 1.264396, -0.002935},{
      1.190803, 1.264838, -0.002935},{1.190627, 1.265380, -0.004312}}],
    Polygon[{{1.188011, 1.264396, -0.002935},{1.188011, 1.264048, -0.001486},{
      1.190910, 1.264507, -0.001486},{1.190803, 1.264838, -0.002935}}],
    Polygon[{{1.188011, 1.264048, -0.001486},{1.188011, 1.263931, 0.000000},{
      1.190947, 1.264396, 0.000000},{1.190910, 1.264507, -0.001486}}],
    Polygon[{{1.188011, 1.263931, 0.000000},{1.188011, 1.264048, 0.001486},{
      1.190910, 1.264507, 0.001486},{1.190947, 1.264396, 0.000000}}],
    Polygon[{{1.188011, 1.264048, 0.001486},{1.188011, 1.264396, 0.002935},{
      1.190803, 1.264838, 0.002935},{1.190910, 1.264507, 0.001486}}],
    Polygon[{{1.188011, 1.264396, 0.002935},{1.188011, 1.264966, 0.004312},{
      1.190627, 1.265380, 0.004312},{1.190803, 1.264838, 0.002935}}],
    Polygon[{{1.188011, 1.264966, 0.004312},{1.188011, 1.265745, 0.005583},{
      1.190386, 1.266121, 0.005583},{1.190627, 1.265380, 0.004312}}],
    Polygon[{{1.188011, 1.265745, 0.005583},{1.188011, 1.266713, 0.006716},{
      1.190087, 1.267042, 0.006716},{1.190386, 1.266121, 0.005583}}],
    Polygon[{{1.188011, 1.266713, 0.006716},{1.188011, 1.267846, 0.007684},{
      1.189737, 1.268120, 0.007684},{1.190087, 1.267042, 0.006716}}],
    Polygon[{{1.188011, 1.267846, 0.007684},{1.188011, 1.269117, 0.008463},{
      1.189344, 1.269328, 0.008463},{1.189737, 1.268120, 0.007684}}],
    Polygon[{{1.188011, 1.269117, 0.008463},{1.188011, 1.270494, 0.009033},{
      1.188918, 1.270638, 0.009033},{1.189344, 1.269328, 0.008463}}],
    Polygon[{{1.188011, 1.270494, 0.009033},{1.188011, 1.271943, 0.009381},{
      1.188471, 1.272016, 0.009381},{1.188918, 1.270638, 0.009033}}],
    Polygon[{{1.188471, 1.272016, -0.009381},{1.188918, 1.270638, -0.009033},{
      1.189737, 1.271055, -0.009033},{1.188885, 1.272227, -0.009381}}],
    Polygon[{{1.188918, 1.270638, -0.009033},{1.189344, 1.269328, -0.008463},{
      1.190546, 1.269941, -0.008463},{1.189737, 1.271055, -0.009033}}],
    Polygon[{{1.189344, 1.269328, -0.008463},{1.189737, 1.268120, -0.007684},{
      1.191293, 1.268913, -0.007684},{1.190546, 1.269941, -0.008463}}],
    Polygon[{{1.189737, 1.268120, -0.007684},{1.190087, 1.267042, -0.006716},{
      1.191959, 1.267996, -0.006716},{1.191293, 1.268913, -0.007684}}],
    Polygon[{{1.190087, 1.267042, -0.006716},{1.190386, 1.266121, -0.005583},{
      1.192528, 1.267213, -0.005583},{1.191959, 1.267996, -0.006716}}],
    Polygon[{{1.190386, 1.266121, -0.005583},{1.190627, 1.265380, -0.004312},{
      1.192986, 1.266582, -0.004312},{1.192528, 1.267213, -0.005583}}],
    Polygon[{{1.190627, 1.265380, -0.004312},{1.190803, 1.264838, -0.002935},{
      1.193321, 1.266121, -0.002935},{1.192986, 1.266582, -0.004312}}],
    Polygon[{{1.190803, 1.264838, -0.002935},{1.190910, 1.264507, -0.001486},{
      1.193526, 1.265840, -0.001486},{1.193321, 1.266121, -0.002935}}],
    Polygon[{{1.190910, 1.264507, -0.001486},{1.190947, 1.264396, 0.000000},{
      1.193594, 1.265745, 0.000000},{1.193526, 1.265840, -0.001486}}],
    Polygon[{{1.190947, 1.264396, 0.000000},{1.190910, 1.264507, 0.001486},{
      1.193526, 1.265840, 0.001486},{1.193594, 1.265745, 0.000000}}],
    Polygon[{{1.190910, 1.264507, 0.001486},{1.190803, 1.264838, 0.002935},{
      1.193321, 1.266121, 0.002935},{1.193526, 1.265840, 0.001486}}],
    Polygon[{{1.190803, 1.264838, 0.002935},{1.190627, 1.265380, 0.004312},{
      1.192986, 1.266582, 0.004312},{1.193321, 1.266121, 0.002935}}],
    Polygon[{{1.190627, 1.265380, 0.004312},{1.190386, 1.266121, 0.005583},{
      1.192528, 1.267213, 0.005583},{1.192986, 1.266582, 0.004312}}],
    Polygon[{{1.190386, 1.266121, 0.005583},{1.190087, 1.267042, 0.006716},{
      1.191959, 1.267996, 0.006716},{1.192528, 1.267213, 0.005583}}],
    Polygon[{{1.190087, 1.267042, 0.006716},{1.189737, 1.268120, 0.007684},{
      1.191293, 1.268913, 0.007684},{1.191959, 1.267996, 0.006716}}],
    Polygon[{{1.189737, 1.268120, 0.007684},{1.189344, 1.269328, 0.008463},{
      1.190546, 1.269941, 0.008463},{1.191293, 1.268913, 0.007684}}],
    Polygon[{{1.189344, 1.269328, 0.008463},{1.188918, 1.270638, 0.009033},{
      1.189737, 1.271055, 0.009033},{1.190546, 1.269941, 0.008463}}],
    Polygon[{{1.188918, 1.270638, 0.009033},{1.188471, 1.272016, 0.009381},{
      1.188885, 1.272227, 0.009381},{1.189737, 1.271055, 0.009033}}],
    Polygon[{{1.188885, 1.272227, -0.009381},{1.189737, 1.271055, -0.009033},{
      1.190386, 1.271704, -0.009033},{1.189214, 1.272556, -0.009381}}],
    Polygon[{{1.189737, 1.271055, -0.009033},{1.190546, 1.269941, -0.008463},{
      1.191500, 1.270895, -0.008463},{1.190386, 1.271704, -0.009033}}],
    Polygon[{{1.190546, 1.269941, -0.008463},{1.191293, 1.268913, -0.007684},{
      1.192528, 1.270148, -0.007684},{1.191500, 1.270895, -0.008463}}],
    Polygon[{{1.191293, 1.268913, -0.007684},{1.191959, 1.267996, -0.006716},{
      1.193445, 1.269482, -0.006716},{1.192528, 1.270148, -0.007684}}],
    Polygon[{{1.191959, 1.267996, -0.006716},{1.192528, 1.267213, -0.005583},{
      1.194228, 1.268913, -0.005583},{1.193445, 1.269482, -0.006716}}],
    Polygon[{{1.192528, 1.267213, -0.005583},{1.192986, 1.266582, -0.004312},{
      1.194858, 1.268455, -0.004312},{1.194228, 1.268913, -0.005583}}],
    Polygon[{{1.192986, 1.266582, -0.004312},{1.193321, 1.266121, -0.002935},{
      1.195320, 1.268120, -0.002935},{1.194858, 1.268455, -0.004312}}],
    Polygon[{{1.193321, 1.266121, -0.002935},{1.193526, 1.265840, -0.001486},{
      1.195601, 1.267915, -0.001486},{1.195320, 1.268120, -0.002935}}],
    Polygon[{{1.193526, 1.265840, -0.001486},{1.193594, 1.265745, 0.000000},{
      1.195696, 1.267846, 0.000000},{1.195601, 1.267915, -0.001486}}],
    Polygon[{{1.193594, 1.265745, 0.000000},{1.193526, 1.265840, 0.001486},{
      1.195601, 1.267915, 0.001486},{1.195696, 1.267846, 0.000000}}],
    Polygon[{{1.193526, 1.265840, 0.001486},{1.193321, 1.266121, 0.002935},{
      1.195320, 1.268120, 0.002935},{1.195601, 1.267915, 0.001486}}],
    Polygon[{{1.193321, 1.266121, 0.002935},{1.192986, 1.266582, 0.004312},{
      1.194858, 1.268455, 0.004312},{1.195320, 1.268120, 0.002935}}],
    Polygon[{{1.192986, 1.266582, 0.004312},{1.192528, 1.267213, 0.005583},{
      1.194228, 1.268913, 0.005583},{1.194858, 1.268455, 0.004312}}],
    Polygon[{{1.192528, 1.267213, 0.005583},{1.191959, 1.267996, 0.006716},{
      1.193445, 1.269482, 0.006716},{1.194228, 1.268913, 0.005583}}],
    Polygon[{{1.191959, 1.267996, 0.006716},{1.191293, 1.268913, 0.007684},{
      1.192528, 1.270148, 0.007684},{1.193445, 1.269482, 0.006716}}],
    Polygon[{{1.191293, 1.268913, 0.007684},{1.190546, 1.269941, 0.008463},{
      1.191500, 1.270895, 0.008463},{1.192528, 1.270148, 0.007684}}],
    Polygon[{{1.190546, 1.269941, 0.008463},{1.189737, 1.271055, 0.009033},{
      1.190386, 1.271704, 0.009033},{1.191500, 1.270895, 0.008463}}],
    Polygon[{{1.189737, 1.271055, 0.009033},{1.188885, 1.272227, 0.009381},{
      1.189214, 1.272556, 0.009381},{1.190386, 1.271704, 0.009033}}],
    Polygon[{{1.189214, 1.272556, -0.009381},{1.190386, 1.271704, -0.009033},{
      1.190803, 1.272522, -0.009033},{1.189425, 1.272970, -0.009381}}],
    Polygon[{{1.190386, 1.271704, -0.009033},{1.191500, 1.270895, -0.008463},{
      1.192113, 1.272097, -0.008463},{1.190803, 1.272522, -0.009033}}],
    Polygon[{{1.191500, 1.270895, -0.008463},{1.192528, 1.270148, -0.007684},{
      1.193321, 1.271704, -0.007684},{1.192113, 1.272097, -0.008463}}],
    Polygon[{{1.192528, 1.270148, -0.007684},{1.193445, 1.269482, -0.006716},{
      1.194399, 1.271354, -0.006716},{1.193321, 1.271704, -0.007684}}],
    Polygon[{{1.193445, 1.269482, -0.006716},{1.194228, 1.268913, -0.005583},{
      1.195320, 1.271055, -0.005583},{1.194399, 1.271354, -0.006716}}],
    Polygon[{{1.194228, 1.268913, -0.005583},{1.194858, 1.268455, -0.004312},{
      1.196060, 1.270814, -0.004312},{1.195320, 1.271055, -0.005583}}],
    Polygon[{{1.194858, 1.268455, -0.004312},{1.195320, 1.268120, -0.002935},{
      1.196603, 1.270638, -0.002935},{1.196060, 1.270814, -0.004312}}],
    Polygon[{{1.195320, 1.268120, -0.002935},{1.195601, 1.267915, -0.001486},{
      1.196934, 1.270530, -0.001486},{1.196603, 1.270638, -0.002935}}],
    Polygon[{{1.195601, 1.267915, -0.001486},{1.195696, 1.267846, 0.000000},{
      1.197045, 1.270494, 0.000000},{1.196934, 1.270530, -0.001486}}],
    Polygon[{{1.195696, 1.267846, 0.000000},{1.195601, 1.267915, 0.001486},{
      1.196934, 1.270530, 0.001486},{1.197045, 1.270494, 0.000000}}],
    Polygon[{{1.195601, 1.267915, 0.001486},{1.195320, 1.268120, 0.002935},{
      1.196603, 1.270638, 0.002935},{1.196934, 1.270530, 0.001486}}],
    Polygon[{{1.195320, 1.268120, 0.002935},{1.194858, 1.268455, 0.004312},{
      1.196060, 1.270814, 0.004312},{1.196603, 1.270638, 0.002935}}],
    Polygon[{{1.194858, 1.268455, 0.004312},{1.194228, 1.268913, 0.005583},{
      1.195320, 1.271055, 0.005583},{1.196060, 1.270814, 0.004312}}],
    Polygon[{{1.194228, 1.268913, 0.005583},{1.193445, 1.269482, 0.006716},{
      1.194399, 1.271354, 0.006716},{1.195320, 1.271055, 0.005583}}],
    Polygon[{{1.193445, 1.269482, 0.006716},{1.192528, 1.270148, 0.007684},{
      1.193321, 1.271704, 0.007684},{1.194399, 1.271354, 0.006716}}],
    Polygon[{{1.192528, 1.270148, 0.007684},{1.191500, 1.270895, 0.008463},{
      1.192113, 1.272097, 0.008463},{1.193321, 1.271704, 0.007684}}],
    Polygon[{{1.191500, 1.270895, 0.008463},{1.190386, 1.271704, 0.009033},{
      1.190803, 1.272522, 0.009033},{1.192113, 1.272097, 0.008463}}],
    Polygon[{{1.190386, 1.271704, 0.009033},{1.189214, 1.272556, 0.009381},{
      1.189425, 1.272970, 0.009381},{1.190803, 1.272522, 0.009033}}],
    Polygon[{{1.189425, 1.272970, -0.009381},{1.190803, 1.272522, -0.009033},{
      1.190947, 1.273429, -0.009033},{1.189497, 1.273429, -0.009381}}],
    Polygon[{{1.190803, 1.272522, -0.009033},{1.192113, 1.272097, -0.008463},{
      1.192324, 1.273429, -0.008463},{1.190947, 1.273429, -0.009033}}],
    Polygon[{{1.192113, 1.272097, -0.008463},{1.193321, 1.271704, -0.007684},{
      1.193594, 1.273429, -0.007684},{1.192324, 1.273429, -0.008463}}],
    Polygon[{{1.193321, 1.271704, -0.007684},{1.194399, 1.271354, -0.006716},{
      1.194728, 1.273429, -0.006716},{1.193594, 1.273429, -0.007684}}],
    Polygon[{{1.194399, 1.271354, -0.006716},{1.195320, 1.271055, -0.005583},{
      1.195696, 1.273429, -0.005583},{1.194728, 1.273429, -0.006716}}],
    Polygon[{{1.195320, 1.271055, -0.005583},{1.196060, 1.270814, -0.004312},{
      1.196475, 1.273429, -0.004312},{1.195696, 1.273429, -0.005583}}],
    Polygon[{{1.196060, 1.270814, -0.004312},{1.196603, 1.270638, -0.002935},{
      1.197045, 1.273429, -0.002935},{1.196475, 1.273429, -0.004312}}],
    Polygon[{{1.196603, 1.270638, -0.002935},{1.196934, 1.270530, -0.001486},{
      1.197393, 1.273429, -0.001486},{1.197045, 1.273429, -0.002935}}],
    Polygon[{{1.196934, 1.270530, -0.001486},{1.197045, 1.270494, 0.000000},{
      1.197510, 1.273429, 0.000000},{1.197393, 1.273429, -0.001486}}],
    Polygon[{{1.197045, 1.270494, 0.000000},{1.196934, 1.270530, 0.001486},{
      1.197393, 1.273429, 0.001486},{1.197510, 1.273429, 0.000000}}],
    Polygon[{{1.196934, 1.270530, 0.001486},{1.196603, 1.270638, 0.002935},{
      1.197045, 1.273429, 0.002935},{1.197393, 1.273429, 0.001486}}],
    Polygon[{{1.196603, 1.270638, 0.002935},{1.196060, 1.270814, 0.004312},{
      1.196475, 1.273429, 0.004312},{1.197045, 1.273429, 0.002935}}],
    Polygon[{{1.196060, 1.270814, 0.004312},{1.195320, 1.271055, 0.005583},{
      1.195696, 1.273429, 0.005583},{1.196475, 1.273429, 0.004312}}],
    Polygon[{{1.195320, 1.271055, 0.005583},{1.194399, 1.271354, 0.006716},{
      1.194728, 1.273429, 0.006716},{1.195696, 1.273429, 0.005583}}],
    Polygon[{{1.194399, 1.271354, 0.006716},{1.193321, 1.271704, 0.007684},{
      1.193594, 1.273429, 0.007684},{1.194728, 1.273429, 0.006716}}],
    Polygon[{{1.193321, 1.271704, 0.007684},{1.192113, 1.272097, 0.008463},{
      1.192324, 1.273429, 0.008463},{1.193594, 1.273429, 0.007684}}],
    Polygon[{{1.192113, 1.272097, 0.008463},{1.190803, 1.272522, 0.009033},{
      1.190947, 1.273429, 0.009033},{1.192324, 1.273429, 0.008463}}],
    Polygon[{{1.190803, 1.272522, 0.009033},{1.189425, 1.272970, 0.009381},{
      1.189497, 1.273429, 0.009381},{1.190947, 1.273429, 0.009033}}],
    Polygon[{{1.126469, 1.167291, -0.024871},{1.130312, 1.167291, -0.023948},{
      1.129931, 1.169695, -0.023948},{1.126277, 1.168508, -0.024871}}],
    Polygon[{{1.130312, 1.167291, -0.023948},{1.133962, 1.167291, -0.022436},{
      1.133403, 1.170824, -0.022436},{1.129931, 1.169695, -0.023948}}],
    Polygon[{{1.133962, 1.167291, -0.022436},{1.137331, 1.167291, -0.020372},{
      1.136607, 1.171865, -0.020372},{1.133403, 1.170824, -0.022436}}],
    Polygon[{{1.137331, 1.167291, -0.020372},{1.140336, 1.167291, -0.017806},{
      1.139464, 1.172793, -0.017806},{1.136607, 1.171865, -0.020372}}],
    Polygon[{{1.140336, 1.167291, -0.017806},{1.142902, 1.167291, -0.014801},{
      1.141905, 1.173586, -0.014801},{1.139464, 1.172793, -0.017806}}],
    Polygon[{{1.142902, 1.167291, -0.014801},{1.144967, 1.167291, -0.011432},{
      1.143868, 1.174224, -0.011432},{1.141905, 1.173586, -0.014801}}],
    Polygon[{{1.144967, 1.167291, -0.011432},{1.146479, 1.167291, -0.007781},{
      1.145307, 1.174691, -0.007781},{1.143868, 1.174224, -0.011432}}],
    Polygon[{{1.146479, 1.167291, -0.007781},{1.147401, 1.167291, -0.003939},{
      1.146184, 1.174976, -0.003939},{1.145307, 1.174691, -0.007781}}],
    Polygon[{{1.147401, 1.167291, -0.003939},{1.147711, 1.167291, 0.000000},{
      1.146479, 1.175072, 0.000000},{1.146184, 1.174976, -0.003939}}],
    Polygon[{{1.147711, 1.167291, 0.000000},{1.147401, 1.167291, 0.003939},{
      1.146184, 1.174976, 0.003939},{1.146479, 1.175072, 0.000000}}],
    Polygon[{{1.147401, 1.167291, 0.003939},{1.146479, 1.167291, 0.007781},{
      1.145307, 1.174691, 0.007781},{1.146184, 1.174976, 0.003939}}],
    Polygon[{{1.146479, 1.167291, 0.007781},{1.144967, 1.167291, 0.011432},{
      1.143868, 1.174224, 0.011432},{1.145307, 1.174691, 0.007781}}],
    Polygon[{{1.144967, 1.167291, 0.011432},{1.142902, 1.167291, 0.014801},{
      1.141905, 1.173586, 0.014801},{1.143868, 1.174224, 0.011432}}],
    Polygon[{{1.142902, 1.167291, 0.014801},{1.140336, 1.167291, 0.017806},{
      1.139464, 1.172793, 0.017806},{1.141905, 1.173586, 0.014801}}],
    Polygon[{{1.140336, 1.167291, 0.017806},{1.137331, 1.167291, 0.020372},{
      1.136607, 1.171865, 0.020372},{1.139464, 1.172793, 0.017806}}],
    Polygon[{{1.137331, 1.167291, 0.020372},{1.133962, 1.167291, 0.022436},{
      1.133403, 1.170824, 0.022436},{1.136607, 1.171865, 0.020372}}],
    Polygon[{{1.133962, 1.167291, 0.022436},{1.130312, 1.167291, 0.023948},{
      1.129931, 1.169695, 0.023948},{1.133403, 1.170824, 0.022436}}],
    Polygon[{{1.130312, 1.167291, 0.023948},{1.126469, 1.167291, 0.024871},{
      1.126277, 1.168508, 0.024871},{1.129931, 1.169695, 0.023948}}],
    Polygon[{{1.126277, 1.168508, -0.024871},{1.129931, 1.169695, -0.023948},{
      1.128826, 1.171865, -0.023948},{1.125717, 1.169606, -0.024871}}],
    Polygon[{{1.129931, 1.169695, -0.023948},{1.133403, 1.170824, -0.022436},{
      1.131779, 1.174010, -0.022436},{1.128826, 1.171865, -0.023948}}],
    Polygon[{{1.133403, 1.170824, -0.022436},{1.136607, 1.171865, -0.020372},{
      1.134505, 1.175991, -0.020372},{1.131779, 1.174010, -0.022436}}],
    Polygon[{{1.136607, 1.171865, -0.020372},{1.139464, 1.172793, -0.017806},{
      1.136935, 1.177757, -0.017806},{1.134505, 1.175991, -0.020372}}],
    Polygon[{{1.139464, 1.172793, -0.017806},{1.141905, 1.173586, -0.014801},{
      1.139011, 1.179265, -0.014801},{1.136935, 1.177757, -0.017806}}],
    Polygon[{{1.141905, 1.173586, -0.014801},{1.143868, 1.174224, -0.011432},{
      1.140682, 1.180479, -0.011432},{1.139011, 1.179265, -0.014801}}],
    Polygon[{{1.143868, 1.174224, -0.011432},{1.145307, 1.174691, -0.007781},{
      1.141905, 1.181367, -0.007781},{1.140682, 1.180479, -0.011432}}],
    Polygon[{{1.145307, 1.174691, -0.007781},{1.146184, 1.174976, -0.003939},{
      1.142651, 1.181910, -0.003939},{1.141905, 1.181367, -0.007781}}],
    Polygon[{{1.146184, 1.174976, -0.003939},{1.146479, 1.175072, 0.000000},{
      1.142902, 1.182092, 0.000000},{1.142651, 1.181910, -0.003939}}],
    Polygon[{{1.146479, 1.175072, 0.000000},{1.146184, 1.174976, 0.003939},{
      1.142651, 1.181910, 0.003939},{1.142902, 1.182092, 0.000000}}],
    Polygon[{{1.146184, 1.174976, 0.003939},{1.145307, 1.174691, 0.007781},{
      1.141905, 1.181367, 0.007781},{1.142651, 1.181910, 0.003939}}],
    Polygon[{{1.145307, 1.174691, 0.007781},{1.143868, 1.174224, 0.011432},{
      1.140682, 1.180479, 0.011432},{1.141905, 1.181367, 0.007781}}],
    Polygon[{{1.143868, 1.174224, 0.011432},{1.141905, 1.173586, 0.014801},{
      1.139011, 1.179265, 0.014801},{1.140682, 1.180479, 0.011432}}],
    Polygon[{{1.141905, 1.173586, 0.014801},{1.139464, 1.172793, 0.017806},{
      1.136935, 1.177757, 0.017806},{1.139011, 1.179265, 0.014801}}],
    Polygon[{{1.139464, 1.172793, 0.017806},{1.136607, 1.171865, 0.020372},{
      1.134505, 1.175991, 0.020372},{1.136935, 1.177757, 0.017806}}],
    Polygon[{{1.136607, 1.171865, 0.020372},{1.133403, 1.170824, 0.022436},{
      1.131779, 1.174010, 0.022436},{1.134505, 1.175991, 0.020372}}],
    Polygon[{{1.133403, 1.170824, 0.022436},{1.129931, 1.169695, 0.023948},{
      1.128826, 1.171865, 0.023948},{1.131779, 1.174010, 0.022436}}],
    Polygon[{{1.129931, 1.169695, 0.023948},{1.126277, 1.168508, 0.024871},{
      1.125717, 1.169606, 0.024871},{1.128826, 1.171865, 0.023948}}],
    Polygon[{{1.125717, 1.169606, -0.024871},{1.128826, 1.171865, -0.023948},{
      1.127104, 1.173586, -0.023948},{1.124846, 1.170478, -0.024871}}],
    Polygon[{{1.128826, 1.171865, -0.023948},{1.131779, 1.174010, -0.022436},{
      1.129250, 1.176540, -0.022436},{1.127104, 1.173586, -0.023948}}],
    Polygon[{{1.131779, 1.174010, -0.022436},{1.134505, 1.175991, -0.020372},{
      1.131230, 1.179265, -0.020372},{1.129250, 1.176540, -0.022436}}],
    Polygon[{{1.134505, 1.175991, -0.020372},{1.136935, 1.177757, -0.017806},{
      1.132996, 1.181696, -0.017806},{1.131230, 1.179265, -0.020372}}],
    Polygon[{{1.136935, 1.177757, -0.017806},{1.139011, 1.179265, -0.014801},{
      1.134505, 1.183772, -0.014801},{1.132996, 1.181696, -0.017806}}],
    Polygon[{{1.139011, 1.179265, -0.014801},{1.140682, 1.180479, -0.011432},{
      1.135718, 1.185442, -0.011432},{1.134505, 1.183772, -0.014801}}],
    Polygon[{{1.140682, 1.180479, -0.011432},{1.141905, 1.181367, -0.007781},{
      1.136607, 1.186666, -0.007781},{1.135718, 1.185442, -0.011432}}],
    Polygon[{{1.141905, 1.181367, -0.007781},{1.142651, 1.181910, -0.003939},{
      1.137149, 1.187412, -0.003939},{1.136607, 1.186666, -0.007781}}],
    Polygon[{{1.142651, 1.181910, -0.003939},{1.142902, 1.182092, 0.000000},{
      1.137331, 1.187663, 0.000000},{1.137149, 1.187412, -0.003939}}],
    Polygon[{{1.142902, 1.182092, 0.000000},{1.142651, 1.181910, 0.003939},{
      1.137149, 1.187412, 0.003939},{1.137331, 1.187663, 0.000000}}],
    Polygon[{{1.142651, 1.181910, 0.003939},{1.141905, 1.181367, 0.007781},{
      1.136607, 1.186666, 0.007781},{1.137149, 1.187412, 0.003939}}],
    Polygon[{{1.141905, 1.181367, 0.007781},{1.140682, 1.180479, 0.011432},{
      1.135718, 1.185442, 0.011432},{1.136607, 1.186666, 0.007781}}],
    Polygon[{{1.140682, 1.180479, 0.011432},{1.139011, 1.179265, 0.014801},{
      1.134505, 1.183772, 0.014801},{1.135718, 1.185442, 0.011432}}],
    Polygon[{{1.139011, 1.179265, 0.014801},{1.136935, 1.177757, 0.017806},{
      1.132996, 1.181696, 0.017806},{1.134505, 1.183772, 0.014801}}],
    Polygon[{{1.136935, 1.177757, 0.017806},{1.134505, 1.175991, 0.020372},{
      1.131230, 1.179265, 0.020372},{1.132996, 1.181696, 0.017806}}],
    Polygon[{{1.134505, 1.175991, 0.020372},{1.131779, 1.174010, 0.022436},{
      1.129250, 1.176540, 0.022436},{1.131230, 1.179265, 0.020372}}],
    Polygon[{{1.131779, 1.174010, 0.022436},{1.128826, 1.171865, 0.023948},{
      1.127104, 1.173586, 0.023948},{1.129250, 1.176540, 0.022436}}],
    Polygon[{{1.128826, 1.171865, 0.023948},{1.125717, 1.169606, 0.024871},{
      1.124846, 1.170478, 0.024871},{1.127104, 1.173586, 0.023948}}],
    Polygon[{{1.124846, 1.170478, -0.024871},{1.127104, 1.173586, -0.023948},{
      1.124935, 1.174691, -0.023948},{1.123748, 1.171037, -0.024871}}],
    Polygon[{{1.127104, 1.173586, -0.023948},{1.129250, 1.176540, -0.022436},{
      1.126063, 1.178163, -0.022436},{1.124935, 1.174691, -0.023948}}],
    Polygon[{{1.129250, 1.176540, -0.022436},{1.131230, 1.179265, -0.020372},{
      1.127104, 1.181367, -0.020372},{1.126063, 1.178163, -0.022436}}],
    Polygon[{{1.131230, 1.179265, -0.020372},{1.132996, 1.181696, -0.017806},{
      1.128033, 1.184225, -0.017806},{1.127104, 1.181367, -0.020372}}],
    Polygon[{{1.132996, 1.181696, -0.017806},{1.134505, 1.183772, -0.014801},{
      1.128826, 1.186666, -0.014801},{1.128033, 1.184225, -0.017806}}],
    Polygon[{{1.134505, 1.183772, -0.014801},{1.135718, 1.185442, -0.011432},{
      1.129464, 1.188629, -0.011432},{1.128826, 1.186666, -0.014801}}],
    Polygon[{{1.135718, 1.185442, -0.011432},{1.136607, 1.186666, -0.007781},{
      1.129931, 1.190067, -0.007781},{1.129464, 1.188629, -0.011432}}],
    Polygon[{{1.136607, 1.186666, -0.007781},{1.137149, 1.187412, -0.003939},{
      1.130216, 1.190944, -0.003939},{1.129931, 1.190067, -0.007781}}],
    Polygon[{{1.137149, 1.187412, -0.003939},{1.137331, 1.187663, 0.000000},{
      1.130312, 1.191239, 0.000000},{1.130216, 1.190944, -0.003939}}],
    Polygon[{{1.137331, 1.187663, 0.000000},{1.137149, 1.187412, 0.003939},{
      1.130216, 1.190944, 0.003939},{1.130312, 1.191239, 0.000000}}],
    Polygon[{{1.137149, 1.187412, 0.003939},{1.136607, 1.186666, 0.007781},{
      1.129931, 1.190067, 0.007781},{1.130216, 1.190944, 0.003939}}],
    Polygon[{{1.136607, 1.186666, 0.007781},{1.135718, 1.185442, 0.011432},{
      1.129464, 1.188629, 0.011432},{1.129931, 1.190067, 0.007781}}],
    Polygon[{{1.135718, 1.185442, 0.011432},{1.134505, 1.183772, 0.014801},{
      1.128826, 1.186666, 0.014801},{1.129464, 1.188629, 0.011432}}],
    Polygon[{{1.134505, 1.183772, 0.014801},{1.132996, 1.181696, 0.017806},{
      1.128033, 1.184225, 0.017806},{1.128826, 1.186666, 0.014801}}],
    Polygon[{{1.132996, 1.181696, 0.017806},{1.131230, 1.179265, 0.020372},{
      1.127104, 1.181367, 0.020372},{1.128033, 1.184225, 0.017806}}],
    Polygon[{{1.131230, 1.179265, 0.020372},{1.129250, 1.176540, 0.022436},{
      1.126063, 1.178163, 0.022436},{1.127104, 1.181367, 0.020372}}],
    Polygon[{{1.129250, 1.176540, 0.022436},{1.127104, 1.173586, 0.023948},{
      1.124935, 1.174691, 0.023948},{1.126063, 1.178163, 0.022436}}],
    Polygon[{{1.127104, 1.173586, 0.023948},{1.124846, 1.170478, 0.024871},{
      1.123748, 1.171037, 0.024871},{1.124935, 1.174691, 0.023948}}],
    Polygon[{{1.123748, 1.171037, -0.024871},{1.124935, 1.174691, -0.023948},{
      1.122530, 1.175072, -0.023948},{1.122530, 1.171230, -0.024871}}],
    Polygon[{{1.124935, 1.174691, -0.023948},{1.126063, 1.178163, -0.022436},{
      1.122530, 1.178723, -0.022436},{1.122530, 1.175072, -0.023948}}],
    Polygon[{{1.126063, 1.178163, -0.022436},{1.127104, 1.181367, -0.020372},{
      1.122530, 1.182092, -0.020372},{1.122530, 1.178723, -0.022436}}],
    Polygon[{{1.127104, 1.181367, -0.020372},{1.128033, 1.184225, -0.017806},{
      1.122530, 1.185096, -0.017806},{1.122530, 1.182092, -0.020372}}],
    Polygon[{{1.128033, 1.184225, -0.017806},{1.128826, 1.186666, -0.014801},{
      1.122530, 1.187663, -0.014801},{1.122530, 1.185096, -0.017806}}],
    Polygon[{{1.128826, 1.186666, -0.014801},{1.129464, 1.188629, -0.011432},{
      1.122530, 1.189727, -0.011432},{1.122530, 1.187663, -0.014801}}],
    Polygon[{{1.129464, 1.188629, -0.011432},{1.129931, 1.190067, -0.007781},{
      1.122530, 1.191239, -0.007781},{1.122530, 1.189727, -0.011432}}],
    Polygon[{{1.129931, 1.190067, -0.007781},{1.130216, 1.190944, -0.003939},{
      1.122530, 1.192162, -0.003939},{1.122530, 1.191239, -0.007781}}],
    Polygon[{{1.130216, 1.190944, -0.003939},{1.130312, 1.191239, 0.000000},{
      1.122530, 1.192472, 0.000000},{1.122530, 1.192162, -0.003939}}],
    Polygon[{{1.130312, 1.191239, 0.000000},{1.130216, 1.190944, 0.003939},{
      1.122530, 1.192162, 0.003939},{1.122530, 1.192472, 0.000000}}],
    Polygon[{{1.130216, 1.190944, 0.003939},{1.129931, 1.190067, 0.007781},{
      1.122530, 1.191239, 0.007781},{1.122530, 1.192162, 0.003939}}],
    Polygon[{{1.129931, 1.190067, 0.007781},{1.129464, 1.188629, 0.011432},{
      1.122530, 1.189727, 0.011432},{1.122530, 1.191239, 0.007781}}],
    Polygon[{{1.129464, 1.188629, 0.011432},{1.128826, 1.186666, 0.014801},{
      1.122530, 1.187663, 0.014801},{1.122530, 1.189727, 0.011432}}],
    Polygon[{{1.128826, 1.186666, 0.014801},{1.128033, 1.184225, 0.017806},{
      1.122530, 1.185096, 0.017806},{1.122530, 1.187663, 0.014801}}],
    Polygon[{{1.128033, 1.184225, 0.017806},{1.127104, 1.181367, 0.020372},{
      1.122530, 1.182092, 0.020372},{1.122530, 1.185096, 0.017806}}],
    Polygon[{{1.127104, 1.181367, 0.020372},{1.126063, 1.178163, 0.022436},{
      1.122530, 1.178723, 0.022436},{1.122530, 1.182092, 0.020372}}],
    Polygon[{{1.126063, 1.178163, 0.022436},{1.124935, 1.174691, 0.023948},{
      1.122530, 1.175072, 0.023948},{1.122530, 1.178723, 0.022436}}],
    Polygon[{{1.124935, 1.174691, 0.023948},{1.123748, 1.171037, 0.024871},{
      1.122530, 1.171230, 0.024871},{1.122530, 1.175072, 0.023948}}],
    Polygon[{{1.122530, 1.171230, -0.024871},{1.122530, 1.175072, -0.023948},{
      1.120126, 1.174691, -0.023948},{1.121313, 1.171037, -0.024871}}],
    Polygon[{{1.122530, 1.175072, -0.023948},{1.122530, 1.178723, -0.022436},{
      1.118998, 1.178163, -0.022436},{1.120126, 1.174691, -0.023948}}],
    Polygon[{{1.122530, 1.178723, -0.022436},{1.122530, 1.182092, -0.020372},{
      1.117957, 1.181367, -0.020372},{1.118998, 1.178163, -0.022436}}],
    Polygon[{{1.122530, 1.182092, -0.020372},{1.122530, 1.185096, -0.017806},{
      1.117028, 1.184225, -0.017806},{1.117957, 1.181367, -0.020372}}],
    Polygon[{{1.122530, 1.185096, -0.017806},{1.122530, 1.187663, -0.014801},{
      1.116235, 1.186666, -0.014801},{1.117028, 1.184225, -0.017806}}],
    Polygon[{{1.122530, 1.187663, -0.014801},{1.122530, 1.189727, -0.011432},{
      1.115597, 1.188629, -0.011432},{1.116235, 1.186666, -0.014801}}],
    Polygon[{{1.122530, 1.189727, -0.011432},{1.122530, 1.191239, -0.007781},{
      1.115130, 1.190067, -0.007781},{1.115597, 1.188629, -0.011432}}],
    Polygon[{{1.122530, 1.191239, -0.007781},{1.122530, 1.192162, -0.003939},{
      1.114845, 1.190944, -0.003939},{1.115130, 1.190067, -0.007781}}],
    Polygon[{{1.122530, 1.192162, -0.003939},{1.122530, 1.192472, 0.000000},{
      1.114749, 1.191239, 0.000000},{1.114845, 1.190944, -0.003939}}],
    Polygon[{{1.122530, 1.192472, 0.000000},{1.122530, 1.192162, 0.003939},{
      1.114845, 1.190944, 0.003939},{1.114749, 1.191239, 0.000000}}],
    Polygon[{{1.122530, 1.192162, 0.003939},{1.122530, 1.191239, 0.007781},{
      1.115130, 1.190067, 0.007781},{1.114845, 1.190944, 0.003939}}],
    Polygon[{{1.122530, 1.191239, 0.007781},{1.122530, 1.189727, 0.011432},{
      1.115597, 1.188629, 0.011432},{1.115130, 1.190067, 0.007781}}],
    Polygon[{{1.122530, 1.189727, 0.011432},{1.122530, 1.187663, 0.014801},{
      1.116235, 1.186666, 0.014801},{1.115597, 1.188629, 0.011432}}],
    Polygon[{{1.122530, 1.187663, 0.014801},{1.122530, 1.185096, 0.017806},{
      1.117028, 1.184225, 0.017806},{1.116235, 1.186666, 0.014801}}],
    Polygon[{{1.122530, 1.185096, 0.017806},{1.122530, 1.182092, 0.020372},{
      1.117957, 1.181367, 0.020372},{1.117028, 1.184225, 0.017806}}],
    Polygon[{{1.122530, 1.182092, 0.020372},{1.122530, 1.178723, 0.022436},{
      1.118998, 1.178163, 0.022436},{1.117957, 1.181367, 0.020372}}],
    Polygon[{{1.122530, 1.178723, 0.022436},{1.122530, 1.175072, 0.023948},{
      1.120126, 1.174691, 0.023948},{1.118998, 1.178163, 0.022436}}],
    Polygon[{{1.122530, 1.175072, 0.023948},{1.122530, 1.171230, 0.024871},{
      1.121313, 1.171037, 0.024871},{1.120126, 1.174691, 0.023948}}],
    Polygon[{{1.121313, 1.171037, -0.024871},{1.120126, 1.174691, -0.023948},{
      1.117957, 1.173586, -0.023948},{1.120215, 1.170478, -0.024871}}],
    Polygon[{{1.120126, 1.174691, -0.023948},{1.118998, 1.178163, -0.022436},{
      1.115811, 1.176540, -0.022436},{1.117957, 1.173586, -0.023948}}],
    Polygon[{{1.118998, 1.178163, -0.022436},{1.117957, 1.181367, -0.020372},{
      1.113831, 1.179265, -0.020372},{1.115811, 1.176540, -0.022436}}],
    Polygon[{{1.117957, 1.181367, -0.020372},{1.117028, 1.184225, -0.017806},{
      1.112065, 1.181696, -0.017806},{1.113831, 1.179265, -0.020372}}],
    Polygon[{{1.117028, 1.184225, -0.017806},{1.116235, 1.186666, -0.014801},{
      1.110556, 1.183772, -0.014801},{1.112065, 1.181696, -0.017806}}],
    Polygon[{{1.116235, 1.186666, -0.014801},{1.115597, 1.188629, -0.011432},{
      1.109343, 1.185442, -0.011432},{1.110556, 1.183772, -0.014801}}],
    Polygon[{{1.115597, 1.188629, -0.011432},{1.115130, 1.190067, -0.007781},{
      1.108454, 1.186666, -0.007781},{1.109343, 1.185442, -0.011432}}],
    Polygon[{{1.115130, 1.190067, -0.007781},{1.114845, 1.190944, -0.003939},{
      1.107912, 1.187412, -0.003939},{1.108454, 1.186666, -0.007781}}],
    Polygon[{{1.114845, 1.190944, -0.003939},{1.114749, 1.191239, 0.000000},{
      1.107729, 1.187663, 0.000000},{1.107912, 1.187412, -0.003939}}],
    Polygon[{{1.114749, 1.191239, 0.000000},{1.114845, 1.190944, 0.003939},{
      1.107912, 1.187412, 0.003939},{1.107729, 1.187663, 0.000000}}],
    Polygon[{{1.114845, 1.190944, 0.003939},{1.115130, 1.190067, 0.007781},{
      1.108454, 1.186666, 0.007781},{1.107912, 1.187412, 0.003939}}],
    Polygon[{{1.115130, 1.190067, 0.007781},{1.115597, 1.188629, 0.011432},{
      1.109343, 1.185442, 0.011432},{1.108454, 1.186666, 0.007781}}],
    Polygon[{{1.115597, 1.188629, 0.011432},{1.116235, 1.186666, 0.014801},{
      1.110556, 1.183772, 0.014801},{1.109343, 1.185442, 0.011432}}],
    Polygon[{{1.116235, 1.186666, 0.014801},{1.117028, 1.184225, 0.017806},{
      1.112065, 1.181696, 0.017806},{1.110556, 1.183772, 0.014801}}],
    Polygon[{{1.117028, 1.184225, 0.017806},{1.117957, 1.181367, 0.020372},{
      1.113831, 1.179265, 0.020372},{1.112065, 1.181696, 0.017806}}],
    Polygon[{{1.117957, 1.181367, 0.020372},{1.118998, 1.178163, 0.022436},{
      1.115811, 1.176540, 0.022436},{1.113831, 1.179265, 0.020372}}],
    Polygon[{{1.118998, 1.178163, 0.022436},{1.120126, 1.174691, 0.023948},{
      1.117957, 1.173586, 0.023948},{1.115811, 1.176540, 0.022436}}],
    Polygon[{{1.120126, 1.174691, 0.023948},{1.121313, 1.171037, 0.024871},{
      1.120215, 1.170478, 0.024871},{1.117957, 1.173586, 0.023948}}],
    Polygon[{{1.120215, 1.170478, -0.024871},{1.117957, 1.173586, -0.023948},{
      1.116235, 1.171865, -0.023948},{1.119344, 1.169606, -0.024871}}],
    Polygon[{{1.117957, 1.173586, -0.023948},{1.115811, 1.176540, -0.022436},{
      1.113282, 1.174010, -0.022436},{1.116235, 1.171865, -0.023948}}],
    Polygon[{{1.115811, 1.176540, -0.022436},{1.113831, 1.179265, -0.020372},{
      1.110556, 1.175991, -0.020372},{1.113282, 1.174010, -0.022436}}],
    Polygon[{{1.113831, 1.179265, -0.020372},{1.112065, 1.181696, -0.017806},{
      1.108125, 1.177757, -0.017806},{1.110556, 1.175991, -0.020372}}],
    Polygon[{{1.112065, 1.181696, -0.017806},{1.110556, 1.183772, -0.014801},{
      1.106049, 1.179265, -0.014801},{1.108125, 1.177757, -0.017806}}],
    Polygon[{{1.110556, 1.183772, -0.014801},{1.109343, 1.185442, -0.011432},{
      1.104379, 1.180479, -0.011432},{1.106049, 1.179265, -0.014801}}],
    Polygon[{{1.109343, 1.185442, -0.011432},{1.108454, 1.186666, -0.007781},{
      1.103156, 1.181367, -0.007781},{1.104379, 1.180479, -0.011432}}],
    Polygon[{{1.108454, 1.186666, -0.007781},{1.107912, 1.187412, -0.003939},{
      1.102409, 1.181910, -0.003939},{1.103156, 1.181367, -0.007781}}],
    Polygon[{{1.107912, 1.187412, -0.003939},{1.107729, 1.187663, 0.000000},{
      1.102159, 1.182092, 0.000000},{1.102409, 1.181910, -0.003939}}],
    Polygon[{{1.107729, 1.187663, 0.000000},{1.107912, 1.187412, 0.003939},{
      1.102409, 1.181910, 0.003939},{1.102159, 1.182092, 0.000000}}],
    Polygon[{{1.107912, 1.187412, 0.003939},{1.108454, 1.186666, 0.007781},{
      1.103156, 1.181367, 0.007781},{1.102409, 1.181910, 0.003939}}],
    Polygon[{{1.108454, 1.186666, 0.007781},{1.109343, 1.185442, 0.011432},{
      1.104379, 1.180479, 0.011432},{1.103156, 1.181367, 0.007781}}],
    Polygon[{{1.109343, 1.185442, 0.011432},{1.110556, 1.183772, 0.014801},{
      1.106049, 1.179265, 0.014801},{1.104379, 1.180479, 0.011432}}],
    Polygon[{{1.110556, 1.183772, 0.014801},{1.112065, 1.181696, 0.017806},{
      1.108125, 1.177757, 0.017806},{1.106049, 1.179265, 0.014801}}],
    Polygon[{{1.112065, 1.181696, 0.017806},{1.113831, 1.179265, 0.020372},{
      1.110556, 1.175991, 0.020372},{1.108125, 1.177757, 0.017806}}],
    Polygon[{{1.113831, 1.179265, 0.020372},{1.115811, 1.176540, 0.022436},{
      1.113282, 1.174010, 0.022436},{1.110556, 1.175991, 0.020372}}],
    Polygon[{{1.115811, 1.176540, 0.022436},{1.117957, 1.173586, 0.023948},{
      1.116235, 1.171865, 0.023948},{1.113282, 1.174010, 0.022436}}],
    Polygon[{{1.117957, 1.173586, 0.023948},{1.120215, 1.170478, 0.024871},{
      1.119344, 1.169606, 0.024871},{1.116235, 1.171865, 0.023948}}],
    Polygon[{{1.119344, 1.169606, -0.024871},{1.116235, 1.171865, -0.023948},{
      1.115130, 1.169695, -0.023948},{1.118784, 1.168508, -0.024871}}],
    Polygon[{{1.116235, 1.171865, -0.023948},{1.113282, 1.174010, -0.022436},{
      1.111658, 1.170824, -0.022436},{1.115130, 1.169695, -0.023948}}],
    Polygon[{{1.113282, 1.174010, -0.022436},{1.110556, 1.175991, -0.020372},{
      1.108454, 1.171865, -0.020372},{1.111658, 1.170824, -0.022436}}],
    Polygon[{{1.110556, 1.175991, -0.020372},{1.108125, 1.177757, -0.017806},{
      1.105596, 1.172793, -0.017806},{1.108454, 1.171865, -0.020372}}],
    Polygon[{{1.108125, 1.177757, -0.017806},{1.106049, 1.179265, -0.014801},{
      1.103156, 1.173586, -0.014801},{1.105596, 1.172793, -0.017806}}],
    Polygon[{{1.106049, 1.179265, -0.014801},{1.104379, 1.180479, -0.011432},{
      1.101192, 1.174224, -0.011432},{1.103156, 1.173586, -0.014801}}],
    Polygon[{{1.104379, 1.180479, -0.011432},{1.103156, 1.181367, -0.007781},{
      1.099754, 1.174691, -0.007781},{1.101192, 1.174224, -0.011432}}],
    Polygon[{{1.103156, 1.181367, -0.007781},{1.102409, 1.181910, -0.003939},{
      1.098877, 1.174976, -0.003939},{1.099754, 1.174691, -0.007781}}],
    Polygon[{{1.102409, 1.181910, -0.003939},{1.102159, 1.182092, 0.000000},{
      1.098582, 1.175072, 0.000000},{1.098877, 1.174976, -0.003939}}],
    Polygon[{{1.102159, 1.182092, 0.000000},{1.102409, 1.181910, 0.003939},{
      1.098877, 1.174976, 0.003939},{1.098582, 1.175072, 0.000000}}],
    Polygon[{{1.102409, 1.181910, 0.003939},{1.103156, 1.181367, 0.007781},{
      1.099754, 1.174691, 0.007781},{1.098877, 1.174976, 0.003939}}],
    Polygon[{{1.103156, 1.181367, 0.007781},{1.104379, 1.180479, 0.011432},{
      1.101192, 1.174224, 0.011432},{1.099754, 1.174691, 0.007781}}],
    Polygon[{{1.104379, 1.180479, 0.011432},{1.106049, 1.179265, 0.014801},{
      1.103156, 1.173586, 0.014801},{1.101192, 1.174224, 0.011432}}],
    Polygon[{{1.106049, 1.179265, 0.014801},{1.108125, 1.177757, 0.017806},{
      1.105596, 1.172793, 0.017806},{1.103156, 1.173586, 0.014801}}],
    Polygon[{{1.108125, 1.177757, 0.017806},{1.110556, 1.175991, 0.020372},{
      1.108454, 1.171865, 0.020372},{1.105596, 1.172793, 0.017806}}],
    Polygon[{{1.110556, 1.175991, 0.020372},{1.113282, 1.174010, 0.022436},{
      1.111658, 1.170824, 0.022436},{1.108454, 1.171865, 0.020372}}],
    Polygon[{{1.113282, 1.174010, 0.022436},{1.116235, 1.171865, 0.023948},{
      1.115130, 1.169695, 0.023948},{1.111658, 1.170824, 0.022436}}],
    Polygon[{{1.116235, 1.171865, 0.023948},{1.119344, 1.169606, 0.024871},{
      1.118784, 1.168508, 0.024871},{1.115130, 1.169695, 0.023948}}],
    Polygon[{{1.118784, 1.168508, -0.024871},{1.115130, 1.169695, -0.023948},{
      1.114749, 1.167291, -0.023948},{1.118591, 1.167291, -0.024871}}],
    Polygon[{{1.115130, 1.169695, -0.023948},{1.111658, 1.170824, -0.022436},{
      1.111099, 1.167291, -0.022436},{1.114749, 1.167291, -0.023948}}],
    Polygon[{{1.111658, 1.170824, -0.022436},{1.108454, 1.171865, -0.020372},{
      1.107729, 1.167291, -0.020372},{1.111099, 1.167291, -0.022436}}],
    Polygon[{{1.108454, 1.171865, -0.020372},{1.105596, 1.172793, -0.017806},{
      1.104725, 1.167291, -0.017806},{1.107729, 1.167291, -0.020372}}],
    Polygon[{{1.105596, 1.172793, -0.017806},{1.103156, 1.173586, -0.014801},{
      1.102159, 1.167291, -0.014801},{1.104725, 1.167291, -0.017806}}],
    Polygon[{{1.103156, 1.173586, -0.014801},{1.101192, 1.174224, -0.011432},{
      1.100094, 1.167291, -0.011432},{1.102159, 1.167291, -0.014801}}],
    Polygon[{{1.101192, 1.174224, -0.011432},{1.099754, 1.174691, -0.007781},{
      1.098582, 1.167291, -0.007781},{1.100094, 1.167291, -0.011432}}],
    Polygon[{{1.099754, 1.174691, -0.007781},{1.098877, 1.174976, -0.003939},{
      1.097660, 1.167291, -0.003939},{1.098582, 1.167291, -0.007781}}],
    Polygon[{{1.098877, 1.174976, -0.003939},{1.098582, 1.175072, 0.000000},{
      1.097350, 1.167291, 0.000000},{1.097660, 1.167291, -0.003939}}],
    Polygon[{{1.098582, 1.175072, 0.000000},{1.098877, 1.174976, 0.003939},{
      1.097660, 1.167291, 0.003939},{1.097350, 1.167291, 0.000000}}],
    Polygon[{{1.098877, 1.174976, 0.003939},{1.099754, 1.174691, 0.007781},{
      1.098582, 1.167291, 0.007781},{1.097660, 1.167291, 0.003939}}],
    Polygon[{{1.099754, 1.174691, 0.007781},{1.101192, 1.174224, 0.011432},{
      1.100094, 1.167291, 0.011432},{1.098582, 1.167291, 0.007781}}],
    Polygon[{{1.101192, 1.174224, 0.011432},{1.103156, 1.173586, 0.014801},{
      1.102159, 1.167291, 0.014801},{1.100094, 1.167291, 0.011432}}],
    Polygon[{{1.103156, 1.173586, 0.014801},{1.105596, 1.172793, 0.017806},{
      1.104725, 1.167291, 0.017806},{1.102159, 1.167291, 0.014801}}],
    Polygon[{{1.105596, 1.172793, 0.017806},{1.108454, 1.171865, 0.020372},{
      1.107729, 1.167291, 0.020372},{1.104725, 1.167291, 0.017806}}],
    Polygon[{{1.108454, 1.171865, 0.020372},{1.111658, 1.170824, 0.022436},{
      1.111099, 1.167291, 0.022436},{1.107729, 1.167291, 0.020372}}],
    Polygon[{{1.111658, 1.170824, 0.022436},{1.115130, 1.169695, 0.023948},{
      1.114749, 1.167291, 0.023948},{1.111099, 1.167291, 0.022436}}],
    Polygon[{{1.115130, 1.169695, 0.023948},{1.118784, 1.168508, 0.024871},{
      1.118591, 1.167291, 0.024871},{1.114749, 1.167291, 0.023948}}],
    Polygon[{{1.118591, 1.167291, -0.024871},{1.114749, 1.167291, -0.023948},{
      1.115130, 1.164886, -0.023948},{1.118784, 1.166074, -0.024871}}],
    Polygon[{{1.114749, 1.167291, -0.023948},{1.111099, 1.167291, -0.022436},{
      1.111658, 1.163758, -0.022436},{1.115130, 1.164886, -0.023948}}],
    Polygon[{{1.111099, 1.167291, -0.022436},{1.107729, 1.167291, -0.020372},{
      1.108454, 1.162717, -0.020372},{1.111658, 1.163758, -0.022436}}],
    Polygon[{{1.107729, 1.167291, -0.020372},{1.104725, 1.167291, -0.017806},{
      1.105596, 1.161789, -0.017806},{1.108454, 1.162717, -0.020372}}],
    Polygon[{{1.104725, 1.167291, -0.017806},{1.102159, 1.167291, -0.014801},{
      1.103156, 1.160996, -0.014801},{1.105596, 1.161789, -0.017806}}],
    Polygon[{{1.102159, 1.167291, -0.014801},{1.100094, 1.167291, -0.011432},{
      1.101192, 1.160358, -0.011432},{1.103156, 1.160996, -0.014801}}],
    Polygon[{{1.100094, 1.167291, -0.011432},{1.098582, 1.167291, -0.007781},{
      1.099754, 1.159891, -0.007781},{1.101192, 1.160358, -0.011432}}],
    Polygon[{{1.098582, 1.167291, -0.007781},{1.097660, 1.167291, -0.003939},{
      1.098877, 1.159605, -0.003939},{1.099754, 1.159891, -0.007781}}],
    Polygon[{{1.097660, 1.167291, -0.003939},{1.097350, 1.167291, 0.000000},{
      1.098582, 1.159510, 0.000000},{1.098877, 1.159605, -0.003939}}],
    Polygon[{{1.097350, 1.167291, 0.000000},{1.097660, 1.167291, 0.003939},{
      1.098877, 1.159605, 0.003939},{1.098582, 1.159510, 0.000000}}],
    Polygon[{{1.097660, 1.167291, 0.003939},{1.098582, 1.167291, 0.007781},{
      1.099754, 1.159891, 0.007781},{1.098877, 1.159605, 0.003939}}],
    Polygon[{{1.098582, 1.167291, 0.007781},{1.100094, 1.167291, 0.011432},{
      1.101192, 1.160358, 0.011432},{1.099754, 1.159891, 0.007781}}],
    Polygon[{{1.100094, 1.167291, 0.011432},{1.102159, 1.167291, 0.014801},{
      1.103156, 1.160996, 0.014801},{1.101192, 1.160358, 0.011432}}],
    Polygon[{{1.102159, 1.167291, 0.014801},{1.104725, 1.167291, 0.017806},{
      1.105596, 1.161789, 0.017806},{1.103156, 1.160996, 0.014801}}],
    Polygon[{{1.104725, 1.167291, 0.017806},{1.107729, 1.167291, 0.020372},{
      1.108454, 1.162717, 0.020372},{1.105596, 1.161789, 0.017806}}],
    Polygon[{{1.107729, 1.167291, 0.020372},{1.111099, 1.167291, 0.022436},{
      1.111658, 1.163758, 0.022436},{1.108454, 1.162717, 0.020372}}],
    Polygon[{{1.111099, 1.167291, 0.022436},{1.114749, 1.167291, 0.023948},{
      1.115130, 1.164886, 0.023948},{1.111658, 1.163758, 0.022436}}],
    Polygon[{{1.114749, 1.167291, 0.023948},{1.118591, 1.167291, 0.024871},{
      1.118784, 1.166074, 0.024871},{1.115130, 1.164886, 0.023948}}],
    Polygon[{{1.118784, 1.166074, -0.024871},{1.115130, 1.164886, -0.023948},{
      1.116235, 1.162717, -0.023948},{1.119344, 1.164976, -0.024871}}],
    Polygon[{{1.115130, 1.164886, -0.023948},{1.111658, 1.163758, -0.022436},{
      1.113282, 1.160571, -0.022436},{1.116235, 1.162717, -0.023948}}],
    Polygon[{{1.111658, 1.163758, -0.022436},{1.108454, 1.162717, -0.020372},{
      1.110556, 1.158591, -0.020372},{1.113282, 1.160571, -0.022436}}],
    Polygon[{{1.108454, 1.162717, -0.020372},{1.105596, 1.161789, -0.017806},{
      1.108125, 1.156825, -0.017806},{1.110556, 1.158591, -0.020372}}],
    Polygon[{{1.105596, 1.161789, -0.017806},{1.103156, 1.160996, -0.014801},{
      1.106049, 1.155317, -0.014801},{1.108125, 1.156825, -0.017806}}],
    Polygon[{{1.103156, 1.160996, -0.014801},{1.101192, 1.160358, -0.011432},{
      1.104379, 1.154103, -0.011432},{1.106049, 1.155317, -0.014801}}],
    Polygon[{{1.101192, 1.160358, -0.011432},{1.099754, 1.159891, -0.007781},{
      1.103156, 1.153214, -0.007781},{1.104379, 1.154103, -0.011432}}],
    Polygon[{{1.099754, 1.159891, -0.007781},{1.098877, 1.159605, -0.003939},{
      1.102409, 1.152672, -0.003939},{1.103156, 1.153214, -0.007781}}],
    Polygon[{{1.098877, 1.159605, -0.003939},{1.098582, 1.159510, 0.000000},{
      1.102159, 1.152490, 0.000000},{1.102409, 1.152672, -0.003939}}],
    Polygon[{{1.098582, 1.159510, 0.000000},{1.098877, 1.159605, 0.003939},{
      1.102409, 1.152672, 0.003939},{1.102159, 1.152490, 0.000000}}],
    Polygon[{{1.098877, 1.159605, 0.003939},{1.099754, 1.159891, 0.007781},{
      1.103156, 1.153214, 0.007781},{1.102409, 1.152672, 0.003939}}],
    Polygon[{{1.099754, 1.159891, 0.007781},{1.101192, 1.160358, 0.011432},{
      1.104379, 1.154103, 0.011432},{1.103156, 1.153214, 0.007781}}],
    Polygon[{{1.101192, 1.160358, 0.011432},{1.103156, 1.160996, 0.014801},{
      1.106049, 1.155317, 0.014801},{1.104379, 1.154103, 0.011432}}],
    Polygon[{{1.103156, 1.160996, 0.014801},{1.105596, 1.161789, 0.017806},{
      1.108125, 1.156825, 0.017806},{1.106049, 1.155317, 0.014801}}],
    Polygon[{{1.105596, 1.161789, 0.017806},{1.108454, 1.162717, 0.020372},{
      1.110556, 1.158591, 0.020372},{1.108125, 1.156825, 0.017806}}],
    Polygon[{{1.108454, 1.162717, 0.020372},{1.111658, 1.163758, 0.022436},{
      1.113282, 1.160571, 0.022436},{1.110556, 1.158591, 0.020372}}],
    Polygon[{{1.111658, 1.163758, 0.022436},{1.115130, 1.164886, 0.023948},{
      1.116235, 1.162717, 0.023948},{1.113282, 1.160571, 0.022436}}],
    Polygon[{{1.115130, 1.164886, 0.023948},{1.118784, 1.166074, 0.024871},{
      1.119344, 1.164976, 0.024871},{1.116235, 1.162717, 0.023948}}],
    Polygon[{{1.119344, 1.164976, -0.024871},{1.116235, 1.162717, -0.023948},{
      1.117957, 1.160996, -0.023948},{1.120215, 1.164104, -0.024871}}],
    Polygon[{{1.116235, 1.162717, -0.023948},{1.113282, 1.160571, -0.022436},{
      1.115811, 1.158042, -0.022436},{1.117957, 1.160996, -0.023948}}],
    Polygon[{{1.113282, 1.160571, -0.022436},{1.110556, 1.158591, -0.020372},{
      1.113831, 1.155317, -0.020372},{1.115811, 1.158042, -0.022436}}],
    Polygon[{{1.110556, 1.158591, -0.020372},{1.108125, 1.156825, -0.017806},{
      1.112065, 1.152886, -0.017806},{1.113831, 1.155317, -0.020372}}],
    Polygon[{{1.108125, 1.156825, -0.017806},{1.106049, 1.155317, -0.014801},{
      1.110556, 1.150810, -0.014801},{1.112065, 1.152886, -0.017806}}],
    Polygon[{{1.106049, 1.155317, -0.014801},{1.104379, 1.154103, -0.011432},{
      1.109343, 1.149140, -0.011432},{1.110556, 1.150810, -0.014801}}],
    Polygon[{{1.104379, 1.154103, -0.011432},{1.103156, 1.153214, -0.007781},{
      1.108454, 1.147916, -0.007781},{1.109343, 1.149140, -0.011432}}],
    Polygon[{{1.103156, 1.153214, -0.007781},{1.102409, 1.152672, -0.003939},{
      1.107912, 1.147170, -0.003939},{1.108454, 1.147916, -0.007781}}],
    Polygon[{{1.102409, 1.152672, -0.003939},{1.102159, 1.152490, 0.000000},{
      1.107729, 1.146919, 0.000000},{1.107912, 1.147170, -0.003939}}],
    Polygon[{{1.102159, 1.152490, 0.000000},{1.102409, 1.152672, 0.003939},{
      1.107912, 1.147170, 0.003939},{1.107729, 1.146919, 0.000000}}],
    Polygon[{{1.102409, 1.152672, 0.003939},{1.103156, 1.153214, 0.007781},{
      1.108454, 1.147916, 0.007781},{1.107912, 1.147170, 0.003939}}],
    Polygon[{{1.103156, 1.153214, 0.007781},{1.104379, 1.154103, 0.011432},{
      1.109343, 1.149140, 0.011432},{1.108454, 1.147916, 0.007781}}],
    Polygon[{{1.104379, 1.154103, 0.011432},{1.106049, 1.155317, 0.014801},{
      1.110556, 1.150810, 0.014801},{1.109343, 1.149140, 0.011432}}],
    Polygon[{{1.106049, 1.155317, 0.014801},{1.108125, 1.156825, 0.017806},{
      1.112065, 1.152886, 0.017806},{1.110556, 1.150810, 0.014801}}],
    Polygon[{{1.108125, 1.156825, 0.017806},{1.110556, 1.158591, 0.020372},{
      1.113831, 1.155317, 0.020372},{1.112065, 1.152886, 0.017806}}],
    Polygon[{{1.110556, 1.158591, 0.020372},{1.113282, 1.160571, 0.022436},{
      1.115811, 1.158042, 0.022436},{1.113831, 1.155317, 0.020372}}],
    Polygon[{{1.113282, 1.160571, 0.022436},{1.116235, 1.162717, 0.023948},{
      1.117957, 1.160996, 0.023948},{1.115811, 1.158042, 0.022436}}],
    Polygon[{{1.116235, 1.162717, 0.023948},{1.119344, 1.164976, 0.024871},{
      1.120215, 1.164104, 0.024871},{1.117957, 1.160996, 0.023948}}],
    Polygon[{{1.120215, 1.164104, -0.024871},{1.117957, 1.160996, -0.023948},{
      1.120126, 1.159891, -0.023948},{1.121313, 1.163545, -0.024871}}],
    Polygon[{{1.117957, 1.160996, -0.023948},{1.115811, 1.158042, -0.022436},{
      1.118998, 1.156419, -0.022436},{1.120126, 1.159891, -0.023948}}],
    Polygon[{{1.115811, 1.158042, -0.022436},{1.113831, 1.155317, -0.020372},{
      1.117957, 1.153214, -0.020372},{1.118998, 1.156419, -0.022436}}],
    Polygon[{{1.113831, 1.155317, -0.020372},{1.112065, 1.152886, -0.017806},{
      1.117028, 1.150357, -0.017806},{1.117957, 1.153214, -0.020372}}],
    Polygon[{{1.112065, 1.152886, -0.017806},{1.110556, 1.150810, -0.014801},{
      1.116235, 1.147916, -0.014801},{1.117028, 1.150357, -0.017806}}],
    Polygon[{{1.110556, 1.150810, -0.014801},{1.109343, 1.149140, -0.011432},{
      1.115597, 1.145953, -0.011432},{1.116235, 1.147916, -0.014801}}],
    Polygon[{{1.109343, 1.149140, -0.011432},{1.108454, 1.147916, -0.007781},{
      1.115130, 1.144515, -0.007781},{1.115597, 1.145953, -0.011432}}],
    Polygon[{{1.108454, 1.147916, -0.007781},{1.107912, 1.147170, -0.003939},{
      1.114845, 1.143637, -0.003939},{1.115130, 1.144515, -0.007781}}],
    Polygon[{{1.107912, 1.147170, -0.003939},{1.107729, 1.146919, 0.000000},{
      1.114749, 1.143343, 0.000000},{1.114845, 1.143637, -0.003939}}],
    Polygon[{{1.107729, 1.146919, 0.000000},{1.107912, 1.147170, 0.003939},{
      1.114845, 1.143637, 0.003939},{1.114749, 1.143343, 0.000000}}],
    Polygon[{{1.107912, 1.147170, 0.003939},{1.108454, 1.147916, 0.007781},{
      1.115130, 1.144515, 0.007781},{1.114845, 1.143637, 0.003939}}],
    Polygon[{{1.108454, 1.147916, 0.007781},{1.109343, 1.149140, 0.011432},{
      1.115597, 1.145953, 0.011432},{1.115130, 1.144515, 0.007781}}],
    Polygon[{{1.109343, 1.149140, 0.011432},{1.110556, 1.150810, 0.014801},{
      1.116235, 1.147916, 0.014801},{1.115597, 1.145953, 0.011432}}],
    Polygon[{{1.110556, 1.150810, 0.014801},{1.112065, 1.152886, 0.017806},{
      1.117028, 1.150357, 0.017806},{1.116235, 1.147916, 0.014801}}],
    Polygon[{{1.112065, 1.152886, 0.017806},{1.113831, 1.155317, 0.020372},{
      1.117957, 1.153214, 0.020372},{1.117028, 1.150357, 0.017806}}],
    Polygon[{{1.113831, 1.155317, 0.020372},{1.115811, 1.158042, 0.022436},{
      1.118998, 1.156419, 0.022436},{1.117957, 1.153214, 0.020372}}],
    Polygon[{{1.115811, 1.158042, 0.022436},{1.117957, 1.160996, 0.023948},{
      1.120126, 1.159891, 0.023948},{1.118998, 1.156419, 0.022436}}],
    Polygon[{{1.117957, 1.160996, 0.023948},{1.120215, 1.164104, 0.024871},{
      1.121313, 1.163545, 0.024871},{1.120126, 1.159891, 0.023948}}],
    Polygon[{{1.121313, 1.163545, -0.024871},{1.120126, 1.159891, -0.023948},{
      1.122530, 1.159510, -0.023948},{1.122530, 1.163352, -0.024871}}],
    Polygon[{{1.120126, 1.159891, -0.023948},{1.118998, 1.156419, -0.022436},{
      1.122530, 1.155859, -0.022436},{1.122530, 1.159510, -0.023948}}],
    Polygon[{{1.118998, 1.156419, -0.022436},{1.117957, 1.153214, -0.020372},{
      1.122530, 1.152490, -0.020372},{1.122530, 1.155859, -0.022436}}],
    Polygon[{{1.117957, 1.153214, -0.020372},{1.117028, 1.150357, -0.017806},{
      1.122530, 1.149485, -0.017806},{1.122530, 1.152490, -0.020372}}],
    Polygon[{{1.117028, 1.150357, -0.017806},{1.116235, 1.147916, -0.014801},{
      1.122530, 1.146919, -0.014801},{1.122530, 1.149485, -0.017806}}],
    Polygon[{{1.116235, 1.147916, -0.014801},{1.115597, 1.145953, -0.011432},{
      1.122530, 1.144855, -0.011432},{1.122530, 1.146919, -0.014801}}],
    Polygon[{{1.115597, 1.145953, -0.011432},{1.115130, 1.144515, -0.007781},{
      1.122530, 1.143343, -0.007781},{1.122530, 1.144855, -0.011432}}],
    Polygon[{{1.115130, 1.144515, -0.007781},{1.114845, 1.143637, -0.003939},{
      1.122530, 1.142420, -0.003939},{1.122530, 1.143343, -0.007781}}],
    Polygon[{{1.114845, 1.143637, -0.003939},{1.114749, 1.143343, 0.000000},{
      1.122530, 1.142110, 0.000000},{1.122530, 1.142420, -0.003939}}],
    Polygon[{{1.114749, 1.143343, 0.000000},{1.114845, 1.143637, 0.003939},{
      1.122530, 1.142420, 0.003939},{1.122530, 1.142110, 0.000000}}],
    Polygon[{{1.114845, 1.143637, 0.003939},{1.115130, 1.144515, 0.007781},{
      1.122530, 1.143343, 0.007781},{1.122530, 1.142420, 0.003939}}],
    Polygon[{{1.115130, 1.144515, 0.007781},{1.115597, 1.145953, 0.011432},{
      1.122530, 1.144855, 0.011432},{1.122530, 1.143343, 0.007781}}],
    Polygon[{{1.115597, 1.145953, 0.011432},{1.116235, 1.147916, 0.014801},{
      1.122530, 1.146919, 0.014801},{1.122530, 1.144855, 0.011432}}],
    Polygon[{{1.116235, 1.147916, 0.014801},{1.117028, 1.150357, 0.017806},{
      1.122530, 1.149485, 0.017806},{1.122530, 1.146919, 0.014801}}],
    Polygon[{{1.117028, 1.150357, 0.017806},{1.117957, 1.153214, 0.020372},{
      1.122530, 1.152490, 0.020372},{1.122530, 1.149485, 0.017806}}],
    Polygon[{{1.117957, 1.153214, 0.020372},{1.118998, 1.156419, 0.022436},{
      1.122530, 1.155859, 0.022436},{1.122530, 1.152490, 0.020372}}],
    Polygon[{{1.118998, 1.156419, 0.022436},{1.120126, 1.159891, 0.023948},{
      1.122530, 1.159510, 0.023948},{1.122530, 1.155859, 0.022436}}],
    Polygon[{{1.120126, 1.159891, 0.023948},{1.121313, 1.163545, 0.024871},{
      1.122530, 1.163352, 0.024871},{1.122530, 1.159510, 0.023948}}],
    Polygon[{{1.122530, 1.163352, -0.024871},{1.122530, 1.159510, -0.023948},{
      1.124935, 1.159891, -0.023948},{1.123748, 1.163545, -0.024871}}],
    Polygon[{{1.122530, 1.159510, -0.023948},{1.122530, 1.155859, -0.022436},{
      1.126063, 1.156419, -0.022436},{1.124935, 1.159891, -0.023948}}],
    Polygon[{{1.122530, 1.155859, -0.022436},{1.122530, 1.152490, -0.020372},{
      1.127104, 1.153214, -0.020372},{1.126063, 1.156419, -0.022436}}],
    Polygon[{{1.122530, 1.152490, -0.020372},{1.122530, 1.149485, -0.017806},{
      1.128033, 1.150357, -0.017806},{1.127104, 1.153214, -0.020372}}],
    Polygon[{{1.122530, 1.149485, -0.017806},{1.122530, 1.146919, -0.014801},{
      1.128826, 1.147916, -0.014801},{1.128033, 1.150357, -0.017806}}],
    Polygon[{{1.122530, 1.146919, -0.014801},{1.122530, 1.144855, -0.011432},{
      1.129464, 1.145953, -0.011432},{1.128826, 1.147916, -0.014801}}],
    Polygon[{{1.122530, 1.144855, -0.011432},{1.122530, 1.143343, -0.007781},{
      1.129931, 1.144515, -0.007781},{1.129464, 1.145953, -0.011432}}],
    Polygon[{{1.122530, 1.143343, -0.007781},{1.122530, 1.142420, -0.003939},{
      1.130216, 1.143637, -0.003939},{1.129931, 1.144515, -0.007781}}],
    Polygon[{{1.122530, 1.142420, -0.003939},{1.122530, 1.142110, 0.000000},{
      1.130312, 1.143343, 0.000000},{1.130216, 1.143637, -0.003939}}],
    Polygon[{{1.122530, 1.142110, 0.000000},{1.122530, 1.142420, 0.003939},{
      1.130216, 1.143637, 0.003939},{1.130312, 1.143343, 0.000000}}],
    Polygon[{{1.122530, 1.142420, 0.003939},{1.122530, 1.143343, 0.007781},{
      1.129931, 1.144515, 0.007781},{1.130216, 1.143637, 0.003939}}],
    Polygon[{{1.122530, 1.143343, 0.007781},{1.122530, 1.144855, 0.011432},{
      1.129464, 1.145953, 0.011432},{1.129931, 1.144515, 0.007781}}],
    Polygon[{{1.122530, 1.144855, 0.011432},{1.122530, 1.146919, 0.014801},{
      1.128826, 1.147916, 0.014801},{1.129464, 1.145953, 0.011432}}],
    Polygon[{{1.122530, 1.146919, 0.014801},{1.122530, 1.149485, 0.017806},{
      1.128033, 1.150357, 0.017806},{1.128826, 1.147916, 0.014801}}],
    Polygon[{{1.122530, 1.149485, 0.017806},{1.122530, 1.152490, 0.020372},{
      1.127104, 1.153214, 0.020372},{1.128033, 1.150357, 0.017806}}],
    Polygon[{{1.122530, 1.152490, 0.020372},{1.122530, 1.155859, 0.022436},{
      1.126063, 1.156419, 0.022436},{1.127104, 1.153214, 0.020372}}],
    Polygon[{{1.122530, 1.155859, 0.022436},{1.122530, 1.159510, 0.023948},{
      1.124935, 1.159891, 0.023948},{1.126063, 1.156419, 0.022436}}],
    Polygon[{{1.122530, 1.159510, 0.023948},{1.122530, 1.163352, 0.024871},{
      1.123748, 1.163545, 0.024871},{1.124935, 1.159891, 0.023948}}],
    Polygon[{{1.123748, 1.163545, -0.024871},{1.124935, 1.159891, -0.023948},{
      1.127104, 1.160996, -0.023948},{1.124846, 1.164104, -0.024871}}],
    Polygon[{{1.124935, 1.159891, -0.023948},{1.126063, 1.156419, -0.022436},{
      1.129250, 1.158042, -0.022436},{1.127104, 1.160996, -0.023948}}],
    Polygon[{{1.126063, 1.156419, -0.022436},{1.127104, 1.153214, -0.020372},{
      1.131230, 1.155317, -0.020372},{1.129250, 1.158042, -0.022436}}],
    Polygon[{{1.127104, 1.153214, -0.020372},{1.128033, 1.150357, -0.017806},{
      1.132996, 1.152886, -0.017806},{1.131230, 1.155317, -0.020372}}],
    Polygon[{{1.128033, 1.150357, -0.017806},{1.128826, 1.147916, -0.014801},{
      1.134505, 1.150810, -0.014801},{1.132996, 1.152886, -0.017806}}],
    Polygon[{{1.128826, 1.147916, -0.014801},{1.129464, 1.145953, -0.011432},{
      1.135718, 1.149140, -0.011432},{1.134505, 1.150810, -0.014801}}],
    Polygon[{{1.129464, 1.145953, -0.011432},{1.129931, 1.144515, -0.007781},{
      1.136607, 1.147916, -0.007781},{1.135718, 1.149140, -0.011432}}],
    Polygon[{{1.129931, 1.144515, -0.007781},{1.130216, 1.143637, -0.003939},{
      1.137149, 1.147170, -0.003939},{1.136607, 1.147916, -0.007781}}],
    Polygon[{{1.130216, 1.143637, -0.003939},{1.130312, 1.143343, 0.000000},{
      1.137331, 1.146919, 0.000000},{1.137149, 1.147170, -0.003939}}],
    Polygon[{{1.130312, 1.143343, 0.000000},{1.130216, 1.143637, 0.003939},{
      1.137149, 1.147170, 0.003939},{1.137331, 1.146919, 0.000000}}],
    Polygon[{{1.130216, 1.143637, 0.003939},{1.129931, 1.144515, 0.007781},{
      1.136607, 1.147916, 0.007781},{1.137149, 1.147170, 0.003939}}],
    Polygon[{{1.129931, 1.144515, 0.007781},{1.129464, 1.145953, 0.011432},{
      1.135718, 1.149140, 0.011432},{1.136607, 1.147916, 0.007781}}],
    Polygon[{{1.129464, 1.145953, 0.011432},{1.128826, 1.147916, 0.014801},{
      1.134505, 1.150810, 0.014801},{1.135718, 1.149140, 0.011432}}],
    Polygon[{{1.128826, 1.147916, 0.014801},{1.128033, 1.150357, 0.017806},{
      1.132996, 1.152886, 0.017806},{1.134505, 1.150810, 0.014801}}],
    Polygon[{{1.128033, 1.150357, 0.017806},{1.127104, 1.153214, 0.020372},{
      1.131230, 1.155317, 0.020372},{1.132996, 1.152886, 0.017806}}],
    Polygon[{{1.127104, 1.153214, 0.020372},{1.126063, 1.156419, 0.022436},{
      1.129250, 1.158042, 0.022436},{1.131230, 1.155317, 0.020372}}],
    Polygon[{{1.126063, 1.156419, 0.022436},{1.124935, 1.159891, 0.023948},{
      1.127104, 1.160996, 0.023948},{1.129250, 1.158042, 0.022436}}],
    Polygon[{{1.124935, 1.159891, 0.023948},{1.123748, 1.163545, 0.024871},{
      1.124846, 1.164104, 0.024871},{1.127104, 1.160996, 0.023948}}],
    Polygon[{{1.124846, 1.164104, -0.024871},{1.127104, 1.160996, -0.023948},{
      1.128826, 1.162717, -0.023948},{1.125717, 1.164976, -0.024871}}],
    Polygon[{{1.127104, 1.160996, -0.023948},{1.129250, 1.158042, -0.022436},{
      1.131779, 1.160571, -0.022436},{1.128826, 1.162717, -0.023948}}],
    Polygon[{{1.129250, 1.158042, -0.022436},{1.131230, 1.155317, -0.020372},{
      1.134505, 1.158591, -0.020372},{1.131779, 1.160571, -0.022436}}],
    Polygon[{{1.131230, 1.155317, -0.020372},{1.132996, 1.152886, -0.017806},{
      1.136935, 1.156825, -0.017806},{1.134505, 1.158591, -0.020372}}],
    Polygon[{{1.132996, 1.152886, -0.017806},{1.134505, 1.150810, -0.014801},{
      1.139011, 1.155317, -0.014801},{1.136935, 1.156825, -0.017806}}],
    Polygon[{{1.134505, 1.150810, -0.014801},{1.135718, 1.149140, -0.011432},{
      1.140682, 1.154103, -0.011432},{1.139011, 1.155317, -0.014801}}],
    Polygon[{{1.135718, 1.149140, -0.011432},{1.136607, 1.147916, -0.007781},{
      1.141905, 1.153214, -0.007781},{1.140682, 1.154103, -0.011432}}],
    Polygon[{{1.136607, 1.147916, -0.007781},{1.137149, 1.147170, -0.003939},{
      1.142651, 1.152672, -0.003939},{1.141905, 1.153214, -0.007781}}],
    Polygon[{{1.137149, 1.147170, -0.003939},{1.137331, 1.146919, 0.000000},{
      1.142902, 1.152490, 0.000000},{1.142651, 1.152672, -0.003939}}],
    Polygon[{{1.137331, 1.146919, 0.000000},{1.137149, 1.147170, 0.003939},{
      1.142651, 1.152672, 0.003939},{1.142902, 1.152490, 0.000000}}],
    Polygon[{{1.137149, 1.147170, 0.003939},{1.136607, 1.147916, 0.007781},{
      1.141905, 1.153214, 0.007781},{1.142651, 1.152672, 0.003939}}],
    Polygon[{{1.136607, 1.147916, 0.007781},{1.135718, 1.149140, 0.011432},{
      1.140682, 1.154103, 0.011432},{1.141905, 1.153214, 0.007781}}],
    Polygon[{{1.135718, 1.149140, 0.011432},{1.134505, 1.150810, 0.014801},{
      1.139011, 1.155317, 0.014801},{1.140682, 1.154103, 0.011432}}],
    Polygon[{{1.134505, 1.150810, 0.014801},{1.132996, 1.152886, 0.017806},{
      1.136935, 1.156825, 0.017806},{1.139011, 1.155317, 0.014801}}],
    Polygon[{{1.132996, 1.152886, 0.017806},{1.131230, 1.155317, 0.020372},{
      1.134505, 1.158591, 0.020372},{1.136935, 1.156825, 0.017806}}],
    Polygon[{{1.131230, 1.155317, 0.020372},{1.129250, 1.158042, 0.022436},{
      1.131779, 1.160571, 0.022436},{1.134505, 1.158591, 0.020372}}],
    Polygon[{{1.129250, 1.158042, 0.022436},{1.127104, 1.160996, 0.023948},{
      1.128826, 1.162717, 0.023948},{1.131779, 1.160571, 0.022436}}],
    Polygon[{{1.127104, 1.160996, 0.023948},{1.124846, 1.164104, 0.024871},{
      1.125717, 1.164976, 0.024871},{1.128826, 1.162717, 0.023948}}],
    Polygon[{{1.125717, 1.164976, -0.024871},{1.128826, 1.162717, -0.023948},{
      1.129931, 1.164886, -0.023948},{1.126277, 1.166074, -0.024871}}],
    Polygon[{{1.128826, 1.162717, -0.023948},{1.131779, 1.160571, -0.022436},{
      1.133403, 1.163758, -0.022436},{1.129931, 1.164886, -0.023948}}],
    Polygon[{{1.131779, 1.160571, -0.022436},{1.134505, 1.158591, -0.020372},{
      1.136607, 1.162717, -0.020372},{1.133403, 1.163758, -0.022436}}],
    Polygon[{{1.134505, 1.158591, -0.020372},{1.136935, 1.156825, -0.017806},{
      1.139464, 1.161789, -0.017806},{1.136607, 1.162717, -0.020372}}],
    Polygon[{{1.136935, 1.156825, -0.017806},{1.139011, 1.155317, -0.014801},{
      1.141905, 1.160996, -0.014801},{1.139464, 1.161789, -0.017806}}],
    Polygon[{{1.139011, 1.155317, -0.014801},{1.140682, 1.154103, -0.011432},{
      1.143868, 1.160358, -0.011432},{1.141905, 1.160996, -0.014801}}],
    Polygon[{{1.140682, 1.154103, -0.011432},{1.141905, 1.153214, -0.007781},{
      1.145307, 1.159891, -0.007781},{1.143868, 1.160358, -0.011432}}],
    Polygon[{{1.141905, 1.153214, -0.007781},{1.142651, 1.152672, -0.003939},{
      1.146184, 1.159605, -0.003939},{1.145307, 1.159891, -0.007781}}],
    Polygon[{{1.142651, 1.152672, -0.003939},{1.142902, 1.152490, 0.000000},{
      1.146479, 1.159510, 0.000000},{1.146184, 1.159605, -0.003939}}],
    Polygon[{{1.142902, 1.152490, 0.000000},{1.142651, 1.152672, 0.003939},{
      1.146184, 1.159605, 0.003939},{1.146479, 1.159510, 0.000000}}],
    Polygon[{{1.142651, 1.152672, 0.003939},{1.141905, 1.153214, 0.007781},{
      1.145307, 1.159891, 0.007781},{1.146184, 1.159605, 0.003939}}],
    Polygon[{{1.141905, 1.153214, 0.007781},{1.140682, 1.154103, 0.011432},{
      1.143868, 1.160358, 0.011432},{1.145307, 1.159891, 0.007781}}],
    Polygon[{{1.140682, 1.154103, 0.011432},{1.139011, 1.155317, 0.014801},{
      1.141905, 1.160996, 0.014801},{1.143868, 1.160358, 0.011432}}],
    Polygon[{{1.139011, 1.155317, 0.014801},{1.136935, 1.156825, 0.017806},{
      1.139464, 1.161789, 0.017806},{1.141905, 1.160996, 0.014801}}],
    Polygon[{{1.136935, 1.156825, 0.017806},{1.134505, 1.158591, 0.020372},{
      1.136607, 1.162717, 0.020372},{1.139464, 1.161789, 0.017806}}],
    Polygon[{{1.134505, 1.158591, 0.020372},{1.131779, 1.160571, 0.022436},{
      1.133403, 1.163758, 0.022436},{1.136607, 1.162717, 0.020372}}],
    Polygon[{{1.131779, 1.160571, 0.022436},{1.128826, 1.162717, 0.023948},{
      1.129931, 1.164886, 0.023948},{1.133403, 1.163758, 0.022436}}],
    Polygon[{{1.128826, 1.162717, 0.023948},{1.125717, 1.164976, 0.024871},{
      1.126277, 1.166074, 0.024871},{1.129931, 1.164886, 0.023948}}],
    Polygon[{{1.126277, 1.166074, -0.024871},{1.129931, 1.164886, -0.023948},{
      1.130312, 1.167291, -0.023948},{1.126469, 1.167291, -0.024871}}],
    Polygon[{{1.129931, 1.164886, -0.023948},{1.133403, 1.163758, -0.022436},{
      1.133962, 1.167291, -0.022436},{1.130312, 1.167291, -0.023948}}],
    Polygon[{{1.133403, 1.163758, -0.022436},{1.136607, 1.162717, -0.020372},{
      1.137331, 1.167291, -0.020372},{1.133962, 1.167291, -0.022436}}],
    Polygon[{{1.136607, 1.162717, -0.020372},{1.139464, 1.161789, -0.017806},{
      1.140336, 1.167291, -0.017806},{1.137331, 1.167291, -0.020372}}],
    Polygon[{{1.139464, 1.161789, -0.017806},{1.141905, 1.160996, -0.014801},{
      1.142902, 1.167291, -0.014801},{1.140336, 1.167291, -0.017806}}],
    Polygon[{{1.141905, 1.160996, -0.014801},{1.143868, 1.160358, -0.011432},{
      1.144967, 1.167291, -0.011432},{1.142902, 1.167291, -0.014801}}],
    Polygon[{{1.143868, 1.160358, -0.011432},{1.145307, 1.159891, -0.007781},{
      1.146479, 1.167291, -0.007781},{1.144967, 1.167291, -0.011432}}],
    Polygon[{{1.145307, 1.159891, -0.007781},{1.146184, 1.159605, -0.003939},{
      1.147401, 1.167291, -0.003939},{1.146479, 1.167291, -0.007781}}],
    Polygon[{{1.146184, 1.159605, -0.003939},{1.146479, 1.159510, 0.000000},{
      1.147711, 1.167291, 0.000000},{1.147401, 1.167291, -0.003939}}],
    Polygon[{{1.146479, 1.159510, 0.000000},{1.146184, 1.159605, 0.003939},{
      1.147401, 1.167291, 0.003939},{1.147711, 1.167291, 0.000000}}],
    Polygon[{{1.146184, 1.159605, 0.003939},{1.145307, 1.159891, 0.007781},{
      1.146479, 1.167291, 0.007781},{1.147401, 1.167291, 0.003939}}],
    Polygon[{{1.145307, 1.159891, 0.007781},{1.143868, 1.160358, 0.011432},{
      1.144967, 1.167291, 0.011432},{1.146479, 1.167291, 0.007781}}],
    Polygon[{{1.143868, 1.160358, 0.011432},{1.141905, 1.160996, 0.014801},{
      1.142902, 1.167291, 0.014801},{1.144967, 1.167291, 0.011432}}],
    Polygon[{{1.141905, 1.160996, 0.014801},{1.139464, 1.161789, 0.017806},{
      1.140336, 1.167291, 0.017806},{1.142902, 1.167291, 0.014801}}],
    Polygon[{{1.139464, 1.161789, 0.017806},{1.136607, 1.162717, 0.020372},{
      1.137331, 1.167291, 0.020372},{1.140336, 1.167291, 0.017806}}],
    Polygon[{{1.136607, 1.162717, 0.020372},{1.133403, 1.163758, 0.022436},{
      1.133962, 1.167291, 0.022436},{1.137331, 1.167291, 0.020372}}],
    Polygon[{{1.133403, 1.163758, 0.022436},{1.129931, 1.164886, 0.023948},{
      1.130312, 1.167291, 0.023948},{1.133962, 1.167291, 0.022436}}],
    Polygon[{{1.129931, 1.164886, 0.023948},{1.126277, 1.166074, 0.024871},{
      1.126469, 1.167291, 0.024871},{1.130312, 1.167291, 0.023948}}],
    Polygon[{{1.087394, 1.160923, -0.012292},{1.089293, 1.160923, -0.011836},{
      1.089105, 1.162111, -0.011836},{1.087299, 1.161525, -0.012292}}],
    Polygon[{{1.089293, 1.160923, -0.011836},{1.091097, 1.160923, -0.011089},{
      1.090821, 1.162669, -0.011089},{1.089105, 1.162111, -0.011836}}],
    Polygon[{{1.091097, 1.160923, -0.011089},{1.092762, 1.160923, -0.010068},{
      1.092404, 1.163183, -0.010068},{1.090821, 1.162669, -0.011089}}],
    Polygon[{{1.092762, 1.160923, -0.010068},{1.094247, 1.160923, -0.008800},{
      1.093817, 1.163642, -0.008800},{1.092404, 1.163183, -0.010068}}],
    Polygon[{{1.094247, 1.160923, -0.008800},{1.095516, 1.160923, -0.007315},{
      1.095023, 1.164034, -0.007315},{1.093817, 1.163642, -0.008800}}],
    Polygon[{{1.095516, 1.160923, -0.007315},{1.096536, 1.160923, -0.005650},{
      1.095993, 1.164350, -0.005650},{1.095023, 1.164034, -0.007315}}],
    Polygon[{{1.096536, 1.160923, -0.005650},{1.097283, 1.160923, -0.003846},{
      1.096704, 1.164580, -0.003846},{1.095993, 1.164350, -0.005650}}],
    Polygon[{{1.097283, 1.160923, -0.003846},{1.097739, 1.160923, -0.001947},{
      1.097138, 1.164721, -0.001947},{1.096704, 1.164580, -0.003846}}],
    Polygon[{{1.097739, 1.160923, -0.001947},{1.097892, 1.160923, 0.000000},{
      1.097283, 1.164769, 0.000000},{1.097138, 1.164721, -0.001947}}],
    Polygon[{{1.097892, 1.160923, 0.000000},{1.097739, 1.160923, 0.001947},{
      1.097138, 1.164721, 0.001947},{1.097283, 1.164769, 0.000000}}],
    Polygon[{{1.097739, 1.160923, 0.001947},{1.097283, 1.160923, 0.003846},{
      1.096704, 1.164580, 0.003846},{1.097138, 1.164721, 0.001947}}],
    Polygon[{{1.097283, 1.160923, 0.003846},{1.096536, 1.160923, 0.005650},{
      1.095993, 1.164350, 0.005650},{1.096704, 1.164580, 0.003846}}],
    Polygon[{{1.096536, 1.160923, 0.005650},{1.095516, 1.160923, 0.007315},{
      1.095023, 1.164034, 0.007315},{1.095993, 1.164350, 0.005650}}],
    Polygon[{{1.095516, 1.160923, 0.007315},{1.094247, 1.160923, 0.008800},{
      1.093817, 1.163642, 0.008800},{1.095023, 1.164034, 0.007315}}],
    Polygon[{{1.094247, 1.160923, 0.008800},{1.092762, 1.160923, 0.010068},{
      1.092404, 1.163183, 0.010068},{1.093817, 1.163642, 0.008800}}],
    Polygon[{{1.092762, 1.160923, 0.010068},{1.091097, 1.160923, 0.011089},{
      1.090821, 1.162669, 0.011089},{1.092404, 1.163183, 0.010068}}],
    Polygon[{{1.091097, 1.160923, 0.011089},{1.089293, 1.160923, 0.011836},{
      1.089105, 1.162111, 0.011836},{1.090821, 1.162669, 0.011089}}],
    Polygon[{{1.089293, 1.160923, 0.011836},{1.087394, 1.160923, 0.012292},{
      1.087299, 1.161525, 0.012292},{1.089105, 1.162111, 0.011836}}],
    Polygon[{{1.087299, 1.161525, -0.012292},{1.089105, 1.162111, -0.011836},{
      1.088559, 1.163183, -0.011836},{1.087022, 1.162067, -0.012292}}],
    Polygon[{{1.089105, 1.162111, -0.011836},{1.090821, 1.162669, -0.011089},{
      1.090018, 1.164244, -0.011089},{1.088559, 1.163183, -0.011836}}],
    Polygon[{{1.090821, 1.162669, -0.011089},{1.092404, 1.163183, -0.010068},{
      1.091365, 1.165223, -0.010068},{1.090018, 1.164244, -0.011089}}],
    Polygon[{{1.092404, 1.163183, -0.010068},{1.093817, 1.163642, -0.008800},{
      1.092567, 1.166095, -0.008800},{1.091365, 1.165223, -0.010068}}],
    Polygon[{{1.093817, 1.163642, -0.008800},{1.095023, 1.164034, -0.007315},{
      1.093593, 1.166841, -0.007315},{1.092567, 1.166095, -0.008800}}],
    Polygon[{{1.095023, 1.164034, -0.007315},{1.095993, 1.164350, -0.005650},{
      1.094418, 1.167441, -0.005650},{1.093593, 1.166841, -0.007315}}],
    Polygon[{{1.095993, 1.164350, -0.005650},{1.096704, 1.164580, -0.003846},{
      1.095023, 1.167880, -0.003846},{1.094418, 1.167441, -0.005650}}],
    Polygon[{{1.096704, 1.164580, -0.003846},{1.097138, 1.164721, -0.001947},{
      1.095392, 1.168148, -0.001947},{1.095023, 1.167880, -0.003846}}],
    Polygon[{{1.097138, 1.164721, -0.001947},{1.097283, 1.164769, 0.000000},{
      1.095516, 1.168238, 0.000000},{1.095392, 1.168148, -0.001947}}],
    Polygon[{{1.097283, 1.164769, 0.000000},{1.097138, 1.164721, 0.001947},{
      1.095392, 1.168148, 0.001947},{1.095516, 1.168238, 0.000000}}],
    Polygon[{{1.097138, 1.164721, 0.001947},{1.096704, 1.164580, 0.003846},{
      1.095023, 1.167880, 0.003846},{1.095392, 1.168148, 0.001947}}],
    Polygon[{{1.096704, 1.164580, 0.003846},{1.095993, 1.164350, 0.005650},{
      1.094418, 1.167441, 0.005650},{1.095023, 1.167880, 0.003846}}],
    Polygon[{{1.095993, 1.164350, 0.005650},{1.095023, 1.164034, 0.007315},{
      1.093593, 1.166841, 0.007315},{1.094418, 1.167441, 0.005650}}],
    Polygon[{{1.095023, 1.164034, 0.007315},{1.093817, 1.163642, 0.008800},{
      1.092567, 1.166095, 0.008800},{1.093593, 1.166841, 0.007315}}],
    Polygon[{{1.093817, 1.163642, 0.008800},{1.092404, 1.163183, 0.010068},{
      1.091365, 1.165223, 0.010068},{1.092567, 1.166095, 0.008800}}],
    Polygon[{{1.092404, 1.163183, 0.010068},{1.090821, 1.162669, 0.011089},{
      1.090018, 1.164244, 0.011089},{1.091365, 1.165223, 0.010068}}],
    Polygon[{{1.090821, 1.162669, 0.011089},{1.089105, 1.162111, 0.011836},{
      1.088559, 1.163183, 0.011836},{1.090018, 1.164244, 0.011089}}],
    Polygon[{{1.089105, 1.162111, 0.011836},{1.087299, 1.161525, 0.012292},{
      1.087022, 1.162067, 0.012292},{1.088559, 1.163183, 0.011836}}],
    Polygon[{{1.087022, 1.162067, -0.012292},{1.088559, 1.163183, -0.011836},{
      1.087708, 1.164034, -0.011836},{1.086592, 1.162498, -0.012292}}],
    Polygon[{{1.088559, 1.163183, -0.011836},{1.090018, 1.164244, -0.011089},{
      1.088768, 1.165494, -0.011089},{1.087708, 1.164034, -0.011836}}],
    Polygon[{{1.090018, 1.164244, -0.011089},{1.091365, 1.165223, -0.010068},{
      1.089747, 1.166841, -0.010068},{1.088768, 1.165494, -0.011089}}],
    Polygon[{{1.091365, 1.165223, -0.010068},{1.092567, 1.166095, -0.008800},{
      1.090620, 1.168042, -0.008800},{1.089747, 1.166841, -0.010068}}],
    Polygon[{{1.092567, 1.166095, -0.008800},{1.093593, 1.166841, -0.007315},{
      1.091365, 1.169068, -0.007315},{1.090620, 1.168042, -0.008800}}],
    Polygon[{{1.093593, 1.166841, -0.007315},{1.094418, 1.167441, -0.005650},{
      1.091965, 1.169894, -0.005650},{1.091365, 1.169068, -0.007315}}],
    Polygon[{{1.094418, 1.167441, -0.005650},{1.095023, 1.167880, -0.003846},{
      1.092404, 1.170498, -0.003846},{1.091965, 1.169894, -0.005650}}],
    Polygon[{{1.095023, 1.167880, -0.003846},{1.095392, 1.168148, -0.001947},{
      1.092672, 1.170867, -0.001947},{1.092404, 1.170498, -0.003846}}],
    Polygon[{{1.095392, 1.168148, -0.001947},{1.095516, 1.168238, 0.000000},{
      1.092762, 1.170991, 0.000000},{1.092672, 1.170867, -0.001947}}],
    Polygon[{{1.095516, 1.168238, 0.000000},{1.095392, 1.168148, 0.001947},{
      1.092672, 1.170867, 0.001947},{1.092762, 1.170991, 0.000000}}],
    Polygon[{{1.095392, 1.168148, 0.001947},{1.095023, 1.167880, 0.003846},{
      1.092404, 1.170498, 0.003846},{1.092672, 1.170867, 0.001947}}],
    Polygon[{{1.095023, 1.167880, 0.003846},{1.094418, 1.167441, 0.005650},{
      1.091965, 1.169894, 0.005650},{1.092404, 1.170498, 0.003846}}],
    Polygon[{{1.094418, 1.167441, 0.005650},{1.093593, 1.166841, 0.007315},{
      1.091365, 1.169068, 0.007315},{1.091965, 1.169894, 0.005650}}],
    Polygon[{{1.093593, 1.166841, 0.007315},{1.092567, 1.166095, 0.008800},{
      1.090620, 1.168042, 0.008800},{1.091365, 1.169068, 0.007315}}],
    Polygon[{{1.092567, 1.166095, 0.008800},{1.091365, 1.165223, 0.010068},{
      1.089747, 1.166841, 0.010068},{1.090620, 1.168042, 0.008800}}],
    Polygon[{{1.091365, 1.165223, 0.010068},{1.090018, 1.164244, 0.011089},{
      1.088768, 1.165494, 0.011089},{1.089747, 1.166841, 0.010068}}],
    Polygon[{{1.090018, 1.164244, 0.011089},{1.088559, 1.163183, 0.011836},{
      1.087708, 1.164034, 0.011836},{1.088768, 1.165494, 0.011089}}],
    Polygon[{{1.088559, 1.163183, 0.011836},{1.087022, 1.162067, 0.012292},{
      1.086592, 1.162498, 0.012292},{1.087708, 1.164034, 0.011836}}],
    Polygon[{{1.086592, 1.162498, -0.012292},{1.087708, 1.164034, -0.011836},{
      1.086636, 1.164580, -0.011836},{1.086049, 1.162775, -0.012292}}],
    Polygon[{{1.087708, 1.164034, -0.011836},{1.088768, 1.165494, -0.011089},{
      1.087193, 1.166296, -0.011089},{1.086636, 1.164580, -0.011836}}],
    Polygon[{{1.088768, 1.165494, -0.011089},{1.089747, 1.166841, -0.010068},{
      1.087708, 1.167880, -0.010068},{1.087193, 1.166296, -0.011089}}],
    Polygon[{{1.089747, 1.166841, -0.010068},{1.090620, 1.168042, -0.008800},{
      1.088167, 1.169292, -0.008800},{1.087708, 1.167880, -0.010068}}],
    Polygon[{{1.090620, 1.168042, -0.008800},{1.091365, 1.169068, -0.007315},{
      1.088559, 1.170498, -0.007315},{1.088167, 1.169292, -0.008800}}],
    Polygon[{{1.091365, 1.169068, -0.007315},{1.091965, 1.169894, -0.005650},{
      1.088874, 1.171469, -0.005650},{1.088559, 1.170498, -0.007315}}],
    Polygon[{{1.091965, 1.169894, -0.005650},{1.092404, 1.170498, -0.003846},{
      1.089105, 1.172180, -0.003846},{1.088874, 1.171469, -0.005650}}],
    Polygon[{{1.092404, 1.170498, -0.003846},{1.092672, 1.170867, -0.001947},{
      1.089246, 1.172613, -0.001947},{1.089105, 1.172180, -0.003846}}],
    Polygon[{{1.092672, 1.170867, -0.001947},{1.092762, 1.170991, 0.000000},{
      1.089293, 1.172759, 0.000000},{1.089246, 1.172613, -0.001947}}],
    Polygon[{{1.092762, 1.170991, 0.000000},{1.092672, 1.170867, 0.001947},{
      1.089246, 1.172613, 0.001947},{1.089293, 1.172759, 0.000000}}],
    Polygon[{{1.092672, 1.170867, 0.001947},{1.092404, 1.170498, 0.003846},{
      1.089105, 1.172180, 0.003846},{1.089246, 1.172613, 0.001947}}],
    Polygon[{{1.092404, 1.170498, 0.003846},{1.091965, 1.169894, 0.005650},{
      1.088874, 1.171469, 0.005650},{1.089105, 1.172180, 0.003846}}],
    Polygon[{{1.091965, 1.169894, 0.005650},{1.091365, 1.169068, 0.007315},{
      1.088559, 1.170498, 0.007315},{1.088874, 1.171469, 0.005650}}],
    Polygon[{{1.091365, 1.169068, 0.007315},{1.090620, 1.168042, 0.008800},{
      1.088167, 1.169292, 0.008800},{1.088559, 1.170498, 0.007315}}],
    Polygon[{{1.090620, 1.168042, 0.008800},{1.089747, 1.166841, 0.010068},{
      1.087708, 1.167880, 0.010068},{1.088167, 1.169292, 0.008800}}],
    Polygon[{{1.089747, 1.166841, 0.010068},{1.088768, 1.165494, 0.011089},{
      1.087193, 1.166296, 0.011089},{1.087708, 1.167880, 0.010068}}],
    Polygon[{{1.088768, 1.165494, 0.011089},{1.087708, 1.164034, 0.011836},{
      1.086636, 1.164580, 0.011836},{1.087193, 1.166296, 0.011089}}],
    Polygon[{{1.087708, 1.164034, 0.011836},{1.086592, 1.162498, 0.012292},{
      1.086049, 1.162775, 0.012292},{1.086636, 1.164580, 0.011836}}],
    Polygon[{{1.086049, 1.162775, -0.012292},{1.086636, 1.164580, -0.011836},{
      1.085447, 1.164769, -0.011836},{1.085447, 1.162870, -0.012292}}],
    Polygon[{{1.086636, 1.164580, -0.011836},{1.087193, 1.166296, -0.011089},{
      1.085447, 1.166573, -0.011089},{1.085447, 1.164769, -0.011836}}],
    Polygon[{{1.087193, 1.166296, -0.011089},{1.087708, 1.167880, -0.010068},{
      1.085447, 1.168238, -0.010068},{1.085447, 1.166573, -0.011089}}],
    Polygon[{{1.087708, 1.167880, -0.010068},{1.088167, 1.169292, -0.008800},{
      1.085447, 1.169723, -0.008800},{1.085447, 1.168238, -0.010068}}],
    Polygon[{{1.088167, 1.169292, -0.008800},{1.088559, 1.170498, -0.007315},{
      1.085447, 1.170991, -0.007315},{1.085447, 1.169723, -0.008800}}],
    Polygon[{{1.088559, 1.170498, -0.007315},{1.088874, 1.171469, -0.005650},{
      1.085447, 1.172012, -0.005650},{1.085447, 1.170991, -0.007315}}],
    Polygon[{{1.088874, 1.171469, -0.005650},{1.089105, 1.172180, -0.003846},{
      1.085447, 1.172759, -0.003846},{1.085447, 1.172012, -0.005650}}],
    Polygon[{{1.089105, 1.172180, -0.003846},{1.089246, 1.172613, -0.001947},{
      1.085447, 1.173215, -0.001947},{1.085447, 1.172759, -0.003846}}],
    Polygon[{{1.089246, 1.172613, -0.001947},{1.089293, 1.172759, 0.000000},{
      1.085447, 1.173368, 0.000000},{1.085447, 1.173215, -0.001947}}],
    Polygon[{{1.089293, 1.172759, 0.000000},{1.089246, 1.172613, 0.001947},{
      1.085447, 1.173215, 0.001947},{1.085447, 1.173368, 0.000000}}],
    Polygon[{{1.089246, 1.172613, 0.001947},{1.089105, 1.172180, 0.003846},{
      1.085447, 1.172759, 0.003846},{1.085447, 1.173215, 0.001947}}],
    Polygon[{{1.089105, 1.172180, 0.003846},{1.088874, 1.171469, 0.005650},{
      1.085447, 1.172012, 0.005650},{1.085447, 1.172759, 0.003846}}],
    Polygon[{{1.088874, 1.171469, 0.005650},{1.088559, 1.170498, 0.007315},{
      1.085447, 1.170991, 0.007315},{1.085447, 1.172012, 0.005650}}],
    Polygon[{{1.088559, 1.170498, 0.007315},{1.088167, 1.169292, 0.008800},{
      1.085447, 1.169723, 0.008800},{1.085447, 1.170991, 0.007315}}],
    Polygon[{{1.088167, 1.169292, 0.008800},{1.087708, 1.167880, 0.010068},{
      1.085447, 1.168238, 0.010068},{1.085447, 1.169723, 0.008800}}],
    Polygon[{{1.087708, 1.167880, 0.010068},{1.087193, 1.166296, 0.011089},{
      1.085447, 1.166573, 0.011089},{1.085447, 1.168238, 0.010068}}],
    Polygon[{{1.087193, 1.166296, 0.011089},{1.086636, 1.164580, 0.011836},{
      1.085447, 1.164769, 0.011836},{1.085447, 1.166573, 0.011089}}],
    Polygon[{{1.086636, 1.164580, 0.011836},{1.086049, 1.162775, 0.012292},{
      1.085447, 1.162870, 0.012292},{1.085447, 1.164769, 0.011836}}],
    Polygon[{{1.085447, 1.162870, -0.012292},{1.085447, 1.164769, -0.011836},{
      1.084259, 1.164580, -0.011836},{1.084846, 1.162775, -0.012292}}],
    Polygon[{{1.085447, 1.164769, -0.011836},{1.085447, 1.166573, -0.011089},{
      1.083701, 1.166296, -0.011089},{1.084259, 1.164580, -0.011836}}],
    Polygon[{{1.085447, 1.166573, -0.011089},{1.085447, 1.168238, -0.010068},{
      1.083187, 1.167880, -0.010068},{1.083701, 1.166296, -0.011089}}],
    Polygon[{{1.085447, 1.168238, -0.010068},{1.085447, 1.169723, -0.008800},{
      1.082728, 1.169292, -0.008800},{1.083187, 1.167880, -0.010068}}],
    Polygon[{{1.085447, 1.169723, -0.008800},{1.085447, 1.170991, -0.007315},{
      1.082336, 1.170498, -0.007315},{1.082728, 1.169292, -0.008800}}],
    Polygon[{{1.085447, 1.170991, -0.007315},{1.085447, 1.172012, -0.005650},{
      1.082021, 1.171469, -0.005650},{1.082336, 1.170498, -0.007315}}],
    Polygon[{{1.085447, 1.172012, -0.005650},{1.085447, 1.172759, -0.003846},{
      1.081790, 1.172180, -0.003846},{1.082021, 1.171469, -0.005650}}],
    Polygon[{{1.085447, 1.172759, -0.003846},{1.085447, 1.173215, -0.001947},{
      1.081649, 1.172613, -0.001947},{1.081790, 1.172180, -0.003846}}],
    Polygon[{{1.085447, 1.173215, -0.001947},{1.085447, 1.173368, 0.000000},{
      1.081602, 1.172759, 0.000000},{1.081649, 1.172613, -0.001947}}],
    Polygon[{{1.085447, 1.173368, 0.000000},{1.085447, 1.173215, 0.001947},{
      1.081649, 1.172613, 0.001947},{1.081602, 1.172759, 0.000000}}],
    Polygon[{{1.085447, 1.173215, 0.001947},{1.085447, 1.172759, 0.003846},{
      1.081790, 1.172180, 0.003846},{1.081649, 1.172613, 0.001947}}],
    Polygon[{{1.085447, 1.172759, 0.003846},{1.085447, 1.172012, 0.005650},{
      1.082021, 1.171469, 0.005650},{1.081790, 1.172180, 0.003846}}],
    Polygon[{{1.085447, 1.172012, 0.005650},{1.085447, 1.170991, 0.007315},{
      1.082336, 1.170498, 0.007315},{1.082021, 1.171469, 0.005650}}],
    Polygon[{{1.085447, 1.170991, 0.007315},{1.085447, 1.169723, 0.008800},{
      1.082728, 1.169292, 0.008800},{1.082336, 1.170498, 0.007315}}],
    Polygon[{{1.085447, 1.169723, 0.008800},{1.085447, 1.168238, 0.010068},{
      1.083187, 1.167880, 0.010068},{1.082728, 1.169292, 0.008800}}],
    Polygon[{{1.085447, 1.168238, 0.010068},{1.085447, 1.166573, 0.011089},{
      1.083701, 1.166296, 0.011089},{1.083187, 1.167880, 0.010068}}],
    Polygon[{{1.085447, 1.166573, 0.011089},{1.085447, 1.164769, 0.011836},{
      1.084259, 1.164580, 0.011836},{1.083701, 1.166296, 0.011089}}],
    Polygon[{{1.085447, 1.164769, 0.011836},{1.085447, 1.162870, 0.012292},{
      1.084846, 1.162775, 0.012292},{1.084259, 1.164580, 0.011836}}],
    Polygon[{{1.084846, 1.162775, -0.012292},{1.084259, 1.164580, -0.011836},{
      1.083187, 1.164034, -0.011836},{1.084303, 1.162498, -0.012292}}],
    Polygon[{{1.084259, 1.164580, -0.011836},{1.083701, 1.166296, -0.011089},{
      1.082126, 1.165494, -0.011089},{1.083187, 1.164034, -0.011836}}],
    Polygon[{{1.083701, 1.166296, -0.011089},{1.083187, 1.167880, -0.010068},{
      1.081148, 1.166841, -0.010068},{1.082126, 1.165494, -0.011089}}],
    Polygon[{{1.083187, 1.167880, -0.010068},{1.082728, 1.169292, -0.008800},{
      1.080275, 1.168042, -0.008800},{1.081148, 1.166841, -0.010068}}],
    Polygon[{{1.082728, 1.169292, -0.008800},{1.082336, 1.170498, -0.007315},{
      1.079530, 1.169068, -0.007315},{1.080275, 1.168042, -0.008800}}],
    Polygon[{{1.082336, 1.170498, -0.007315},{1.082021, 1.171469, -0.005650},{
      1.078930, 1.169894, -0.005650},{1.079530, 1.169068, -0.007315}}],
    Polygon[{{1.082021, 1.171469, -0.005650},{1.081790, 1.172180, -0.003846},{
      1.078490, 1.170498, -0.003846},{1.078930, 1.169894, -0.005650}}],
    Polygon[{{1.081790, 1.172180, -0.003846},{1.081649, 1.172613, -0.001947},{
      1.078223, 1.170867, -0.001947},{1.078490, 1.170498, -0.003846}}],
    Polygon[{{1.081649, 1.172613, -0.001947},{1.081602, 1.172759, 0.000000},{
      1.078132, 1.170991, 0.000000},{1.078223, 1.170867, -0.001947}}],
    Polygon[{{1.081602, 1.172759, 0.000000},{1.081649, 1.172613, 0.001947},{
      1.078223, 1.170867, 0.001947},{1.078132, 1.170991, 0.000000}}],
    Polygon[{{1.081649, 1.172613, 0.001947},{1.081790, 1.172180, 0.003846},{
      1.078490, 1.170498, 0.003846},{1.078223, 1.170867, 0.001947}}],
    Polygon[{{1.081790, 1.172180, 0.003846},{1.082021, 1.171469, 0.005650},{
      1.078930, 1.169894, 0.005650},{1.078490, 1.170498, 0.003846}}],
    Polygon[{{1.082021, 1.171469, 0.005650},{1.082336, 1.170498, 0.007315},{
      1.079530, 1.169068, 0.007315},{1.078930, 1.169894, 0.005650}}],
    Polygon[{{1.082336, 1.170498, 0.007315},{1.082728, 1.169292, 0.008800},{
      1.080275, 1.168042, 0.008800},{1.079530, 1.169068, 0.007315}}],
    Polygon[{{1.082728, 1.169292, 0.008800},{1.083187, 1.167880, 0.010068},{
      1.081148, 1.166841, 0.010068},{1.080275, 1.168042, 0.008800}}],
    Polygon[{{1.083187, 1.167880, 0.010068},{1.083701, 1.166296, 0.011089},{
      1.082126, 1.165494, 0.011089},{1.081148, 1.166841, 0.010068}}],
    Polygon[{{1.083701, 1.166296, 0.011089},{1.084259, 1.164580, 0.011836},{
      1.083187, 1.164034, 0.011836},{1.082126, 1.165494, 0.011089}}],
    Polygon[{{1.084259, 1.164580, 0.011836},{1.084846, 1.162775, 0.012292},{
      1.084303, 1.162498, 0.012292},{1.083187, 1.164034, 0.011836}}],
    Polygon[{{1.084303, 1.162498, -0.012292},{1.083187, 1.164034, -0.011836},{
      1.082336, 1.163183, -0.011836},{1.083872, 1.162067, -0.012292}}],
    Polygon[{{1.083187, 1.164034, -0.011836},{1.082126, 1.165494, -0.011089},{
      1.080877, 1.164244, -0.011089},{1.082336, 1.163183, -0.011836}}],
    Polygon[{{1.082126, 1.165494, -0.011089},{1.081148, 1.166841, -0.010068},{
      1.079530, 1.165223, -0.010068},{1.080877, 1.164244, -0.011089}}],
    Polygon[{{1.081148, 1.166841, -0.010068},{1.080275, 1.168042, -0.008800},{
      1.078328, 1.166095, -0.008800},{1.079530, 1.165223, -0.010068}}],
    Polygon[{{1.080275, 1.168042, -0.008800},{1.079530, 1.169068, -0.007315},{
      1.077302, 1.166841, -0.007315},{1.078328, 1.166095, -0.008800}}],
    Polygon[{{1.079530, 1.169068, -0.007315},{1.078930, 1.169894, -0.005650},{
      1.076477, 1.167441, -0.005650},{1.077302, 1.166841, -0.007315}}],
    Polygon[{{1.078930, 1.169894, -0.005650},{1.078490, 1.170498, -0.003846},{
      1.075872, 1.167880, -0.003846},{1.076477, 1.167441, -0.005650}}],
    Polygon[{{1.078490, 1.170498, -0.003846},{1.078223, 1.170867, -0.001947},{
      1.075503, 1.168148, -0.001947},{1.075872, 1.167880, -0.003846}}],
    Polygon[{{1.078223, 1.170867, -0.001947},{1.078132, 1.170991, 0.000000},{
      1.075379, 1.168238, 0.000000},{1.075503, 1.168148, -0.001947}}],
    Polygon[{{1.078132, 1.170991, 0.000000},{1.078223, 1.170867, 0.001947},{
      1.075503, 1.168148, 0.001947},{1.075379, 1.168238, 0.000000}}],
    Polygon[{{1.078223, 1.170867, 0.001947},{1.078490, 1.170498, 0.003846},{
      1.075872, 1.167880, 0.003846},{1.075503, 1.168148, 0.001947}}],
    Polygon[{{1.078490, 1.170498, 0.003846},{1.078930, 1.169894, 0.005650},{
      1.076477, 1.167441, 0.005650},{1.075872, 1.167880, 0.003846}}],
    Polygon[{{1.078930, 1.169894, 0.005650},{1.079530, 1.169068, 0.007315},{
      1.077302, 1.166841, 0.007315},{1.076477, 1.167441, 0.005650}}],
    Polygon[{{1.079530, 1.169068, 0.007315},{1.080275, 1.168042, 0.008800},{
      1.078328, 1.166095, 0.008800},{1.077302, 1.166841, 0.007315}}],
    Polygon[{{1.080275, 1.168042, 0.008800},{1.081148, 1.166841, 0.010068},{
      1.079530, 1.165223, 0.010068},{1.078328, 1.166095, 0.008800}}],
    Polygon[{{1.081148, 1.166841, 0.010068},{1.082126, 1.165494, 0.011089},{
      1.080877, 1.164244, 0.011089},{1.079530, 1.165223, 0.010068}}],
    Polygon[{{1.082126, 1.165494, 0.011089},{1.083187, 1.164034, 0.011836},{
      1.082336, 1.163183, 0.011836},{1.080877, 1.164244, 0.011089}}],
    Polygon[{{1.083187, 1.164034, 0.011836},{1.084303, 1.162498, 0.012292},{
      1.083872, 1.162067, 0.012292},{1.082336, 1.163183, 0.011836}}],
    Polygon[{{1.083872, 1.162067, -0.012292},{1.082336, 1.163183, -0.011836},{
      1.081790, 1.162111, -0.011836},{1.083596, 1.161525, -0.012292}}],
    Polygon[{{1.082336, 1.163183, -0.011836},{1.080877, 1.164244, -0.011089},{
      1.080074, 1.162669, -0.011089},{1.081790, 1.162111, -0.011836}}],
    Polygon[{{1.080877, 1.164244, -0.011089},{1.079530, 1.165223, -0.010068},{
      1.078490, 1.163183, -0.010068},{1.080074, 1.162669, -0.011089}}],
    Polygon[{{1.079530, 1.165223, -0.010068},{1.078328, 1.166095, -0.008800},{
      1.077078, 1.163642, -0.008800},{1.078490, 1.163183, -0.010068}}],
    Polygon[{{1.078328, 1.166095, -0.008800},{1.077302, 1.166841, -0.007315},{
      1.075872, 1.164034, -0.007315},{1.077078, 1.163642, -0.008800}}],
    Polygon[{{1.077302, 1.166841, -0.007315},{1.076477, 1.167441, -0.005650},{
      1.074902, 1.164350, -0.005650},{1.075872, 1.164034, -0.007315}}],
    Polygon[{{1.076477, 1.167441, -0.005650},{1.075872, 1.167880, -0.003846},{
      1.074191, 1.164580, -0.003846},{1.074902, 1.164350, -0.005650}}],
    Polygon[{{1.075872, 1.167880, -0.003846},{1.075503, 1.168148, -0.001947},{
      1.073757, 1.164721, -0.001947},{1.074191, 1.164580, -0.003846}}],
    Polygon[{{1.075503, 1.168148, -0.001947},{1.075379, 1.168238, 0.000000},{
      1.073611, 1.164769, 0.000000},{1.073757, 1.164721, -0.001947}}],
    Polygon[{{1.075379, 1.168238, 0.000000},{1.075503, 1.168148, 0.001947},{
      1.073757, 1.164721, 0.001947},{1.073611, 1.164769, 0.000000}}],
    Polygon[{{1.075503, 1.168148, 0.001947},{1.075872, 1.167880, 0.003846},{
      1.074191, 1.164580, 0.003846},{1.073757, 1.164721, 0.001947}}],
    Polygon[{{1.075872, 1.167880, 0.003846},{1.076477, 1.167441, 0.005650},{
      1.074902, 1.164350, 0.005650},{1.074191, 1.164580, 0.003846}}],
    Polygon[{{1.076477, 1.167441, 0.005650},{1.077302, 1.166841, 0.007315},{
      1.075872, 1.164034, 0.007315},{1.074902, 1.164350, 0.005650}}],
    Polygon[{{1.077302, 1.166841, 0.007315},{1.078328, 1.166095, 0.008800},{
      1.077078, 1.163642, 0.008800},{1.075872, 1.164034, 0.007315}}],
    Polygon[{{1.078328, 1.166095, 0.008800},{1.079530, 1.165223, 0.010068},{
      1.078490, 1.163183, 0.010068},{1.077078, 1.163642, 0.008800}}],
    Polygon[{{1.079530, 1.165223, 0.010068},{1.080877, 1.164244, 0.011089},{
      1.080074, 1.162669, 0.011089},{1.078490, 1.163183, 0.010068}}],
    Polygon[{{1.080877, 1.164244, 0.011089},{1.082336, 1.163183, 0.011836},{
      1.081790, 1.162111, 0.011836},{1.080074, 1.162669, 0.011089}}],
    Polygon[{{1.082336, 1.163183, 0.011836},{1.083872, 1.162067, 0.012292},{
      1.083596, 1.161525, 0.012292},{1.081790, 1.162111, 0.011836}}],
    Polygon[{{1.083596, 1.161525, -0.012292},{1.081790, 1.162111, -0.011836},{
      1.081602, 1.160923, -0.011836},{1.083501, 1.160923, -0.012292}}],
    Polygon[{{1.081790, 1.162111, -0.011836},{1.080074, 1.162669, -0.011089},{
      1.079798, 1.160923, -0.011089},{1.081602, 1.160923, -0.011836}}],
    Polygon[{{1.080074, 1.162669, -0.011089},{1.078490, 1.163183, -0.010068},{
      1.078132, 1.160923, -0.010068},{1.079798, 1.160923, -0.011089}}],
    Polygon[{{1.078490, 1.163183, -0.010068},{1.077078, 1.163642, -0.008800},{
      1.076648, 1.160923, -0.008800},{1.078132, 1.160923, -0.010068}}],
    Polygon[{{1.077078, 1.163642, -0.008800},{1.075872, 1.164034, -0.007315},{
      1.075379, 1.160923, -0.007315},{1.076648, 1.160923, -0.008800}}],
    Polygon[{{1.075872, 1.164034, -0.007315},{1.074902, 1.164350, -0.005650},{
      1.074359, 1.160923, -0.005650},{1.075379, 1.160923, -0.007315}}],
    Polygon[{{1.074902, 1.164350, -0.005650},{1.074191, 1.164580, -0.003846},{
      1.073611, 1.160923, -0.003846},{1.074359, 1.160923, -0.005650}}],
    Polygon[{{1.074191, 1.164580, -0.003846},{1.073757, 1.164721, -0.001947},{
      1.073156, 1.160923, -0.001947},{1.073611, 1.160923, -0.003846}}],
    Polygon[{{1.073757, 1.164721, -0.001947},{1.073611, 1.164769, 0.000000},{
      1.073002, 1.160923, 0.000000},{1.073156, 1.160923, -0.001947}}],
    Polygon[{{1.073611, 1.164769, 0.000000},{1.073757, 1.164721, 0.001947},{
      1.073156, 1.160923, 0.001947},{1.073002, 1.160923, 0.000000}}],
    Polygon[{{1.073757, 1.164721, 0.001947},{1.074191, 1.164580, 0.003846},{
      1.073611, 1.160923, 0.003846},{1.073156, 1.160923, 0.001947}}],
    Polygon[{{1.074191, 1.164580, 0.003846},{1.074902, 1.164350, 0.005650},{
      1.074359, 1.160923, 0.005650},{1.073611, 1.160923, 0.003846}}],
    Polygon[{{1.074902, 1.164350, 0.005650},{1.075872, 1.164034, 0.007315},{
      1.075379, 1.160923, 0.007315},{1.074359, 1.160923, 0.005650}}],
    Polygon[{{1.075872, 1.164034, 0.007315},{1.077078, 1.163642, 0.008800},{
      1.076648, 1.160923, 0.008800},{1.075379, 1.160923, 0.007315}}],
    Polygon[{{1.077078, 1.163642, 0.008800},{1.078490, 1.163183, 0.010068},{
      1.078132, 1.160923, 0.010068},{1.076648, 1.160923, 0.008800}}],
    Polygon[{{1.078490, 1.163183, 0.010068},{1.080074, 1.162669, 0.011089},{
      1.079798, 1.160923, 0.011089},{1.078132, 1.160923, 0.010068}}],
    Polygon[{{1.080074, 1.162669, 0.011089},{1.081790, 1.162111, 0.011836},{
      1.081602, 1.160923, 0.011836},{1.079798, 1.160923, 0.011089}}],
    Polygon[{{1.081790, 1.162111, 0.011836},{1.083596, 1.161525, 0.012292},{
      1.083501, 1.160923, 0.012292},{1.081602, 1.160923, 0.011836}}],
    Polygon[{{1.083501, 1.160923, -0.012292},{1.081602, 1.160923, -0.011836},{
      1.081790, 1.159735, -0.011836},{1.083596, 1.160321, -0.012292}}],
    Polygon[{{1.081602, 1.160923, -0.011836},{1.079798, 1.160923, -0.011089},{
      1.080074, 1.159177, -0.011089},{1.081790, 1.159735, -0.011836}}],
    Polygon[{{1.079798, 1.160923, -0.011089},{1.078132, 1.160923, -0.010068},{
      1.078490, 1.158663, -0.010068},{1.080074, 1.159177, -0.011089}}],
    Polygon[{{1.078132, 1.160923, -0.010068},{1.076648, 1.160923, -0.008800},{
      1.077078, 1.158204, -0.008800},{1.078490, 1.158663, -0.010068}}],
    Polygon[{{1.076648, 1.160923, -0.008800},{1.075379, 1.160923, -0.007315},{
      1.075872, 1.157812, -0.007315},{1.077078, 1.158204, -0.008800}}],
    Polygon[{{1.075379, 1.160923, -0.007315},{1.074359, 1.160923, -0.005650},{
      1.074902, 1.157496, -0.005650},{1.075872, 1.157812, -0.007315}}],
    Polygon[{{1.074359, 1.160923, -0.005650},{1.073611, 1.160923, -0.003846},{
      1.074191, 1.157266, -0.003846},{1.074902, 1.157496, -0.005650}}],
    Polygon[{{1.073611, 1.160923, -0.003846},{1.073156, 1.160923, -0.001947},{
      1.073757, 1.157125, -0.001947},{1.074191, 1.157266, -0.003846}}],
    Polygon[{{1.073156, 1.160923, -0.001947},{1.073002, 1.160923, 0.000000},{
      1.073611, 1.157077, 0.000000},{1.073757, 1.157125, -0.001947}}],
    Polygon[{{1.073002, 1.160923, 0.000000},{1.073156, 1.160923, 0.001947},{
      1.073757, 1.157125, 0.001947},{1.073611, 1.157077, 0.000000}}],
    Polygon[{{1.073156, 1.160923, 0.001947},{1.073611, 1.160923, 0.003846},{
      1.074191, 1.157266, 0.003846},{1.073757, 1.157125, 0.001947}}],
    Polygon[{{1.073611, 1.160923, 0.003846},{1.074359, 1.160923, 0.005650},{
      1.074902, 1.157496, 0.005650},{1.074191, 1.157266, 0.003846}}],
    Polygon[{{1.074359, 1.160923, 0.005650},{1.075379, 1.160923, 0.007315},{
      1.075872, 1.157812, 0.007315},{1.074902, 1.157496, 0.005650}}],
    Polygon[{{1.075379, 1.160923, 0.007315},{1.076648, 1.160923, 0.008800},{
      1.077078, 1.158204, 0.008800},{1.075872, 1.157812, 0.007315}}],
    Polygon[{{1.076648, 1.160923, 0.008800},{1.078132, 1.160923, 0.010068},{
      1.078490, 1.158663, 0.010068},{1.077078, 1.158204, 0.008800}}],
    Polygon[{{1.078132, 1.160923, 0.010068},{1.079798, 1.160923, 0.011089},{
      1.080074, 1.159177, 0.011089},{1.078490, 1.158663, 0.010068}}],
    Polygon[{{1.079798, 1.160923, 0.011089},{1.081602, 1.160923, 0.011836},{
      1.081790, 1.159735, 0.011836},{1.080074, 1.159177, 0.011089}}],
    Polygon[{{1.081602, 1.160923, 0.011836},{1.083501, 1.160923, 0.012292},{
      1.083596, 1.160321, 0.012292},{1.081790, 1.159735, 0.011836}}],
    Polygon[{{1.083596, 1.160321, -0.012292},{1.081790, 1.159735, -0.011836},{
      1.082336, 1.158663, -0.011836},{1.083872, 1.159779, -0.012292}}],
    Polygon[{{1.081790, 1.159735, -0.011836},{1.080074, 1.159177, -0.011089},{
      1.080877, 1.157602, -0.011089},{1.082336, 1.158663, -0.011836}}],
    Polygon[{{1.080074, 1.159177, -0.011089},{1.078490, 1.158663, -0.010068},{
      1.079530, 1.156623, -0.010068},{1.080877, 1.157602, -0.011089}}],
    Polygon[{{1.078490, 1.158663, -0.010068},{1.077078, 1.158204, -0.008800},{
      1.078328, 1.155751, -0.008800},{1.079530, 1.156623, -0.010068}}],
    Polygon[{{1.077078, 1.158204, -0.008800},{1.075872, 1.157812, -0.007315},{
      1.077302, 1.155005, -0.007315},{1.078328, 1.155751, -0.008800}}],
    Polygon[{{1.075872, 1.157812, -0.007315},{1.074902, 1.157496, -0.005650},{
      1.076477, 1.154405, -0.005650},{1.077302, 1.155005, -0.007315}}],
    Polygon[{{1.074902, 1.157496, -0.005650},{1.074191, 1.157266, -0.003846},{
      1.075872, 1.153966, -0.003846},{1.076477, 1.154405, -0.005650}}],
    Polygon[{{1.074191, 1.157266, -0.003846},{1.073757, 1.157125, -0.001947},{
      1.075503, 1.153698, -0.001947},{1.075872, 1.153966, -0.003846}}],
    Polygon[{{1.073757, 1.157125, -0.001947},{1.073611, 1.157077, 0.000000},{
      1.075379, 1.153608, 0.000000},{1.075503, 1.153698, -0.001947}}],
    Polygon[{{1.073611, 1.157077, 0.000000},{1.073757, 1.157125, 0.001947},{
      1.075503, 1.153698, 0.001947},{1.075379, 1.153608, 0.000000}}],
    Polygon[{{1.073757, 1.157125, 0.001947},{1.074191, 1.157266, 0.003846},{
      1.075872, 1.153966, 0.003846},{1.075503, 1.153698, 0.001947}}],
    Polygon[{{1.074191, 1.157266, 0.003846},{1.074902, 1.157496, 0.005650},{
      1.076477, 1.154405, 0.005650},{1.075872, 1.153966, 0.003846}}],
    Polygon[{{1.074902, 1.157496, 0.005650},{1.075872, 1.157812, 0.007315},{
      1.077302, 1.155005, 0.007315},{1.076477, 1.154405, 0.005650}}],
    Polygon[{{1.075872, 1.157812, 0.007315},{1.077078, 1.158204, 0.008800},{
      1.078328, 1.155751, 0.008800},{1.077302, 1.155005, 0.007315}}],
    Polygon[{{1.077078, 1.158204, 0.008800},{1.078490, 1.158663, 0.010068},{
      1.079530, 1.156623, 0.010068},{1.078328, 1.155751, 0.008800}}],
    Polygon[{{1.078490, 1.158663, 0.010068},{1.080074, 1.159177, 0.011089},{
      1.080877, 1.157602, 0.011089},{1.079530, 1.156623, 0.010068}}],
    Polygon[{{1.080074, 1.159177, 0.011089},{1.081790, 1.159735, 0.011836},{
      1.082336, 1.158663, 0.011836},{1.080877, 1.157602, 0.011089}}],
    Polygon[{{1.081790, 1.159735, 0.011836},{1.083596, 1.160321, 0.012292},{
      1.083872, 1.159779, 0.012292},{1.082336, 1.158663, 0.011836}}],
    Polygon[{{1.083872, 1.159779, -0.012292},{1.082336, 1.158663, -0.011836},{
      1.083187, 1.157812, -0.011836},{1.084303, 1.159348, -0.012292}}],
    Polygon[{{1.082336, 1.158663, -0.011836},{1.080877, 1.157602, -0.011089},{
      1.082126, 1.156352, -0.011089},{1.083187, 1.157812, -0.011836}}],
    Polygon[{{1.080877, 1.157602, -0.011089},{1.079530, 1.156623, -0.010068},{
      1.081148, 1.155005, -0.010068},{1.082126, 1.156352, -0.011089}}],
    Polygon[{{1.079530, 1.156623, -0.010068},{1.078328, 1.155751, -0.008800},{
      1.080275, 1.153804, -0.008800},{1.081148, 1.155005, -0.010068}}],
    Polygon[{{1.078328, 1.155751, -0.008800},{1.077302, 1.155005, -0.007315},{
      1.079530, 1.152778, -0.007315},{1.080275, 1.153804, -0.008800}}],
    Polygon[{{1.077302, 1.155005, -0.007315},{1.076477, 1.154405, -0.005650},{
      1.078930, 1.151952, -0.005650},{1.079530, 1.152778, -0.007315}}],
    Polygon[{{1.076477, 1.154405, -0.005650},{1.075872, 1.153966, -0.003846},{
      1.078490, 1.151348, -0.003846},{1.078930, 1.151952, -0.005650}}],
    Polygon[{{1.075872, 1.153966, -0.003846},{1.075503, 1.153698, -0.001947},{
      1.078223, 1.150979, -0.001947},{1.078490, 1.151348, -0.003846}}],
    Polygon[{{1.075503, 1.153698, -0.001947},{1.075379, 1.153608, 0.000000},{
      1.078132, 1.150855, 0.000000},{1.078223, 1.150979, -0.001947}}],
    Polygon[{{1.075379, 1.153608, 0.000000},{1.075503, 1.153698, 0.001947},{
      1.078223, 1.150979, 0.001947},{1.078132, 1.150855, 0.000000}}],
    Polygon[{{1.075503, 1.153698, 0.001947},{1.075872, 1.153966, 0.003846},{
      1.078490, 1.151348, 0.003846},{1.078223, 1.150979, 0.001947}}],
    Polygon[{{1.075872, 1.153966, 0.003846},{1.076477, 1.154405, 0.005650},{
      1.078930, 1.151952, 0.005650},{1.078490, 1.151348, 0.003846}}],
    Polygon[{{1.076477, 1.154405, 0.005650},{1.077302, 1.155005, 0.007315},{
      1.079530, 1.152778, 0.007315},{1.078930, 1.151952, 0.005650}}],
    Polygon[{{1.077302, 1.155005, 0.007315},{1.078328, 1.155751, 0.008800},{
      1.080275, 1.153804, 0.008800},{1.079530, 1.152778, 0.007315}}],
    Polygon[{{1.078328, 1.155751, 0.008800},{1.079530, 1.156623, 0.010068},{
      1.081148, 1.155005, 0.010068},{1.080275, 1.153804, 0.008800}}],
    Polygon[{{1.079530, 1.156623, 0.010068},{1.080877, 1.157602, 0.011089},{
      1.082126, 1.156352, 0.011089},{1.081148, 1.155005, 0.010068}}],
    Polygon[{{1.080877, 1.157602, 0.011089},{1.082336, 1.158663, 0.011836},{
      1.083187, 1.157812, 0.011836},{1.082126, 1.156352, 0.011089}}],
    Polygon[{{1.082336, 1.158663, 0.011836},{1.083872, 1.159779, 0.012292},{
      1.084303, 1.159348, 0.012292},{1.083187, 1.157812, 0.011836}}],
    Polygon[{{1.084303, 1.159348, -0.012292},{1.083187, 1.157812, -0.011836},{
      1.084259, 1.157266, -0.011836},{1.084846, 1.159071, -0.012292}}],
    Polygon[{{1.083187, 1.157812, -0.011836},{1.082126, 1.156352, -0.011089},{
      1.083701, 1.155550, -0.011089},{1.084259, 1.157266, -0.011836}}],
    Polygon[{{1.082126, 1.156352, -0.011089},{1.081148, 1.155005, -0.010068},{
      1.083187, 1.153966, -0.010068},{1.083701, 1.155550, -0.011089}}],
    Polygon[{{1.081148, 1.155005, -0.010068},{1.080275, 1.153804, -0.008800},{
      1.082728, 1.152554, -0.008800},{1.083187, 1.153966, -0.010068}}],
    Polygon[{{1.080275, 1.153804, -0.008800},{1.079530, 1.152778, -0.007315},{
      1.082336, 1.151348, -0.007315},{1.082728, 1.152554, -0.008800}}],
    Polygon[{{1.079530, 1.152778, -0.007315},{1.078930, 1.151952, -0.005650},{
      1.082021, 1.150377, -0.005650},{1.082336, 1.151348, -0.007315}}],
    Polygon[{{1.078930, 1.151952, -0.005650},{1.078490, 1.151348, -0.003846},{
      1.081790, 1.149666, -0.003846},{1.082021, 1.150377, -0.005650}}],
    Polygon[{{1.078490, 1.151348, -0.003846},{1.078223, 1.150979, -0.001947},{
      1.081649, 1.149233, -0.001947},{1.081790, 1.149666, -0.003846}}],
    Polygon[{{1.078223, 1.150979, -0.001947},{1.078132, 1.150855, 0.000000},{
      1.081602, 1.149087, 0.000000},{1.081649, 1.149233, -0.001947}}],
    Polygon[{{1.078132, 1.150855, 0.000000},{1.078223, 1.150979, 0.001947},{
      1.081649, 1.149233, 0.001947},{1.081602, 1.149087, 0.000000}}],
    Polygon[{{1.078223, 1.150979, 0.001947},{1.078490, 1.151348, 0.003846},{
      1.081790, 1.149666, 0.003846},{1.081649, 1.149233, 0.001947}}],
    Polygon[{{1.078490, 1.151348, 0.003846},{1.078930, 1.151952, 0.005650},{
      1.082021, 1.150377, 0.005650},{1.081790, 1.149666, 0.003846}}],
    Polygon[{{1.078930, 1.151952, 0.005650},{1.079530, 1.152778, 0.007315},{
      1.082336, 1.151348, 0.007315},{1.082021, 1.150377, 0.005650}}],
    Polygon[{{1.079530, 1.152778, 0.007315},{1.080275, 1.153804, 0.008800},{
      1.082728, 1.152554, 0.008800},{1.082336, 1.151348, 0.007315}}],
    Polygon[{{1.080275, 1.153804, 0.008800},{1.081148, 1.155005, 0.010068},{
      1.083187, 1.153966, 0.010068},{1.082728, 1.152554, 0.008800}}],
    Polygon[{{1.081148, 1.155005, 0.010068},{1.082126, 1.156352, 0.011089},{
      1.083701, 1.155550, 0.011089},{1.083187, 1.153966, 0.010068}}],
    Polygon[{{1.082126, 1.156352, 0.011089},{1.083187, 1.157812, 0.011836},{
      1.084259, 1.157266, 0.011836},{1.083701, 1.155550, 0.011089}}],
    Polygon[{{1.083187, 1.157812, 0.011836},{1.084303, 1.159348, 0.012292},{
      1.084846, 1.159071, 0.012292},{1.084259, 1.157266, 0.011836}}],
    Polygon[{{1.084846, 1.159071, -0.012292},{1.084259, 1.157266, -0.011836},{
      1.085447, 1.157077, -0.011836},{1.085447, 1.158976, -0.012292}}],
    Polygon[{{1.084259, 1.157266, -0.011836},{1.083701, 1.155550, -0.011089},{
      1.085447, 1.155273, -0.011089},{1.085447, 1.157077, -0.011836}}],
    Polygon[{{1.083701, 1.155550, -0.011089},{1.083187, 1.153966, -0.010068},{
      1.085447, 1.153608, -0.010068},{1.085447, 1.155273, -0.011089}}],
    Polygon[{{1.083187, 1.153966, -0.010068},{1.082728, 1.152554, -0.008800},{
      1.085447, 1.152123, -0.008800},{1.085447, 1.153608, -0.010068}}],
    Polygon[{{1.082728, 1.152554, -0.008800},{1.082336, 1.151348, -0.007315},{
      1.085447, 1.150855, -0.007315},{1.085447, 1.152123, -0.008800}}],
    Polygon[{{1.082336, 1.151348, -0.007315},{1.082021, 1.150377, -0.005650},{
      1.085447, 1.149835, -0.005650},{1.085447, 1.150855, -0.007315}}],
    Polygon[{{1.082021, 1.150377, -0.005650},{1.081790, 1.149666, -0.003846},{
      1.085447, 1.149087, -0.003846},{1.085447, 1.149835, -0.005650}}],
    Polygon[{{1.081790, 1.149666, -0.003846},{1.081649, 1.149233, -0.001947},{
      1.085447, 1.148631, -0.001947},{1.085447, 1.149087, -0.003846}}],
    Polygon[{{1.081649, 1.149233, -0.001947},{1.081602, 1.149087, 0.000000},{
      1.085447, 1.148478, 0.000000},{1.085447, 1.148631, -0.001947}}],
    Polygon[{{1.081602, 1.149087, 0.000000},{1.081649, 1.149233, 0.001947},{
      1.085447, 1.148631, 0.001947},{1.085447, 1.148478, 0.000000}}],
    Polygon[{{1.081649, 1.149233, 0.001947},{1.081790, 1.149666, 0.003846},{
      1.085447, 1.149087, 0.003846},{1.085447, 1.148631, 0.001947}}],
    Polygon[{{1.081790, 1.149666, 0.003846},{1.082021, 1.150377, 0.005650},{
      1.085447, 1.149835, 0.005650},{1.085447, 1.149087, 0.003846}}],
    Polygon[{{1.082021, 1.150377, 0.005650},{1.082336, 1.151348, 0.007315},{
      1.085447, 1.150855, 0.007315},{1.085447, 1.149835, 0.005650}}],
    Polygon[{{1.082336, 1.151348, 0.007315},{1.082728, 1.152554, 0.008800},{
      1.085447, 1.152123, 0.008800},{1.085447, 1.150855, 0.007315}}],
    Polygon[{{1.082728, 1.152554, 0.008800},{1.083187, 1.153966, 0.010068},{
      1.085447, 1.153608, 0.010068},{1.085447, 1.152123, 0.008800}}],
    Polygon[{{1.083187, 1.153966, 0.010068},{1.083701, 1.155550, 0.011089},{
      1.085447, 1.155273, 0.011089},{1.085447, 1.153608, 0.010068}}],
    Polygon[{{1.083701, 1.155550, 0.011089},{1.084259, 1.157266, 0.011836},{
      1.085447, 1.157077, 0.011836},{1.085447, 1.155273, 0.011089}}],
    Polygon[{{1.084259, 1.157266, 0.011836},{1.084846, 1.159071, 0.012292},{
      1.085447, 1.158976, 0.012292},{1.085447, 1.157077, 0.011836}}],
    Polygon[{{1.085447, 1.158976, -0.012292},{1.085447, 1.157077, -0.011836},{
      1.086636, 1.157266, -0.011836},{1.086049, 1.159071, -0.012292}}],
    Polygon[{{1.085447, 1.157077, -0.011836},{1.085447, 1.155273, -0.011089},{
      1.087193, 1.155550, -0.011089},{1.086636, 1.157266, -0.011836}}],
    Polygon[{{1.085447, 1.155273, -0.011089},{1.085447, 1.153608, -0.010068},{
      1.087708, 1.153966, -0.010068},{1.087193, 1.155550, -0.011089}}],
    Polygon[{{1.085447, 1.153608, -0.010068},{1.085447, 1.152123, -0.008800},{
      1.088167, 1.152554, -0.008800},{1.087708, 1.153966, -0.010068}}],
    Polygon[{{1.085447, 1.152123, -0.008800},{1.085447, 1.150855, -0.007315},{
      1.088559, 1.151348, -0.007315},{1.088167, 1.152554, -0.008800}}],
    Polygon[{{1.085447, 1.150855, -0.007315},{1.085447, 1.149835, -0.005650},{
      1.088874, 1.150377, -0.005650},{1.088559, 1.151348, -0.007315}}],
    Polygon[{{1.085447, 1.149835, -0.005650},{1.085447, 1.149087, -0.003846},{
      1.089105, 1.149666, -0.003846},{1.088874, 1.150377, -0.005650}}],
    Polygon[{{1.085447, 1.149087, -0.003846},{1.085447, 1.148631, -0.001947},{
      1.089246, 1.149233, -0.001947},{1.089105, 1.149666, -0.003846}}],
    Polygon[{{1.085447, 1.148631, -0.001947},{1.085447, 1.148478, 0.000000},{
      1.089293, 1.149087, 0.000000},{1.089246, 1.149233, -0.001947}}],
    Polygon[{{1.085447, 1.148478, 0.000000},{1.085447, 1.148631, 0.001947},{
      1.089246, 1.149233, 0.001947},{1.089293, 1.149087, 0.000000}}],
    Polygon[{{1.085447, 1.148631, 0.001947},{1.085447, 1.149087, 0.003846},{
      1.089105, 1.149666, 0.003846},{1.089246, 1.149233, 0.001947}}],
    Polygon[{{1.085447, 1.149087, 0.003846},{1.085447, 1.149835, 0.005650},{
      1.088874, 1.150377, 0.005650},{1.089105, 1.149666, 0.003846}}],
    Polygon[{{1.085447, 1.149835, 0.005650},{1.085447, 1.150855, 0.007315},{
      1.088559, 1.151348, 0.007315},{1.088874, 1.150377, 0.005650}}],
    Polygon[{{1.085447, 1.150855, 0.007315},{1.085447, 1.152123, 0.008800},{
      1.088167, 1.152554, 0.008800},{1.088559, 1.151348, 0.007315}}],
    Polygon[{{1.085447, 1.152123, 0.008800},{1.085447, 1.153608, 0.010068},{
      1.087708, 1.153966, 0.010068},{1.088167, 1.152554, 0.008800}}],
    Polygon[{{1.085447, 1.153608, 0.010068},{1.085447, 1.155273, 0.011089},{
      1.087193, 1.155550, 0.011089},{1.087708, 1.153966, 0.010068}}],
    Polygon[{{1.085447, 1.155273, 0.011089},{1.085447, 1.157077, 0.011836},{
      1.086636, 1.157266, 0.011836},{1.087193, 1.155550, 0.011089}}],
    Polygon[{{1.085447, 1.157077, 0.011836},{1.085447, 1.158976, 0.012292},{
      1.086049, 1.159071, 0.012292},{1.086636, 1.157266, 0.011836}}],
    Polygon[{{1.086049, 1.159071, -0.012292},{1.086636, 1.157266, -0.011836},{
      1.087708, 1.157812, -0.011836},{1.086592, 1.159348, -0.012292}}],
    Polygon[{{1.086636, 1.157266, -0.011836},{1.087193, 1.155550, -0.011089},{
      1.088768, 1.156352, -0.011089},{1.087708, 1.157812, -0.011836}}],
    Polygon[{{1.087193, 1.155550, -0.011089},{1.087708, 1.153966, -0.010068},{
      1.089747, 1.155005, -0.010068},{1.088768, 1.156352, -0.011089}}],
    Polygon[{{1.087708, 1.153966, -0.010068},{1.088167, 1.152554, -0.008800},{
      1.090620, 1.153804, -0.008800},{1.089747, 1.155005, -0.010068}}],
    Polygon[{{1.088167, 1.152554, -0.008800},{1.088559, 1.151348, -0.007315},{
      1.091365, 1.152778, -0.007315},{1.090620, 1.153804, -0.008800}}],
    Polygon[{{1.088559, 1.151348, -0.007315},{1.088874, 1.150377, -0.005650},{
      1.091965, 1.151952, -0.005650},{1.091365, 1.152778, -0.007315}}],
    Polygon[{{1.088874, 1.150377, -0.005650},{1.089105, 1.149666, -0.003846},{
      1.092404, 1.151348, -0.003846},{1.091965, 1.151952, -0.005650}}],
    Polygon[{{1.089105, 1.149666, -0.003846},{1.089246, 1.149233, -0.001947},{
      1.092672, 1.150979, -0.001947},{1.092404, 1.151348, -0.003846}}],
    Polygon[{{1.089246, 1.149233, -0.001947},{1.089293, 1.149087, 0.000000},{
      1.092762, 1.150855, 0.000000},{1.092672, 1.150979, -0.001947}}],
    Polygon[{{1.089293, 1.149087, 0.000000},{1.089246, 1.149233, 0.001947},{
      1.092672, 1.150979, 0.001947},{1.092762, 1.150855, 0.000000}}],
    Polygon[{{1.089246, 1.149233, 0.001947},{1.089105, 1.149666, 0.003846},{
      1.092404, 1.151348, 0.003846},{1.092672, 1.150979, 0.001947}}],
    Polygon[{{1.089105, 1.149666, 0.003846},{1.088874, 1.150377, 0.005650},{
      1.091965, 1.151952, 0.005650},{1.092404, 1.151348, 0.003846}}],
    Polygon[{{1.088874, 1.150377, 0.005650},{1.088559, 1.151348, 0.007315},{
      1.091365, 1.152778, 0.007315},{1.091965, 1.151952, 0.005650}}],
    Polygon[{{1.088559, 1.151348, 0.007315},{1.088167, 1.152554, 0.008800},{
      1.090620, 1.153804, 0.008800},{1.091365, 1.152778, 0.007315}}],
    Polygon[{{1.088167, 1.152554, 0.008800},{1.087708, 1.153966, 0.010068},{
      1.089747, 1.155005, 0.010068},{1.090620, 1.153804, 0.008800}}],
    Polygon[{{1.087708, 1.153966, 0.010068},{1.087193, 1.155550, 0.011089},{
      1.088768, 1.156352, 0.011089},{1.089747, 1.155005, 0.010068}}],
    Polygon[{{1.087193, 1.155550, 0.011089},{1.086636, 1.157266, 0.011836},{
      1.087708, 1.157812, 0.011836},{1.088768, 1.156352, 0.011089}}],
    Polygon[{{1.086636, 1.157266, 0.011836},{1.086049, 1.159071, 0.012292},{
      1.086592, 1.159348, 0.012292},{1.087708, 1.157812, 0.011836}}],
    Polygon[{{1.086592, 1.159348, -0.012292},{1.087708, 1.157812, -0.011836},{
      1.088559, 1.158663, -0.011836},{1.087022, 1.159779, -0.012292}}],
    Polygon[{{1.087708, 1.157812, -0.011836},{1.088768, 1.156352, -0.011089},{
      1.090018, 1.157602, -0.011089},{1.088559, 1.158663, -0.011836}}],
    Polygon[{{1.088768, 1.156352, -0.011089},{1.089747, 1.155005, -0.010068},{
      1.091365, 1.156623, -0.010068},{1.090018, 1.157602, -0.011089}}],
    Polygon[{{1.089747, 1.155005, -0.010068},{1.090620, 1.153804, -0.008800},{
      1.092567, 1.155751, -0.008800},{1.091365, 1.156623, -0.010068}}],
    Polygon[{{1.090620, 1.153804, -0.008800},{1.091365, 1.152778, -0.007315},{
      1.093593, 1.155005, -0.007315},{1.092567, 1.155751, -0.008800}}],
    Polygon[{{1.091365, 1.152778, -0.007315},{1.091965, 1.151952, -0.005650},{
      1.094418, 1.154405, -0.005650},{1.093593, 1.155005, -0.007315}}],
    Polygon[{{1.091965, 1.151952, -0.005650},{1.092404, 1.151348, -0.003846},{
      1.095023, 1.153966, -0.003846},{1.094418, 1.154405, -0.005650}}],
    Polygon[{{1.092404, 1.151348, -0.003846},{1.092672, 1.150979, -0.001947},{
      1.095392, 1.153698, -0.001947},{1.095023, 1.153966, -0.003846}}],
    Polygon[{{1.092672, 1.150979, -0.001947},{1.092762, 1.150855, 0.000000},{
      1.095516, 1.153608, 0.000000},{1.095392, 1.153698, -0.001947}}],
    Polygon[{{1.092762, 1.150855, 0.000000},{1.092672, 1.150979, 0.001947},{
      1.095392, 1.153698, 0.001947},{1.095516, 1.153608, 0.000000}}],
    Polygon[{{1.092672, 1.150979, 0.001947},{1.092404, 1.151348, 0.003846},{
      1.095023, 1.153966, 0.003846},{1.095392, 1.153698, 0.001947}}],
    Polygon[{{1.092404, 1.151348, 0.003846},{1.091965, 1.151952, 0.005650},{
      1.094418, 1.154405, 0.005650},{1.095023, 1.153966, 0.003846}}],
    Polygon[{{1.091965, 1.151952, 0.005650},{1.091365, 1.152778, 0.007315},{
      1.093593, 1.155005, 0.007315},{1.094418, 1.154405, 0.005650}}],
    Polygon[{{1.091365, 1.152778, 0.007315},{1.090620, 1.153804, 0.008800},{
      1.092567, 1.155751, 0.008800},{1.093593, 1.155005, 0.007315}}],
    Polygon[{{1.090620, 1.153804, 0.008800},{1.089747, 1.155005, 0.010068},{
      1.091365, 1.156623, 0.010068},{1.092567, 1.155751, 0.008800}}],
    Polygon[{{1.089747, 1.155005, 0.010068},{1.088768, 1.156352, 0.011089},{
      1.090018, 1.157602, 0.011089},{1.091365, 1.156623, 0.010068}}],
    Polygon[{{1.088768, 1.156352, 0.011089},{1.087708, 1.157812, 0.011836},{
      1.088559, 1.158663, 0.011836},{1.090018, 1.157602, 0.011089}}],
    Polygon[{{1.087708, 1.157812, 0.011836},{1.086592, 1.159348, 0.012292},{
      1.087022, 1.159779, 0.012292},{1.088559, 1.158663, 0.011836}}],
    Polygon[{{1.087022, 1.159779, -0.012292},{1.088559, 1.158663, -0.011836},{
      1.089105, 1.159735, -0.011836},{1.087299, 1.160321, -0.012292}}],
    Polygon[{{1.088559, 1.158663, -0.011836},{1.090018, 1.157602, -0.011089},{
      1.090821, 1.159177, -0.011089},{1.089105, 1.159735, -0.011836}}],
    Polygon[{{1.090018, 1.157602, -0.011089},{1.091365, 1.156623, -0.010068},{
      1.092404, 1.158663, -0.010068},{1.090821, 1.159177, -0.011089}}],
    Polygon[{{1.091365, 1.156623, -0.010068},{1.092567, 1.155751, -0.008800},{
      1.093817, 1.158204, -0.008800},{1.092404, 1.158663, -0.010068}}],
    Polygon[{{1.092567, 1.155751, -0.008800},{1.093593, 1.155005, -0.007315},{
      1.095023, 1.157812, -0.007315},{1.093817, 1.158204, -0.008800}}],
    Polygon[{{1.093593, 1.155005, -0.007315},{1.094418, 1.154405, -0.005650},{
      1.095993, 1.157496, -0.005650},{1.095023, 1.157812, -0.007315}}],
    Polygon[{{1.094418, 1.154405, -0.005650},{1.095023, 1.153966, -0.003846},{
      1.096704, 1.157266, -0.003846},{1.095993, 1.157496, -0.005650}}],
    Polygon[{{1.095023, 1.153966, -0.003846},{1.095392, 1.153698, -0.001947},{
      1.097138, 1.157125, -0.001947},{1.096704, 1.157266, -0.003846}}],
    Polygon[{{1.095392, 1.153698, -0.001947},{1.095516, 1.153608, 0.000000},{
      1.097283, 1.157077, 0.000000},{1.097138, 1.157125, -0.001947}}],
    Polygon[{{1.095516, 1.153608, 0.000000},{1.095392, 1.153698, 0.001947},{
      1.097138, 1.157125, 0.001947},{1.097283, 1.157077, 0.000000}}],
    Polygon[{{1.095392, 1.153698, 0.001947},{1.095023, 1.153966, 0.003846},{
      1.096704, 1.157266, 0.003846},{1.097138, 1.157125, 0.001947}}],
    Polygon[{{1.095023, 1.153966, 0.003846},{1.094418, 1.154405, 0.005650},{
      1.095993, 1.157496, 0.005650},{1.096704, 1.157266, 0.003846}}],
    Polygon[{{1.094418, 1.154405, 0.005650},{1.093593, 1.155005, 0.007315},{
      1.095023, 1.157812, 0.007315},{1.095993, 1.157496, 0.005650}}],
    Polygon[{{1.093593, 1.155005, 0.007315},{1.092567, 1.155751, 0.008800},{
      1.093817, 1.158204, 0.008800},{1.095023, 1.157812, 0.007315}}],
    Polygon[{{1.092567, 1.155751, 0.008800},{1.091365, 1.156623, 0.010068},{
      1.092404, 1.158663, 0.010068},{1.093817, 1.158204, 0.008800}}],
    Polygon[{{1.091365, 1.156623, 0.010068},{1.090018, 1.157602, 0.011089},{
      1.090821, 1.159177, 0.011089},{1.092404, 1.158663, 0.010068}}],
    Polygon[{{1.090018, 1.157602, 0.011089},{1.088559, 1.158663, 0.011836},{
      1.089105, 1.159735, 0.011836},{1.090821, 1.159177, 0.011089}}],
    Polygon[{{1.088559, 1.158663, 0.011836},{1.087022, 1.159779, 0.012292},{
      1.087299, 1.160321, 0.012292},{1.089105, 1.159735, 0.011836}}],
    Polygon[{{1.087299, 1.160321, -0.012292},{1.089105, 1.159735, -0.011836},{
      1.089293, 1.160923, -0.011836},{1.087394, 1.160923, -0.012292}}],
    Polygon[{{1.089105, 1.159735, -0.011836},{1.090821, 1.159177, -0.011089},{
      1.091097, 1.160923, -0.011089},{1.089293, 1.160923, -0.011836}}],
    Polygon[{{1.090821, 1.159177, -0.011089},{1.092404, 1.158663, -0.010068},{
      1.092762, 1.160923, -0.010068},{1.091097, 1.160923, -0.011089}}],
    Polygon[{{1.092404, 1.158663, -0.010068},{1.093817, 1.158204, -0.008800},{
      1.094247, 1.160923, -0.008800},{1.092762, 1.160923, -0.010068}}],
    Polygon[{{1.093817, 1.158204, -0.008800},{1.095023, 1.157812, -0.007315},{
      1.095516, 1.160923, -0.007315},{1.094247, 1.160923, -0.008800}}],
    Polygon[{{1.095023, 1.157812, -0.007315},{1.095993, 1.157496, -0.005650},{
      1.096536, 1.160923, -0.005650},{1.095516, 1.160923, -0.007315}}],
    Polygon[{{1.095993, 1.157496, -0.005650},{1.096704, 1.157266, -0.003846},{
      1.097283, 1.160923, -0.003846},{1.096536, 1.160923, -0.005650}}],
    Polygon[{{1.096704, 1.157266, -0.003846},{1.097138, 1.157125, -0.001947},{
      1.097739, 1.160923, -0.001947},{1.097283, 1.160923, -0.003846}}],
    Polygon[{{1.097138, 1.157125, -0.001947},{1.097283, 1.157077, 0.000000},{
      1.097892, 1.160923, 0.000000},{1.097739, 1.160923, -0.001947}}],
    Polygon[{{1.097283, 1.157077, 0.000000},{1.097138, 1.157125, 0.001947},{
      1.097739, 1.160923, 0.001947},{1.097892, 1.160923, 0.000000}}],
    Polygon[{{1.097138, 1.157125, 0.001947},{1.096704, 1.157266, 0.003846},{
      1.097283, 1.160923, 0.003846},{1.097739, 1.160923, 0.001947}}],
    Polygon[{{1.096704, 1.157266, 0.003846},{1.095993, 1.157496, 0.005650},{
      1.096536, 1.160923, 0.005650},{1.097283, 1.160923, 0.003846}}],
    Polygon[{{1.095993, 1.157496, 0.005650},{1.095023, 1.157812, 0.007315},{
      1.095516, 1.160923, 0.007315},{1.096536, 1.160923, 0.005650}}],
    Polygon[{{1.095023, 1.157812, 0.007315},{1.093817, 1.158204, 0.008800},{
      1.094247, 1.160923, 0.008800},{1.095516, 1.160923, 0.007315}}],
    Polygon[{{1.093817, 1.158204, 0.008800},{1.092404, 1.158663, 0.010068},{
      1.092762, 1.160923, 0.010068},{1.094247, 1.160923, 0.008800}}],
    Polygon[{{1.092404, 1.158663, 0.010068},{1.090821, 1.159177, 0.011089},{
      1.091097, 1.160923, 0.011089},{1.092762, 1.160923, 0.010068}}],
    Polygon[{{1.090821, 1.159177, 0.011089},{1.089105, 1.159735, 0.011836},{
      1.089293, 1.160923, 0.011836},{1.091097, 1.160923, 0.011089}}],
    Polygon[{{1.089105, 1.159735, 0.011836},{1.087299, 1.160321, 0.012292},{
      1.087394, 1.160923, 0.012292},{1.089293, 1.160923, 0.011836}}],
    Polygon[{{1.150850, 1.145043, -0.009538},{1.152324, 1.145043, -0.009185},{
      1.152178, 1.145966, -0.009185},{1.150776, 1.145510, -0.009538}}],
    Polygon[{{1.152324, 1.145043, -0.009185},{1.153724, 1.145043, -0.008605},{
      1.153509, 1.146398, -0.008605},{1.152178, 1.145966, -0.009185}}],
    Polygon[{{1.153724, 1.145043, -0.008605},{1.155016, 1.145043, -0.007813},{
      1.154738, 1.146797, -0.007813},{1.153509, 1.146398, -0.008605}}],
    Polygon[{{1.155016, 1.145043, -0.007813},{1.156168, 1.145043, -0.006829},{
      1.155834, 1.147153, -0.006829},{1.154738, 1.146797, -0.007813}}],
    Polygon[{{1.156168, 1.145043, -0.006829},{1.157152, 1.145043, -0.005676},{
      1.156770, 1.147458, -0.005676},{1.155834, 1.147153, -0.006829}}],
    Polygon[{{1.157152, 1.145043, -0.005676},{1.157944, 1.145043, -0.004384},{
      1.157523, 1.147702, -0.004384},{1.156770, 1.147458, -0.005676}}],
    Polygon[{{1.157944, 1.145043, -0.004384},{1.158524, 1.145043, -0.002984},{
      1.158074, 1.147882, -0.002984},{1.157523, 1.147702, -0.004384}}],
    Polygon[{{1.158524, 1.145043, -0.002984},{1.158878, 1.145043, -0.001511},{
      1.158411, 1.147991, -0.001511},{1.158074, 1.147882, -0.002984}}],
    Polygon[{{1.158878, 1.145043, -0.001511},{1.158997, 1.145043, 0.000000},{
      1.158524, 1.148028, 0.000000},{1.158411, 1.147991, -0.001511}}],
    Polygon[{{1.158997, 1.145043, 0.000000},{1.158878, 1.145043, 0.001511},{
      1.158411, 1.147991, 0.001511},{1.158524, 1.148028, 0.000000}}],
    Polygon[{{1.158878, 1.145043, 0.001511},{1.158524, 1.145043, 0.002984},{
      1.158074, 1.147882, 0.002984},{1.158411, 1.147991, 0.001511}}],
    Polygon[{{1.158524, 1.145043, 0.002984},{1.157944, 1.145043, 0.004384},{
      1.157523, 1.147702, 0.004384},{1.158074, 1.147882, 0.002984}}],
    Polygon[{{1.157944, 1.145043, 0.004384},{1.157152, 1.145043, 0.005676},{
      1.156770, 1.147458, 0.005676},{1.157523, 1.147702, 0.004384}}],
    Polygon[{{1.157152, 1.145043, 0.005676},{1.156168, 1.145043, 0.006829},{
      1.155834, 1.147153, 0.006829},{1.156770, 1.147458, 0.005676}}],
    Polygon[{{1.156168, 1.145043, 0.006829},{1.155016, 1.145043, 0.007813},{
      1.154738, 1.146797, 0.007813},{1.155834, 1.147153, 0.006829}}],
    Polygon[{{1.155016, 1.145043, 0.007813},{1.153724, 1.145043, 0.008605},{
      1.153509, 1.146398, 0.008605},{1.154738, 1.146797, 0.007813}}],
    Polygon[{{1.153724, 1.145043, 0.008605},{1.152324, 1.145043, 0.009185},{
      1.152178, 1.145966, 0.009185},{1.153509, 1.146398, 0.008605}}],
    Polygon[{{1.152324, 1.145043, 0.009185},{1.150850, 1.145043, 0.009538},{
      1.150776, 1.145510, 0.009538},{1.152178, 1.145966, 0.009185}}],
    Polygon[{{1.150776, 1.145510, -0.009538},{1.152178, 1.145966, -0.009185},{
      1.151754, 1.146797, -0.009185},{1.150562, 1.145931, -0.009538}}],
    Polygon[{{1.152178, 1.145966, -0.009185},{1.153509, 1.146398, -0.008605},{
      1.152886, 1.147620, -0.008605},{1.151754, 1.146797, -0.009185}}],
    Polygon[{{1.153509, 1.146398, -0.008605},{1.154738, 1.146797, -0.007813},{
      1.153932, 1.148380, -0.007813},{1.152886, 1.147620, -0.008605}}],
    Polygon[{{1.154738, 1.146797, -0.007813},{1.155834, 1.147153, -0.006829},{
      1.154864, 1.149057, -0.006829},{1.153932, 1.148380, -0.007813}}],
    Polygon[{{1.155834, 1.147153, -0.006829},{1.156770, 1.147458, -0.005676},{
      1.155660, 1.149636, -0.005676},{1.154864, 1.149057, -0.006829}}],
    Polygon[{{1.156770, 1.147458, -0.005676},{1.157523, 1.147702, -0.004384},{
      1.156301, 1.150101, -0.004384},{1.155660, 1.149636, -0.005676}}],
    Polygon[{{1.157523, 1.147702, -0.004384},{1.158074, 1.147882, -0.002984},{
      1.156770, 1.150442, -0.002984},{1.156301, 1.150101, -0.004384}}],
    Polygon[{{1.158074, 1.147882, -0.002984},{1.158411, 1.147991, -0.001511},{
      1.157056, 1.150650, -0.001511},{1.156770, 1.150442, -0.002984}}],
    Polygon[{{1.158411, 1.147991, -0.001511},{1.158524, 1.148028, 0.000000},{
      1.157152, 1.150720, 0.000000},{1.157056, 1.150650, -0.001511}}],
    Polygon[{{1.158524, 1.148028, 0.000000},{1.158411, 1.147991, 0.001511},{
      1.157056, 1.150650, 0.001511},{1.157152, 1.150720, 0.000000}}],
    Polygon[{{1.158411, 1.147991, 0.001511},{1.158074, 1.147882, 0.002984},{
      1.156770, 1.150442, 0.002984},{1.157056, 1.150650, 0.001511}}],
    Polygon[{{1.158074, 1.147882, 0.002984},{1.157523, 1.147702, 0.004384},{
      1.156301, 1.150101, 0.004384},{1.156770, 1.150442, 0.002984}}],
    Polygon[{{1.157523, 1.147702, 0.004384},{1.156770, 1.147458, 0.005676},{
      1.155660, 1.149636, 0.005676},{1.156301, 1.150101, 0.004384}}],
    Polygon[{{1.156770, 1.147458, 0.005676},{1.155834, 1.147153, 0.006829},{
      1.154864, 1.149057, 0.006829},{1.155660, 1.149636, 0.005676}}],
    Polygon[{{1.155834, 1.147153, 0.006829},{1.154738, 1.146797, 0.007813},{
      1.153932, 1.148380, 0.007813},{1.154864, 1.149057, 0.006829}}],
    Polygon[{{1.154738, 1.146797, 0.007813},{1.153509, 1.146398, 0.008605},{
      1.152886, 1.147620, 0.008605},{1.153932, 1.148380, 0.007813}}],
    Polygon[{{1.153509, 1.146398, 0.008605},{1.152178, 1.145966, 0.009185},{
      1.151754, 1.146797, 0.009185},{1.152886, 1.147620, 0.008605}}],
    Polygon[{{1.152178, 1.145966, 0.009185},{1.150776, 1.145510, 0.009538},{
      1.150562, 1.145931, 0.009538},{1.151754, 1.146797, 0.009185}}],
    Polygon[{{1.150562, 1.145931, -0.009538},{1.151754, 1.146797, -0.009185},{
      1.151094, 1.147458, -0.009185},{1.150227, 1.146266, -0.009538}}],
    Polygon[{{1.151754, 1.146797, -0.009185},{1.152886, 1.147620, -0.008605},{
      1.151917, 1.148590, -0.008605},{1.151094, 1.147458, -0.009185}}],
    Polygon[{{1.152886, 1.147620, -0.008605},{1.153932, 1.148380, -0.007813},{
      1.152676, 1.149636, -0.007813},{1.151917, 1.148590, -0.008605}}],
    Polygon[{{1.153932, 1.148380, -0.007813},{1.154864, 1.149057, -0.006829},{
      1.153353, 1.150568, -0.006829},{1.152676, 1.149636, -0.007813}}],
    Polygon[{{1.154864, 1.149057, -0.006829},{1.155660, 1.149636, -0.005676},{
      1.153932, 1.151364, -0.005676},{1.153353, 1.150568, -0.006829}}],
    Polygon[{{1.155660, 1.149636, -0.005676},{1.156301, 1.150101, -0.004384},{
      1.154397, 1.152005, -0.004384},{1.153932, 1.151364, -0.005676}}],
    Polygon[{{1.156301, 1.150101, -0.004384},{1.156770, 1.150442, -0.002984},{
      1.154738, 1.152474, -0.002984},{1.154397, 1.152005, -0.004384}}],
    Polygon[{{1.156770, 1.150442, -0.002984},{1.157056, 1.150650, -0.001511},{
      1.154946, 1.152760, -0.001511},{1.154738, 1.152474, -0.002984}}],
    Polygon[{{1.157056, 1.150650, -0.001511},{1.157152, 1.150720, 0.000000},{
      1.155016, 1.152856, 0.000000},{1.154946, 1.152760, -0.001511}}],
    Polygon[{{1.157152, 1.150720, 0.000000},{1.157056, 1.150650, 0.001511},{
      1.154946, 1.152760, 0.001511},{1.155016, 1.152856, 0.000000}}],
    Polygon[{{1.157056, 1.150650, 0.001511},{1.156770, 1.150442, 0.002984},{
      1.154738, 1.152474, 0.002984},{1.154946, 1.152760, 0.001511}}],
    Polygon[{{1.156770, 1.150442, 0.002984},{1.156301, 1.150101, 0.004384},{
      1.154397, 1.152005, 0.004384},{1.154738, 1.152474, 0.002984}}],
    Polygon[{{1.156301, 1.150101, 0.004384},{1.155660, 1.149636, 0.005676},{
      1.153932, 1.151364, 0.005676},{1.154397, 1.152005, 0.004384}}],
    Polygon[{{1.155660, 1.149636, 0.005676},{1.154864, 1.149057, 0.006829},{
      1.153353, 1.150568, 0.006829},{1.153932, 1.151364, 0.005676}}],
    Polygon[{{1.154864, 1.149057, 0.006829},{1.153932, 1.148380, 0.007813},{
      1.152676, 1.149636, 0.007813},{1.153353, 1.150568, 0.006829}}],
    Polygon[{{1.153932, 1.148380, 0.007813},{1.152886, 1.147620, 0.008605},{
      1.151917, 1.148590, 0.008605},{1.152676, 1.149636, 0.007813}}],
    Polygon[{{1.152886, 1.147620, 0.008605},{1.151754, 1.146797, 0.009185},{
      1.151094, 1.147458, 0.009185},{1.151917, 1.148590, 0.008605}}],
    Polygon[{{1.151754, 1.146797, 0.009185},{1.150562, 1.145931, 0.009538},{
      1.150227, 1.146266, 0.009538},{1.151094, 1.147458, 0.009185}}],
    Polygon[{{1.150227, 1.146266, -0.009538},{1.151094, 1.147458, -0.009185},{
      1.150262, 1.147882, -0.009185},{1.149806, 1.146480, -0.009538}}],
    Polygon[{{1.151094, 1.147458, -0.009185},{1.151917, 1.148590, -0.008605},{
      1.150694, 1.149213, -0.008605},{1.150262, 1.147882, -0.009185}}],
    Polygon[{{1.151917, 1.148590, -0.008605},{1.152676, 1.149636, -0.007813},{
      1.151094, 1.150442, -0.007813},{1.150694, 1.149213, -0.008605}}],
    Polygon[{{1.152676, 1.149636, -0.007813},{1.153353, 1.150568, -0.006829},{
      1.151450, 1.151538, -0.006829},{1.151094, 1.150442, -0.007813}}],
    Polygon[{{1.153353, 1.150568, -0.006829},{1.153932, 1.151364, -0.005676},{
      1.151754, 1.152474, -0.005676},{1.151450, 1.151538, -0.006829}}],
    Polygon[{{1.153932, 1.151364, -0.005676},{1.154397, 1.152005, -0.004384},{
      1.151999, 1.153227, -0.004384},{1.151754, 1.152474, -0.005676}}],
    Polygon[{{1.154397, 1.152005, -0.004384},{1.154738, 1.152474, -0.002984},{
      1.152178, 1.153778, -0.002984},{1.151999, 1.153227, -0.004384}}],
    Polygon[{{1.154738, 1.152474, -0.002984},{1.154946, 1.152760, -0.001511},{
      1.152287, 1.154115, -0.001511},{1.152178, 1.153778, -0.002984}}],
    Polygon[{{1.154946, 1.152760, -0.001511},{1.155016, 1.152856, 0.000000},{
      1.152324, 1.154228, 0.000000},{1.152287, 1.154115, -0.001511}}],
    Polygon[{{1.155016, 1.152856, 0.000000},{1.154946, 1.152760, 0.001511},{
      1.152287, 1.154115, 0.001511},{1.152324, 1.154228, 0.000000}}],
    Polygon[{{1.154946, 1.152760, 0.001511},{1.154738, 1.152474, 0.002984},{
      1.152178, 1.153778, 0.002984},{1.152287, 1.154115, 0.001511}}],
    Polygon[{{1.154738, 1.152474, 0.002984},{1.154397, 1.152005, 0.004384},{
      1.151999, 1.153227, 0.004384},{1.152178, 1.153778, 0.002984}}],
    Polygon[{{1.154397, 1.152005, 0.004384},{1.153932, 1.151364, 0.005676},{
      1.151754, 1.152474, 0.005676},{1.151999, 1.153227, 0.004384}}],
    Polygon[{{1.153932, 1.151364, 0.005676},{1.153353, 1.150568, 0.006829},{
      1.151450, 1.151538, 0.006829},{1.151754, 1.152474, 0.005676}}],
    Polygon[{{1.153353, 1.150568, 0.006829},{1.152676, 1.149636, 0.007813},{
      1.151094, 1.150442, 0.007813},{1.151450, 1.151538, 0.006829}}],
    Polygon[{{1.152676, 1.149636, 0.007813},{1.151917, 1.148590, 0.008605},{
      1.150694, 1.149213, 0.008605},{1.151094, 1.150442, 0.007813}}],
    Polygon[{{1.151917, 1.148590, 0.008605},{1.151094, 1.147458, 0.009185},{
      1.150262, 1.147882, 0.009185},{1.150694, 1.149213, 0.008605}}],
    Polygon[{{1.151094, 1.147458, 0.009185},{1.150227, 1.146266, 0.009538},{
      1.149806, 1.146480, 0.009538},{1.150262, 1.147882, 0.009185}}],
    Polygon[{{1.149806, 1.146480, -0.009538},{1.150262, 1.147882, -0.009185},{
      1.149339, 1.148028, -0.009185},{1.149339, 1.146554, -0.009538}}],
    Polygon[{{1.150262, 1.147882, -0.009185},{1.150694, 1.149213, -0.008605},{
      1.149339, 1.149428, -0.008605},{1.149339, 1.148028, -0.009185}}],
    Polygon[{{1.150694, 1.149213, -0.008605},{1.151094, 1.150442, -0.007813},{
      1.149339, 1.150720, -0.007813},{1.149339, 1.149428, -0.008605}}],
    Polygon[{{1.151094, 1.150442, -0.007813},{1.151450, 1.151538, -0.006829},{
      1.149339, 1.151872, -0.006829},{1.149339, 1.150720, -0.007813}}],
    Polygon[{{1.151450, 1.151538, -0.006829},{1.151754, 1.152474, -0.005676},{
      1.149339, 1.152856, -0.005676},{1.149339, 1.151872, -0.006829}}],
    Polygon[{{1.151754, 1.152474, -0.005676},{1.151999, 1.153227, -0.004384},{
      1.149339, 1.153648, -0.004384},{1.149339, 1.152856, -0.005676}}],
    Polygon[{{1.151999, 1.153227, -0.004384},{1.152178, 1.153778, -0.002984},{
      1.149339, 1.154228, -0.002984},{1.149339, 1.153648, -0.004384}}],
    Polygon[{{1.152178, 1.153778, -0.002984},{1.152287, 1.154115, -0.001511},{
      1.149339, 1.154582, -0.001511},{1.149339, 1.154228, -0.002984}}],
    Polygon[{{1.152287, 1.154115, -0.001511},{1.152324, 1.154228, 0.000000},{
      1.149339, 1.154701, 0.000000},{1.149339, 1.154582, -0.001511}}],
    Polygon[{{1.152324, 1.154228, 0.000000},{1.152287, 1.154115, 0.001511},{
      1.149339, 1.154582, 0.001511},{1.149339, 1.154701, 0.000000}}],
    Polygon[{{1.152287, 1.154115, 0.001511},{1.152178, 1.153778, 0.002984},{
      1.149339, 1.154228, 0.002984},{1.149339, 1.154582, 0.001511}}],
    Polygon[{{1.152178, 1.153778, 0.002984},{1.151999, 1.153227, 0.004384},{
      1.149339, 1.153648, 0.004384},{1.149339, 1.154228, 0.002984}}],
    Polygon[{{1.151999, 1.153227, 0.004384},{1.151754, 1.152474, 0.005676},{
      1.149339, 1.152856, 0.005676},{1.149339, 1.153648, 0.004384}}],
    Polygon[{{1.151754, 1.152474, 0.005676},{1.151450, 1.151538, 0.006829},{
      1.149339, 1.151872, 0.006829},{1.149339, 1.152856, 0.005676}}],
    Polygon[{{1.151450, 1.151538, 0.006829},{1.151094, 1.150442, 0.007813},{
      1.149339, 1.150720, 0.007813},{1.149339, 1.151872, 0.006829}}],
    Polygon[{{1.151094, 1.150442, 0.007813},{1.150694, 1.149213, 0.008605},{
      1.149339, 1.149428, 0.008605},{1.149339, 1.150720, 0.007813}}],
    Polygon[{{1.150694, 1.149213, 0.008605},{1.150262, 1.147882, 0.009185},{
      1.149339, 1.148028, 0.009185},{1.149339, 1.149428, 0.008605}}],
    Polygon[{{1.150262, 1.147882, 0.009185},{1.149806, 1.146480, 0.009538},{
      1.149339, 1.146554, 0.009538},{1.149339, 1.148028, 0.009185}}],
    Polygon[{{1.149339, 1.146554, -0.009538},{1.149339, 1.148028, -0.009185},{
      1.148417, 1.147882, -0.009185},{1.148873, 1.146480, -0.009538}}],
    Polygon[{{1.149339, 1.148028, -0.009185},{1.149339, 1.149428, -0.008605},{
      1.147985, 1.149213, -0.008605},{1.148417, 1.147882, -0.009185}}],
    Polygon[{{1.149339, 1.149428, -0.008605},{1.149339, 1.150720, -0.007813},{
      1.147585, 1.150442, -0.007813},{1.147985, 1.149213, -0.008605}}],
    Polygon[{{1.149339, 1.150720, -0.007813},{1.149339, 1.151872, -0.006829},{
      1.147229, 1.151538, -0.006829},{1.147585, 1.150442, -0.007813}}],
    Polygon[{{1.149339, 1.151872, -0.006829},{1.149339, 1.152856, -0.005676},{
      1.146925, 1.152474, -0.005676},{1.147229, 1.151538, -0.006829}}],
    Polygon[{{1.149339, 1.152856, -0.005676},{1.149339, 1.153648, -0.004384},{
      1.146680, 1.153227, -0.004384},{1.146925, 1.152474, -0.005676}}],
    Polygon[{{1.149339, 1.153648, -0.004384},{1.149339, 1.154228, -0.002984},{
      1.146501, 1.153778, -0.002984},{1.146680, 1.153227, -0.004384}}],
    Polygon[{{1.149339, 1.154228, -0.002984},{1.149339, 1.154582, -0.001511},{
      1.146392, 1.154115, -0.001511},{1.146501, 1.153778, -0.002984}}],
    Polygon[{{1.149339, 1.154582, -0.001511},{1.149339, 1.154701, 0.000000},{
      1.146355, 1.154228, 0.000000},{1.146392, 1.154115, -0.001511}}],
    Polygon[{{1.149339, 1.154701, 0.000000},{1.149339, 1.154582, 0.001511},{
      1.146392, 1.154115, 0.001511},{1.146355, 1.154228, 0.000000}}],
    Polygon[{{1.149339, 1.154582, 0.001511},{1.149339, 1.154228, 0.002984},{
      1.146501, 1.153778, 0.002984},{1.146392, 1.154115, 0.001511}}],
    Polygon[{{1.149339, 1.154228, 0.002984},{1.149339, 1.153648, 0.004384},{
      1.146680, 1.153227, 0.004384},{1.146501, 1.153778, 0.002984}}],
    Polygon[{{1.149339, 1.153648, 0.004384},{1.149339, 1.152856, 0.005676},{
      1.146925, 1.152474, 0.005676},{1.146680, 1.153227, 0.004384}}],
    Polygon[{{1.149339, 1.152856, 0.005676},{1.149339, 1.151872, 0.006829},{
      1.147229, 1.151538, 0.006829},{1.146925, 1.152474, 0.005676}}],
    Polygon[{{1.149339, 1.151872, 0.006829},{1.149339, 1.150720, 0.007813},{
      1.147585, 1.150442, 0.007813},{1.147229, 1.151538, 0.006829}}],
    Polygon[{{1.149339, 1.150720, 0.007813},{1.149339, 1.149428, 0.008605},{
      1.147985, 1.149213, 0.008605},{1.147585, 1.150442, 0.007813}}],
    Polygon[{{1.149339, 1.149428, 0.008605},{1.149339, 1.148028, 0.009185},{
      1.148417, 1.147882, 0.009185},{1.147985, 1.149213, 0.008605}}],
    Polygon[{{1.149339, 1.148028, 0.009185},{1.149339, 1.146554, 0.009538},{
      1.148873, 1.146480, 0.009538},{1.148417, 1.147882, 0.009185}}],
    Polygon[{{1.148873, 1.146480, -0.009538},{1.148417, 1.147882, -0.009185},{
      1.147585, 1.147458, -0.009185},{1.148452, 1.146266, -0.009538}}],
    Polygon[{{1.148417, 1.147882, -0.009185},{1.147985, 1.149213, -0.008605},{
      1.146762, 1.148590, -0.008605},{1.147585, 1.147458, -0.009185}}],
    Polygon[{{1.147985, 1.149213, -0.008605},{1.147585, 1.150442, -0.007813},{
      1.146003, 1.149636, -0.007813},{1.146762, 1.148590, -0.008605}}],
    Polygon[{{1.147585, 1.150442, -0.007813},{1.147229, 1.151538, -0.006829},{
      1.145326, 1.150568, -0.006829},{1.146003, 1.149636, -0.007813}}],
    Polygon[{{1.147229, 1.151538, -0.006829},{1.146925, 1.152474, -0.005676},{
      1.144747, 1.151364, -0.005676},{1.145326, 1.150568, -0.006829}}],
    Polygon[{{1.146925, 1.152474, -0.005676},{1.146680, 1.153227, -0.004384},{
      1.144282, 1.152005, -0.004384},{1.144747, 1.151364, -0.005676}}],
    Polygon[{{1.146680, 1.153227, -0.004384},{1.146501, 1.153778, -0.002984},{
      1.143941, 1.152474, -0.002984},{1.144282, 1.152005, -0.004384}}],
    Polygon[{{1.146501, 1.153778, -0.002984},{1.146392, 1.154115, -0.001511},{
      1.143733, 1.152760, -0.001511},{1.143941, 1.152474, -0.002984}}],
    Polygon[{{1.146392, 1.154115, -0.001511},{1.146355, 1.154228, 0.000000},{
      1.143663, 1.152856, 0.000000},{1.143733, 1.152760, -0.001511}}],
    Polygon[{{1.146355, 1.154228, 0.000000},{1.146392, 1.154115, 0.001511},{
      1.143733, 1.152760, 0.001511},{1.143663, 1.152856, 0.000000}}],
    Polygon[{{1.146392, 1.154115, 0.001511},{1.146501, 1.153778, 0.002984},{
      1.143941, 1.152474, 0.002984},{1.143733, 1.152760, 0.001511}}],
    Polygon[{{1.146501, 1.153778, 0.002984},{1.146680, 1.153227, 0.004384},{
      1.144282, 1.152005, 0.004384},{1.143941, 1.152474, 0.002984}}],
    Polygon[{{1.146680, 1.153227, 0.004384},{1.146925, 1.152474, 0.005676},{
      1.144747, 1.151364, 0.005676},{1.144282, 1.152005, 0.004384}}],
    Polygon[{{1.146925, 1.152474, 0.005676},{1.147229, 1.151538, 0.006829},{
      1.145326, 1.150568, 0.006829},{1.144747, 1.151364, 0.005676}}],
    Polygon[{{1.147229, 1.151538, 0.006829},{1.147585, 1.150442, 0.007813},{
      1.146003, 1.149636, 0.007813},{1.145326, 1.150568, 0.006829}}],
    Polygon[{{1.147585, 1.150442, 0.007813},{1.147985, 1.149213, 0.008605},{
      1.146762, 1.148590, 0.008605},{1.146003, 1.149636, 0.007813}}],
    Polygon[{{1.147985, 1.149213, 0.008605},{1.148417, 1.147882, 0.009185},{
      1.147585, 1.147458, 0.009185},{1.146762, 1.148590, 0.008605}}],
    Polygon[{{1.148417, 1.147882, 0.009185},{1.148873, 1.146480, 0.009538},{
      1.148452, 1.146266, 0.009538},{1.147585, 1.147458, 0.009185}}],
    Polygon[{{1.148452, 1.146266, -0.009538},{1.147585, 1.147458, -0.009185},{
      1.146925, 1.146797, -0.009185},{1.148117, 1.145931, -0.009538}}],
    Polygon[{{1.147585, 1.147458, -0.009185},{1.146762, 1.148590, -0.008605},{
      1.145793, 1.147620, -0.008605},{1.146925, 1.146797, -0.009185}}],
    Polygon[{{1.146762, 1.148590, -0.008605},{1.146003, 1.149636, -0.007813},{
      1.144747, 1.148380, -0.007813},{1.145793, 1.147620, -0.008605}}],
    Polygon[{{1.146003, 1.149636, -0.007813},{1.145326, 1.150568, -0.006829},{
      1.143815, 1.149057, -0.006829},{1.144747, 1.148380, -0.007813}}],
    Polygon[{{1.145326, 1.150568, -0.006829},{1.144747, 1.151364, -0.005676},{
      1.143019, 1.149636, -0.005676},{1.143815, 1.149057, -0.006829}}],
    Polygon[{{1.144747, 1.151364, -0.005676},{1.144282, 1.152005, -0.004384},{
      1.142378, 1.150101, -0.004384},{1.143019, 1.149636, -0.005676}}],
    Polygon[{{1.144282, 1.152005, -0.004384},{1.143941, 1.152474, -0.002984},{
      1.141909, 1.150442, -0.002984},{1.142378, 1.150101, -0.004384}}],
    Polygon[{{1.143941, 1.152474, -0.002984},{1.143733, 1.152760, -0.001511},{
      1.141623, 1.150650, -0.001511},{1.141909, 1.150442, -0.002984}}],
    Polygon[{{1.143733, 1.152760, -0.001511},{1.143663, 1.152856, 0.000000},{
      1.141527, 1.150720, 0.000000},{1.141623, 1.150650, -0.001511}}],
    Polygon[{{1.143663, 1.152856, 0.000000},{1.143733, 1.152760, 0.001511},{
      1.141623, 1.150650, 0.001511},{1.141527, 1.150720, 0.000000}}],
    Polygon[{{1.143733, 1.152760, 0.001511},{1.143941, 1.152474, 0.002984},{
      1.141909, 1.150442, 0.002984},{1.141623, 1.150650, 0.001511}}],
    Polygon[{{1.143941, 1.152474, 0.002984},{1.144282, 1.152005, 0.004384},{
      1.142378, 1.150101, 0.004384},{1.141909, 1.150442, 0.002984}}],
    Polygon[{{1.144282, 1.152005, 0.004384},{1.144747, 1.151364, 0.005676},{
      1.143019, 1.149636, 0.005676},{1.142378, 1.150101, 0.004384}}],
    Polygon[{{1.144747, 1.151364, 0.005676},{1.145326, 1.150568, 0.006829},{
      1.143815, 1.149057, 0.006829},{1.143019, 1.149636, 0.005676}}],
    Polygon[{{1.145326, 1.150568, 0.006829},{1.146003, 1.149636, 0.007813},{
      1.144747, 1.148380, 0.007813},{1.143815, 1.149057, 0.006829}}],
    Polygon[{{1.146003, 1.149636, 0.007813},{1.146762, 1.148590, 0.008605},{
      1.145793, 1.147620, 0.008605},{1.144747, 1.148380, 0.007813}}],
    Polygon[{{1.146762, 1.148590, 0.008605},{1.147585, 1.147458, 0.009185},{
      1.146925, 1.146797, 0.009185},{1.145793, 1.147620, 0.008605}}],
    Polygon[{{1.147585, 1.147458, 0.009185},{1.148452, 1.146266, 0.009538},{
      1.148117, 1.145931, 0.009538},{1.146925, 1.146797, 0.009185}}],
    Polygon[{{1.148117, 1.145931, -0.009538},{1.146925, 1.146797, -0.009185},{
      1.146501, 1.145966, -0.009185},{1.147903, 1.145510, -0.009538}}],
    Polygon[{{1.146925, 1.146797, -0.009185},{1.145793, 1.147620, -0.008605},{
      1.145170, 1.146398, -0.008605},{1.146501, 1.145966, -0.009185}}],
    Polygon[{{1.145793, 1.147620, -0.008605},{1.144747, 1.148380, -0.007813},{
      1.143941, 1.146797, -0.007813},{1.145170, 1.146398, -0.008605}}],
    Polygon[{{1.144747, 1.148380, -0.007813},{1.143815, 1.149057, -0.006829},{
      1.142845, 1.147153, -0.006829},{1.143941, 1.146797, -0.007813}}],
    Polygon[{{1.143815, 1.149057, -0.006829},{1.143019, 1.149636, -0.005676},{
      1.141909, 1.147458, -0.005676},{1.142845, 1.147153, -0.006829}}],
    Polygon[{{1.143019, 1.149636, -0.005676},{1.142378, 1.150101, -0.004384},{
      1.141156, 1.147702, -0.004384},{1.141909, 1.147458, -0.005676}}],
    Polygon[{{1.142378, 1.150101, -0.004384},{1.141909, 1.150442, -0.002984},{
      1.140604, 1.147882, -0.002984},{1.141156, 1.147702, -0.004384}}],
    Polygon[{{1.141909, 1.150442, -0.002984},{1.141623, 1.150650, -0.001511},{
      1.140268, 1.147991, -0.001511},{1.140604, 1.147882, -0.002984}}],
    Polygon[{{1.141623, 1.150650, -0.001511},{1.141527, 1.150720, 0.000000},{
      1.140155, 1.148028, 0.000000},{1.140268, 1.147991, -0.001511}}],
    Polygon[{{1.141527, 1.150720, 0.000000},{1.141623, 1.150650, 0.001511},{
      1.140268, 1.147991, 0.001511},{1.140155, 1.148028, 0.000000}}],
    Polygon[{{1.141623, 1.150650, 0.001511},{1.141909, 1.150442, 0.002984},{
      1.140604, 1.147882, 0.002984},{1.140268, 1.147991, 0.001511}}],
    Polygon[{{1.141909, 1.150442, 0.002984},{1.142378, 1.150101, 0.004384},{
      1.141156, 1.147702, 0.004384},{1.140604, 1.147882, 0.002984}}],
    Polygon[{{1.142378, 1.150101, 0.004384},{1.143019, 1.149636, 0.005676},{
      1.141909, 1.147458, 0.005676},{1.141156, 1.147702, 0.004384}}],
    Polygon[{{1.143019, 1.149636, 0.005676},{1.143815, 1.149057, 0.006829},{
      1.142845, 1.147153, 0.006829},{1.141909, 1.147458, 0.005676}}],
    Polygon[{{1.143815, 1.149057, 0.006829},{1.144747, 1.148380, 0.007813},{
      1.143941, 1.146797, 0.007813},{1.142845, 1.147153, 0.006829}}],
    Polygon[{{1.144747, 1.148380, 0.007813},{1.145793, 1.147620, 0.008605},{
      1.145170, 1.146398, 0.008605},{1.143941, 1.146797, 0.007813}}],
    Polygon[{{1.145793, 1.147620, 0.008605},{1.146925, 1.146797, 0.009185},{
      1.146501, 1.145966, 0.009185},{1.145170, 1.146398, 0.008605}}],
    Polygon[{{1.146925, 1.146797, 0.009185},{1.148117, 1.145931, 0.009538},{
      1.147903, 1.145510, 0.009538},{1.146501, 1.145966, 0.009185}}],
    Polygon[{{1.147903, 1.145510, -0.009538},{1.146501, 1.145966, -0.009185},{
      1.146355, 1.145043, -0.009185},{1.147829, 1.145043, -0.009538}}],
    Polygon[{{1.146501, 1.145966, -0.009185},{1.145170, 1.146398, -0.008605},{
      1.144955, 1.145043, -0.008605},{1.146355, 1.145043, -0.009185}}],
    Polygon[{{1.145170, 1.146398, -0.008605},{1.143941, 1.146797, -0.007813},{
      1.143663, 1.145043, -0.007813},{1.144955, 1.145043, -0.008605}}],
    Polygon[{{1.143941, 1.146797, -0.007813},{1.142845, 1.147153, -0.006829},{
      1.142511, 1.145043, -0.006829},{1.143663, 1.145043, -0.007813}}],
    Polygon[{{1.142845, 1.147153, -0.006829},{1.141909, 1.147458, -0.005676},{
      1.141527, 1.145043, -0.005676},{1.142511, 1.145043, -0.006829}}],
    Polygon[{{1.141909, 1.147458, -0.005676},{1.141156, 1.147702, -0.004384},{
      1.140735, 1.145043, -0.004384},{1.141527, 1.145043, -0.005676}}],
    Polygon[{{1.141156, 1.147702, -0.004384},{1.140604, 1.147882, -0.002984},{
      1.140155, 1.145043, -0.002984},{1.140735, 1.145043, -0.004384}}],
    Polygon[{{1.140604, 1.147882, -0.002984},{1.140268, 1.147991, -0.001511},{
      1.139801, 1.145043, -0.001511},{1.140155, 1.145043, -0.002984}}],
    Polygon[{{1.140268, 1.147991, -0.001511},{1.140155, 1.148028, 0.000000},{
      1.139682, 1.145043, 0.000000},{1.139801, 1.145043, -0.001511}}],
    Polygon[{{1.140155, 1.148028, 0.000000},{1.140268, 1.147991, 0.001511},{
      1.139801, 1.145043, 0.001511},{1.139682, 1.145043, 0.000000}}],
    Polygon[{{1.140268, 1.147991, 0.001511},{1.140604, 1.147882, 0.002984},{
      1.140155, 1.145043, 0.002984},{1.139801, 1.145043, 0.001511}}],
    Polygon[{{1.140604, 1.147882, 0.002984},{1.141156, 1.147702, 0.004384},{
      1.140735, 1.145043, 0.004384},{1.140155, 1.145043, 0.002984}}],
    Polygon[{{1.141156, 1.147702, 0.004384},{1.141909, 1.147458, 0.005676},{
      1.141527, 1.145043, 0.005676},{1.140735, 1.145043, 0.004384}}],
    Polygon[{{1.141909, 1.147458, 0.005676},{1.142845, 1.147153, 0.006829},{
      1.142511, 1.145043, 0.006829},{1.141527, 1.145043, 0.005676}}],
    Polygon[{{1.142845, 1.147153, 0.006829},{1.143941, 1.146797, 0.007813},{
      1.143663, 1.145043, 0.007813},{1.142511, 1.145043, 0.006829}}],
    Polygon[{{1.143941, 1.146797, 0.007813},{1.145170, 1.146398, 0.008605},{
      1.144955, 1.145043, 0.008605},{1.143663, 1.145043, 0.007813}}],
    Polygon[{{1.145170, 1.146398, 0.008605},{1.146501, 1.145966, 0.009185},{
      1.146355, 1.145043, 0.009185},{1.144955, 1.145043, 0.008605}}],
    Polygon[{{1.146501, 1.145966, 0.009185},{1.147903, 1.145510, 0.009538},{
      1.147829, 1.145043, 0.009538},{1.146355, 1.145043, 0.009185}}],
    Polygon[{{1.147829, 1.145043, -0.009538},{1.146355, 1.145043, -0.009185},{
      1.146501, 1.144121, -0.009185},{1.147903, 1.144577, -0.009538}}],
    Polygon[{{1.146355, 1.145043, -0.009185},{1.144955, 1.145043, -0.008605},{
      1.145170, 1.143689, -0.008605},{1.146501, 1.144121, -0.009185}}],
    Polygon[{{1.144955, 1.145043, -0.008605},{1.143663, 1.145043, -0.007813},{
      1.143941, 1.143289, -0.007813},{1.145170, 1.143689, -0.008605}}],
    Polygon[{{1.143663, 1.145043, -0.007813},{1.142511, 1.145043, -0.006829},{
      1.142845, 1.142933, -0.006829},{1.143941, 1.143289, -0.007813}}],
    Polygon[{{1.142511, 1.145043, -0.006829},{1.141527, 1.145043, -0.005676},{
      1.141909, 1.142629, -0.005676},{1.142845, 1.142933, -0.006829}}],
    Polygon[{{1.141527, 1.145043, -0.005676},{1.140735, 1.145043, -0.004384},{
      1.141156, 1.142384, -0.004384},{1.141909, 1.142629, -0.005676}}],
    Polygon[{{1.140735, 1.145043, -0.004384},{1.140155, 1.145043, -0.002984},{
      1.140604, 1.142205, -0.002984},{1.141156, 1.142384, -0.004384}}],
    Polygon[{{1.140155, 1.145043, -0.002984},{1.139801, 1.145043, -0.001511},{
      1.140268, 1.142096, -0.001511},{1.140604, 1.142205, -0.002984}}],
    Polygon[{{1.139801, 1.145043, -0.001511},{1.139682, 1.145043, 0.000000},{
      1.140155, 1.142059, 0.000000},{1.140268, 1.142096, -0.001511}}],
    Polygon[{{1.139682, 1.145043, 0.000000},{1.139801, 1.145043, 0.001511},{
      1.140268, 1.142096, 0.001511},{1.140155, 1.142059, 0.000000}}],
    Polygon[{{1.139801, 1.145043, 0.001511},{1.140155, 1.145043, 0.002984},{
      1.140604, 1.142205, 0.002984},{1.140268, 1.142096, 0.001511}}],
    Polygon[{{1.140155, 1.145043, 0.002984},{1.140735, 1.145043, 0.004384},{
      1.141156, 1.142384, 0.004384},{1.140604, 1.142205, 0.002984}}],
    Polygon[{{1.140735, 1.145043, 0.004384},{1.141527, 1.145043, 0.005676},{
      1.141909, 1.142629, 0.005676},{1.141156, 1.142384, 0.004384}}],
    Polygon[{{1.141527, 1.145043, 0.005676},{1.142511, 1.145043, 0.006829},{
      1.142845, 1.142933, 0.006829},{1.141909, 1.142629, 0.005676}}],
    Polygon[{{1.142511, 1.145043, 0.006829},{1.143663, 1.145043, 0.007813},{
      1.143941, 1.143289, 0.007813},{1.142845, 1.142933, 0.006829}}],
    Polygon[{{1.143663, 1.145043, 0.007813},{1.144955, 1.145043, 0.008605},{
      1.145170, 1.143689, 0.008605},{1.143941, 1.143289, 0.007813}}],
    Polygon[{{1.144955, 1.145043, 0.008605},{1.146355, 1.145043, 0.009185},{
      1.146501, 1.144121, 0.009185},{1.145170, 1.143689, 0.008605}}],
    Polygon[{{1.146355, 1.145043, 0.009185},{1.147829, 1.145043, 0.009538},{
      1.147903, 1.144577, 0.009538},{1.146501, 1.144121, 0.009185}}],
    Polygon[{{1.147903, 1.144577, -0.009538},{1.146501, 1.144121, -0.009185},{
      1.146925, 1.143289, -0.009185},{1.148117, 1.144155, -0.009538}}],
    Polygon[{{1.146501, 1.144121, -0.009185},{1.145170, 1.143689, -0.008605},{
      1.145793, 1.142466, -0.008605},{1.146925, 1.143289, -0.009185}}],
    Polygon[{{1.145170, 1.143689, -0.008605},{1.143941, 1.143289, -0.007813},{
      1.144747, 1.141707, -0.007813},{1.145793, 1.142466, -0.008605}}],
    Polygon[{{1.143941, 1.143289, -0.007813},{1.142845, 1.142933, -0.006829},{
      1.143815, 1.141030, -0.006829},{1.144747, 1.141707, -0.007813}}],
    Polygon[{{1.142845, 1.142933, -0.006829},{1.141909, 1.142629, -0.005676},{
      1.143019, 1.140451, -0.005676},{1.143815, 1.141030, -0.006829}}],
    Polygon[{{1.141909, 1.142629, -0.005676},{1.141156, 1.142384, -0.004384},{
      1.142378, 1.139986, -0.004384},{1.143019, 1.140451, -0.005676}}],
    Polygon[{{1.141156, 1.142384, -0.004384},{1.140604, 1.142205, -0.002984},{
      1.141909, 1.139645, -0.002984},{1.142378, 1.139986, -0.004384}}],
    Polygon[{{1.140604, 1.142205, -0.002984},{1.140268, 1.142096, -0.001511},{
      1.141623, 1.139437, -0.001511},{1.141909, 1.139645, -0.002984}}],
    Polygon[{{1.140268, 1.142096, -0.001511},{1.140155, 1.142059, 0.000000},{
      1.141527, 1.139367, 0.000000},{1.141623, 1.139437, -0.001511}}],
    Polygon[{{1.140155, 1.142059, 0.000000},{1.140268, 1.142096, 0.001511},{
      1.141623, 1.139437, 0.001511},{1.141527, 1.139367, 0.000000}}],
    Polygon[{{1.140268, 1.142096, 0.001511},{1.140604, 1.142205, 0.002984},{
      1.141909, 1.139645, 0.002984},{1.141623, 1.139437, 0.001511}}],
    Polygon[{{1.140604, 1.142205, 0.002984},{1.141156, 1.142384, 0.004384},{
      1.142378, 1.139986, 0.004384},{1.141909, 1.139645, 0.002984}}],
    Polygon[{{1.141156, 1.142384, 0.004384},{1.141909, 1.142629, 0.005676},{
      1.143019, 1.140451, 0.005676},{1.142378, 1.139986, 0.004384}}],
    Polygon[{{1.141909, 1.142629, 0.005676},{1.142845, 1.142933, 0.006829},{
      1.143815, 1.141030, 0.006829},{1.143019, 1.140451, 0.005676}}],
    Polygon[{{1.142845, 1.142933, 0.006829},{1.143941, 1.143289, 0.007813},{
      1.144747, 1.141707, 0.007813},{1.143815, 1.141030, 0.006829}}],
    Polygon[{{1.143941, 1.143289, 0.007813},{1.145170, 1.143689, 0.008605},{
      1.145793, 1.142466, 0.008605},{1.144747, 1.141707, 0.007813}}],
    Polygon[{{1.145170, 1.143689, 0.008605},{1.146501, 1.144121, 0.009185},{
      1.146925, 1.143289, 0.009185},{1.145793, 1.142466, 0.008605}}],
    Polygon[{{1.146501, 1.144121, 0.009185},{1.147903, 1.144577, 0.009538},{
      1.148117, 1.144155, 0.009538},{1.146925, 1.143289, 0.009185}}],
    Polygon[{{1.148117, 1.144155, -0.009538},{1.146925, 1.143289, -0.009185},{
      1.147585, 1.142629, -0.009185},{1.148452, 1.143821, -0.009538}}],
    Polygon[{{1.146925, 1.143289, -0.009185},{1.145793, 1.142466, -0.008605},{
      1.146762, 1.141496, -0.008605},{1.147585, 1.142629, -0.009185}}],
    Polygon[{{1.145793, 1.142466, -0.008605},{1.144747, 1.141707, -0.007813},{
      1.146003, 1.140451, -0.007813},{1.146762, 1.141496, -0.008605}}],
    Polygon[{{1.144747, 1.141707, -0.007813},{1.143815, 1.141030, -0.006829},{
      1.145326, 1.139519, -0.006829},{1.146003, 1.140451, -0.007813}}],
    Polygon[{{1.143815, 1.141030, -0.006829},{1.143019, 1.140451, -0.005676},{
      1.144747, 1.138723, -0.005676},{1.145326, 1.139519, -0.006829}}],
    Polygon[{{1.143019, 1.140451, -0.005676},{1.142378, 1.139986, -0.004384},{
      1.144282, 1.138082, -0.004384},{1.144747, 1.138723, -0.005676}}],
    Polygon[{{1.142378, 1.139986, -0.004384},{1.141909, 1.139645, -0.002984},{
      1.143941, 1.137613, -0.002984},{1.144282, 1.138082, -0.004384}}],
    Polygon[{{1.141909, 1.139645, -0.002984},{1.141623, 1.139437, -0.001511},{
      1.143733, 1.137327, -0.001511},{1.143941, 1.137613, -0.002984}}],
    Polygon[{{1.141623, 1.139437, -0.001511},{1.141527, 1.139367, 0.000000},{
      1.143663, 1.137231, 0.000000},{1.143733, 1.137327, -0.001511}}],
    Polygon[{{1.141527, 1.139367, 0.000000},{1.141623, 1.139437, 0.001511},{
      1.143733, 1.137327, 0.001511},{1.143663, 1.137231, 0.000000}}],
    Polygon[{{1.141623, 1.139437, 0.001511},{1.141909, 1.139645, 0.002984},{
      1.143941, 1.137613, 0.002984},{1.143733, 1.137327, 0.001511}}],
    Polygon[{{1.141909, 1.139645, 0.002984},{1.142378, 1.139986, 0.004384},{
      1.144282, 1.138082, 0.004384},{1.143941, 1.137613, 0.002984}}],
    Polygon[{{1.142378, 1.139986, 0.004384},{1.143019, 1.140451, 0.005676},{
      1.144747, 1.138723, 0.005676},{1.144282, 1.138082, 0.004384}}],
    Polygon[{{1.143019, 1.140451, 0.005676},{1.143815, 1.141030, 0.006829},{
      1.145326, 1.139519, 0.006829},{1.144747, 1.138723, 0.005676}}],
    Polygon[{{1.143815, 1.141030, 0.006829},{1.144747, 1.141707, 0.007813},{
      1.146003, 1.140451, 0.007813},{1.145326, 1.139519, 0.006829}}],
    Polygon[{{1.144747, 1.141707, 0.007813},{1.145793, 1.142466, 0.008605},{
      1.146762, 1.141496, 0.008605},{1.146003, 1.140451, 0.007813}}],
    Polygon[{{1.145793, 1.142466, 0.008605},{1.146925, 1.143289, 0.009185},{
      1.147585, 1.142629, 0.009185},{1.146762, 1.141496, 0.008605}}],
    Polygon[{{1.146925, 1.143289, 0.009185},{1.148117, 1.144155, 0.009538},{
      1.148452, 1.143821, 0.009538},{1.147585, 1.142629, 0.009185}}],
    Polygon[{{1.148452, 1.143821, -0.009538},{1.147585, 1.142629, -0.009185},{
      1.148417, 1.142205, -0.009185},{1.148873, 1.143607, -0.009538}}],
    Polygon[{{1.147585, 1.142629, -0.009185},{1.146762, 1.141496, -0.008605},{
      1.147985, 1.140874, -0.008605},{1.148417, 1.142205, -0.009185}}],
    Polygon[{{1.146762, 1.141496, -0.008605},{1.146003, 1.140451, -0.007813},{
      1.147585, 1.139645, -0.007813},{1.147985, 1.140874, -0.008605}}],
    Polygon[{{1.146003, 1.140451, -0.007813},{1.145326, 1.139519, -0.006829},{
      1.147229, 1.138549, -0.006829},{1.147585, 1.139645, -0.007813}}],
    Polygon[{{1.145326, 1.139519, -0.006829},{1.144747, 1.138723, -0.005676},{
      1.146925, 1.137613, -0.005676},{1.147229, 1.138549, -0.006829}}],
    Polygon[{{1.144747, 1.138723, -0.005676},{1.144282, 1.138082, -0.004384},{
      1.146680, 1.136860, -0.004384},{1.146925, 1.137613, -0.005676}}],
    Polygon[{{1.144282, 1.138082, -0.004384},{1.143941, 1.137613, -0.002984},{
      1.146501, 1.136308, -0.002984},{1.146680, 1.136860, -0.004384}}],
    Polygon[{{1.143941, 1.137613, -0.002984},{1.143733, 1.137327, -0.001511},{
      1.146392, 1.135972, -0.001511},{1.146501, 1.136308, -0.002984}}],
    Polygon[{{1.143733, 1.137327, -0.001511},{1.143663, 1.137231, 0.000000},{
      1.146355, 1.135859, 0.000000},{1.146392, 1.135972, -0.001511}}],
    Polygon[{{1.143663, 1.137231, 0.000000},{1.143733, 1.137327, 0.001511},{
      1.146392, 1.135972, 0.001511},{1.146355, 1.135859, 0.000000}}],
    Polygon[{{1.143733, 1.137327, 0.001511},{1.143941, 1.137613, 0.002984},{
      1.146501, 1.136308, 0.002984},{1.146392, 1.135972, 0.001511}}],
    Polygon[{{1.143941, 1.137613, 0.002984},{1.144282, 1.138082, 0.004384},{
      1.146680, 1.136860, 0.004384},{1.146501, 1.136308, 0.002984}}],
    Polygon[{{1.144282, 1.138082, 0.004384},{1.144747, 1.138723, 0.005676},{
      1.146925, 1.137613, 0.005676},{1.146680, 1.136860, 0.004384}}],
    Polygon[{{1.144747, 1.138723, 0.005676},{1.145326, 1.139519, 0.006829},{
      1.147229, 1.138549, 0.006829},{1.146925, 1.137613, 0.005676}}],
    Polygon[{{1.145326, 1.139519, 0.006829},{1.146003, 1.140451, 0.007813},{
      1.147585, 1.139645, 0.007813},{1.147229, 1.138549, 0.006829}}],
    Polygon[{{1.146003, 1.140451, 0.007813},{1.146762, 1.141496, 0.008605},{
      1.147985, 1.140874, 0.008605},{1.147585, 1.139645, 0.007813}}],
    Polygon[{{1.146762, 1.141496, 0.008605},{1.147585, 1.142629, 0.009185},{
      1.148417, 1.142205, 0.009185},{1.147985, 1.140874, 0.008605}}],
    Polygon[{{1.147585, 1.142629, 0.009185},{1.148452, 1.143821, 0.009538},{
      1.148873, 1.143607, 0.009538},{1.148417, 1.142205, 0.009185}}],
    Polygon[{{1.148873, 1.143607, -0.009538},{1.148417, 1.142205, -0.009185},{
      1.149339, 1.142059, -0.009185},{1.149339, 1.143533, -0.009538}}],
    Polygon[{{1.148417, 1.142205, -0.009185},{1.147985, 1.140874, -0.008605},{
      1.149339, 1.140659, -0.008605},{1.149339, 1.142059, -0.009185}}],
    Polygon[{{1.147985, 1.140874, -0.008605},{1.147585, 1.139645, -0.007813},{
      1.149339, 1.139367, -0.007813},{1.149339, 1.140659, -0.008605}}],
    Polygon[{{1.147585, 1.139645, -0.007813},{1.147229, 1.138549, -0.006829},{
      1.149339, 1.138215, -0.006829},{1.149339, 1.139367, -0.007813}}],
    Polygon[{{1.147229, 1.138549, -0.006829},{1.146925, 1.137613, -0.005676},{
      1.149339, 1.137231, -0.005676},{1.149339, 1.138215, -0.006829}}],
    Polygon[{{1.146925, 1.137613, -0.005676},{1.146680, 1.136860, -0.004384},{
      1.149339, 1.136439, -0.004384},{1.149339, 1.137231, -0.005676}}],
    Polygon[{{1.146680, 1.136860, -0.004384},{1.146501, 1.136308, -0.002984},{
      1.149339, 1.135859, -0.002984},{1.149339, 1.136439, -0.004384}}],
    Polygon[{{1.146501, 1.136308, -0.002984},{1.146392, 1.135972, -0.001511},{
      1.149339, 1.135505, -0.001511},{1.149339, 1.135859, -0.002984}}],
    Polygon[{{1.146392, 1.135972, -0.001511},{1.146355, 1.135859, 0.000000},{
      1.149339, 1.135386, 0.000000},{1.149339, 1.135505, -0.001511}}],
    Polygon[{{1.146355, 1.135859, 0.000000},{1.146392, 1.135972, 0.001511},{
      1.149339, 1.135505, 0.001511},{1.149339, 1.135386, 0.000000}}],
    Polygon[{{1.146392, 1.135972, 0.001511},{1.146501, 1.136308, 0.002984},{
      1.149339, 1.135859, 0.002984},{1.149339, 1.135505, 0.001511}}],
    Polygon[{{1.146501, 1.136308, 0.002984},{1.146680, 1.136860, 0.004384},{
      1.149339, 1.136439, 0.004384},{1.149339, 1.135859, 0.002984}}],
    Polygon[{{1.146680, 1.136860, 0.004384},{1.146925, 1.137613, 0.005676},{
      1.149339, 1.137231, 0.005676},{1.149339, 1.136439, 0.004384}}],
    Polygon[{{1.146925, 1.137613, 0.005676},{1.147229, 1.138549, 0.006829},{
      1.149339, 1.138215, 0.006829},{1.149339, 1.137231, 0.005676}}],
    Polygon[{{1.147229, 1.138549, 0.006829},{1.147585, 1.139645, 0.007813},{
      1.149339, 1.139367, 0.007813},{1.149339, 1.138215, 0.006829}}],
    Polygon[{{1.147585, 1.139645, 0.007813},{1.147985, 1.140874, 0.008605},{
      1.149339, 1.140659, 0.008605},{1.149339, 1.139367, 0.007813}}],
    Polygon[{{1.147985, 1.140874, 0.008605},{1.148417, 1.142205, 0.009185},{
      1.149339, 1.142059, 0.009185},{1.149339, 1.140659, 0.008605}}],
    Polygon[{{1.148417, 1.142205, 0.009185},{1.148873, 1.143607, 0.009538},{
      1.149339, 1.143533, 0.009538},{1.149339, 1.142059, 0.009185}}],
    Polygon[{{1.149339, 1.143533, -0.009538},{1.149339, 1.142059, -0.009185},{
      1.150262, 1.142205, -0.009185},{1.149806, 1.143607, -0.009538}}],
    Polygon[{{1.149339, 1.142059, -0.009185},{1.149339, 1.140659, -0.008605},{
      1.150694, 1.140874, -0.008605},{1.150262, 1.142205, -0.009185}}],
    Polygon[{{1.149339, 1.140659, -0.008605},{1.149339, 1.139367, -0.007813},{
      1.151094, 1.139645, -0.007813},{1.150694, 1.140874, -0.008605}}],
    Polygon[{{1.149339, 1.139367, -0.007813},{1.149339, 1.138215, -0.006829},{
      1.151450, 1.138549, -0.006829},{1.151094, 1.139645, -0.007813}}],
    Polygon[{{1.149339, 1.138215, -0.006829},{1.149339, 1.137231, -0.005676},{
      1.151754, 1.137613, -0.005676},{1.151450, 1.138549, -0.006829}}],
    Polygon[{{1.149339, 1.137231, -0.005676},{1.149339, 1.136439, -0.004384},{
      1.151999, 1.136860, -0.004384},{1.151754, 1.137613, -0.005676}}],
    Polygon[{{1.149339, 1.136439, -0.004384},{1.149339, 1.135859, -0.002984},{
      1.152178, 1.136308, -0.002984},{1.151999, 1.136860, -0.004384}}],
    Polygon[{{1.149339, 1.135859, -0.002984},{1.149339, 1.135505, -0.001511},{
      1.152287, 1.135972, -0.001511},{1.152178, 1.136308, -0.002984}}],
    Polygon[{{1.149339, 1.135505, -0.001511},{1.149339, 1.135386, 0.000000},{
      1.152324, 1.135859, 0.000000},{1.152287, 1.135972, -0.001511}}],
    Polygon[{{1.149339, 1.135386, 0.000000},{1.149339, 1.135505, 0.001511},{
      1.152287, 1.135972, 0.001511},{1.152324, 1.135859, 0.000000}}],
    Polygon[{{1.149339, 1.135505, 0.001511},{1.149339, 1.135859, 0.002984},{
      1.152178, 1.136308, 0.002984},{1.152287, 1.135972, 0.001511}}],
    Polygon[{{1.149339, 1.135859, 0.002984},{1.149339, 1.136439, 0.004384},{
      1.151999, 1.136860, 0.004384},{1.152178, 1.136308, 0.002984}}],
    Polygon[{{1.149339, 1.136439, 0.004384},{1.149339, 1.137231, 0.005676},{
      1.151754, 1.137613, 0.005676},{1.151999, 1.136860, 0.004384}}],
    Polygon[{{1.149339, 1.137231, 0.005676},{1.149339, 1.138215, 0.006829},{
      1.151450, 1.138549, 0.006829},{1.151754, 1.137613, 0.005676}}],
    Polygon[{{1.149339, 1.138215, 0.006829},{1.149339, 1.139367, 0.007813},{
      1.151094, 1.139645, 0.007813},{1.151450, 1.138549, 0.006829}}],
    Polygon[{{1.149339, 1.139367, 0.007813},{1.149339, 1.140659, 0.008605},{
      1.150694, 1.140874, 0.008605},{1.151094, 1.139645, 0.007813}}],
    Polygon[{{1.149339, 1.140659, 0.008605},{1.149339, 1.142059, 0.009185},{
      1.150262, 1.142205, 0.009185},{1.150694, 1.140874, 0.008605}}],
    Polygon[{{1.149339, 1.142059, 0.009185},{1.149339, 1.143533, 0.009538},{
      1.149806, 1.143607, 0.009538},{1.150262, 1.142205, 0.009185}}],
    Polygon[{{1.149806, 1.143607, -0.009538},{1.150262, 1.142205, -0.009185},{
      1.151094, 1.142629, -0.009185},{1.150227, 1.143821, -0.009538}}],
    Polygon[{{1.150262, 1.142205, -0.009185},{1.150694, 1.140874, -0.008605},{
      1.151917, 1.141496, -0.008605},{1.151094, 1.142629, -0.009185}}],
    Polygon[{{1.150694, 1.140874, -0.008605},{1.151094, 1.139645, -0.007813},{
      1.152676, 1.140451, -0.007813},{1.151917, 1.141496, -0.008605}}],
    Polygon[{{1.151094, 1.139645, -0.007813},{1.151450, 1.138549, -0.006829},{
      1.153353, 1.139519, -0.006829},{1.152676, 1.140451, -0.007813}}],
    Polygon[{{1.151450, 1.138549, -0.006829},{1.151754, 1.137613, -0.005676},{
      1.153932, 1.138723, -0.005676},{1.153353, 1.139519, -0.006829}}],
    Polygon[{{1.151754, 1.137613, -0.005676},{1.151999, 1.136860, -0.004384},{
      1.154397, 1.138082, -0.004384},{1.153932, 1.138723, -0.005676}}],
    Polygon[{{1.151999, 1.136860, -0.004384},{1.152178, 1.136308, -0.002984},{
      1.154738, 1.137613, -0.002984},{1.154397, 1.138082, -0.004384}}],
    Polygon[{{1.152178, 1.136308, -0.002984},{1.152287, 1.135972, -0.001511},{
      1.154946, 1.137327, -0.001511},{1.154738, 1.137613, -0.002984}}],
    Polygon[{{1.152287, 1.135972, -0.001511},{1.152324, 1.135859, 0.000000},{
      1.155016, 1.137231, 0.000000},{1.154946, 1.137327, -0.001511}}],
    Polygon[{{1.152324, 1.135859, 0.000000},{1.152287, 1.135972, 0.001511},{
      1.154946, 1.137327, 0.001511},{1.155016, 1.137231, 0.000000}}],
    Polygon[{{1.152287, 1.135972, 0.001511},{1.152178, 1.136308, 0.002984},{
      1.154738, 1.137613, 0.002984},{1.154946, 1.137327, 0.001511}}],
    Polygon[{{1.152178, 1.136308, 0.002984},{1.151999, 1.136860, 0.004384},{
      1.154397, 1.138082, 0.004384},{1.154738, 1.137613, 0.002984}}],
    Polygon[{{1.151999, 1.136860, 0.004384},{1.151754, 1.137613, 0.005676},{
      1.153932, 1.138723, 0.005676},{1.154397, 1.138082, 0.004384}}],
    Polygon[{{1.151754, 1.137613, 0.005676},{1.151450, 1.138549, 0.006829},{
      1.153353, 1.139519, 0.006829},{1.153932, 1.138723, 0.005676}}],
    Polygon[{{1.151450, 1.138549, 0.006829},{1.151094, 1.139645, 0.007813},{
      1.152676, 1.140451, 0.007813},{1.153353, 1.139519, 0.006829}}],
    Polygon[{{1.151094, 1.139645, 0.007813},{1.150694, 1.140874, 0.008605},{
      1.151917, 1.141496, 0.008605},{1.152676, 1.140451, 0.007813}}],
    Polygon[{{1.150694, 1.140874, 0.008605},{1.150262, 1.142205, 0.009185},{
      1.151094, 1.142629, 0.009185},{1.151917, 1.141496, 0.008605}}],
    Polygon[{{1.150262, 1.142205, 0.009185},{1.149806, 1.143607, 0.009538},{
      1.150227, 1.143821, 0.009538},{1.151094, 1.142629, 0.009185}}],
    Polygon[{{1.150227, 1.143821, -0.009538},{1.151094, 1.142629, -0.009185},{
      1.151754, 1.143289, -0.009185},{1.150562, 1.144155, -0.009538}}],
    Polygon[{{1.151094, 1.142629, -0.009185},{1.151917, 1.141496, -0.008605},{
      1.152886, 1.142466, -0.008605},{1.151754, 1.143289, -0.009185}}],
    Polygon[{{1.151917, 1.141496, -0.008605},{1.152676, 1.140451, -0.007813},{
      1.153932, 1.141707, -0.007813},{1.152886, 1.142466, -0.008605}}],
    Polygon[{{1.152676, 1.140451, -0.007813},{1.153353, 1.139519, -0.006829},{
      1.154864, 1.141030, -0.006829},{1.153932, 1.141707, -0.007813}}],
    Polygon[{{1.153353, 1.139519, -0.006829},{1.153932, 1.138723, -0.005676},{
      1.155660, 1.140451, -0.005676},{1.154864, 1.141030, -0.006829}}],
    Polygon[{{1.153932, 1.138723, -0.005676},{1.154397, 1.138082, -0.004384},{
      1.156301, 1.139986, -0.004384},{1.155660, 1.140451, -0.005676}}],
    Polygon[{{1.154397, 1.138082, -0.004384},{1.154738, 1.137613, -0.002984},{
      1.156770, 1.139645, -0.002984},{1.156301, 1.139986, -0.004384}}],
    Polygon[{{1.154738, 1.137613, -0.002984},{1.154946, 1.137327, -0.001511},{
      1.157056, 1.139437, -0.001511},{1.156770, 1.139645, -0.002984}}],
    Polygon[{{1.154946, 1.137327, -0.001511},{1.155016, 1.137231, 0.000000},{
      1.157152, 1.139367, 0.000000},{1.157056, 1.139437, -0.001511}}],
    Polygon[{{1.155016, 1.137231, 0.000000},{1.154946, 1.137327, 0.001511},{
      1.157056, 1.139437, 0.001511},{1.157152, 1.139367, 0.000000}}],
    Polygon[{{1.154946, 1.137327, 0.001511},{1.154738, 1.137613, 0.002984},{
      1.156770, 1.139645, 0.002984},{1.157056, 1.139437, 0.001511}}],
    Polygon[{{1.154738, 1.137613, 0.002984},{1.154397, 1.138082, 0.004384},{
      1.156301, 1.139986, 0.004384},{1.156770, 1.139645, 0.002984}}],
    Polygon[{{1.154397, 1.138082, 0.004384},{1.153932, 1.138723, 0.005676},{
      1.155660, 1.140451, 0.005676},{1.156301, 1.139986, 0.004384}}],
    Polygon[{{1.153932, 1.138723, 0.005676},{1.153353, 1.139519, 0.006829},{
      1.154864, 1.141030, 0.006829},{1.155660, 1.140451, 0.005676}}],
    Polygon[{{1.153353, 1.139519, 0.006829},{1.152676, 1.140451, 0.007813},{
      1.153932, 1.141707, 0.007813},{1.154864, 1.141030, 0.006829}}],
    Polygon[{{1.152676, 1.140451, 0.007813},{1.151917, 1.141496, 0.008605},{
      1.152886, 1.142466, 0.008605},{1.153932, 1.141707, 0.007813}}],
    Polygon[{{1.151917, 1.141496, 0.008605},{1.151094, 1.142629, 0.009185},{
      1.151754, 1.143289, 0.009185},{1.152886, 1.142466, 0.008605}}],
    Polygon[{{1.151094, 1.142629, 0.009185},{1.150227, 1.143821, 0.009538},{
      1.150562, 1.144155, 0.009538},{1.151754, 1.143289, 0.009185}}],
    Polygon[{{1.150562, 1.144155, -0.009538},{1.151754, 1.143289, -0.009185},{
      1.152178, 1.144121, -0.009185},{1.150776, 1.144577, -0.009538}}],
    Polygon[{{1.151754, 1.143289, -0.009185},{1.152886, 1.142466, -0.008605},{
      1.153509, 1.143689, -0.008605},{1.152178, 1.144121, -0.009185}}],
    Polygon[{{1.152886, 1.142466, -0.008605},{1.153932, 1.141707, -0.007813},{
      1.154738, 1.143289, -0.007813},{1.153509, 1.143689, -0.008605}}],
    Polygon[{{1.153932, 1.141707, -0.007813},{1.154864, 1.141030, -0.006829},{
      1.155834, 1.142933, -0.006829},{1.154738, 1.143289, -0.007813}}],
    Polygon[{{1.154864, 1.141030, -0.006829},{1.155660, 1.140451, -0.005676},{
      1.156770, 1.142629, -0.005676},{1.155834, 1.142933, -0.006829}}],
    Polygon[{{1.155660, 1.140451, -0.005676},{1.156301, 1.139986, -0.004384},{
      1.157523, 1.142384, -0.004384},{1.156770, 1.142629, -0.005676}}],
    Polygon[{{1.156301, 1.139986, -0.004384},{1.156770, 1.139645, -0.002984},{
      1.158074, 1.142205, -0.002984},{1.157523, 1.142384, -0.004384}}],
    Polygon[{{1.156770, 1.139645, -0.002984},{1.157056, 1.139437, -0.001511},{
      1.158411, 1.142096, -0.001511},{1.158074, 1.142205, -0.002984}}],
    Polygon[{{1.157056, 1.139437, -0.001511},{1.157152, 1.139367, 0.000000},{
      1.158524, 1.142059, 0.000000},{1.158411, 1.142096, -0.001511}}],
    Polygon[{{1.157152, 1.139367, 0.000000},{1.157056, 1.139437, 0.001511},{
      1.158411, 1.142096, 0.001511},{1.158524, 1.142059, 0.000000}}],
    Polygon[{{1.157056, 1.139437, 0.001511},{1.156770, 1.139645, 0.002984},{
      1.158074, 1.142205, 0.002984},{1.158411, 1.142096, 0.001511}}],
    Polygon[{{1.156770, 1.139645, 0.002984},{1.156301, 1.139986, 0.004384},{
      1.157523, 1.142384, 0.004384},{1.158074, 1.142205, 0.002984}}],
    Polygon[{{1.156301, 1.139986, 0.004384},{1.155660, 1.140451, 0.005676},{
      1.156770, 1.142629, 0.005676},{1.157523, 1.142384, 0.004384}}],
    Polygon[{{1.155660, 1.140451, 0.005676},{1.154864, 1.141030, 0.006829},{
      1.155834, 1.142933, 0.006829},{1.156770, 1.142629, 0.005676}}],
    Polygon[{{1.154864, 1.141030, 0.006829},{1.153932, 1.141707, 0.007813},{
      1.154738, 1.143289, 0.007813},{1.155834, 1.142933, 0.006829}}],
    Polygon[{{1.153932, 1.141707, 0.007813},{1.152886, 1.142466, 0.008605},{
      1.153509, 1.143689, 0.008605},{1.154738, 1.143289, 0.007813}}],
    Polygon[{{1.152886, 1.142466, 0.008605},{1.151754, 1.143289, 0.009185},{
      1.152178, 1.144121, 0.009185},{1.153509, 1.143689, 0.008605}}],
    Polygon[{{1.151754, 1.143289, 0.009185},{1.150562, 1.144155, 0.009538},{
      1.150776, 1.144577, 0.009538},{1.152178, 1.144121, 0.009185}}],
    Polygon[{{1.150776, 1.144577, -0.009538},{1.152178, 1.144121, -0.009185},{
      1.152324, 1.145043, -0.009185},{1.150850, 1.145043, -0.009538}}],
    Polygon[{{1.152178, 1.144121, -0.009185},{1.153509, 1.143689, -0.008605},{
      1.153724, 1.145043, -0.008605},{1.152324, 1.145043, -0.009185}}],
    Polygon[{{1.153509, 1.143689, -0.008605},{1.154738, 1.143289, -0.007813},{
      1.155016, 1.145043, -0.007813},{1.153724, 1.145043, -0.008605}}],
    Polygon[{{1.154738, 1.143289, -0.007813},{1.155834, 1.142933, -0.006829},{
      1.156168, 1.145043, -0.006829},{1.155016, 1.145043, -0.007813}}],
    Polygon[{{1.155834, 1.142933, -0.006829},{1.156770, 1.142629, -0.005676},{
      1.157152, 1.145043, -0.005676},{1.156168, 1.145043, -0.006829}}],
    Polygon[{{1.156770, 1.142629, -0.005676},{1.157523, 1.142384, -0.004384},{
      1.157944, 1.145043, -0.004384},{1.157152, 1.145043, -0.005676}}],
    Polygon[{{1.157523, 1.142384, -0.004384},{1.158074, 1.142205, -0.002984},{
      1.158524, 1.145043, -0.002984},{1.157944, 1.145043, -0.004384}}],
    Polygon[{{1.158074, 1.142205, -0.002984},{1.158411, 1.142096, -0.001511},{
      1.158878, 1.145043, -0.001511},{1.158524, 1.145043, -0.002984}}],
    Polygon[{{1.158411, 1.142096, -0.001511},{1.158524, 1.142059, 0.000000},{
      1.158997, 1.145043, 0.000000},{1.158878, 1.145043, -0.001511}}],
    Polygon[{{1.158524, 1.142059, 0.000000},{1.158411, 1.142096, 0.001511},{
      1.158878, 1.145043, 0.001511},{1.158997, 1.145043, 0.000000}}],
    Polygon[{{1.158411, 1.142096, 0.001511},{1.158074, 1.142205, 0.002984},{
      1.158524, 1.145043, 0.002984},{1.158878, 1.145043, 0.001511}}],
    Polygon[{{1.158074, 1.142205, 0.002984},{1.157523, 1.142384, 0.004384},{
      1.157944, 1.145043, 0.004384},{1.158524, 1.145043, 0.002984}}],
    Polygon[{{1.157523, 1.142384, 0.004384},{1.156770, 1.142629, 0.005676},{
      1.157152, 1.145043, 0.005676},{1.157944, 1.145043, 0.004384}}],
    Polygon[{{1.156770, 1.142629, 0.005676},{1.155834, 1.142933, 0.006829},{
      1.156168, 1.145043, 0.006829},{1.157152, 1.145043, 0.005676}}],
    Polygon[{{1.155834, 1.142933, 0.006829},{1.154738, 1.143289, 0.007813},{
      1.155016, 1.145043, 0.007813},{1.156168, 1.145043, 0.006829}}],
    Polygon[{{1.154738, 1.143289, 0.007813},{1.153509, 1.143689, 0.008605},{
      1.153724, 1.145043, 0.008605},{1.155016, 1.145043, 0.007813}}],
    Polygon[{{1.153509, 1.143689, 0.008605},{1.152178, 1.144121, 0.009185},{
      1.152324, 1.145043, 0.009185},{1.153724, 1.145043, 0.008605}}],
    Polygon[{{1.152178, 1.144121, 0.009185},{1.150776, 1.144577, 0.009538},{
      1.150850, 1.145043, 0.009538},{1.152324, 1.145043, 0.009185}}],
    Polygon[{{1.137092, 1.198582, -0.008668},{1.138431, 1.198582, -0.008347},{
      1.138298, 1.199420, -0.008347},{1.137024, 1.199007, -0.008668}}],
    Polygon[{{1.138431, 1.198582, -0.008347},{1.139703, 1.198582, -0.007820},{
      1.139508, 1.199814, -0.007820},{1.138298, 1.199420, -0.008347}}],
    Polygon[{{1.139703, 1.198582, -0.007820},{1.140877, 1.198582, -0.007100},{
      1.140625, 1.200176, -0.007100},{1.139508, 1.199814, -0.007820}}],
    Polygon[{{1.140877, 1.198582, -0.007100},{1.141925, 1.198582, -0.006206},{
      1.141621, 1.200500, -0.006206},{1.140625, 1.200176, -0.007100}}],
    Polygon[{{1.141925, 1.198582, -0.006206},{1.142819, 1.198582, -0.005159},{
      1.142471, 1.200776, -0.005159},{1.141621, 1.200500, -0.006206}}],
    Polygon[{{1.142819, 1.198582, -0.005159},{1.143538, 1.198582, -0.003984},{
      1.143156, 1.200999, -0.003984},{1.142471, 1.200776, -0.005159}}],
    Polygon[{{1.143538, 1.198582, -0.003984},{1.144065, 1.198582, -0.002712},{
      1.143657, 1.201162, -0.002712},{1.143156, 1.200999, -0.003984}}],
    Polygon[{{1.144065, 1.198582, -0.002712},{1.144387, 1.198582, -0.001373},{
      1.143963, 1.201261, -0.001373},{1.143657, 1.201162, -0.002712}}],
    Polygon[{{1.144387, 1.198582, -0.001373},{1.144495, 1.198582, 0.000000},{
      1.144065, 1.201294, 0.000000},{1.143963, 1.201261, -0.001373}}],
    Polygon[{{1.144495, 1.198582, 0.000000},{1.144387, 1.198582, 0.001373},{
      1.143963, 1.201261, 0.001373},{1.144065, 1.201294, 0.000000}}],
    Polygon[{{1.144387, 1.198582, 0.001373},{1.144065, 1.198582, 0.002712},{
      1.143657, 1.201162, 0.002712},{1.143963, 1.201261, 0.001373}}],
    Polygon[{{1.144065, 1.198582, 0.002712},{1.143538, 1.198582, 0.003984},{
      1.143156, 1.200999, 0.003984},{1.143657, 1.201162, 0.002712}}],
    Polygon[{{1.143538, 1.198582, 0.003984},{1.142819, 1.198582, 0.005159},{
      1.142471, 1.200776, 0.005159},{1.143156, 1.200999, 0.003984}}],
    Polygon[{{1.142819, 1.198582, 0.005159},{1.141925, 1.198582, 0.006206},{
      1.141621, 1.200500, 0.006206},{1.142471, 1.200776, 0.005159}}],
    Polygon[{{1.141925, 1.198582, 0.006206},{1.140877, 1.198582, 0.007100},{
      1.140625, 1.200176, 0.007100},{1.141621, 1.200500, 0.006206}}],
    Polygon[{{1.140877, 1.198582, 0.007100},{1.139703, 1.198582, 0.007820},{
      1.139508, 1.199814, 0.007820},{1.140625, 1.200176, 0.007100}}],
    Polygon[{{1.139703, 1.198582, 0.007820},{1.138431, 1.198582, 0.008347},{
      1.138298, 1.199420, 0.008347},{1.139508, 1.199814, 0.007820}}],
    Polygon[{{1.138431, 1.198582, 0.008347},{1.137092, 1.198582, 0.008668},{
      1.137024, 1.199007, 0.008668},{1.138298, 1.199420, 0.008347}}],
    Polygon[{{1.137024, 1.199007, -0.008668},{1.138298, 1.199420, -0.008347},{
      1.137913, 1.200176, -0.008347},{1.136829, 1.199389, -0.008668}}],
    Polygon[{{1.138298, 1.199420, -0.008347},{1.139508, 1.199814, -0.007820},{
      1.138942, 1.200924, -0.007820},{1.137913, 1.200176, -0.008347}}],
    Polygon[{{1.139508, 1.199814, -0.007820},{1.140625, 1.200176, -0.007100},{
      1.139892, 1.201615, -0.007100},{1.138942, 1.200924, -0.007820}}],
    Polygon[{{1.140625, 1.200176, -0.007100},{1.141621, 1.200500, -0.006206},{
      1.140739, 1.202230, -0.006206},{1.139892, 1.201615, -0.007100}}],
    Polygon[{{1.141621, 1.200500, -0.006206},{1.142471, 1.200776, -0.005159},{
      1.141463, 1.202756, -0.005159},{1.140739, 1.202230, -0.006206}}],
    Polygon[{{1.142471, 1.200776, -0.005159},{1.143156, 1.200999, -0.003984},{
      1.142045, 1.203179, -0.003984},{1.141463, 1.202756, -0.005159}}],
    Polygon[{{1.143156, 1.200999, -0.003984},{1.143657, 1.201162, -0.002712},{
      1.142471, 1.203489, -0.002712},{1.142045, 1.203179, -0.003984}}],
    Polygon[{{1.143657, 1.201162, -0.002712},{1.143963, 1.201261, -0.001373},{
      1.142732, 1.203678, -0.001373},{1.142471, 1.203489, -0.002712}}],
    Polygon[{{1.143963, 1.201261, -0.001373},{1.144065, 1.201294, 0.000000},{
      1.142819, 1.203741, 0.000000},{1.142732, 1.203678, -0.001373}}],
    Polygon[{{1.144065, 1.201294, 0.000000},{1.143963, 1.201261, 0.001373},{
      1.142732, 1.203678, 0.001373},{1.142819, 1.203741, 0.000000}}],
    Polygon[{{1.143963, 1.201261, 0.001373},{1.143657, 1.201162, 0.002712},{
      1.142471, 1.203489, 0.002712},{1.142732, 1.203678, 0.001373}}],
    Polygon[{{1.143657, 1.201162, 0.002712},{1.143156, 1.200999, 0.003984},{
      1.142045, 1.203179, 0.003984},{1.142471, 1.203489, 0.002712}}],
    Polygon[{{1.143156, 1.200999, 0.003984},{1.142471, 1.200776, 0.005159},{
      1.141463, 1.202756, 0.005159},{1.142045, 1.203179, 0.003984}}],
    Polygon[{{1.142471, 1.200776, 0.005159},{1.141621, 1.200500, 0.006206},{
      1.140739, 1.202230, 0.006206},{1.141463, 1.202756, 0.005159}}],
    Polygon[{{1.141621, 1.200500, 0.006206},{1.140625, 1.200176, 0.007100},{
      1.139892, 1.201615, 0.007100},{1.140739, 1.202230, 0.006206}}],
    Polygon[{{1.140625, 1.200176, 0.007100},{1.139508, 1.199814, 0.007820},{
      1.138942, 1.200924, 0.007820},{1.139892, 1.201615, 0.007100}}],
    Polygon[{{1.139508, 1.199814, 0.007820},{1.138298, 1.199420, 0.008347},{
      1.137913, 1.200176, 0.008347},{1.138942, 1.200924, 0.007820}}],
    Polygon[{{1.138298, 1.199420, 0.008347},{1.137024, 1.199007, 0.008668},{
      1.136829, 1.199389, 0.008668},{1.137913, 1.200176, 0.008347}}],
    Polygon[{{1.136829, 1.199389, -0.008668},{1.137913, 1.200176, -0.008347},{
      1.137313, 1.200776, -0.008347},{1.136526, 1.199693, -0.008668}}],
    Polygon[{{1.137913, 1.200176, -0.008347},{1.138942, 1.200924, -0.007820},{
      1.138061, 1.201806, -0.007820},{1.137313, 1.200776, -0.008347}}],
    Polygon[{{1.138942, 1.200924, -0.007820},{1.139892, 1.201615, -0.007100},{
      1.138751, 1.202756, -0.007100},{1.138061, 1.201806, -0.007820}}],
    Polygon[{{1.139892, 1.201615, -0.007100},{1.140739, 1.202230, -0.006206},{
      1.139366, 1.203603, -0.006206},{1.138751, 1.202756, -0.007100}}],
    Polygon[{{1.140739, 1.202230, -0.006206},{1.141463, 1.202756, -0.005159},{
      1.139892, 1.204327, -0.005159},{1.139366, 1.203603, -0.006206}}],
    Polygon[{{1.141463, 1.202756, -0.005159},{1.142045, 1.203179, -0.003984},{
      1.140315, 1.204909, -0.003984},{1.139892, 1.204327, -0.005159}}],
    Polygon[{{1.142045, 1.203179, -0.003984},{1.142471, 1.203489, -0.002712},{
      1.140625, 1.205335, -0.002712},{1.140315, 1.204909, -0.003984}}],
    Polygon[{{1.142471, 1.203489, -0.002712},{1.142732, 1.203678, -0.001373},{
      1.140814, 1.205595, -0.001373},{1.140625, 1.205335, -0.002712}}],
    Polygon[{{1.142732, 1.203678, -0.001373},{1.142819, 1.203741, 0.000000},{
      1.140877, 1.205683, 0.000000},{1.140814, 1.205595, -0.001373}}],
    Polygon[{{1.142819, 1.203741, 0.000000},{1.142732, 1.203678, 0.001373},{
      1.140814, 1.205595, 0.001373},{1.140877, 1.205683, 0.000000}}],
    Polygon[{{1.142732, 1.203678, 0.001373},{1.142471, 1.203489, 0.002712},{
      1.140625, 1.205335, 0.002712},{1.140814, 1.205595, 0.001373}}],
    Polygon[{{1.142471, 1.203489, 0.002712},{1.142045, 1.203179, 0.003984},{
      1.140315, 1.204909, 0.003984},{1.140625, 1.205335, 0.002712}}],
    Polygon[{{1.142045, 1.203179, 0.003984},{1.141463, 1.202756, 0.005159},{
      1.139892, 1.204327, 0.005159},{1.140315, 1.204909, 0.003984}}],
    Polygon[{{1.141463, 1.202756, 0.005159},{1.140739, 1.202230, 0.006206},{
      1.139366, 1.203603, 0.006206},{1.139892, 1.204327, 0.005159}}],
    Polygon[{{1.140739, 1.202230, 0.006206},{1.139892, 1.201615, 0.007100},{
      1.138751, 1.202756, 0.007100},{1.139366, 1.203603, 0.006206}}],
    Polygon[{{1.139892, 1.201615, 0.007100},{1.138942, 1.200924, 0.007820},{
      1.138061, 1.201806, 0.007820},{1.138751, 1.202756, 0.007100}}],
    Polygon[{{1.138942, 1.200924, 0.007820},{1.137913, 1.200176, 0.008347},{
      1.137313, 1.200776, 0.008347},{1.138061, 1.201806, 0.007820}}],
    Polygon[{{1.137913, 1.200176, 0.008347},{1.136829, 1.199389, 0.008668},{
      1.136526, 1.199693, 0.008668},{1.137313, 1.200776, 0.008347}}],
    Polygon[{{1.136526, 1.199693, -0.008668},{1.137313, 1.200776, -0.008347},{
      1.136557, 1.201162, -0.008347},{1.136143, 1.199888, -0.008668}}],
    Polygon[{{1.137313, 1.200776, -0.008347},{1.138061, 1.201806, -0.007820},{
      1.136950, 1.202372, -0.007820},{1.136557, 1.201162, -0.008347}}],
    Polygon[{{1.138061, 1.201806, -0.007820},{1.138751, 1.202756, -0.007100},{
      1.137313, 1.203489, -0.007100},{1.136950, 1.202372, -0.007820}}],
    Polygon[{{1.138751, 1.202756, -0.007100},{1.139366, 1.203603, -0.006206},{
      1.137636, 1.204484, -0.006206},{1.137313, 1.203489, -0.007100}}],
    Polygon[{{1.139366, 1.203603, -0.006206},{1.139892, 1.204327, -0.005159},{
      1.137913, 1.205335, -0.005159},{1.137636, 1.204484, -0.006206}}],
    Polygon[{{1.139892, 1.204327, -0.005159},{1.140315, 1.204909, -0.003984},{
      1.138135, 1.206020, -0.003984},{1.137913, 1.205335, -0.005159}}],
    Polygon[{{1.140315, 1.204909, -0.003984},{1.140625, 1.205335, -0.002712},{
      1.138298, 1.206521, -0.002712},{1.138135, 1.206020, -0.003984}}],
    Polygon[{{1.140625, 1.205335, -0.002712},{1.140814, 1.205595, -0.001373},{
      1.138397, 1.206826, -0.001373},{1.138298, 1.206521, -0.002712}}],
    Polygon[{{1.140814, 1.205595, -0.001373},{1.140877, 1.205683, 0.000000},{
      1.138431, 1.206929, 0.000000},{1.138397, 1.206826, -0.001373}}],
    Polygon[{{1.140877, 1.205683, 0.000000},{1.140814, 1.205595, 0.001373},{
      1.138397, 1.206826, 0.001373},{1.138431, 1.206929, 0.000000}}],
    Polygon[{{1.140814, 1.205595, 0.001373},{1.140625, 1.205335, 0.002712},{
      1.138298, 1.206521, 0.002712},{1.138397, 1.206826, 0.001373}}],
    Polygon[{{1.140625, 1.205335, 0.002712},{1.140315, 1.204909, 0.003984},{
      1.138135, 1.206020, 0.003984},{1.138298, 1.206521, 0.002712}}],
    Polygon[{{1.140315, 1.204909, 0.003984},{1.139892, 1.204327, 0.005159},{
      1.137913, 1.205335, 0.005159},{1.138135, 1.206020, 0.003984}}],
    Polygon[{{1.139892, 1.204327, 0.005159},{1.139366, 1.203603, 0.006206},{
      1.137636, 1.204484, 0.006206},{1.137913, 1.205335, 0.005159}}],
    Polygon[{{1.139366, 1.203603, 0.006206},{1.138751, 1.202756, 0.007100},{
      1.137313, 1.203489, 0.007100},{1.137636, 1.204484, 0.006206}}],
    Polygon[{{1.138751, 1.202756, 0.007100},{1.138061, 1.201806, 0.007820},{
      1.136950, 1.202372, 0.007820},{1.137313, 1.203489, 0.007100}}],
    Polygon[{{1.138061, 1.201806, 0.007820},{1.137313, 1.200776, 0.008347},{
      1.136557, 1.201162, 0.008347},{1.136950, 1.202372, 0.007820}}],
    Polygon[{{1.137313, 1.200776, 0.008347},{1.136526, 1.199693, 0.008668},{
      1.136143, 1.199888, 0.008668},{1.136557, 1.201162, 0.008347}}],
    Polygon[{{1.136143, 1.199888, -0.008668},{1.136557, 1.201162, -0.008347},{
      1.135719, 1.201294, -0.008347},{1.135719, 1.199955, -0.008668}}],
    Polygon[{{1.136557, 1.201162, -0.008347},{1.136950, 1.202372, -0.007820},{
      1.135719, 1.202567, -0.007820},{1.135719, 1.201294, -0.008347}}],
    Polygon[{{1.136950, 1.202372, -0.007820},{1.137313, 1.203489, -0.007100},{
      1.135719, 1.203741, -0.007100},{1.135719, 1.202567, -0.007820}}],
    Polygon[{{1.137313, 1.203489, -0.007100},{1.137636, 1.204484, -0.006206},{
      1.135719, 1.204788, -0.006206},{1.135719, 1.203741, -0.007100}}],
    Polygon[{{1.137636, 1.204484, -0.006206},{1.137913, 1.205335, -0.005159},{
      1.135719, 1.205683, -0.005159},{1.135719, 1.204788, -0.006206}}],
    Polygon[{{1.137913, 1.205335, -0.005159},{1.138135, 1.206020, -0.003984},{
      1.135719, 1.206402, -0.003984},{1.135719, 1.205683, -0.005159}}],
    Polygon[{{1.138135, 1.206020, -0.003984},{1.138298, 1.206521, -0.002712},{
      1.135719, 1.206929, -0.002712},{1.135719, 1.206402, -0.003984}}],
    Polygon[{{1.138298, 1.206521, -0.002712},{1.138397, 1.206826, -0.001373},{
      1.135719, 1.207251, -0.001373},{1.135719, 1.206929, -0.002712}}],
    Polygon[{{1.138397, 1.206826, -0.001373},{1.138431, 1.206929, 0.000000},{
      1.135719, 1.207359, 0.000000},{1.135719, 1.207251, -0.001373}}],
    Polygon[{{1.138431, 1.206929, 0.000000},{1.138397, 1.206826, 0.001373},{
      1.135719, 1.207251, 0.001373},{1.135719, 1.207359, 0.000000}}],
    Polygon[{{1.138397, 1.206826, 0.001373},{1.138298, 1.206521, 0.002712},{
      1.135719, 1.206929, 0.002712},{1.135719, 1.207251, 0.001373}}],
    Polygon[{{1.138298, 1.206521, 0.002712},{1.138135, 1.206020, 0.003984},{
      1.135719, 1.206402, 0.003984},{1.135719, 1.206929, 0.002712}}],
    Polygon[{{1.138135, 1.206020, 0.003984},{1.137913, 1.205335, 0.005159},{
      1.135719, 1.205683, 0.005159},{1.135719, 1.206402, 0.003984}}],
    Polygon[{{1.137913, 1.205335, 0.005159},{1.137636, 1.204484, 0.006206},{
      1.135719, 1.204788, 0.006206},{1.135719, 1.205683, 0.005159}}],
    Polygon[{{1.137636, 1.204484, 0.006206},{1.137313, 1.203489, 0.007100},{
      1.135719, 1.203741, 0.007100},{1.135719, 1.204788, 0.006206}}],
    Polygon[{{1.137313, 1.203489, 0.007100},{1.136950, 1.202372, 0.007820},{
      1.135719, 1.202567, 0.007820},{1.135719, 1.203741, 0.007100}}],
    Polygon[{{1.136950, 1.202372, 0.007820},{1.136557, 1.201162, 0.008347},{
      1.135719, 1.201294, 0.008347},{1.135719, 1.202567, 0.007820}}],
    Polygon[{{1.136557, 1.201162, 0.008347},{1.136143, 1.199888, 0.008668},{
      1.135719, 1.199955, 0.008668},{1.135719, 1.201294, 0.008347}}],
    Polygon[{{1.135719, 1.199955, -0.008668},{1.135719, 1.201294, -0.008347},{
      1.134881, 1.201162, -0.008347},{1.135294, 1.199888, -0.008668}}],
    Polygon[{{1.135719, 1.201294, -0.008347},{1.135719, 1.202567, -0.007820},{
      1.134488, 1.202372, -0.007820},{1.134881, 1.201162, -0.008347}}],
    Polygon[{{1.135719, 1.202567, -0.007820},{1.135719, 1.203741, -0.007100},{
      1.134125, 1.203489, -0.007100},{1.134488, 1.202372, -0.007820}}],
    Polygon[{{1.135719, 1.203741, -0.007100},{1.135719, 1.204788, -0.006206},{
      1.133801, 1.204484, -0.006206},{1.134125, 1.203489, -0.007100}}],
    Polygon[{{1.135719, 1.204788, -0.006206},{1.135719, 1.205683, -0.005159},{
      1.133525, 1.205335, -0.005159},{1.133801, 1.204484, -0.006206}}],
    Polygon[{{1.135719, 1.205683, -0.005159},{1.135719, 1.206402, -0.003984},{
      1.133302, 1.206020, -0.003984},{1.133525, 1.205335, -0.005159}}],
    Polygon[{{1.135719, 1.206402, -0.003984},{1.135719, 1.206929, -0.002712},{
      1.133139, 1.206521, -0.002712},{1.133302, 1.206020, -0.003984}}],
    Polygon[{{1.135719, 1.206929, -0.002712},{1.135719, 1.207251, -0.001373},{
      1.133040, 1.206826, -0.001373},{1.133139, 1.206521, -0.002712}}],
    Polygon[{{1.135719, 1.207251, -0.001373},{1.135719, 1.207359, 0.000000},{
      1.133007, 1.206929, 0.000000},{1.133040, 1.206826, -0.001373}}],
    Polygon[{{1.135719, 1.207359, 0.000000},{1.135719, 1.207251, 0.001373},{
      1.133040, 1.206826, 0.001373},{1.133007, 1.206929, 0.000000}}],
    Polygon[{{1.135719, 1.207251, 0.001373},{1.135719, 1.206929, 0.002712},{
      1.133139, 1.206521, 0.002712},{1.133040, 1.206826, 0.001373}}],
    Polygon[{{1.135719, 1.206929, 0.002712},{1.135719, 1.206402, 0.003984},{
      1.133302, 1.206020, 0.003984},{1.133139, 1.206521, 0.002712}}],
    Polygon[{{1.135719, 1.206402, 0.003984},{1.135719, 1.205683, 0.005159},{
      1.133525, 1.205335, 0.005159},{1.133302, 1.206020, 0.003984}}],
    Polygon[{{1.135719, 1.205683, 0.005159},{1.135719, 1.204788, 0.006206},{
      1.133801, 1.204484, 0.006206},{1.133525, 1.205335, 0.005159}}],
    Polygon[{{1.135719, 1.204788, 0.006206},{1.135719, 1.203741, 0.007100},{
      1.134125, 1.203489, 0.007100},{1.133801, 1.204484, 0.006206}}],
    Polygon[{{1.135719, 1.203741, 0.007100},{1.135719, 1.202567, 0.007820},{
      1.134488, 1.202372, 0.007820},{1.134125, 1.203489, 0.007100}}],
    Polygon[{{1.135719, 1.202567, 0.007820},{1.135719, 1.201294, 0.008347},{
      1.134881, 1.201162, 0.008347},{1.134488, 1.202372, 0.007820}}],
    Polygon[{{1.135719, 1.201294, 0.008347},{1.135719, 1.199955, 0.008668},{
      1.135294, 1.199888, 0.008668},{1.134881, 1.201162, 0.008347}}],
    Polygon[{{1.135294, 1.199888, -0.008668},{1.134881, 1.201162, -0.008347},{
      1.134125, 1.200776, -0.008347},{1.134912, 1.199693, -0.008668}}],
    Polygon[{{1.134881, 1.201162, -0.008347},{1.134488, 1.202372, -0.007820},{
      1.133377, 1.201806, -0.007820},{1.134125, 1.200776, -0.008347}}],
    Polygon[{{1.134488, 1.202372, -0.007820},{1.134125, 1.203489, -0.007100},{
      1.132687, 1.202756, -0.007100},{1.133377, 1.201806, -0.007820}}],
    Polygon[{{1.134125, 1.203489, -0.007100},{1.133801, 1.204484, -0.006206},{
      1.132071, 1.203603, -0.006206},{1.132687, 1.202756, -0.007100}}],
    Polygon[{{1.133801, 1.204484, -0.006206},{1.133525, 1.205335, -0.005159},{
      1.131545, 1.204327, -0.005159},{1.132071, 1.203603, -0.006206}}],
    Polygon[{{1.133525, 1.205335, -0.005159},{1.133302, 1.206020, -0.003984},{
      1.131122, 1.204909, -0.003984},{1.131545, 1.204327, -0.005159}}],
    Polygon[{{1.133302, 1.206020, -0.003984},{1.133139, 1.206521, -0.002712},{
      1.130813, 1.205335, -0.002712},{1.131122, 1.204909, -0.003984}}],
    Polygon[{{1.133139, 1.206521, -0.002712},{1.133040, 1.206826, -0.001373},{
      1.130624, 1.205595, -0.001373},{1.130813, 1.205335, -0.002712}}],
    Polygon[{{1.133040, 1.206826, -0.001373},{1.133007, 1.206929, 0.000000},{
      1.130560, 1.205683, 0.000000},{1.130624, 1.205595, -0.001373}}],
    Polygon[{{1.133007, 1.206929, 0.000000},{1.133040, 1.206826, 0.001373},{
      1.130624, 1.205595, 0.001373},{1.130560, 1.205683, 0.000000}}],
    Polygon[{{1.133040, 1.206826, 0.001373},{1.133139, 1.206521, 0.002712},{
      1.130813, 1.205335, 0.002712},{1.130624, 1.205595, 0.001373}}],
    Polygon[{{1.133139, 1.206521, 0.002712},{1.133302, 1.206020, 0.003984},{
      1.131122, 1.204909, 0.003984},{1.130813, 1.205335, 0.002712}}],
    Polygon[{{1.133302, 1.206020, 0.003984},{1.133525, 1.205335, 0.005159},{
      1.131545, 1.204327, 0.005159},{1.131122, 1.204909, 0.003984}}],
    Polygon[{{1.133525, 1.205335, 0.005159},{1.133801, 1.204484, 0.006206},{
      1.132071, 1.203603, 0.006206},{1.131545, 1.204327, 0.005159}}],
    Polygon[{{1.133801, 1.204484, 0.006206},{1.134125, 1.203489, 0.007100},{
      1.132687, 1.202756, 0.007100},{1.132071, 1.203603, 0.006206}}],
    Polygon[{{1.134125, 1.203489, 0.007100},{1.134488, 1.202372, 0.007820},{
      1.133377, 1.201806, 0.007820},{1.132687, 1.202756, 0.007100}}],
    Polygon[{{1.134488, 1.202372, 0.007820},{1.134881, 1.201162, 0.008347},{
      1.134125, 1.200776, 0.008347},{1.133377, 1.201806, 0.007820}}],
    Polygon[{{1.134881, 1.201162, 0.008347},{1.135294, 1.199888, 0.008668},{
      1.134912, 1.199693, 0.008668},{1.134125, 1.200776, 0.008347}}],
    Polygon[{{1.134912, 1.199693, -0.008668},{1.134125, 1.200776, -0.008347},{
      1.133525, 1.200176, -0.008347},{1.134608, 1.199389, -0.008668}}],
    Polygon[{{1.134125, 1.200776, -0.008347},{1.133377, 1.201806, -0.007820},{
      1.132495, 1.200924, -0.007820},{1.133525, 1.200176, -0.008347}}],
    Polygon[{{1.133377, 1.201806, -0.007820},{1.132687, 1.202756, -0.007100},{
      1.131545, 1.201615, -0.007100},{1.132495, 1.200924, -0.007820}}],
    Polygon[{{1.132687, 1.202756, -0.007100},{1.132071, 1.203603, -0.006206},{
      1.130698, 1.202230, -0.006206},{1.131545, 1.201615, -0.007100}}],
    Polygon[{{1.132071, 1.203603, -0.006206},{1.131545, 1.204327, -0.005159},{
      1.129974, 1.202756, -0.005159},{1.130698, 1.202230, -0.006206}}],
    Polygon[{{1.131545, 1.204327, -0.005159},{1.131122, 1.204909, -0.003984},{
      1.129392, 1.203179, -0.003984},{1.129974, 1.202756, -0.005159}}],
    Polygon[{{1.131122, 1.204909, -0.003984},{1.130813, 1.205335, -0.002712},{
      1.128966, 1.203489, -0.002712},{1.129392, 1.203179, -0.003984}}],
    Polygon[{{1.130813, 1.205335, -0.002712},{1.130624, 1.205595, -0.001373},{
      1.128706, 1.203678, -0.001373},{1.128966, 1.203489, -0.002712}}],
    Polygon[{{1.130624, 1.205595, -0.001373},{1.130560, 1.205683, 0.000000},{
      1.128618, 1.203741, 0.000000},{1.128706, 1.203678, -0.001373}}],
    Polygon[{{1.130560, 1.205683, 0.000000},{1.130624, 1.205595, 0.001373},{
      1.128706, 1.203678, 0.001373},{1.128618, 1.203741, 0.000000}}],
    Polygon[{{1.130624, 1.205595, 0.001373},{1.130813, 1.205335, 0.002712},{
      1.128966, 1.203489, 0.002712},{1.128706, 1.203678, 0.001373}}],
    Polygon[{{1.130813, 1.205335, 0.002712},{1.131122, 1.204909, 0.003984},{
      1.129392, 1.203179, 0.003984},{1.128966, 1.203489, 0.002712}}],
    Polygon[{{1.131122, 1.204909, 0.003984},{1.131545, 1.204327, 0.005159},{
      1.129974, 1.202756, 0.005159},{1.129392, 1.203179, 0.003984}}],
    Polygon[{{1.131545, 1.204327, 0.005159},{1.132071, 1.203603, 0.006206},{
      1.130698, 1.202230, 0.006206},{1.129974, 1.202756, 0.005159}}],
    Polygon[{{1.132071, 1.203603, 0.006206},{1.132687, 1.202756, 0.007100},{
      1.131545, 1.201615, 0.007100},{1.130698, 1.202230, 0.006206}}],
    Polygon[{{1.132687, 1.202756, 0.007100},{1.133377, 1.201806, 0.007820},{
      1.132495, 1.200924, 0.007820},{1.131545, 1.201615, 0.007100}}],
    Polygon[{{1.133377, 1.201806, 0.007820},{1.134125, 1.200776, 0.008347},{
      1.133525, 1.200176, 0.008347},{1.132495, 1.200924, 0.007820}}],
    Polygon[{{1.134125, 1.200776, 0.008347},{1.134912, 1.199693, 0.008668},{
      1.134608, 1.199389, 0.008668},{1.133525, 1.200176, 0.008347}}],
    Polygon[{{1.134608, 1.199389, -0.008668},{1.133525, 1.200176, -0.008347},{
      1.133139, 1.199420, -0.008347},{1.134413, 1.199007, -0.008668}}],
    Polygon[{{1.133525, 1.200176, -0.008347},{1.132495, 1.200924, -0.007820},{
      1.131929, 1.199814, -0.007820},{1.133139, 1.199420, -0.008347}}],
    Polygon[{{1.132495, 1.200924, -0.007820},{1.131545, 1.201615, -0.007100},{
      1.130813, 1.200176, -0.007100},{1.131929, 1.199814, -0.007820}}],
    Polygon[{{1.131545, 1.201615, -0.007100},{1.130698, 1.202230, -0.006206},{
      1.129817, 1.200500, -0.006206},{1.130813, 1.200176, -0.007100}}],
    Polygon[{{1.130698, 1.202230, -0.006206},{1.129974, 1.202756, -0.005159},{
      1.128966, 1.200776, -0.005159},{1.129817, 1.200500, -0.006206}}],
    Polygon[{{1.129974, 1.202756, -0.005159},{1.129392, 1.203179, -0.003984},{
      1.128282, 1.200999, -0.003984},{1.128966, 1.200776, -0.005159}}],
    Polygon[{{1.129392, 1.203179, -0.003984},{1.128966, 1.203489, -0.002712},{
      1.127780, 1.201162, -0.002712},{1.128282, 1.200999, -0.003984}}],
    Polygon[{{1.128966, 1.203489, -0.002712},{1.128706, 1.203678, -0.001373},{
      1.127475, 1.201261, -0.001373},{1.127780, 1.201162, -0.002712}}],
    Polygon[{{1.128706, 1.203678, -0.001373},{1.128618, 1.203741, 0.000000},{
      1.127372, 1.201294, 0.000000},{1.127475, 1.201261, -0.001373}}],
    Polygon[{{1.128618, 1.203741, 0.000000},{1.128706, 1.203678, 0.001373},{
      1.127475, 1.201261, 0.001373},{1.127372, 1.201294, 0.000000}}],
    Polygon[{{1.128706, 1.203678, 0.001373},{1.128966, 1.203489, 0.002712},{
      1.127780, 1.201162, 0.002712},{1.127475, 1.201261, 0.001373}}],
    Polygon[{{1.128966, 1.203489, 0.002712},{1.129392, 1.203179, 0.003984},{
      1.128282, 1.200999, 0.003984},{1.127780, 1.201162, 0.002712}}],
    Polygon[{{1.129392, 1.203179, 0.003984},{1.129974, 1.202756, 0.005159},{
      1.128966, 1.200776, 0.005159},{1.128282, 1.200999, 0.003984}}],
    Polygon[{{1.129974, 1.202756, 0.005159},{1.130698, 1.202230, 0.006206},{
      1.129817, 1.200500, 0.006206},{1.128966, 1.200776, 0.005159}}],
    Polygon[{{1.130698, 1.202230, 0.006206},{1.131545, 1.201615, 0.007100},{
      1.130813, 1.200176, 0.007100},{1.129817, 1.200500, 0.006206}}],
    Polygon[{{1.131545, 1.201615, 0.007100},{1.132495, 1.200924, 0.007820},{
      1.131929, 1.199814, 0.007820},{1.130813, 1.200176, 0.007100}}],
    Polygon[{{1.132495, 1.200924, 0.007820},{1.133525, 1.200176, 0.008347},{
      1.133139, 1.199420, 0.008347},{1.131929, 1.199814, 0.007820}}],
    Polygon[{{1.133525, 1.200176, 0.008347},{1.134608, 1.199389, 0.008668},{
      1.134413, 1.199007, 0.008668},{1.133139, 1.199420, 0.008347}}],
    Polygon[{{1.134413, 1.199007, -0.008668},{1.133139, 1.199420, -0.008347},{
      1.133007, 1.198582, -0.008347},{1.134346, 1.198582, -0.008668}}],
    Polygon[{{1.133139, 1.199420, -0.008347},{1.131929, 1.199814, -0.007820},{
      1.131734, 1.198582, -0.007820},{1.133007, 1.198582, -0.008347}}],
    Polygon[{{1.131929, 1.199814, -0.007820},{1.130813, 1.200176, -0.007100},{
      1.130560, 1.198582, -0.007100},{1.131734, 1.198582, -0.007820}}],
    Polygon[{{1.130813, 1.200176, -0.007100},{1.129817, 1.200500, -0.006206},{
      1.129513, 1.198582, -0.006206},{1.130560, 1.198582, -0.007100}}],
    Polygon[{{1.129817, 1.200500, -0.006206},{1.128966, 1.200776, -0.005159},{
      1.128618, 1.198582, -0.005159},{1.129513, 1.198582, -0.006206}}],
    Polygon[{{1.128966, 1.200776, -0.005159},{1.128282, 1.200999, -0.003984},{
      1.127899, 1.198582, -0.003984},{1.128618, 1.198582, -0.005159}}],
    Polygon[{{1.128282, 1.200999, -0.003984},{1.127780, 1.201162, -0.002712},{
      1.127372, 1.198582, -0.002712},{1.127899, 1.198582, -0.003984}}],
    Polygon[{{1.127780, 1.201162, -0.002712},{1.127475, 1.201261, -0.001373},{
      1.127050, 1.198582, -0.001373},{1.127372, 1.198582, -0.002712}}],
    Polygon[{{1.127475, 1.201261, -0.001373},{1.127372, 1.201294, 0.000000},{
      1.126942, 1.198582, 0.000000},{1.127050, 1.198582, -0.001373}}],
    Polygon[{{1.127372, 1.201294, 0.000000},{1.127475, 1.201261, 0.001373},{
      1.127050, 1.198582, 0.001373},{1.126942, 1.198582, 0.000000}}],
    Polygon[{{1.127475, 1.201261, 0.001373},{1.127780, 1.201162, 0.002712},{
      1.127372, 1.198582, 0.002712},{1.127050, 1.198582, 0.001373}}],
    Polygon[{{1.127780, 1.201162, 0.002712},{1.128282, 1.200999, 0.003984},{
      1.127899, 1.198582, 0.003984},{1.127372, 1.198582, 0.002712}}],
    Polygon[{{1.128282, 1.200999, 0.003984},{1.128966, 1.200776, 0.005159},{
      1.128618, 1.198582, 0.005159},{1.127899, 1.198582, 0.003984}}],
    Polygon[{{1.128966, 1.200776, 0.005159},{1.129817, 1.200500, 0.006206},{
      1.129513, 1.198582, 0.006206},{1.128618, 1.198582, 0.005159}}],
    Polygon[{{1.129817, 1.200500, 0.006206},{1.130813, 1.200176, 0.007100},{
      1.130560, 1.198582, 0.007100},{1.129513, 1.198582, 0.006206}}],
    Polygon[{{1.130813, 1.200176, 0.007100},{1.131929, 1.199814, 0.007820},{
      1.131734, 1.198582, 0.007820},{1.130560, 1.198582, 0.007100}}],
    Polygon[{{1.131929, 1.199814, 0.007820},{1.133139, 1.199420, 0.008347},{
      1.133007, 1.198582, 0.008347},{1.131734, 1.198582, 0.007820}}],
    Polygon[{{1.133139, 1.199420, 0.008347},{1.134413, 1.199007, 0.008668},{
      1.134346, 1.198582, 0.008668},{1.133007, 1.198582, 0.008347}}],
    Polygon[{{1.134346, 1.198582, -0.008668},{1.133007, 1.198582, -0.008347},{
      1.133139, 1.197744, -0.008347},{1.134413, 1.198158, -0.008668}}],
    Polygon[{{1.133007, 1.198582, -0.008347},{1.131734, 1.198582, -0.007820},{
      1.131929, 1.197351, -0.007820},{1.133139, 1.197744, -0.008347}}],
    Polygon[{{1.131734, 1.198582, -0.007820},{1.130560, 1.198582, -0.007100},{
      1.130813, 1.196988, -0.007100},{1.131929, 1.197351, -0.007820}}],
    Polygon[{{1.130560, 1.198582, -0.007100},{1.129513, 1.198582, -0.006206},{
      1.129817, 1.196665, -0.006206},{1.130813, 1.196988, -0.007100}}],
    Polygon[{{1.129513, 1.198582, -0.006206},{1.128618, 1.198582, -0.005159},{
      1.128966, 1.196388, -0.005159},{1.129817, 1.196665, -0.006206}}],
    Polygon[{{1.128618, 1.198582, -0.005159},{1.127899, 1.198582, -0.003984},{
      1.128282, 1.196166, -0.003984},{1.128966, 1.196388, -0.005159}}],
    Polygon[{{1.127899, 1.198582, -0.003984},{1.127372, 1.198582, -0.002712},{
      1.127780, 1.196003, -0.002712},{1.128282, 1.196166, -0.003984}}],
    Polygon[{{1.127372, 1.198582, -0.002712},{1.127050, 1.198582, -0.001373},{
      1.127475, 1.195904, -0.001373},{1.127780, 1.196003, -0.002712}}],
    Polygon[{{1.127050, 1.198582, -0.001373},{1.126942, 1.198582, 0.000000},{
      1.127372, 1.195870, 0.000000},{1.127475, 1.195904, -0.001373}}],
    Polygon[{{1.126942, 1.198582, 0.000000},{1.127050, 1.198582, 0.001373},{
      1.127475, 1.195904, 0.001373},{1.127372, 1.195870, 0.000000}}],
    Polygon[{{1.127050, 1.198582, 0.001373},{1.127372, 1.198582, 0.002712},{
      1.127780, 1.196003, 0.002712},{1.127475, 1.195904, 0.001373}}],
    Polygon[{{1.127372, 1.198582, 0.002712},{1.127899, 1.198582, 0.003984},{
      1.128282, 1.196166, 0.003984},{1.127780, 1.196003, 0.002712}}],
    Polygon[{{1.127899, 1.198582, 0.003984},{1.128618, 1.198582, 0.005159},{
      1.128966, 1.196388, 0.005159},{1.128282, 1.196166, 0.003984}}],
    Polygon[{{1.128618, 1.198582, 0.005159},{1.129513, 1.198582, 0.006206},{
      1.129817, 1.196665, 0.006206},{1.128966, 1.196388, 0.005159}}],
    Polygon[{{1.129513, 1.198582, 0.006206},{1.130560, 1.198582, 0.007100},{
      1.130813, 1.196988, 0.007100},{1.129817, 1.196665, 0.006206}}],
    Polygon[{{1.130560, 1.198582, 0.007100},{1.131734, 1.198582, 0.007820},{
      1.131929, 1.197351, 0.007820},{1.130813, 1.196988, 0.007100}}],
    Polygon[{{1.131734, 1.198582, 0.007820},{1.133007, 1.198582, 0.008347},{
      1.133139, 1.197744, 0.008347},{1.131929, 1.197351, 0.007820}}],
    Polygon[{{1.133007, 1.198582, 0.008347},{1.134346, 1.198582, 0.008668},{
      1.134413, 1.198158, 0.008668},{1.133139, 1.197744, 0.008347}}],
    Polygon[{{1.134413, 1.198158, -0.008668},{1.133139, 1.197744, -0.008347},{
      1.133525, 1.196988, -0.008347},{1.134608, 1.197775, -0.008668}}],
    Polygon[{{1.133139, 1.197744, -0.008347},{1.131929, 1.197351, -0.007820},{
      1.132495, 1.196240, -0.007820},{1.133525, 1.196988, -0.008347}}],
    Polygon[{{1.131929, 1.197351, -0.007820},{1.130813, 1.196988, -0.007100},{
      1.131545, 1.195550, -0.007100},{1.132495, 1.196240, -0.007820}}],
    Polygon[{{1.130813, 1.196988, -0.007100},{1.129817, 1.196665, -0.006206},{
      1.130698, 1.194935, -0.006206},{1.131545, 1.195550, -0.007100}}],
    Polygon[{{1.129817, 1.196665, -0.006206},{1.128966, 1.196388, -0.005159},{
      1.129974, 1.194409, -0.005159},{1.130698, 1.194935, -0.006206}}],
    Polygon[{{1.128966, 1.196388, -0.005159},{1.128282, 1.196166, -0.003984},{
      1.129392, 1.193986, -0.003984},{1.129974, 1.194409, -0.005159}}],
    Polygon[{{1.128282, 1.196166, -0.003984},{1.127780, 1.196003, -0.002712},{
      1.128966, 1.193676, -0.002712},{1.129392, 1.193986, -0.003984}}],
    Polygon[{{1.127780, 1.196003, -0.002712},{1.127475, 1.195904, -0.001373},{
      1.128706, 1.193487, -0.001373},{1.128966, 1.193676, -0.002712}}],
    Polygon[{{1.127475, 1.195904, -0.001373},{1.127372, 1.195870, 0.000000},{
      1.128618, 1.193424, 0.000000},{1.128706, 1.193487, -0.001373}}],
    Polygon[{{1.127372, 1.195870, 0.000000},{1.127475, 1.195904, 0.001373},{
      1.128706, 1.193487, 0.001373},{1.128618, 1.193424, 0.000000}}],
    Polygon[{{1.127475, 1.195904, 0.001373},{1.127780, 1.196003, 0.002712},{
      1.128966, 1.193676, 0.002712},{1.128706, 1.193487, 0.001373}}],
    Polygon[{{1.127780, 1.196003, 0.002712},{1.128282, 1.196166, 0.003984},{
      1.129392, 1.193986, 0.003984},{1.128966, 1.193676, 0.002712}}],
    Polygon[{{1.128282, 1.196166, 0.003984},{1.128966, 1.196388, 0.005159},{
      1.129974, 1.194409, 0.005159},{1.129392, 1.193986, 0.003984}}],
    Polygon[{{1.128966, 1.196388, 0.005159},{1.129817, 1.196665, 0.006206},{
      1.130698, 1.194935, 0.006206},{1.129974, 1.194409, 0.005159}}],
    Polygon[{{1.129817, 1.196665, 0.006206},{1.130813, 1.196988, 0.007100},{
      1.131545, 1.195550, 0.007100},{1.130698, 1.194935, 0.006206}}],
    Polygon[{{1.130813, 1.196988, 0.007100},{1.131929, 1.197351, 0.007820},{
      1.132495, 1.196240, 0.007820},{1.131545, 1.195550, 0.007100}}],
    Polygon[{{1.131929, 1.197351, 0.007820},{1.133139, 1.197744, 0.008347},{
      1.133525, 1.196988, 0.008347},{1.132495, 1.196240, 0.007820}}],
    Polygon[{{1.133139, 1.197744, 0.008347},{1.134413, 1.198158, 0.008668},{
      1.134608, 1.197775, 0.008668},{1.133525, 1.196988, 0.008347}}],
    Polygon[{{1.134608, 1.197775, -0.008668},{1.133525, 1.196988, -0.008347},{
      1.134125, 1.196388, -0.008347},{1.134912, 1.197472, -0.008668}}],
    Polygon[{{1.133525, 1.196988, -0.008347},{1.132495, 1.196240, -0.007820},{
      1.133377, 1.195359, -0.007820},{1.134125, 1.196388, -0.008347}}],
    Polygon[{{1.132495, 1.196240, -0.007820},{1.131545, 1.195550, -0.007100},{
      1.132687, 1.194409, -0.007100},{1.133377, 1.195359, -0.007820}}],
    Polygon[{{1.131545, 1.195550, -0.007100},{1.130698, 1.194935, -0.006206},{
      1.132071, 1.193562, -0.006206},{1.132687, 1.194409, -0.007100}}],
    Polygon[{{1.130698, 1.194935, -0.006206},{1.129974, 1.194409, -0.005159},{
      1.131545, 1.192838, -0.005159},{1.132071, 1.193562, -0.006206}}],
    Polygon[{{1.129974, 1.194409, -0.005159},{1.129392, 1.193986, -0.003984},{
      1.131122, 1.192256, -0.003984},{1.131545, 1.192838, -0.005159}}],
    Polygon[{{1.129392, 1.193986, -0.003984},{1.128966, 1.193676, -0.002712},{
      1.130813, 1.191830, -0.002712},{1.131122, 1.192256, -0.003984}}],
    Polygon[{{1.128966, 1.193676, -0.002712},{1.128706, 1.193487, -0.001373},{
      1.130624, 1.191570, -0.001373},{1.130813, 1.191830, -0.002712}}],
    Polygon[{{1.128706, 1.193487, -0.001373},{1.128618, 1.193424, 0.000000},{
      1.130560, 1.191482, 0.000000},{1.130624, 1.191570, -0.001373}}],
    Polygon[{{1.128618, 1.193424, 0.000000},{1.128706, 1.193487, 0.001373},{
      1.130624, 1.191570, 0.001373},{1.130560, 1.191482, 0.000000}}],
    Polygon[{{1.128706, 1.193487, 0.001373},{1.128966, 1.193676, 0.002712},{
      1.130813, 1.191830, 0.002712},{1.130624, 1.191570, 0.001373}}],
    Polygon[{{1.128966, 1.193676, 0.002712},{1.129392, 1.193986, 0.003984},{
      1.131122, 1.192256, 0.003984},{1.130813, 1.191830, 0.002712}}],
    Polygon[{{1.129392, 1.193986, 0.003984},{1.129974, 1.194409, 0.005159},{
      1.131545, 1.192838, 0.005159},{1.131122, 1.192256, 0.003984}}],
    Polygon[{{1.129974, 1.194409, 0.005159},{1.130698, 1.194935, 0.006206},{
      1.132071, 1.193562, 0.006206},{1.131545, 1.192838, 0.005159}}],
    Polygon[{{1.130698, 1.194935, 0.006206},{1.131545, 1.195550, 0.007100},{
      1.132687, 1.194409, 0.007100},{1.132071, 1.193562, 0.006206}}],
    Polygon[{{1.131545, 1.195550, 0.007100},{1.132495, 1.196240, 0.007820},{
      1.133377, 1.195359, 0.007820},{1.132687, 1.194409, 0.007100}}],
    Polygon[{{1.132495, 1.196240, 0.007820},{1.133525, 1.196988, 0.008347},{
      1.134125, 1.196388, 0.008347},{1.133377, 1.195359, 0.007820}}],
    Polygon[{{1.133525, 1.196988, 0.008347},{1.134608, 1.197775, 0.008668},{
      1.134912, 1.197472, 0.008668},{1.134125, 1.196388, 0.008347}}],
    Polygon[{{1.134912, 1.197472, -0.008668},{1.134125, 1.196388, -0.008347},{
      1.134881, 1.196003, -0.008347},{1.135294, 1.197277, -0.008668}}],
    Polygon[{{1.134125, 1.196388, -0.008347},{1.133377, 1.195359, -0.007820},{
      1.134488, 1.194793, -0.007820},{1.134881, 1.196003, -0.008347}}],
    Polygon[{{1.133377, 1.195359, -0.007820},{1.132687, 1.194409, -0.007100},{
      1.134125, 1.193676, -0.007100},{1.134488, 1.194793, -0.007820}}],
    Polygon[{{1.132687, 1.194409, -0.007100},{1.132071, 1.193562, -0.006206},{
      1.133801, 1.192680, -0.006206},{1.134125, 1.193676, -0.007100}}],
    Polygon[{{1.132071, 1.193562, -0.006206},{1.131545, 1.192838, -0.005159},{
      1.133525, 1.191830, -0.005159},{1.133801, 1.192680, -0.006206}}],
    Polygon[{{1.131545, 1.192838, -0.005159},{1.131122, 1.192256, -0.003984},{
      1.133302, 1.191145, -0.003984},{1.133525, 1.191830, -0.005159}}],
    Polygon[{{1.131122, 1.192256, -0.003984},{1.130813, 1.191830, -0.002712},{
      1.133139, 1.190644, -0.002712},{1.133302, 1.191145, -0.003984}}],
    Polygon[{{1.130813, 1.191830, -0.002712},{1.130624, 1.191570, -0.001373},{
      1.133040, 1.190338, -0.001373},{1.133139, 1.190644, -0.002712}}],
    Polygon[{{1.130624, 1.191570, -0.001373},{1.130560, 1.191482, 0.000000},{
      1.133007, 1.190236, 0.000000},{1.133040, 1.190338, -0.001373}}],
    Polygon[{{1.130560, 1.191482, 0.000000},{1.130624, 1.191570, 0.001373},{
      1.133040, 1.190338, 0.001373},{1.133007, 1.190236, 0.000000}}],
    Polygon[{{1.130624, 1.191570, 0.001373},{1.130813, 1.191830, 0.002712},{
      1.133139, 1.190644, 0.002712},{1.133040, 1.190338, 0.001373}}],
    Polygon[{{1.130813, 1.191830, 0.002712},{1.131122, 1.192256, 0.003984},{
      1.133302, 1.191145, 0.003984},{1.133139, 1.190644, 0.002712}}],
    Polygon[{{1.131122, 1.192256, 0.003984},{1.131545, 1.192838, 0.005159},{
      1.133525, 1.191830, 0.005159},{1.133302, 1.191145, 0.003984}}],
    Polygon[{{1.131545, 1.192838, 0.005159},{1.132071, 1.193562, 0.006206},{
      1.133801, 1.192680, 0.006206},{1.133525, 1.191830, 0.005159}}],
    Polygon[{{1.132071, 1.193562, 0.006206},{1.132687, 1.194409, 0.007100},{
      1.134125, 1.193676, 0.007100},{1.133801, 1.192680, 0.006206}}],
    Polygon[{{1.132687, 1.194409, 0.007100},{1.133377, 1.195359, 0.007820},{
      1.134488, 1.194793, 0.007820},{1.134125, 1.193676, 0.007100}}],
    Polygon[{{1.133377, 1.195359, 0.007820},{1.134125, 1.196388, 0.008347},{
      1.134881, 1.196003, 0.008347},{1.134488, 1.194793, 0.007820}}],
    Polygon[{{1.134125, 1.196388, 0.008347},{1.134912, 1.197472, 0.008668},{
      1.135294, 1.197277, 0.008668},{1.134881, 1.196003, 0.008347}}],
    Polygon[{{1.135294, 1.197277, -0.008668},{1.134881, 1.196003, -0.008347},{
      1.135719, 1.195870, -0.008347},{1.135719, 1.197209, -0.008668}}],
    Polygon[{{1.134881, 1.196003, -0.008347},{1.134488, 1.194793, -0.007820},{
      1.135719, 1.194598, -0.007820},{1.135719, 1.195870, -0.008347}}],
    Polygon[{{1.134488, 1.194793, -0.007820},{1.134125, 1.193676, -0.007100},{
      1.135719, 1.193424, -0.007100},{1.135719, 1.194598, -0.007820}}],
    Polygon[{{1.134125, 1.193676, -0.007100},{1.133801, 1.192680, -0.006206},{
      1.135719, 1.192377, -0.006206},{1.135719, 1.193424, -0.007100}}],
    Polygon[{{1.133801, 1.192680, -0.006206},{1.133525, 1.191830, -0.005159},{
      1.135719, 1.191482, -0.005159},{1.135719, 1.192377, -0.006206}}],
    Polygon[{{1.133525, 1.191830, -0.005159},{1.133302, 1.191145, -0.003984},{
      1.135719, 1.190763, -0.003984},{1.135719, 1.191482, -0.005159}}],
    Polygon[{{1.133302, 1.191145, -0.003984},{1.133139, 1.190644, -0.002712},{
      1.135719, 1.190236, -0.002712},{1.135719, 1.190763, -0.003984}}],
    Polygon[{{1.133139, 1.190644, -0.002712},{1.133040, 1.190338, -0.001373},{
      1.135719, 1.189914, -0.001373},{1.135719, 1.190236, -0.002712}}],
    Polygon[{{1.133040, 1.190338, -0.001373},{1.133007, 1.190236, 0.000000},{
      1.135719, 1.189806, 0.000000},{1.135719, 1.189914, -0.001373}}],
    Polygon[{{1.133007, 1.190236, 0.000000},{1.133040, 1.190338, 0.001373},{
      1.135719, 1.189914, 0.001373},{1.135719, 1.189806, 0.000000}}],
    Polygon[{{1.133040, 1.190338, 0.001373},{1.133139, 1.190644, 0.002712},{
      1.135719, 1.190236, 0.002712},{1.135719, 1.189914, 0.001373}}],
    Polygon[{{1.133139, 1.190644, 0.002712},{1.133302, 1.191145, 0.003984},{
      1.135719, 1.190763, 0.003984},{1.135719, 1.190236, 0.002712}}],
    Polygon[{{1.133302, 1.191145, 0.003984},{1.133525, 1.191830, 0.005159},{
      1.135719, 1.191482, 0.005159},{1.135719, 1.190763, 0.003984}}],
    Polygon[{{1.133525, 1.191830, 0.005159},{1.133801, 1.192680, 0.006206},{
      1.135719, 1.192377, 0.006206},{1.135719, 1.191482, 0.005159}}],
    Polygon[{{1.133801, 1.192680, 0.006206},{1.134125, 1.193676, 0.007100},{
      1.135719, 1.193424, 0.007100},{1.135719, 1.192377, 0.006206}}],
    Polygon[{{1.134125, 1.193676, 0.007100},{1.134488, 1.194793, 0.007820},{
      1.135719, 1.194598, 0.007820},{1.135719, 1.193424, 0.007100}}],
    Polygon[{{1.134488, 1.194793, 0.007820},{1.134881, 1.196003, 0.008347},{
      1.135719, 1.195870, 0.008347},{1.135719, 1.194598, 0.007820}}],
    Polygon[{{1.134881, 1.196003, 0.008347},{1.135294, 1.197277, 0.008668},{
      1.135719, 1.197209, 0.008668},{1.135719, 1.195870, 0.008347}}],
    Polygon[{{1.135719, 1.197209, -0.008668},{1.135719, 1.195870, -0.008347},{
      1.136557, 1.196003, -0.008347},{1.136143, 1.197277, -0.008668}}],
    Polygon[{{1.135719, 1.195870, -0.008347},{1.135719, 1.194598, -0.007820},{
      1.136950, 1.194793, -0.007820},{1.136557, 1.196003, -0.008347}}],
    Polygon[{{1.135719, 1.194598, -0.007820},{1.135719, 1.193424, -0.007100},{
      1.137313, 1.193676, -0.007100},{1.136950, 1.194793, -0.007820}}],
    Polygon[{{1.135719, 1.193424, -0.007100},{1.135719, 1.192377, -0.006206},{
      1.137636, 1.192680, -0.006206},{1.137313, 1.193676, -0.007100}}],
    Polygon[{{1.135719, 1.192377, -0.006206},{1.135719, 1.191482, -0.005159},{
      1.137913, 1.191830, -0.005159},{1.137636, 1.192680, -0.006206}}],
    Polygon[{{1.135719, 1.191482, -0.005159},{1.135719, 1.190763, -0.003984},{
      1.138135, 1.191145, -0.003984},{1.137913, 1.191830, -0.005159}}],
    Polygon[{{1.135719, 1.190763, -0.003984},{1.135719, 1.190236, -0.002712},{
      1.138298, 1.190644, -0.002712},{1.138135, 1.191145, -0.003984}}],
    Polygon[{{1.135719, 1.190236, -0.002712},{1.135719, 1.189914, -0.001373},{
      1.138397, 1.190338, -0.001373},{1.138298, 1.190644, -0.002712}}],
    Polygon[{{1.135719, 1.189914, -0.001373},{1.135719, 1.189806, 0.000000},{
      1.138431, 1.190236, 0.000000},{1.138397, 1.190338, -0.001373}}],
    Polygon[{{1.135719, 1.189806, 0.000000},{1.135719, 1.189914, 0.001373},{
      1.138397, 1.190338, 0.001373},{1.138431, 1.190236, 0.000000}}],
    Polygon[{{1.135719, 1.189914, 0.001373},{1.135719, 1.190236, 0.002712},{
      1.138298, 1.190644, 0.002712},{1.138397, 1.190338, 0.001373}}],
    Polygon[{{1.135719, 1.190236, 0.002712},{1.135719, 1.190763, 0.003984},{
      1.138135, 1.191145, 0.003984},{1.138298, 1.190644, 0.002712}}],
    Polygon[{{1.135719, 1.190763, 0.003984},{1.135719, 1.191482, 0.005159},{
      1.137913, 1.191830, 0.005159},{1.138135, 1.191145, 0.003984}}],
    Polygon[{{1.135719, 1.191482, 0.005159},{1.135719, 1.192377, 0.006206},{
      1.137636, 1.192680, 0.006206},{1.137913, 1.191830, 0.005159}}],
    Polygon[{{1.135719, 1.192377, 0.006206},{1.135719, 1.193424, 0.007100},{
      1.137313, 1.193676, 0.007100},{1.137636, 1.192680, 0.006206}}],
    Polygon[{{1.135719, 1.193424, 0.007100},{1.135719, 1.194598, 0.007820},{
      1.136950, 1.194793, 0.007820},{1.137313, 1.193676, 0.007100}}],
    Polygon[{{1.135719, 1.194598, 0.007820},{1.135719, 1.195870, 0.008347},{
      1.136557, 1.196003, 0.008347},{1.136950, 1.194793, 0.007820}}],
    Polygon[{{1.135719, 1.195870, 0.008347},{1.135719, 1.197209, 0.008668},{
      1.136143, 1.197277, 0.008668},{1.136557, 1.196003, 0.008347}}],
    Polygon[{{1.136143, 1.197277, -0.008668},{1.136557, 1.196003, -0.008347},{
      1.137313, 1.196388, -0.008347},{1.136526, 1.197472, -0.008668}}],
    Polygon[{{1.136557, 1.196003, -0.008347},{1.136950, 1.194793, -0.007820},{
      1.138061, 1.195359, -0.007820},{1.137313, 1.196388, -0.008347}}],
    Polygon[{{1.136950, 1.194793, -0.007820},{1.137313, 1.193676, -0.007100},{
      1.138751, 1.194409, -0.007100},{1.138061, 1.195359, -0.007820}}],
    Polygon[{{1.137313, 1.193676, -0.007100},{1.137636, 1.192680, -0.006206},{
      1.139366, 1.193562, -0.006206},{1.138751, 1.194409, -0.007100}}],
    Polygon[{{1.137636, 1.192680, -0.006206},{1.137913, 1.191830, -0.005159},{
      1.139892, 1.192838, -0.005159},{1.139366, 1.193562, -0.006206}}],
    Polygon[{{1.137913, 1.191830, -0.005159},{1.138135, 1.191145, -0.003984},{
      1.140315, 1.192256, -0.003984},{1.139892, 1.192838, -0.005159}}],
    Polygon[{{1.138135, 1.191145, -0.003984},{1.138298, 1.190644, -0.002712},{
      1.140625, 1.191830, -0.002712},{1.140315, 1.192256, -0.003984}}],
    Polygon[{{1.138298, 1.190644, -0.002712},{1.138397, 1.190338, -0.001373},{
      1.140814, 1.191570, -0.001373},{1.140625, 1.191830, -0.002712}}],
    Polygon[{{1.138397, 1.190338, -0.001373},{1.138431, 1.190236, 0.000000},{
      1.140877, 1.191482, 0.000000},{1.140814, 1.191570, -0.001373}}],
    Polygon[{{1.138431, 1.190236, 0.000000},{1.138397, 1.190338, 0.001373},{
      1.140814, 1.191570, 0.001373},{1.140877, 1.191482, 0.000000}}],
    Polygon[{{1.138397, 1.190338, 0.001373},{1.138298, 1.190644, 0.002712},{
      1.140625, 1.191830, 0.002712},{1.140814, 1.191570, 0.001373}}],
    Polygon[{{1.138298, 1.190644, 0.002712},{1.138135, 1.191145, 0.003984},{
      1.140315, 1.192256, 0.003984},{1.140625, 1.191830, 0.002712}}],
    Polygon[{{1.138135, 1.191145, 0.003984},{1.137913, 1.191830, 0.005159},{
      1.139892, 1.192838, 0.005159},{1.140315, 1.192256, 0.003984}}],
    Polygon[{{1.137913, 1.191830, 0.005159},{1.137636, 1.192680, 0.006206},{
      1.139366, 1.193562, 0.006206},{1.139892, 1.192838, 0.005159}}],
    Polygon[{{1.137636, 1.192680, 0.006206},{1.137313, 1.193676, 0.007100},{
      1.138751, 1.194409, 0.007100},{1.139366, 1.193562, 0.006206}}],
    Polygon[{{1.137313, 1.193676, 0.007100},{1.136950, 1.194793, 0.007820},{
      1.138061, 1.195359, 0.007820},{1.138751, 1.194409, 0.007100}}],
    Polygon[{{1.136950, 1.194793, 0.007820},{1.136557, 1.196003, 0.008347},{
      1.137313, 1.196388, 0.008347},{1.138061, 1.195359, 0.007820}}],
    Polygon[{{1.136557, 1.196003, 0.008347},{1.136143, 1.197277, 0.008668},{
      1.136526, 1.197472, 0.008668},{1.137313, 1.196388, 0.008347}}],
    Polygon[{{1.136526, 1.197472, -0.008668},{1.137313, 1.196388, -0.008347},{
      1.137913, 1.196988, -0.008347},{1.136829, 1.197775, -0.008668}}],
    Polygon[{{1.137313, 1.196388, -0.008347},{1.138061, 1.195359, -0.007820},{
      1.138942, 1.196240, -0.007820},{1.137913, 1.196988, -0.008347}}],
    Polygon[{{1.138061, 1.195359, -0.007820},{1.138751, 1.194409, -0.007100},{
      1.139892, 1.195550, -0.007100},{1.138942, 1.196240, -0.007820}}],
    Polygon[{{1.138751, 1.194409, -0.007100},{1.139366, 1.193562, -0.006206},{
      1.140739, 1.194935, -0.006206},{1.139892, 1.195550, -0.007100}}],
    Polygon[{{1.139366, 1.193562, -0.006206},{1.139892, 1.192838, -0.005159},{
      1.141463, 1.194409, -0.005159},{1.140739, 1.194935, -0.006206}}],
    Polygon[{{1.139892, 1.192838, -0.005159},{1.140315, 1.192256, -0.003984},{
      1.142045, 1.193986, -0.003984},{1.141463, 1.194409, -0.005159}}],
    Polygon[{{1.140315, 1.192256, -0.003984},{1.140625, 1.191830, -0.002712},{
      1.142471, 1.193676, -0.002712},{1.142045, 1.193986, -0.003984}}],
    Polygon[{{1.140625, 1.191830, -0.002712},{1.140814, 1.191570, -0.001373},{
      1.142732, 1.193487, -0.001373},{1.142471, 1.193676, -0.002712}}],
    Polygon[{{1.140814, 1.191570, -0.001373},{1.140877, 1.191482, 0.000000},{
      1.142819, 1.193424, 0.000000},{1.142732, 1.193487, -0.001373}}],
    Polygon[{{1.140877, 1.191482, 0.000000},{1.140814, 1.191570, 0.001373},{
      1.142732, 1.193487, 0.001373},{1.142819, 1.193424, 0.000000}}],
    Polygon[{{1.140814, 1.191570, 0.001373},{1.140625, 1.191830, 0.002712},{
      1.142471, 1.193676, 0.002712},{1.142732, 1.193487, 0.001373}}],
    Polygon[{{1.140625, 1.191830, 0.002712},{1.140315, 1.192256, 0.003984},{
      1.142045, 1.193986, 0.003984},{1.142471, 1.193676, 0.002712}}],
    Polygon[{{1.140315, 1.192256, 0.003984},{1.139892, 1.192838, 0.005159},{
      1.141463, 1.194409, 0.005159},{1.142045, 1.193986, 0.003984}}],
    Polygon[{{1.139892, 1.192838, 0.005159},{1.139366, 1.193562, 0.006206},{
      1.140739, 1.194935, 0.006206},{1.141463, 1.194409, 0.005159}}],
    Polygon[{{1.139366, 1.193562, 0.006206},{1.138751, 1.194409, 0.007100},{
      1.139892, 1.195550, 0.007100},{1.140739, 1.194935, 0.006206}}],
    Polygon[{{1.138751, 1.194409, 0.007100},{1.138061, 1.195359, 0.007820},{
      1.138942, 1.196240, 0.007820},{1.139892, 1.195550, 0.007100}}],
    Polygon[{{1.138061, 1.195359, 0.007820},{1.137313, 1.196388, 0.008347},{
      1.137913, 1.196988, 0.008347},{1.138942, 1.196240, 0.007820}}],
    Polygon[{{1.137313, 1.196388, 0.008347},{1.136526, 1.197472, 0.008668},{
      1.136829, 1.197775, 0.008668},{1.137913, 1.196988, 0.008347}}],
    Polygon[{{1.136829, 1.197775, -0.008668},{1.137913, 1.196988, -0.008347},{
      1.138298, 1.197744, -0.008347},{1.137024, 1.198158, -0.008668}}],
    Polygon[{{1.137913, 1.196988, -0.008347},{1.138942, 1.196240, -0.007820},{
      1.139508, 1.197351, -0.007820},{1.138298, 1.197744, -0.008347}}],
    Polygon[{{1.138942, 1.196240, -0.007820},{1.139892, 1.195550, -0.007100},{
      1.140625, 1.196988, -0.007100},{1.139508, 1.197351, -0.007820}}],
    Polygon[{{1.139892, 1.195550, -0.007100},{1.140739, 1.194935, -0.006206},{
      1.141621, 1.196665, -0.006206},{1.140625, 1.196988, -0.007100}}],
    Polygon[{{1.140739, 1.194935, -0.006206},{1.141463, 1.194409, -0.005159},{
      1.142471, 1.196388, -0.005159},{1.141621, 1.196665, -0.006206}}],
    Polygon[{{1.141463, 1.194409, -0.005159},{1.142045, 1.193986, -0.003984},{
      1.143156, 1.196166, -0.003984},{1.142471, 1.196388, -0.005159}}],
    Polygon[{{1.142045, 1.193986, -0.003984},{1.142471, 1.193676, -0.002712},{
      1.143657, 1.196003, -0.002712},{1.143156, 1.196166, -0.003984}}],
    Polygon[{{1.142471, 1.193676, -0.002712},{1.142732, 1.193487, -0.001373},{
      1.143963, 1.195904, -0.001373},{1.143657, 1.196003, -0.002712}}],
    Polygon[{{1.142732, 1.193487, -0.001373},{1.142819, 1.193424, 0.000000},{
      1.144065, 1.195870, 0.000000},{1.143963, 1.195904, -0.001373}}],
    Polygon[{{1.142819, 1.193424, 0.000000},{1.142732, 1.193487, 0.001373},{
      1.143963, 1.195904, 0.001373},{1.144065, 1.195870, 0.000000}}],
    Polygon[{{1.142732, 1.193487, 0.001373},{1.142471, 1.193676, 0.002712},{
      1.143657, 1.196003, 0.002712},{1.143963, 1.195904, 0.001373}}],
    Polygon[{{1.142471, 1.193676, 0.002712},{1.142045, 1.193986, 0.003984},{
      1.143156, 1.196166, 0.003984},{1.143657, 1.196003, 0.002712}}],
    Polygon[{{1.142045, 1.193986, 0.003984},{1.141463, 1.194409, 0.005159},{
      1.142471, 1.196388, 0.005159},{1.143156, 1.196166, 0.003984}}],
    Polygon[{{1.141463, 1.194409, 0.005159},{1.140739, 1.194935, 0.006206},{
      1.141621, 1.196665, 0.006206},{1.142471, 1.196388, 0.005159}}],
    Polygon[{{1.140739, 1.194935, 0.006206},{1.139892, 1.195550, 0.007100},{
      1.140625, 1.196988, 0.007100},{1.141621, 1.196665, 0.006206}}],
    Polygon[{{1.139892, 1.195550, 0.007100},{1.138942, 1.196240, 0.007820},{
      1.139508, 1.197351, 0.007820},{1.140625, 1.196988, 0.007100}}],
    Polygon[{{1.138942, 1.196240, 0.007820},{1.137913, 1.196988, 0.008347},{
      1.138298, 1.197744, 0.008347},{1.139508, 1.197351, 0.007820}}],
    Polygon[{{1.137913, 1.196988, 0.008347},{1.136829, 1.197775, 0.008668},{
      1.137024, 1.198158, 0.008668},{1.138298, 1.197744, 0.008347}}],
    Polygon[{{1.137024, 1.198158, -0.008668},{1.138298, 1.197744, -0.008347},{
      1.138431, 1.198582, -0.008347},{1.137092, 1.198582, -0.008668}}],
    Polygon[{{1.138298, 1.197744, -0.008347},{1.139508, 1.197351, -0.007820},{
      1.139703, 1.198582, -0.007820},{1.138431, 1.198582, -0.008347}}],
    Polygon[{{1.139508, 1.197351, -0.007820},{1.140625, 1.196988, -0.007100},{
      1.140877, 1.198582, -0.007100},{1.139703, 1.198582, -0.007820}}],
    Polygon[{{1.140625, 1.196988, -0.007100},{1.141621, 1.196665, -0.006206},{
      1.141925, 1.198582, -0.006206},{1.140877, 1.198582, -0.007100}}],
    Polygon[{{1.141621, 1.196665, -0.006206},{1.142471, 1.196388, -0.005159},{
      1.142819, 1.198582, -0.005159},{1.141925, 1.198582, -0.006206}}],
    Polygon[{{1.142471, 1.196388, -0.005159},{1.143156, 1.196166, -0.003984},{
      1.143538, 1.198582, -0.003984},{1.142819, 1.198582, -0.005159}}],
    Polygon[{{1.143156, 1.196166, -0.003984},{1.143657, 1.196003, -0.002712},{
      1.144065, 1.198582, -0.002712},{1.143538, 1.198582, -0.003984}}],
    Polygon[{{1.143657, 1.196003, -0.002712},{1.143963, 1.195904, -0.001373},{
      1.144387, 1.198582, -0.001373},{1.144065, 1.198582, -0.002712}}],
    Polygon[{{1.143963, 1.195904, -0.001373},{1.144065, 1.195870, 0.000000},{
      1.144495, 1.198582, 0.000000},{1.144387, 1.198582, -0.001373}}],
    Polygon[{{1.144065, 1.195870, 0.000000},{1.143963, 1.195904, 0.001373},{
      1.144387, 1.198582, 0.001373},{1.144495, 1.198582, 0.000000}}],
    Polygon[{{1.143963, 1.195904, 0.001373},{1.143657, 1.196003, 0.002712},{
      1.144065, 1.198582, 0.002712},{1.144387, 1.198582, 0.001373}}],
    Polygon[{{1.143657, 1.196003, 0.002712},{1.143156, 1.196166, 0.003984},{
      1.143538, 1.198582, 0.003984},{1.144065, 1.198582, 0.002712}}],
    Polygon[{{1.143156, 1.196166, 0.003984},{1.142471, 1.196388, 0.005159},{
      1.142819, 1.198582, 0.005159},{1.143538, 1.198582, 0.003984}}],
    Polygon[{{1.142471, 1.196388, 0.005159},{1.141621, 1.196665, 0.006206},{
      1.141925, 1.198582, 0.006206},{1.142819, 1.198582, 0.005159}}],
    Polygon[{{1.141621, 1.196665, 0.006206},{1.140625, 1.196988, 0.007100},{
      1.140877, 1.198582, 0.007100},{1.141925, 1.198582, 0.006206}}],
    Polygon[{{1.140625, 1.196988, 0.007100},{1.139508, 1.197351, 0.007820},{
      1.139703, 1.198582, 0.007820},{1.140877, 1.198582, 0.007100}}],
    Polygon[{{1.139508, 1.197351, 0.007820},{1.138298, 1.197744, 0.008347},{
      1.138431, 1.198582, 0.008347},{1.139703, 1.198582, 0.007820}}],
    Polygon[{{1.138298, 1.197744, 0.008347},{1.137024, 1.198158, 0.008668},{
      1.137092, 1.198582, 0.008668},{1.138431, 1.198582, 0.008347}}]},
    Boxed -> False,
    ViewPoint -> {0.684257, -0.773888, 1.734594}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3oool90?ooo`<0000000<0oooo000000000000
4P3oool00?d0oooo100000030?ooo`/000004@3oool00?X0oooo5000000B0?ooo`00lP3oool20000
0080oooo0P0000000`3oool000000000000B000001<0oooo003L0?ooo`T000001`3oool200000080
oooo7@00000C0?ooo`00f03oool@000000<0oooo8P00000C0?ooo`00e@3oool70000000303<c<`00
0000?S<c00L0?S<c500000000`0c<c<000000000000?000001@0oooo003C0?ooo`D000000`0c<c<>
0000000306Tc<`000000000000d0000000<0<c<c00000015<c<00P0000001@1n<c<0000000000000
0000`ULc0080000000<0e6lc0000000000000`00000E0?ooo`00dP3oool300000080<c<c10000003
03<c<`030000001D<c<0E3<c00D0E3<c00<0000007lc<`1o<c<03`0000001@0c<c<0000000000000
0000GC<c00<0000000D0[Ta200000000000000000=en@P06000001D0oooo00370?ooo`<000000P3o
ool70000000403<c<`0000000000000000@0<c<c3P00000307lc<`h0000000@0@S=2000000000000
MC=<3000000F0?ooo`00`P3oool2000000030?ooo`000000000000@0000000<0oooo000000000000
10000000100c<c<0000003<c<`00000203<c<`<000000`0n<c<00`000000JS<c06Xc<`0606Xc<`03
0000002D<c<00000008000000P1o<c<:0000000403<cA@000000000005dcG@L0000000<0jIMg0000
000000000`00000G0?ooo`00]`3oool9000000030?ooo`0000000000010000000P0c<c<3000000H0
?S<c2P00000409@c<`<0000000<0Xc`c0000000000001`000000100c<ed000000000001g?gL20000
00030:m[P0000000000000L000005`3oool00;D0oooo7000000303<c<`8000001@0n<c<4000000P0
OS<c0`00000509@c<`80000000<0Xc`c0000000000001P000000101<<gD000000000002@Gi0;0000
01L0oooo001n0?oooaT000004P3oool3000000<0oooo100000000`3oool000000000000J00000080
<c<c0P00000203<c<`030000000n<c<0000000800000101D<c<00`000000OS<c07hc<`0507hc<`03
0000002V<c<0YS<c00@0000000D0U3<c0000002gCS<000000:<l<`0E000001P0oooo001j0?ooo`D0
00005`0c<c<5000000`0oooo1`0000000`3oool000000000000:00000080OS<c4@00000203<c<`80
00000`0c<c<3000000L0E3<c00<0000007hc<`1n<c<01@1n<c<00`000000YS<c0:Hc<`040:Hc<`80
00000P2gCS<00`000000Xc`c0000000;000000030<RYb0000000000000D00000603oool007L0oooo
0`00000403<c<`030000000c<c<0<c<c01H0<c<c00<00000054c<`1A<c<0100000000`3oool00000
00000002000000<0oooo3`0000000`0c<c<000000000000F0000000303<c<`000000<c<c00<0<c<c
00<0000003<c<`0000001P1D<c<=000000@0YS<c00<000000<QO<`0000000P2gCS<<00000080b:W8
1P00000I0?ooo`00M03oool3000000@0<c<c7`000004054c<`H0000000<0oooo0000000000004@00
000206Xc<`@000000P2e@c<<00000080<c<c00@0000003<c<`0c<c<0<c<c0P00000303<c<`030000
001D<c<0000000<000000P1Z<c<00`000000T3<c090c<`05090c<`030000002e@c<0]D<c00<00000
00D0YS<c00000038Gc<0b5lc000000030;M><a8000006@3oool00700oooo1000000303<c<`@00000
0P0c<c<00`000000?S<c03hc<`0G03hc<`030000001Y<c<0JC<c01`0000000<0AC<c000000000000
0P0000020:4d<`@0000000<0e6lc0000000000001`00000203<c<`8000000P0c<c<00`000000<c<c
03<c<`0303<c<`8000001P1Z<c<00`000000T3<c090c<`05090c<`030000002e@c<0]D<c00<0]D<c
0P0000030<QO<`80000000<0]dhc0000000000003`00000J0?ooo`00K@3oool3000000@0<c<c0`00
000603<c<`030000000n<c<0?S<c01L0?S<c00<0000006Tc<`1Y<c<00`1Y<c<F0000000503<c<`00
000000000000001M<c<01`0000000`32Ec<00000000000090000000403<c<`000000<c<c03<c<`80
0000100c<c<20000000304Dc<`000000JS<c00D0JS<c1P000002090c<`030000002e@c<0]D<c00@0
]D<c0`0000030<QO<a4000006`3oool006T0oooo1000000403<c<`<000002@0c<c<00`000000?S<c
03hc<`0G03hc<`030000001Y<c<0JC<c00<0JC<c5`0000000`0c<c<0000005dc<`0200000080TC=2
00@000000:i<@P000000bVY<0P0000000`3MOT8000000>^LA@060000000403<c<`000000<c<c03<c
<`800000100c<c<01@000000AC<c04Dc<`15<c<0000000<0JS<c1@0000040:4d<`D00000102e@c<0
10000000e6lc0=A_<`0000030<QO<`030000003AP3<0000000`00000703oool006L0oooo0`000003
03<c<`@000002`0c<c<M000000@0JC<c600000001012<d80000007DcC01e<d`7000000030>><G@00
0000lZIM00H0000000D0<c<c0000000c<c<0<c<c0000000203<c<`040000000c<c<00000000000@0
AC<c1000000407hc<`030000002Q=3<0XC@c00@0XC@c00<000000<9G<`32Ec<01@0000030=A_<`04
00000038Gc<000000>2?<`h00000703oool006H0oooo0P00000203<c<`<000002`0c<c<400000003
03<c<`000000E3<c01P0E3<c00<0000007lc<`0000000P00000206Tc<aP0000000D0GC=M00000000
000000000:5@HP04000000030>VGM`000000000000P000000`0c<c<00`000000<c<c03<c<`020000
00D0AC<c0`00000607hc<`030000002Q=3<0XC@c00@0XC@c00<000000<9G<`32Ec<00`32Ec<20000
00@0e6lc0P0000000`3PSc<000000=60<`0;000001d0oooo001U0?ooo`D000002`0c<c<3000000D0
<c<c00<0000005@c<`1D<c<05`1D<c<00`000000Oc<c07lc<`0207lc<`L000000P1Y<c<500000003
0<RYb0000000000000/0000000<0Rd=Y00000000000010000000103YUgL000000000003h[GD60000
00<0<c<c00@0000003<c<`0c<c<0<c<c0P00000404Dc<`040000001M<c<0GC<c000000H0OS<c00<0
00000:4d<`2Q=3<0102Q=3<00`000000`ULc0<9G<`030<9G<`040000003MOT800000000000<0e6lc
00D000000>2?<`3PSc<000000=60<`09000001h0oooo001S0?ooo`@000002`0c<c<3000000P0<c<c
00<0000005@c<`1D<c<05`1D<c<00`000000Oc<c07lc<`0507lc<`<000000`1Y<c<>0000000703<c
G@000000C3=e0000001g?gL0000009iRQP06000000030?nbR`000000000000@0000000D0<c<c0000
00000000<c<c0000000303<c<`030000000c<c<000000080AC<c0P00000305dc<`040000001n<c<0
OS<c07hc<`d000000`32Ec<01@000000gGi20=en@P3MOT8000000080e6lc0P0000020>2?<`X00000
7P3oool005/0oooo00<000000?ooo`3oool0103oool4000000P0<c<c1000000;03<c<`030000001D
<c<0E3<c01L0E3<c00<0000007lc<`1o<c<0201o<c<30000000306Tc<`000000000000h0000000<0
JD>;0000002@Gi001P0000000`3o/ih000000?o;X@060000000303<c<`000000000000<0<c<c00@0
000003<c<`0c<c<0<c<c0P00000605dc<`<000000`2A<d800`000000[Ta20:i<@P030:i<@P040000
003:JT`0bVY<0<YZC0@00000103MOT8200000080jia500<000000>2?<`0000002@00000N0?ooo`00
F@3oool500000080oooo0`00000203<c<`030000000c<c<0<c<c00<0<c<c0`00000?03<c<`030000
001D<c<0E3<c01L0E3<c00<0000007lc<`1o<c<02`1o<c<?00000003048cT@000000000001400000
00<0<c<c0000000000000P0c<c<00`000000<c<c03<c<`0203<c<`8000001@1M<c<2000000D0TC=2
00<000000:i<@P2^C4800`2^C4800`000000bVY<0<YZC0030<YZC08000001@3MOT8010000000jia5
0>^LA@0000020>2?<`T000007P3oool00500oooo1P0000020?ooo`P0000000<0<c<c0000000c<c<0
0P0c<c<00`000000<c<c0000000300000180<c<c00<0000005@c<`1D<c<05`1D<c<00`000000Oc<c
07lc<`0?07lc<`<0000000<0JC<c000000000000300000020<RYb0T0000000<0<c<c0000000c<c<0
0P0000000`0c<c<0000003<c<`0303<c<`0300000012<d80000000<0GC<c0P00000207DcC0030000
002A<d80TC=200<0TC=200<000000:i<@P2^C4800P2^C4800`000000bVY<0<YZC0030<YZC0040000
003SS5d0000000000080gGi200<000000?:VG@0000000P3[W4D00`000000h8lc00000007000001l0
oooo00120?ooo`D000000`3oool300000080oooo200000000`3oool0000000000007000000@0<c<c
0P00000C03<c<b0000004P1o<c<40000000308dc<`000000000000P000000P38ZLP:0000000503<c
<`000000<c<c03<c<`000000100c<c<010000000@S=2048c@P12<d83000000@0MC=<00@00000094c
@P2A<d80TC=22@0000030<YZC0030000003SS5d0hhaM0080hhaM00D000000=en@P000000lZIM0000
00030>^LA@L000008@3oool003l0oooo8@00000303<c<`<000004@0c<c<3000000<0?S<c00<00000
06Xc<`1Z<c<05`1Z<c<00`000000U3<c09@c<`0300000180Oc<c0P0000000`2=<c<000000000000A
0000000403<c<`000000<c<c00000080<c<c0P00000203<c<`0300000012<d80@S=20080@S=20P00
000507DcC0@000000P2QD6800`000000^F=R0;USHP020;USHP030000003@NfT0000000<000001@3S
S5d01@000000lZIM0?:VG@3bYUd000000080jia500<000000>fjE00000001@00000P0?ooo`00>@3o
ool2000000<0oooo8P00000203<c<`030000000c<c<0000000h0<c<c1000000603hc<`030000001Z
<c<0JS<c01L0JS<c00<0000009@c<`2D<c<00`2D<c<3000000l0Oc<c00<000000:<l<`0000000`00
00000`1<J/X0000000000008000000030>Woj@000000000000<000000P0c<c<00`000000<c<c0000
000203<cA@8000001012<d800`000000GC=M0000000407DcC0<00000102QD6800`000000^F=R0;US
HP020;USHP030000003@NfT0d7]Y0080d7]Y0P0000030>><G@030000003h[GD0000000<0lZIM0`00
00000`3]^U@000000000000300000240oooo000R0?ooo`T00000203oool_00000080<c<c00<00000
03<c<`0c<c<02@0c<c<3000000X0?S<c00<0000006Xc<`1Z<c<05`1Z<c<00`000000U3<c09@c<`06
09@c<`@000002`1o<c<00`000000Xc`c0:<l<`080000000309jco`000000000000T0000000D0<c<c
0000000c<c<0<c<c0000000203<cA@8000001012<d8010000000GC=M05dcG@00000207DcC0040000
002;@fT0Rd=Y000000@0XE1R00<000000;USHP2iHf800P2iHf801@000000d7]Y0=1kJ@3@NfT00000
0080jIMg00H000000>><G@3SS5d000000?R]M@0000030?:VG@030000003g`fX0ml=Z00D000008P3o
ool001l0oooo4P0000000`3oool000000000000>00000080OS<c00<000000:Hc<`0000006@000004
03<c<`030000000c<c<0<c<c00D0<c<c1000000=03hc<`030000001Z<c<0JS<c01L0JS<c00<00000
09@c<`2D<c<02P2D<c<3000000T0Oc<c00@000000:<l<`2S?3<0Xc`c5000000203<c<`060000000c
<dD0<c=50000000c<ed000000P12<d800`000000GC=M05dcG@0205dcG@800000102;@fT01@000000
XE1R0:5@HP2QD680000000<0^F=R00<000000=1kJ@3@NfT00P3@NfT010000000jIMg0>VGM`3YUgL2
000000<0n:ee00<000000?:VG@3bYUd00P000000103g`fX0000000000000000T0?ooo`006`3oool6
000000H0?S<c8`0000000`2gCS<000000000000B000000D0<c<c00<0000003<c<`0c<c<00P0c<c<3
00000140?S<c00<0000006Xc<`1Z<c<05`1Z<c<00`000000U3<c09@c<`0=09@c<`<000001P1o<c<0
0`000000Xc`c0:<l<`020:<l<a8000000P0c<c<01@000000<c=503<cA@0c<dD000000080<c=M0P00
000405dcG@030000001g?gL0000000@0Rd=Y3@0000040>VGM`800000103h[GD2000000060?g9OP00
0000ml=Z0000003]^U@00000903oool001X0oooo100000000`0c<c<0000000000009000000<0JC<c
4P0000000`1Z<c<0000000000004000000040;E3<`00000000000<QO<`l000000`0c<c<00`000000
<c<c03<c<`0503<c<`030000000c<c<0000000800000500n<c<00`000000JS<c06Xc<`0G06Xc<`03
0000002D<c<0U3<c0100U3<c0`00000307lc<`030000002S?3<0Xc`c00@0Xc`c4@0000001@0c<c<0
000003<cA@0c<dD0000000<0<c=M0P00000305dcG@040000001g?gL0Mcmg000000<0Rd=Y0P000003
0:m[P00500000031NH00`GV00<5iP00000000`3ERhH2000000<0jIMg00<000000?nbR`0000000`3h
[GD01@000000oLUn0?g9OP000000ml=Z00<00000903oool001P0oooo0P0000000`0c<c<000000000
0003000000P0E3<c00<0000007lc<`0000004P0000001@15<c<000000000001n<c<000000080XC@c
00D000000<9G<`00000000000=A_<`03000000030=60<`000000000000<0000000<0b:W800000000
0000100000000`0c<c<000000000000803<c<`8000005`0n<c<00`000000JS<c06Xc<`0G06Xc<`03
0000002D<c<0U3<c01<0U3<c100000070:<l<`l0000000<0<c=D0000000000000P0c<dD01`000000
<c=M03<cG@0c<ed0000004`cM@0000000P1M<ed01`000000Mcmg07LoM`1g?gL0000008]3J@000000
0P2NHXH01@000000[f^00:m[P02_Jh0000000080`GV000@000000=F;QP3ERhH000000P3kWi000`00
0000jIMg000000030?nbR`080000003h[GD000000?o<T@000000oLUn0000003g`fX2000002D0oooo
000=0?ooo`8000000P3oool3000000<0oooo1000000403<c<`X000001@1o<c<@0000000305dc<`00
0000000000H0000000@0gGi2000000000000jia53@0000000`0c<c<0000003<c<`0703<c<`<00000
5`0n<c<L000001L0U3<c0`0000080:<l<`80000000<0SC<c000000000000200000000`0c<e@00000
03<cJP02000000<0<c=M00@0000004`cM@1<<gD0C3=e0P00000507LoM`050000002NHXH0WV:609iR
QP0000000`2_Jh0010000000`GV00<5iP00000020=F;QP050000003kWi00nin@0?^OT0000000103o
/X/200000080olbA00<000000?g9OP3mbGh00`00000U0?ooo`000P3oool400000080oooo0P000000
0`3oool000000000000<00000080<c<c1@00000706Xc<`030000002D<c<00000008000001@1o<c<?
00000003094c@P00000000000080000000@0bVY<000000000000gGi20P0000000`3[W4D000000000
000;000000P0<c<c00@0000003<c<`0c<c<00000500n<c<30000000305@c<`000000OS<c01P0OS<c
1000000D09@c<`040000002gCS<0]dhc000000P0Xc`c300000001@0c<e@0000003<cJP0c<fX00000
00<0<c=M00L0000004`cM@1<<gD0C3=e0000001Y@h/0000000<0Mcmg00<00000091OT00000000`2N
HXH00`000000[f^000000004000000030=F;QP000000nin@0080nin@00<000000?ncWP0000000P3o
/X/300000080olbA00<000000?g9OP3mbGh00`00000U0?ooo`006`00000403hc<`030000001Z<c<0
JS<c00D0JS<c00<0000009@c<`2D<c<00P2D<c<500000080Xc`c2@0000000`12<d80000007DcC004
000000050;USHP00000000000000003SS5d00P0000000`3bYUd000000000000:000000P0<c<c0P00
000303<c<`030000000n<c<0?S<c00h0?S<c1000000405@c<`030000001n<c<0OS<c01H0OS<c00<0
00000:Hc<`2V<c<00P2V<c<300000140U3<c00@000000;M><`2gCS<0]dhc0P0000080:<l<`P00000
00@0<c<n0000000c<e@000000P0c<fX4000000@0C3=e00H0000006U3R`1Y@h/0000007LoM`000003
091OT0030000002NHXH000000080000000D0^XFM00000037SYd000000=VIX00200000080nin@00@0
00000?ncWP3o/ih0ok>N0P0000020?o;X@050000003oc940olbA0000003mbGh01000000U0?ooo`00
5@0000000`0c<c<000000000000603hc<`/000001`2D<c<200000080Xc`c2@0000000`1M<ed00000
08]3J@06000000030>VGM`000000n:ee00<0000000<0ml=Z0000000000001`00000803<c<`030000
000c<c<0<c<c00@0<c<c00<0000003hc<`0n<c<02P0n<c<3000000P0E3<c00<0000007hc<`1n<c<0
5P1n<c<00`000000YS<c0:Hc<`050:Hc<`@000003@2D<c<00`000000]dhc0;M><`030;M><`030000
002S?3<0Xc`c00H0Xc`c2@0000001@0c<e@0000003<cJP0c<fX000000080<c=n0P00000204`cM@03
0000001Y@h/0JD>;0080JD>;0P000003091OT08000000P2_P:0020000000^XFM00000037SYd00000
0=VIX0000000njFW0P0000040?ncWP050000003obj40ol^Q0?o;X@0000000P3oc942000000040?gU
X@0000000000000002D0oooo000D0000000403<c<`000000<c<c00000080?S<c100000000`1D<c<0
000007hc<`0607hc<`030000002V<c<00000008000000`2D<c<010000000]dhc0;M><`0000030:<l
<`P0000000<0Mcmg0000000000000`0000000`3ERhH0000000000004000000030?g9OP0000000000
00H00000200c<c<2000000L0<c<c00<0000003hc<`0n<c<01P0n<c<4000000/0E3<c00<0000007hc
<`1n<c<05P1n<c<00`000000YS<c0:Hc<`090:Hc<`<000002P2D<c<00`000000]dhc0;M><`040;M>
<`8000001`2S?3<80000000503<cE0000000<c=Z03<cJP0000000P0c<gh00`000000@S>A00000002
000000@0JD>;00<0000008IRWP0000000P2@Gi0200000080[h2P00`000000;Z5W@000000ahjM0000
003IVJ0000000?^UY`000000ok:_0000003o/ih3000000<0ol^Q00L000000?o<T@00000000000?gU
X@000000mn>@008000009@3oool000D0000000<0YS<c0000000000002`000000100c<c<0000003<c
<`0c<c<3000000@0E3<c00<0000007hc<`1n<c<01@1n<c<00`000000YS<c0:Hc<`030:Hc<`@00000
0`2gCS<200000080Xc`c3P0000000`3kWi00000000000002000000030?o<T@000000000000H00000
200c<c<00`000000<c<c03<c<`0703<c<`030000000n<c<0?S<c00<0?S<c0`00000?05@c<`030000
001n<c<0OS<c01H0OS<c00<000000:Hc<`2V<c<0302V<c<3000000L0U3<c00<000000;M><`2gCS<0
1P2gCS<00`000000Xc`c0:<l<`060:<l<`P000000P0c<fX010000000<c=n03<cOP000003048cT@80
00000P1Y@h/010000000QV:N08IRWP26HYh200000080YgjW00@000000:n0X0000000^XFM10000000
103kYJL000000?nb[`3o/Zl2000000<0olZ_00<000000?o;X@3obj400P0000001P3oijh000000?gU
X@000000mn>@000002H0oooo0004000000040;E3<`00000000000<QO<``000000P0c<c<2000000H0
E3<c2@0000080:Hc<`800000102gCS<00`000000Xc`c0:<l<`0@000000030?o;X@000000000000L0
00001`0c<c<2000000X0<c<c00<0000003hc<`0000000`00000B05@c<`030000001n<c<0OS<c01H0
OS<c00<000000:Hc<`2V<c<03`2V<c<4000000<0U3<c00<000000;M><`2gCS<01`2gCS<2000000L0
Xc`c0P0000001`2WGC<000000000000c<gh0000003<cJP0000000`0c<gh010000000@S>A048cT@00
0002069@X@<000000`26HYh00`000000X82_000000020:MnY`<000000P38ZLP300000080ok:_0`00
00030?o:[`@000000P3oijh01@000000oNFQ0000003ghi00000002H0oooo00000`1n<c<000000:4d
<`07000000030=60<`000000000000D000000P0c<c<20000000303<c<`000000E3<c0080E3<c1000
0007090c<`@00000102V<c<00`000000b5lc0<QO<`02000000<0]dhc0P0000020;i_<`80000000<0
@S>A0000000000002`0000000`3oijh00000000000020000000303<c<`000000<c<c00H0<c<c00<0
000003<c<`0c<c<02P0c<c<2000001H0E3<c00<0000007hc<`1n<c<05P1n<c<00`000000YS<c0:Hc
<`0C0:Hc<`@000002`2gCS<00`000000Xc`c0:<l<`050:<l<`80000000<0Yedc0000000000000`00
000303<cOP0400000012<i40@S>A000000<0HU2Q00<00000081[[`0000000`0000020:20[`<00000
1P38ZLP300000080ol:j1@0000020?ob^@050000003oijh0onN^0000003miJ400P00000W0?ooo`00
1P0000000`3MOT8000000>^LA@090000000303<c<`000000<c<c0080<c<c1000000306Xc<`030000
002@<c<0T3<c00D0T3<c00@000000;E3<`2e@c<0]D<c1@0000040<QO<`040000002gCS<0]dhc0;M>
<`80000000<0_Vlc0000000000001P0000030<RYb0`000001@0c<c<2000000/0<c<c0`00000G05@c
<`030000001n<c<0OS<c01H0OS<c00<000000:Hc<`2V<c<05P2V<c<00`000000]dhc0;M><`0:0;M>
<`030000002S?3<0Xc`c00@0Xc`c0P000000102WGC<0000000000000000203<cT0@000000P12<i40
1@000000HU2Q069@X@1RD:40000000@0P6^_1@0000080<RYb0030000003o`[X00000008000000`3o
n/4010000000oo:i0?ob^@0000020?oW[P@000009`3oool000D0000000D0hhaM0000000000000000
0>^LA@09000000<0<c<c0P00000606Xc<`030000002@<c<0T3<c00D0T3<c00<000000;E3<`2e@c<0
1@2e@c<2000000@0b5lc0`0000020=60<`030000002nKc<0000000<0000000D0P7W1000000000000
00000<RYb003000000040?ooe@00000000000?SobP@0000000<0<c<c0000000c<c<00`0c<c<00`00
0000<c<c03<c<`0:03<c<`040000000c<c<0<c<c000001L0E3<c00<0000007hc<`1n<c<05P1n<c<0
0`000000YS<c0:Hc<`0E0:Hc<`0400000038Gc<00000000000/0]dhc0P0000040:<l<`030000002n
Kc<000000080000000@0<c=n0000000c<i0000000P0c=:4500000080HU2Q00<00000081[[`20Jjl0
0P20Jjl01@000000WHFj09f5^P2MQKX0000000P0b:W80P0000020?oIa`050000003on/40oo[10?oj
`@0000000P3ol[T6000002P0oooo0000102QD68000000000003@NfT4000000030?:VG@0000000000
00D0000000<0<c<c0000000c<c<00P0c<c<010000000AC<c04Dc<`00000406Xc<`X000001P2e@c<0
10000000e6lc0=A_<`0000050<QO<`060000003AP3<0dH0c0=60<`000000_Vlc100000000`26RmD0
00000000000;00000080<c<c00<0000003<c<`0c<c<00P00000;03<c<`8000000`0c<c<00`000000
E3<c05@c<`0E05@c<`<000005P1n<c<00`000000YS<c0:Hc<`0E0:Hc<`0500000038Gc<0b5lc0<QO
<`000000302gCS<01@000000Xc`c0:<l<`2S?3<000000080_Vlc0P000000100c<gh0000003<cT000
000203<dX@0500000012C:h0@Tb^0000001RHkT0300000080<RYb0`0000000<0n?o:0000003bnL80
0P00000X0?ooo`002P0000000`3g`fX00000000000020000000403<c<`000000000003<c<`800000
0`15<c<00`000000JS<c000000020000000307hc<`000000XC@c00D0XC@c00<000000<9G<`000000
0`0000020;E3<`040000003DKc<0e6lc0=A_<`8000000P38Gc<00`000000h8lc000000030=60<`03
0000002nKc<0000000/0000000<0hooS0000000000000P00000203<c<`030000000c<c<0000000`0
<c<c00<0000003<c<`0c<c<0100c<c<00`000000E3<c05@c<`0A05@c<`D0000000<0T3<c00000000
00005`00000E0:Hc<`0300000038Gc<0b5lc0080b5lc0P00000;0;M><`8000000P2S?3<00`000000
_Vlc0;i_<`030000000503<cT0000000<cBQ03<dX@0000000`12C:h010000000HV>i069S^@000004
081i`@050000002MS/L0WHk709f>a`0000001`38ZLP01@000000ooSI0?ohf@3on=T0000000<0oooE
00@000000?ood03oom0000000P3holX3000002T0oooo0008000000030?o<T@000000000000D00000
0P0c<c<00`000000AC<c04Dc<`0304Dc<`800000101n<c<00`000000XC@c0:4d<`040:4d<`030000
0032Ec<0`ULc00<0`ULc0P0000060=A_<`<000000P3PSc<01@000000dH0c0=60<`000000_Vlc0100
00000`0c<c<2000000/0<c<c0P00000703<c<`030000001D<c<0E3<c00h0E3<c0`00000406Xc<`03
0000002@<c<0T3<c01D0T3<c00<000000;E3<`2e@c<00`00000B0:Hc<`0300000038Gc<0b5lc00@0
b5lc00<000000;M><`2gCS<02P2gCS<00`000000Xc`c000000020;i_<`<000000P0c<i0010000000
<cBQ03<dX@000002049<[P050000001RHkT0HV>i069S^@0000000`20NL44000000030:2If@000000
b:W800@0b:W800<000000?_on`0000000`0000030?ooe@070000003oom00ooo@0000003holX00000
0?;i`P02000002T0oooo000>0000000303<c<`000000<c<c008000000`15<c<3000000D0OS<c0P00
00050:4d<`0300000032Ec<0`ULc00@0`ULc0`0000050=A_<`8000000`3PSc<00`000000dH0c0=60
<`0>0000000303<c<`000000<c<c00<0<c<c00<0000003<c<`0c<c<02@0c<c<00`000000<c<c03<c
<`0703<c<`030000001D<c<0E3<c00X0E3<c1000000706Xc<`030000002@<c<0T3<c01D0T3<c00<0
00000;E3<`2e@c<00`2e@c<4000000h0YS<c00<000000<QO<`38Gc<01@38Gc<2000000/0]dhc0P00
00030;i_<`H0000000D0<cBQ00000012C:h0@Tb^00000002069S^@H000000P2PVMT2000000030:NU
n`000000000000<0000000@0fOSo0000003koo/0nook1@0000020?ood0030000003holX0n?o:00<0
0000:P3oool00080000000<0b:W80000000000000P0000000`3ol[T000000000000500000080<c<c
0P00000204Dc<`040000001M<c<0GC<c000000D0OS<c200000060<9G<`030000003MOT80gGi20080
00000`3DKc<00`000000jia5000000030>2?<`050000003AP3<000000000003<WC<03000000403<c
<`8000002@0c<c<2000000X0<c<c00<0000005@c<`1D<c<01`1D<c<3000000/0JS<c00<00000090c
<`2@<c<05@2@<c<00`000000]D<c0;E3<`070;E3<`<000002P2V<c<00`000000b5lc0<QO<`080<QO
<`030000002gCS<0]dhc00P0]dhc0P0000040;i_<`<0000000<0<d>e0000000000001P00000206Uk
d00400000026RmD0QX_E08J;e@8000000P2WYO/020000000[k;o0000002j`_l000000<OIo`000000
fOSo0P0000030?_on`030000003YonT0000000H00000:`3oool00080000000<0b:W8000000000000
2@00000203<c<`030000000c<c<0<c<c00800000101M<c<500000003094c@P000000[Ta200@0[Ta2
1@0000000`32Ec<000000=en@P040=en@P030000003DKc<000000080jia500<000000>2?<`3PSc<0
0P3PSc<3000000030<bM<`000000000000P0000000<0<c<c0000000c<c<00P0c<c<00`000000<c<c
0000000803<c<`030000000c<c<0<c<c00X0<c<c00<0000005@c<`1D<c<00`1D<c<4000000h0JS<c
00<00000090c<`2@<c<0502@<c<00`000000]D<c0;E3<`0;0;E3<`<000001`2V<c<00`000000b5lc
0<QO<`090<QO<`800000202gCS<00`000000dH0c000000040;i_<`80000000D0<d>e0000000cEl80
<eO20000000204aZbP050000001YNm00JG_@06Ukd00000000P26RmD500000080[k;o00H000000;[2
o`000000amWo0000003In?l3000000030?_on`000000jOoY0080jOoY00D000000>?oh`000000gOoM
0000000/0?ooo`003P000000100c<c<0000003<c<`0c<c<2000000@0GC<c0P000005094c@P030000
002^C480[Ta20080[Ta200<000000<YZC03:JT`00`3:JT`2000000H0gGi20P0000030>^LA@050000
003PSc<0h8lc0>2?<`0000000P3N[Ch00`000000c9dc000000070000000303<c<`000000<c<c0080
<c<c00D0000003<c<`0c<c<0<c<c0000000503<c<`8000003@0c<c<00`000000E3<c05@c<`030000
0180JS<c00<00000090c<`2@<c<0502@<c<00`000000]D<c0;E3<`0>0;E3<`@000000`2V<c<00`00
0000b5lc0<QO<`0;0<QO<`030000002gCS<0]dhc00D0]dhc00@000000=60<`3AP3<000000`2nKc<3
0000000503=3]@000000<eO203=G`P0000000P1<J/X010000000JG_@06Ukd01YNm02000000<0T9ok
100000020;[2o`@000000`3Eool200000080jOoY00D000000>?oh`000000gOoM0000000]0?ooo`00
4000000203<c<`8000000`1M<c<00`000000MC=<00000005094c@P030000002^C480[Ta20080[Ta2
00<000000<YZC03:JT`00`3:JT`010000000hhaM0000000000040=en@P800000103[W4D020000000
h8lc0000003]^U@000000=j]?P000000c9dc2@00000403<c<`050000000c<c<0<c<c03<c<`000000
100c<c<00`000000<c<c03<c<`0=03<c<`<000005@1Z<c<00`000000T3<c090c<`0D090c<`030000
002e@c<0]D<c0180]D<c1000000>0<QO<`8000001@2gCS<010000000dH0c0=60<`0000040;i_<`<0
000000@0<d>e0000000cEl8000000`1<J/X30000000507NGj@0000000000092On`0000000`2N/ol4
00000080`O[o00D000000=Goo`3Eool000000=3oo`03000000040>?oh`000000gOoM000002h0oooo
000?00000080<c<c00H00000048c@P12<d80000005dc<`00000307DcC0030000002A<d80TC=20080
TC=21P0000050<YZC0040000003SS5d0hhaM0>><G@80000000D0gGi20000003bYUd0lZIM00000004
0>^LA@80000000H0kKYD0000003N[Ch0gZdn0000003<WC<7000000@0<c<c00<0000003<c<`0c<c<0
0P0c<c<00`000000<c<c03<c<`02000000l0<c<c00<0000004Dc<`0000005P1Z<c<00`000000T3<c
090c<`0D090c<`030000002e@c<0]D<c01D0]D<c0P00000?0<QO<`030000002gCS<0]dhc0080]dhc
00D000000=60<`3AP3<0dH0c000000040;i_<`T0000000<0GHcS0000001gUnT00`1gUnT2000000<0
W[?o00@000000:o:o`2_b_l000000`31n_l200000080d?oo100000000`3Momd000000000000^0?oo
o`0000<0oooo0000000000002P000000100c<c<0000003<c<`000003048c@P800000101e<d`00`00
0000TC=200000003000000@0^F=R100000020<YZC0030000003SS5d0hhaM00<0hhaM00<000000?:V
G@3bYUd00P3bYUd010000000jia50>^LA@3[W4D200000080kKYD00@000000=j]?P000000c9dc1`00
000303<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0000003`0c<c<200000080AC<c00<0
000006Xc<`1Z<c<0501Z<c<00`000000T3<c090c<`0D090c<`030000002e@c<0]D<c01@0]D<c00@0
00000=A_<`3DKc<000003`38Gc<200000080]dhc00<000000=60<`3AP3<00P3AP3<01P000000_Vlc
0;i_<`2nKc<000000:MM<`@0000000<0@WkM0000000000000P1MS><01@000000MiOY07NGj@000000
Rk;o00`000000P3@ool00`000000b_oh0<[on004000002l0oooo00030?ooo`/0000000<0<c=50000
000000000`12<d82000000@0MC=<0P0000030:5@HP030000002iHf80^F=R0080^F=R00@000000=1k
J@3@NfT0d7]Y0`0000040>><G@030000003h[GD0000000@0lZIM00D000000>^LA@000000ml=Z0000
00020>fjE0030000003N[Ch0gZdn00L000000`0c<c<00`000000<c<c03<c<`0403<c<`8000003`0c
<c<00`000000AC<c04Dc<`0204Dc<`030000001Z<c<0JS<c01@0JS<c00<00000090c<`2@<c<0502@
<c<00`000000]D<c0;E3<`0D0;E3<`040000003DKc<0e6lc0=A_<`8000003`38Gc<2000000H0dH0c
00@000000;i_<`2nKc<0_Vlc1P000002049ng@030000001MS><0GHcS008000001@2;/_l01@000000
XL_o0:7;o`2Qbol0000000@0^O;o0P0000000`3:ooP000000000000300000300oooo00040?ooo`X0
000000<0<c=50000000000000P12<d801@000000GC=M05dcG@000000MC=<0080000000<0Rd=Y0000
002QD6800P2QD6800`000000^F=R0;USHP020;USHP030000003@NfT0d7]Y0080d7]Y00<000000>VG
M`0000000`3SS5d010000000n:ee0?R]M@0000040?:VG@050000003g`fX0ml=Z0?O3JP0000000P3]
^U@00`000000gZdn00000005000000@0<c<c00<0000003<c<`0c<c<0100c<c<00`000000<c<c03<c
<`0<03<c<`8000001P15<c<00`000000JS<c06Xc<`0C06Xc<`030000002@<c<0T3<c01@0T3<c00<0
00000;E3<`2e@c<0502e@c<00`000000e6lc0=A_<`030=A_<`0300000038Gc<0b5lc00d0b5lc00<0
00000=60<`3AP3<0103AP3<00`000000_Vlc0;i_<`020;i_<`L0000000D0@WkM0000000000000000
07F]n005000000@0XL_o3000000a0?ooo`001@3oool90000000503<cA@0000000000048c@P000000
0`1M<ed2000000<0Rd=Y00D000000:5@HP2QD680XE1R000000040;USHP050000003@NfT0d7]Y0=1k
J@0000000`3YUgL3000000@0n:ee00H000000?:VG@3bYUd000000?g9OP0000020?O3JP030000003]
^U@0kKYD00P000000`0c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0000000`0<c<c00<0
000004Dc<`15<c<01P15<c<00`000000JS<c06Xc<`0C06Xc<aD000000P2@<c<00`000000]D<c0;E3
<`0D0;E3<`030000003DKc<0e6lc00@0e6lc0P00000=0<QO<`8000001P3AP3<00`000000_Vlc0;i_
<`020;i_<`P0000000@0GJKb00000000000000000P1e[OP700000080[^Oo2@00000a0?ooo`001P3o
ool80000000303<cA@000000<c=M008000000`1M<ed2000000@0Rd=Y00<000000:5@HP0000002000
00000`3@NfT000000>VGM`030>VGM`8000001@3h[GD200000080oLUn00P000000?O3JP3g`fX0ml=Z
0000003]^U@000000=kAJP80000000<0oooo0000000000000`0c<c<00`000000<c<c03<c<`0403<c
<`040000000c<c<0<c<c000000X0<c<c0P00000904Dc<`030000001Z<c<0JS<c0100JS<c1000000D
0:4d<`H000004P2e@c<00`000000e6lc0=A_<`070=A_<`0300000038Gc<0b5lc00X0b5lc00<00000
0>2?<`0000001P3AP3<010000000_Vlc0;i_<`2nKc<;0000000305fVlP000000000001800000<@3o
ool000H0oooo200000000`0c<dD0000003<cG@0200000080GC=M00@0000007LoM`1g?gL000000P2;
@fT300000080[f^000@000000<5iP031NH0000000`3ERhH2000000<0jIMg00@000000?nbR`3o/X/0
0000103h[GD01@000000oLUn0?g9OP3mbGh0000000<0ml=Z0P0000000`3]g7h00000000000030000
00<0<c<c00<0000003<c<`0c<c<0100c<c<01@000000<c<c03<c<`0c<c<0000000T0<c<c00<00000
04Dc<`15<c<02@15<c<00`000000JS<c06Xc<`0<06Xc<`@00000101n<c<00`000000XC@c0:4d<`0C
0:4d<`0400000032Ec<0`ULc0<9G<`<000003`2e@c<00`000000e6lc0=A_<`080=A_<`8000002@38
Gc<01@000000h8lc0>2?<`3PSc<0000000H0dH0c00@000000;i_<`2nKc<0_Vlc7`00000a0?ooo`00
203oool700000080<c=M00D0000004`cM@000000GC=M0000000207LoM`030000002;@fT000000080
WV:600@000000:m[P02_Jh0000000P31NH001P000000eH^60=F;QP3ERhH000000?^OT080000000<0
jIMg0000003o/X/00P3o/X/01P000000n:ee000000000000olbA000000<0oLUn00@000000?O3JP3g
`fX000000P3]g7h3000000030?ooo`000000<c<c0080<c<c00<0000003<c<`0c<c<0100c<c<00`00
0000<c<c03<c<`0203<c<`030000000c<c<0<c<c00@0<c<c0P00000=04Dc<`030000001Z<c<0JS<c
00P0JS<c0`00000807hc<`030000002Q=3<0XC@c0180XC@c00<000000<9G<`32Ec<01@32Ec<30000
00`0]D<c00<000000=A_<`3DKc<02P3DKc<00`000000b5lc0<QO<`060<QO<`050000003PSc<0h8lc
0>2?<`0000001P3AP3<00`000000_Vlc0;i_<`020;i_<ad00000<P3oool000T0oooo1P00000203<c
G@040000001<<gD0C3=e000000@0Mcmg00D0000009iRQP2NHXH0WV:6000000020:m[P00400000031
NH00`GV0000000<0eH^600D000000?^OT03kWi00nin@000000050?nbR`050000003oc940olbA0?o<
T@0000000`3mbGh010000000ml=Z0000000000020>gLOP<0000000D0oooo0000000c<c<0<c<c0000
000603<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000AC<c04Dc
<`0=04Dc<`030000001Z<c<0JS<c00@0JS<c1000000;07hc<`030000002Q=3<0XC@c0180XC@c00<0
00000<9G<`32Ec<02032Ec<4000000L0]D<c00<000000=A_<`3DKc<0303DKc<2000000H0b5lc00<0
00000>2?<`3PSc<00P3PSc<00`000000dH0c0=60<`040=60<`040000002nKc<0_Vlc0;i_<`P00000
00D0<c<c000000000000000006Xc<`05000000040;E3<`00000000000<QO<`H00000<`3oool000X0
oooo1P000000100c<ed0000004`cM@1<<gD200000080Mcmg00<00000091OT00000000P2NHXH00`00
0000[f^000000005000000030=F;QP000000nin@0080nin@00<000000?ncWP0000000`3o/X/20000
00@0olbA00<000000?g9OP3mbGh00P0000020?OST0030000003]g7h0000000@0000000<0<c<c0000
000c<c<01@0c<c<00`000000<c<c03<c<`0403<c<`040000000c<c<0<c<c03<c<`8000004015<c<0
10000000JS<c06Xc<`1Z<c<3000000l0OS<c00<000000:4d<`2Q=3<04P2Q=3<00`000000`ULc0<9G
<`0<0<9G<`<00000102e@c<00`000000e6lc0=A_<`0>0=A_<`0300000038Gc<0b5lc0080b5lc00<0
00000>2?<`3PSc<0103PSc<00`000000dH0c0=60<`040=60<`030000002nKc<0_Vlc00L0000000<0
<c<c00000015<c<00`0000001@1n<c<000000:4d<`000000`ULc0080000000<0e6lc000000000000
1@00000c0?ooo`002`3oool01P000000oooo000000000000<c=n000000<0C3=e00D0000006U3R`00
0000Mcmg00000002091OT0040000002NHXH0000000000080^XFM00@000000<N>W@000000fIVP0P00
00020?^OT0040000003o/ih0ok>N0?ncWP<000000P3obj4010000000olbA0?o<T@3oc94300000006
0?gUX@000000mn>@0?OST0000000kMan1P00000603<c<`030000000c<c<0<c<c00D0<c<c00@00000
03<c<`0c<c<000004P15<c<400000180OS<c00<000000:4d<`2Q=3<04P2Q=3<00`000000`ULc0<9G
<`0?0<9G<`<0000000<0]D<c0000003DKc<0403DKc<200000080b5lc00<000000>2?<`3PSc<01@3P
Sc<00`000000dH0c0=60<`040=60<`030000002nKc<0000000D0000000D0<c<c0000000000000000
05dc<`08000000030=en@P000000000000D00000=03oool000d0oooo0P0000001@0c<gh000000000
001<<gD0000000<0JD>;0P000003091OT00;0000002_P:00[h2P0000002jQId000000<N>W@000000
fIVP0000003kYJL00P0000040?ncWP8000000`3obj400`000000olbA0?o<T@0300000080oNFQ00D0
00000?OST03ghi0000000>gLOP02000000040?ooo`0000000000000000H0<c<c00<0000003<c<`0c
<c<01P0c<c<200000180AC<c0`00000D07hc<`030000002Q=3<0XC@c0180XC@c00<000000<9G<`32
Ec<04P32Ec<2000001<0e6lc00<000000<QO<`0000001`3PSc<00`000000dH0c0=60<`040=60<`03
0000002nKc<0000000H0000000<0<c<c0000000000000`0000001@2A<d800000000000000000bVY<
00@0000000<0jia5000000000000=P3oool000d0oooo00D0000003<cJP0000000000048cT@020000
00<0JD>;01@0000008IRWP000000T5n@0000002WOZL000000:n0X0000000^XFM00000037SYd00000
0=VIX0000000njFW0000003o/Zl000000?ncWP80000000<0olZ_0000003obj400`3obj4200000080
onN^00@000000?gUX@3miJ4000000P3ghi050000000303<c<`000000<c<c00D0<c<c00<0000003<c
<`0c<c<01P0c<c<200000140AC<c0P00000205dc<`030000001n<c<0OS<c0180OS<c00<000000:4d
<`2Q=3<04P2Q=3<00`000000`ULc0<9G<`0B0<9G<`040000003MOT80000000000180e6lc00<00000
0>2?<`3PSc<01`3PSc<00`000000dH0c0=60<`040=60<`<0000000L0oooo000000000000000003<c
A@000000@S=200H0000000L0^F=R00000000000000000>><G@000000lZIM00<00000=P3oool000h0
oooo0P0000000`0c<gh00000048cT@030000000406U3R`000000QV:N08IRWP8000000P2WOZL00`00
0000[h2P00000004000000030?^UY`000000ok:_0080ok:_00<000000?o:[`3obZl00P3obZl00`00
0000ol^Q00000002000000<0onN^00@000000?gUX@3miJ4000000P3ghi000`000000h?:V00000004
000000D0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000<c<c0000000?04Dc<`030000001M<c<0
GC<c0080GC<c00<0000007hc<`1n<c<04P1n<c<00`000000XC@c0:4d<`0B0:4d<`0300000032Ec<0
`ULc0180`ULc00D000000=en@P3MOT80gGi20000000A0=A_<`8000002@3PSc<00`000000dH0c0=60
<`040=60<`80000000<0oooo0000000000000P0000001@0c<ed0000005dcG@000000Rd=Y00H00000
00<0jIMg0000003h[GD01000000f0?ooo`003P3oool20000000403<cOP000000@S>A00000080HU2Q
0P00000208IRWP050000002PP:l000000000002WOZL00P0000030<RYb0<0000000@0ok:_00000000
000000000`3obZl300000080oo:i00D000000?oW[P3oijh0onN^000000020?gUX@X00000100c<c<0
0`000000<c<c03<c<`0703<c<`040000000c<c<0<c<c000000d0AC<c0P00000505dc<`030000001n
<c<0OS<c0180OS<c00<000000:4d<`2Q=3<04P2Q=3<00`000000`ULc0<9G<`0B0<9G<`030000003M
OT80gGi20080gGi20P00000?0=A_<`030000003[W4D0000000P0h8lc00<000000=60<`3AP3<0103A
P3<00`000000c9dc000000050000000304`cM@000000Mcmg00@0000000D0`GV00000000000000000
0?nbR`02000000030?g9OP000000000003H0oooo000?0?ooo`<0000000H0@S>A0000001RD:40HU2Q
00000020Jjl3000000<0X82_0P0000060<RYb08000000`3o`[X3000000030?oj`@000000oo:i0080
oo:i00H000000?oW[P3oijh0onN^0000003miJ4200000080joNe0`000000103oool0000000000000
000303<c<`030000000c<c<0<c<c00L0<c<c00D0000003<c<`0c<c<0<c<c0000000<04Dc<`030000
001M<c<0GC<c00H0GC<c00<0000007hc<`1n<c<04@1n<c<00`000000XC@c0:4d<`0B0:4d<`030000
0032Ec<0`ULc0140`ULc00<000000=en@P3MOT801@3MOT800`000000e6lc0=A_<`0;0=A_<`050000
003[W4D0jia50>^LA@000000203PSc<00`000000dH0c0=60<`030=60<`030000003<WC<0000000D0
000000<0C3=e0000000000002P000000103oc940000000000000000f0?ooo`003`3oool600000080
HU2Q00<00000081[[`20Jjl01@0000070<RYb0H000000`3on/401@000000oo:i0?ob^@3ol[T00000
0080onN^0`0000001@3bnL8000000>_g]@000000h?:V00<0000000<0<c<c0000000000000`0c<c<0
0`000000<c<c03<c<`0603<c<`030000000c<c<0<c<c00<0<c<c00<0000004Dc<`15<c<01`15<c<2
000000T0GC<c00<0000007hc<`1n<c<04@1n<c<00`000000XC@c0:4d<`0A0:4d<`0300000032Ec<0
`ULc0180`ULc00<000000=en@P3MOT801P3MOT82000000/0e6lc00D000000>^LA@3[W4D0jia50000
00090>2?<`060000003AP3<0dH0c0=60<`000000gZdn5`00000g0?ooo`00403oool010000000<cBQ
00000012C:h500000003081[[`000000WHFj0080WHFj00<000000<RYb038ZLP01P38ZLP01@000000
omW70?oIa`3ofLL0000000<0oo[11`0000002P3holX000000?;i`P3bnL8000000>_g]@000000h?:V
0000003oool20000000503<c<`000000<c<c03<c<`0000002@0c<c<00`000000<c<c03<c<`0303<c
<`0300000015<c<0AC<c00H0AC<c00<0000005dc<`1M<c<02@1M<c<00`000000OS<c07hc<`0B07hc
<a80000000<0XC@c00000032Ec<04`32Ec<00`000000gGi20=en@P080=en@P030000003DKc<0e6lc
00L0e6lc00<000000>^LA@3[W4D00`3[W4D00`000000h8lc0>2?<`070>2?<`070000003AP3<0dH0c
0000003N[Ch000000<bM<`0600000003069@X@0000000000008000000P38ZLP4000000040?ob^@00
00000000000003L0oooo000@0?ooo`<0000000H0@Tb^0000001RHkT0HV>i00000020NL46000000P0
b:W82@0000030?ood0070000003holX0n?o:0?SobP000000l_W2000000020>_g]@<0000000<0oooo
0000000000000P0c<c<2000000T0<c<c00<0000003<c<`0c<c<01@0c<c<00`000000AC<c04Dc<`03
04Dc<`8000003@1M<c<00`000000OS<c07hc<`0=07hc<`D000004@2^C48500000100`ULc00<00000
0=en@P3MOT802P3MOT82000000L0e6lc00<000000>^LA@3[W4D0103[W4D00`000000h8lc0>2?<`06
0>2?<`070000003AP3<0dH0c0000003N[Ch000000<bM<`0;00000080b:W81`00000h0?ooo`004@3o
ool01@000000<cBQ00000012C:h000000080HV>i00D00000081i`@20NL40000009f>a`03000000H0
b:W8100000000`3on=T000000?ooe@020?ooe@050000003oom00ooo@0?ood00000000P3holX01@00
0000l_W20?;i`P000000joNe00<0000000@0oooo0000000c<c<000000P0c<c<00`000000<c<c03<c
<`0703<c<`030000000c<c<0<c<c00H0<c<c00<0000004Dc<`15<c<00P15<c<00`000000GC<c05dc
<`0=05dc<`030000001n<c<0OS<c00T0OS<c10000004094c@P030000002^C480[Ta20100[Ta200@0
00000<YZC03:JT`0bVY<1000000<0<9G<`030000003MOT80gGi200`0gGi200<000000=A_<`3DKc<0
0`3DKc<00`000000jia50>^LA@060>^LA@030000003PSc<0h8lc00H0h8lc00<000000=60<`000000
0P3N[Ch2000000030?ooo`000000000001000000>03oool00180oooo0P0000001012C:h00000069S
^@1RHkT500000080X9WI0`0000030<RYb0<000000P3koo/4000000030?ooe@000000ooo@0080ooo@
00@000000?SobP3holX000000P3bnL85000000030?ooo`000000000000<0<c<c00<0000003<c<`0c
<c<01P0c<c<00`000000<c<c03<c<`0703<c<`0300000015<c<0AC<c00800000401M<c<00`000000
OS<c07hc<`0607hc<`<00000202A<d800`000000[Ta20:i<@P0@0:i<@P030000003:JT`0bVY<00D0
bVY<0`0000090<9G<`030000003MOT80gGi200d0gGi20P0000030=A_<`030000003[W4D0jia500H0
jia500<000000>2?<`3PSc<01`3PSc<200000080gZdn0P0000020?oooa000000>@3oool001<0oooo
1`00000308J;e@8000000P2WYO/500000080fOSo00<000000?_on`0000000`3koo/;000000030=Cn
e0000000000000D000000`0c<c<00`000000<c<c03<c<`0503<c<`030000000c<c<0<c<c00T0<c<c
0P00000C05dc<`040000001n<c<0OS<c07hc<`@000002`2A<d800`000000[Ta20:i<@P0@0:i<@P03
0000003:JT`0bVY<00P0bVY<0`0000050<9G<`030000003MOT80gGi20100gGi200<000000=A_<`00
00002P3[W4D00`000000h8lc0>2?<`060>2?<`8000000P3N[Ch00`000000c9dc0000000600000003
07NGj@000000000000L00000>P3oool001@0oooo0P0000001@1<J/X0000006Ukd01YNm0000000080
QX_E0P000000202WYO/000000:nbo`000000^/;o00000037fOl000000P3In?l2000000<0nook00D0
00000>Woj@3YonT0jOoY000000020>?oh`030000003Momd0gOoM00T000000P0c<c<00`000000<c<c
0000000603<c<`030000000c<c<0<c<c00T0<c<c00<0000005dc<`1M<c<04P1M<c<4000000l0TC=2
00<000000:i<@P2^C480402^C4800`000000bVY<0<YZC00;0<YZC0@0000000<0`ULc0000003MOT80
4P3MOT82000000/0jia500<000000>2?<`3PSc<01@3PSc<200000080gZdn00<000000<bM<`000000
3`00000k0?ooo`00503oool30000000404aZbP000000JG_@06Ukd08000000P2@Wo/400000080^/;o
00@000000<OIo`00000000000P3Eool3000000<0jOoY00@000000>?oh`3Son<000000P3Momd00`00
0000e?kD000000050000000703<c<`000000<c<c03<c<`000000<c<c0000000503<c<`030000000c
<c<0<c<c00T0<c<c00<00000048c@P0000004P1M<c<200000180TC=200<000000:i<@P2^C480402^
C4800`000000bVY<0<YZC00?0<YZC08000004`3MOT800`000000lZIM0000000;0>^LA@030000003P
Sc<0h8lc00<0h8lc00<000000>fjE00000000`3N[ChA000003/0oooo000E0?ooo`<0000000@0C6[:
000000000000MiOY0P000000102@Wo/0000009jco`2N/ol5000000040<7jo`000000eOoo0=Goo`H0
00000P3Son<01@000000gOoM0=gog@000000e?kD00P000000`0c<c<010000000<c<c03<c<`000003
03<c<`030000000c<c<0<c<c00T0<c<c00@00000048c@P12<d800000401M<c<200000080MC=<00<0
0000094c@P2A<d803`2A<d800`000000[Ta20:i<@P0?0:i<@P030000003:JT`0bVY<0100bVY<00@0
00000>><G@00000000004@3MOT800`000000lZIM0000000;0>^LA@030000003PSc<0h8lc00<0h8lc
00<000000>fjE00000000`3N[Ch2000000030?ooo`000000000000/00000?03oool001H0oooo0`00
00000`1MS><000000000000207NGj@8000000P2N/ol010000000[l[o0:o:o`0000030<7jo`800000
103@oolA00000080<c<c00D0000003<c<`0c<c<0<c<c0000000203<c<`030000000c<c<0<c<c00T0
<c<c00<00000048c@P12<d800P12<d800`000000GC<c05dc<`0<05dc<`030000001e<d`0MC=<0080
MC=<00<00000094c@P2A<d803`2A<d800`000000[Ta20:i<@P0?0:i<@P030000003:JT`0bVY<0100
bVY<00D000000>><G@3SS5d0hhaM0000000?0=en@P050000003bYUd0lZIM0?:VG@0000002`3[W4D0
0`000000h8lc0>2?<`020>2?<`040000003]^U@0kKYD00000080gZdn00<000000<bM<`0000002`00
000n0?ooo`00603oool30000000505f<h`000000MiOY0000002;/_l0300000000`3@ool000000000
00020<[on080000000<0`_Wb000000000000200000001@0c<c<0000003<c<`0c<c<0000000<0<c<c
00@0000003<c<`0c<c<000002`0c<c<00`000000@S=2048c@P02048c@P030000001M<c<0GC<c00X0
GC<c0P00000507DcC0030000002A<d80TC=20100TC=200<000000:i<@P2^C4803P2^C4800`000000
bVY<0<YZC00@0<YZC0030000003SS5d0hhaM0080hhaM0P00000=0=en@P030000003bYUd0lZIM0080
lZIM00<000000>^LA@3[W4D02@3[W4D010000000h8lc0>2?<`0000030>fjE0040000003N[Ch0gZdn
0=j]?Ph00000?@3oool001X0oooo1P00000208^bo`030000002Qbol0XL_o0080XL_o00@000000;Wb
o`2il_l0^O;o0`0000020<[on00300000032nO80000000`000000`0c<c<00`000000<c<c03<c<`02
03<c<`8000002`0c<c<00`000000@S=2048c@P04048c@P030000001M<c<0GC<c00P0GC<c00<00000
07DcC01e<d`01P1e<d`00`000000TC=2094c@P0?094c@P030000002^C480[Ta200h0[Ta200<00000
0<YZC03:JT`03`3:JT`00`000000hhaM0>><G@050>><G@030000003MOT80gGi200T0gGi200<00000
0?:VG@3bYUd0103bYUd00`000000jia50>^LA@090>^LA@030000003PSc<0000000<0kKYD00@00000
0=j]?P3N[Ch0gZdn3@00000n0?ooo`006`3oool40000000307F]n0000000000000T000000P2^iol8
0000000309@c<`000000000000L000000`0c<c<00`000000<c<c03<c<`0203<c<`030000000c<c<0
<c<c00T0<c<c00<00000048c@P12<d801P12<d800`000000GC<c05dc<`0505dc<`8000002@1e<d`0
0`000000TC=2094c@P0?094c@P030000002^C480[Ta200h0[Ta200<000000<YZC03:JT`03`3:JT`0
0`000000hhaM0>><G@060>><G@8000002@3MOT800`000000lZIM0?:VG@040?:VG@030000003[W4D0
jia500T0jia50P0000050>fjE0030000003N[Ch0gZdn00d00000?P3oool001d0oooo1`000004097<
o`030000002^iol0000000T0000000@0YS<c000000000000]dhc1`00000203<c<`030000000c<c<0
<c<c00<0<c<c0P00000903<c<`0300000012<d80@S=200L0@S=200<0000005dc<`1M<c<0101M<c<0
0`000000MC=<07DcC00907DcC0030000002A<d80TC=200l0TC=200<000000:i<@P2^C4803P2^C480
0`000000bVY<0<YZC00>0<YZC0030000003SS5d0hhaM00T0hhaM00<000000=en@P3MOT801@3MOT80
0`000000lZIM0?:VG@060?:VG@030000003[W4D0jia500T0jia500<000000>fjE03]^U@00`3]^U@0
0`000000gZdn0=j]?P0=000003h0oooo000Q0?oooa0000000P2@<c<<00000080<c<c00<0000003<c
<`0c<c<00`0c<c<2000000P0<c<c00<00000048c@P12<d802@12<d8010000000GC<c05dc<`1M<c<2
000000d0MC=<00<00000094c@P2A<d803P2A<d800`000000[Ta20:i<@P0>0:i<@P030000003:JT`0
bVY<00h0bVY<00<000000>><G@3SS5d02P3SS5d2000000D0gGi200<000000?:VG@3bYUd01`3bYUd0
0`000000jia50>^LA@070>^LA@8000001@3]^U@010000000gZdn0=j]?P3N[Ch;000003l0oooo000R
0?oooa<0000000H0]D<c000000000000b5lc0000003AP3<3000000<0<c<c00<0000003<c<`0c<c<0
0P0c<c<010000000<c=503<cA@00000703<c<`0300000012<d80@S=200T0@S=200@0000005dc<`00
000000003`1e<d`00`000000TC=2094c@P0=094c@Q<00000403:JT`00`000000hhaM0>><G@0<0>><
G@8000000P3MOT800`000000lZIM0?:VG@090?:VG@030000003[W4D0jia500H0jia500<000000?O3
JP000000103]^U@010000000gZdn0=j]?P3N[Ch:00000400oooo000R0?ooo`X0000000@0AC<c0000
00000000OS<c0`0000020<9G<`80000000<0e6lc0000003PSc<01000000203<c<`030000000c<c<0
<c<c00<0<c<c00D0000003<cA@0c<dD0<c=50000000503<c<`0300000012<d80@S=200/0@S=200<0
000007DcC01e<d`0401e<d`00`000000TC=2094c@P08094c@P@0000000<0XE1R0000002iHf803P2i
Hf800`000000d7]Y00000003000000/0bVY<00<000000>><G@3SS5d03`3SS5d2000000d0lZIM00<0
00000>^LA@3[W4D0103[W4D010000000ml=Z0?O3JP0000050>fjE0030000003N[Ch0gZdn00T00000
@@3oool002<0oooo200000000`0c<c<0000005dc<`03000000030:i<@P00000000000080000000D0
gGi200000000000000000>2?<`0300000080<c<c00<0000003<c<`0c<c<00`0c<c<01@000000<c=5
03<cA@0c<dD0000000@0<c<c00<00000048c@P12<d802`12<d8200000180MC=<00<00000094c@P2A
<d801@2A<d83000000D0XE1R00<000000;USHP2iHf803@2iHf800`000000d7]Y0=1kJ@030=1kJ@<0
0000203:JT`00`000000hhaM0>><G@0@0>><G@030000003bYUd0lZIM00/0lZIM00<000000>^LA@3[
W4D00`3[W4D01@000000ml=Z0?O3JP3g`fX0000000D0kKYD00@000000=j]?P3N[Ch0gZdn1`000012
0?ooo`009@3oool@000000050>><G@00000000000000003[W4D01000000203<c<`030000000c<c<0
<c<c0080<c<c00<0000003<cA@0c<dD00`0c<dD010000000<c<c03<c<`00000=048c@P040000001M
<ed0GC=M00000140MC=<00@00000094c@P2A<d80TC=2100000090:5@HP030000002iHf80^F=R00`0
^F=R00<000000=1kJ@3@NfT01P3@NfT4000000@0bVY<00<000000>><G@3SS5d03`3SS5d00`000000
n:ee0000000=0?:VG@030000003[W4D0jia50080jia500<000000?O3JP3g`fX00P3g`fX00`000000
kKYD0>fjE0020>fjE0040000003N[Ch0gZdn0=j]?PL00000@P3oool002H0oooo1@0000000`12<d80
000000000003000000030;USHP000000d7]Y00@0000000<0lZIM0000003g`fX00`0000000`0c<c<0
000003<c<`0403<c<`030000000c<dD0<c=500<0<c=500<0000003<c<`0000003P12<d801@000000
GC=M05dcG@1M<ed000000140MC=<0`00000=0:5@HP030000002iHf80^F=R00`0^F=R00<000000=1k
J@3@NfT02P3@NfT400000180hhaM00@000000?R]M@3h[GD000003@3bYUd010000000jia50>^LA@00
00050?O3JP030000003]^U@0kKYD00<0kKYD00<000000=j]?P0000001`0000120?ooo`009`3oool5
0000000305dcG@000000Rd=Y00P0000000<0n:ee0000003mbGh0100000000`0c<c<0000003<c<`04
03<c<`030000000c<dD0<c=500@0<c=50P00000=048c@P030000001M<ed0GC=M0080GC=M00<00000
07DcC01e<d`03@1e<d`3000000l0XE1R00<000000;USHP2iHf80302iHf800`000000d7]Y0=1kJ@0=
0=1kJ@800000403SS5d00`000000n:ee0?R]M@020?R]M@030000003bYUd0lZIM00/0lZIM0P000006
0?O3JP030000003]^U@0kKYD00<0kKYD00<000000=j]?P0000001`0000120?ooo`00:@3oool40000
000307LoM`000000WV:600@0000000D0nin@0000003o/X/000000?o<T@07000000@0<c<c00<00000
03<cA@0c<dD01@0c<dD2000000`0@S=200<0000005dcG@1M<ed0101M<ed00`000000MC=<07DcC00;
07DcC0040000002;@fT0Rd=Y000000l0XE1R00<000000;USHP2iHf80302iHf800`000000d7]Y0=1k
J@0<0=1kJ@040000003YUgL0jIMg000000h0hhaM00<000000?R]M@3h[GD00`3h[GD00`000000lZIM
0?:VG@0;0?:VG@8000001P3g`fX00`000000kKYD0>fjE0030>fjE0040000003N[Ch000000?ooo`D0
0000@`3oool002T0oooo3P0000000`3obj40000000000006000000@0<c<c00<0000003<cA@0c<dD0
1@0c<dD00`000000<c=M0000000:048c@P030000001M<ed0GC=M00H0GC=M00<0000007DcC01e<d`0
201e<d`2000000@0Rd=Y00<000000:5@HP2QD680302QD6800`000000^F=R0;USHP0<0;USHP030000
003@NfT0d7]Y00`0d7]Y00@000000>VGM`3YUgL0jIMg0P00000<0>><G@030000003h[GD0n:ee00@0
n:ee00<000000?:VG@3bYUd02P3bYUd2000000L0ml=Z00<000000>fjE03]^U@00P3]^U@00`000000
gZdn000000190?ooo`00:P3oool;000000030?o:[`000000000000L000001@0c<c<00`000000<c=5
03<cA@0503<cA@030000000c<ed0000000T0@S=200<0000005dcG@1M<ed01`1M<ed00`000000MC=<
07DcC00607DcC08000001P2;@fT00`000000XE1R0:5@HP0<0:5@HP030000002iHf80^F=R00/0^F=R
00<000000=1kJ@3@NfT03@3@NfT00`000000jIMg0>VGM`030>VGM`8000002@3SS5d00`000000n:ee
0?R]M@060?R]M@030000003bYUd0lZIM00P0lZIM00<000000?g9OP0000001`3g`fX00`000000kKYD
0>fjE0030>fjE0800000B@3oool002X0oooo1`0000020<RYb0`000001@0c<c<00`000000<c=503<c
A@0403<cA@050000000c<ed0<c=M03<cG@0000002012<d800`000000GC=M05dcG@0805dcG@030000
001e<d`0MC=<00@0MC=<00<0000008]3J@2;@fT01`2;@fT00`000000XE1R0:5@HP0;0:5@HP030000
002iHf80^F=R00/0^F=R00<000000=1kJ@3@NfT0303@NfT00`000000jIMg0>VGM`060>VGM`030000
003SS5d0hhaM00D0hhaM00<000000?R]M@3h[GD0203h[GD00`000000lZIM0?:VG@060?:VG@040000
003mbGh0oLUn000000L0ml=Z00<000000>fjE03]^U@00`3]^U@2000004T0oooo000[0?ooo`H00000
0P38ZLP4000000030?ood0000000000000H000000`0c<c<00`000000<c=503<cA@0503<cA@030000
000c<ed0<c=M0080<c=M00<00000048c@P12<d801012<d800`000000GC=M05dcG@0905dcG@030000
001e<d`0MC=<0080MC=<0P00000:08]3J@030000002QD680XE1R00/0XE1R00<000000;USHP2iHf80
2`2iHf800`000000d7]Y0=1kJ@0<0=1kJ@030000003YUgL0jIMg00L0jIMg0P0000050>><G@030000
003h[GD0n:ee00P0n:ee00<000000?:VG@3bYUd01P3bYUd01@000000oLUn0?g9OP3mbGh0000000L0
ml=Z00<000000>fjE03]^U@00P3]^U@2000004T0oooo000/0?oooa@000000`0c<c<00`000000<c=5
03<cA@0503<cA@030000000c<ed0<c=M00<0<c=M00<00000048c@P12<d800P12<d800`000000GC=M
05dcG@0;05dcG@040000001e<d`0MC=<000000`0Rd=Y00<000000:5@HP2QD680302QD6800`000000
^F=R0;USHP0:0;USHP030000003@NfT0d7]Y00/0d7]Y00<000000>VGM`3YUgL02P3YUgL01@000000
hhaM0>><G@3SS5d0000000`0n:ee00<000000?:VG@3bYUd0103bYUd00`000000oLUn0?g9OP020?g9
OP030000003g`fX0ml=Z00D0ml=Z00@000000>fjE03]^U@0kKYD0`0000190?ooo`00;@3ooolD0000
0080<c<c00<0000003<cA@0c<dD0100c<dD00`000000<c=M03<cG@0503<cG@0400000012<d80@S=2
000000l0GC=M0P00000>08]3J@030000002QD680XE1R00/0XE1R00<000000;USHP2iHf802P2iHf80
0`000000d7]Y0=1kJ@0;0=1kJ@030000003YUgL0jIMg00/0jIMg0`00000>0?R]M@030000003bYUd0
lZIM0080lZIM00<000000?g9OP3mbGh00`3mbGh00`000000ml=Z0?O3JP050?O3JP040000003]^U@0
kKYD0>fjE0<00000B@3oool002h0oooo4`0000000`0c<c<0000003<cA@0603<cA@030000000c<ed0
<c=M00D0<c=M00<00000048c@P0000003`1M<ed2000000l0Rd=Y00<000000:5@HP2QD6802`2QD680
0`000000^F=R0;USHP0:0;USHP030000003@NfT0d7]Y00X0d7]Y00<000000>VGM`3YUgL03P3YUgL0
0`000000n:ee0?R]M@0=0?R]M@040000003bYUd0lZIM000000L0oLUn00<000000?O3JP3g`fX0103g
`fX01@000000kKYD0>fjE0000000kMan00800000B@3oool00300oooo400000000`0c<e@000000000
000703<cA@030000000c<ed0<c=M00H0<c=M0P00000>05dcG@040000001g?gL0Mcmg000000l0Rd=Y
00<000000:5@HP2QD680202QD68A000000/0d7]Y00<000000>VGM`3YUgL03@3YUgL00`000000ok:;
0000000?0?R]M@800000203mbGh00`000000ml=Z0?O3JP050?O3JP040000003]^U@000000>gLOP80
0000B@3oool00340oooo3`0000000`0c<e@000000000000603<cA@030000000c<ed0<c=M00L0<c=M
0P00000>05dcG@050000001g?gL0Mcmg07LoM`0000003P2;@fT00`000000XE1R0:5@HP050:5@HP<0
00000P2_Jh000`000000`GV00<5iP0090<5iP0030000003ERhH0eH^600<00000203@NfT00`000000
jIMg0>VGM`0<0>VGM`050000003o/X/0ok:;0?nbR`0000003P3h[GD00`000000oLUn0?g9OP070?g9
OP030000003g`fX0ml=Z00D0ml=Z0P0000020>gLOP030000003oool0oooo04P0oooo000c0?ooo`d0
00000P0c<e@00`000000<c=503<cA@0403<cA@030000000c<ed0<c=M00L0<c=M00<0000004`cM@00
0000301M<ed00`000000Mcmg07LoM`0307LoM`030000002;@fT0Rd=Y00`0Rd=Y00<000000:5@HP2Q
D680100000050:m[P00300000031NH00`GV000T0`GV000<000000=F;QP3ERhH00`3ERhH4000000<0
d7]Y00<000000>VGM`3YUgL0303YUgL00`000000ok:;0?nbR`020?nbR`030000003h[GD0n:ee00/0
n:ee00<000000?o<T@0000002@3mbGh00`000000ml=Z0?O3JP040?O3JP80000000<0kMan00000000
0000BP3oool003D0oooo2`00000203<cE08000001@0c<dD00`000000<c=M03<cG@0603<cG@050000
001<<gD0C3=e04`cM@0000002P1M<ed00`000000Mcmg07LoM`0407LoM`030000002;@fT0Rd=Y00`0
Rd=Y0`0000090:m[P00300000031NH00`GV000T0`GV000<000000=F;QP3ERhH01`3ERhH4000000h0
jIMg00<000000?nbR`3o/X/00`3o/X/00`000000n:ee0?R]M@090?R]M@040000003oc940olbA0000
00T0oLUn00<000000?O3JP3g`fX0103g`fX00`000000kMan0>gLOP02000004X0oooo000e0?ooo`/0
00000P0c<e@00`000000<c=Z0000000303<cA@030000000c<ed0<c=M00L0<c=M00<0000004`cM@1<
<gD00P1<<gD00`000000GC=M05dcG@0605dcG@030000001g?gL0Mcmg00H0Mcmg00<0000008]3J@2;
@fT02@2;@fT3000000`0[f^000<000000<5iP031NH002031NH000`000000eH^60=F;QP090=F;QP<0
0000303YUgL00`000000ok:;0?nbR`050?nbR`030000003h[GD0n:ee00L0n:ee00D000000?o<T@3o
c940olbA000000090?g9OP030000003g`fX0ml=Z00<0ml=Z0P0000020>gLOP800000BP3oool003D0
oooo100000000`38ZLP000000000000400000080<c=D00<0000003<cJP0000000`0c<dD00`000000
<c=M03<cG@0703<cG@030000001<<gD0C3=e00<0C3=e00<0000005dcG@1M<ed0101M<ed00`000000
Mcmg07LoM`0807LoM`030000002;@fT0Rd=Y00L0Rd=Y00D0000009iRQP2NHXH0WV:60000000;0:m[
P00300000031NH00`GV000P0`GV000<000000=F;QP3ERhH02@3ERhH010000000nin@0?^OT000000:
0>VGM`030000003o/X/0ok:;00L0ok:;00<000000?R]M@3h[GD01@3h[GD00`000000olbA0?o<T@03
0?o<T@030000003mbGh0oLUn00H0oLUn00<000000?O3JP3g`fX00P3g`fX00`000000mn>@00000002
0>gLOP800000BP3oool003H0oooo2P00000203<cE0040000000c<fX0<c=Z00000080<c=500<00000
03<cG@0c<ed01`0c<ed00`000000C3=e04`cM@0404`cM@030000001M<ed0GC=M00<0GC=M00<00000
07LoM`1g?gL02@1g?gL00`000000Rd=Y08]3J@0408]3J@800000102NHXH00`000000[f^00:m[P009
0:m[P00300000031NH00`GV000P0`GV000<000000=F;QP3ERhH0203ERhH00`000000nin@0?^OT002
0?^OT08000001`3YUgL00`000000ok:;0?nbR`090?nbR`030000003h[GD0n:ee00<0n:ee00<00000
0?o<T@3oc940103oc9400`000000oLUn0?g9OP070?g9OP040000003g`fX0ml=Z00000080mn>@00<0
00000>gLOP3]g7h00P00001:0?ooo`00=`3oool900000080<c=D00L0000003<cJP0c<fX0<c=Z0000
000c<dD0000000P0<c=M00<0000004`cM@1<<gD01P1<<gD01@000000GC=M05dcG@1M<ed0000000`0
Mcmg00<0000008]3J@2;@fT00P2;@fT2000000L0WV:600<000000:m[P02_Jh00202_Jh000`000000
`GV00<5iP0080<5iP0030000003ERhH0eH^600P0eH^600<000000?^OT03kWi00103kWi02000000@0
jIMg00<000000?nbR`3o/X/02P3o/X/00`000000n:ee0?R]M@020?R]M@030000003oc940olbA00D0
olbA00<000000?g9OP3mbGh01`3mbGh010000000ml=Z0?O3JP0000020?OST0030000003]g7h0kMan
00800000BP3oool003T0oooo1`00000203<cE0030000000c<fX0<c=Z0080<c=Z00<0000003<cG@0c
<ed01`0c<ed00`000000C3=e04`cM@0704`cM@030000001M<ed0000000h0Mcmg00@0000008]3J@2;
@fT000002@2NHXH00`000000[f^00:m[P0080:m[P00300000031NH00`GV000L0`GV000<000000=F;
QP3ERhH0203ERhH00`000000nin@0?^OT0070?^OT0050000003YUgL0jIMg0>VGM`0000003@3o/X/0
10000000n:ee0?R]M@0000090?o<T@030000003mbGh0oLUn00H0oLUn00<000000?O3JP0000000`3g
hi000`000000kMan0>gLOP02000004X0oooo000k0?ooo`H0000000<0<c=D0000000c<fX00`0c<fX2
000000P0<c=M00<0000004`cM@1<<gD0201<<gD00`000000Mcmg07LoM`0>07LoM`8000002`2NHXH0
0`000000[f^00:m[P0070:m[P00300000031NH00`GV000L0`GV000<000000=F;QP3ERhH0203ERhH0
0`000000nin@0?^OT0080?^OT0<000003`3o/X/2000000X0olbA00<000000?g9OP3mbGh01`3mbGh0
0`000000mn>@0?OST0020?OST0030000003]g7h0kMan00800000BP3oool003/0oooo1P0000000`0c
<e@0000003<cJP0303<cJP030000000c<gh0000000H0<c=M00<0000004`cM@1<<gD02@1<<gD20000
00h0Mcmg00<00000091OT00000002`2NHXH00`000000[f^00:m[P0070:m[P00300000031NH00`GV0
00L0`GV000<000000=F;QP3ERhH01`3ERhH00`000000nin@0?^OT00:0?^OT08000003`3o/X/20000
00X0olbA00<000000?g9OP3mbGh01P3mbGh2000000@0mn>@00@000000>gLOP3]g7h00000B`3oool0
03`0oooo1@0000000`0c<e@0000003<cJP0303<cJP040000000c<gh0<c=n000000D0<c=M00<00000
04`cM@1<<gD0201<<gD010000000JD>;06U3R`00000=07LoM`040000002@Gi00T5n@000000/0WV:6
00<000000:m[P02_Jh001`2_Jh000`000000`GV00<5iP0060<5iP0030000003ERhH0eH^600L0eH^6
00<000000?^OT03kWi002@3kWi0010000000ok>N0?ncWP00000=0?nbR`030000003obj40000000/0
olbA00<000000?g9OP3mbGh0103mbGh00`000000oNFQ000000040?OST0040000003]g7h0kMan0000
04/0oooo000m0?ooo`@000000P0c<e@01@000000<c=Z03<cJP0c<fX0000000<0<c=n00<0000003<c
G@0c<ed00P0c<ed00`000000C3=e04`cM@0804`cM@040000001Y@h/0JD>;06U3R`8000002P1g?gL0
1@000000T5n@091OT02@Gi00000000/0WV:600<000000:m[P02_Jh001`2_Jh000`000000`GV00<5i
P0060<5iP0030000003ERhH0eH^600H0eH^600<000000?^OT03kWi002@3kWi001@000000ok>N0?nc
WP3o/ih0000000`0ok:;00@000000?o;X@3obj4000002`3oc9400`000000oLUn0?g9OP030?g9OP04
0000003miJ40oNFQ000000@0mn>@00@000000>gLOP0000000000B`3oool00400oooo00@0000003<c
E00c<e@00000100c<fX01@000000<c=n03<cOP0c<gh000000080<c=M00<0000004`cM@1<<gD02@1<
<gD00`000000JD>;06U3R`0306U3R`030000001g?gL0Mcmg00H0Mcmg00<00000091OT02@Gi000`2@
Gi000`000000WV:609iRQP0909iRQP030000002_Jh00[f^000H0[f^000<000000<5iP031NH001P31
NH000`000000eH^60=F;QP060=F;QP030000003kWi00nin@00P0nin@00<000000?ncWP3o/ih00`3o
/ih00`000000ok:;0?nbR`070?nbR`800000103obj400`000000olbA0?o<T@080?o<T@040000003m
bGh0oLUn0?g9OP8000000P3miJ400`000000mn>@0?OST0020?OST0030000003]g7h0kMan00800000
B`3oool00400oooo00@0000003<cE00c<e@00000100c<fX00`000000<c=n03<cOP0203<cOP030000
000c<ed0000000X0C3=e00<0000006U3R`1Y@h/01@1Y@h/00`000000Mcmg07LoM`0407LoM`030000
002@Gi00T5n@00D0T5n@00<0000009iRQP2NHXH0202NHXH00`000000[f^00:m[P0030:m[P0l00000
1@3ERhH00`000000nin@0?^OT0090?^OT0030000003o/ih0ok>N00@0ok>N00<000000?nbR`3o/X/0
1@3o/X/00`000000ol^Q0?o;X@040?o;X@030000003oc940olbA00T0olbA00<000000?g9OP000000
103miJ400`000000mn>@0?OST0020?OST0040000003]g7h0kMan000004`0oooo00100?ooo`040000
000c<e@0<c=D000000@0<c=Z00<0000003<cOP0c<gh00`0c<gh2000000X0C3=e00<0000006U3R`1Y
@h/01P1Y@h/00`000000Mcmg07LoM`0207LoM`030000002@Gi00T5n@00L0T5n@00<0000009iRQP2N
HXH0202NHXH5000000<0^XFM00<000000<N>W@37SYd01@37SYd010000000fIVP0=VIX03IVJ040000
00030=F;QP000000nin@00T0nin@00<000000?ncWP3o/ih01P3o/ih00`000000ok:;0?nbR`030?nb
R`030000003obj40ol^Q00D0ol^Q00<000000?o<T@3oc9402@3oc942000000D0oNFQ00<000000?OS
T03ghi000P3ghi0010000000kMan0>gLOP00001<0?ooo`00@@3oool00`000000<c=D0000000403<c
JP030000000c<gh0<c=n00@0<c=n0P00000904`cM@030000001Y@h/0JD>;00L0JD>;00@0000007Lo
M`1g?gL000002`2@Gi000`000000WV:609iRQP0609iRQP8000001`2jQId00`000000ahjM0<N>W@05
0<N>W@030000003IVJ00fIVP00D0fIVP0P0000090?^OT0030000003o/ih0ok>N00P0ok>N00D00000
0?nbR`3o/X/0ok:;000000090?o;X@030000003oc940olbA00P0olbA00<000000?gUX@3miJ40103m
iJ400`000000mn>@0?OST0020?OST0040000003]g7h0kMan000004`0oooo00110?ooo`<00000100c
<fX00`000000<c=n03<cOP0403<cOP0400000012<i400000000000H0C3=e00<0000006U3R`1Y@h/0
2@1Y@h/2000000d0T5n@00<0000009iRQP2NHXH00`2NHXH200000080[h2P00<000000;Z5W@2jQId0
1@2jQId00`000000ahjM0<N>W@040<N>W@030000003IVJ00fIVP00D0fIVP00@000000?^UY`000000
00001P3kWi000`000000ok>N0?ncWP0:0?ncWP<000002P3obj400`000000olbA0?o<T@060?o<T@<0
00001P3miJ400`000000mn>@0?OST0020?OST0030000003]g7h0000004d0oooo00120?ooo`800000
100c<fX00`000000<c=n03<cOP0403<cOP0500000012<i40@S>A048cT@0000001@1<<gD00`000000
JD>;06U3R`0:06U3R`8000003@2@Gi001@000000WV:609iRQP2NHXH0000000@0[h2P00<000000;Z5
W@2jQId01@2jQId00`000000ahjM0<N>W@040<N>W@030000003IVJ00fIVP00@0fIVP00<000000?^U
Y`3kYJL00P3kYJL2000000<0nin@00<000000?ncWP3o/ih02`3o/ih00`000000ol^Q0?o;X@0:0?o;
X@030000003oc940olbA00D0olbA00@000000?oW[P3oijh000001P3miJ400`000000mn>@0?OST002
0?OST0<00000C@3oool00480oooo0P00000403<cJP030000000c<gh0<c=n00@0<c=n00<00000048c
T@12<i400P12<i42000000<0C3=e00<0000006U3R`1Y@h/02P1Y@h/00`000000QV:N0000000<091O
T0040000002NHXH00000000000H0[h2P00<000000;Z5W@2jQId0102jQId00`000000ahjM0<N>W@04
0<N>W@030000003IVJ00fIVP00@0fIVP00<000000?^UY`3kYJL0103kYJL00`000000nin@0000000=
0?ncWP030000003obZl0000000`0ol^Q00<000000?o<T@3oc9400P3oc942000000<0onN^00<00000
0?gUX@3miJ40103miJ400`000000mn>@0?OST0020?OST0800000CP3oool004<0oooo00<0000003<c
JP0c<fX00P0c<fX00`000000<c=n03<cOP0403<cOP0300000012<i40@S>A00@0@S>A00<0000004`c
M@000000301Y@h/010000000QV:N08IRWP26HYh2000000/0T5n@00<000000:n0X02_P:001P2_P:00
0`000000^XFM0;Z5W@040;Z5W@0300000037SYd0ahjM00<0ahjM00<000000=VIX03IVJ00103IVJ00
0`000000njFW0?^UY`060?^UY`030000003o/ih0ok>N00X0ok>N0P0000020?o:[`030000003obj40
ol^Q00X0ol^Q00D000000?o<T@3oc940olbA000000050?oW[P030000003miJ40oNFQ00@0oNFQ00<0
00000?OST03ghi000P3ghi02000004h0oooo00130?ooo`8000000`0c<fX00`000000<c=n03<cOP04
03<cOP0300000012<i40@S>A00D0@S>A0P00000<06U3R`0300000026HYh0QV:N00<0QV:N00<00000
091OT02@Gi001`2@Gi000`000000YgjW000000080:n0X0030000002jQId0^XFM00<0^XFM00<00000
0<N>W@37SYd00`37SYd00`000000fIVP0=VIX0040=VIX0030000003kYJL0njFW00D0njFW00<00000
0?nb[`0000002P3o/ih00`000000olZ_0?o:[`020?o:[`030000003obj40ol^Q00X0ol^Q00@00000
0?o<T@00000000001P3oijh00`000000oNFQ0?gUX@040?gUX@030000003ghi00mn>@0080mn>@00<0
00000?ooo`3oool0C@3oool004@0oooo0P00000203<cJP030000000c<gh0<c=n00@0<c=n00<00000
048cT@12<i401P12<i42000000X0JD>;00<0000008IRWP26HYh01@26HYh2000000H0T5n@00D00000
0:MnY`2WOZL0YgjW000000070:n0X0030000002jQId0^XFM00<0^XFM00<000000<N>W@37SYd00`37
SYd00`000000fIVP0=VIX0030=VIX0030000003kYJL0njFW00D0njFW00D000000?nb[`3o/Zl0ok:_
000000070?ncWP8000001P3obZl00`000000ol^Q0?o;X@090?o;X@800000203oijh00`000000oNFQ
0?gUX@040?gUX@040000003ghi00mn>@0?OST0800000C`3oool004@0oooo0`0000000`0c<fX00000
03<cOP0503<cOP0300000012<i40@S>A00H0@S>A00@00000069@X@0000000000201Y@h/00`000000
QV:N08IRWP0708IRWP030000002@Gi00T5n@0080T5n@00<000000:MnY`2WOZL00`2WOZL00`000000
[h2P0:n0X0050:n0X0030000002jQId0^XFM0080^XFM00<000000<N>W@37SYd00`37SYd00`000000
fIVP0=VIX0030=VIX0030000003kYJL0njFW00@0njFW00<000000?nb[`3o/Zl00`3o/Zl00`000000
ok>N0?ncWP030?ncWP030000003obZl0olZ_00H0olZ_00<000000?o;X@3obj401`3obj4200000003
0?ob^@000000onN^00L0onN^00<000000?gUX@3miJ40103miJ400`000000mn>@0?OST00200000500
oooo00150?ooo`040000000c<i000000000000H0<c=n00<00000048cT@12<i401P12<i4010000000
HU2Q069@X@1RD:42000000H0JD>;00<0000008IRWP26HYh02026HYh200000003091OT0000000YgjW
00H0YgjW00<000000:n0X02_P:00102_P:000`000000^XFM0;Z5W@030;Z5W@0300000037SYd0ahjM
0080ahjM00<000000=VIX03IVJ000P3IVJ000`000000njFW0?^UY`040?^UY`030000003o/Zl0ok:_
00D0ok:_00<000000?ncWP3o/ih00P00000:0?o:[`030000003obj40ol^Q00@0ol^Q0P0000030?ob
^@030000003oijh0onN^00D0onN^00<000000?gUX@3miJ40103miJ400`000000mn>@0?OST0030000
0500oooo00150?ooo`80000000<0<c>@0000000000001@0c<gh00`000000@S>A048cT@06048cT@03
0000001RD:40HU2Q00<0HU2Q0P00000306U3R`0300000026HYh0QV:N00/0QV:N00<000000:MnY`2W
OZL01`2WOZL00`000000[h2P0:n0X0040:n0X0030000002jQId0^XFM0080^XFM00<000000<N>W@37
SYd00P37SYd00`000000fIVP0=VIX0020=VIX0030000003kYJL0njFW00<0njFW00<000000?nb[`3o
/Zl01`3o/Zl2000000`0olZ_00<000000?o;X@3obj400P3obj42000000D0oo:i00<000000?oW[P3o
ijh01@3oijh00`000000oNFQ0?gUX@040?gUX@050000003ghi0000000>_g]@000000D@3oool004H0
oooo00<0000003<cT00c<i000P00000403<cOP0300000012<i40@S>A00H0@S>A00<00000069@X@1R
D:401@1RD:420000000306U3R`000000QV:N00`0QV:N0`0000080:MnY`030000002_P:00[h2P00<0
[h2P00<000000;Z5W@2jQId00P2jQId6000000<0fIVP00<000000?^UY`3kYJL00`3kYJL00`000000
ok:_0?nb[`070?nb[`8000003@3obZl00`000000ol^Q0?o;X@02000000H0oo:i00<000000?oW[P3o
ijh01P3oijh00`000000oNFQ0?gUX@040?gUX@80000000<0joNe000000000000D@3oool004H0oooo
0P000000100c<i00000003<dX@00000303<cOP0300000012<i40@S>A00H0@S>A00<00000069@X@1R
D:401`1RD:42000000d0QV:N00<000000:20[`2PP:l00P0000070:MnY`030000002_P:00[h2P00<0
[h2P100000060<RYb0@00000103kYJL00`000000ok:_0?nb[`060?nb[`8000000P3o`[X00`000000
olZ_0?o:[`0;0?o:[`800000203ol[T00`000000onN^0?oW[P060?oW[P030000003miJ40oNFQ00<0
oNFQ0P0000020>_g]@030000003oool0oooo0500oooo00170?ooo`050000000c<i00<c>@0000000c
=:400P00000203<cOP0300000012<i40@S>A00D0@S>A00<00000069@X@1RD:40201RD:44000000T0
QV:N00<000000:20[`2PP:l00`2PP:l00`000000YgjW0:MnY`050:MnY`030000002_P:00[h2P0080
00003@38ZLP200000080njFW00<000000?nb[`3o/Zl01@3o/Zl2000000@0ol:j00<000000?o:[`3o
bZl02@3obZl3000000T0oo:i00<000000?oW[P3oijh01P3oijh010000000oNFQ0?gUX@3miJ430000
0080joNe0P00001B0?ooo`00A`3oool20000000303<cT0000000<cBQ0080<cBQ00<0000003<cOP00
00001`12<i400`000000HU2Q069@X@08069@X@0400000020Jjl0P6^_081[[`<000001P26HYh00`00
0000X82_0:20[`040:20[`8000001P2WOZL200000140b:W80P0000070?nb[`030000003o`[X0ol:j
00@0ol:j00<000000?o:[`3obZl01P3obZl300000080oo[100<000000?ob^@3ol[T01`3ol[T00`00
0000onN^0?oW[P060?oW[P040000003miJ40oNFQ00000080l_W200@000000>_g]@3[mkD00000D`3o
ool004P0oooo00@0000003<cT00c<i0000000`0c=:42000000L0@S>A00<00000069@X@1RD:40201R
D:400`000000P6^_081[[`04081[[`8000000`26HYh00`000000X82_0:20[`070:20[`800000102W
OZL00`000000b:W80<RYb00A0<RYb0030000003o/Zl0ok:_00<0ok:_0P0000080?o2^P030000003o
bZl0olZ_0080olZ_0`0000050?oj`@030000003ol[T0oo:i00L0oo:i00<000000?oW[P3oijh01P3o
ijh3000000<0l_W200@000000>_g]@0000000000D`3oool004P0oooo0P0000000`0c<i00000003<d
X@0303<dX@<000001@12<i400`000000HU2Q069@X@08069@X@0300000020Jjl0P6^_00H0P6^_1000
000;0:20[`80000000<0YgjW00000038ZLP05038ZLP00`000000ok:_0?nb[`02000000X0ol:j00<0
00000?o:[`0000000P0000080?oj`@030000003ol[T0oo:i00L0oo:i00<000000?oW[P3oijh01@3o
ijh2000000@0l_W200@000000>_g]@3[mkD00000E03oool004T0oooo00@0000003<cT00c<i000000
100c=:400`000000@Tb^00000002000000<0@S>A00<00000069@X@1RD:401`1RD:400`000000P6^_
081[[`09081[[`<000002`2PP:l00`000000b:W80<RYb00E0<RYb08000002`3o`[X3000000X0oo[1
00<000000?ob^@3ol[T0203ol[T00`000000onN^0?oW[P030?oW[P<000001@3bnL8010000000joNe
00000000001D0?ooo`00B@3oool20000000303<cT0000000<cBQ00<0<cBQ00<00000049<[P12C:h0
0P12C:h200000003048cT@000000HU2Q00P0HU2Q00<00000081[[`20Jjl02@20Jjl00`000000WHFj
09f5^P04000000L0X82_00<000000<RYb038ZLP05P38ZLP00`000000ol:j0?o2^P060?o2^P<00000
0P3ofLL00`000000oo[10?oj`@080?oj`@030000003ol[T0oo:i00P0oo:i00<000000?oW[P3oijh0
0`0000020?SobP030000003bnL80l_W20080l_W200@000000>_g]@3[mkD00000E@3oool004X0oooo
00@0000003<cT00c<i000000100c=:400`000000@Tb^049<[P03049<[P<00000201RD:400`000000
P6^_081[[`09081[[`030000002MQKX0WHFj00@0WHFj0`0000030:20[`0300000038ZLP0b:W801L0
b:W800<000000?o2^P3o`[X00P3o`[X4000000@0omW700<000000?oj`@3on/402@3on/400`000000
oo:i0?ob^@080?ob^@<00000103holX00`000000l_W20?;i`P030?;i`P040000003[mkD000000000
05D0oooo001:0?ooo`80000000<0<c>@0000000c=:400`0c=:400`000000@Tb^049<[P04049<[P03
0000001RHkT0000000<00000101RD:400`000000P6^_081[[`09081[[`030000002MQKX0WHFj00L0
WHFj1000000I0<RYb0D00000203ofLL00`000000oo[10?oj`@090?oj`@030000003ol[T0oo:i00D0
oo:i100000060?SobP030000003bnL80l_W20080l_W200@000000>_g]@3[mkD00000EP3oool004/0
oooo00@0000003<cT00c<i0000000`0c=:400`000000@Tb^049<[P05049<[P030000001RHkT0HV>i
0080HV>i1@00000;081[[`030000002MQKX0WHFj00X0WHFj00<000000<RYb038ZLP06038ZLP00`00
0000omW70?oIa`090?oIa`030000003on/40oo[100T0oo[100@000000?ob^@3ol[T0oo:i10000002
0?ood0030000003holX0n?o:00D0n?o:00<000000?;i`P3bnL800P3bnL8010000000joNe00000000
001F0?ooo`00B`3oool20000000303<cT0000000<cBQ00<0<cBQ00<00000049<[P12C:h01012C:h0
0`000000HV>i069S^@06069S^@H000001P20Jjl00`000000WHFj09f5^P0:09f5^P0300000038ZLP0
b:W801P0b:W800<000000?oIa`3ofLL02@3ofLL00`000000oo[10?oj`@080?oj`@D000001P3oom00
0`000000n?o:0?SobP040?SobP030000003bnL80l_W20080l_W200@000000>_g]@3[mkD00000E`3o
ool004`0oooo0P0000000`0c<i00000003<dX@0203<dX@0300000012C:h0@Tb^00D0@Tb^00<00000
069S^@1RHkT01P1RHkT00`000000P7W1081i`@02081i`@/00000202MQKX00`000000b:W80<RYb00G
0<RYb0030000003ofLL0omW700X0omW700<000000?oj`@3on/40200000000`3oomD000000?ood007
0?ood0030000003holX0n?o:00D0n?o:00<000000?;i`P3bnL800P3bnL800`000000joNe0000001H
0?ooo`00C@3oool3000000@0<cBQ00<00000049<[P12C:h01012C:h00`000000HV>i069S^@06069S
^@0300000020NL40P7W100P0P7W100@0000009f>a`2MS/L0WHk72P00000I0<RYb1000000203oomD0
0`000000ooo@0?ood0070?ood0030000003holX0n?o:00@0n?o:00<000000?;i`P3bnL800P3bnL80
0`000000joNe0000001I0?ooo`00CP3oool3000000<0<cBQ00<00000049<[P12C:h01012C:h00`00
0000HV>i069S^@07069S^@0300000020NL40P7W100P0P7W100<0000009f>a`2MS/L02@2MS/L00`00
0000b:W80<RYb00G0<RYb0030000003on=T0ooSI00X0ooSI00<000000?ooe@3oomD0203oomD00`00
0000ooo@0?ood0060?ood0030000003holX0n?o:00D0n?o:00<000000?;i`P3bnL800P3bnL820000
05X0oooo001?0?ooo`800000100c=:400`000000@Tb^049<[P04049<[P030000001RHkT0HV>i00H0
HV>i00<00000081i`@20NL402020NL400`000000WHk709f>a`0:09f>a`0300000038ZLP0b:W801H0
b:W800<000000?ohf@3on=T02@3on=T00`000000oooE0?ooe@090?ooe@030000003oom00ooo@00H0
ooo@00<000000?SobP3holX0103holX00`000000l_W20?;i`P020?;i`P800000F`3oool00500oooo
0`00000203<dX@0300000012C:h0@Tb^00@0@Tb^00<00000069S^@1RHkT01`1RHkT00`000000P7W1
081i`@08081i`@030000002MS/L0WHk700L0WHk70`00000G0<RYb08000002`3on=T00`000000oooE
0?ooe@080?ooe@030000003oom00ooo@00H0ooo@00<000000?SobP3holX01@3holX010000000l_W2
0?;i`P3bnL82000005`0oooo001A0?ooo`H000001P12C:h00`000000HV>i069S^@06069S^@030000
0020NL40P7W100P0P7W100<0000009f>a`2MS/L00`2MS/L4000000<0X9WI00<000000<RYb038ZLP0
4`38ZLP00`000000nook0?_on`04000000H0ooSI00<000000?ooe@3oomD02@3oomD00`000000ooo@
0?ood0060?ood0030000003holX0n?o:00@0n?o:00<000000?;i`P3bnL800`00001M0?ooo`00DP3o
ool200000080<eO20`000004049<[P030000001RHkT0HV>i00H0HV>i00<00000081i`@20NL402@20
NL45000000P0X9WI00<000000<RYb038ZLP04@38ZLP00`000000nook0?_on`050?_on`@000000P3o
n=T00`000000oooE0?ooe@080?ooe@030000003oom00ooo@00H0ooo@00<000000?SobP3holX01@3h
olX3000000030=gog@000000oooo05d0oooo001C0?ooo`8000000P0cEl800`000000C6[:00000005
000000P0HV>i00@00000081i`@20NL40P7W12000000<0:2If@<000004038ZLP2000000/0nook1P00
00070?ooe@030000003oom00ooo@00H0ooo@00@000000?SobP3holX0n?o:100000030=gog@030000
003oool0oooo05d0oooo001D0?ooo`8000000P0cEl800`000000C6[:04aZbP0304aZbPd000002026
RmD00`000000X9WI0:2If@070:2If@8000000`2WYO/00`000000b:W80<RYb00;0<RYb08000000P3I
n?l2000000X0nook00<000000?_on`3koo/00P3koo/D00000080hooS00D000000=gog@3Momd0gOoM
0000001P0?ooo`00E@3oool200000080<eO200<0000004aZbP1<J/X00`1<J/X00`000000JG_@06Uk
d00606Ukd00300000026RmD0QX_E00T0QX_E00<000000:2If@2PVMT0102PVMT2000000H0YjGk1000
00050<RYb0@000001P3In?l2000000L0nook00<000000?_on`3koo/0203koo/00`000000jOoY0>Wo
j@070>Woj@030000003Son<0hooS00<0hooS00D000000=gog@3Momd0gOoM0000001Q0?ooo`00EP3o
ool200000080<eO200<0000004aZbP1<J/X00`1<J/X00`000000JG_@06Ukd00606Ukd00300000026
RmD0QX_E00T0QX_E00<000000:2If@2PVMT00P2PVMT00`000000YjGk0:NUn`050:NUn`030000002_
/_l0[k;o0080[k;o1@0000040<OIo`030000003In?l0fOSo00D0fOSo00<000000?_on`3koo/00`3k
oo/00`000000nook0?_on`080?_on`030000003YonT0jOoY00L0jOoY00<000000>?oh`3Son<00`3S
on<01@000000gOoM0=gog@3Momd000000680oooo001G0?ooo`8000000P0cEl800`000000C6[:04aZ
bP0304aZbP030000001YNm00JG_@00H0JG_@00<0000008J;e@26RmD02@26RmD010000000X9WI0000
000000070:NUn`030000002_/_l0[k;o00<0[k;o00<000000;[2o`2j`_l00P2j`_l00`000000amWo
0<OIo`020<OIo`030000003In?l0fOSo00D0fOSo0P0000020?_on`030000003koo/0nook00P0nook
00<000000>Woj@3YonT01`3YonT00`000000hooS0>?oh`030>?oh`050000003Momd0gOoM0=gog@00
0000H`3oool005P0oooo0P00000203=G`P030000001<J/X0C6[:00<0C6[:00<0000006Ukd01YNm00
1P1YNm000`000000QX_E08J;e@0808J;e@800000202WYO/00`000000[k;o0:nbo`030:nbo`030000
002j`_l0^/;o00<0^/;o00<000000<OIo`37fOl00`37fOl00`000000fOSo0=Who`060=Who`800000
2`3koo/00`000000jOoY0>Woj@060>Woj@030000003Son<0hooS00<0hooS00D000000=gog@3Momd0
gOoM0000001T0?ooo`00F@3oool200000080<eO200<0000004aZbP1<J/X00`1<J/X00`000000JG_@
06Ukd00606Ukd00300000026RmD0QX_E00D0QX_E0P000002092On`8000001P2WYO/00`000000[k;o
0:nbo`030:nbo`030000002j`_l0^/;o00<0^/;o00<000000<OIo`37fOl01037fOl00`000000fOSo
0=Who`040=Who`030000003Eool0eOoo00800000203koo/00`000000jOoY0>Woj@060>Woj@030000
003Son<0hooS00<0hooS00D000000=gog@3Momd0gOoM0000001U0?ooo`00FP3oool200000080<eO2
00<0000004aZbP1<J/X00`1<J/X00`000000JG_@06Ukd00606Ukd00400000026RmD0QX_E08J;e@<0
00001P2@Wo/2000000<0YjGk00<000000:nbo`2_/_l0102_/_l00`000000^/;o0;[2o`030;[2o`03
00000037fOl0amWo00@0amWo00<000000=Who`3In?l00P3In?l2000000D0eOoo0P0000050?_on`03
0000003YonT0jOoY00H0jOoY00<000000>?oh`3Son<00`3Son<010000000gOoM0=gog@3Momd20000
06D0oooo001K0?ooo`8000000P0cEl800`000000C6[:04aZbP0304aZbP030000001YNm00JG_@00H0
JG_@0`00000;092On`<000001`2_/_l00`000000^/;o0;[2o`040;[2o`0300000037fOl0amWo00@0
amWo00@000000=Who`00000000002@3Eool3000000030?_on`000000jOoY00L0jOoY00<000000>?o
h`3Son<00`3Son<010000000gOoM0=gog@3Momd3000006D0oooo001M0?ooo`80000000<0<eO20000
001<J/X0101<J/X00`000000JG_@06Ukd00206Ukd0H00000302@Wo/4000000D0[k;o00<000000;[2
o`2j`_l0102j`_l00`000000amWo0<OIo`030<OIo`<000003@3Eool4000000H0jOoY00<000000>?o
h`3Son<00`3Son<010000000gOoM0=gog@3Momd4000006D0oooo001N0?ooo`d000001P1gUnT20000
00T0T9ok00<0000009jco`2N/ol00P2N/ol5000000L0^/;o00<000000<OIo`0000000`0000030<7j
o`030000003Eool0eOoo00P0eOoo0P0000040=3oo`@0000000<0jOoY0000003Son<0103Son<80000
06H0oooo001P0?ooo`@00000101MS><2000000T0MiOY00<00000092On`2@Wo/01@2@Wo/00`000000
W[?o09jco`0709jco`X000002031n_l00`000000eOoo0=Goo`050=Goo`8000002@3@ool@000006H0
oooo001R0?ooo`0400000012O]d00000000000@0GHcS0P00000807NGj@800000102@Wo/00`000000
W[?o09jco`0809jco`030000002_b_l0[l[o00H0[l[o00<000000<7jo`31n_l01`31n_l00`000000
eOoo0=Goo`030=Goo`030000003@ool0d?oo00L0d?oo0P0000050<[on0X00000I`3oool006<0oooo
0P0000000`12O]d0000005f<h`0405f<h`800000201gUnT200000003092On`000000W[?o00T0W[?o
00<000000:o:o`2_b_l01`2_b_l00`000000`O[o0<7jo`080<7jo`030000003Eool0eOoo00800000
2@3@ool00`000000b_oh0<[on0030<[on0@0000000<0b:W80000000000001@00001W0?ooo`00I@3o
ool4000000D0GHcS00<0000007NGj@1gUnT01`1gUnT3000000T0W[?o00<000000:o:o`2_b_l01`2_
b_l00`000000`O[o0<7jo`080<7jo`<000002@3@ool2000000@0b_oh0P0000000`32nO8000000000
0008000006P0oooo001W0?ooo`@00000101MS><2000000H0MiOY00@0000008^bo`2;/_l0Rk;o1000
000509jco`030000002_b_l0[l[o00L0[l[o00<000000<7jo`31n_l01031n_l400000080^O;o0P00
00060=3oo`800000103:ooP2000000030<;ilP000000000000T00000J@3oool006T0oooo10000004
05f<h`8000000P1gUnT2000000P0Rk;o100000000`2N/ol000000:o:o`090:o:o`0300000031n_l0
000000<00000202il_l010000000d?oo0=3oo`3@ool2000000D0b_oh00D000000<;ilP0000000000
0;i_<`09000006X0oooo001[0?ooo`0400000012O]d00000000000@0GHcS0P00000>08^bo`h00000
3@2il_l3000000D0b_oh100000000`3AP3<000000;i_<`09000006X0oooo001/0?ooo`@0000000D0
GHcS000000000000000007F]n004000000X0Rk;o00<000000:7;o`2Qbol02@2Qbol00`000000^O;o
0;Wbo`090;Wbo`L000000P3:ooP600000080dH0c2P00001Z0?ooo`00K`3oool5000000D0MJgh1000
000608^bo`030000002Qbol0XL_o00X0XL_o00<000000;Wbo`2il_l0102il_l4000000H0[^Oo1P00
00001038Gc<000000>2?<`0000020=60<`P00000J`3oool007<0oooo1@00000507F]n0@0000000<0
Rk;o0000002Qbol0302Qbol00`000000^O;o0;Wbo`04000000H0[^Oo1@0000050=A_<`8000000P3P
Sc<00`000000dH0c00000006000006`0oooo001e0?ooo`L000001@1e[OPB000000D0[^Oo1P000003
0<9G<`<000000`3DKc<2000000<0h8lc00<000000=j]?P0000001000001]0?ooo`00M`3oool90000
000307F]n0000000TLco00h0TLco00<000000:kWo`2^iol0200000050<9G<`030000003MOT80gGi2
0080000000@0e6lc0000003[W4D000000P3PSc<7000006d0oooo001i0?oooah00000102^C4850000
00030<9G<`000000gGi200<0gGi200H000000>^LA@3[W4D0jia50000003PSc<6000006h0oooo001j
0?ooo`X000000P0c<c<01`000000<c<c03<c<`0c<c<00000048c@P0000000`1M<c<2000000@0TC=2
00<000000:i<@P2^C4800P2^C4800`000000bVY<0<YZC0020<YZC0800000103MOT82000000<0jia5
00D000000>fjE0000000gZdn0000001`0?ooo`00N`3oool90000000303<c<`00000000000080<c<c
00D00000048c@P12<d80000005dc<`020000000307DcC0000000TC=200<0TC=200<000000:i<@P2^
C4800P2^C4800`000000bVY<0<YZC0020<YZC0060000003SS5d000000000003MOT8000000P3bYUd0
0`000000jia50>^LA@02000000030>fjE000000000000700oooo001l0?ooo`L000000P0c<c<01000
0000<c=5000000000004048c@P030000001e<d`0MC=<0080MC=<00@00000094c@P2A<d80TC=21P00
00030<YZC0030000003SS5d0hhaM0080hhaM0P0000030?:VG@80000000<0ml=Z0000003]^U@00P00
001`0?ooo`00OP3oool700000080<c=50P000003048c@P800000101e<d`4000000030:5@HP000000
^F=R0080^F=R1@0000040>><G@8000000`3bYUd2000000030?O3JP000000kKYD00800000L03oool0
07h0oooo1`00000203<cA@8000000P12<d801@000000GC=M05dcG@000000MC=<0080000000<0Rd=Y
0000002QD6800P2QD6801@000000^F=R0;USHP2iHf80000000<0d7]Y0`0000001@3SS5d000000?R]
M@3h[GD000000080lZIM0P0000020?O3JP<00000L03oool00880oooo00D0000003<cE0000000<c=5
0000000203<cG@8000000`1M<ed2000000<0Rd=Y00D000000:5@HP2QD680XE1R000000020;USHP05
0000003@NfT0d7]Y0=1kJ@0000000`3YUgL2000000<0n:ee0P000000103mbGh000000?O3JP3g`fX3
00000700oooo00220?ooo`030000000c<e@00000008000000P0c<ed2000000<0GC=M0P00000308]3
J@030000002QD680000000L0000000<0d7]Y0000003YUgL00P3YUgL2000000<0n:ee0P0000020?g9
OP@00000L@3oool00880oooo00D0000003<cE0000000<c=Z0000000203<cG@050000001<<gD00000
05dcG@0000000P1g?gL00`000000Rd=Y08]3J@0200000080[f^000@000000<5iP031NH0000000P3E
RhH200000080jIMg00P000000?nbR`3o/X/000000?R]M@000000olbA00000080oLUn00@000000?OS
T00000000000L@3oool008<0oooo0P000000100c<fX0000000000000000304`cM@030000001g?gL0
Mcmg0080Mcmg0P0000001@2NHXH000000:m[P02_Jh0000000080`GV000D000000=F;QP3ERhH00000
0?^OT002000000@0ok:;00D000000?o<T@3oc94000000?g9OP02000000030?OST000000000000740
oooo00230?ooo`80000000@0<c=Z0000000c<gh000000P1<<gD300000080Mcmg00<00000091OT000
00000P2NHXH00`000000[f^000000003000000030=F;QP000000nin@0080nin@0P0000020?nbR`80
00000`3oc9401@000000oNFQ0000003ghi0000000780oooo00230?ooo`80000000<0<c=Z0000000c
<gh00P000000101<<gD0000006U3R`1Y@h/200000080T5n@00<0000009iRQP2NHXH00`0000020<N>
W@<000000P3kWi000`000000ok>N0?ncWP0200000080ol^Q00D000000?o<T@00000000000?gUX@03
00000780oooo00240?ooo`<0000000<0<c=n00000012<i400P00000306U3R`8000000P2@Gi020000
00030:n0X0000000^XFM0080000000<0fIVP0000003kYJL00P0000020?ncWP8000000`3obj420000
00030?oW[P000000oNFQ00800000L`3oool008@0oooo1@000002048cT@@000000P26HYh200000005
0:MnY`000000[h2P0000002jQId00P0000001@3IVJ0000000?^UY`000000ok:_008000000P3obZl4
00000080onN^1000001c0?ooo`00Q@3oool20000000503<dX@000000@S>A048cT@0000000P1RD:42
00000080QV:N0P0000000`2WOZL0000000000004000000030?^UY`000000ok:_008000000P3obZl2
00000080oo:i00<000000?oW[P3oijh00`00001d0?ooo`00QP3oool600000080HU2Q00<00000081[
[`0000000P0000000`2PP:l00000000000050<RYb0<0000000H0ol:j00000000000000000?oj`@00
00020?ob^@<0000000<0l_W2000000000000M03oool008H0oooo0P0000000`0c=:400000049<[P05
00000003081[[`000000WHFj00<000001P38ZLP3000000040?oIa`000000oo[10?oj`@@0000000@0
n?o:0000000000000000M@3oool008L0oooo0`0000001P12C:h00000069S^@1RHkT00000081i`@H0
00001P38ZLP8000000030?ood0000000n?o:00<00000MP3oool008P0oooo1`000003081i`@@00000
1P38ZLP400000080oooE00<000000?ood03oom001000001g0?ooo`00R@3oool30000000304aZbP00
0000000000@0000000<0X9WI0000000000001`0000000`3koo/0000000000005000000030>?oh`00
0000000007P0oooo002:0?ooo`@000000P1YNm000`000000QX_E00000002000000030:NUn`000000
[k;o0080000000<0amWo0000003In?l00`0000001@3koo/000000>Woj@000000hooS00<00000N03o
ool008`0oooo1`000002092On`P000000P3Eool8000007T0oooo002>0?ooo`@0000000<0MiOY0000
000000000P2N/ol01@000000[l[o0:o:o`000000`O[o00<0000000<0d?oo0000000000001000001j
0?ooo`00S`3oool=000000030;Wbo`000000000000<0000000@0h8lc0000000000000000NP3oool0
09<0oooo3@0000000`3MOT80000000000002000007/0oooo002D0?ooo`d0000000@0lZIM00000000
00000000N`3oool009D0oooo0P0000000`0c<ed000000000000:000007`0oooo002F0?ooo`h00000
O03oool009H0oooo3@00001m0?ooo`00U`3oool500000080b:W81@00001m0?ooo`00V03oool:0000
07h0oooo002I0?ooo`P00000O`3oool009/0oooo1P00001o0?ooo`00W03oool400000800oooo002M
0?ooo`<00000P03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{849, 831},
WindowMargins->{{142, Automatic}, {Automatic, 10}},
ShowCellLabel->False,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 115, 2, 93, "Title"],
Cell[1894, 57, 98, 2, 41, "Author"],
Cell[1995, 61, 175, 5, 72, "Address"],
Cell[2173, 68, 212, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[2410, 78, 32, 0, 62, "SectionFirst"],
Cell[2445, 80, 302, 5, 44, "Text"],
Cell[2750, 87, 443, 12, 124, "Abstract"],
Cell[3196, 101, 104, 3, 31, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3337, 109, 29, 0, 56, "Section"],
Cell[3369, 111, 95, 2, 27, "Text"],
Cell[3467, 115, 627, 13, 180, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4119, 132, 82, 2, 31, "Input"],
Cell[4204, 136, 29078, 494, 259, 2346, 159, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[33297, 633, 65, 0, 27, "Text"],
Cell[33365, 635, 28582, 488, 259, 2358, 159, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61984, 1128, 41, 0, 56, "Section"],
Cell[62028, 1130, 659, 11, 112, "Text"],

Cell[CellGroupData[{
Cell[62712, 1145, 176, 4, 54, "Input"],
Cell[62891, 1151, 16253, 241, 258, 687, 44, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[79159, 1395, 103, 3, 27, "Text"],
Cell[79265, 1400, 204, 5, 45, "Input",
  InitializationCell->True],
Cell[79472, 1407, 125, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[79622, 1414, 255, 6, 32, "Input"],
Cell[79880, 1422, 83, 2, 43, "Output"]
}, Open  ]],
Cell[79978, 1427, 127, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[80130, 1434, 592, 12, 53, "Input"],
Cell[80725, 1448, 61, 2, 30, "Output"]
}, Open  ]],
Cell[80801, 1453, 118, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[80944, 1460, 607, 12, 53, "Input"],
Cell[81554, 1474, 190, 4, 22, "Message"],
Cell[81747, 1480, 210, 4, 47, "Output"]
}, Open  ]],
Cell[81972, 1487, 56, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[82053, 1491, 587, 11, 53, "Input"],
Cell[82643, 1504, 210, 4, 47, "Output"]
}, Open  ]],
Cell[82868, 1511, 148, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[83041, 1518, 386, 9, 52, "Input"],
Cell[83430, 1529, 24712, 356, 276, 838, 56, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108179, 1890, 38, 0, 43, "Subsection"],
Cell[108220, 1892, 73, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[108318, 1896, 714, 12, 154, "Input"],
Cell[109035, 1910, 81154, 1375, 336, 6853, 452, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[190204, 3288, 227, 6, 28, "Text"],
Cell[190434, 3296, 684, 14, 134, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[191143, 3314, 657, 12, 151, "Input"],
Cell[191803, 3328, 48515, 1091, 181, 9172, 600, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[240333, 4422, 115, 3, 27, "Text"],
Cell[240451, 4427, 584, 12, 185, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[241060, 4443, 657, 12, 151, "Input"],
Cell[241720, 4457, 62298, 1262, 230, 9178, 600, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[304067, 5725, 33, 0, 43, "Subsection"],
Cell[304103, 5727, 205, 4, 44, "Text"],
Cell[304311, 5733, 130, 3, 31, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[304466, 5740, 470, 9, 73, "Input"],
Cell[304939, 5751, 190, 4, 22, "Message"],
Cell[305132, 5757, 303, 5, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[305472, 5767, 439, 10, 94, "Input"],
Cell[305914, 5779, 24946, 365, 276, 947, 64, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[330875, 6147, 253, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[331153, 6155, 192, 4, 50, "Subsubsection"],
Cell[331348, 6161, 171, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[331544, 6168, 176, 4, 43, "Input"],
Cell[331723, 6174, 347, 7, 93, "Output"]
}, Open  ]],
Cell[332085, 6184, 135, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[332245, 6191, 246, 6, 81, "Input"],
Cell[332494, 6199, 450, 7, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332981, 6211, 92, 2, 31, "Input"],
Cell[333076, 6215, 13459, 215, 120, 848, 54, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[346550, 6433, 97, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[346672, 6439, 80, 2, 31, "Input"],
Cell[346755, 6443, 257, 5, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347049, 6453, 153, 4, 44, "Input"],
Cell[347205, 6459, 74, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347316, 6466, 300, 6, 101, "Input"],
Cell[347619, 6474, 213, 4, 55, "Output"],
Cell[347835, 6480, 20213, 299, 296, 816, 54, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[368097, 6785, 316, 5, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[368438, 6794, 263, 5, 104, "Input"],
Cell[368704, 6801, 190, 4, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368931, 6810, 160, 4, 67, "Input"],
Cell[369094, 6816, 190, 4, 22, "Message"],
Cell[369287, 6822, 362, 6, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369686, 6833, 421, 7, 123, "Input"],
Cell[370110, 6842, 285, 5, 54, "Output"]
}, Open  ]],
Cell[370410, 6850, 39, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[370474, 6854, 140, 3, 31, "Input"],
Cell[370617, 6859, 60, 2, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[370738, 6868, 36, 0, 43, "Subsection"],
Cell[370777, 6870, 131, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[370933, 6877, 874, 19, 178, "Input"],
Cell[371810, 6898, 190, 4, 22, "Message"],
Cell[372003, 6904, 172, 3, 47, "Output"],
Cell[372178, 6909, 19313, 289, 178, 866, 56, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[391528, 7203, 642, 14, 178, "Input"],
Cell[392173, 7219, 190, 4, 22, "Message"],
Cell[392366, 7225, 202, 4, 47, "Output"],
Cell[392571, 7231, 15978, 251, 147, 898, 60, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[408610, 7489, 100, 2, 56, "Section"],
Cell[408713, 7493, 544, 11, 205, "Input",
  InitializationCell->True],
Cell[409260, 7506, 44, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[409329, 7510, 877, 15, 231, "Input"],
Cell[410209, 7527, 44364, 1023, 397, 9568, 588, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[454622, 8556, 102, 2, 56, "Section"],

Cell[CellGroupData[{
Cell[454749, 8562, 329, 7, 91, "Input"],
Cell[455081, 8571, 558, 10, 108, "Output"]
}, Open  ]],
Cell[455654, 8584, 35, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[455714, 8588, 220, 5, 59, "Input"],
Cell[455937, 8595, 139, 3, 57, "Output"]
}, Open  ]],
Cell[456091, 8601, 553, 11, 226, "Input",
  InitializationCell->True],
Cell[456647, 8614, 44, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[456716, 8618, 1465, 23, 371, "Input"],
Cell[458184, 8643, 49298, 1265, 245, 13410, 816, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[507531, 9914, 88, 2, 56, "Section"],
Cell[507622, 9918, 125, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[507772, 9925, 246, 5, 71, "Input"],
Cell[508021, 9932, 379, 6, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508437, 9943, 260, 5, 64, "Input"],
Cell[508700, 9950, 177, 3, 52, "Output"]
}, Open  ]],
Cell[508892, 9956, 111, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[509028, 9963, 246, 6, 52, "Input"],
Cell[509277, 9971, 88, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509402, 9978, 737, 13, 167, "Input"],
Cell[510142, 9993, 268, 4, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[510447, 10002, 188, 4, 32, "Input"],
Cell[510638, 10008, 149, 3, 30, "Output"]
}, Open  ]],
Cell[510802, 10014, 110, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[510937, 10021, 325, 5, 95, "Input"],
Cell[511265, 10028, 155, 3, 50, "Output"]
}, Open  ]],
Cell[511435, 10034, 30, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[511490, 10038, 65, 2, 31, "Input"],
Cell[511558, 10042, 170, 4, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511765, 10051, 321, 7, 91, "Input"],
Cell[512089, 10060, 450, 9, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[512576, 10074, 401, 7, 134, "Input"],
Cell[512980, 10083, 129, 3, 47, "Output"]
}, Open  ]],
Cell[513124, 10089, 376, 8, 71, "Input",
  InitializationCell->True],
Cell[513503, 10099, 44, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[513572, 10103, 2122, 33, 511, "Input"],
Cell[515697, 10138, 45319, 994, 355, 8973, 540, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[561065, 11138, 46, 0, 56, "Section"],
Cell[561114, 11140, 54, 0, 27, "Text"],
Cell[561171, 11142, 1842, 36, 511, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[563038, 11182, 109, 2, 34, "Input"],
Cell[563150, 11186, 900, 15, 164, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[564099, 11207, 26, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[564150, 11211, 251, 5, 54, "Input"],
Cell[564404, 11218, 72289, 3275, 258, 46351, 2950, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[636730, 14498, 265, 6, 51, "Input"],
Cell[636998, 14506, 40245, 1327, 231, 14683, 1006, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[677280, 15838, 580, 10, 111, "Input"],
Cell[677863, 15850, 97002, 4359, 296, 61728, 3918, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[774902, 20214, 856, 17, 157, "Input"],
Cell[775761, 20233, 101094, 5187, 296, 77130, 4886, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[876904, 25426, 30, 0, 56, "Section"],
Cell[876937, 25428, 131, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[877093, 25435, 305, 6, 74, "Input"],
Cell[877401, 25443, 310797, 4839, 296, 272467, 4364, "BoxData", "Graphics3D", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1188235, 30287, 517, 11, 134, "Input"],
Cell[1188755, 30300, 6728957, 90432, 296, 6657295, 89545, "BoxData", \
"Graphics3D", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

